(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   9536925,     261586]*)
(*NotebookOutlinePosition[   9543920,     261755]*)
(*  CellTagsIndexPosition[   9543620,     261744]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Laser Radar Example", "Section",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{

Cell["Definitions (Evaluate First)", "Subsection",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{

Cell["createDiskEdge subroutine", "Subsubsection",
  CellTags->"Laser Radar Example"],

Cell["This subroutine generates the edge surfaces of the disk.", "Text",
  CellTags->"Laser Radar Example"],

Cell["Clear[createDiskEdge];", "Input",
  CellTags->"Laser Radar Example"],

Cell["Options[createDiskEdge] = {ComponentRendering->False};", "Input",
  CellTags->"Laser Radar Example"],

Cell["\<\
createDiskEdge[radius_,length_,opts___] :=
Block[{edgesurface, rendering},
\trendering = ComponentRendering/.Flatten[{opts,Options[createDiskEdge]}];
\t
\tedgesurface = ComponentFoundation[radius, {2. radius Cos[30. Degree], \
length}, 
\t\tFlatten[{opts, SurfaceLabel -> CylindricalShape}]];
\tIf[rendering === True,
\t\tedgesurface = ComponentRendering[edgesurface,opts]
\t];
\t
\tMove[
\t\t{
\t\tMove3D[edgesurface, {0,0,radius}, {0,0,-1},0],
\t\tMove3D[Move3D[edgesurface,{0,0,radius}, {0,0,-1},0], \
{0,0,0},{1,0,0},120],
\t\tMove3D[Move3D[edgesurface, {0,0,radius}, {0,0,-1},0], \
{0,0,0},{1,0,0},240]
\t\t},
\t\t.5 length
\t]
];\
\>", "Input",
  AspectRatioFixed->True,
  CellTags->{
  "genetic building-blocks", "creating new components", "Resonate", 
    "using LensSurface", "optical fibers", "Laser Radar Example"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Usage messages", "Subsubsection",
  CellTags->"Laser Radar Example"],

Cell["\<\
TreeDisk::usage = \"TreeDisk[radius, thickness, {topholedensity, \
bottomholedensity}, absorption, surfacescatter, options] is a partially \
reflective thick circular disk with random holes located on its outer \
surfaces that also contains a specified amount of random scattering.\";\
\>", \
"Input",
  CellTags->"Laser Radar Example"],

Cell["\<\
ModelEdge::usage = \"ModelEdge-> True/False is an option of \
TreeDisk that indicates whether the edge surfaces of the disk are modelled \
during the ray-trace.\";\
\>", "Input",
  CellTags->"Laser Radar Example"],

Cell["\<\
FocusEdge::usage = \"FocusEdge-> True/False is an option of \
TreeDisk that indicates whether the disk edge surfaces will direct the light \
rays to a concentrated point, given by the DetectorPosition, or whether the \
edge behaves as a partially reflective mirror.\";\
\>", "Input",
  CellTags->"Laser Radar Example"],

Cell["\<\
DetectorPosition::usage = \"DetectorPosition -> {xpos, ypos, zpos} \
is an option of TreeDisk that indicates the first outer disk surface to \
direct the light rays to a common focal point, {xpos, ypos, zpos}. \
\\n\\nOtherwise, DetectorPosition -> False causes the first disk surface to \
reflect the rays as a classical mirror. Note, that the second outer disk \
surface shall always reflect the rays as a classical mirror and is not \
affected by the DetectorPosition setting.\";\
\>", "Input",
  CellTags->"Laser Radar Example"],

Cell["\<\
TreeTrunk::usage = \"TreeTrunk[radius, height, surfacescatter, \
options] is a partially reflective cylindrical tube that also contains a \
specified amount of random scattering.\";\
\>", "Input",
  CellTags->"Laser Radar Example"]
}, Closed]],

Cell[CellGroupData[{

Cell["TreeDisk source code", "Subsubsection",
  CellTags->"Laser Radar Example"],

Cell["Clear[TreeDisk];", "Input",
  CellTags->"Laser Radar Example"],

Cell["\<\
Options[TreeDisk] :=
\t{
\t\tDetectorPosition -> False,
\t\tReflectance -> 100,
\t\tFocusEfficiency -> 1.,
\t\tModelEdge -> False,
\t\tFocusEdge -> False,
\t\tLabels -> \"\", 
\t\tComponentDescription -> Automatic, 
\t\tGraphicDesign -> Automatic, 
\t\tAutomatic -> {SurfaceRendering -> {{Fill, Trace}}, EdgeRendering -> Fill, \
CrossRendering -> Empty}, 
\t\tSketch -> {SurfaceRendering -> Trace, EdgeRendering -> Trace, \
CrossRendering -> Empty}, 
\t\tWire -> {SurfaceRendering -> Mesh, EdgeRendering -> Mesh, CrossRendering \
-> {{Fill, Trace}}}, 
\t\tSolid -> {SurfaceRendering -> {{Fill, Trace}}, EdgeRendering -> Fill, \
CrossRendering -> Empty}
\t}\
\>", "Input",
  CellTags->"Laser Radar Example"],

Cell["Attributes[TreeDisk] = {HoldAll};", "Input",
  CellTags->"Laser Radar Example"],

Cell["\<\
TreeDisk[radius_, thickness_, {topholedensity_, \
bottomholedensity_}, absorption_, surfacescatter_, options___] :=
Block[{diskcomponent, disksurface1, disksurface2, disksurface3, \
detectorposition, efficiency, edgesurfaces, focusedge, topscatter, \
bottomscatter, opts},
\t
\topts = ModifyElementsOptions[TreeDisk, {radius, thickness, {topholedensity, \
bottomholedensity}, absorption, {topscatter, bottomscatter}}, options];
\t{detectorposition, efficiency, edgesurfaces, focusedge} = 
\t\t{DetectorPosition, FocusEfficiency, ModelEdge, FocusEdge}/.opts;
\t
\tIf[Length[surfacescatter]==2, 
\t\t{topscatter, bottomscatter} = surfacescatter
\t,
\t\ttopscatter = bottomscatter = surfacescatter
\t];
\tIf[Length[topscatter]==0,
\t\ttopscatter = {{-topscatter/2,topscatter/2}}
\t,
\t\ttopscatter = topscatter
\t];
\tIf[Length[bottomscatter]==0,
\t\tbottomscatter = {{-bottomscatter/2,bottomscatter/2}}
\t,
\t\tbottomscatter = bottomscatter
\t];
\t
\t(*define top surface of disk*)
\tIf[Head[detectorposition] =!= Symbol,
\t\tdisksurface1 = 
\t\t\tHole[
\t\t\t\tFocusRays[ComponentFoundation[Infinity,2*radius,opts],\
detectorposition,efficiency,opts]
\t\t\t,
\t\t\t\t{{Function[If[Random[]<topholedensity,True,False]],0}}
\t\t\t]
\t,
\t\tdisksurface1 = 
\t\t\tHole[
\t\t\t\tReflection[ComponentFoundation[Infinity,2*radius,opts],opts]
\t\t\t,
\t\t\t\t{{Function[If[Random[]<topholedensity,True,False]],0}}
\t\t\t]
\t];
\tdisksurface1 = AddRandomRayTilt[disksurface1,topscatter,opts];
\t
\t(*define side edges of disk*)
\tIf[edgesurfaces === True,
\t\tedgesurfaces = createDiskEdge[radius,thickness,opts];
\t\tIf[Length[detectorposition]==3 && focusedge === True,
\t\t\tedgesurfaces = \
Hole[FocusRays[edgesurfaces,detectorposition,efficiency,opts],
\t\t\t\t{{Function[If[Random[]<topholedensity,True,False]],0}}]
\t\t,
\t\t\tedgesurfaces = Hole[Reflection[edgesurfaces,opts],
\t\t\t\t{{Function[If[Random[]<topholedensity,True,False]],0}}]
\t\t];
\t\tedgesurfaces = AddRandomRayTilt[edgesurfaces,bottomscatter,opts]
\t,
\t\tedgesurfaces = {}
\t];
\t
\t(*define interior absorption of disk*)
\tdisksurface2 = Screen[2*radius, \
ModelIntensity->Function[(Intensity*(1-absorption))/.#], 
\t\tGraphicDesign->Off,opts];
\t
\t(*define bottom surface of disk*)
\tdisksurface3 = 
\t\tHole[
\t\t\tReflection[ComponentFoundation[Infinity,2*radius,opts],opts]
\t\t,
\t\t\t{{Function[If[Random[]<bottomholedensity,True,False]],0}}
\t\t];
\tdisksurface3 = AddRandomRayTilt[disksurface3,bottomscatter,opts];
\t
\t(*combine all disk surfaces*)
\tdiskcomponent = 
\t\tComponentRendering[
\t\t\tFlatten[{
\t\t\t\tdisksurface1,
\t\t\t\tMove[disksurface2, thickness/2],
\t\t\t\tMove[disksurface3,thickness]
\t\t\t}],
\t\t\topts
\t\t];
\tResonate[Flatten[{diskcomponent,edgesurfaces}], opts]
];\
\>", "Input",
  CellTags->"Laser Radar Example"]
}, Closed]],

Cell[CellGroupData[{

Cell["TreeTrunk source code", "Subsubsection",
  CellTags->"Laser Radar Example"],

Cell["Clear[TreeTrunk];", "Input",
  CellTags->"Laser Radar Example"],

Cell["\<\
Options[TreeTrunk] :=
\t{
\t\tDetectorPosition -> False,
\t\tReflectance -> 100,
\t\tFocusEfficiency -> 1.,
\t\tLabels -> \"\", 
\t\tComponentDescription -> Automatic, 
\t\tComponentRendering->True,
\t\tGraphicDesign -> Automatic, 
\t\tAutomatic -> {SurfaceRendering -> {{Fill, Trace}}, EdgeRendering -> Fill, \
CrossRendering -> Empty}, 
\t\tSketch -> {SurfaceRendering -> Trace, EdgeRendering -> Trace, \
CrossRendering -> Empty}, 
\t\tWire -> {SurfaceRendering -> Mesh, EdgeRendering -> Mesh, CrossRendering \
-> {{Fill, Trace}}}, 
\t\tSolid -> {SurfaceRendering -> {{Fill, Trace}}, EdgeRendering -> Fill, \
CrossRendering -> Empty}
\t}\
\>", "Input",
  CellTags->"Laser Radar Example"],

Cell["Attributes[TreeTrunk] = {HoldAll};", "Input",
  CellTags->"Laser Radar Example"],

Cell["\<\
TreeTrunk[radius_, height_, scatter_, options___] :=
Block[{diskcomponent, detectorposition, efficiency, edgesurfaces, \
scatterangles, opts},
\t
\topts = ModifyElementsOptions[TreeTrunk, {radius, height, scatter}, \
options];
\t{detectorposition, efficiency} = {DetectorPosition, FocusEfficiency}/.opts;
\t
\tIf[Length[scatter]==0,
\t\tscatterangles = {{-scatter/2,scatter/2}}
\t,
\t\tscatterangles = scatter
\t];
\t
\t(*define trunk sides*)
\tedgesurfaces = createDiskEdge[radius,height,opts];
\tIf[Length[detectorposition]==3,
\t\tedgesurfaces = FocusRays[edgesurfaces,detectorposition,efficiency,opts]
\t,
\t\tedgesurfaces = Reflection[edgesurfaces, opts]
\t];
\tedgesurfaces = AddRandomRayTilt[edgesurfaces, scatterangles, opts];
\t
\tResonate[edgesurfaces, opts]
];\
\>", "Input",
  CellTags->"Laser Radar Example"]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractTemporalSignal Usage message", "Subsubsection",
  CellTags->"Laser Radar Example"],

Cell["\<\
ExtractTemporalSignal::usage = \
\"ExtractTemporalSignal[tracedresult, timeresolution, meterunit] uses the \
optical path length and intensity information from the traced rays to \
simulate the electronically-detected signal given by the rays passing through \
an apertured surface in space.\";\
\>", "Input",
  CellTags->"Laser Radar Example"]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractTemporalSignal source code", "Subsubsection",
  CellTags->"Laser Radar Example"],

Cell["Clear[ExtractTemporalSignal];", "Input",
  CellTags->"Laser Radar Example"],

Cell["\<\
ExtractTemporalSignal[trace_, timeresolution_, meterunit_] :=
Block[{tracedata},
\tWhich[Head[trace] === TurboSystem || Head[trace] === TurboRays,
\t\ttracedata = Sort[ReadTurboRays[trace,{OpticalLength,Intensity}]]
\t,
\t\tHead[trace] === OpticalSystem,
\t\ttracedata = Sort[ReadRays[trace,{OpticalLength,Intensity}]]
\t,
\t\tHead[trace] === List && FreeQ[trace,TurboSystem] && \
FreeQ[trace,OpticalSystem] && 
\t\tFreeQ[trace,Component] && Length[trace[[1]]] == 2,
\t\ttracedata = trace
\t];
\t
\t(*convert to temporal signal*)
\ttracedata = Map[{#[[1]]/(meterunit*2.998*10^8),#[[2]]}&,tracedata];
\t
\t(*convolve gaussian smoothing function with signal*)
\tCompile[{{tracedata,_Real,2}},
\tMap[
\t\tFunction[{time},
\t\t\t{time, 
\t\t\t\tApply[Plus,
\t\t\t\t\tMap[
\t\t\t\t\t\t(#[[2]]*Exp[-(time-#[[1]])^2/timeresolution^2])&
\t\t\t\t\t,
\t\t\t\t\t\ttracedata
\t\t\t\t\t]
\t\t\t\t]
\t\t\t}
\t\t]
\t,
\t\tTranspose[tracedata][[1]]
\t]][tracedata]
];
\t\
\>", "Input",
  CellTags->"Laser Radar Example"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsection",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{

Cell["\<\
Timing[TurboPlot[
\t{Move[GaussianBeam[10, .3, NumberOfRays->100, MonteCarlo->Stratified, \
FullForm->False], 
\t\t{0,0,1000},{0,0,-1}, 0],
\tfocusedtreecomposite,
\tBoundary[{-150,-150,-150},{150,150,1100}]},RunningCommentary->TurboTrace, \
PlotType->FrontView];]\
\>", "Input",
  CellTags->"Laser Radar Example"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 4.16387 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.50032 0.00317247 0.57501 0.00317247 [
[ 0 0 0 0 ]
[ 1 4.16387 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.50032 .73363 m
.50018 .72819 L
.54123 .72735 L
.50032 .73363 L
.50032 .73363 L
F
.50018 .72819 m
.50005 .72274 L
.58214 .72107 L
.54123 .72735 L
.50018 .72819 L
F
.50005 .72274 m
.49991 .71729 L
.62305 .71479 L
.58214 .72107 L
.50005 .72274 L
F
.50032 .73363 m
.54123 .72735 L
.57949 .72695 L
.50032 .73363 L
.50032 .73363 L
F
.54123 .72735 m
.58214 .72107 L
.65866 .72026 L
.57949 .72695 L
.54123 .72735 L
F
.58214 .72107 m
.62305 .71479 L
.73783 .71358 L
.65866 .72026 L
.58214 .72107 L
F
.50032 .73363 m
.57949 .72695 L
.61235 .727 L
.50032 .73363 L
.50032 .73363 L
F
.57949 .72695 m
.65866 .72026 L
.72439 .72037 L
.61235 .727 L
.57949 .72695 L
F
.65866 .72026 m
.73783 .71358 L
.83642 .71374 L
.72439 .72037 L
.65866 .72026 L
F
.50032 .73363 m
.61235 .727 L
.63758 .7275 L
.50032 .73363 L
.50032 .73363 L
F
.61235 .727 m
.72439 .72037 L
.77484 .72138 L
.63758 .7275 L
.61235 .727 L
F
.72439 .72037 m
.83642 .71374 L
.91211 .71525 L
.77484 .72138 L
.72439 .72037 L
F
.50032 .73363 m
.63758 .7275 L
.65346 .72843 L
.50032 .73363 L
.50032 .73363 L
F
.63758 .7275 m
.77484 .72138 L
.80659 .72322 L
.65346 .72843 L
.63758 .7275 L
F
.77484 .72138 m
.91211 .71525 L
.95973 .71801 L
.80659 .72322 L
.77484 .72138 L
F
.50032 .73363 m
.65346 .72843 L
.65889 .7297 L
.50032 .73363 L
.50032 .73363 L
F
.65346 .72843 m
.80659 .72322 L
.81747 .72577 L
.65889 .7297 L
.65346 .72843 L
F
.80659 .72322 m
.95973 .71801 L
.97604 .72184 L
.81747 .72577 L
.80659 .72322 L
F
.50032 .73363 m
.65889 .7297 L
.65353 .73125 L
.50032 .73363 L
.50032 .73363 L
F
.65889 .7297 m
.81747 .72577 L
.80673 .72886 L
.65353 .73125 L
.65889 .7297 L
F
.81747 .72577 m
.97604 .72184 L
.95994 .72647 L
.80673 .72886 L
.81747 .72577 L
F
.50032 .73363 m
.65353 .73125 L
.63772 .73295 L
.50032 .73363 L
.50032 .73363 L
F
.65353 .73125 m
.80673 .72886 L
.77511 .73227 L
.63772 .73295 L
.65353 .73125 L
F
.80673 .72886 m
.95994 .72647 L
.91251 .73159 L
.77511 .73227 L
.80673 .72886 L
F
.50032 .73363 m
.63772 .73295 L
.61254 .73471 L
.50032 .73363 L
.50032 .73363 L
F
.63772 .73295 m
.77511 .73227 L
.72477 .73578 L
.61254 .73471 L
.63772 .73295 L
F
.77511 .73227 m
.91251 .73159 L
.83699 .73685 L
.72477 .73578 L
.77511 .73227 L
F
.50032 .73363 m
.61254 .73471 L
.57972 .73639 L
.50032 .73363 L
.50032 .73363 L
F
.61254 .73471 m
.72477 .73578 L
.65913 .73914 L
.57972 .73639 L
.61254 .73471 L
F
.72477 .73578 m
.83699 .73685 L
.73853 .74189 L
.65913 .73914 L
.72477 .73578 L
F
.50032 .73363 m
.57972 .73639 L
.54149 .73788 L
.50032 .73363 L
.50032 .73363 L
F
.57972 .73639 m
.65913 .73914 L
.58267 .74213 L
.54149 .73788 L
.57972 .73639 L
F
.65913 .73914 m
.73853 .74189 L
.62384 .74637 L
.58267 .74213 L
.65913 .73914 L
F
.50032 .73363 m
.54149 .73788 L
.50045 .73908 L
.50032 .73363 L
.50032 .73363 L
F
.54149 .73788 m
.58267 .74213 L
.50059 .74453 L
.50045 .73908 L
.54149 .73788 L
F
.58267 .74213 m
.62384 .74637 L
.50073 .74998 L
.50059 .74453 L
.58267 .74213 L
F
.50032 .73363 m
.50045 .73908 L
.45941 .73991 L
.50032 .73363 L
.50032 .73363 L
F
.50045 .73908 m
.50059 .74453 L
.4185 .7462 L
.45941 .73991 L
.50045 .73908 L
F
.50059 .74453 m
.50073 .74998 L
.37758 .75248 L
.4185 .7462 L
.50059 .74453 L
F
.50032 .73363 m
.45941 .73991 L
.42115 .74032 L
.50032 .73363 L
.50032 .73363 L
F
.45941 .73991 m
.4185 .7462 L
.34198 .747 L
.42115 .74032 L
.45941 .73991 L
F
.4185 .7462 m
.37758 .75248 L
.26281 .75369 L
.34198 .747 L
.4185 .7462 L
F
.50032 .73363 m
.42115 .74032 L
.38829 .74027 L
.50032 .73363 L
.50032 .73363 L
F
.42115 .74032 m
.34198 .747 L
.27625 .7469 L
.38829 .74027 L
.42115 .74032 L
F
.34198 .747 m
.26281 .75369 L
.16422 .75353 L
.27625 .7469 L
.34198 .747 L
F
.50032 .73363 m
.38829 .74027 L
.36306 .73976 L
.50032 .73363 L
.50032 .73363 L
F
.38829 .74027 m
.27625 .7469 L
.2258 .74589 L
.36306 .73976 L
.38829 .74027 L
F
.27625 .7469 m
.16422 .75353 L
.08853 .75202 L
.2258 .74589 L
.27625 .7469 L
F
.50032 .73363 m
.36306 .73976 L
.34718 .73884 L
.50032 .73363 L
.50032 .73363 L
F
.36306 .73976 m
.2258 .74589 L
.19405 .74405 L
.34718 .73884 L
.36306 .73976 L
F
.2258 .74589 m
.08853 .75202 L
.04091 .74926 L
.19405 .74405 L
.2258 .74589 L
F
.50032 .73363 m
.34718 .73884 L
.34174 .73757 L
.50032 .73363 L
.50032 .73363 L
F
.34718 .73884 m
.19405 .74405 L
.18317 .7415 L
.34174 .73757 L
.34718 .73884 L
F
.19405 .74405 m
.04091 .74926 L
.0246 .74543 L
.18317 .7415 L
.19405 .74405 L
F
.50032 .73363 m
.34174 .73757 L
.34711 .73602 L
.50032 .73363 L
.50032 .73363 L
F
.34174 .73757 m
.18317 .7415 L
.19391 .73841 L
.34711 .73602 L
.34174 .73757 L
F
.18317 .7415 m
.0246 .74543 L
.0407 .7408 L
.19391 .73841 L
.18317 .7415 L
F
.50032 .73363 m
.34711 .73602 L
.36292 .73431 L
.50032 .73363 L
.50032 .73363 L
F
.34711 .73602 m
.19391 .73841 L
.22553 .73499 L
.36292 .73431 L
.34711 .73602 L
F
.19391 .73841 m
.0407 .7408 L
.08813 .73567 L
.22553 .73499 L
.19391 .73841 L
F
.50032 .73363 m
.36292 .73431 L
.38809 .73256 L
.50032 .73363 L
.50032 .73363 L
F
.36292 .73431 m
.22553 .73499 L
.27587 .73149 L
.38809 .73256 L
.36292 .73431 L
F
.22553 .73499 m
.08813 .73567 L
.16365 .73041 L
.27587 .73149 L
.22553 .73499 L
F
.50032 .73363 m
.38809 .73256 L
.42092 .73088 L
.50032 .73363 L
.50032 .73363 L
F
.38809 .73256 m
.27587 .73149 L
.34151 .72813 L
.42092 .73088 L
.38809 .73256 L
F
.27587 .73149 m
.16365 .73041 L
.26211 .72537 L
.34151 .72813 L
.27587 .73149 L
F
.50032 .73363 m
.42092 .73088 L
.45915 .72939 L
.50032 .73363 L
.50032 .73363 L
F
.42092 .73088 m
.34151 .72813 L
.41797 .72514 L
.45915 .72939 L
.42092 .73088 L
F
.34151 .72813 m
.26211 .72537 L
.3768 .7209 L
.41797 .72514 L
.34151 .72813 L
F
.50032 .73363 m
.45915 .72939 L
.50018 .72819 L
.50032 .73363 L
.50032 .73363 L
F
.45915 .72939 m
.41797 .72514 L
.50005 .72274 L
.50018 .72819 L
.45915 .72939 L
F
.41797 .72514 m
.3768 .7209 L
.49991 .71729 L
.50005 .72274 L
.41797 .72514 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.49991 .71729 m
.62305 .71479 L
.73783 .71358 L
.83642 .71374 L
.91211 .71525 L
.95973 .71801 L
.97604 .72184 L
.95994 .72647 L
.91251 .73159 L
.83699 .73685 L
.73853 .74189 L
.62384 .74637 L
.50073 .74998 L
.37758 .75248 L
.26281 .75369 L
.16422 .75353 L
.08853 .75202 L
.04091 .74926 L
.0246 .74543 L
.0407 .7408 L
.08813 .73567 L
.16365 .73041 L
.26211 .72537 L
.3768 .7209 L
.49991 .71729 L
s
.5 g
.49993 .71779 m
.49979 .71234 L
.54084 .71151 L
.49993 .71779 L
.49993 .71779 L
F
.49979 .71234 m
.49966 .70689 L
.58175 .70522 L
.54084 .71151 L
.49979 .71234 L
F
.49966 .70689 m
.49952 .70144 L
.62266 .69894 L
.58175 .70522 L
.49966 .70689 L
F
.49993 .71779 m
.54084 .71151 L
.5791 .7111 L
.49993 .71779 L
.49993 .71779 L
F
.54084 .71151 m
.58175 .70522 L
.65827 .70442 L
.5791 .7111 L
.54084 .71151 L
F
.58175 .70522 m
.62266 .69894 L
.73744 .69773 L
.65827 .70442 L
.58175 .70522 L
F
.49993 .71779 m
.5791 .7111 L
.61196 .71115 L
.49993 .71779 L
.49993 .71779 L
F
.5791 .7111 m
.65827 .70442 L
.72399 .70452 L
.61196 .71115 L
.5791 .7111 L
F
.65827 .70442 m
.73744 .69773 L
.83603 .69789 L
.72399 .70452 L
.65827 .70442 L
F
.49993 .71779 m
.61196 .71115 L
.63719 .71166 L
.49993 .71779 L
.49993 .71779 L
F
.61196 .71115 m
.72399 .70452 L
.77445 .70553 L
.63719 .71166 L
.61196 .71115 L
F
.72399 .70452 m
.83603 .69789 L
.91171 .6994 L
.77445 .70553 L
.72399 .70452 L
F
.49993 .71779 m
.63719 .71166 L
.65306 .71258 L
.49993 .71779 L
.49993 .71779 L
F
.63719 .71166 m
.77445 .70553 L
.8062 .70737 L
.65306 .71258 L
.63719 .71166 L
F
.77445 .70553 m
.91171 .6994 L
.95934 .70216 L
.8062 .70737 L
.77445 .70553 L
F
.49993 .71779 m
.65306 .71258 L
.6585 .71385 L
.49993 .71779 L
.49993 .71779 L
F
.65306 .71258 m
.8062 .70737 L
.81708 .70992 L
.6585 .71385 L
.65306 .71258 L
F
.8062 .70737 m
.95934 .70216 L
.97565 .70599 L
.81708 .70992 L
.8062 .70737 L
F
.49993 .71779 m
.6585 .71385 L
.65313 .7154 L
.49993 .71779 L
.49993 .71779 L
F
.6585 .71385 m
.81708 .70992 L
.80634 .71301 L
.65313 .7154 L
.6585 .71385 L
F
.81708 .70992 m
.97565 .70599 L
.95955 .71062 L
.80634 .71301 L
.81708 .70992 L
F
.49993 .71779 m
.65313 .7154 L
.63732 .71711 L
.49993 .71779 L
.49993 .71779 L
F
.65313 .7154 m
.80634 .71301 L
.77472 .71643 L
.63732 .71711 L
.65313 .7154 L
F
.80634 .71301 m
.95955 .71062 L
.91212 .71575 L
.77472 .71643 L
.80634 .71301 L
F
.49993 .71779 m
.63732 .71711 L
.61215 .71886 L
.49993 .71779 L
.49993 .71779 L
F
.63732 .71711 m
.77472 .71643 L
.72438 .71993 L
.61215 .71886 L
.63732 .71711 L
F
.77472 .71643 m
.91212 .71575 L
.8366 .72101 L
.72438 .71993 L
.77472 .71643 L
F
.49993 .71779 m
.61215 .71886 L
.57933 .72054 L
.49993 .71779 L
.49993 .71779 L
F
.61215 .71886 m
.72438 .71993 L
.65874 .72329 L
.57933 .72054 L
.61215 .71886 L
F
.72438 .71993 m
.8366 .72101 L
.73814 .72605 L
.65874 .72329 L
.72438 .71993 L
F
.49993 .71779 m
.57933 .72054 L
.5411 .72203 L
.49993 .71779 L
.49993 .71779 L
F
.57933 .72054 m
.65874 .72329 L
.58227 .72628 L
.5411 .72203 L
.57933 .72054 L
F
.65874 .72329 m
.73814 .72605 L
.62344 .73052 L
.58227 .72628 L
.65874 .72329 L
F
.49993 .71779 m
.5411 .72203 L
.50006 .72323 L
.49993 .71779 L
.49993 .71779 L
F
.5411 .72203 m
.58227 .72628 L
.5002 .72868 L
.50006 .72323 L
.5411 .72203 L
F
.58227 .72628 m
.62344 .73052 L
.50033 .73413 L
.5002 .72868 L
.58227 .72628 L
F
.49993 .71779 m
.50006 .72323 L
.45902 .72407 L
.49993 .71779 L
.49993 .71779 L
F
.50006 .72323 m
.5002 .72868 L
.4181 .73035 L
.45902 .72407 L
.50006 .72323 L
F
.5002 .72868 m
.50033 .73413 L
.37719 .73663 L
.4181 .73035 L
.5002 .72868 L
F
.49993 .71779 m
.45902 .72407 L
.42076 .72447 L
.49993 .71779 L
.49993 .71779 L
F
.45902 .72407 m
.4181 .73035 L
.34159 .73115 L
.42076 .72447 L
.45902 .72407 L
F
.4181 .73035 m
.37719 .73663 L
.26242 .73784 L
.34159 .73115 L
.4181 .73035 L
F
.49993 .71779 m
.42076 .72447 L
.38789 .72442 L
.49993 .71779 L
.49993 .71779 L
F
.42076 .72447 m
.34159 .73115 L
.27586 .73105 L
.38789 .72442 L
.42076 .72447 L
F
.34159 .73115 m
.26242 .73784 L
.16383 .73768 L
.27586 .73105 L
.34159 .73115 L
F
.49993 .71779 m
.38789 .72442 L
.36266 .72391 L
.49993 .71779 L
.49993 .71779 L
F
.38789 .72442 m
.27586 .73105 L
.2254 .73004 L
.36266 .72391 L
.38789 .72442 L
F
.27586 .73105 m
.16383 .73768 L
.08814 .73617 L
.2254 .73004 L
.27586 .73105 L
F
.49993 .71779 m
.36266 .72391 L
.34679 .72299 L
.49993 .71779 L
.49993 .71779 L
F
.36266 .72391 m
.2254 .73004 L
.19365 .7282 L
.34679 .72299 L
.36266 .72391 L
F
.2254 .73004 m
.08814 .73617 L
.04052 .73341 L
.19365 .7282 L
.2254 .73004 L
F
.49993 .71779 m
.34679 .72299 L
.34135 .72172 L
.49993 .71779 L
.49993 .71779 L
F
.34679 .72299 m
.19365 .7282 L
.18278 .72565 L
.34135 .72172 L
.34679 .72299 L
F
.19365 .7282 m
.04052 .73341 L
.0242 .72958 L
.18278 .72565 L
.19365 .7282 L
F
.49993 .71779 m
.34135 .72172 L
.34672 .72017 L
.49993 .71779 L
.49993 .71779 L
F
.34135 .72172 m
.18278 .72565 L
.19351 .72256 L
.34672 .72017 L
.34135 .72172 L
F
.18278 .72565 m
.0242 .72958 L
.04031 .72495 L
.19351 .72256 L
.18278 .72565 L
F
.49993 .71779 m
.34672 .72017 L
.36253 .71847 L
.49993 .71779 L
.49993 .71779 L
F
.34672 .72017 m
.19351 .72256 L
.22513 .71915 L
.36253 .71847 L
.34672 .72017 L
F
.19351 .72256 m
.04031 .72495 L
.08773 .71983 L
.22513 .71915 L
.19351 .72256 L
F
.49993 .71779 m
.36253 .71847 L
.3877 .71671 L
.49993 .71779 L
.49993 .71779 L
F
.36253 .71847 m
.22513 .71915 L
.27548 .71564 L
.3877 .71671 L
.36253 .71847 L
F
.22513 .71915 m
.08773 .71983 L
.16325 .71457 L
.27548 .71564 L
.22513 .71915 L
F
.49993 .71779 m
.3877 .71671 L
.42052 .71503 L
.49993 .71779 L
.49993 .71779 L
F
.3877 .71671 m
.27548 .71564 L
.34112 .71228 L
.42052 .71503 L
.3877 .71671 L
F
.27548 .71564 m
.16325 .71457 L
.26171 .70953 L
.34112 .71228 L
.27548 .71564 L
F
.49993 .71779 m
.42052 .71503 L
.45875 .71354 L
.49993 .71779 L
.49993 .71779 L
F
.42052 .71503 m
.34112 .71228 L
.41758 .70929 L
.45875 .71354 L
.42052 .71503 L
F
.34112 .71228 m
.26171 .70953 L
.37641 .70505 L
.41758 .70929 L
.34112 .71228 L
F
.49993 .71779 m
.45875 .71354 L
.49979 .71234 L
.49993 .71779 L
.49993 .71779 L
F
.45875 .71354 m
.41758 .70929 L
.49966 .70689 L
.49979 .71234 L
.45875 .71354 L
F
.41758 .70929 m
.37641 .70505 L
.49952 .70144 L
.49966 .70689 L
.41758 .70929 L
F
0 g
.49952 .70144 m
.62266 .69894 L
.73744 .69773 L
.83603 .69789 L
.91171 .6994 L
.95934 .70216 L
.97565 .70599 L
.95955 .71062 L
.91212 .71575 L
.8366 .72101 L
.73814 .72605 L
.62344 .73052 L
.50033 .73413 L
.37719 .73663 L
.26242 .73784 L
.16383 .73768 L
.08814 .73617 L
.04052 .73341 L
.0242 .72958 L
.04031 .72495 L
.08773 .71983 L
.16325 .71457 L
.26171 .70953 L
.37641 .70505 L
.49952 .70144 L
s
.5 g
.49953 .70194 m
.4994 .69652 L
.54024 .69569 L
.49953 .70194 L
.49953 .70194 L
F
.4994 .69652 m
.49927 .69109 L
.58095 .68944 L
.54024 .69569 L
.4994 .69652 L
F
.49927 .69109 m
.49913 .68567 L
.62166 .68319 L
.58095 .68944 L
.49927 .69109 L
F
.49953 .70194 m
.54024 .69569 L
.57831 .69529 L
.49953 .70194 L
.49953 .70194 L
F
.54024 .69569 m
.58095 .68944 L
.65708 .68864 L
.57831 .69529 L
.54024 .69569 L
F
.58095 .68944 m
.62166 .68319 L
.73586 .68198 L
.65708 .68864 L
.58095 .68944 L
F
.49953 .70194 m
.57831 .69529 L
.61101 .69534 L
.49953 .70194 L
.49953 .70194 L
F
.57831 .69529 m
.65708 .68864 L
.72248 .68874 L
.61101 .69534 L
.57831 .69529 L
F
.65708 .68864 m
.73586 .68198 L
.83395 .68214 L
.72248 .68874 L
.65708 .68864 L
F
.49953 .70194 m
.61101 .69534 L
.63611 .69584 L
.49953 .70194 L
.49953 .70194 L
F
.61101 .69534 m
.72248 .68874 L
.77269 .68974 L
.63611 .69584 L
.61101 .69534 L
F
.72248 .68874 m
.83395 .68214 L
.90926 .68364 L
.77269 .68974 L
.72248 .68874 L
F
.49953 .70194 m
.63611 .69584 L
.6519 .69676 L
.49953 .70194 L
.49953 .70194 L
F
.63611 .69584 m
.77269 .68974 L
.80428 .69157 L
.6519 .69676 L
.63611 .69584 L
F
.77269 .68974 m
.90926 .68364 L
.95665 .68639 L
.80428 .69157 L
.77269 .68974 L
F
.49953 .70194 m
.6519 .69676 L
.65732 .69803 L
.49953 .70194 L
.49953 .70194 L
F
.6519 .69676 m
.80428 .69157 L
.8151 .69411 L
.65732 .69803 L
.6519 .69676 L
F
.80428 .69157 m
.95665 .68639 L
.97288 .6902 L
.8151 .69411 L
.80428 .69157 L
F
.49953 .70194 m
.65732 .69803 L
.65197 .69956 L
.49953 .70194 L
.49953 .70194 L
F
.65732 .69803 m
.8151 .69411 L
.80441 .69719 L
.65197 .69956 L
.65732 .69803 L
F
.8151 .69411 m
.97288 .6902 L
.95686 .69481 L
.80441 .69719 L
.8151 .69411 L
F
.49953 .70194 m
.65197 .69956 L
.63624 .70126 L
.49953 .70194 L
.49953 .70194 L
F
.65197 .69956 m
.80441 .69719 L
.77295 .70058 L
.63624 .70126 L
.65197 .69956 L
F
.80441 .69719 m
.95686 .69481 L
.90967 .69991 L
.77295 .70058 L
.80441 .69719 L
F
.49953 .70194 m
.63624 .70126 L
.6112 .70301 L
.49953 .70194 L
.49953 .70194 L
F
.63624 .70126 m
.77295 .70058 L
.72286 .70407 L
.6112 .70301 L
.63624 .70126 L
F
.77295 .70058 m
.90967 .69991 L
.83453 .70514 L
.72286 .70407 L
.77295 .70058 L
F
.49953 .70194 m
.6112 .70301 L
.57854 .70468 L
.49953 .70194 L
.49953 .70194 L
F
.6112 .70301 m
.72286 .70407 L
.65755 .70742 L
.57854 .70468 L
.6112 .70301 L
F
.72286 .70407 m
.83453 .70514 L
.73656 .71016 L
.65755 .70742 L
.72286 .70407 L
F
.49953 .70194 m
.57854 .70468 L
.5405 .70616 L
.49953 .70194 L
.49953 .70194 L
F
.57854 .70468 m
.65755 .70742 L
.58147 .71039 L
.5405 .70616 L
.57854 .70468 L
F
.65755 .70742 m
.73656 .71016 L
.62243 .71461 L
.58147 .71039 L
.65755 .70742 L
F
.49953 .70194 m
.5405 .70616 L
.49967 .70736 L
.49953 .70194 L
.49953 .70194 L
F
.5405 .70616 m
.58147 .71039 L
.4998 .71278 L
.49967 .70736 L
.5405 .70616 L
F
.58147 .71039 m
.62243 .71461 L
.49994 .7182 L
.4998 .71278 L
.58147 .71039 L
F
.49953 .70194 m
.49967 .70736 L
.45883 .70819 L
.49953 .70194 L
.49953 .70194 L
F
.49967 .70736 m
.4998 .71278 L
.41812 .71444 L
.45883 .70819 L
.49967 .70736 L
F
.4998 .71278 m
.49994 .7182 L
.37741 .72069 L
.41812 .71444 L
.4998 .71278 L
F
.49953 .70194 m
.45883 .70819 L
.42076 .70859 L
.49953 .70194 L
.49953 .70194 L
F
.45883 .70819 m
.41812 .71444 L
.34198 .71524 L
.42076 .70859 L
.45883 .70819 L
F
.41812 .71444 m
.37741 .72069 L
.26321 .72189 L
.34198 .71524 L
.41812 .71444 L
F
.49953 .70194 m
.42076 .70859 L
.38806 .70854 L
.49953 .70194 L
.49953 .70194 L
F
.42076 .70859 m
.34198 .71524 L
.27659 .71514 L
.38806 .70854 L
.42076 .70859 L
F
.34198 .71524 m
.26321 .72189 L
.16511 .72174 L
.27659 .71514 L
.34198 .71524 L
F
.49953 .70194 m
.38806 .70854 L
.36296 .70804 L
.49953 .70194 L
.49953 .70194 L
F
.38806 .70854 m
.27659 .71514 L
.22638 .71413 L
.36296 .70804 L
.38806 .70854 L
F
.27659 .71514 m
.16511 .72174 L
.08981 .72023 L
.22638 .71413 L
.27659 .71514 L
F
.49953 .70194 m
.36296 .70804 L
.34716 .70712 L
.49953 .70194 L
.49953 .70194 L
F
.36296 .70804 m
.22638 .71413 L
.19479 .7123 L
.34716 .70712 L
.36296 .70804 L
F
.22638 .71413 m
.08981 .72023 L
.04242 .71748 L
.19479 .7123 L
.22638 .71413 L
F
.49953 .70194 m
.34716 .70712 L
.34175 .70585 L
.49953 .70194 L
.49953 .70194 L
F
.34716 .70712 m
.19479 .7123 L
.18397 .70976 L
.34175 .70585 L
.34716 .70712 L
F
.19479 .7123 m
.04242 .71748 L
.02619 .71367 L
.18397 .70976 L
.19479 .7123 L
F
.49953 .70194 m
.34175 .70585 L
.34709 .70431 L
.49953 .70194 L
.49953 .70194 L
F
.34175 .70585 m
.18397 .70976 L
.19465 .70669 L
.34709 .70431 L
.34175 .70585 L
F
.18397 .70976 m
.02619 .71367 L
.04221 .70906 L
.19465 .70669 L
.18397 .70976 L
F
.49953 .70194 m
.34709 .70431 L
.36282 .70261 L
.49953 .70194 L
.49953 .70194 L
F
.34709 .70431 m
.19465 .70669 L
.22611 .70329 L
.36282 .70261 L
.34709 .70431 L
F
.19465 .70669 m
.04221 .70906 L
.0894 .70397 L
.22611 .70329 L
.19465 .70669 L
F
.49953 .70194 m
.36282 .70261 L
.38787 .70087 L
.49953 .70194 L
.49953 .70194 L
F
.36282 .70261 m
.22611 .70329 L
.27621 .6998 L
.38787 .70087 L
.36282 .70261 L
F
.22611 .70329 m
.0894 .70397 L
.16454 .69873 L
.27621 .6998 L
.22611 .70329 L
F
.49953 .70194 m
.38787 .70087 L
.42053 .6992 L
.49953 .70194 L
.49953 .70194 L
F
.38787 .70087 m
.27621 .6998 L
.34152 .69646 L
.42053 .6992 L
.38787 .70087 L
F
.27621 .6998 m
.16454 .69873 L
.26251 .69372 L
.34152 .69646 L
.27621 .6998 L
F
.49953 .70194 m
.42053 .6992 L
.45857 .69771 L
.49953 .70194 L
.49953 .70194 L
F
.42053 .6992 m
.34152 .69646 L
.4176 .69349 L
.45857 .69771 L
.42053 .6992 L
F
.34152 .69646 m
.26251 .69372 L
.37663 .68926 L
.4176 .69349 L
.34152 .69646 L
F
.49953 .70194 m
.45857 .69771 L
.4994 .69652 L
.49953 .70194 L
.49953 .70194 L
F
.45857 .69771 m
.4176 .69349 L
.49927 .69109 L
.4994 .69652 L
.45857 .69771 L
F
.4176 .69349 m
.37663 .68926 L
.49913 .68567 L
.49927 .69109 L
.4176 .69349 L
F
0 g
.49913 .68559 m
.62227 .6831 L
.73705 .68188 L
.83564 .68204 L
.91132 .68355 L
.95894 .68631 L
.97526 .69014 L
.95915 .69478 L
.91173 .6999 L
.83621 .70516 L
.73775 .7102 L
.62305 .71467 L
.49994 .71828 L
.3768 .72078 L
.26202 .72199 L
.16343 .72184 L
.08775 .72032 L
.04012 .71756 L
.02381 .71373 L
.03991 .7091 L
.08734 .70398 L
.16286 .69872 L
.26132 .69368 L
.37602 .6892 L
.49913 .68559 L
s
.5 g
.49991 .71729 m
.49952 .70144 L
.62266 .69894 L
.62305 .71479 L
.49991 .71729 L
F
.62305 .71479 m
.62266 .69894 L
.73744 .69773 L
.73783 .71358 L
.62305 .71479 L
F
.73783 .71358 m
.73744 .69773 L
.83603 .69789 L
.83642 .71374 L
.73783 .71358 L
F
.83642 .71374 m
.83603 .69789 L
.91171 .6994 L
.91211 .71525 L
.83642 .71374 L
F
.91211 .71525 m
.91171 .6994 L
.95934 .70216 L
.95973 .71801 L
.91211 .71525 L
F
.95973 .71801 m
.95934 .70216 L
.97565 .70599 L
.97604 .72184 L
.95973 .71801 L
F
.97604 .72184 m
.97565 .70599 L
.95955 .71062 L
.95994 .72647 L
.97604 .72184 L
F
.95994 .72647 m
.95955 .71062 L
.91212 .71575 L
.91251 .73159 L
.95994 .72647 L
F
.91251 .73159 m
.91212 .71575 L
.8366 .72101 L
.83699 .73685 L
.91251 .73159 L
F
.83699 .73685 m
.8366 .72101 L
.73814 .72605 L
.73853 .74189 L
.83699 .73685 L
F
.73853 .74189 m
.73814 .72605 L
.62344 .73052 L
.62384 .74637 L
.73853 .74189 L
F
.62384 .74637 m
.62344 .73052 L
.50033 .73413 L
.50073 .74998 L
.62384 .74637 L
F
.50073 .74998 m
.50033 .73413 L
.37719 .73663 L
.37758 .75248 L
.50073 .74998 L
F
.37758 .75248 m
.37719 .73663 L
.26242 .73784 L
.26281 .75369 L
.37758 .75248 L
F
.26281 .75369 m
.26242 .73784 L
.16383 .73768 L
.16422 .75353 L
.26281 .75369 L
F
.16422 .75353 m
.16383 .73768 L
.08814 .73617 L
.08853 .75202 L
.16422 .75353 L
F
.08853 .75202 m
.08814 .73617 L
.04052 .73341 L
.04091 .74926 L
.08853 .75202 L
F
.04091 .74926 m
.04052 .73341 L
.0242 .72958 L
.0246 .74543 L
.04091 .74926 L
F
.0246 .74543 m
.0242 .72958 L
.04031 .72495 L
.0407 .7408 L
.0246 .74543 L
F
.0407 .7408 m
.04031 .72495 L
.08773 .71983 L
.08813 .73567 L
.0407 .7408 L
F
.08813 .73567 m
.08773 .71983 L
.16325 .71457 L
.16365 .73041 L
.08813 .73567 L
F
.16365 .73041 m
.16325 .71457 L
.26171 .70953 L
.26211 .72537 L
.16365 .73041 L
F
.26211 .72537 m
.26171 .70953 L
.37641 .70505 L
.3768 .7209 L
.26211 .72537 L
F
.3768 .7209 m
.37641 .70505 L
.49952 .70144 L
.49991 .71729 L
.3768 .7209 L
F
.49952 .70144 m
.49913 .68559 L
.62227 .6831 L
.62266 .69894 L
.49952 .70144 L
F
.62266 .69894 m
.62227 .6831 L
.73705 .68188 L
.73744 .69773 L
.62266 .69894 L
F
.73744 .69773 m
.73705 .68188 L
.83564 .68204 L
.83603 .69789 L
.73744 .69773 L
F
.83603 .69789 m
.83564 .68204 L
.91132 .68355 L
.91171 .6994 L
.83603 .69789 L
F
.91171 .6994 m
.91132 .68355 L
.95894 .68631 L
.95934 .70216 L
.91171 .6994 L
F
.95934 .70216 m
.95894 .68631 L
.97526 .69014 L
.97565 .70599 L
.95934 .70216 L
F
.97565 .70599 m
.97526 .69014 L
.95915 .69478 L
.95955 .71062 L
.97565 .70599 L
F
.95955 .71062 m
.95915 .69478 L
.91173 .6999 L
.91212 .71575 L
.95955 .71062 L
F
.91212 .71575 m
.91173 .6999 L
.83621 .70516 L
.8366 .72101 L
.91212 .71575 L
F
.8366 .72101 m
.83621 .70516 L
.73775 .7102 L
.73814 .72605 L
.8366 .72101 L
F
.73814 .72605 m
.73775 .7102 L
.62305 .71467 L
.62344 .73052 L
.73814 .72605 L
F
.62344 .73052 m
.62305 .71467 L
.49994 .71828 L
.50033 .73413 L
.62344 .73052 L
F
.50033 .73413 m
.49994 .71828 L
.3768 .72078 L
.37719 .73663 L
.50033 .73413 L
F
.37719 .73663 m
.3768 .72078 L
.26202 .72199 L
.26242 .73784 L
.37719 .73663 L
F
.26242 .73784 m
.26202 .72199 L
.16343 .72184 L
.16383 .73768 L
.26242 .73784 L
F
.16383 .73768 m
.16343 .72184 L
.08775 .72032 L
.08814 .73617 L
.16383 .73768 L
F
.08814 .73617 m
.08775 .72032 L
.04012 .71756 L
.04052 .73341 L
.08814 .73617 L
F
.04052 .73341 m
.04012 .71756 L
.02381 .71373 L
.0242 .72958 L
.04052 .73341 L
F
.0242 .72958 m
.02381 .71373 L
.03991 .7091 L
.04031 .72495 L
.0242 .72958 L
F
.04031 .72495 m
.03991 .7091 L
.08734 .70398 L
.08773 .71983 L
.04031 .72495 L
F
.08773 .71983 m
.08734 .70398 L
.16286 .69872 L
.16325 .71457 L
.08773 .71983 L
F
.16325 .71457 m
.16286 .69872 L
.26132 .69368 L
.26171 .70953 L
.16325 .71457 L
F
.26171 .70953 m
.26132 .69368 L
.37602 .6892 L
.37641 .70505 L
.26171 .70953 L
F
.37641 .70505 m
.37602 .6892 L
.49913 .68559 L
.49952 .70144 L
.37641 .70505 L
F
.50032 .89226 m
.50028 .89138 L
.53446 .88984 L
.50032 .89226 L
.50032 .89226 L
F
.50028 .89138 m
.50024 .8905 L
.56859 .88742 L
.53446 .88984 L
.50028 .89138 L
F
.50024 .8905 m
.5002 .88961 L
.60273 .885 L
.56859 .88742 L
.50024 .8905 L
F
.50032 .89226 m
.53446 .88984 L
.56631 .88847 L
.50032 .89226 L
.50032 .89226 L
F
.53446 .88984 m
.56859 .88742 L
.6323 .88467 L
.56631 .88847 L
.53446 .88984 L
F
.56859 .88742 m
.60273 .885 L
.69829 .88088 L
.6323 .88467 L
.56859 .88742 L
F
.50032 .89226 m
.56631 .88847 L
.59366 .88735 L
.50032 .89226 L
.50032 .89226 L
F
.56631 .88847 m
.6323 .88467 L
.68701 .88244 L
.59366 .88735 L
.56631 .88847 L
F
.6323 .88467 m
.69829 .88088 L
.78035 .87754 L
.68701 .88244 L
.6323 .88467 L
F
.50032 .89226 m
.59366 .88735 L
.61466 .88657 L
.50032 .89226 L
.50032 .89226 L
F
.59366 .88735 m
.68701 .88244 L
.72899 .88088 L
.61466 .88657 L
.59366 .88735 L
F
.68701 .88244 m
.78035 .87754 L
.84333 .8752 L
.72899 .88088 L
.68701 .88244 L
F
.50032 .89226 m
.61466 .88657 L
.62786 .88618 L
.50032 .89226 L
.50032 .89226 L
F
.61466 .88657 m
.72899 .88088 L
.75539 .8801 L
.62786 .88618 L
.61466 .88657 L
F
.72899 .88088 m
.84333 .8752 L
.88293 .87402 L
.75539 .8801 L
.72899 .88088 L
F
.50032 .89226 m
.62786 .88618 L
.63237 .8862 L
.50032 .89226 L
.50032 .89226 L
F
.62786 .88618 m
.75539 .8801 L
.76441 .88014 L
.63237 .8862 L
.62786 .88618 L
F
.75539 .8801 m
.88293 .87402 L
.89646 .87408 L
.76441 .88014 L
.75539 .8801 L
F
.50032 .89226 m
.63237 .8862 L
.62788 .88663 L
.50032 .89226 L
.50032 .89226 L
F
.63237 .8862 m
.76441 .88014 L
.75544 .88101 L
.62788 .88663 L
.63237 .8862 L
F
.76441 .88014 m
.89646 .87408 L
.883 .87539 L
.75544 .88101 L
.76441 .88014 L
F
.50032 .89226 m
.62788 .88663 L
.6147 .88745 L
.50032 .89226 L
.50032 .89226 L
F
.62788 .88663 m
.75544 .88101 L
.72907 .88265 L
.6147 .88745 L
.62788 .88663 L
F
.75544 .88101 m
.883 .87539 L
.84345 .87784 L
.72907 .88265 L
.75544 .88101 L
F
.50032 .89226 m
.6147 .88745 L
.59372 .8886 L
.50032 .89226 L
.50032 .89226 L
F
.6147 .88745 m
.72907 .88265 L
.68712 .88494 L
.59372 .8886 L
.6147 .88745 L
F
.72907 .88265 m
.84345 .87784 L
.78052 .88128 L
.68712 .88494 L
.72907 .88265 L
F
.50032 .89226 m
.59372 .8886 L
.56638 .88999 L
.50032 .89226 L
.50032 .89226 L
F
.59372 .8886 m
.68712 .88494 L
.63244 .88773 L
.56638 .88999 L
.59372 .8886 L
F
.68712 .88494 m
.78052 .88128 L
.6985 .88546 L
.63244 .88773 L
.68712 .88494 L
F
.50032 .89226 m
.56638 .88999 L
.53454 .89154 L
.50032 .89226 L
.50032 .89226 L
F
.56638 .88999 m
.63244 .88773 L
.56875 .89082 L
.53454 .89154 L
.56638 .88999 L
F
.63244 .88773 m
.6985 .88546 L
.60297 .89011 L
.56875 .89082 L
.63244 .88773 L
F
.50032 .89226 m
.53454 .89154 L
.50036 .89314 L
.50032 .89226 L
.50032 .89226 L
F
.53454 .89154 m
.56875 .89082 L
.5004 .89402 L
.50036 .89314 L
.53454 .89154 L
F
.56875 .89082 m
.60297 .89011 L
.50044 .8949 L
.5004 .89402 L
.56875 .89082 L
F
.50032 .89226 m
.50036 .89314 L
.46618 .89468 L
.50032 .89226 L
.50032 .89226 L
F
.50036 .89314 m
.5004 .89402 L
.43205 .8971 L
.46618 .89468 L
.50036 .89314 L
F
.5004 .89402 m
.50044 .8949 L
.39791 .89951 L
.43205 .8971 L
.5004 .89402 L
F
.50032 .89226 m
.46618 .89468 L
.43433 .89605 L
.50032 .89226 L
.50032 .89226 L
F
.46618 .89468 m
.43205 .8971 L
.36834 .89984 L
.43433 .89605 L
.46618 .89468 L
F
.43205 .8971 m
.39791 .89951 L
.30235 .90363 L
.36834 .89984 L
.43205 .8971 L
F
.50032 .89226 m
.43433 .89605 L
.40698 .89716 L
.50032 .89226 L
.50032 .89226 L
F
.43433 .89605 m
.36834 .89984 L
.31363 .90207 L
.40698 .89716 L
.43433 .89605 L
F
.36834 .89984 m
.30235 .90363 L
.22029 .90698 L
.31363 .90207 L
.36834 .89984 L
F
.50032 .89226 m
.40698 .89716 L
.38598 .89794 L
.50032 .89226 L
.50032 .89226 L
F
.40698 .89716 m
.31363 .90207 L
.27165 .90363 L
.38598 .89794 L
.40698 .89716 L
F
.31363 .90207 m
.22029 .90698 L
.15731 .90932 L
.27165 .90363 L
.31363 .90207 L
F
.50032 .89226 m
.38598 .89794 L
.37278 .89834 L
.50032 .89226 L
.50032 .89226 L
F
.38598 .89794 m
.27165 .90363 L
.24524 .90442 L
.37278 .89834 L
.38598 .89794 L
F
.27165 .90363 m
.15731 .90932 L
.11771 .9105 L
.24524 .90442 L
.27165 .90363 L
F
.50032 .89226 m
.37278 .89834 L
.36827 .89832 L
.50032 .89226 L
.50032 .89226 L
F
.37278 .89834 m
.24524 .90442 L
.23622 .90437 L
.36827 .89832 L
.37278 .89834 L
F
.24524 .90442 m
.11771 .9105 L
.10418 .91043 L
.23622 .90437 L
.24524 .90442 L
F
.50032 .89226 m
.36827 .89832 L
.37276 .89788 L
.50032 .89226 L
.50032 .89226 L
F
.36827 .89832 m
.23622 .90437 L
.2452 .9035 L
.37276 .89788 L
.36827 .89832 L
F
.23622 .90437 m
.10418 .91043 L
.11764 .90913 L
.2452 .9035 L
.23622 .90437 L
F
.50032 .89226 m
.37276 .89788 L
.38594 .89706 L
.50032 .89226 L
.50032 .89226 L
F
.37276 .89788 m
.2452 .9035 L
.27157 .90187 L
.38594 .89706 L
.37276 .89788 L
F
.2452 .9035 m
.11764 .90913 L
.15719 .90667 L
.27157 .90187 L
.2452 .9035 L
F
.50032 .89226 m
.38594 .89706 L
.40692 .89592 L
.50032 .89226 L
.50032 .89226 L
F
.38594 .89706 m
.27157 .90187 L
.31352 .89958 L
.40692 .89592 L
.38594 .89706 L
F
.27157 .90187 m
.15719 .90667 L
.22012 .90324 L
.31352 .89958 L
.27157 .90187 L
F
.50032 .89226 m
.40692 .89592 L
.43426 .89452 L
.50032 .89226 L
.50032 .89226 L
F
.40692 .89592 m
.31352 .89958 L
.3682 .89679 L
.43426 .89452 L
.40692 .89592 L
F
.31352 .89958 m
.22012 .90324 L
.30214 .89905 L
.3682 .89679 L
.31352 .89958 L
F
.50032 .89226 m
.43426 .89452 L
.4661 .89297 L
.50032 .89226 L
.50032 .89226 L
F
.43426 .89452 m
.3682 .89679 L
.43189 .89369 L
.4661 .89297 L
.43426 .89452 L
F
.3682 .89679 m
.30214 .89905 L
.39767 .89441 L
.43189 .89369 L
.3682 .89679 L
F
.50032 .89226 m
.4661 .89297 L
.50028 .89138 L
.50032 .89226 L
.50032 .89226 L
F
.4661 .89297 m
.43189 .89369 L
.50024 .8905 L
.50028 .89138 L
.4661 .89297 L
F
.43189 .89369 m
.39767 .89441 L
.5002 .88961 L
.50024 .8905 L
.43189 .89369 L
F
0 g
.5002 .88961 m
.60273 .885 L
.69829 .88088 L
.78035 .87754 L
.84333 .8752 L
.88293 .87402 L
.89646 .87408 L
.883 .87539 L
.84345 .87784 L
.78052 .88128 L
.6985 .88546 L
.60297 .89011 L
.50044 .8949 L
.39791 .89951 L
.30235 .90363 L
.22029 .90698 L
.15731 .90932 L
.11771 .9105 L
.10418 .91043 L
.11764 .90913 L
.15719 .90667 L
.22012 .90324 L
.30214 .89905 L
.39767 .89441 L
.5002 .88961 L
s
.5 g
.49959 .87641 m
.49955 .87553 L
.53373 .87399 L
.49959 .87641 L
.49959 .87641 L
F
.49955 .87553 m
.49951 .87465 L
.56787 .87157 L
.53373 .87399 L
.49955 .87553 L
F
.49951 .87465 m
.49947 .87377 L
.602 .86916 L
.56787 .87157 L
.49951 .87465 L
F
.49959 .87641 m
.53373 .87399 L
.56558 .87262 L
.49959 .87641 L
.49959 .87641 L
F
.53373 .87399 m
.56787 .87157 L
.63157 .86883 L
.56558 .87262 L
.53373 .87399 L
F
.56787 .87157 m
.602 .86916 L
.69756 .86504 L
.63157 .86883 L
.56787 .87157 L
F
.49959 .87641 m
.56558 .87262 L
.59294 .87151 L
.49959 .87641 L
.49959 .87641 L
F
.56558 .87262 m
.63157 .86883 L
.68628 .8666 L
.59294 .87151 L
.56558 .87262 L
F
.63157 .86883 m
.69756 .86504 L
.77962 .86169 L
.68628 .8666 L
.63157 .86883 L
F
.49959 .87641 m
.59294 .87151 L
.61393 .87073 L
.49959 .87641 L
.49959 .87641 L
F
.59294 .87151 m
.68628 .8666 L
.72827 .86504 L
.61393 .87073 L
.59294 .87151 L
F
.68628 .8666 m
.77962 .86169 L
.8426 .85935 L
.72827 .86504 L
.68628 .8666 L
F
.49959 .87641 m
.61393 .87073 L
.62713 .87033 L
.49959 .87641 L
.49959 .87641 L
F
.61393 .87073 m
.72827 .86504 L
.75467 .86425 L
.62713 .87033 L
.61393 .87073 L
F
.72827 .86504 m
.8426 .85935 L
.88221 .85817 L
.75467 .86425 L
.72827 .86504 L
F
.49959 .87641 m
.62713 .87033 L
.63164 .87035 L
.49959 .87641 L
.49959 .87641 L
F
.62713 .87033 m
.75467 .86425 L
.76369 .8643 L
.63164 .87035 L
.62713 .87033 L
F
.75467 .86425 m
.88221 .85817 L
.89574 .85824 L
.76369 .8643 L
.75467 .86425 L
F
.49959 .87641 m
.63164 .87035 L
.62715 .87079 L
.49959 .87641 L
.49959 .87641 L
F
.63164 .87035 m
.76369 .8643 L
.75471 .86517 L
.62715 .87079 L
.63164 .87035 L
F
.76369 .8643 m
.89574 .85824 L
.88227 .85954 L
.75471 .86517 L
.76369 .8643 L
F
.49959 .87641 m
.62715 .87079 L
.61397 .87161 L
.49959 .87641 L
.49959 .87641 L
F
.62715 .87079 m
.75471 .86517 L
.72835 .8668 L
.61397 .87161 L
.62715 .87079 L
F
.75471 .86517 m
.88227 .85954 L
.84272 .862 L
.72835 .8668 L
.75471 .86517 L
F
.49959 .87641 m
.61397 .87161 L
.59299 .87275 L
.49959 .87641 L
.49959 .87641 L
F
.61397 .87161 m
.72835 .8668 L
.68639 .86909 L
.59299 .87275 L
.61397 .87161 L
F
.72835 .8668 m
.84272 .862 L
.77979 .86543 L
.68639 .86909 L
.72835 .8668 L
F
.49959 .87641 m
.59299 .87275 L
.56565 .87415 L
.49959 .87641 L
.49959 .87641 L
F
.59299 .87275 m
.68639 .86909 L
.63171 .87188 L
.56565 .87415 L
.59299 .87275 L
F
.68639 .86909 m
.77979 .86543 L
.69777 .86961 L
.63171 .87188 L
.68639 .86909 L
F
.49959 .87641 m
.56565 .87415 L
.53381 .8757 L
.49959 .87641 L
.49959 .87641 L
F
.56565 .87415 m
.63171 .87188 L
.56802 .87498 L
.53381 .8757 L
.56565 .87415 L
F
.63171 .87188 m
.69777 .86961 L
.60224 .87426 L
.56802 .87498 L
.63171 .87188 L
F
.49959 .87641 m
.53381 .8757 L
.49963 .87729 L
.49959 .87641 L
.49959 .87641 L
F
.53381 .8757 m
.56802 .87498 L
.49967 .87817 L
.49963 .87729 L
.53381 .8757 L
F
.56802 .87498 m
.60224 .87426 L
.49971 .87906 L
.49967 .87817 L
.56802 .87498 L
F
.49959 .87641 m
.49963 .87729 L
.46546 .87883 L
.49959 .87641 L
.49959 .87641 L
F
.49963 .87729 m
.49967 .87817 L
.43132 .88125 L
.46546 .87883 L
.49963 .87729 L
F
.49967 .87817 m
.49971 .87906 L
.39718 .88367 L
.43132 .88125 L
.49967 .87817 L
F
.49959 .87641 m
.46546 .87883 L
.4336 .8802 L
.49959 .87641 L
.49959 .87641 L
F
.46546 .87883 m
.43132 .88125 L
.36762 .884 L
.4336 .8802 L
.46546 .87883 L
F
.43132 .88125 m
.39718 .88367 L
.30163 .88779 L
.36762 .884 L
.43132 .88125 L
F
.49959 .87641 m
.4336 .8802 L
.40625 .88132 L
.49959 .87641 L
.49959 .87641 L
F
.4336 .8802 m
.36762 .884 L
.31291 .88623 L
.40625 .88132 L
.4336 .8802 L
F
.36762 .884 m
.30163 .88779 L
.21956 .89113 L
.31291 .88623 L
.36762 .884 L
F
.49959 .87641 m
.40625 .88132 L
.38526 .8821 L
.49959 .87641 L
.49959 .87641 L
F
.40625 .88132 m
.31291 .88623 L
.27092 .88779 L
.38526 .8821 L
.40625 .88132 L
F
.31291 .88623 m
.21956 .89113 L
.15658 .89347 L
.27092 .88779 L
.31291 .88623 L
F
.49959 .87641 m
.38526 .8821 L
.37206 .88249 L
.49959 .87641 L
.49959 .87641 L
F
.38526 .8821 m
.27092 .88779 L
.24452 .88857 L
.37206 .88249 L
.38526 .8821 L
F
.27092 .88779 m
.15658 .89347 L
.11698 .89465 L
.24452 .88857 L
.27092 .88779 L
F
.49959 .87641 m
.37206 .88249 L
.36755 .88247 L
.49959 .87641 L
.49959 .87641 L
F
.37206 .88249 m
.24452 .88857 L
.2355 .88853 L
.36755 .88247 L
.37206 .88249 L
F
.24452 .88857 m
.11698 .89465 L
.10345 .89459 L
.2355 .88853 L
.24452 .88857 L
F
.49959 .87641 m
.36755 .88247 L
.37203 .88204 L
.49959 .87641 L
.49959 .87641 L
F
.36755 .88247 m
.2355 .88853 L
.24448 .88766 L
.37203 .88204 L
.36755 .88247 L
F
.2355 .88853 m
.10345 .89459 L
.11692 .89328 L
.24448 .88766 L
.2355 .88853 L
F
.49959 .87641 m
.37203 .88204 L
.38522 .88122 L
.49959 .87641 L
.49959 .87641 L
F
.37203 .88204 m
.24448 .88766 L
.27084 .88602 L
.38522 .88122 L
.37203 .88204 L
F
.24448 .88766 m
.11692 .89328 L
.15646 .89083 L
.27084 .88602 L
.24448 .88766 L
F
.49959 .87641 m
.38522 .88122 L
.40619 .88007 L
.49959 .87641 L
.49959 .87641 L
F
.38522 .88122 m
.27084 .88602 L
.31279 .88373 L
.40619 .88007 L
.38522 .88122 L
F
.27084 .88602 m
.15646 .89083 L
.21939 .88739 L
.31279 .88373 L
.27084 .88602 L
F
.49959 .87641 m
.40619 .88007 L
.43353 .87868 L
.49959 .87641 L
.49959 .87641 L
F
.40619 .88007 m
.31279 .88373 L
.36748 .88094 L
.43353 .87868 L
.40619 .88007 L
F
.31279 .88373 m
.21939 .88739 L
.30142 .88321 L
.36748 .88094 L
.31279 .88373 L
F
.49959 .87641 m
.43353 .87868 L
.46538 .87713 L
.49959 .87641 L
.49959 .87641 L
F
.43353 .87868 m
.36748 .88094 L
.43116 .87785 L
.46538 .87713 L
.43353 .87868 L
F
.36748 .88094 m
.30142 .88321 L
.39695 .87856 L
.43116 .87785 L
.36748 .88094 L
F
.49959 .87641 m
.46538 .87713 L
.49955 .87553 L
.49959 .87641 L
.49959 .87641 L
F
.46538 .87713 m
.43116 .87785 L
.49951 .87465 L
.49955 .87553 L
.46538 .87713 L
F
.43116 .87785 m
.39695 .87856 L
.49947 .87377 L
.49951 .87465 L
.43116 .87785 L
F
0 g
.49947 .87377 m
.602 .86916 L
.69756 .86504 L
.77962 .86169 L
.8426 .85935 L
.88221 .85817 L
.89574 .85824 L
.88227 .85954 L
.84272 .862 L
.77979 .86543 L
.69777 .86961 L
.60224 .87426 L
.49971 .87906 L
.39718 .88367 L
.30163 .88779 L
.21956 .89113 L
.15658 .89347 L
.11698 .89465 L
.10345 .89459 L
.11692 .89328 L
.15646 .89083 L
.21939 .88739 L
.30142 .88321 L
.39695 .87856 L
.49947 .87377 L
s
.5 g
.49887 .86057 m
.49883 .85969 L
.53283 .85816 L
.49887 .86057 L
.49887 .86057 L
F
.49883 .85969 m
.49879 .85881 L
.5668 .85575 L
.53283 .85816 L
.49883 .85969 L
F
.49879 .85881 m
.49875 .85794 L
.60077 .85335 L
.5668 .85575 L
.49879 .85881 L
F
.49887 .86057 m
.53283 .85816 L
.56452 .85679 L
.49887 .86057 L
.49887 .86057 L
F
.53283 .85816 m
.5668 .85575 L
.63018 .85302 L
.56452 .85679 L
.53283 .85816 L
F
.5668 .85575 m
.60077 .85335 L
.69584 .84925 L
.63018 .85302 L
.5668 .85575 L
F
.49887 .86057 m
.56452 .85679 L
.59174 .85568 L
.49887 .86057 L
.49887 .86057 L
F
.56452 .85679 m
.63018 .85302 L
.68462 .8508 L
.59174 .85568 L
.56452 .85679 L
F
.63018 .85302 m
.69584 .84925 L
.7775 .84592 L
.68462 .8508 L
.63018 .85302 L
F
.49887 .86057 m
.59174 .85568 L
.61263 .85491 L
.49887 .86057 L
.49887 .86057 L
F
.59174 .85568 m
.68462 .8508 L
.7264 .84925 L
.61263 .85491 L
.59174 .85568 L
F
.68462 .8508 m
.7775 .84592 L
.84016 .84359 L
.7264 .84925 L
.68462 .8508 L
F
.49887 .86057 m
.61263 .85491 L
.62577 .85452 L
.49887 .86057 L
.49887 .86057 L
F
.61263 .85491 m
.7264 .84925 L
.75267 .84847 L
.62577 .85452 L
.61263 .85491 L
F
.7264 .84925 m
.84016 .84359 L
.87957 .84242 L
.75267 .84847 L
.7264 .84925 L
F
.49887 .86057 m
.62577 .85452 L
.63025 .85454 L
.49887 .86057 L
.49887 .86057 L
F
.62577 .85452 m
.75267 .84847 L
.76164 .84851 L
.63025 .85454 L
.62577 .85452 L
F
.75267 .84847 m
.87957 .84242 L
.89303 .84248 L
.76164 .84851 L
.75267 .84847 L
F
.49887 .86057 m
.63025 .85454 L
.62579 .85497 L
.49887 .86057 L
.49887 .86057 L
F
.63025 .85454 m
.76164 .84851 L
.75271 .84938 L
.62579 .85497 L
.63025 .85454 L
F
.76164 .84851 m
.89303 .84248 L
.87963 .84378 L
.75271 .84938 L
.76164 .84851 L
F
.49887 .86057 m
.62579 .85497 L
.61267 .85579 L
.49887 .86057 L
.49887 .86057 L
F
.62579 .85497 m
.75271 .84938 L
.72648 .851 L
.61267 .85579 L
.62579 .85497 L
F
.75271 .84938 m
.87963 .84378 L
.84028 .84622 L
.72648 .851 L
.75271 .84938 L
F
.49887 .86057 m
.61267 .85579 L
.5918 .85692 L
.49887 .86057 L
.49887 .86057 L
F
.61267 .85579 m
.72648 .851 L
.68473 .85328 L
.5918 .85692 L
.61267 .85579 L
F
.72648 .851 m
.84028 .84622 L
.77767 .84964 L
.68473 .85328 L
.72648 .851 L
F
.49887 .86057 m
.5918 .85692 L
.56459 .85831 L
.49887 .86057 L
.49887 .86057 L
F
.5918 .85692 m
.68473 .85328 L
.63032 .85606 L
.56459 .85831 L
.5918 .85692 L
F
.68473 .85328 m
.77767 .84964 L
.69605 .8538 L
.63032 .85606 L
.68473 .85328 L
F
.49887 .86057 m
.56459 .85831 L
.53291 .85985 L
.49887 .86057 L
.49887 .86057 L
F
.56459 .85831 m
.63032 .85606 L
.56695 .85914 L
.53291 .85985 L
.56459 .85831 L
F
.63032 .85606 m
.69605 .8538 L
.601 .85843 L
.56695 .85914 L
.63032 .85606 L
F
.49887 .86057 m
.53291 .85985 L
.49891 .86144 L
.49887 .86057 L
.49887 .86057 L
F
.53291 .85985 m
.56695 .85914 L
.49895 .86232 L
.49891 .86144 L
.53291 .85985 L
F
.56695 .85914 m
.601 .85843 L
.49899 .8632 L
.49895 .86232 L
.56695 .85914 L
F
.49887 .86057 m
.49891 .86144 L
.4649 .86297 L
.49887 .86057 L
.49887 .86057 L
F
.49891 .86144 m
.49895 .86232 L
.43093 .86538 L
.4649 .86297 L
.49891 .86144 L
F
.49895 .86232 m
.49899 .8632 L
.39697 .86779 L
.43093 .86538 L
.49895 .86232 L
F
.49887 .86057 m
.4649 .86297 L
.43321 .86434 L
.49887 .86057 L
.49887 .86057 L
F
.4649 .86297 m
.43093 .86538 L
.36755 .86811 L
.43321 .86434 L
.4649 .86297 L
F
.43093 .86538 m
.39697 .86779 L
.30189 .87189 L
.36755 .86811 L
.43093 .86538 L
F
.49887 .86057 m
.43321 .86434 L
.40599 .86545 L
.49887 .86057 L
.49887 .86057 L
F
.43321 .86434 m
.36755 .86811 L
.31311 .87033 L
.40599 .86545 L
.43321 .86434 L
F
.36755 .86811 m
.30189 .87189 L
.22024 .87521 L
.31311 .87033 L
.36755 .86811 L
F
.49887 .86057 m
.40599 .86545 L
.3851 .86623 L
.49887 .86057 L
.49887 .86057 L
F
.40599 .86545 m
.31311 .87033 L
.27134 .87188 L
.3851 .86623 L
.40599 .86545 L
F
.31311 .87033 m
.22024 .87521 L
.15757 .87754 L
.27134 .87188 L
.31311 .87033 L
F
.49887 .86057 m
.3851 .86623 L
.37197 .86662 L
.49887 .86057 L
.49887 .86057 L
F
.3851 .86623 m
.27134 .87188 L
.24507 .87266 L
.37197 .86662 L
.3851 .86623 L
F
.27134 .87188 m
.15757 .87754 L
.11817 .87871 L
.24507 .87266 L
.27134 .87188 L
F
.49887 .86057 m
.37197 .86662 L
.36748 .86659 L
.49887 .86057 L
.49887 .86057 L
F
.37197 .86662 m
.24507 .87266 L
.23609 .87262 L
.36748 .86659 L
.37197 .86662 L
F
.24507 .87266 m
.11817 .87871 L
.1047 .87865 L
.23609 .87262 L
.24507 .87266 L
F
.49887 .86057 m
.36748 .86659 L
.37195 .86616 L
.49887 .86057 L
.49887 .86057 L
F
.36748 .86659 m
.23609 .87262 L
.24502 .87176 L
.37195 .86616 L
.36748 .86659 L
F
.23609 .87262 m
.1047 .87865 L
.1181 .87735 L
.24502 .87176 L
.23609 .87262 L
F
.49887 .86057 m
.37195 .86616 L
.38506 .86535 L
.49887 .86057 L
.49887 .86057 L
F
.37195 .86616 m
.24502 .87176 L
.27126 .87013 L
.38506 .86535 L
.37195 .86616 L
F
.24502 .87176 m
.1181 .87735 L
.15745 .87491 L
.27126 .87013 L
.24502 .87176 L
F
.49887 .86057 m
.38506 .86535 L
.40593 .86421 L
.49887 .86057 L
.49887 .86057 L
F
.38506 .86535 m
.27126 .87013 L
.313 .86785 L
.40593 .86421 L
.38506 .86535 L
F
.27126 .87013 m
.15745 .87491 L
.22007 .87149 L
.313 .86785 L
.27126 .87013 L
F
.49887 .86057 m
.40593 .86421 L
.43314 .86282 L
.49887 .86057 L
.49887 .86057 L
F
.40593 .86421 m
.313 .86785 L
.36741 .86508 L
.43314 .86282 L
.40593 .86421 L
F
.313 .86785 m
.22007 .87149 L
.30168 .86733 L
.36741 .86508 L
.313 .86785 L
F
.49887 .86057 m
.43314 .86282 L
.46482 .86128 L
.49887 .86057 L
.49887 .86057 L
F
.43314 .86282 m
.36741 .86508 L
.43078 .86199 L
.46482 .86128 L
.43314 .86282 L
F
.36741 .86508 m
.30168 .86733 L
.39673 .86271 L
.43078 .86199 L
.36741 .86508 L
F
.49887 .86057 m
.46482 .86128 L
.49883 .85969 L
.49887 .86057 L
.49887 .86057 L
F
.46482 .86128 m
.43078 .86199 L
.49879 .85881 L
.49883 .85969 L
.46482 .86128 L
F
.43078 .86199 m
.39673 .86271 L
.49875 .85794 L
.49879 .85881 L
.43078 .86199 L
F
0 g
.49874 .85792 m
.60128 .85331 L
.69683 .84919 L
.7789 .84585 L
.84187 .84351 L
.88148 .84233 L
.89501 .84239 L
.88154 .8437 L
.842 .84615 L
.77907 .84959 L
.69704 .85377 L
.60151 .85842 L
.49899 .86321 L
.39645 .86782 L
.3009 .87194 L
.21884 .87529 L
.15586 .87763 L
.11625 .8788 L
.10272 .87874 L
.11619 .87744 L
.15574 .87498 L
.21867 .87155 L
.30069 .86736 L
.39622 .86272 L
.49874 .85792 L
s
.5 g
.5002 .88961 m
.49947 .87377 L
.602 .86916 L
.60273 .885 L
.5002 .88961 L
F
.60273 .885 m
.602 .86916 L
.69756 .86504 L
.69829 .88088 L
.60273 .885 L
F
.69829 .88088 m
.69756 .86504 L
.77962 .86169 L
.78035 .87754 L
.69829 .88088 L
F
.78035 .87754 m
.77962 .86169 L
.8426 .85935 L
.84333 .8752 L
.78035 .87754 L
F
.84333 .8752 m
.8426 .85935 L
.88221 .85817 L
.88293 .87402 L
.84333 .8752 L
F
.88293 .87402 m
.88221 .85817 L
.89574 .85824 L
.89646 .87408 L
.88293 .87402 L
F
.89646 .87408 m
.89574 .85824 L
.88227 .85954 L
.883 .87539 L
.89646 .87408 L
F
.883 .87539 m
.88227 .85954 L
.84272 .862 L
.84345 .87784 L
.883 .87539 L
F
.84345 .87784 m
.84272 .862 L
.77979 .86543 L
.78052 .88128 L
.84345 .87784 L
F
.78052 .88128 m
.77979 .86543 L
.69777 .86961 L
.6985 .88546 L
.78052 .88128 L
F
.6985 .88546 m
.69777 .86961 L
.60224 .87426 L
.60297 .89011 L
.6985 .88546 L
F
.60297 .89011 m
.60224 .87426 L
.49971 .87906 L
.50044 .8949 L
.60297 .89011 L
F
.50044 .8949 m
.49971 .87906 L
.39718 .88367 L
.39791 .89951 L
.50044 .8949 L
F
.39791 .89951 m
.39718 .88367 L
.30163 .88779 L
.30235 .90363 L
.39791 .89951 L
F
.30235 .90363 m
.30163 .88779 L
.21956 .89113 L
.22029 .90698 L
.30235 .90363 L
F
.22029 .90698 m
.21956 .89113 L
.15658 .89347 L
.15731 .90932 L
.22029 .90698 L
F
.15731 .90932 m
.15658 .89347 L
.11698 .89465 L
.11771 .9105 L
.15731 .90932 L
F
.11771 .9105 m
.11698 .89465 L
.10345 .89459 L
.10418 .91043 L
.11771 .9105 L
F
.10418 .91043 m
.10345 .89459 L
.11692 .89328 L
.11764 .90913 L
.10418 .91043 L
F
.11764 .90913 m
.11692 .89328 L
.15646 .89083 L
.15719 .90667 L
.11764 .90913 L
F
.15719 .90667 m
.15646 .89083 L
.21939 .88739 L
.22012 .90324 L
.15719 .90667 L
F
.22012 .90324 m
.21939 .88739 L
.30142 .88321 L
.30214 .89905 L
.22012 .90324 L
F
.30214 .89905 m
.30142 .88321 L
.39695 .87856 L
.39767 .89441 L
.30214 .89905 L
F
.39767 .89441 m
.39695 .87856 L
.49947 .87377 L
.5002 .88961 L
.39767 .89441 L
F
.49947 .87377 m
.49874 .85792 L
.60128 .85331 L
.602 .86916 L
.49947 .87377 L
F
.602 .86916 m
.60128 .85331 L
.69683 .84919 L
.69756 .86504 L
.602 .86916 L
F
.69756 .86504 m
.69683 .84919 L
.7789 .84585 L
.77962 .86169 L
.69756 .86504 L
F
.77962 .86169 m
.7789 .84585 L
.84187 .84351 L
.8426 .85935 L
.77962 .86169 L
F
.8426 .85935 m
.84187 .84351 L
.88148 .84233 L
.88221 .85817 L
.8426 .85935 L
F
.88221 .85817 m
.88148 .84233 L
.89501 .84239 L
.89574 .85824 L
.88221 .85817 L
F
.89574 .85824 m
.89501 .84239 L
.88154 .8437 L
.88227 .85954 L
.89574 .85824 L
F
.88227 .85954 m
.88154 .8437 L
.842 .84615 L
.84272 .862 L
.88227 .85954 L
F
.84272 .862 m
.842 .84615 L
.77907 .84959 L
.77979 .86543 L
.84272 .862 L
F
.77979 .86543 m
.77907 .84959 L
.69704 .85377 L
.69777 .86961 L
.77979 .86543 L
F
.69777 .86961 m
.69704 .85377 L
.60151 .85842 L
.60224 .87426 L
.69777 .86961 L
F
.60224 .87426 m
.60151 .85842 L
.49899 .86321 L
.49971 .87906 L
.60224 .87426 L
F
.49971 .87906 m
.49899 .86321 L
.39645 .86782 L
.39718 .88367 L
.49971 .87906 L
F
.39718 .88367 m
.39645 .86782 L
.3009 .87194 L
.30163 .88779 L
.39718 .88367 L
F
.30163 .88779 m
.3009 .87194 L
.21884 .87529 L
.21956 .89113 L
.30163 .88779 L
F
.21956 .89113 m
.21884 .87529 L
.15586 .87763 L
.15658 .89347 L
.21956 .89113 L
F
.15658 .89347 m
.15586 .87763 L
.11625 .8788 L
.11698 .89465 L
.15658 .89347 L
F
.11698 .89465 m
.11625 .8788 L
.10272 .87874 L
.10345 .89459 L
.11698 .89465 L
F
.10345 .89459 m
.10272 .87874 L
.11619 .87744 L
.11692 .89328 L
.10345 .89459 L
F
.11692 .89328 m
.11619 .87744 L
.15574 .87498 L
.15646 .89083 L
.11692 .89328 L
F
.15646 .89083 m
.15574 .87498 L
.21867 .87155 L
.21939 .88739 L
.15646 .89083 L
F
.21939 .88739 m
.21867 .87155 L
.30069 .86736 L
.30142 .88321 L
.21939 .88739 L
F
.30142 .88321 m
.30069 .86736 L
.39622 .86272 L
.39695 .87856 L
.30142 .88321 L
F
.39695 .87856 m
.39622 .86272 L
.49874 .85792 L
.49947 .87377 L
.39695 .87856 L
F
.50032 1.05088 m
.50009 1.04834 L
.52736 1.04599 L
.50032 1.05088 L
.50032 1.05088 L
F
.50009 1.04834 m
.49987 1.0458 L
.5544 1.0411 L
.52736 1.04599 L
.50009 1.04834 L
F
.49987 1.0458 m
.49964 1.04326 L
.58145 1.03621 L
.5544 1.0411 L
.49987 1.0458 L
F
.50032 1.05088 m
.52736 1.04599 L
.55279 1.04398 L
.50032 1.05088 L
.50032 1.05088 L
F
.52736 1.04599 m
.5544 1.0411 L
.60526 1.03707 L
.55279 1.04398 L
.52736 1.04599 L
F
.5544 1.0411 m
.58145 1.03621 L
.65772 1.03017 L
.60526 1.03707 L
.5544 1.0411 L
F
.50032 1.05088 m
.55279 1.04398 L
.57464 1.04243 L
.50032 1.05088 L
.50032 1.05088 L
F
.55279 1.04398 m
.60526 1.03707 L
.64896 1.03398 L
.57464 1.04243 L
.55279 1.04398 L
F
.60526 1.03707 m
.65772 1.03017 L
.72328 1.02553 L
.64896 1.03398 L
.60526 1.03707 L
F
.50032 1.05088 m
.57464 1.04243 L
.59142 1.04146 L
.50032 1.05088 L
.50032 1.05088 L
F
.57464 1.04243 m
.64896 1.03398 L
.68253 1.03204 L
.59142 1.04146 L
.57464 1.04243 L
F
.64896 1.03398 m
.72328 1.02553 L
.77363 1.02262 L
.68253 1.03204 L
.64896 1.03398 L
F
.50032 1.05088 m
.59142 1.04146 L
.602 1.04113 L
.50032 1.05088 L
.50032 1.05088 L
F
.59142 1.04146 m
.68253 1.03204 L
.70368 1.03138 L
.602 1.04113 L
.59142 1.04146 L
F
.68253 1.03204 m
.77363 1.02262 L
.80536 1.02163 L
.70368 1.03138 L
.68253 1.03204 L
F
.50032 1.05088 m
.602 1.04113 L
.60565 1.04147 L
.50032 1.05088 L
.50032 1.05088 L
F
.602 1.04113 m
.70368 1.03138 L
.71098 1.03206 L
.60565 1.04147 L
.602 1.04113 L
F
.70368 1.03138 m
.80536 1.02163 L
.81631 1.02264 L
.71098 1.03206 L
.70368 1.03138 L
F
.50032 1.05088 m
.60565 1.04147 L
.60212 1.04245 L
.50032 1.05088 L
.50032 1.05088 L
F
.60565 1.04147 m
.71098 1.03206 L
.70392 1.03401 L
.60212 1.04245 L
.60565 1.04147 L
F
.71098 1.03206 m
.81631 1.02264 L
.80572 1.02558 L
.70392 1.03401 L
.71098 1.03206 L
F
.50032 1.05088 m
.60212 1.04245 L
.59165 1.044 L
.50032 1.05088 L
.50032 1.05088 L
F
.60212 1.04245 m
.70392 1.03401 L
.68298 1.03712 L
.59165 1.044 L
.60212 1.04245 L
F
.70392 1.03401 m
.80572 1.02558 L
.77431 1.03023 L
.68298 1.03712 L
.70392 1.03401 L
F
.50032 1.05088 m
.59165 1.044 L
.57496 1.04602 L
.50032 1.05088 L
.50032 1.05088 L
F
.59165 1.044 m
.68298 1.03712 L
.6496 1.04116 L
.57496 1.04602 L
.59165 1.044 L
F
.68298 1.03712 m
.77431 1.03023 L
.72424 1.0363 L
.6496 1.04116 L
.68298 1.03712 L
F
.50032 1.05088 m
.57496 1.04602 L
.55318 1.04837 L
.50032 1.05088 L
.50032 1.05088 L
F
.57496 1.04602 m
.6496 1.04116 L
.60604 1.04587 L
.55318 1.04837 L
.57496 1.04602 L
F
.6496 1.04116 m
.72424 1.0363 L
.6589 1.04336 L
.60604 1.04587 L
.6496 1.04116 L
F
.50032 1.05088 m
.55318 1.04837 L
.5278 1.0509 L
.50032 1.05088 L
.50032 1.05088 L
F
.55318 1.04837 m
.60604 1.04587 L
.55528 1.05091 L
.5278 1.0509 L
.55318 1.04837 L
F
.60604 1.04587 m
.6589 1.04336 L
.58276 1.05093 L
.55528 1.05091 L
.60604 1.04587 L
F
.50032 1.05088 m
.5278 1.0509 L
.50055 1.05342 L
.50032 1.05088 L
.50032 1.05088 L
F
.5278 1.0509 m
.55528 1.05091 L
.50077 1.05596 L
.50055 1.05342 L
.5278 1.0509 L
F
.55528 1.05091 m
.58276 1.05093 L
.501 1.0585 L
.50077 1.05596 L
.55528 1.05091 L
F
.50032 1.05088 m
.50055 1.05342 L
.47328 1.05577 L
.50032 1.05088 L
.50032 1.05088 L
F
.50055 1.05342 m
.50077 1.05596 L
.44624 1.06066 L
.47328 1.05577 L
.50055 1.05342 L
F
.50077 1.05596 m
.501 1.0585 L
.41919 1.06555 L
.44624 1.06066 L
.50077 1.05596 L
F
.50032 1.05088 m
.47328 1.05577 L
.44785 1.05779 L
.50032 1.05088 L
.50032 1.05088 L
F
.47328 1.05577 m
.44624 1.06066 L
.39538 1.06469 L
.44785 1.05779 L
.47328 1.05577 L
F
.44624 1.06066 m
.41919 1.06555 L
.34292 1.0716 L
.39538 1.06469 L
.44624 1.06066 L
F
.50032 1.05088 m
.44785 1.05779 L
.426 1.05933 L
.50032 1.05088 L
.50032 1.05088 L
F
.44785 1.05779 m
.39538 1.06469 L
.35168 1.06778 L
.426 1.05933 L
.44785 1.05779 L
F
.39538 1.06469 m
.34292 1.0716 L
.27736 1.07623 L
.35168 1.06778 L
.39538 1.06469 L
F
.50032 1.05088 m
.426 1.05933 L
.40922 1.0603 L
.50032 1.05088 L
.50032 1.05088 L
F
.426 1.05933 m
.35168 1.06778 L
.31811 1.06972 L
.40922 1.0603 L
.426 1.05933 L
F
.35168 1.06778 m
.27736 1.07623 L
.22701 1.07914 L
.31811 1.06972 L
.35168 1.06778 L
F
.50032 1.05088 m
.40922 1.0603 L
.39864 1.06063 L
.50032 1.05088 L
.50032 1.05088 L
F
.40922 1.0603 m
.31811 1.06972 L
.29696 1.07038 L
.39864 1.06063 L
.40922 1.0603 L
F
.31811 1.06972 m
.22701 1.07914 L
.19528 1.08013 L
.29696 1.07038 L
.31811 1.06972 L
F
.50032 1.05088 m
.39864 1.06063 L
.39499 1.06029 L
.50032 1.05088 L
.50032 1.05088 L
F
.39864 1.06063 m
.29696 1.07038 L
.28966 1.06971 L
.39499 1.06029 L
.39864 1.06063 L
F
.29696 1.07038 m
.19528 1.08013 L
.18433 1.07912 L
.28966 1.06971 L
.29696 1.07038 L
F
.50032 1.05088 m
.39499 1.06029 L
.39852 1.05932 L
.50032 1.05088 L
.50032 1.05088 L
F
.39499 1.06029 m
.28966 1.06971 L
.29672 1.06775 L
.39852 1.05932 L
.39499 1.06029 L
F
.28966 1.06971 m
.18433 1.07912 L
.19492 1.07619 L
.29672 1.06775 L
.28966 1.06971 L
F
.50032 1.05088 m
.39852 1.05932 L
.40899 1.05776 L
.50032 1.05088 L
.50032 1.05088 L
F
.39852 1.05932 m
.29672 1.06775 L
.31766 1.06465 L
.40899 1.05776 L
.39852 1.05932 L
F
.29672 1.06775 m
.19492 1.07619 L
.22633 1.07153 L
.31766 1.06465 L
.29672 1.06775 L
F
.50032 1.05088 m
.40899 1.05776 L
.42568 1.05574 L
.50032 1.05088 L
.50032 1.05088 L
F
.40899 1.05776 m
.31766 1.06465 L
.35104 1.0606 L
.42568 1.05574 L
.40899 1.05776 L
F
.31766 1.06465 m
.22633 1.07153 L
.2764 1.06546 L
.35104 1.0606 L
.31766 1.06465 L
F
.50032 1.05088 m
.42568 1.05574 L
.44746 1.05339 L
.50032 1.05088 L
.50032 1.05088 L
F
.42568 1.05574 m
.35104 1.0606 L
.3946 1.0559 L
.44746 1.05339 L
.42568 1.05574 L
F
.35104 1.0606 m
.2764 1.06546 L
.34174 1.0584 L
.3946 1.0559 L
.35104 1.0606 L
F
.50032 1.05088 m
.44746 1.05339 L
.47284 1.05086 L
.50032 1.05088 L
.50032 1.05088 L
F
.44746 1.05339 m
.3946 1.0559 L
.44536 1.05085 L
.47284 1.05086 L
.44746 1.05339 L
F
.3946 1.0559 m
.34174 1.0584 L
.41788 1.05083 L
.44536 1.05085 L
.3946 1.0559 L
F
.50032 1.05088 m
.47284 1.05086 L
.50009 1.04834 L
.50032 1.05088 L
.50032 1.05088 L
F
.47284 1.05086 m
.44536 1.05085 L
.49987 1.0458 L
.50009 1.04834 L
.47284 1.05086 L
F
.44536 1.05085 m
.41788 1.05083 L
.49964 1.04326 L
.49987 1.0458 L
.44536 1.05085 L
F
0 g
.49964 1.04326 m
.58145 1.03621 L
.65772 1.03017 L
.72328 1.02553 L
.77363 1.02262 L
.80536 1.02163 L
.81631 1.02264 L
.80572 1.02558 L
.77431 1.03023 L
.72424 1.0363 L
.6589 1.04336 L
.58276 1.05093 L
.501 1.0585 L
.41919 1.06555 L
.34292 1.0716 L
.27736 1.07623 L
.22701 1.07914 L
.19528 1.08013 L
.18433 1.07912 L
.19492 1.07619 L
.22633 1.07153 L
.2764 1.06546 L
.34174 1.0584 L
.41788 1.05083 L
.49964 1.04326 L
s
.5 g
.49891 1.03509 m
.49868 1.03255 L
.52595 1.0302 L
.49891 1.03509 L
.49891 1.03509 L
F
.49868 1.03255 m
.49845 1.03001 L
.55299 1.02531 L
.52595 1.0302 L
.49868 1.03255 L
F
.49845 1.03001 m
.49823 1.02747 L
.58003 1.02042 L
.55299 1.02531 L
.49845 1.03001 L
F
.49891 1.03509 m
.52595 1.0302 L
.55138 1.02818 L
.49891 1.03509 L
.49891 1.03509 L
F
.52595 1.0302 m
.55299 1.02531 L
.60384 1.02128 L
.55138 1.02818 L
.52595 1.0302 L
F
.55299 1.02531 m
.58003 1.02042 L
.65631 1.01437 L
.60384 1.02128 L
.55299 1.02531 L
F
.49891 1.03509 m
.55138 1.02818 L
.57323 1.02664 L
.49891 1.03509 L
.49891 1.03509 L
F
.55138 1.02818 m
.60384 1.02128 L
.64755 1.01818 L
.57323 1.02664 L
.55138 1.02818 L
F
.60384 1.02128 m
.65631 1.01437 L
.72186 1.00973 L
.64755 1.01818 L
.60384 1.02128 L
F
.49891 1.03509 m
.57323 1.02664 L
.59001 1.02567 L
.49891 1.03509 L
.49891 1.03509 L
F
.57323 1.02664 m
.64755 1.01818 L
.68112 1.01624 L
.59001 1.02567 L
.57323 1.02664 L
F
.64755 1.01818 m
.72186 1.00973 L
.77222 1.00682 L
.68112 1.01624 L
.64755 1.01818 L
F
.49891 1.03509 m
.59001 1.02567 L
.60059 1.02534 L
.49891 1.03509 L
.49891 1.03509 L
F
.59001 1.02567 m
.68112 1.01624 L
.70227 1.01559 L
.60059 1.02534 L
.59001 1.02567 L
F
.68112 1.01624 m
.77222 1.00682 L
.80395 1.00584 L
.70227 1.01559 L
.68112 1.01624 L
F
.49891 1.03509 m
.60059 1.02534 L
.60424 1.02567 L
.49891 1.03509 L
.49891 1.03509 L
F
.60059 1.02534 m
.70227 1.01559 L
.70957 1.01626 L
.60424 1.02567 L
.60059 1.02534 L
F
.70227 1.01559 m
.80395 1.00584 L
.8149 1.00685 L
.70957 1.01626 L
.70227 1.01559 L
F
.49891 1.03509 m
.60424 1.02567 L
.60071 1.02665 L
.49891 1.03509 L
.49891 1.03509 L
F
.60424 1.02567 m
.70957 1.01626 L
.70251 1.01822 L
.60071 1.02665 L
.60424 1.02567 L
F
.70957 1.01626 m
.8149 1.00685 L
.80431 1.00978 L
.70251 1.01822 L
.70957 1.01626 L
F
.49891 1.03509 m
.60071 1.02665 L
.59024 1.0282 L
.49891 1.03509 L
.49891 1.03509 L
F
.60071 1.02665 m
.70251 1.01822 L
.68157 1.02132 L
.59024 1.0282 L
.60071 1.02665 L
F
.70251 1.01822 m
.80431 1.00978 L
.7729 1.01444 L
.68157 1.02132 L
.70251 1.01822 L
F
.49891 1.03509 m
.59024 1.0282 L
.57355 1.03023 L
.49891 1.03509 L
.49891 1.03509 L
F
.59024 1.0282 m
.68157 1.02132 L
.64819 1.02537 L
.57355 1.03023 L
.59024 1.0282 L
F
.68157 1.02132 m
.7729 1.01444 L
.72283 1.02051 L
.64819 1.02537 L
.68157 1.02132 L
F
.49891 1.03509 m
.57355 1.03023 L
.55177 1.03258 L
.49891 1.03509 L
.49891 1.03509 L
F
.57355 1.03023 m
.64819 1.02537 L
.60463 1.03007 L
.55177 1.03258 L
.57355 1.03023 L
F
.64819 1.02537 m
.72283 1.02051 L
.65749 1.02756 L
.60463 1.03007 L
.64819 1.02537 L
F
.49891 1.03509 m
.55177 1.03258 L
.52639 1.0351 L
.49891 1.03509 L
.49891 1.03509 L
F
.55177 1.03258 m
.60463 1.03007 L
.55387 1.03512 L
.52639 1.0351 L
.55177 1.03258 L
F
.60463 1.03007 m
.65749 1.02756 L
.58135 1.03514 L
.55387 1.03512 L
.60463 1.03007 L
F
.49891 1.03509 m
.52639 1.0351 L
.49914 1.03763 L
.49891 1.03509 L
.49891 1.03509 L
F
.52639 1.0351 m
.55387 1.03512 L
.49936 1.04016 L
.49914 1.03763 L
.52639 1.0351 L
F
.55387 1.03512 m
.58135 1.03514 L
.49959 1.0427 L
.49936 1.04016 L
.55387 1.03512 L
F
.49891 1.03509 m
.49914 1.03763 L
.47187 1.03997 L
.49891 1.03509 L
.49891 1.03509 L
F
.49914 1.03763 m
.49936 1.04016 L
.44482 1.04486 L
.47187 1.03997 L
.49914 1.03763 L
F
.49936 1.04016 m
.49959 1.0427 L
.41778 1.04975 L
.44482 1.04486 L
.49936 1.04016 L
F
.49891 1.03509 m
.47187 1.03997 L
.44644 1.04199 L
.49891 1.03509 L
.49891 1.03509 L
F
.47187 1.03997 m
.44482 1.04486 L
.39397 1.0489 L
.44644 1.04199 L
.47187 1.03997 L
F
.44482 1.04486 m
.41778 1.04975 L
.3415 1.0558 L
.39397 1.0489 L
.44482 1.04486 L
F
.49891 1.03509 m
.44644 1.04199 L
.42459 1.04354 L
.49891 1.03509 L
.49891 1.03509 L
F
.44644 1.04199 m
.39397 1.0489 L
.35027 1.05199 L
.42459 1.04354 L
.44644 1.04199 L
F
.39397 1.0489 m
.3415 1.0558 L
.27595 1.06044 L
.35027 1.05199 L
.39397 1.0489 L
F
.49891 1.03509 m
.42459 1.04354 L
.4078 1.04451 L
.49891 1.03509 L
.49891 1.03509 L
F
.42459 1.04354 m
.35027 1.05199 L
.3167 1.05393 L
.4078 1.04451 L
.42459 1.04354 L
F
.35027 1.05199 m
.27595 1.06044 L
.2256 1.06335 L
.3167 1.05393 L
.35027 1.05199 L
F
.49891 1.03509 m
.4078 1.04451 L
.39723 1.04484 L
.49891 1.03509 L
.49891 1.03509 L
F
.4078 1.04451 m
.3167 1.05393 L
.29555 1.05458 L
.39723 1.04484 L
.4078 1.04451 L
F
.3167 1.05393 m
.2256 1.06335 L
.19386 1.06433 L
.29555 1.05458 L
.3167 1.05393 L
F
.49891 1.03509 m
.39723 1.04484 L
.39358 1.0445 L
.49891 1.03509 L
.49891 1.03509 L
F
.39723 1.04484 m
.29555 1.05458 L
.28825 1.05391 L
.39358 1.0445 L
.39723 1.04484 L
F
.29555 1.05458 m
.19386 1.06433 L
.18292 1.06332 L
.28825 1.05391 L
.29555 1.05458 L
F
.49891 1.03509 m
.39358 1.0445 L
.39711 1.04352 L
.49891 1.03509 L
.49891 1.03509 L
F
.39358 1.0445 m
.28825 1.05391 L
.29531 1.05196 L
.39711 1.04352 L
.39358 1.0445 L
F
.28825 1.05391 m
.18292 1.06332 L
.19351 1.06039 L
.29531 1.05196 L
.28825 1.05391 L
F
.49891 1.03509 m
.39711 1.04352 L
.40758 1.04197 L
.49891 1.03509 L
.49891 1.03509 L
F
.39711 1.04352 m
.29531 1.05196 L
.31625 1.04885 L
.40758 1.04197 L
.39711 1.04352 L
F
.29531 1.05196 m
.19351 1.06039 L
.22491 1.05573 L
.31625 1.04885 L
.29531 1.05196 L
F
.49891 1.03509 m
.40758 1.04197 L
.42427 1.03995 L
.49891 1.03509 L
.49891 1.03509 L
F
.40758 1.04197 m
.31625 1.04885 L
.34963 1.04481 L
.42427 1.03995 L
.40758 1.04197 L
F
.31625 1.04885 m
.22491 1.05573 L
.27499 1.04967 L
.34963 1.04481 L
.31625 1.04885 L
F
.49891 1.03509 m
.42427 1.03995 L
.44605 1.03759 L
.49891 1.03509 L
.49891 1.03509 L
F
.42427 1.03995 m
.34963 1.04481 L
.39319 1.0401 L
.44605 1.03759 L
.42427 1.03995 L
F
.34963 1.04481 m
.27499 1.04967 L
.34032 1.04261 L
.39319 1.0401 L
.34963 1.04481 L
F
.49891 1.03509 m
.44605 1.03759 L
.47143 1.03507 L
.49891 1.03509 L
.49891 1.03509 L
F
.44605 1.03759 m
.39319 1.0401 L
.44395 1.03505 L
.47143 1.03507 L
.44605 1.03759 L
F
.39319 1.0401 m
.34032 1.04261 L
.41647 1.03504 L
.44395 1.03505 L
.39319 1.0401 L
F
.49891 1.03509 m
.47143 1.03507 L
.49868 1.03255 L
.49891 1.03509 L
.49891 1.03509 L
F
.47143 1.03507 m
.44395 1.03505 L
.49845 1.03001 L
.49868 1.03255 L
.47143 1.03507 L
F
.44395 1.03505 m
.41647 1.03504 L
.49823 1.02747 L
.49845 1.03001 L
.44395 1.03505 L
F
0 g
.49823 1.02747 m
.58003 1.02042 L
.65631 1.01437 L
.72186 1.00973 L
.77222 1.00682 L
.80395 1.00584 L
.8149 1.00685 L
.80431 1.00978 L
.7729 1.01444 L
.72283 1.02051 L
.65749 1.02756 L
.58135 1.03514 L
.49959 1.0427 L
.41778 1.04975 L
.3415 1.0558 L
.27595 1.06044 L
.2256 1.06335 L
.19386 1.06433 L
.18292 1.06332 L
.19351 1.06039 L
.22491 1.05573 L
.27499 1.04967 L
.34032 1.04261 L
.41647 1.03504 L
.49823 1.02747 L
s
.5 g
.4975 1.01929 m
.49727 1.01677 L
.5244 1.01443 L
.4975 1.01929 L
.4975 1.01929 L
F
.49727 1.01677 m
.49705 1.01424 L
.55131 1.00956 L
.5244 1.01443 L
.49727 1.01677 L
F
.49705 1.01424 m
.49682 1.01171 L
.57822 1.0047 L
.55131 1.00956 L
.49705 1.01424 L
F
.4975 1.01929 m
.5244 1.01443 L
.5497 1.01242 L
.4975 1.01929 L
.4975 1.01929 L
F
.5244 1.01443 m
.55131 1.00956 L
.60191 1.00555 L
.5497 1.01242 L
.5244 1.01443 L
F
.55131 1.00956 m
.57822 1.0047 L
.65411 .99868 L
.60191 1.00555 L
.55131 1.00956 L
F
.4975 1.01929 m
.5497 1.01242 L
.57144 1.01088 L
.4975 1.01929 L
.4975 1.01929 L
F
.5497 1.01242 m
.60191 1.00555 L
.64539 1.00247 L
.57144 1.01088 L
.5497 1.01242 L
F
.60191 1.00555 m
.65411 .99868 L
.71934 .99406 L
.64539 1.00247 L
.60191 1.00555 L
F
.4975 1.01929 m
.57144 1.01088 L
.58815 1.00992 L
.4975 1.01929 L
.4975 1.01929 L
F
.57144 1.01088 m
.64539 1.00247 L
.67879 1.00054 L
.58815 1.00992 L
.57144 1.01088 L
F
.64539 1.00247 m
.71934 .99406 L
.76944 .99117 L
.67879 1.00054 L
.64539 1.00247 L
F
.4975 1.01929 m
.58815 1.00992 L
.59867 1.00959 L
.4975 1.01929 L
.4975 1.01929 L
F
.58815 1.00992 m
.67879 1.00054 L
.69984 .99989 L
.59867 1.00959 L
.58815 1.00992 L
F
.67879 1.00054 m
.76944 .99117 L
.80102 .99019 L
.69984 .99989 L
.67879 1.00054 L
F
.4975 1.01929 m
.59867 1.00959 L
.6023 1.00993 L
.4975 1.01929 L
.4975 1.01929 L
F
.59867 1.00959 m
.69984 .99989 L
.7071 1.00056 L
.6023 1.00993 L
.59867 1.00959 L
F
.69984 .99989 m
.80102 .99019 L
.8119 .99119 L
.7071 1.00056 L
.69984 .99989 L
F
.4975 1.01929 m
.6023 1.00993 L
.59879 1.0109 L
.4975 1.01929 L
.4975 1.01929 L
F
.6023 1.00993 m
.7071 1.00056 L
.70008 1.00251 L
.59879 1.0109 L
.6023 1.00993 L
F
.7071 1.00056 m
.8119 .99119 L
.80137 .99411 L
.70008 1.00251 L
.7071 1.00056 L
F
.4975 1.01929 m
.59879 1.0109 L
.58837 1.01244 L
.4975 1.01929 L
.4975 1.01929 L
F
.59879 1.0109 m
.70008 1.00251 L
.67925 1.0056 L
.58837 1.01244 L
.59879 1.0109 L
F
.70008 1.00251 m
.80137 .99411 L
.77012 .99875 L
.67925 1.0056 L
.70008 1.00251 L
F
.4975 1.01929 m
.58837 1.01244 L
.57176 1.01446 L
.4975 1.01929 L
.4975 1.01929 L
F
.58837 1.01244 m
.67925 1.0056 L
.64603 1.00962 L
.57176 1.01446 L
.58837 1.01244 L
F
.67925 1.0056 m
.77012 .99875 L
.7203 1.00478 L
.64603 1.00962 L
.67925 1.0056 L
F
.4975 1.01929 m
.57176 1.01446 L
.55009 1.0168 L
.4975 1.01929 L
.4975 1.01929 L
F
.57176 1.01446 m
.64603 1.00962 L
.60269 1.0143 L
.55009 1.0168 L
.57176 1.01446 L
F
.64603 1.00962 m
.7203 1.00478 L
.65529 1.01181 L
.60269 1.0143 L
.64603 1.00962 L
F
.4975 1.01929 m
.55009 1.0168 L
.52484 1.01931 L
.4975 1.01929 L
.4975 1.01929 L
F
.55009 1.0168 m
.60269 1.0143 L
.55218 1.01932 L
.52484 1.01931 L
.55009 1.0168 L
F
.60269 1.0143 m
.65529 1.01181 L
.57953 1.01934 L
.55218 1.01932 L
.60269 1.0143 L
F
.4975 1.01929 m
.52484 1.01931 L
.49772 1.02182 L
.4975 1.01929 L
.4975 1.01929 L
F
.52484 1.01931 m
.55218 1.01932 L
.49795 1.02434 L
.49772 1.02182 L
.52484 1.01931 L
F
.55218 1.01932 m
.57953 1.01934 L
.49817 1.02687 L
.49795 1.02434 L
.55218 1.01932 L
F
.4975 1.01929 m
.49772 1.02182 L
.47059 1.02416 L
.4975 1.01929 L
.4975 1.01929 L
F
.49772 1.02182 m
.49795 1.02434 L
.44368 1.02902 L
.47059 1.02416 L
.49772 1.02182 L
F
.49795 1.02434 m
.49817 1.02687 L
.41678 1.03388 L
.44368 1.02902 L
.49795 1.02434 L
F
.4975 1.01929 m
.47059 1.02416 L
.44529 1.02616 L
.4975 1.01929 L
.4975 1.01929 L
F
.47059 1.02416 m
.44368 1.02902 L
.39309 1.03303 L
.44529 1.02616 L
.47059 1.02416 L
F
.44368 1.02902 m
.41678 1.03388 L
.34088 1.0399 L
.39309 1.03303 L
.44368 1.02902 L
F
.4975 1.01929 m
.44529 1.02616 L
.42355 1.0277 L
.4975 1.01929 L
.4975 1.01929 L
F
.44529 1.02616 m
.39309 1.03303 L
.3496 1.03611 L
.42355 1.0277 L
.44529 1.02616 L
F
.39309 1.03303 m
.34088 1.0399 L
.27566 1.04452 L
.3496 1.03611 L
.39309 1.03303 L
F
.4975 1.01929 m
.42355 1.0277 L
.40685 1.02867 L
.4975 1.01929 L
.4975 1.01929 L
F
.42355 1.0277 m
.3496 1.03611 L
.3162 1.03804 L
.40685 1.02867 L
.42355 1.0277 L
F
.3496 1.03611 m
.27566 1.04452 L
.22555 1.04741 L
.3162 1.03804 L
.3496 1.03611 L
F
.4975 1.01929 m
.40685 1.02867 L
.39632 1.02899 L
.4975 1.01929 L
.4975 1.01929 L
F
.40685 1.02867 m
.3162 1.03804 L
.29515 1.03869 L
.39632 1.02899 L
.40685 1.02867 L
F
.3162 1.03804 m
.22555 1.04741 L
.19398 1.04839 L
.29515 1.03869 L
.3162 1.03804 L
F
.4975 1.01929 m
.39632 1.02899 L
.39269 1.02866 L
.4975 1.01929 L
.4975 1.01929 L
F
.39632 1.02899 m
.29515 1.03869 L
.28789 1.03802 L
.39269 1.02866 L
.39632 1.02899 L
F
.29515 1.03869 m
.19398 1.04839 L
.18309 1.04739 L
.28789 1.03802 L
.29515 1.03869 L
F
.4975 1.01929 m
.39269 1.02866 L
.39621 1.02768 L
.4975 1.01929 L
.4975 1.01929 L
F
.39269 1.02866 m
.28789 1.03802 L
.29492 1.03608 L
.39621 1.02768 L
.39269 1.02866 L
F
.28789 1.03802 m
.18309 1.04739 L
.19363 1.04447 L
.29492 1.03608 L
.28789 1.03802 L
F
.4975 1.01929 m
.39621 1.02768 L
.40662 1.02614 L
.4975 1.01929 L
.4975 1.01929 L
F
.39621 1.02768 m
.29492 1.03608 L
.31575 1.03299 L
.40662 1.02614 L
.39621 1.02768 L
F
.29492 1.03608 m
.19363 1.04447 L
.22487 1.03983 L
.31575 1.03299 L
.29492 1.03608 L
F
.4975 1.01929 m
.40662 1.02614 L
.42323 1.02413 L
.4975 1.01929 L
.4975 1.01929 L
F
.40662 1.02614 m
.31575 1.03299 L
.34896 1.02896 L
.42323 1.02413 L
.40662 1.02614 L
F
.31575 1.03299 m
.22487 1.03983 L
.2747 1.0338 L
.34896 1.02896 L
.31575 1.03299 L
F
.4975 1.01929 m
.42323 1.02413 L
.4449 1.02179 L
.4975 1.01929 L
.4975 1.01929 L
F
.42323 1.02413 m
.34896 1.02896 L
.3923 1.02428 L
.4449 1.02179 L
.42323 1.02413 L
F
.34896 1.02896 m
.2747 1.0338 L
.33971 1.02678 L
.3923 1.02428 L
.34896 1.02896 L
F
.4975 1.01929 m
.4449 1.02179 L
.47015 1.01928 L
.4975 1.01929 L
.4975 1.01929 L
F
.4449 1.02179 m
.3923 1.02428 L
.44281 1.01926 L
.47015 1.01928 L
.4449 1.02179 L
F
.3923 1.02428 m
.33971 1.02678 L
.41547 1.01924 L
.44281 1.01926 L
.3923 1.02428 L
F
.4975 1.01929 m
.47015 1.01928 L
.49727 1.01677 L
.4975 1.01929 L
.4975 1.01929 L
F
.47015 1.01928 m
.44281 1.01926 L
.49705 1.01424 L
.49727 1.01677 L
.47015 1.01928 L
F
.44281 1.01926 m
.41547 1.01924 L
.49682 1.01171 L
.49705 1.01424 L
.44281 1.01926 L
F
0 g
.49682 1.01167 m
.57862 1.00463 L
.6549 .99858 L
.72045 .99394 L
.77081 .99103 L
.80254 .99004 L
.81348 .99105 L
.80289 .99399 L
.77149 .99865 L
.72142 1.00471 L
.65608 1.01177 L
.57994 1.01934 L
.49818 1.02691 L
.41637 1.03396 L
.34009 1.04001 L
.27454 1.04464 L
.22418 1.04755 L
.19245 1.04854 L
.18151 1.04753 L
.1921 1.0446 L
.2235 1.03994 L
.27358 1.03387 L
.33891 1.02681 L
.41506 1.01924 L
.49682 1.01167 L
s
.5 g
.49964 1.04326 m
.49823 1.02747 L
.58003 1.02042 L
.58145 1.03621 L
.49964 1.04326 L
F
.58145 1.03621 m
.58003 1.02042 L
.65631 1.01437 L
.65772 1.03017 L
.58145 1.03621 L
F
.65772 1.03017 m
.65631 1.01437 L
.72186 1.00973 L
.72328 1.02553 L
.65772 1.03017 L
F
.72328 1.02553 m
.72186 1.00973 L
.77222 1.00682 L
.77363 1.02262 L
.72328 1.02553 L
F
.77363 1.02262 m
.77222 1.00682 L
.80395 1.00584 L
.80536 1.02163 L
.77363 1.02262 L
F
.80536 1.02163 m
.80395 1.00584 L
.8149 1.00685 L
.81631 1.02264 L
.80536 1.02163 L
F
.81631 1.02264 m
.8149 1.00685 L
.80431 1.00978 L
.80572 1.02558 L
.81631 1.02264 L
F
.80572 1.02558 m
.80431 1.00978 L
.7729 1.01444 L
.77431 1.03023 L
.80572 1.02558 L
F
.77431 1.03023 m
.7729 1.01444 L
.72283 1.02051 L
.72424 1.0363 L
.77431 1.03023 L
F
.72424 1.0363 m
.72283 1.02051 L
.65749 1.02756 L
.6589 1.04336 L
.72424 1.0363 L
F
.6589 1.04336 m
.65749 1.02756 L
.58135 1.03514 L
.58276 1.05093 L
.6589 1.04336 L
F
.58276 1.05093 m
.58135 1.03514 L
.49959 1.0427 L
.501 1.0585 L
.58276 1.05093 L
F
.501 1.0585 m
.49959 1.0427 L
.41778 1.04975 L
.41919 1.06555 L
.501 1.0585 L
F
.41919 1.06555 m
.41778 1.04975 L
.3415 1.0558 L
.34292 1.0716 L
.41919 1.06555 L
F
.34292 1.0716 m
.3415 1.0558 L
.27595 1.06044 L
.27736 1.07623 L
.34292 1.0716 L
F
.27736 1.07623 m
.27595 1.06044 L
.2256 1.06335 L
.22701 1.07914 L
.27736 1.07623 L
F
.22701 1.07914 m
.2256 1.06335 L
.19386 1.06433 L
.19528 1.08013 L
.22701 1.07914 L
F
.19528 1.08013 m
.19386 1.06433 L
.18292 1.06332 L
.18433 1.07912 L
.19528 1.08013 L
F
.18433 1.07912 m
.18292 1.06332 L
.19351 1.06039 L
.19492 1.07619 L
.18433 1.07912 L
F
.19492 1.07619 m
.19351 1.06039 L
.22491 1.05573 L
.22633 1.07153 L
.19492 1.07619 L
F
.22633 1.07153 m
.22491 1.05573 L
.27499 1.04967 L
.2764 1.06546 L
.22633 1.07153 L
F
.2764 1.06546 m
.27499 1.04967 L
.34032 1.04261 L
.34174 1.0584 L
.2764 1.06546 L
F
.34174 1.0584 m
.34032 1.04261 L
.41647 1.03504 L
.41788 1.05083 L
.34174 1.0584 L
F
.41788 1.05083 m
.41647 1.03504 L
.49823 1.02747 L
.49964 1.04326 L
.41788 1.05083 L
F
.49823 1.02747 m
.49682 1.01167 L
.57862 1.00463 L
.58003 1.02042 L
.49823 1.02747 L
F
.58003 1.02042 m
.57862 1.00463 L
.6549 .99858 L
.65631 1.01437 L
.58003 1.02042 L
F
.65631 1.01437 m
.6549 .99858 L
.72045 .99394 L
.72186 1.00973 L
.65631 1.01437 L
F
.72186 1.00973 m
.72045 .99394 L
.77081 .99103 L
.77222 1.00682 L
.72186 1.00973 L
F
.77222 1.00682 m
.77081 .99103 L
.80254 .99004 L
.80395 1.00584 L
.77222 1.00682 L
F
.80395 1.00584 m
.80254 .99004 L
.81348 .99105 L
.8149 1.00685 L
.80395 1.00584 L
F
.8149 1.00685 m
.81348 .99105 L
.80289 .99399 L
.80431 1.00978 L
.8149 1.00685 L
F
.80431 1.00978 m
.80289 .99399 L
.77149 .99865 L
.7729 1.01444 L
.80431 1.00978 L
F
.7729 1.01444 m
.77149 .99865 L
.72142 1.00471 L
.72283 1.02051 L
.7729 1.01444 L
F
.72283 1.02051 m
.72142 1.00471 L
.65608 1.01177 L
.65749 1.02756 L
.72283 1.02051 L
F
.65749 1.02756 m
.65608 1.01177 L
.57994 1.01934 L
.58135 1.03514 L
.65749 1.02756 L
F
.58135 1.03514 m
.57994 1.01934 L
.49818 1.02691 L
.49959 1.0427 L
.58135 1.03514 L
F
.49959 1.0427 m
.49818 1.02691 L
.41637 1.03396 L
.41778 1.04975 L
.49959 1.0427 L
F
.41778 1.04975 m
.41637 1.03396 L
.34009 1.04001 L
.3415 1.0558 L
.41778 1.04975 L
F
.3415 1.0558 m
.34009 1.04001 L
.27454 1.04464 L
.27595 1.06044 L
.3415 1.0558 L
F
.27595 1.06044 m
.27454 1.04464 L
.22418 1.04755 L
.2256 1.06335 L
.27595 1.06044 L
F
.2256 1.06335 m
.22418 1.04755 L
.19245 1.04854 L
.19386 1.06433 L
.2256 1.06335 L
F
.19386 1.06433 m
.19245 1.04854 L
.18151 1.04753 L
.18292 1.06332 L
.19386 1.06433 L
F
.18292 1.06332 m
.18151 1.04753 L
.1921 1.0446 L
.19351 1.06039 L
.18292 1.06332 L
F
.19351 1.06039 m
.1921 1.0446 L
.2235 1.03994 L
.22491 1.05573 L
.19351 1.06039 L
F
.22491 1.05573 m
.2235 1.03994 L
.27358 1.03387 L
.27499 1.04967 L
.22491 1.05573 L
F
.27499 1.04967 m
.27358 1.03387 L
.33891 1.02681 L
.34032 1.04261 L
.27499 1.04967 L
F
.34032 1.04261 m
.33891 1.02681 L
.41506 1.01924 L
.41647 1.03504 L
.34032 1.04261 L
F
.41647 1.03504 m
.41506 1.01924 L
.49682 1.01167 L
.49823 1.02747 L
.41647 1.03504 L
F
.50032 1.2095 m
.50018 1.20271 L
.52071 1.20254 L
.50032 1.2095 L
.50032 1.2095 L
F
.50018 1.20271 m
.50005 1.19592 L
.54111 1.19557 L
.52071 1.20254 L
.50018 1.20271 L
F
.50005 1.19592 m
.49991 1.18913 L
.5615 1.1886 L
.54111 1.19557 L
.50005 1.19592 L
F
.50032 1.2095 m
.52071 1.20254 L
.53985 1.20283 L
.50032 1.2095 L
.50032 1.2095 L
F
.52071 1.20254 m
.54111 1.19557 L
.57938 1.19616 L
.53985 1.20283 L
.52071 1.20254 L
F
.54111 1.19557 m
.5615 1.1886 L
.61891 1.18949 L
.57938 1.19616 L
.54111 1.19557 L
F
.50032 1.2095 m
.53985 1.20283 L
.5563 1.20359 L
.50032 1.2095 L
.50032 1.2095 L
F
.53985 1.20283 m
.57938 1.19616 L
.61227 1.19767 L
.5563 1.20359 L
.53985 1.20283 L
F
.57938 1.19616 m
.61891 1.18949 L
.66825 1.19175 L
.61227 1.19767 L
.57938 1.19616 L
F
.50032 1.2095 m
.5563 1.20359 L
.56892 1.20474 L
.50032 1.2095 L
.50032 1.2095 L
F
.5563 1.20359 m
.61227 1.19767 L
.63753 1.19998 L
.56892 1.20474 L
.5563 1.20359 L
F
.61227 1.19767 m
.66825 1.19175 L
.70613 1.19522 L
.63753 1.19998 L
.61227 1.19767 L
F
.50032 1.2095 m
.56892 1.20474 L
.57688 1.20622 L
.50032 1.2095 L
.50032 1.2095 L
F
.56892 1.20474 m
.63753 1.19998 L
.65344 1.20294 L
.57688 1.20622 L
.56892 1.20474 L
F
.63753 1.19998 m
.70613 1.19522 L
.73 1.19966 L
.65344 1.20294 L
.63753 1.19998 L
F
.50032 1.2095 m
.57688 1.20622 L
.57962 1.20793 L
.50032 1.2095 L
.50032 1.2095 L
F
.57688 1.20622 m
.65344 1.20294 L
.65891 1.20635 L
.57962 1.20793 L
.57688 1.20622 L
F
.65344 1.20294 m
.73 1.19966 L
.73821 1.20477 L
.65891 1.20635 L
.65344 1.20294 L
F
.50032 1.2095 m
.57962 1.20793 L
.57695 1.20974 L
.50032 1.2095 L
.50032 1.2095 L
F
.57962 1.20793 m
.65891 1.20635 L
.65358 1.20997 L
.57695 1.20974 L
.57962 1.20793 L
F
.65891 1.20635 m
.73821 1.20477 L
.73021 1.21021 L
.65358 1.20997 L
.65891 1.20635 L
F
.50032 1.2095 m
.57695 1.20974 L
.56906 1.21154 L
.50032 1.2095 L
.50032 1.2095 L
F
.57695 1.20974 m
.65358 1.20997 L
.6378 1.21357 L
.56906 1.21154 L
.57695 1.20974 L
F
.65358 1.20997 m
.73021 1.21021 L
.70654 1.2156 L
.6378 1.21357 L
.65358 1.20997 L
F
.50032 1.2095 m
.56906 1.21154 L
.55649 1.21319 L
.50032 1.2095 L
.50032 1.2095 L
F
.56906 1.21154 m
.6378 1.21357 L
.61265 1.21688 L
.55649 1.21319 L
.56906 1.21154 L
F
.6378 1.21357 m
.70654 1.2156 L
.66882 1.22057 L
.61265 1.21688 L
.6378 1.21357 L
F
.50032 1.2095 m
.55649 1.21319 L
.54008 1.2146 L
.50032 1.2095 L
.50032 1.2095 L
F
.55649 1.21319 m
.61265 1.21688 L
.57985 1.21969 L
.54008 1.2146 L
.55649 1.21319 L
F
.61265 1.21688 m
.66882 1.22057 L
.61961 1.22479 L
.57985 1.21969 L
.61265 1.21688 L
F
.50032 1.2095 m
.54008 1.2146 L
.52097 1.21566 L
.50032 1.2095 L
.50032 1.2095 L
F
.54008 1.2146 m
.57985 1.21969 L
.54163 1.22181 L
.52097 1.21566 L
.54008 1.2146 L
F
.57985 1.21969 m
.61961 1.22479 L
.56228 1.22796 L
.54163 1.22181 L
.57985 1.21969 L
F
.50032 1.2095 m
.52097 1.21566 L
.50045 1.2163 L
.50032 1.2095 L
.50032 1.2095 L
F
.52097 1.21566 m
.54163 1.22181 L
.50059 1.22309 L
.50045 1.2163 L
.52097 1.21566 L
F
.54163 1.22181 m
.56228 1.22796 L
.50073 1.22988 L
.50059 1.22309 L
.54163 1.22181 L
F
.50032 1.2095 m
.50045 1.2163 L
.47993 1.21647 L
.50032 1.2095 L
.50032 1.2095 L
F
.50045 1.2163 m
.50059 1.22309 L
.45953 1.22344 L
.47993 1.21647 L
.50045 1.2163 L
F
.50059 1.22309 m
.50073 1.22988 L
.43914 1.23041 L
.45953 1.22344 L
.50059 1.22309 L
F
.50032 1.2095 m
.47993 1.21647 L
.46079 1.21618 L
.50032 1.2095 L
.50032 1.2095 L
F
.47993 1.21647 m
.45953 1.22344 L
.42126 1.22285 L
.46079 1.21618 L
.47993 1.21647 L
F
.45953 1.22344 m
.43914 1.23041 L
.38173 1.22952 L
.42126 1.22285 L
.45953 1.22344 L
F
.50032 1.2095 m
.46079 1.21618 L
.44434 1.21542 L
.50032 1.2095 L
.50032 1.2095 L
F
.46079 1.21618 m
.42126 1.22285 L
.38837 1.22134 L
.44434 1.21542 L
.46079 1.21618 L
F
.42126 1.22285 m
.38173 1.22952 L
.33239 1.22726 L
.38837 1.22134 L
.42126 1.22285 L
F
.50032 1.2095 m
.44434 1.21542 L
.43171 1.21427 L
.50032 1.2095 L
.50032 1.2095 L
F
.44434 1.21542 m
.38837 1.22134 L
.36311 1.21903 L
.43171 1.21427 L
.44434 1.21542 L
F
.38837 1.22134 m
.33239 1.22726 L
.29451 1.22379 L
.36311 1.21903 L
.38837 1.22134 L
F
.50032 1.2095 m
.43171 1.21427 L
.42376 1.21279 L
.50032 1.2095 L
.50032 1.2095 L
F
.43171 1.21427 m
.36311 1.21903 L
.3472 1.21607 L
.42376 1.21279 L
.43171 1.21427 L
F
.36311 1.21903 m
.29451 1.22379 L
.27064 1.21935 L
.3472 1.21607 L
.36311 1.21903 L
F
.50032 1.2095 m
.42376 1.21279 L
.42102 1.21108 L
.50032 1.2095 L
.50032 1.2095 L
F
.42376 1.21279 m
.3472 1.21607 L
.34173 1.21266 L
.42102 1.21108 L
.42376 1.21279 L
F
.3472 1.21607 m
.27064 1.21935 L
.26243 1.21424 L
.34173 1.21266 L
.3472 1.21607 L
F
.50032 1.2095 m
.42102 1.21108 L
.42369 1.20927 L
.50032 1.2095 L
.50032 1.2095 L
F
.42102 1.21108 m
.34173 1.21266 L
.34706 1.20904 L
.42369 1.20927 L
.42102 1.21108 L
F
.34173 1.21266 m
.26243 1.21424 L
.27043 1.2088 L
.34706 1.20904 L
.34173 1.21266 L
F
.50032 1.2095 m
.42369 1.20927 L
.43158 1.20747 L
.50032 1.2095 L
.50032 1.2095 L
F
.42369 1.20927 m
.34706 1.20904 L
.36284 1.20544 L
.43158 1.20747 L
.42369 1.20927 L
F
.34706 1.20904 m
.27043 1.2088 L
.2941 1.20341 L
.36284 1.20544 L
.34706 1.20904 L
F
.50032 1.2095 m
.43158 1.20747 L
.44415 1.20582 L
.50032 1.2095 L
.50032 1.2095 L
F
.43158 1.20747 m
.36284 1.20544 L
.38799 1.20213 L
.44415 1.20582 L
.43158 1.20747 L
F
.36284 1.20544 m
.2941 1.20341 L
.33182 1.19844 L
.38799 1.20213 L
.36284 1.20544 L
F
.50032 1.2095 m
.44415 1.20582 L
.46055 1.20441 L
.50032 1.2095 L
.50032 1.2095 L
F
.44415 1.20582 m
.38799 1.20213 L
.42079 1.19932 L
.46055 1.20441 L
.44415 1.20582 L
F
.38799 1.20213 m
.33182 1.19844 L
.38102 1.19422 L
.42079 1.19932 L
.38799 1.20213 L
F
.50032 1.2095 m
.46055 1.20441 L
.47967 1.20335 L
.50032 1.2095 L
.50032 1.2095 L
F
.46055 1.20441 m
.42079 1.19932 L
.45901 1.1972 L
.47967 1.20335 L
.46055 1.20441 L
F
.42079 1.19932 m
.38102 1.19422 L
.43836 1.19105 L
.45901 1.1972 L
.42079 1.19932 L
F
.50032 1.2095 m
.47967 1.20335 L
.50018 1.20271 L
.50032 1.2095 L
.50032 1.2095 L
F
.47967 1.20335 m
.45901 1.1972 L
.50005 1.19592 L
.50018 1.20271 L
.47967 1.20335 L
F
.45901 1.1972 m
.43836 1.19105 L
.49991 1.18913 L
.50005 1.19592 L
.45901 1.1972 L
F
0 g
.49991 1.18913 m
.5615 1.1886 L
.61891 1.18949 L
.66825 1.19175 L
.70613 1.19522 L
.73 1.19966 L
.73821 1.20477 L
.73021 1.21021 L
.70654 1.2156 L
.66882 1.22057 L
.61961 1.22479 L
.56228 1.22796 L
.50073 1.22988 L
.43914 1.23041 L
.38173 1.22952 L
.33239 1.22726 L
.29451 1.22379 L
.27064 1.21935 L
.26243 1.21424 L
.27043 1.2088 L
.2941 1.20341 L
.33182 1.19844 L
.38102 1.19422 L
.43836 1.19105 L
.49991 1.18913 L
s
.5 g
.50001 1.1937 m
.49987 1.18691 L
.5204 1.18673 L
.50001 1.1937 L
.50001 1.1937 L
F
.49987 1.18691 m
.49974 1.18012 L
.54079 1.17976 L
.5204 1.18673 L
.49987 1.18691 L
F
.49974 1.18012 m
.4996 1.17333 L
.56118 1.1728 L
.54079 1.17976 L
.49974 1.18012 L
F
.50001 1.1937 m
.5204 1.18673 L
.53954 1.18703 L
.50001 1.1937 L
.50001 1.1937 L
F
.5204 1.18673 m
.54079 1.17976 L
.57907 1.18036 L
.53954 1.18703 L
.5204 1.18673 L
F
.54079 1.17976 m
.56118 1.1728 L
.6186 1.17369 L
.57907 1.18036 L
.54079 1.17976 L
F
.50001 1.1937 m
.53954 1.18703 L
.55598 1.18779 L
.50001 1.1937 L
.50001 1.1937 L
F
.53954 1.18703 m
.57907 1.18036 L
.61196 1.18187 L
.55598 1.18779 L
.53954 1.18703 L
F
.57907 1.18036 m
.6186 1.17369 L
.66793 1.17595 L
.61196 1.18187 L
.57907 1.18036 L
F
.50001 1.1937 m
.55598 1.18779 L
.56861 1.18894 L
.50001 1.1937 L
.50001 1.1937 L
F
.55598 1.18779 m
.61196 1.18187 L
.63722 1.18418 L
.56861 1.18894 L
.55598 1.18779 L
F
.61196 1.18187 m
.66793 1.17595 L
.70582 1.17942 L
.63722 1.18418 L
.61196 1.18187 L
F
.50001 1.1937 m
.56861 1.18894 L
.57656 1.19042 L
.50001 1.1937 L
.50001 1.1937 L
F
.56861 1.18894 m
.63722 1.18418 L
.65312 1.18714 L
.57656 1.19042 L
.56861 1.18894 L
F
.63722 1.18418 m
.70582 1.17942 L
.72968 1.18386 L
.65312 1.18714 L
.63722 1.18418 L
F
.50001 1.1937 m
.57656 1.19042 L
.5793 1.19213 L
.50001 1.1937 L
.50001 1.1937 L
F
.57656 1.19042 m
.65312 1.18714 L
.6586 1.19055 L
.5793 1.19213 L
.57656 1.19042 L
F
.65312 1.18714 m
.72968 1.18386 L
.73789 1.18897 L
.6586 1.19055 L
.65312 1.18714 L
F
.50001 1.1937 m
.5793 1.19213 L
.57663 1.19394 L
.50001 1.1937 L
.50001 1.1937 L
F
.5793 1.19213 m
.6586 1.19055 L
.65326 1.19417 L
.57663 1.19394 L
.5793 1.19213 L
F
.6586 1.19055 m
.73789 1.18897 L
.72989 1.19441 L
.65326 1.19417 L
.6586 1.19055 L
F
.50001 1.1937 m
.57663 1.19394 L
.56875 1.19573 L
.50001 1.1937 L
.50001 1.1937 L
F
.57663 1.19394 m
.65326 1.19417 L
.63749 1.19776 L
.56875 1.19573 L
.57663 1.19394 L
F
.65326 1.19417 m
.72989 1.19441 L
.70623 1.1998 L
.63749 1.19776 L
.65326 1.19417 L
F
.50001 1.1937 m
.56875 1.19573 L
.55617 1.19739 L
.50001 1.1937 L
.50001 1.1937 L
F
.56875 1.19573 m
.63749 1.19776 L
.61234 1.20108 L
.55617 1.19739 L
.56875 1.19573 L
F
.63749 1.19776 m
.70623 1.1998 L
.6685 1.20477 L
.61234 1.20108 L
.63749 1.19776 L
F
.50001 1.1937 m
.55617 1.19739 L
.53977 1.1988 L
.50001 1.1937 L
.50001 1.1937 L
F
.55617 1.19739 m
.61234 1.20108 L
.57954 1.20389 L
.53977 1.1988 L
.55617 1.19739 L
F
.61234 1.20108 m
.6685 1.20477 L
.6193 1.20899 L
.57954 1.20389 L
.61234 1.20108 L
F
.50001 1.1937 m
.53977 1.1988 L
.52066 1.19986 L
.50001 1.1937 L
.50001 1.1937 L
F
.53977 1.1988 m
.57954 1.20389 L
.54131 1.20601 L
.52066 1.19986 L
.53977 1.1988 L
F
.57954 1.20389 m
.6193 1.20899 L
.56197 1.21216 L
.54131 1.20601 L
.57954 1.20389 L
F
.50001 1.1937 m
.52066 1.19986 L
.50014 1.2005 L
.50001 1.1937 L
.50001 1.1937 L
F
.52066 1.19986 m
.54131 1.20601 L
.50028 1.20729 L
.50014 1.2005 L
.52066 1.19986 L
F
.54131 1.20601 m
.56197 1.21216 L
.50041 1.21408 L
.50028 1.20729 L
.54131 1.20601 L
F
.50001 1.1937 m
.50014 1.2005 L
.47961 1.20067 L
.50001 1.1937 L
.50001 1.1937 L
F
.50014 1.2005 m
.50028 1.20729 L
.45922 1.20764 L
.47961 1.20067 L
.50014 1.2005 L
F
.50028 1.20729 m
.50041 1.21408 L
.43883 1.21461 L
.45922 1.20764 L
.50028 1.20729 L
F
.50001 1.1937 m
.47961 1.20067 L
.46047 1.20037 L
.50001 1.1937 L
.50001 1.1937 L
F
.47961 1.20067 m
.45922 1.20764 L
.42094 1.20705 L
.46047 1.20037 L
.47961 1.20067 L
F
.45922 1.20764 m
.43883 1.21461 L
.38141 1.21372 L
.42094 1.20705 L
.45922 1.20764 L
F
.50001 1.1937 m
.46047 1.20037 L
.44403 1.19962 L
.50001 1.1937 L
.50001 1.1937 L
F
.46047 1.20037 m
.42094 1.20705 L
.38805 1.20554 L
.44403 1.19962 L
.46047 1.20037 L
F
.42094 1.20705 m
.38141 1.21372 L
.33208 1.21146 L
.38805 1.20554 L
.42094 1.20705 L
F
.50001 1.1937 m
.44403 1.19962 L
.4314 1.19847 L
.50001 1.1937 L
.50001 1.1937 L
F
.44403 1.19962 m
.38805 1.20554 L
.3628 1.20323 L
.4314 1.19847 L
.44403 1.19962 L
F
.38805 1.20554 m
.33208 1.21146 L
.29419 1.20799 L
.3628 1.20323 L
.38805 1.20554 L
F
.50001 1.1937 m
.4314 1.19847 L
.42345 1.19699 L
.50001 1.1937 L
.50001 1.1937 L
F
.4314 1.19847 m
.3628 1.20323 L
.34689 1.20027 L
.42345 1.19699 L
.4314 1.19847 L
F
.3628 1.20323 m
.29419 1.20799 L
.27033 1.20355 L
.34689 1.20027 L
.3628 1.20323 L
F
.50001 1.1937 m
.42345 1.19699 L
.42071 1.19528 L
.50001 1.1937 L
.50001 1.1937 L
F
.42345 1.19699 m
.34689 1.20027 L
.34141 1.19686 L
.42071 1.19528 L
.42345 1.19699 L
F
.34689 1.20027 m
.27033 1.20355 L
.26212 1.19844 L
.34141 1.19686 L
.34689 1.20027 L
F
.50001 1.1937 m
.42071 1.19528 L
.42338 1.19347 L
.50001 1.1937 L
.50001 1.1937 L
F
.42071 1.19528 m
.34141 1.19686 L
.34675 1.19323 L
.42338 1.19347 L
.42071 1.19528 L
F
.34141 1.19686 m
.26212 1.19844 L
.27012 1.193 L
.34675 1.19323 L
.34141 1.19686 L
F
.50001 1.1937 m
.42338 1.19347 L
.43127 1.19167 L
.50001 1.1937 L
.50001 1.1937 L
F
.42338 1.19347 m
.34675 1.19323 L
.36253 1.18964 L
.43127 1.19167 L
.42338 1.19347 L
F
.34675 1.19323 m
.27012 1.193 L
.29379 1.18761 L
.36253 1.18964 L
.34675 1.19323 L
F
.50001 1.1937 m
.43127 1.19167 L
.44384 1.19002 L
.50001 1.1937 L
.50001 1.1937 L
F
.43127 1.19167 m
.36253 1.18964 L
.38767 1.18633 L
.44384 1.19002 L
.43127 1.19167 L
F
.36253 1.18964 m
.29379 1.18761 L
.33151 1.18264 L
.38767 1.18633 L
.36253 1.18964 L
F
.50001 1.1937 m
.44384 1.19002 L
.46024 1.18861 L
.50001 1.1937 L
.50001 1.1937 L
F
.44384 1.19002 m
.38767 1.18633 L
.42048 1.18352 L
.46024 1.18861 L
.44384 1.19002 L
F
.38767 1.18633 m
.33151 1.18264 L
.38071 1.17842 L
.42048 1.18352 L
.38767 1.18633 L
F
.50001 1.1937 m
.46024 1.18861 L
.47935 1.18755 L
.50001 1.1937 L
.50001 1.1937 L
F
.46024 1.18861 m
.42048 1.18352 L
.4587 1.1814 L
.47935 1.18755 L
.46024 1.18861 L
F
.42048 1.18352 m
.38071 1.17842 L
.43804 1.17524 L
.4587 1.1814 L
.42048 1.18352 L
F
.50001 1.1937 m
.47935 1.18755 L
.49987 1.18691 L
.50001 1.1937 L
.50001 1.1937 L
F
.47935 1.18755 m
.4587 1.1814 L
.49974 1.18012 L
.49987 1.18691 L
.47935 1.18755 L
F
.4587 1.1814 m
.43804 1.17524 L
.4996 1.17333 L
.49974 1.18012 L
.4587 1.1814 L
F
0 g
.4996 1.17333 m
.56118 1.1728 L
.6186 1.17369 L
.66793 1.17595 L
.70582 1.17942 L
.72968 1.18386 L
.73789 1.18897 L
.72989 1.19441 L
.70623 1.1998 L
.6685 1.20477 L
.6193 1.20899 L
.56197 1.21216 L
.50041 1.21408 L
.43883 1.21461 L
.38141 1.21372 L
.33208 1.21146 L
.29419 1.20799 L
.27033 1.20355 L
.26212 1.19844 L
.27012 1.193 L
.29379 1.18761 L
.33151 1.18264 L
.38071 1.17842 L
.43804 1.17524 L
.4996 1.17333 L
s
.5 g
.49969 1.1779 m
.49956 1.17114 L
.51998 1.17097 L
.49969 1.1779 L
.49969 1.1779 L
F
.49956 1.17114 m
.49942 1.16439 L
.54027 1.16403 L
.51998 1.17097 L
.49956 1.17114 L
F
.49942 1.16439 m
.49929 1.15763 L
.56056 1.1571 L
.54027 1.16403 L
.49942 1.16439 L
F
.49969 1.1779 m
.51998 1.17097 L
.53902 1.17126 L
.49969 1.1779 L
.49969 1.1779 L
F
.51998 1.17097 m
.54027 1.16403 L
.57836 1.16463 L
.53902 1.17126 L
.51998 1.17097 L
F
.54027 1.16403 m
.56056 1.1571 L
.61769 1.15799 L
.57836 1.16463 L
.54027 1.16403 L
F
.49969 1.1779 m
.53902 1.17126 L
.55539 1.17201 L
.49969 1.1779 L
.49969 1.1779 L
F
.53902 1.17126 m
.57836 1.16463 L
.61108 1.16613 L
.55539 1.17201 L
.53902 1.17126 L
F
.57836 1.16463 m
.61769 1.15799 L
.66678 1.16024 L
.61108 1.16613 L
.57836 1.16463 L
F
.49969 1.1779 m
.55539 1.17201 L
.56795 1.17316 L
.49969 1.1779 L
.49969 1.1779 L
F
.55539 1.17201 m
.61108 1.16613 L
.63621 1.16843 L
.56795 1.17316 L
.55539 1.17201 L
F
.61108 1.16613 m
.66678 1.16024 L
.70448 1.16369 L
.63621 1.16843 L
.61108 1.16613 L
F
.49969 1.1779 m
.56795 1.17316 L
.57587 1.17464 L
.49969 1.1779 L
.49969 1.1779 L
F
.56795 1.17316 m
.63621 1.16843 L
.65204 1.17137 L
.57587 1.17464 L
.56795 1.17316 L
F
.63621 1.16843 m
.70448 1.16369 L
.72822 1.16811 L
.65204 1.17137 L
.63621 1.16843 L
F
.49969 1.1779 m
.57587 1.17464 L
.57859 1.17633 L
.49969 1.1779 L
.49969 1.1779 L
F
.57587 1.17464 m
.65204 1.17137 L
.65749 1.17476 L
.57859 1.17633 L
.57587 1.17464 L
F
.65204 1.17137 m
.72822 1.16811 L
.73639 1.17319 L
.65749 1.17476 L
.65204 1.17137 L
F
.49969 1.1779 m
.57859 1.17633 L
.57594 1.17814 L
.49969 1.1779 L
.49969 1.1779 L
F
.57859 1.17633 m
.65749 1.17476 L
.65218 1.17837 L
.57594 1.17814 L
.57859 1.17633 L
F
.65749 1.17476 m
.73639 1.17319 L
.72843 1.1786 L
.65218 1.17837 L
.65749 1.17476 L
F
.49969 1.1779 m
.57594 1.17814 L
.56809 1.17992 L
.49969 1.1779 L
.49969 1.1779 L
F
.57594 1.17814 m
.65218 1.17837 L
.63648 1.18194 L
.56809 1.17992 L
.57594 1.17814 L
F
.65218 1.17837 m
.72843 1.1786 L
.70488 1.18396 L
.63648 1.18194 L
.65218 1.17837 L
F
.49969 1.1779 m
.56809 1.17992 L
.55558 1.18157 L
.49969 1.1779 L
.49969 1.1779 L
F
.56809 1.17992 m
.63648 1.18194 L
.61146 1.18524 L
.55558 1.18157 L
.56809 1.17992 L
F
.63648 1.18194 m
.70488 1.18396 L
.66735 1.18891 L
.61146 1.18524 L
.63648 1.18194 L
F
.49969 1.1779 m
.55558 1.18157 L
.53926 1.18297 L
.49969 1.1779 L
.49969 1.1779 L
F
.55558 1.18157 m
.61146 1.18524 L
.57882 1.18804 L
.53926 1.18297 L
.55558 1.18157 L
F
.61146 1.18524 m
.66735 1.18891 L
.61839 1.19311 L
.57882 1.18804 L
.61146 1.18524 L
F
.49969 1.1779 m
.53926 1.18297 L
.52024 1.18403 L
.49969 1.1779 L
.49969 1.1779 L
F
.53926 1.18297 m
.57882 1.18804 L
.54079 1.19015 L
.52024 1.18403 L
.53926 1.18297 L
F
.57882 1.18804 m
.61839 1.19311 L
.56134 1.19627 L
.54079 1.19015 L
.57882 1.18804 L
F
.49969 1.1779 m
.52024 1.18403 L
.49983 1.18466 L
.49969 1.1779 L
.49969 1.1779 L
F
.52024 1.18403 m
.54079 1.19015 L
.49996 1.19142 L
.49983 1.18466 L
.52024 1.18403 L
F
.54079 1.19015 m
.56134 1.19627 L
.50009 1.19818 L
.49996 1.19142 L
.54079 1.19015 L
F
.49969 1.1779 m
.49983 1.18466 L
.4794 1.18484 L
.49969 1.1779 L
.49969 1.1779 L
F
.49983 1.18466 m
.49996 1.19142 L
.45911 1.19177 L
.4794 1.18484 L
.49983 1.18466 L
F
.49996 1.19142 m
.50009 1.19818 L
.43882 1.19871 L
.45911 1.19177 L
.49996 1.19142 L
F
.49969 1.1779 m
.4794 1.18484 L
.46036 1.18454 L
.49969 1.1779 L
.49969 1.1779 L
F
.4794 1.18484 m
.45911 1.19177 L
.42102 1.19118 L
.46036 1.18454 L
.4794 1.18484 L
F
.45911 1.19177 m
.43882 1.19871 L
.38169 1.19782 L
.42102 1.19118 L
.45911 1.19177 L
F
.49969 1.1779 m
.46036 1.18454 L
.444 1.18379 L
.49969 1.1779 L
.49969 1.1779 L
F
.46036 1.18454 m
.42102 1.19118 L
.3883 1.18968 L
.444 1.18379 L
.46036 1.18454 L
F
.42102 1.19118 m
.38169 1.19782 L
.33261 1.19557 L
.3883 1.18968 L
.42102 1.19118 L
F
.49969 1.1779 m
.444 1.18379 L
.43143 1.18264 L
.49969 1.1779 L
.49969 1.1779 L
F
.444 1.18379 m
.3883 1.18968 L
.36317 1.18738 L
.43143 1.18264 L
.444 1.18379 L
F
.3883 1.18968 m
.33261 1.19557 L
.29491 1.19212 L
.36317 1.18738 L
.3883 1.18968 L
F
.49969 1.1779 m
.43143 1.18264 L
.42351 1.18117 L
.49969 1.1779 L
.49969 1.1779 L
F
.43143 1.18264 m
.36317 1.18738 L
.34734 1.18443 L
.42351 1.18117 L
.43143 1.18264 L
F
.36317 1.18738 m
.29491 1.19212 L
.27116 1.1877 L
.34734 1.18443 L
.36317 1.18738 L
F
.49969 1.1779 m
.42351 1.18117 L
.42079 1.17947 L
.49969 1.1779 L
.49969 1.1779 L
F
.42351 1.18117 m
.34734 1.18443 L
.34189 1.18104 L
.42079 1.17947 L
.42351 1.18117 L
F
.34734 1.18443 m
.27116 1.1877 L
.26299 1.18261 L
.34189 1.18104 L
.34734 1.18443 L
F
.49969 1.1779 m
.42079 1.17947 L
.42345 1.17767 L
.49969 1.1779 L
.49969 1.1779 L
F
.42079 1.17947 m
.34189 1.18104 L
.3472 1.17744 L
.42345 1.17767 L
.42079 1.17947 L
F
.34189 1.18104 m
.26299 1.18261 L
.27095 1.1772 L
.3472 1.17744 L
.34189 1.18104 L
F
.49969 1.1779 m
.42345 1.17767 L
.43129 1.17588 L
.49969 1.1779 L
.49969 1.1779 L
F
.42345 1.17767 m
.3472 1.17744 L
.3629 1.17386 L
.43129 1.17588 L
.42345 1.17767 L
F
.3472 1.17744 m
.27095 1.1772 L
.2945 1.17184 L
.3629 1.17386 L
.3472 1.17744 L
F
.49969 1.1779 m
.43129 1.17588 L
.44381 1.17423 L
.49969 1.1779 L
.49969 1.1779 L
F
.43129 1.17588 m
.3629 1.17386 L
.38792 1.17056 L
.44381 1.17423 L
.43129 1.17588 L
F
.3629 1.17386 m
.2945 1.17184 L
.33203 1.16689 L
.38792 1.17056 L
.3629 1.17386 L
F
.49969 1.1779 m
.44381 1.17423 L
.46013 1.17283 L
.49969 1.1779 L
.49969 1.1779 L
F
.44381 1.17423 m
.38792 1.17056 L
.42056 1.16777 L
.46013 1.17283 L
.44381 1.17423 L
F
.38792 1.17056 m
.33203 1.16689 L
.38099 1.1627 L
.42056 1.16777 L
.38792 1.17056 L
F
.49969 1.1779 m
.46013 1.17283 L
.47914 1.17178 L
.49969 1.1779 L
.49969 1.1779 L
F
.46013 1.17283 m
.42056 1.16777 L
.45859 1.16566 L
.47914 1.17178 L
.46013 1.17283 L
F
.42056 1.16777 m
.38099 1.1627 L
.43804 1.15954 L
.45859 1.16566 L
.42056 1.16777 L
F
.49969 1.1779 m
.47914 1.17178 L
.49956 1.17114 L
.49969 1.1779 L
.49969 1.1779 L
F
.47914 1.17178 m
.45859 1.16566 L
.49942 1.16439 L
.49956 1.17114 L
.47914 1.17178 L
F
.45859 1.16566 m
.43804 1.15954 L
.49929 1.15763 L
.49942 1.16439 L
.45859 1.16566 L
F
0 g
.49929 1.15752 m
.56087 1.15699 L
.61828 1.15789 L
.66762 1.16015 L
.70551 1.16362 L
.72937 1.16806 L
.73758 1.17317 L
.72958 1.17861 L
.70591 1.18399 L
.66819 1.18897 L
.61899 1.19318 L
.56165 1.19636 L
.5001 1.19828 L
.43851 1.19881 L
.3811 1.19792 L
.33177 1.19566 L
.29388 1.19219 L
.27001 1.18775 L
.2618 1.18263 L
.2698 1.1772 L
.29347 1.17181 L
.33119 1.16684 L
.3804 1.16262 L
.43773 1.15944 L
.49929 1.15752 L
s
.5 g
.49991 1.18913 m
.4996 1.17333 L
.56118 1.1728 L
.5615 1.1886 L
.49991 1.18913 L
F
.5615 1.1886 m
.56118 1.1728 L
.6186 1.17369 L
.61891 1.18949 L
.5615 1.1886 L
F
.61891 1.18949 m
.6186 1.17369 L
.66793 1.17595 L
.66825 1.19175 L
.61891 1.18949 L
F
.66825 1.19175 m
.66793 1.17595 L
.70582 1.17942 L
.70613 1.19522 L
.66825 1.19175 L
F
.70613 1.19522 m
.70582 1.17942 L
.72968 1.18386 L
.73 1.19966 L
.70613 1.19522 L
F
.73 1.19966 m
.72968 1.18386 L
.73789 1.18897 L
.73821 1.20477 L
.73 1.19966 L
F
.73821 1.20477 m
.73789 1.18897 L
.72989 1.19441 L
.73021 1.21021 L
.73821 1.20477 L
F
.73021 1.21021 m
.72989 1.19441 L
.70623 1.1998 L
.70654 1.2156 L
.73021 1.21021 L
F
.70654 1.2156 m
.70623 1.1998 L
.6685 1.20477 L
.66882 1.22057 L
.70654 1.2156 L
F
.66882 1.22057 m
.6685 1.20477 L
.6193 1.20899 L
.61961 1.22479 L
.66882 1.22057 L
F
.61961 1.22479 m
.6193 1.20899 L
.56197 1.21216 L
.56228 1.22796 L
.61961 1.22479 L
F
.56228 1.22796 m
.56197 1.21216 L
.50041 1.21408 L
.50073 1.22988 L
.56228 1.22796 L
F
.50073 1.22988 m
.50041 1.21408 L
.43883 1.21461 L
.43914 1.23041 L
.50073 1.22988 L
F
.43914 1.23041 m
.43883 1.21461 L
.38141 1.21372 L
.38173 1.22952 L
.43914 1.23041 L
F
.38173 1.22952 m
.38141 1.21372 L
.33208 1.21146 L
.33239 1.22726 L
.38173 1.22952 L
F
.33239 1.22726 m
.33208 1.21146 L
.29419 1.20799 L
.29451 1.22379 L
.33239 1.22726 L
F
.29451 1.22379 m
.29419 1.20799 L
.27033 1.20355 L
.27064 1.21935 L
.29451 1.22379 L
F
.27064 1.21935 m
.27033 1.20355 L
.26212 1.19844 L
.26243 1.21424 L
.27064 1.21935 L
F
.26243 1.21424 m
.26212 1.19844 L
.27012 1.193 L
.27043 1.2088 L
.26243 1.21424 L
F
.27043 1.2088 m
.27012 1.193 L
.29379 1.18761 L
.2941 1.20341 L
.27043 1.2088 L
F
.2941 1.20341 m
.29379 1.18761 L
.33151 1.18264 L
.33182 1.19844 L
.2941 1.20341 L
F
.33182 1.19844 m
.33151 1.18264 L
.38071 1.17842 L
.38102 1.19422 L
.33182 1.19844 L
F
.38102 1.19422 m
.38071 1.17842 L
.43804 1.17524 L
.43836 1.19105 L
.38102 1.19422 L
F
.43836 1.19105 m
.43804 1.17524 L
.4996 1.17333 L
.49991 1.18913 L
.43836 1.19105 L
F
.4996 1.17333 m
.49929 1.15752 L
.56087 1.15699 L
.56118 1.1728 L
.4996 1.17333 L
F
.56118 1.1728 m
.56087 1.15699 L
.61828 1.15789 L
.6186 1.17369 L
.56118 1.1728 L
F
.6186 1.17369 m
.61828 1.15789 L
.66762 1.16015 L
.66793 1.17595 L
.6186 1.17369 L
F
.66793 1.17595 m
.66762 1.16015 L
.70551 1.16362 L
.70582 1.17942 L
.66793 1.17595 L
F
.70582 1.17942 m
.70551 1.16362 L
.72937 1.16806 L
.72968 1.18386 L
.70582 1.17942 L
F
.72968 1.18386 m
.72937 1.16806 L
.73758 1.17317 L
.73789 1.18897 L
.72968 1.18386 L
F
.73789 1.18897 m
.73758 1.17317 L
.72958 1.17861 L
.72989 1.19441 L
.73789 1.18897 L
F
.72989 1.19441 m
.72958 1.17861 L
.70591 1.18399 L
.70623 1.1998 L
.72989 1.19441 L
F
.70623 1.1998 m
.70591 1.18399 L
.66819 1.18897 L
.6685 1.20477 L
.70623 1.1998 L
F
.6685 1.20477 m
.66819 1.18897 L
.61899 1.19318 L
.6193 1.20899 L
.6685 1.20477 L
F
.6193 1.20899 m
.61899 1.19318 L
.56165 1.19636 L
.56197 1.21216 L
.6193 1.20899 L
F
.56197 1.21216 m
.56165 1.19636 L
.5001 1.19828 L
.50041 1.21408 L
.56197 1.21216 L
F
.50041 1.21408 m
.5001 1.19828 L
.43851 1.19881 L
.43883 1.21461 L
.50041 1.21408 L
F
.43883 1.21461 m
.43851 1.19881 L
.3811 1.19792 L
.38141 1.21372 L
.43883 1.21461 L
F
.38141 1.21372 m
.3811 1.19792 L
.33177 1.19566 L
.33208 1.21146 L
.38141 1.21372 L
F
.33208 1.21146 m
.33177 1.19566 L
.29388 1.19219 L
.29419 1.20799 L
.33208 1.21146 L
F
.29419 1.20799 m
.29388 1.19219 L
.27001 1.18775 L
.27033 1.20355 L
.29419 1.20799 L
F
.27033 1.20355 m
.27001 1.18775 L
.2618 1.18263 L
.26212 1.19844 L
.27033 1.20355 L
F
.26212 1.19844 m
.2618 1.18263 L
.2698 1.1772 L
.27012 1.193 L
.26212 1.19844 L
F
.27012 1.193 m
.2698 1.1772 L
.29347 1.17181 L
.29379 1.18761 L
.27012 1.193 L
F
.29379 1.18761 m
.29347 1.17181 L
.33119 1.16684 L
.33151 1.18264 L
.29379 1.18761 L
F
.33151 1.18264 m
.33119 1.16684 L
.3804 1.16262 L
.38071 1.17842 L
.33151 1.18264 L
F
.38071 1.17842 m
.3804 1.16262 L
.43773 1.15944 L
.43804 1.17524 L
.38071 1.17842 L
F
.43804 1.17524 m
.43773 1.15944 L
.49929 1.15752 L
.4996 1.17333 L
.43804 1.17524 L
F
.50032 1.36813 m
.5006 1.37246 L
.51425 1.37141 L
.50032 1.36813 L
.50032 1.36813 L
F
.5006 1.37246 m
.50089 1.37679 L
.52818 1.3747 L
.51425 1.37141 L
.5006 1.37246 L
F
.50089 1.37679 m
.50117 1.38112 L
.54211 1.37798 L
.52818 1.3747 L
.50089 1.37679 L
F
.50032 1.36813 m
.51425 1.37141 L
.52695 1.37014 L
.50032 1.36813 L
.50032 1.36813 L
F
.51425 1.37141 m
.52818 1.3747 L
.55357 1.37216 L
.52695 1.37014 L
.51425 1.37141 L
F
.52818 1.3747 m
.54211 1.37798 L
.5802 1.37417 L
.55357 1.37216 L
.52818 1.3747 L
F
.50032 1.36813 m
.52695 1.37014 L
.53783 1.36874 L
.50032 1.36813 L
.50032 1.36813 L
F
.52695 1.37014 m
.55357 1.37216 L
.57534 1.36934 L
.53783 1.36874 L
.52695 1.37014 L
F
.55357 1.37216 m
.5802 1.37417 L
.61285 1.36995 L
.57534 1.36934 L
.55357 1.37216 L
F
.50032 1.36813 m
.53783 1.36874 L
.54615 1.36729 L
.50032 1.36813 L
.50032 1.36813 L
F
.53783 1.36874 m
.57534 1.36934 L
.59199 1.36645 L
.54615 1.36729 L
.53783 1.36874 L
F
.57534 1.36934 m
.61285 1.36995 L
.63782 1.3656 L
.59199 1.36645 L
.57534 1.36934 L
F
.50032 1.36813 m
.54615 1.36729 L
.55136 1.3659 L
.50032 1.36813 L
.50032 1.36813 L
F
.54615 1.36729 m
.59199 1.36645 L
.60239 1.36366 L
.55136 1.3659 L
.54615 1.36729 L
F
.59199 1.36645 m
.63782 1.3656 L
.65343 1.36143 L
.60239 1.36366 L
.59199 1.36645 L
F
.50032 1.36813 m
.55136 1.3659 L
.55308 1.36466 L
.50032 1.36813 L
.50032 1.36813 L
F
.55136 1.3659 m
.60239 1.36366 L
.60584 1.36119 L
.55308 1.36466 L
.55136 1.3659 L
F
.60239 1.36366 m
.65343 1.36143 L
.6586 1.35771 L
.60584 1.36119 L
.60239 1.36366 L
F
.50032 1.36813 m
.55308 1.36466 L
.55121 1.36365 L
.50032 1.36813 L
.50032 1.36813 L
F
.55308 1.36466 m
.60584 1.36119 L
.6021 1.35918 L
.55121 1.36365 L
.55308 1.36466 L
F
.60584 1.36119 m
.6586 1.35771 L
.65299 1.35471 L
.6021 1.35918 L
.60584 1.36119 L
F
.50032 1.36813 m
.55121 1.36365 L
.54587 1.36296 L
.50032 1.36813 L
.50032 1.36813 L
F
.55121 1.36365 m
.6021 1.35918 L
.59142 1.35779 L
.54587 1.36296 L
.55121 1.36365 L
F
.6021 1.35918 m
.65299 1.35471 L
.63697 1.35262 L
.59142 1.35779 L
.6021 1.35918 L
F
.50032 1.36813 m
.54587 1.36296 L
.53743 1.36261 L
.50032 1.36813 L
.50032 1.36813 L
F
.54587 1.36296 m
.59142 1.35779 L
.57453 1.3571 L
.53743 1.36261 L
.54587 1.36296 L
F
.59142 1.35779 m
.63697 1.35262 L
.61164 1.35158 L
.57453 1.3571 L
.59142 1.35779 L
F
.50032 1.36813 m
.53743 1.36261 L
.52645 1.36264 L
.50032 1.36813 L
.50032 1.36813 L
F
.53743 1.36261 m
.57453 1.3571 L
.55259 1.35716 L
.52645 1.36264 L
.53743 1.36261 L
F
.57453 1.3571 m
.61164 1.35158 L
.57872 1.35167 L
.55259 1.35716 L
.57453 1.3571 L
F
.50032 1.36813 m
.52645 1.36264 L
.5137 1.36305 L
.50032 1.36813 L
.50032 1.36813 L
F
.52645 1.36264 m
.55259 1.35716 L
.52708 1.35797 L
.5137 1.36305 L
.52645 1.36264 L
F
.55259 1.35716 m
.57872 1.35167 L
.54046 1.35289 L
.52708 1.35797 L
.55259 1.35716 L
F
.50032 1.36813 m
.5137 1.36305 L
.50003 1.3638 L
.50032 1.36813 L
.50032 1.36813 L
F
.5137 1.36305 m
.52708 1.35797 L
.49975 1.35947 L
.50003 1.3638 L
.5137 1.36305 L
F
.52708 1.35797 m
.54046 1.35289 L
.49947 1.35514 L
.49975 1.35947 L
.52708 1.35797 L
F
.50032 1.36813 m
.50003 1.3638 L
.48639 1.36484 L
.50032 1.36813 L
.50032 1.36813 L
F
.50003 1.3638 m
.49975 1.35947 L
.47246 1.36156 L
.48639 1.36484 L
.50003 1.3638 L
F
.49975 1.35947 m
.49947 1.35514 L
.45853 1.35828 L
.47246 1.36156 L
.49975 1.35947 L
F
.50032 1.36813 m
.48639 1.36484 L
.47369 1.36611 L
.50032 1.36813 L
.50032 1.36813 L
F
.48639 1.36484 m
.47246 1.36156 L
.44707 1.3641 L
.47369 1.36611 L
.48639 1.36484 L
F
.47246 1.36156 m
.45853 1.35828 L
.42044 1.36209 L
.44707 1.3641 L
.47246 1.36156 L
F
.50032 1.36813 m
.47369 1.36611 L
.46281 1.36752 L
.50032 1.36813 L
.50032 1.36813 L
F
.47369 1.36611 m
.44707 1.3641 L
.4253 1.36691 L
.46281 1.36752 L
.47369 1.36611 L
F
.44707 1.3641 m
.42044 1.36209 L
.38779 1.36631 L
.4253 1.36691 L
.44707 1.3641 L
F
.50032 1.36813 m
.46281 1.36752 L
.45449 1.36897 L
.50032 1.36813 L
.50032 1.36813 L
F
.46281 1.36752 m
.4253 1.36691 L
.40865 1.36981 L
.45449 1.36897 L
.46281 1.36752 L
F
.4253 1.36691 m
.38779 1.36631 L
.36282 1.37065 L
.40865 1.36981 L
.4253 1.36691 L
F
.50032 1.36813 m
.45449 1.36897 L
.44928 1.37036 L
.50032 1.36813 L
.50032 1.36813 L
F
.45449 1.36897 m
.40865 1.36981 L
.39825 1.37259 L
.44928 1.37036 L
.45449 1.36897 L
F
.40865 1.36981 m
.36282 1.37065 L
.34721 1.37483 L
.39825 1.37259 L
.40865 1.36981 L
F
.50032 1.36813 m
.44928 1.37036 L
.44756 1.3716 L
.50032 1.36813 L
.50032 1.36813 L
F
.44928 1.37036 m
.39825 1.37259 L
.3948 1.37507 L
.44756 1.3716 L
.44928 1.37036 L
F
.39825 1.37259 m
.34721 1.37483 L
.34204 1.37854 L
.3948 1.37507 L
.39825 1.37259 L
F
.50032 1.36813 m
.44756 1.3716 L
.44943 1.3726 L
.50032 1.36813 L
.50032 1.36813 L
F
.44756 1.3716 m
.3948 1.37507 L
.39854 1.37708 L
.44943 1.3726 L
.44756 1.3716 L
F
.3948 1.37507 m
.34204 1.37854 L
.34765 1.38155 L
.39854 1.37708 L
.3948 1.37507 L
F
.50032 1.36813 m
.44943 1.3726 L
.45477 1.3733 L
.50032 1.36813 L
.50032 1.36813 L
F
.44943 1.3726 m
.39854 1.37708 L
.40922 1.37847 L
.45477 1.3733 L
.44943 1.3726 L
F
.39854 1.37708 m
.34765 1.38155 L
.36367 1.38364 L
.40922 1.37847 L
.39854 1.37708 L
F
.50032 1.36813 m
.45477 1.3733 L
.46321 1.37364 L
.50032 1.36813 L
.50032 1.36813 L
F
.45477 1.3733 m
.40922 1.37847 L
.42611 1.37916 L
.46321 1.37364 L
.45477 1.3733 L
F
.40922 1.37847 m
.36367 1.38364 L
.389 1.38468 L
.42611 1.37916 L
.40922 1.37847 L
F
.50032 1.36813 m
.46321 1.37364 L
.47419 1.37361 L
.50032 1.36813 L
.50032 1.36813 L
F
.46321 1.37364 m
.42611 1.37916 L
.44805 1.3791 L
.47419 1.37361 L
.46321 1.37364 L
F
.42611 1.37916 m
.389 1.38468 L
.42192 1.38458 L
.44805 1.3791 L
.42611 1.37916 L
F
.50032 1.36813 m
.47419 1.37361 L
.48694 1.37321 L
.50032 1.36813 L
.50032 1.36813 L
F
.47419 1.37361 m
.44805 1.3791 L
.47356 1.37829 L
.48694 1.37321 L
.47419 1.37361 L
F
.44805 1.3791 m
.42192 1.38458 L
.46018 1.38337 L
.47356 1.37829 L
.44805 1.3791 L
F
.50032 1.36813 m
.48694 1.37321 L
.5006 1.37246 L
.50032 1.36813 L
.50032 1.36813 L
F
.48694 1.37321 m
.47356 1.37829 L
.50089 1.37679 L
.5006 1.37246 L
.48694 1.37321 L
F
.47356 1.37829 m
.46018 1.38337 L
.50117 1.38112 L
.50089 1.37679 L
.47356 1.37829 L
F
0 g
.50117 1.38112 m
.54211 1.37798 L
.5802 1.37417 L
.61285 1.36995 L
.63782 1.3656 L
.65343 1.36143 L
.6586 1.35771 L
.65299 1.35471 L
.63697 1.35262 L
.61164 1.35158 L
.57872 1.35167 L
.54046 1.35289 L
.49947 1.35514 L
.45853 1.35828 L
.42044 1.36209 L
.38779 1.36631 L
.36282 1.37065 L
.34721 1.37483 L
.34204 1.37854 L
.34765 1.38155 L
.36367 1.38364 L
.389 1.38468 L
.42192 1.38458 L
.46018 1.38337 L
.50117 1.38112 L
s
.5 g
.49928 1.35235 m
.49957 1.35668 L
.51321 1.35564 L
.49928 1.35235 L
.49928 1.35235 L
F
.49957 1.35668 m
.49985 1.36101 L
.52714 1.35892 L
.51321 1.35564 L
.49957 1.35668 L
F
.49985 1.36101 m
.50014 1.36534 L
.54107 1.3622 L
.52714 1.35892 L
.49985 1.36101 L
F
.49928 1.35235 m
.51321 1.35564 L
.52591 1.35437 L
.49928 1.35235 L
.49928 1.35235 L
F
.51321 1.35564 m
.52714 1.35892 L
.55254 1.35638 L
.52591 1.35437 L
.51321 1.35564 L
F
.52714 1.35892 m
.54107 1.3622 L
.57916 1.3584 L
.55254 1.35638 L
.52714 1.35892 L
F
.49928 1.35235 m
.52591 1.35437 L
.53679 1.35296 L
.49928 1.35235 L
.49928 1.35235 L
F
.52591 1.35437 m
.55254 1.35638 L
.5743 1.35357 L
.53679 1.35296 L
.52591 1.35437 L
F
.55254 1.35638 m
.57916 1.3584 L
.61181 1.35417 L
.5743 1.35357 L
.55254 1.35638 L
F
.49928 1.35235 m
.53679 1.35296 L
.54512 1.35151 L
.49928 1.35235 L
.49928 1.35235 L
F
.53679 1.35296 m
.5743 1.35357 L
.59095 1.35067 L
.54512 1.35151 L
.53679 1.35296 L
F
.5743 1.35357 m
.61181 1.35417 L
.63678 1.34983 L
.59095 1.35067 L
.5743 1.35357 L
F
.49928 1.35235 m
.54512 1.35151 L
.55032 1.35012 L
.49928 1.35235 L
.49928 1.35235 L
F
.54512 1.35151 m
.59095 1.35067 L
.60135 1.34789 L
.55032 1.35012 L
.54512 1.35151 L
F
.59095 1.35067 m
.63678 1.34983 L
.65239 1.34566 L
.60135 1.34789 L
.59095 1.35067 L
F
.49928 1.35235 m
.55032 1.35012 L
.55204 1.34888 L
.49928 1.35235 L
.49928 1.35235 L
F
.55032 1.35012 m
.60135 1.34789 L
.6048 1.34541 L
.55204 1.34888 L
.55032 1.35012 L
F
.60135 1.34789 m
.65239 1.34566 L
.65756 1.34194 L
.6048 1.34541 L
.60135 1.34789 L
F
.49928 1.35235 m
.55204 1.34888 L
.55017 1.34788 L
.49928 1.35235 L
.49928 1.35235 L
F
.55204 1.34888 m
.6048 1.34541 L
.60106 1.34341 L
.55017 1.34788 L
.55204 1.34888 L
F
.6048 1.34541 m
.65756 1.34194 L
.65195 1.33893 L
.60106 1.34341 L
.6048 1.34541 L
F
.49928 1.35235 m
.55017 1.34788 L
.54483 1.34718 L
.49928 1.35235 L
.49928 1.35235 L
F
.55017 1.34788 m
.60106 1.34341 L
.59038 1.34201 L
.54483 1.34718 L
.55017 1.34788 L
F
.60106 1.34341 m
.65195 1.33893 L
.63593 1.33684 L
.59038 1.34201 L
.60106 1.34341 L
F
.49928 1.35235 m
.54483 1.34718 L
.53639 1.34684 L
.49928 1.35235 L
.49928 1.35235 L
F
.54483 1.34718 m
.59038 1.34201 L
.57349 1.34132 L
.53639 1.34684 L
.54483 1.34718 L
F
.59038 1.34201 m
.63593 1.33684 L
.6106 1.33581 L
.57349 1.34132 L
.59038 1.34201 L
F
.49928 1.35235 m
.53639 1.34684 L
.52542 1.34687 L
.49928 1.35235 L
.49928 1.35235 L
F
.53639 1.34684 m
.57349 1.34132 L
.55155 1.34138 L
.52542 1.34687 L
.53639 1.34684 L
F
.57349 1.34132 m
.6106 1.33581 L
.57768 1.3359 L
.55155 1.34138 L
.57349 1.34132 L
F
.49928 1.35235 m
.52542 1.34687 L
.51266 1.34727 L
.49928 1.35235 L
.49928 1.35235 L
F
.52542 1.34687 m
.55155 1.34138 L
.52604 1.34219 L
.51266 1.34727 L
.52542 1.34687 L
F
.55155 1.34138 m
.57768 1.3359 L
.53942 1.33711 L
.52604 1.34219 L
.55155 1.34138 L
F
.49928 1.35235 m
.51266 1.34727 L
.499 1.34802 L
.49928 1.35235 L
.49928 1.35235 L
F
.51266 1.34727 m
.52604 1.34219 L
.49871 1.34369 L
.499 1.34802 L
.51266 1.34727 L
F
.52604 1.34219 m
.53942 1.33711 L
.49843 1.33936 L
.49871 1.34369 L
.52604 1.34219 L
F
.49928 1.35235 m
.499 1.34802 L
.48535 1.34907 L
.49928 1.35235 L
.49928 1.35235 L
F
.499 1.34802 m
.49871 1.34369 L
.47142 1.34579 L
.48535 1.34907 L
.499 1.34802 L
F
.49871 1.34369 m
.49843 1.33936 L
.45749 1.3425 L
.47142 1.34579 L
.49871 1.34369 L
F
.49928 1.35235 m
.48535 1.34907 L
.47266 1.35034 L
.49928 1.35235 L
.49928 1.35235 L
F
.48535 1.34907 m
.47142 1.34579 L
.44603 1.34833 L
.47266 1.35034 L
.48535 1.34907 L
F
.47142 1.34579 m
.45749 1.3425 L
.4194 1.34631 L
.44603 1.34833 L
.47142 1.34579 L
F
.49928 1.35235 m
.47266 1.35034 L
.46177 1.35175 L
.49928 1.35235 L
.49928 1.35235 L
F
.47266 1.35034 m
.44603 1.34833 L
.42426 1.35114 L
.46177 1.35175 L
.47266 1.35034 L
F
.44603 1.34833 m
.4194 1.34631 L
.38676 1.35053 L
.42426 1.35114 L
.44603 1.34833 L
F
.49928 1.35235 m
.46177 1.35175 L
.45345 1.35319 L
.49928 1.35235 L
.49928 1.35235 L
F
.46177 1.35175 m
.42426 1.35114 L
.40761 1.35404 L
.45345 1.35319 L
.46177 1.35175 L
F
.42426 1.35114 m
.38676 1.35053 L
.36178 1.35488 L
.40761 1.35404 L
.42426 1.35114 L
F
.49928 1.35235 m
.45345 1.35319 L
.44825 1.35459 L
.49928 1.35235 L
.49928 1.35235 L
F
.45345 1.35319 m
.40761 1.35404 L
.39721 1.35682 L
.44825 1.35459 L
.45345 1.35319 L
F
.40761 1.35404 m
.36178 1.35488 L
.34617 1.35905 L
.39721 1.35682 L
.40761 1.35404 L
F
.49928 1.35235 m
.44825 1.35459 L
.44652 1.35582 L
.49928 1.35235 L
.49928 1.35235 L
F
.44825 1.35459 m
.39721 1.35682 L
.39376 1.3593 L
.44652 1.35582 L
.44825 1.35459 L
F
.39721 1.35682 m
.34617 1.35905 L
.341 1.36277 L
.39376 1.3593 L
.39721 1.35682 L
F
.49928 1.35235 m
.44652 1.35582 L
.44839 1.35683 L
.49928 1.35235 L
.49928 1.35235 L
F
.44652 1.35582 m
.39376 1.3593 L
.3975 1.3613 L
.44839 1.35683 L
.44652 1.35582 L
F
.39376 1.3593 m
.341 1.36277 L
.34662 1.36577 L
.3975 1.3613 L
.39376 1.3593 L
F
.49928 1.35235 m
.44839 1.35683 L
.45373 1.35752 L
.49928 1.35235 L
.49928 1.35235 L
F
.44839 1.35683 m
.3975 1.3613 L
.40818 1.3627 L
.45373 1.35752 L
.44839 1.35683 L
F
.3975 1.3613 m
.34662 1.36577 L
.36263 1.36787 L
.40818 1.3627 L
.3975 1.3613 L
F
.49928 1.35235 m
.45373 1.35752 L
.46218 1.35787 L
.49928 1.35235 L
.49928 1.35235 L
F
.45373 1.35752 m
.40818 1.3627 L
.42507 1.36339 L
.46218 1.35787 L
.45373 1.35752 L
F
.40818 1.3627 m
.36263 1.36787 L
.38796 1.3689 L
.42507 1.36339 L
.40818 1.3627 L
F
.49928 1.35235 m
.46218 1.35787 L
.47315 1.35784 L
.49928 1.35235 L
.49928 1.35235 L
F
.46218 1.35787 m
.42507 1.36339 L
.44701 1.36332 L
.47315 1.35784 L
.46218 1.35787 L
F
.42507 1.36339 m
.38796 1.3689 L
.42088 1.36881 L
.44701 1.36332 L
.42507 1.36339 L
F
.49928 1.35235 m
.47315 1.35784 L
.4859 1.35743 L
.49928 1.35235 L
.49928 1.35235 L
F
.47315 1.35784 m
.44701 1.36332 L
.47252 1.36251 L
.4859 1.35743 L
.47315 1.35784 L
F
.44701 1.36332 m
.42088 1.36881 L
.45914 1.36759 L
.47252 1.36251 L
.44701 1.36332 L
F
.49928 1.35235 m
.4859 1.35743 L
.49957 1.35668 L
.49928 1.35235 L
.49928 1.35235 L
F
.4859 1.35743 m
.47252 1.36251 L
.49985 1.36101 L
.49957 1.35668 L
.4859 1.35743 L
F
.47252 1.36251 m
.45914 1.36759 L
.50014 1.36534 L
.49985 1.36101 L
.47252 1.36251 L
F
0 g
.50014 1.36534 m
.54107 1.3622 L
.57916 1.3584 L
.61181 1.35417 L
.63678 1.34983 L
.65239 1.34566 L
.65756 1.34194 L
.65195 1.33893 L
.63593 1.33684 L
.6106 1.33581 L
.57768 1.3359 L
.53942 1.33711 L
.49843 1.33936 L
.45749 1.3425 L
.4194 1.34631 L
.38676 1.35053 L
.36178 1.35488 L
.34617 1.35905 L
.341 1.36277 L
.34662 1.36577 L
.36263 1.36787 L
.38796 1.3689 L
.42088 1.36881 L
.45914 1.36759 L
.50014 1.36534 L
s
.5 g
.49824 1.33658 m
.49853 1.34089 L
.51211 1.33985 L
.49824 1.33658 L
.49824 1.33658 L
F
.49853 1.34089 m
.49881 1.34519 L
.52597 1.34311 L
.51211 1.33985 L
.49853 1.34089 L
F
.49881 1.34519 m
.49909 1.3495 L
.53983 1.34638 L
.52597 1.34311 L
.49881 1.34519 L
F
.49824 1.33658 m
.51211 1.33985 L
.52474 1.33858 L
.49824 1.33658 L
.49824 1.33658 L
F
.51211 1.33985 m
.52597 1.34311 L
.55123 1.34059 L
.52474 1.33858 L
.51211 1.33985 L
F
.52597 1.34311 m
.53983 1.34638 L
.57773 1.34259 L
.55123 1.34059 L
.52597 1.34311 L
F
.49824 1.33658 m
.52474 1.33858 L
.53557 1.33718 L
.49824 1.33658 L
.49824 1.33658 L
F
.52474 1.33858 m
.55123 1.34059 L
.57289 1.33779 L
.53557 1.33718 L
.52474 1.33858 L
F
.55123 1.34059 m
.57773 1.34259 L
.61021 1.33839 L
.57289 1.33779 L
.55123 1.34059 L
F
.49824 1.33658 m
.53557 1.33718 L
.54385 1.33574 L
.49824 1.33658 L
.49824 1.33658 L
F
.53557 1.33718 m
.57289 1.33779 L
.58945 1.3349 L
.54385 1.33574 L
.53557 1.33718 L
F
.57289 1.33779 m
.61021 1.33839 L
.63506 1.33407 L
.58945 1.3349 L
.57289 1.33779 L
F
.49824 1.33658 m
.54385 1.33574 L
.54903 1.33436 L
.49824 1.33658 L
.49824 1.33658 L
F
.54385 1.33574 m
.58945 1.3349 L
.59981 1.33214 L
.54903 1.33436 L
.54385 1.33574 L
F
.58945 1.3349 m
.63506 1.33407 L
.65059 1.32992 L
.59981 1.33214 L
.58945 1.3349 L
F
.49824 1.33658 m
.54903 1.33436 L
.55074 1.33312 L
.49824 1.33658 L
.49824 1.33658 L
F
.54903 1.33436 m
.59981 1.33214 L
.60324 1.32967 L
.55074 1.33312 L
.54903 1.33436 L
F
.59981 1.33214 m
.65059 1.32992 L
.65573 1.32622 L
.60324 1.32967 L
.59981 1.33214 L
F
.49824 1.33658 m
.55074 1.33312 L
.54888 1.33213 L
.49824 1.33658 L
.49824 1.33658 L
F
.55074 1.33312 m
.60324 1.32967 L
.59951 1.32768 L
.54888 1.33213 L
.55074 1.33312 L
F
.60324 1.32967 m
.65573 1.32622 L
.65015 1.32323 L
.59951 1.32768 L
.60324 1.32967 L
F
.49824 1.33658 m
.54888 1.33213 L
.54357 1.33143 L
.49824 1.33658 L
.49824 1.33658 L
F
.54888 1.33213 m
.59951 1.32768 L
.58889 1.32629 L
.54357 1.33143 L
.54888 1.33213 L
F
.59951 1.32768 m
.65015 1.32323 L
.63421 1.32114 L
.58889 1.32629 L
.59951 1.32768 L
F
.49824 1.33658 m
.54357 1.33143 L
.53516 1.33109 L
.49824 1.33658 L
.49824 1.33658 L
F
.54357 1.33143 m
.58889 1.32629 L
.57208 1.3256 L
.53516 1.33109 L
.54357 1.33143 L
F
.58889 1.32629 m
.63421 1.32114 L
.60901 1.32011 L
.57208 1.3256 L
.58889 1.32629 L
F
.49824 1.33658 m
.53516 1.33109 L
.52425 1.33112 L
.49824 1.33658 L
.49824 1.33658 L
F
.53516 1.33109 m
.57208 1.3256 L
.55025 1.32566 L
.52425 1.33112 L
.53516 1.33109 L
F
.57208 1.3256 m
.60901 1.32011 L
.57625 1.32021 L
.55025 1.32566 L
.57208 1.3256 L
F
.49824 1.33658 m
.52425 1.33112 L
.51156 1.33152 L
.49824 1.33658 L
.49824 1.33658 L
F
.52425 1.33112 m
.55025 1.32566 L
.52487 1.32647 L
.51156 1.33152 L
.52425 1.33112 L
F
.55025 1.32566 m
.57625 1.32021 L
.53818 1.32141 L
.52487 1.32647 L
.55025 1.32566 L
F
.49824 1.33658 m
.51156 1.33152 L
.49796 1.33227 L
.49824 1.33658 L
.49824 1.33658 L
F
.51156 1.33152 m
.52487 1.32647 L
.49768 1.32796 L
.49796 1.33227 L
.51156 1.33152 L
F
.52487 1.32647 m
.53818 1.32141 L
.49739 1.32366 L
.49768 1.32796 L
.52487 1.32647 L
F
.49824 1.33658 m
.49796 1.33227 L
.48438 1.33331 L
.49824 1.33658 L
.49824 1.33658 L
F
.49796 1.33227 m
.49768 1.32796 L
.47052 1.33004 L
.48438 1.33331 L
.49796 1.33227 L
F
.49768 1.32796 m
.49739 1.32366 L
.45666 1.32678 L
.47052 1.33004 L
.49768 1.32796 L
F
.49824 1.33658 m
.48438 1.33331 L
.47175 1.33457 L
.49824 1.33658 L
.49824 1.33658 L
F
.48438 1.33331 m
.47052 1.33004 L
.44526 1.33257 L
.47175 1.33457 L
.48438 1.33331 L
F
.47052 1.33004 m
.45666 1.32678 L
.41876 1.33057 L
.44526 1.33257 L
.47052 1.33004 L
F
.49824 1.33658 m
.47175 1.33457 L
.46092 1.33597 L
.49824 1.33658 L
.49824 1.33658 L
F
.47175 1.33457 m
.44526 1.33257 L
.4236 1.33537 L
.46092 1.33597 L
.47175 1.33457 L
F
.44526 1.33257 m
.41876 1.33057 L
.38628 1.33477 L
.4236 1.33537 L
.44526 1.33257 L
F
.49824 1.33658 m
.46092 1.33597 L
.45264 1.33742 L
.49824 1.33658 L
.49824 1.33658 L
F
.46092 1.33597 m
.4236 1.33537 L
.40703 1.33825 L
.45264 1.33742 L
.46092 1.33597 L
F
.4236 1.33537 m
.38628 1.33477 L
.36143 1.33909 L
.40703 1.33825 L
.4236 1.33537 L
F
.49824 1.33658 m
.45264 1.33742 L
.44746 1.3388 L
.49824 1.33658 L
.49824 1.33658 L
F
.45264 1.33742 m
.40703 1.33825 L
.39668 1.34102 L
.44746 1.3388 L
.45264 1.33742 L
F
.40703 1.33825 m
.36143 1.33909 L
.3459 1.34324 L
.39668 1.34102 L
.40703 1.33825 L
F
.49824 1.33658 m
.44746 1.3388 L
.44575 1.34003 L
.49824 1.33658 L
.49824 1.33658 L
F
.44746 1.3388 m
.39668 1.34102 L
.39325 1.34349 L
.44575 1.34003 L
.44746 1.3388 L
F
.39668 1.34102 m
.3459 1.34324 L
.34075 1.34694 L
.39325 1.34349 L
.39668 1.34102 L
F
.49824 1.33658 m
.44575 1.34003 L
.44761 1.34103 L
.49824 1.33658 L
.49824 1.33658 L
F
.44575 1.34003 m
.39325 1.34349 L
.39698 1.34548 L
.44761 1.34103 L
.44575 1.34003 L
F
.39325 1.34349 m
.34075 1.34694 L
.34634 1.34993 L
.39698 1.34548 L
.39325 1.34349 L
F
.49824 1.33658 m
.44761 1.34103 L
.45292 1.34172 L
.49824 1.33658 L
.49824 1.33658 L
F
.44761 1.34103 m
.39698 1.34548 L
.4076 1.34687 L
.45292 1.34172 L
.44761 1.34103 L
F
.39698 1.34548 m
.34634 1.34993 L
.36228 1.35201 L
.4076 1.34687 L
.39698 1.34548 L
F
.49824 1.33658 m
.45292 1.34172 L
.46132 1.34207 L
.49824 1.33658 L
.49824 1.33658 L
F
.45292 1.34172 m
.4076 1.34687 L
.4244 1.34756 L
.46132 1.34207 L
.45292 1.34172 L
F
.4076 1.34687 m
.36228 1.35201 L
.38748 1.35304 L
.4244 1.34756 L
.4076 1.34687 L
F
.49824 1.33658 m
.46132 1.34207 L
.47224 1.34204 L
.49824 1.33658 L
.49824 1.33658 L
F
.46132 1.34207 m
.4244 1.34756 L
.44624 1.34749 L
.47224 1.34204 L
.46132 1.34207 L
F
.4244 1.34756 m
.38748 1.35304 L
.42024 1.35295 L
.44624 1.34749 L
.4244 1.34756 L
F
.49824 1.33658 m
.47224 1.34204 L
.48493 1.34163 L
.49824 1.33658 L
.49824 1.33658 L
F
.47224 1.34204 m
.44624 1.34749 L
.47162 1.34669 L
.48493 1.34163 L
.47224 1.34204 L
F
.44624 1.34749 m
.42024 1.35295 L
.4583 1.35174 L
.47162 1.34669 L
.44624 1.34749 L
F
.49824 1.33658 m
.48493 1.34163 L
.49853 1.34089 L
.49824 1.33658 L
.49824 1.33658 L
F
.48493 1.34163 m
.47162 1.34669 L
.49881 1.34519 L
.49853 1.34089 L
.48493 1.34163 L
F
.47162 1.34669 m
.4583 1.35174 L
.49909 1.3495 L
.49881 1.34519 L
.47162 1.34669 L
F
0 g
.4991 1.34957 m
.54004 1.34643 L
.57812 1.34262 L
.61077 1.3384 L
.63575 1.33405 L
.65135 1.32988 L
.65653 1.32617 L
.65091 1.32316 L
.63489 1.32107 L
.60956 1.32003 L
.57664 1.32012 L
.53838 1.32134 L
.49739 1.32359 L
.45645 1.32673 L
.41836 1.33054 L
.38572 1.33476 L
.36074 1.3391 L
.34513 1.34328 L
.33996 1.34699 L
.34558 1.35 L
.3616 1.35209 L
.38693 1.35313 L
.41984 1.35303 L
.4581 1.35182 L
.4991 1.34957 L
s
.5 g
.50117 1.38112 m
.50014 1.36534 L
.54107 1.3622 L
.54211 1.37798 L
.50117 1.38112 L
F
.54211 1.37798 m
.54107 1.3622 L
.57916 1.3584 L
.5802 1.37417 L
.54211 1.37798 L
F
.5802 1.37417 m
.57916 1.3584 L
.61181 1.35417 L
.61285 1.36995 L
.5802 1.37417 L
F
.61285 1.36995 m
.61181 1.35417 L
.63678 1.34983 L
.63782 1.3656 L
.61285 1.36995 L
F
.63782 1.3656 m
.63678 1.34983 L
.65239 1.34566 L
.65343 1.36143 L
.63782 1.3656 L
F
.65343 1.36143 m
.65239 1.34566 L
.65756 1.34194 L
.6586 1.35771 L
.65343 1.36143 L
F
.6586 1.35771 m
.65756 1.34194 L
.65195 1.33893 L
.65299 1.35471 L
.6586 1.35771 L
F
.65299 1.35471 m
.65195 1.33893 L
.63593 1.33684 L
.63697 1.35262 L
.65299 1.35471 L
F
.63697 1.35262 m
.63593 1.33684 L
.6106 1.33581 L
.61164 1.35158 L
.63697 1.35262 L
F
.61164 1.35158 m
.6106 1.33581 L
.57768 1.3359 L
.57872 1.35167 L
.61164 1.35158 L
F
.57872 1.35167 m
.57768 1.3359 L
.53942 1.33711 L
.54046 1.35289 L
.57872 1.35167 L
F
.54046 1.35289 m
.53942 1.33711 L
.49843 1.33936 L
.49947 1.35514 L
.54046 1.35289 L
F
.49947 1.35514 m
.49843 1.33936 L
.45749 1.3425 L
.45853 1.35828 L
.49947 1.35514 L
F
.45853 1.35828 m
.45749 1.3425 L
.4194 1.34631 L
.42044 1.36209 L
.45853 1.35828 L
F
.42044 1.36209 m
.4194 1.34631 L
.38676 1.35053 L
.38779 1.36631 L
.42044 1.36209 L
F
.38779 1.36631 m
.38676 1.35053 L
.36178 1.35488 L
.36282 1.37065 L
.38779 1.36631 L
F
.36282 1.37065 m
.36178 1.35488 L
.34617 1.35905 L
.34721 1.37483 L
.36282 1.37065 L
F
.34721 1.37483 m
.34617 1.35905 L
.341 1.36277 L
.34204 1.37854 L
.34721 1.37483 L
F
.34204 1.37854 m
.341 1.36277 L
.34662 1.36577 L
.34765 1.38155 L
.34204 1.37854 L
F
.34765 1.38155 m
.34662 1.36577 L
.36263 1.36787 L
.36367 1.38364 L
.34765 1.38155 L
F
.36367 1.38364 m
.36263 1.36787 L
.38796 1.3689 L
.389 1.38468 L
.36367 1.38364 L
F
.389 1.38468 m
.38796 1.3689 L
.42088 1.36881 L
.42192 1.38458 L
.389 1.38468 L
F
.42192 1.38458 m
.42088 1.36881 L
.45914 1.36759 L
.46018 1.38337 L
.42192 1.38458 L
F
.46018 1.38337 m
.45914 1.36759 L
.50014 1.36534 L
.50117 1.38112 L
.46018 1.38337 L
F
.50014 1.36534 m
.4991 1.34957 L
.54004 1.34643 L
.54107 1.3622 L
.50014 1.36534 L
F
.54107 1.3622 m
.54004 1.34643 L
.57812 1.34262 L
.57916 1.3584 L
.54107 1.3622 L
F
.57916 1.3584 m
.57812 1.34262 L
.61077 1.3384 L
.61181 1.35417 L
.57916 1.3584 L
F
.61181 1.35417 m
.61077 1.3384 L
.63575 1.33405 L
.63678 1.34983 L
.61181 1.35417 L
F
.63678 1.34983 m
.63575 1.33405 L
.65135 1.32988 L
.65239 1.34566 L
.63678 1.34983 L
F
.65239 1.34566 m
.65135 1.32988 L
.65653 1.32617 L
.65756 1.34194 L
.65239 1.34566 L
F
.65756 1.34194 m
.65653 1.32617 L
.65091 1.32316 L
.65195 1.33893 L
.65756 1.34194 L
F
.65195 1.33893 m
.65091 1.32316 L
.63489 1.32107 L
.63593 1.33684 L
.65195 1.33893 L
F
.63593 1.33684 m
.63489 1.32107 L
.60956 1.32003 L
.6106 1.33581 L
.63593 1.33684 L
F
.6106 1.33581 m
.60956 1.32003 L
.57664 1.32012 L
.57768 1.3359 L
.6106 1.33581 L
F
.57768 1.3359 m
.57664 1.32012 L
.53838 1.32134 L
.53942 1.33711 L
.57768 1.3359 L
F
.53942 1.33711 m
.53838 1.32134 L
.49739 1.32359 L
.49843 1.33936 L
.53942 1.33711 L
F
.49843 1.33936 m
.49739 1.32359 L
.45645 1.32673 L
.45749 1.3425 L
.49843 1.33936 L
F
.45749 1.3425 m
.45645 1.32673 L
.41836 1.33054 L
.4194 1.34631 L
.45749 1.3425 L
F
.4194 1.34631 m
.41836 1.33054 L
.38572 1.33476 L
.38676 1.35053 L
.4194 1.34631 L
F
.38676 1.35053 m
.38572 1.33476 L
.36074 1.3391 L
.36178 1.35488 L
.38676 1.35053 L
F
.36178 1.35488 m
.36074 1.3391 L
.34513 1.34328 L
.34617 1.35905 L
.36178 1.35488 L
F
.34617 1.35905 m
.34513 1.34328 L
.33996 1.34699 L
.341 1.36277 L
.34617 1.35905 L
F
.341 1.36277 m
.33996 1.34699 L
.34558 1.35 L
.34662 1.36577 L
.341 1.36277 L
F
.34662 1.36577 m
.34558 1.35 L
.3616 1.35209 L
.36263 1.36787 L
.34662 1.36577 L
F
.36263 1.36787 m
.3616 1.35209 L
.38693 1.35313 L
.38796 1.3689 L
.36263 1.36787 L
F
.38796 1.3689 m
.38693 1.35313 L
.41984 1.35303 L
.42088 1.36881 L
.38796 1.3689 L
F
.42088 1.36881 m
.41984 1.35303 L
.4581 1.35182 L
.45914 1.36759 L
.42088 1.36881 L
F
.45914 1.36759 m
.4581 1.35182 L
.4991 1.34957 L
.50014 1.36534 L
.45914 1.36759 L
F
.50032 1.52675 m
.50042 1.52814 L
.50724 1.52759 L
.50032 1.52675 L
.50032 1.52675 L
F
.50042 1.52814 m
.50053 1.52953 L
.51417 1.52842 L
.50724 1.52759 L
.50042 1.52814 L
F
.50053 1.52953 m
.50063 1.53093 L
.52109 1.52926 L
.51417 1.52842 L
.50053 1.52953 L
F
.50032 1.52675 m
.50724 1.52759 L
.51359 1.52697 L
.50032 1.52675 L
.50032 1.52675 L
F
.50724 1.52759 m
.51417 1.52842 L
.52686 1.5272 L
.51359 1.52697 L
.50724 1.52759 L
F
.51417 1.52842 m
.52109 1.52926 L
.54014 1.52742 L
.52686 1.5272 L
.51417 1.52842 L
F
.50032 1.52675 m
.51359 1.52697 L
.51904 1.52635 L
.50032 1.52675 L
.50032 1.52675 L
F
.51359 1.52697 m
.52686 1.5272 L
.53775 1.52594 L
.51904 1.52635 L
.51359 1.52697 L
F
.52686 1.5272 m
.54014 1.52742 L
.55647 1.52554 L
.53775 1.52594 L
.52686 1.5272 L
F
.50032 1.52675 m
.51904 1.52635 L
.5232 1.52575 L
.50032 1.52675 L
.50032 1.52675 L
F
.51904 1.52635 m
.53775 1.52594 L
.54609 1.52474 L
.5232 1.52575 L
.51904 1.52635 L
F
.53775 1.52594 m
.55647 1.52554 L
.56897 1.52374 L
.54609 1.52474 L
.53775 1.52594 L
F
.50032 1.52675 m
.5232 1.52575 L
.52581 1.52521 L
.50032 1.52675 L
.50032 1.52675 L
F
.5232 1.52575 m
.54609 1.52474 L
.55131 1.52368 L
.52581 1.52521 L
.5232 1.52575 L
F
.54609 1.52474 m
.56897 1.52374 L
.5768 1.52214 L
.55131 1.52368 L
.54609 1.52474 L
F
.50032 1.52675 m
.52581 1.52521 L
.52668 1.52479 L
.50032 1.52675 L
.50032 1.52675 L
F
.52581 1.52521 m
.55131 1.52368 L
.55305 1.52282 L
.52668 1.52479 L
.52581 1.52521 L
F
.55131 1.52368 m
.5768 1.52214 L
.57941 1.52086 L
.55305 1.52282 L
.55131 1.52368 L
F
.50032 1.52675 m
.52668 1.52479 L
.52576 1.52449 L
.50032 1.52675 L
.50032 1.52675 L
F
.52668 1.52479 m
.55305 1.52282 L
.5512 1.52224 L
.52576 1.52449 L
.52668 1.52479 L
F
.55305 1.52282 m
.57941 1.52086 L
.57664 1.51998 L
.5512 1.52224 L
.55305 1.52282 L
F
.50032 1.52675 m
.52576 1.52449 L
.5231 1.52436 L
.50032 1.52675 L
.50032 1.52675 L
F
.52576 1.52449 m
.5512 1.52224 L
.54588 1.52196 L
.5231 1.52436 L
.52576 1.52449 L
F
.5512 1.52224 m
.57664 1.51998 L
.56866 1.51956 L
.54588 1.52196 L
.5512 1.52224 L
F
.50032 1.52675 m
.5231 1.52436 L
.51889 1.52438 L
.50032 1.52675 L
.50032 1.52675 L
F
.5231 1.52436 m
.54588 1.52196 L
.53746 1.52201 L
.51889 1.52438 L
.5231 1.52436 L
F
.54588 1.52196 m
.56866 1.51956 L
.55603 1.51963 L
.53746 1.52201 L
.54588 1.52196 L
F
.50032 1.52675 m
.51889 1.52438 L
.51341 1.52456 L
.50032 1.52675 L
.50032 1.52675 L
F
.51889 1.52438 m
.53746 1.52201 L
.5265 1.52238 L
.51341 1.52456 L
.51889 1.52438 L
F
.53746 1.52201 m
.55603 1.51963 L
.5396 1.52019 L
.5265 1.52238 L
.53746 1.52201 L
F
.50032 1.52675 m
.51341 1.52456 L
.50704 1.5249 L
.50032 1.52675 L
.50032 1.52675 L
F
.51341 1.52456 m
.5265 1.52238 L
.51377 1.52305 L
.50704 1.5249 L
.51341 1.52456 L
F
.5265 1.52238 m
.5396 1.52019 L
.52049 1.52119 L
.51377 1.52305 L
.5265 1.52238 L
F
.50032 1.52675 m
.50704 1.5249 L
.50022 1.52536 L
.50032 1.52675 L
.50032 1.52675 L
F
.50704 1.5249 m
.51377 1.52305 L
.50011 1.52397 L
.50022 1.52536 L
.50704 1.5249 L
F
.51377 1.52305 m
.52049 1.52119 L
.50001 1.52258 L
.50011 1.52397 L
.51377 1.52305 L
F
.50032 1.52675 m
.50022 1.52536 L
.4934 1.52592 L
.50032 1.52675 L
.50032 1.52675 L
F
.50022 1.52536 m
.50011 1.52397 L
.48647 1.52508 L
.4934 1.52592 L
.50022 1.52536 L
F
.50011 1.52397 m
.50001 1.52258 L
.47955 1.52424 L
.48647 1.52508 L
.50011 1.52397 L
F
.50032 1.52675 m
.4934 1.52592 L
.48705 1.52653 L
.50032 1.52675 L
.50032 1.52675 L
F
.4934 1.52592 m
.48647 1.52508 L
.47378 1.52631 L
.48705 1.52653 L
.4934 1.52592 L
F
.48647 1.52508 m
.47955 1.52424 L
.4605 1.52608 L
.47378 1.52631 L
.48647 1.52508 L
F
.50032 1.52675 m
.48705 1.52653 L
.4816 1.52716 L
.50032 1.52675 L
.50032 1.52675 L
F
.48705 1.52653 m
.47378 1.52631 L
.46289 1.52756 L
.4816 1.52716 L
.48705 1.52653 L
F
.47378 1.52631 m
.4605 1.52608 L
.44417 1.52797 L
.46289 1.52756 L
.47378 1.52631 L
F
.50032 1.52675 m
.4816 1.52716 L
.47744 1.52776 L
.50032 1.52675 L
.50032 1.52675 L
F
.4816 1.52716 m
.46289 1.52756 L
.45455 1.52876 L
.47744 1.52776 L
.4816 1.52716 L
F
.46289 1.52756 m
.44417 1.52797 L
.43167 1.52977 L
.45455 1.52876 L
.46289 1.52756 L
F
.50032 1.52675 m
.47744 1.52776 L
.47483 1.52829 L
.50032 1.52675 L
.50032 1.52675 L
F
.47744 1.52776 m
.45455 1.52876 L
.44933 1.52983 L
.47483 1.52829 L
.47744 1.52776 L
F
.45455 1.52876 m
.43167 1.52977 L
.42384 1.53136 L
.44933 1.52983 L
.45455 1.52876 L
F
.50032 1.52675 m
.47483 1.52829 L
.47396 1.52872 L
.50032 1.52675 L
.50032 1.52675 L
F
.47483 1.52829 m
.44933 1.52983 L
.44759 1.53068 L
.47396 1.52872 L
.47483 1.52829 L
F
.44933 1.52983 m
.42384 1.53136 L
.42123 1.53264 L
.44759 1.53068 L
.44933 1.52983 L
F
.50032 1.52675 m
.47396 1.52872 L
.47488 1.52901 L
.50032 1.52675 L
.50032 1.52675 L
F
.47396 1.52872 m
.44759 1.53068 L
.44944 1.53127 L
.47488 1.52901 L
.47396 1.52872 L
F
.44759 1.53068 m
.42123 1.53264 L
.424 1.53352 L
.44944 1.53127 L
.44759 1.53068 L
F
.50032 1.52675 m
.47488 1.52901 L
.47754 1.52915 L
.50032 1.52675 L
.50032 1.52675 L
F
.47488 1.52901 m
.44944 1.53127 L
.45476 1.53154 L
.47754 1.52915 L
.47488 1.52901 L
F
.44944 1.53127 m
.424 1.53352 L
.43198 1.53394 L
.45476 1.53154 L
.44944 1.53127 L
F
.50032 1.52675 m
.47754 1.52915 L
.48175 1.52912 L
.50032 1.52675 L
.50032 1.52675 L
F
.47754 1.52915 m
.45476 1.53154 L
.46318 1.5315 L
.48175 1.52912 L
.47754 1.52915 L
F
.45476 1.53154 m
.43198 1.53394 L
.44461 1.53387 L
.46318 1.5315 L
.45476 1.53154 L
F
.50032 1.52675 m
.48175 1.52912 L
.48723 1.52894 L
.50032 1.52675 L
.50032 1.52675 L
F
.48175 1.52912 m
.46318 1.5315 L
.47414 1.53113 L
.48723 1.52894 L
.48175 1.52912 L
F
.46318 1.5315 m
.44461 1.53387 L
.46104 1.53331 L
.47414 1.53113 L
.46318 1.5315 L
F
.50032 1.52675 m
.48723 1.52894 L
.4936 1.5286 L
.50032 1.52675 L
.50032 1.52675 L
F
.48723 1.52894 m
.47414 1.53113 L
.48687 1.53046 L
.4936 1.5286 L
.48723 1.52894 L
F
.47414 1.53113 m
.46104 1.53331 L
.48015 1.53231 L
.48687 1.53046 L
.47414 1.53113 L
F
.50032 1.52675 m
.4936 1.5286 L
.50042 1.52814 L
.50032 1.52675 L
.50032 1.52675 L
F
.4936 1.5286 m
.48687 1.53046 L
.50053 1.52953 L
.50042 1.52814 L
.4936 1.5286 L
F
.48687 1.53046 m
.48015 1.53231 L
.50063 1.53093 L
.50053 1.52953 L
.48687 1.53046 L
F
0 g
.50063 1.53093 m
.52109 1.52926 L
.54014 1.52742 L
.55647 1.52554 L
.56897 1.52374 L
.5768 1.52214 L
.57941 1.52086 L
.57664 1.51998 L
.56866 1.51956 L
.55603 1.51963 L
.5396 1.52019 L
.52049 1.52119 L
.50001 1.52258 L
.47955 1.52424 L
.4605 1.52608 L
.44417 1.52797 L
.43167 1.52977 L
.42384 1.53136 L
.42123 1.53264 L
.424 1.53352 L
.43198 1.53394 L
.44461 1.53387 L
.46104 1.53331 L
.48015 1.53231 L
.50063 1.53093 L
s
.5 g
.49914 1.51096 m
.49925 1.51235 L
.50607 1.51179 L
.49914 1.51096 L
.49914 1.51096 L
F
.49925 1.51235 m
.49935 1.51374 L
.51299 1.51263 L
.50607 1.51179 L
.49925 1.51235 L
F
.49935 1.51374 m
.49945 1.51513 L
.51991 1.51346 L
.51299 1.51263 L
.49935 1.51374 L
F
.49914 1.51096 m
.50607 1.51179 L
.51241 1.51118 L
.49914 1.51096 L
.49914 1.51096 L
F
.50607 1.51179 m
.51299 1.51263 L
.52569 1.5114 L
.51241 1.51118 L
.50607 1.51179 L
F
.51299 1.51263 m
.51991 1.51346 L
.53896 1.51162 L
.52569 1.5114 L
.51299 1.51263 L
F
.49914 1.51096 m
.51241 1.51118 L
.51786 1.51055 L
.49914 1.51096 L
.49914 1.51096 L
F
.51241 1.51118 m
.52569 1.5114 L
.53657 1.51015 L
.51786 1.51055 L
.51241 1.51118 L
F
.52569 1.5114 m
.53896 1.51162 L
.55529 1.50974 L
.53657 1.51015 L
.52569 1.5114 L
F
.49914 1.51096 m
.51786 1.51055 L
.52203 1.50995 L
.49914 1.51096 L
.49914 1.51096 L
F
.51786 1.51055 m
.53657 1.51015 L
.54491 1.50895 L
.52203 1.50995 L
.51786 1.51055 L
F
.53657 1.51015 m
.55529 1.50974 L
.56779 1.50794 L
.54491 1.50895 L
.53657 1.51015 L
F
.49914 1.51096 m
.52203 1.50995 L
.52464 1.50942 L
.49914 1.51096 L
.49914 1.51096 L
F
.52203 1.50995 m
.54491 1.50895 L
.55013 1.50788 L
.52464 1.50942 L
.52203 1.50995 L
F
.54491 1.50895 m
.56779 1.50794 L
.57562 1.50634 L
.55013 1.50788 L
.54491 1.50895 L
F
.49914 1.51096 m
.52464 1.50942 L
.52551 1.50899 L
.49914 1.51096 L
.49914 1.51096 L
F
.52464 1.50942 m
.55013 1.50788 L
.55187 1.50703 L
.52551 1.50899 L
.52464 1.50942 L
F
.55013 1.50788 m
.57562 1.50634 L
.57824 1.50506 L
.55187 1.50703 L
.55013 1.50788 L
F
.49914 1.51096 m
.52551 1.50899 L
.52458 1.5087 L
.49914 1.51096 L
.49914 1.51096 L
F
.52551 1.50899 m
.55187 1.50703 L
.55002 1.50644 L
.52458 1.5087 L
.52551 1.50899 L
F
.55187 1.50703 m
.57824 1.50506 L
.57546 1.50418 L
.55002 1.50644 L
.55187 1.50703 L
F
.49914 1.51096 m
.52458 1.5087 L
.52192 1.50856 L
.49914 1.51096 L
.49914 1.51096 L
F
.52458 1.5087 m
.55002 1.50644 L
.5447 1.50616 L
.52192 1.50856 L
.52458 1.5087 L
F
.55002 1.50644 m
.57546 1.50418 L
.56748 1.50377 L
.5447 1.50616 L
.55002 1.50644 L
F
.49914 1.51096 m
.52192 1.50856 L
.51771 1.50858 L
.49914 1.51096 L
.49914 1.51096 L
F
.52192 1.50856 m
.5447 1.50616 L
.53628 1.50621 L
.51771 1.50858 L
.52192 1.50856 L
F
.5447 1.50616 m
.56748 1.50377 L
.55485 1.50384 L
.53628 1.50621 L
.5447 1.50616 L
F
.49914 1.51096 m
.51771 1.50858 L
.51224 1.50877 L
.49914 1.51096 L
.49914 1.51096 L
F
.51771 1.50858 m
.53628 1.50621 L
.52533 1.50658 L
.51224 1.50877 L
.51771 1.50858 L
F
.53628 1.50621 m
.55485 1.50384 L
.53842 1.50439 L
.52533 1.50658 L
.53628 1.50621 L
F
.49914 1.51096 m
.51224 1.50877 L
.50587 1.5091 L
.49914 1.51096 L
.49914 1.51096 L
F
.51224 1.50877 m
.52533 1.50658 L
.51259 1.50725 L
.50587 1.5091 L
.51224 1.50877 L
F
.52533 1.50658 m
.53842 1.50439 L
.51931 1.5054 L
.51259 1.50725 L
.52533 1.50658 L
F
.49914 1.51096 m
.50587 1.5091 L
.49904 1.50956 L
.49914 1.51096 L
.49914 1.51096 L
F
.50587 1.5091 m
.51259 1.50725 L
.49894 1.50817 L
.49904 1.50956 L
.50587 1.5091 L
F
.51259 1.50725 m
.51931 1.5054 L
.49883 1.50678 L
.49894 1.50817 L
.51259 1.50725 L
F
.49914 1.51096 m
.49904 1.50956 L
.49222 1.51012 L
.49914 1.51096 L
.49914 1.51096 L
F
.49904 1.50956 m
.49894 1.50817 L
.4853 1.50928 L
.49222 1.51012 L
.49904 1.50956 L
F
.49894 1.50817 m
.49883 1.50678 L
.47837 1.50845 L
.4853 1.50928 L
.49894 1.50817 L
F
.49914 1.51096 m
.49222 1.51012 L
.48587 1.51073 L
.49914 1.51096 L
.49914 1.51096 L
F
.49222 1.51012 m
.4853 1.50928 L
.4726 1.51051 L
.48587 1.51073 L
.49222 1.51012 L
F
.4853 1.50928 m
.47837 1.50845 L
.45933 1.51029 L
.4726 1.51051 L
.4853 1.50928 L
F
.49914 1.51096 m
.48587 1.51073 L
.48043 1.51136 L
.49914 1.51096 L
.49914 1.51096 L
F
.48587 1.51073 m
.4726 1.51051 L
.46171 1.51176 L
.48043 1.51136 L
.48587 1.51073 L
F
.4726 1.51051 m
.45933 1.51029 L
.443 1.51217 L
.46171 1.51176 L
.4726 1.51051 L
F
.49914 1.51096 m
.48043 1.51136 L
.47626 1.51196 L
.49914 1.51096 L
.49914 1.51096 L
F
.48043 1.51136 m
.46171 1.51176 L
.45338 1.51297 L
.47626 1.51196 L
.48043 1.51136 L
F
.46171 1.51176 m
.443 1.51217 L
.43049 1.51397 L
.45338 1.51297 L
.46171 1.51176 L
F
.49914 1.51096 m
.47626 1.51196 L
.47365 1.51249 L
.49914 1.51096 L
.49914 1.51096 L
F
.47626 1.51196 m
.45338 1.51297 L
.44816 1.51403 L
.47365 1.51249 L
.47626 1.51196 L
F
.45338 1.51297 m
.43049 1.51397 L
.42266 1.51557 L
.44816 1.51403 L
.45338 1.51297 L
F
.49914 1.51096 m
.47365 1.51249 L
.47278 1.51292 L
.49914 1.51096 L
.49914 1.51096 L
F
.47365 1.51249 m
.44816 1.51403 L
.44641 1.51488 L
.47278 1.51292 L
.47365 1.51249 L
F
.44816 1.51403 m
.42266 1.51557 L
.42005 1.51685 L
.44641 1.51488 L
.44816 1.51403 L
F
.49914 1.51096 m
.47278 1.51292 L
.4737 1.51321 L
.49914 1.51096 L
.49914 1.51096 L
F
.47278 1.51292 m
.44641 1.51488 L
.44826 1.51547 L
.4737 1.51321 L
.47278 1.51292 L
F
.44641 1.51488 m
.42005 1.51685 L
.42283 1.51773 L
.44826 1.51547 L
.44641 1.51488 L
F
.49914 1.51096 m
.4737 1.51321 L
.47636 1.51335 L
.49914 1.51096 L
.49914 1.51096 L
F
.4737 1.51321 m
.44826 1.51547 L
.45358 1.51575 L
.47636 1.51335 L
.4737 1.51321 L
F
.44826 1.51547 m
.42283 1.51773 L
.4308 1.51815 L
.45358 1.51575 L
.44826 1.51547 L
F
.49914 1.51096 m
.47636 1.51335 L
.48057 1.51333 L
.49914 1.51096 L
.49914 1.51096 L
F
.47636 1.51335 m
.45358 1.51575 L
.46201 1.5157 L
.48057 1.51333 L
.47636 1.51335 L
F
.45358 1.51575 m
.4308 1.51815 L
.44344 1.51807 L
.46201 1.5157 L
.45358 1.51575 L
F
.49914 1.51096 m
.48057 1.51333 L
.48605 1.51314 L
.49914 1.51096 L
.49914 1.51096 L
F
.48057 1.51333 m
.46201 1.5157 L
.47296 1.51533 L
.48605 1.51314 L
.48057 1.51333 L
F
.46201 1.5157 m
.44344 1.51807 L
.45987 1.51752 L
.47296 1.51533 L
.46201 1.5157 L
F
.49914 1.51096 m
.48605 1.51314 L
.49242 1.51281 L
.49914 1.51096 L
.49914 1.51096 L
F
.48605 1.51314 m
.47296 1.51533 L
.4857 1.51466 L
.49242 1.51281 L
.48605 1.51314 L
F
.47296 1.51533 m
.45987 1.51752 L
.47897 1.51651 L
.4857 1.51466 L
.47296 1.51533 L
F
.49914 1.51096 m
.49242 1.51281 L
.49925 1.51235 L
.49914 1.51096 L
.49914 1.51096 L
F
.49242 1.51281 m
.4857 1.51466 L
.49935 1.51374 L
.49925 1.51235 L
.49242 1.51281 L
F
.4857 1.51466 m
.47897 1.51651 L
.49945 1.51513 L
.49935 1.51374 L
.4857 1.51466 L
F
0 g
.49945 1.51513 m
.51991 1.51346 L
.53896 1.51162 L
.55529 1.50974 L
.56779 1.50794 L
.57562 1.50634 L
.57824 1.50506 L
.57546 1.50418 L
.56748 1.50377 L
.55485 1.50384 L
.53842 1.50439 L
.51931 1.5054 L
.49883 1.50678 L
.47837 1.50845 L
.45933 1.51029 L
.443 1.51217 L
.43049 1.51397 L
.42266 1.51557 L
.42005 1.51685 L
.42283 1.51773 L
.4308 1.51815 L
.44344 1.51807 L
.45987 1.51752 L
.47897 1.51651 L
.49945 1.51513 L
s
.5 g
.49797 1.49516 m
.49807 1.49654 L
.50486 1.49599 L
.49797 1.49516 L
.49797 1.49516 L
F
.49807 1.49654 m
.49817 1.49793 L
.51174 1.49682 L
.50486 1.49599 L
.49807 1.49654 L
F
.49817 1.49793 m
.49828 1.49931 L
.51863 1.49765 L
.51174 1.49682 L
.49817 1.49793 L
F
.49797 1.49516 m
.50486 1.49599 L
.51117 1.49538 L
.49797 1.49516 L
.49797 1.49516 L
F
.50486 1.49599 m
.51174 1.49682 L
.52438 1.4956 L
.51117 1.49538 L
.50486 1.49599 L
F
.51174 1.49682 m
.51863 1.49765 L
.53758 1.49582 L
.52438 1.4956 L
.51174 1.49682 L
F
.49797 1.49516 m
.51117 1.49538 L
.51659 1.49476 L
.49797 1.49516 L
.49797 1.49516 L
F
.51117 1.49538 m
.52438 1.4956 L
.53521 1.49435 L
.51659 1.49476 L
.51117 1.49538 L
F
.52438 1.4956 m
.53758 1.49582 L
.55383 1.49395 L
.53521 1.49435 L
.52438 1.4956 L
F
.49797 1.49516 m
.51659 1.49476 L
.52074 1.49416 L
.49797 1.49516 L
.49797 1.49516 L
F
.51659 1.49476 m
.53521 1.49435 L
.54351 1.49316 L
.52074 1.49416 L
.51659 1.49476 L
F
.53521 1.49435 m
.55383 1.49395 L
.56627 1.49216 L
.54351 1.49316 L
.53521 1.49435 L
F
.49797 1.49516 m
.52074 1.49416 L
.52333 1.49363 L
.49797 1.49516 L
.49797 1.49516 L
F
.52074 1.49416 m
.54351 1.49316 L
.5487 1.4921 L
.52333 1.49363 L
.52074 1.49416 L
F
.54351 1.49316 m
.56627 1.49216 L
.57406 1.49057 L
.5487 1.4921 L
.54351 1.49316 L
F
.49797 1.49516 m
.52333 1.49363 L
.5242 1.4932 L
.49797 1.49516 L
.49797 1.49516 L
F
.52333 1.49363 m
.5487 1.4921 L
.55043 1.49125 L
.5242 1.4932 L
.52333 1.49363 L
F
.5487 1.4921 m
.57406 1.49057 L
.57666 1.4893 L
.55043 1.49125 L
.5487 1.4921 L
F
.49797 1.49516 m
.5242 1.4932 L
.52328 1.49291 L
.49797 1.49516 L
.49797 1.49516 L
F
.5242 1.4932 m
.55043 1.49125 L
.54859 1.49067 L
.52328 1.49291 L
.5242 1.4932 L
F
.55043 1.49125 m
.57666 1.4893 L
.5739 1.48842 L
.54859 1.49067 L
.55043 1.49125 L
F
.49797 1.49516 m
.52328 1.49291 L
.52063 1.49277 L
.49797 1.49516 L
.49797 1.49516 L
F
.52328 1.49291 m
.54859 1.49067 L
.5433 1.49039 L
.52063 1.49277 L
.52328 1.49291 L
F
.54859 1.49067 m
.5739 1.48842 L
.56597 1.488 L
.5433 1.49039 L
.54859 1.49067 L
F
.49797 1.49516 m
.52063 1.49277 L
.51644 1.4928 L
.49797 1.49516 L
.49797 1.49516 L
F
.52063 1.49277 m
.5433 1.49039 L
.53492 1.49044 L
.51644 1.4928 L
.52063 1.49277 L
F
.5433 1.49039 m
.56597 1.488 L
.55339 1.48808 L
.53492 1.49044 L
.5433 1.49039 L
F
.49797 1.49516 m
.51644 1.4928 L
.51099 1.49298 L
.49797 1.49516 L
.49797 1.49516 L
F
.51644 1.4928 m
.53492 1.49044 L
.52402 1.49081 L
.51099 1.49298 L
.51644 1.4928 L
F
.53492 1.49044 m
.55339 1.48808 L
.53705 1.48863 L
.52402 1.49081 L
.53492 1.49044 L
F
.49797 1.49516 m
.51099 1.49298 L
.50466 1.49332 L
.49797 1.49516 L
.49797 1.49516 L
F
.51099 1.49298 m
.52402 1.49081 L
.51135 1.49147 L
.50466 1.49332 L
.51099 1.49298 L
F
.52402 1.49081 m
.53705 1.48863 L
.51804 1.48963 L
.51135 1.49147 L
.52402 1.49081 L
F
.49797 1.49516 m
.50466 1.49332 L
.49786 1.49377 L
.49797 1.49516 L
.49797 1.49516 L
F
.50466 1.49332 m
.51135 1.49147 L
.49776 1.49239 L
.49786 1.49377 L
.50466 1.49332 L
F
.51135 1.49147 m
.51804 1.48963 L
.49766 1.491 L
.49776 1.49239 L
.51135 1.49147 L
F
.49797 1.49516 m
.49786 1.49377 L
.49108 1.49433 L
.49797 1.49516 L
.49797 1.49516 L
F
.49786 1.49377 m
.49776 1.49239 L
.48419 1.4935 L
.49108 1.49433 L
.49786 1.49377 L
F
.49776 1.49239 m
.49766 1.491 L
.4773 1.49266 L
.48419 1.4935 L
.49776 1.49239 L
F
.49797 1.49516 m
.49108 1.49433 L
.48476 1.49494 L
.49797 1.49516 L
.49797 1.49516 L
F
.49108 1.49433 m
.48419 1.4935 L
.47156 1.49471 L
.48476 1.49494 L
.49108 1.49433 L
F
.48419 1.4935 m
.4773 1.49266 L
.45835 1.49449 L
.47156 1.49471 L
.48419 1.4935 L
F
.49797 1.49516 m
.48476 1.49494 L
.47934 1.49556 L
.49797 1.49516 L
.49797 1.49516 L
F
.48476 1.49494 m
.47156 1.49471 L
.46072 1.49596 L
.47934 1.49556 L
.48476 1.49494 L
F
.47156 1.49471 m
.45835 1.49449 L
.4421 1.49637 L
.46072 1.49596 L
.47156 1.49471 L
F
.49797 1.49516 m
.47934 1.49556 L
.4752 1.49616 L
.49797 1.49516 L
.49797 1.49516 L
F
.47934 1.49556 m
.46072 1.49596 L
.45243 1.49716 L
.4752 1.49616 L
.47934 1.49556 L
F
.46072 1.49596 m
.4421 1.49637 L
.42966 1.49816 L
.45243 1.49716 L
.46072 1.49596 L
F
.49797 1.49516 m
.4752 1.49616 L
.4726 1.49669 L
.49797 1.49516 L
.49797 1.49516 L
F
.4752 1.49616 m
.45243 1.49716 L
.44724 1.49822 L
.4726 1.49669 L
.4752 1.49616 L
F
.45243 1.49716 m
.42966 1.49816 L
.42187 1.49975 L
.44724 1.49822 L
.45243 1.49716 L
F
.49797 1.49516 m
.4726 1.49669 L
.47173 1.49711 L
.49797 1.49516 L
.49797 1.49516 L
F
.4726 1.49669 m
.44724 1.49822 L
.4455 1.49907 L
.47173 1.49711 L
.4726 1.49669 L
F
.44724 1.49822 m
.42187 1.49975 L
.41927 1.50102 L
.4455 1.49907 L
.44724 1.49822 L
F
.49797 1.49516 m
.47173 1.49711 L
.47265 1.4974 L
.49797 1.49516 L
.49797 1.49516 L
F
.47173 1.49711 m
.4455 1.49907 L
.44734 1.49965 L
.47265 1.4974 L
.47173 1.49711 L
F
.4455 1.49907 m
.41927 1.50102 L
.42203 1.5019 L
.44734 1.49965 L
.4455 1.49907 L
F
.49797 1.49516 m
.47265 1.4974 L
.4753 1.49754 L
.49797 1.49516 L
.49797 1.49516 L
F
.47265 1.4974 m
.44734 1.49965 L
.45263 1.49993 L
.4753 1.49754 L
.47265 1.4974 L
F
.44734 1.49965 m
.42203 1.5019 L
.42997 1.50231 L
.45263 1.49993 L
.44734 1.49965 L
F
.49797 1.49516 m
.4753 1.49754 L
.47949 1.49752 L
.49797 1.49516 L
.49797 1.49516 L
F
.4753 1.49754 m
.45263 1.49993 L
.46101 1.49988 L
.47949 1.49752 L
.4753 1.49754 L
F
.45263 1.49993 m
.42997 1.50231 L
.44254 1.50224 L
.46101 1.49988 L
.45263 1.49993 L
F
.49797 1.49516 m
.47949 1.49752 L
.48494 1.49733 L
.49797 1.49516 L
.49797 1.49516 L
F
.47949 1.49752 m
.46101 1.49988 L
.47191 1.49951 L
.48494 1.49733 L
.47949 1.49752 L
F
.46101 1.49988 m
.44254 1.50224 L
.45889 1.50169 L
.47191 1.49951 L
.46101 1.49988 L
F
.49797 1.49516 m
.48494 1.49733 L
.49128 1.497 L
.49797 1.49516 L
.49797 1.49516 L
F
.48494 1.49733 m
.47191 1.49951 L
.48459 1.49885 L
.49128 1.497 L
.48494 1.49733 L
F
.47191 1.49951 m
.45889 1.50169 L
.4779 1.50069 L
.48459 1.49885 L
.47191 1.49951 L
F
.49797 1.49516 m
.49128 1.497 L
.49807 1.49654 L
.49797 1.49516 L
.49797 1.49516 L
F
.49128 1.497 m
.48459 1.49885 L
.49817 1.49793 L
.49807 1.49654 L
.49128 1.497 L
F
.48459 1.49885 m
.4779 1.50069 L
.49828 1.49931 L
.49817 1.49793 L
.48459 1.49885 L
F
0 g
.49828 1.49933 m
.51874 1.49767 L
.53778 1.49583 L
.55411 1.49394 L
.56662 1.49214 L
.57444 1.49055 L
.57706 1.48927 L
.57428 1.48839 L
.56631 1.48797 L
.55367 1.48804 L
.53724 1.4886 L
.51814 1.4896 L
.49766 1.49098 L
.4772 1.49265 L
.45815 1.49449 L
.44182 1.49637 L
.42931 1.49817 L
.42149 1.49977 L
.41887 1.50105 L
.42165 1.50193 L
.42963 1.50235 L
.44226 1.50228 L
.45869 1.50172 L
.4778 1.50072 L
.49828 1.49933 L
s
.5 g
.50063 1.53093 m
.49945 1.51513 L
.51991 1.51346 L
.52109 1.52926 L
.50063 1.53093 L
F
.52109 1.52926 m
.51991 1.51346 L
.53896 1.51162 L
.54014 1.52742 L
.52109 1.52926 L
F
.54014 1.52742 m
.53896 1.51162 L
.55529 1.50974 L
.55647 1.52554 L
.54014 1.52742 L
F
.55647 1.52554 m
.55529 1.50974 L
.56779 1.50794 L
.56897 1.52374 L
.55647 1.52554 L
F
.56897 1.52374 m
.56779 1.50794 L
.57562 1.50634 L
.5768 1.52214 L
.56897 1.52374 L
F
.5768 1.52214 m
.57562 1.50634 L
.57824 1.50506 L
.57941 1.52086 L
.5768 1.52214 L
F
.57941 1.52086 m
.57824 1.50506 L
.57546 1.50418 L
.57664 1.51998 L
.57941 1.52086 L
F
.57664 1.51998 m
.57546 1.50418 L
.56748 1.50377 L
.56866 1.51956 L
.57664 1.51998 L
F
.56866 1.51956 m
.56748 1.50377 L
.55485 1.50384 L
.55603 1.51963 L
.56866 1.51956 L
F
.55603 1.51963 m
.55485 1.50384 L
.53842 1.50439 L
.5396 1.52019 L
.55603 1.51963 L
F
.5396 1.52019 m
.53842 1.50439 L
.51931 1.5054 L
.52049 1.52119 L
.5396 1.52019 L
F
.52049 1.52119 m
.51931 1.5054 L
.49883 1.50678 L
.50001 1.52258 L
.52049 1.52119 L
F
.50001 1.52258 m
.49883 1.50678 L
.47837 1.50845 L
.47955 1.52424 L
.50001 1.52258 L
F
.47955 1.52424 m
.47837 1.50845 L
.45933 1.51029 L
.4605 1.52608 L
.47955 1.52424 L
F
.4605 1.52608 m
.45933 1.51029 L
.443 1.51217 L
.44417 1.52797 L
.4605 1.52608 L
F
.44417 1.52797 m
.443 1.51217 L
.43049 1.51397 L
.43167 1.52977 L
.44417 1.52797 L
F
.43167 1.52977 m
.43049 1.51397 L
.42266 1.51557 L
.42384 1.53136 L
.43167 1.52977 L
F
.42384 1.53136 m
.42266 1.51557 L
.42005 1.51685 L
.42123 1.53264 L
.42384 1.53136 L
F
.42123 1.53264 m
.42005 1.51685 L
.42283 1.51773 L
.424 1.53352 L
.42123 1.53264 L
F
.424 1.53352 m
.42283 1.51773 L
.4308 1.51815 L
.43198 1.53394 L
.424 1.53352 L
F
.43198 1.53394 m
.4308 1.51815 L
.44344 1.51807 L
.44461 1.53387 L
.43198 1.53394 L
F
.44461 1.53387 m
.44344 1.51807 L
.45987 1.51752 L
.46104 1.53331 L
.44461 1.53387 L
F
.46104 1.53331 m
.45987 1.51752 L
.47897 1.51651 L
.48015 1.53231 L
.46104 1.53331 L
F
.48015 1.53231 m
.47897 1.51651 L
.49945 1.51513 L
.50063 1.53093 L
.48015 1.53231 L
F
.49945 1.51513 m
.49828 1.49933 L
.51874 1.49767 L
.51991 1.51346 L
.49945 1.51513 L
F
.51991 1.51346 m
.51874 1.49767 L
.53778 1.49583 L
.53896 1.51162 L
.51991 1.51346 L
F
.53896 1.51162 m
.53778 1.49583 L
.55411 1.49394 L
.55529 1.50974 L
.53896 1.51162 L
F
.55529 1.50974 m
.55411 1.49394 L
.56662 1.49214 L
.56779 1.50794 L
.55529 1.50974 L
F
.56779 1.50794 m
.56662 1.49214 L
.57444 1.49055 L
.57562 1.50634 L
.56779 1.50794 L
F
.57562 1.50634 m
.57444 1.49055 L
.57706 1.48927 L
.57824 1.50506 L
.57562 1.50634 L
F
.57824 1.50506 m
.57706 1.48927 L
.57428 1.48839 L
.57546 1.50418 L
.57824 1.50506 L
F
.57546 1.50418 m
.57428 1.48839 L
.56631 1.48797 L
.56748 1.50377 L
.57546 1.50418 L
F
.56748 1.50377 m
.56631 1.48797 L
.55367 1.48804 L
.55485 1.50384 L
.56748 1.50377 L
F
.55485 1.50384 m
.55367 1.48804 L
.53724 1.4886 L
.53842 1.50439 L
.55485 1.50384 L
F
.53842 1.50439 m
.53724 1.4886 L
.51814 1.4896 L
.51931 1.5054 L
.53842 1.50439 L
F
.51931 1.5054 m
.51814 1.4896 L
.49766 1.49098 L
.49883 1.50678 L
.51931 1.5054 L
F
.49883 1.50678 m
.49766 1.49098 L
.4772 1.49265 L
.47837 1.50845 L
.49883 1.50678 L
F
.47837 1.50845 m
.4772 1.49265 L
.45815 1.49449 L
.45933 1.51029 L
.47837 1.50845 L
F
.45933 1.51029 m
.45815 1.49449 L
.44182 1.49637 L
.443 1.51217 L
.45933 1.51029 L
F
.443 1.51217 m
.44182 1.49637 L
.42931 1.49817 L
.43049 1.51397 L
.443 1.51217 L
F
.43049 1.51397 m
.42931 1.49817 L
.42149 1.49977 L
.42266 1.51557 L
.43049 1.51397 L
F
.42266 1.51557 m
.42149 1.49977 L
.41887 1.50105 L
.42005 1.51685 L
.42266 1.51557 L
F
.42005 1.51685 m
.41887 1.50105 L
.42165 1.50193 L
.42283 1.51773 L
.42005 1.51685 L
F
.42283 1.51773 m
.42165 1.50193 L
.42963 1.50235 L
.4308 1.51815 L
.42283 1.51773 L
F
.4308 1.51815 m
.42963 1.50235 L
.44226 1.50228 L
.44344 1.51807 L
.4308 1.51815 L
F
.44344 1.51807 m
.44226 1.50228 L
.45869 1.50172 L
.45987 1.51752 L
.44344 1.51807 L
F
.45987 1.51752 m
.45869 1.50172 L
.4778 1.50072 L
.47897 1.51651 L
.45987 1.51752 L
F
.47897 1.51651 m
.4778 1.50072 L
.49828 1.49933 L
.49945 1.51513 L
.47897 1.51651 L
F
.47285 .57501 m
.482 .57501 L
.482 .73363 L
.47285 .73363 L
.47285 .57501 L
F
.47285 .73363 m
.482 .73363 L
.482 .89226 L
.47285 .89226 L
.47285 .73363 L
F
.47285 .89226 m
.482 .89226 L
.482 1.05088 L
.47285 1.05088 L
.47285 .89226 L
F
.47285 1.05088 m
.482 1.05088 L
.482 1.2095 L
.47285 1.2095 L
.47285 1.05088 L
F
.47285 1.2095 m
.482 1.2095 L
.482 1.36813 L
.47285 1.36813 L
.47285 1.2095 L
F
.47285 1.36813 m
.482 1.36813 L
.482 1.52675 L
.47285 1.52675 L
.47285 1.36813 L
F
.482 .57501 m
.49116 .57501 L
.49116 .73363 L
.482 .73363 L
.482 .57501 L
F
.482 .73363 m
.49116 .73363 L
.49116 .89226 L
.482 .89226 L
.482 .73363 L
F
.482 .89226 m
.49116 .89226 L
.49116 1.05088 L
.482 1.05088 L
.482 .89226 L
F
.482 1.05088 m
.49116 1.05088 L
.49116 1.2095 L
.482 1.2095 L
.482 1.05088 L
F
.482 1.2095 m
.49116 1.2095 L
.49116 1.36813 L
.482 1.36813 L
.482 1.2095 L
F
.482 1.36813 m
.49116 1.36813 L
.49116 1.52675 L
.482 1.52675 L
.482 1.36813 L
F
.49116 .57501 m
.50032 .57501 L
.50032 .73363 L
.49116 .73363 L
.49116 .57501 L
F
.49116 .73363 m
.50032 .73363 L
.50032 .89226 L
.49116 .89226 L
.49116 .73363 L
F
.49116 .89226 m
.50032 .89226 L
.50032 1.05088 L
.49116 1.05088 L
.49116 .89226 L
F
.49116 1.05088 m
.50032 1.05088 L
.50032 1.2095 L
.49116 1.2095 L
.49116 1.05088 L
F
.49116 1.2095 m
.50032 1.2095 L
.50032 1.36813 L
.49116 1.36813 L
.49116 1.2095 L
F
.49116 1.36813 m
.50032 1.36813 L
.50032 1.52675 L
.49116 1.52675 L
.49116 1.36813 L
F
.50032 .57501 m
.50948 .57501 L
.50948 .73363 L
.50032 .73363 L
.50032 .57501 L
F
.50032 .73363 m
.50948 .73363 L
.50948 .89226 L
.50032 .89226 L
.50032 .73363 L
F
.50032 .89226 m
.50948 .89226 L
.50948 1.05088 L
.50032 1.05088 L
.50032 .89226 L
F
.50032 1.05088 m
.50948 1.05088 L
.50948 1.2095 L
.50032 1.2095 L
.50032 1.05088 L
F
.50032 1.2095 m
.50948 1.2095 L
.50948 1.36813 L
.50032 1.36813 L
.50032 1.2095 L
F
.50032 1.36813 m
.50948 1.36813 L
.50948 1.52675 L
.50032 1.52675 L
.50032 1.36813 L
F
.50948 .57501 m
.51864 .57501 L
.51864 .73363 L
.50948 .73363 L
.50948 .57501 L
F
.50948 .73363 m
.51864 .73363 L
.51864 .89226 L
.50948 .89226 L
.50948 .73363 L
F
.50948 .89226 m
.51864 .89226 L
.51864 1.05088 L
.50948 1.05088 L
.50948 .89226 L
F
.50948 1.05088 m
.51864 1.05088 L
.51864 1.2095 L
.50948 1.2095 L
.50948 1.05088 L
F
.50948 1.2095 m
.51864 1.2095 L
.51864 1.36813 L
.50948 1.36813 L
.50948 1.2095 L
F
.50948 1.36813 m
.51864 1.36813 L
.51864 1.52675 L
.50948 1.52675 L
.50948 1.36813 L
F
.51864 .57501 m
.52779 .57501 L
.52779 .73363 L
.51864 .73363 L
.51864 .57501 L
F
.51864 .73363 m
.52779 .73363 L
.52779 .89226 L
.51864 .89226 L
.51864 .73363 L
F
.51864 .89226 m
.52779 .89226 L
.52779 1.05088 L
.51864 1.05088 L
.51864 .89226 L
F
.51864 1.05088 m
.52779 1.05088 L
.52779 1.2095 L
.51864 1.2095 L
.51864 1.05088 L
F
.51864 1.2095 m
.52779 1.2095 L
.52779 1.36813 L
.51864 1.36813 L
.51864 1.2095 L
F
.51864 1.36813 m
.52779 1.36813 L
.52779 1.52675 L
.51864 1.52675 L
.51864 1.36813 L
F
0 g
.47285 1.52675 m
.482 1.52675 L
.49116 1.52675 L
.50032 1.52675 L
.50948 1.52675 L
.51864 1.52675 L
.52779 1.52675 L
.52779 1.52675 L
.52779 1.36813 L
.52779 1.2095 L
.52779 1.05088 L
.52779 .89226 L
.52779 .73363 L
.52779 .57501 L
.52779 .57501 L
.51864 .57501 L
.50948 .57501 L
.50032 .57501 L
.49116 .57501 L
.482 .57501 L
.47285 .57501 L
.47285 .57501 L
.47285 .73363 L
.47285 .89226 L
.47285 1.05088 L
.47285 1.2095 L
.47285 1.36813 L
.47285 1.52675 L
s
.5 g
.52779 .57501 m
.53191 .57501 L
.53191 .73363 L
.52779 .73363 L
.52779 .57501 L
F
.52779 .73363 m
.53191 .73363 L
.53191 .89226 L
.52779 .89226 L
.52779 .73363 L
F
.52779 .89226 m
.53191 .89226 L
.53191 1.05088 L
.52779 1.05088 L
.52779 .89226 L
F
.52779 1.05088 m
.53191 1.05088 L
.53191 1.2095 L
.52779 1.2095 L
.52779 1.05088 L
F
.52779 1.2095 m
.53191 1.2095 L
.53191 1.36813 L
.52779 1.36813 L
.52779 1.2095 L
F
.52779 1.36813 m
.53191 1.36813 L
.53191 1.52675 L
.52779 1.52675 L
.52779 1.36813 L
F
.53191 .57501 m
.5312 .57501 L
.5312 .73363 L
.53191 .73363 L
.53191 .57501 L
F
.53191 .73363 m
.5312 .73363 L
.5312 .89226 L
.53191 .89226 L
.53191 .73363 L
F
.53191 .89226 m
.5312 .89226 L
.5312 1.05088 L
.53191 1.05088 L
.53191 .89226 L
F
.53191 1.05088 m
.5312 1.05088 L
.5312 1.2095 L
.53191 1.2095 L
.53191 1.05088 L
F
.53191 1.2095 m
.5312 1.2095 L
.5312 1.36813 L
.53191 1.36813 L
.53191 1.2095 L
F
.53191 1.36813 m
.5312 1.36813 L
.5312 1.52675 L
.53191 1.52675 L
.53191 1.36813 L
F
.5312 .57501 m
.52779 .57501 L
.52779 .73363 L
.5312 .73363 L
.5312 .57501 L
F
.5312 .73363 m
.52779 .73363 L
.52779 .89226 L
.5312 .89226 L
.5312 .73363 L
F
.5312 .89226 m
.52779 .89226 L
.52779 1.05088 L
.5312 1.05088 L
.5312 .89226 L
F
.5312 1.05088 m
.52779 1.05088 L
.52779 1.2095 L
.5312 1.2095 L
.5312 1.05088 L
F
.5312 1.2095 m
.52779 1.2095 L
.52779 1.36813 L
.5312 1.36813 L
.5312 1.2095 L
F
.5312 1.36813 m
.52779 1.36813 L
.52779 1.52675 L
.5312 1.52675 L
.5312 1.36813 L
F
.52779 .57501 m
.52205 .57501 L
.52205 .73363 L
.52779 .73363 L
.52779 .57501 L
F
.52779 .73363 m
.52205 .73363 L
.52205 .89226 L
.52779 .89226 L
.52779 .73363 L
F
.52779 .89226 m
.52205 .89226 L
.52205 1.05088 L
.52779 1.05088 L
.52779 .89226 L
F
.52779 1.05088 m
.52205 1.05088 L
.52205 1.2095 L
.52779 1.2095 L
.52779 1.05088 L
F
.52779 1.2095 m
.52205 1.2095 L
.52205 1.36813 L
.52779 1.36813 L
.52779 1.2095 L
F
.52779 1.36813 m
.52205 1.36813 L
.52205 1.52675 L
.52779 1.52675 L
.52779 1.36813 L
F
.52205 .57501 m
.51359 .57501 L
.51359 .73363 L
.52205 .73363 L
.52205 .57501 L
F
.52205 .73363 m
.51359 .73363 L
.51359 .89226 L
.52205 .89226 L
.52205 .73363 L
F
.52205 .89226 m
.51359 .89226 L
.51359 1.05088 L
.52205 1.05088 L
.52205 .89226 L
F
.52205 1.05088 m
.51359 1.05088 L
.51359 1.2095 L
.52205 1.2095 L
.52205 1.05088 L
F
.52205 1.2095 m
.51359 1.2095 L
.51359 1.36813 L
.52205 1.36813 L
.52205 1.2095 L
F
.52205 1.36813 m
.51359 1.36813 L
.51359 1.52675 L
.52205 1.52675 L
.52205 1.36813 L
F
.51359 .57501 m
.50032 .57501 L
.50032 .73363 L
.51359 .73363 L
.51359 .57501 L
F
.51359 .73363 m
.50032 .73363 L
.50032 .89226 L
.51359 .89226 L
.51359 .73363 L
F
.51359 .89226 m
.50032 .89226 L
.50032 1.05088 L
.51359 1.05088 L
.51359 .89226 L
F
.51359 1.05088 m
.50032 1.05088 L
.50032 1.2095 L
.51359 1.2095 L
.51359 1.05088 L
F
.51359 1.2095 m
.50032 1.2095 L
.50032 1.36813 L
.51359 1.36813 L
.51359 1.2095 L
F
.51359 1.36813 m
.50032 1.36813 L
.50032 1.52675 L
.51359 1.52675 L
.51359 1.36813 L
F
0 g
.52779 1.52675 m
.53191 1.52675 L
.5312 1.52675 L
.52779 1.52675 L
.52205 1.52675 L
.51359 1.52675 L
.50032 1.52675 L
.50032 1.52675 L
.50032 1.36813 L
.50032 1.2095 L
.50032 1.05088 L
.50032 .89226 L
.50032 .73363 L
.50032 .57501 L
.50032 .57501 L
.51359 .57501 L
.52205 .57501 L
.52779 .57501 L
.5312 .57501 L
.53191 .57501 L
.52779 .57501 L
.52779 .57501 L
.52779 .73363 L
.52779 .89226 L
.52779 1.05088 L
.52779 1.2095 L
.52779 1.36813 L
.52779 1.52675 L
s
.5 g
.50032 .57501 m
.48705 .57501 L
.48705 .73363 L
.50032 .73363 L
.50032 .57501 L
F
.50032 .73363 m
.48705 .73363 L
.48705 .89226 L
.50032 .89226 L
.50032 .73363 L
F
.50032 .89226 m
.48705 .89226 L
.48705 1.05088 L
.50032 1.05088 L
.50032 .89226 L
F
.50032 1.05088 m
.48705 1.05088 L
.48705 1.2095 L
.50032 1.2095 L
.50032 1.05088 L
F
.50032 1.2095 m
.48705 1.2095 L
.48705 1.36813 L
.50032 1.36813 L
.50032 1.2095 L
F
.50032 1.36813 m
.48705 1.36813 L
.48705 1.52675 L
.50032 1.52675 L
.50032 1.36813 L
F
.48705 .57501 m
.47859 .57501 L
.47859 .73363 L
.48705 .73363 L
.48705 .57501 L
F
.48705 .73363 m
.47859 .73363 L
.47859 .89226 L
.48705 .89226 L
.48705 .73363 L
F
.48705 .89226 m
.47859 .89226 L
.47859 1.05088 L
.48705 1.05088 L
.48705 .89226 L
F
.48705 1.05088 m
.47859 1.05088 L
.47859 1.2095 L
.48705 1.2095 L
.48705 1.05088 L
F
.48705 1.2095 m
.47859 1.2095 L
.47859 1.36813 L
.48705 1.36813 L
.48705 1.2095 L
F
.48705 1.36813 m
.47859 1.36813 L
.47859 1.52675 L
.48705 1.52675 L
.48705 1.36813 L
F
.47859 .57501 m
.47285 .57501 L
.47285 .73363 L
.47859 .73363 L
.47859 .57501 L
F
.47859 .73363 m
.47285 .73363 L
.47285 .89226 L
.47859 .89226 L
.47859 .73363 L
F
.47859 .89226 m
.47285 .89226 L
.47285 1.05088 L
.47859 1.05088 L
.47859 .89226 L
F
.47859 1.05088 m
.47285 1.05088 L
.47285 1.2095 L
.47859 1.2095 L
.47859 1.05088 L
F
.47859 1.2095 m
.47285 1.2095 L
.47285 1.36813 L
.47859 1.36813 L
.47859 1.2095 L
F
.47859 1.36813 m
.47285 1.36813 L
.47285 1.52675 L
.47859 1.52675 L
.47859 1.36813 L
F
.47285 .57501 m
.46944 .57501 L
.46944 .73363 L
.47285 .73363 L
.47285 .57501 L
F
.47285 .73363 m
.46944 .73363 L
.46944 .89226 L
.47285 .89226 L
.47285 .73363 L
F
.47285 .89226 m
.46944 .89226 L
.46944 1.05088 L
.47285 1.05088 L
.47285 .89226 L
F
.47285 1.05088 m
.46944 1.05088 L
.46944 1.2095 L
.47285 1.2095 L
.47285 1.05088 L
F
.47285 1.2095 m
.46944 1.2095 L
.46944 1.36813 L
.47285 1.36813 L
.47285 1.2095 L
F
.47285 1.36813 m
.46944 1.36813 L
.46944 1.52675 L
.47285 1.52675 L
.47285 1.36813 L
F
.46944 .57501 m
.46873 .57501 L
.46873 .73363 L
.46944 .73363 L
.46944 .57501 L
F
.46944 .73363 m
.46873 .73363 L
.46873 .89226 L
.46944 .89226 L
.46944 .73363 L
F
.46944 .89226 m
.46873 .89226 L
.46873 1.05088 L
.46944 1.05088 L
.46944 .89226 L
F
.46944 1.05088 m
.46873 1.05088 L
.46873 1.2095 L
.46944 1.2095 L
.46944 1.05088 L
F
.46944 1.2095 m
.46873 1.2095 L
.46873 1.36813 L
.46944 1.36813 L
.46944 1.2095 L
F
.46944 1.36813 m
.46873 1.36813 L
.46873 1.52675 L
.46944 1.52675 L
.46944 1.36813 L
F
.46873 .57501 m
.47285 .57501 L
.47285 .73363 L
.46873 .73363 L
.46873 .57501 L
F
.46873 .73363 m
.47285 .73363 L
.47285 .89226 L
.46873 .89226 L
.46873 .73363 L
F
.46873 .89226 m
.47285 .89226 L
.47285 1.05088 L
.46873 1.05088 L
.46873 .89226 L
F
.46873 1.05088 m
.47285 1.05088 L
.47285 1.2095 L
.46873 1.2095 L
.46873 1.05088 L
F
.46873 1.2095 m
.47285 1.2095 L
.47285 1.36813 L
.46873 1.36813 L
.46873 1.2095 L
F
.46873 1.36813 m
.47285 1.36813 L
.47285 1.52675 L
.46873 1.52675 L
.46873 1.36813 L
F
0 g
.50032 1.52675 m
.48705 1.52675 L
.47859 1.52675 L
.47285 1.52675 L
.46944 1.52675 L
.46873 1.52675 L
.47285 1.52675 L
.47285 1.52675 L
.47285 1.36813 L
.47285 1.2095 L
.47285 1.05088 L
.47285 .89226 L
.47285 .73363 L
.47285 .57501 L
.47285 .57501 L
.46873 .57501 L
.46944 .57501 L
.47285 .57501 L
.47859 .57501 L
.48705 .57501 L
.50032 .57501 L
.50032 .57501 L
.50032 .73363 L
.50032 .89226 L
.50032 1.05088 L
.50032 1.2095 L
.50032 1.36813 L
.50032 1.52675 L
s
.97619 .09914 m
.02445 .09914 L
.02445 4.06473 L
.97619 4.06473 L
.97619 .09914 L
s
.02445 .09914 m
.02445 .09914 L
.02445 4.06473 L
.02445 4.06473 L
.02445 .09914 L
s
.02445 .09914 m
.97619 .09914 L
.97619 4.06473 L
.02445 4.06473 L
.02445 .09914 L
s
.97619 .09914 m
.97619 .09914 L
.97619 4.06473 L
.97619 4.06473 L
.97619 .09914 L
s
.02445 .09914 m
.97619 .09914 L
.97619 .09914 L
.02445 .09914 L
.02445 .09914 L
s
.97619 4.06473 m
.02445 4.06473 L
.02445 4.06473 L
.97619 4.06473 L
.97619 4.06473 L
s
.039 .916 .04 r
.53093 3.74971 m
.97377 .7219 L
s
0 0 0 r
2.5 Mabswid
.97377 .7219 Mdot
.039 .916 .04 r
.5 Mabswid
.53075 3.74968 m
.97102 .72196 L
s
0 0 0 r
2.5 Mabswid
.97102 .72196 Mdot
.039 .916 .04 r
.5 Mabswid
.52974 3.74954 m
.95504 .72236 L
s
0 0 0 r
2.5 Mabswid
.95504 .72236 Mdot
.039 .916 .04 r
.5 Mabswid
.52924 3.74947 m
.94709 .72256 L
s
0 0 0 r
2.5 Mabswid
.94709 .72256 Mdot
.039 .916 .04 r
.5 Mabswid
.52872 3.7494 m
.93885 .72276 L
s
0 0 0 r
2.5 Mabswid
.93885 .72276 Mdot
.039 .916 .04 r
.5 Mabswid
.52771 3.74926 m
.92296 .72316 L
s
0 0 0 r
2.5 Mabswid
.92296 .72316 Mdot
.039 .916 .04 r
.5 Mabswid
.52735 3.74922 m
.91722 .7233 L
s
0 0 0 r
2.5 Mabswid
.91722 .7233 Mdot
.039 .916 .04 r
.5 Mabswid
.52672 3.74914 m
.88838 .87446 L
s
0 0 0 r
2.5 Mabswid
.88838 .87446 Mdot
.039 .916 .04 r
.5 Mabswid
.52609 3.74906 m
.87891 .87489 L
s
0 0 0 r
2.5 Mabswid
.87891 .87489 Mdot
.039 .916 .04 r
.5 Mabswid
.52544 3.74898 m
.86916 .87534 L
s
0 0 0 r
2.5 Mabswid
.86916 .87534 Mdot
.039 .916 .04 r
.5 Mabswid
.52453 3.74887 m
.85551 .87596 L
s
0 0 0 r
2.5 Mabswid
.85551 .87596 Mdot
.039 .916 .04 r
.5 Mabswid
.52448 3.74887 m
.85478 .876 L
s
0 0 0 r
2.5 Mabswid
.85478 .876 Mdot
.039 .916 .04 r
.5 Mabswid
.52369 3.74878 m
.84295 .87654 L
s
0 0 0 r
2.5 Mabswid
.84295 .87654 Mdot
.039 .916 .04 r
.5 Mabswid
.52289 3.74869 m
.81548 1.02272 L
s
0 0 0 r
2.5 Mabswid
.81548 1.02272 Mdot
.039 .916 .04 r
.5 Mabswid
.52227 3.74862 m
.80669 1.0235 L
s
0 0 0 r
2.5 Mabswid
.80669 1.0235 Mdot
.039 .916 .04 r
.5 Mabswid
.52162 3.74856 m
.79742 1.02433 L
s
0 0 0 r
2.5 Mabswid
.79742 1.02433 Mdot
.039 .916 .04 r
.5 Mabswid
.52096 3.74849 m
.78801 1.02517 L
s
0 0 0 r
2.5 Mabswid
.78801 1.02517 Mdot
.039 .916 .04 r
.5 Mabswid
.5201 3.74841 m
.77586 1.02626 L
s
0 0 0 r
2.5 Mabswid
.77586 1.02626 Mdot
.039 .916 .04 r
.5 Mabswid
.5198 3.74838 m
.77163 1.02664 L
s
0 0 0 r
2.5 Mabswid
.77163 1.02664 Mdot
.039 .916 .04 r
.5 Mabswid
.5193 3.74833 m
.76445 1.02728 L
s
0 0 0 r
2.5 Mabswid
.76445 1.02728 Mdot
.039 .916 .04 r
.5 Mabswid
.51838 3.74825 m
.73632 1.20481 L
s
0 0 0 r
2.5 Mabswid
.73632 1.20481 Mdot
.039 .916 .04 r
.5 Mabswid
.51803 3.74822 m
.73171 1.2049 L
s
0 0 0 r
2.5 Mabswid
.73171 1.2049 Mdot
.039 .916 .04 r
.5 Mabswid
.51725 3.74816 m
.72149 1.20511 L
s
0 0 0 r
2.5 Mabswid
.72149 1.20511 Mdot
.039 .916 .04 r
.5 Mabswid
.51662 3.74811 m
.71316 1.20527 L
s
0 0 0 r
2.5 Mabswid
.71316 1.20527 Mdot
.039 .916 .04 r
.5 Mabswid
.51567 3.74804 m
.70067 1.20552 L
s
0 0 0 r
2.5 Mabswid
.70067 1.20552 Mdot
.039 .916 .04 r
.5 Mabswid
.5155 3.74803 m
.6984 1.20556 L
s
0 0 0 r
2.5 Mabswid
.6984 1.20556 Mdot
.039 .916 .04 r
.5 Mabswid
.51448 3.74796 m
.68504 1.20583 L
s
0 0 0 r
2.5 Mabswid
.68504 1.20583 Mdot
.039 .916 .04 r
.5 Mabswid
.51436 3.74795 m
.68346 1.20586 L
s
0 0 0 r
2.5 Mabswid
.68346 1.20586 Mdot
.039 .916 .04 r
.5 Mabswid
.5133 3.74788 m
.66961 1.20614 L
s
0 0 0 r
2.5 Mabswid
.66961 1.20614 Mdot
.039 .916 .04 r
.5 Mabswid
.51288 3.74785 m
.6551 1.35794 L
s
0 0 0 r
2.5 Mabswid
.6551 1.35794 Mdot
.039 .916 .04 r
.5 Mabswid
.51224 3.74782 m
.64707 1.35847 L
s
0 0 0 r
2.5 Mabswid
.64707 1.35847 Mdot
.039 .916 .04 r
.5 Mabswid
.51148 3.74778 m
.63767 1.35909 L
s
0 0 0 r
2.5 Mabswid
.63767 1.35909 Mdot
.039 .916 .04 r
.5 Mabswid
.51106 3.74775 m
.63255 1.35943 L
s
0 0 0 r
2.5 Mabswid
.63255 1.35943 Mdot
.039 .916 .04 r
.5 Mabswid
.51003 3.7477 m
.61975 1.36027 L
s
0 0 0 r
2.5 Mabswid
.61975 1.36027 Mdot
.039 .916 .04 r
.5 Mabswid
.50967 3.74769 m
.61531 1.36056 L
s
0 0 0 r
2.5 Mabswid
.61531 1.36056 Mdot
.039 .916 .04 r
.5 Mabswid
.50896 3.74766 m
.60654 1.36114 L
s
0 0 0 r
2.5 Mabswid
.60654 1.36114 Mdot
.039 .916 .04 r
.5 Mabswid
.50807 3.74762 m
.59558 1.36186 L
s
0 0 0 r
2.5 Mabswid
.59558 1.36186 Mdot
.039 .916 .04 r
.5 Mabswid
.50784 3.74762 m
.59275 1.36205 L
s
0 0 0 r
2.5 Mabswid
.59275 1.36205 Mdot
.039 .916 .04 r
.5 Mabswid
.50683 3.74758 m
.57539 1.52116 L
s
0 0 0 r
2.5 Mabswid
.57539 1.52116 Mdot
.039 .916 .04 r
.5 Mabswid
.50614 3.74756 m
.56741 1.52175 L
s
0 0 0 r
2.5 Mabswid
.56741 1.52175 Mdot
.039 .916 .04 r
.5 Mabswid
.50592 3.74756 m
.56489 1.52194 L
s
0 0 0 r
2.5 Mabswid
.56489 1.52194 Mdot
.039 .916 .04 r
.5 Mabswid
.50528 3.74754 m
.55747 1.52249 L
s
0 0 0 r
2.5 Mabswid
.55747 1.52249 Mdot
.039 .916 .04 r
.5 Mabswid
.50457 3.74752 m
.54926 1.52311 L
s
0 0 0 r
2.5 Mabswid
.54926 1.52311 Mdot
.039 .916 .04 r
.5 Mabswid
.50375 3.74751 m
.53982 1.52381 L
s
0 0 0 r
2.5 Mabswid
.53982 1.52381 Mdot
.039 .916 .04 r
.5 Mabswid
.50318 3.7475 m
.53327 1.5243 L
s
0 0 0 r
2.5 Mabswid
.53327 1.5243 Mdot
.039 .916 .04 r
.5 Mabswid
.50225 3.74749 m
.52255 1.5251 L
s
0 0 0 r
2.5 Mabswid
.52255 1.5251 Mdot
.039 .916 .04 r
.5 Mabswid
.50168 3.74749 m
.516 1.52558 L
s
0 0 0 r
2.5 Mabswid
.516 1.52558 Mdot
.039 .916 .04 r
.5 Mabswid
.5015 3.74748 m
.51393 1.52574 L
s
0 0 0 r
2.5 Mabswid
.51393 1.52574 Mdot
.039 .916 .04 r
.5 Mabswid
.50061 3.74748 m
.50367 1.5265 L
s
0 0 0 r
2.5 Mabswid
.50367 1.5265 Mdot
.039 .916 .04 r
.5 Mabswid
.49986 3.74748 m
.49498 1.52715 L
s
0 0 0 r
2.5 Mabswid
.49498 1.52715 Mdot
.039 .916 .04 r
.5 Mabswid
.49967 3.74748 m
.49284 1.52731 L
s
0 0 0 r
2.5 Mabswid
.49284 1.52731 Mdot
.039 .916 .04 r
.5 Mabswid
.49897 3.74749 m
.48481 1.52791 L
s
0 0 0 r
2.5 Mabswid
.48481 1.52791 Mdot
.039 .916 .04 r
.5 Mabswid
.49786 3.7475 m
.47204 1.52886 L
s
0 0 0 r
2.5 Mabswid
.47204 1.52886 Mdot
.039 .916 .04 r
.5 Mabswid
.49752 3.7475 m
.4682 1.52914 L
s
0 0 0 r
2.5 Mabswid
.4682 1.52914 Mdot
.039 .916 .04 r
.5 Mabswid
.49671 3.74751 m
.45882 1.52984 L
s
0 0 0 r
2.5 Mabswid
.45882 1.52984 Mdot
.039 .916 .04 r
.5 Mabswid
.49613 3.74752 m
.45219 1.53034 L
s
0 0 0 r
2.5 Mabswid
.45219 1.53034 Mdot
.039 .916 .04 r
.5 Mabswid
.49543 3.74754 m
.44421 1.53093 L
s
0 0 0 r
2.5 Mabswid
.44421 1.53093 Mdot
.039 .916 .04 r
.5 Mabswid
.49486 3.74755 m
.43758 1.53143 L
s
0 0 0 r
2.5 Mabswid
.43758 1.53143 Mdot
.039 .916 .04 r
.5 Mabswid
.4944 3.74756 m
.43236 1.53181 L
s
0 0 0 r
2.5 Mabswid
.43236 1.53181 Mdot
.039 .916 .04 r
.5 Mabswid
.49389 3.74758 m
.42655 1.53225 L
s
0 0 0 r
2.5 Mabswid
.42655 1.53225 Mdot
.039 .916 .04 r
.5 Mabswid
.49281 3.74761 m
.40845 1.37417 L
s
0 0 0 r
2.5 Mabswid
.40845 1.37417 Mdot
.039 .916 .04 r
.5 Mabswid
.49246 3.74763 m
.40419 1.37445 L
s
0 0 0 r
2.5 Mabswid
.40419 1.37445 Mdot
.039 .916 .04 r
.5 Mabswid
.49174 3.74766 m
.39538 1.37503 L
s
0 0 0 r
2.5 Mabswid
.39538 1.37503 Mdot
.039 .916 .04 r
.5 Mabswid
.49128 3.74767 m
.3898 1.3754 L
s
0 0 0 r
2.5 Mabswid
.3898 1.3754 Mdot
.039 .916 .04 r
.5 Mabswid
.49041 3.74771 m
.37921 1.3761 L
s
0 0 0 r
2.5 Mabswid
.37921 1.3761 Mdot
.039 .916 .04 r
.5 Mabswid
.49007 3.74773 m
.37499 1.37637 L
s
0 0 0 r
2.5 Mabswid
.37499 1.37637 Mdot
.039 .916 .04 r
.5 Mabswid
.48942 3.74776 m
.36705 1.3769 L
s
0 0 0 r
2.5 Mabswid
.36705 1.3769 Mdot
.039 .916 .04 r
.5 Mabswid
.4885 3.74781 m
.35585 1.37763 L
s
0 0 0 r
2.5 Mabswid
.35585 1.37763 Mdot
.039 .916 .04 r
.5 Mabswid
.48756 3.74787 m
.34439 1.37839 L
s
0 0 0 r
2.5 Mabswid
.34439 1.37839 Mdot
.039 .916 .04 r
.5 Mabswid
.48751 3.74787 m
.3437 1.37843 L
s
0 0 0 r
2.5 Mabswid
.3437 1.37843 Mdot
.039 .916 .04 r
.5 Mabswid
.48679 3.74791 m
.32426 1.21301 L
s
0 0 0 r
2.5 Mabswid
.32426 1.21301 Mdot
.039 .916 .04 r
.5 Mabswid
.48605 3.74796 m
.31464 1.2132 L
s
0 0 0 r
2.5 Mabswid
.31464 1.2132 Mdot
.039 .916 .04 r
.5 Mabswid
.48536 3.74801 m
.30568 1.21338 L
s
0 0 0 r
2.5 Mabswid
.30568 1.21338 Mdot
.039 .916 .04 r
.5 Mabswid
.48479 3.74805 m
.29812 1.21353 L
s
0 0 0 r
2.5 Mabswid
.29812 1.21353 Mdot
.039 .916 .04 r
.5 Mabswid
.48425 3.74809 m
.29115 1.21366 L
s
0 0 0 r
2.5 Mabswid
.29115 1.21366 Mdot
.039 .916 .04 r
.5 Mabswid
.48357 3.74815 m
.28229 1.21384 L
s
0 0 0 r
2.5 Mabswid
.28229 1.21384 Mdot
.039 .916 .04 r
.5 Mabswid
.48272 3.74821 m
.27113 1.21406 L
s
0 0 0 r
2.5 Mabswid
.27113 1.21406 Mdot
.039 .916 .04 r
.5 Mabswid
.48184 3.74829 m
.24726 1.0735 L
s
0 0 0 r
2.5 Mabswid
.24726 1.0735 Mdot
.039 .916 .04 r
.5 Mabswid
.48148 3.74832 m
.24236 1.07393 L
s
0 0 0 r
2.5 Mabswid
.24236 1.07393 Mdot
.039 .916 .04 r
.5 Mabswid
.48075 3.74839 m
.23226 1.07484 L
s
0 0 0 r
2.5 Mabswid
.23226 1.07484 Mdot
.039 .916 .04 r
.5 Mabswid
.47995 3.74846 m
.22136 1.07581 L
s
0 0 0 r
2.5 Mabswid
.22136 1.07581 Mdot
.039 .916 .04 r
.5 Mabswid
.47965 3.74849 m
.21717 1.07618 L
s
0 0 0 r
2.5 Mabswid
.21717 1.07618 Mdot
.039 .916 .04 r
.5 Mabswid
.47911 3.74855 m
.20978 1.07684 L
s
0 0 0 r
2.5 Mabswid
.20978 1.07684 Mdot
.039 .916 .04 r
.5 Mabswid
.47824 3.74864 m
.1979 1.07791 L
s
0 0 0 r
2.5 Mabswid
.1979 1.07791 Mdot
.039 .916 .04 r
.5 Mabswid
.47789 3.74867 m
.19306 1.07834 L
s
0 0 0 r
2.5 Mabswid
.19306 1.07834 Mdot
.039 .916 .04 r
.5 Mabswid
.4773 3.74874 m
.18494 1.07906 L
s
0 0 0 r
2.5 Mabswid
.18494 1.07906 Mdot
.039 .916 .04 r
.5 Mabswid
.47621 3.74886 m
.15029 .90831 L
s
0 0 0 r
2.5 Mabswid
.15029 .90831 Mdot
.039 .916 .04 r
.5 Mabswid
.4758 3.74891 m
.14423 .90859 L
s
0 0 0 r
2.5 Mabswid
.14423 .90859 Mdot
.039 .916 .04 r
.5 Mabswid
.47504 3.749 m
.13317 .9091 L
s
0 0 0 r
2.5 Mabswid
.13317 .9091 Mdot
.039 .916 .04 r
.5 Mabswid
.47479 3.74903 m
.12951 .90927 L
s
0 0 0 r
2.5 Mabswid
.12951 .90927 Mdot
.039 .916 .04 r
.5 Mabswid
.47372 3.74916 m
.11383 .90999 L
s
0 0 0 r
2.5 Mabswid
.11383 .90999 Mdot
.039 .916 .04 r
.5 Mabswid
.47358 3.74918 m
.11178 .91008 L
s
0 0 0 r
2.5 Mabswid
.11178 .91008 Mdot
.039 .916 .04 r
.5 Mabswid
.4725 3.74932 m
.07376 .74421 L
s
0 0 0 r
2.5 Mabswid
.07376 .74421 Mdot
.039 .916 .04 r
.5 Mabswid
.47231 3.74934 m
.07077 .74428 L
s
0 0 0 r
2.5 Mabswid
.07077 .74428 Mdot
.039 .916 .04 r
.5 Mabswid
.47132 3.74948 m
.05545 .74466 L
s
0 0 0 r
2.5 Mabswid
.05545 .74466 Mdot
.039 .916 .04 r
.5 Mabswid
.47066 3.74957 m
.04511 .74492 L
s
0 0 0 r
2.5 Mabswid
.04511 .74492 Mdot
.039 .916 .04 r
.5 Mabswid
.47025 3.74963 m
.03875 .74508 L
s
0 0 0 r
2.5 Mabswid
.03875 .74508 Mdot
.039 .916 .04 r
.5 Mabswid
.46939 3.74976 m
.02519 .74541 L
s
0 0 0 r
2.5 Mabswid
.02519 .74541 Mdot
.039 .916 .04 r
.5 Mabswid
.95504 .72236 m
.95728 .70643 L
s
0 0 0 r
2.5 Mabswid
.95728 .70643 Mdot
.039 .916 .04 r
.5 Mabswid
.94709 .72256 m
.94929 .70663 L
s
0 0 0 r
2.5 Mabswid
.94929 .70663 Mdot
.039 .916 .04 r
.5 Mabswid
.93885 .72276 m
.94101 .70683 L
s
0 0 0 r
2.5 Mabswid
.94101 .70683 Mdot
.039 .916 .04 r
.5 Mabswid
.92296 .72316 m
.92504 .70723 L
s
0 0 0 r
2.5 Mabswid
.92504 .70723 Mdot
.039 .916 .04 r
.5 Mabswid
.91722 .7233 m
.91927 .70737 L
s
0 0 0 r
2.5 Mabswid
.91927 .70737 Mdot
.039 .916 .04 r
.5 Mabswid
.88838 .87446 m
.89039 .85848 L
s
0 0 0 r
2.5 Mabswid
.89039 .85848 Mdot
.039 .916 .04 r
.5 Mabswid
.86916 .87534 m
.87107 .85937 L
s
0 0 0 r
2.5 Mabswid
.87107 .85937 Mdot
.039 .916 .04 r
.5 Mabswid
.85551 .87596 m
.85735 .86 L
s
0 0 0 r
2.5 Mabswid
.85735 .86 Mdot
.039 .916 .04 r
.5 Mabswid
.85478 .876 m
.85662 .86003 L
s
0 0 0 r
2.5 Mabswid
.85662 .86003 Mdot
.039 .916 .04 r
.5 Mabswid
.80669 1.0235 m
.80837 1.00742 L
s
0 0 0 r
2.5 Mabswid
.80837 1.00742 Mdot
.039 .916 .04 r
.5 Mabswid
.77586 1.02626 m
.77737 1.01019 L
s
0 0 0 r
2.5 Mabswid
.77737 1.01019 Mdot
.039 .916 .04 r
.5 Mabswid
.73632 1.20481 m
.73769 1.18886 L
s
0 0 0 r
2.5 Mabswid
.73769 1.18886 Mdot
.039 .916 .04 r
.5 Mabswid
.72149 1.20511 m
.72277 1.18916 L
s
0 0 0 r
2.5 Mabswid
.72277 1.18916 Mdot
.039 .916 .04 r
.5 Mabswid
.71316 1.20527 m
.71439 1.18932 L
s
0 0 0 r
2.5 Mabswid
.71439 1.18932 Mdot
.039 .916 .04 r
.5 Mabswid
.70067 1.20552 m
.70183 1.18957 L
s
0 0 0 r
2.5 Mabswid
.70183 1.18957 Mdot
.039 .916 .04 r
.5 Mabswid
.66961 1.20614 m
.6706 1.19019 L
s
0 0 0 r
2.5 Mabswid
.6706 1.19019 Mdot
.039 .916 .04 r
.5 Mabswid
.6551 1.35794 m
.65605 1.34193 L
s
0 0 0 r
2.5 Mabswid
.65605 1.34193 Mdot
.039 .916 .04 r
.5 Mabswid
.64707 1.35847 m
.64797 1.34246 L
s
0 0 0 r
2.5 Mabswid
.64797 1.34246 Mdot
.039 .916 .04 r
.5 Mabswid
.63767 1.35909 m
.63852 1.34309 L
s
0 0 0 r
2.5 Mabswid
.63852 1.34309 Mdot
.039 .916 .04 r
.5 Mabswid
.63255 1.35943 m
.63336 1.34342 L
s
0 0 0 r
2.5 Mabswid
.63336 1.34342 Mdot
.039 .916 .04 r
.5 Mabswid
.61975 1.36027 m
.62049 1.34427 L
s
0 0 0 r
2.5 Mabswid
.62049 1.34427 Mdot
.039 .916 .04 r
.5 Mabswid
.61531 1.36056 m
.61601 1.34457 L
s
0 0 0 r
2.5 Mabswid
.61601 1.34457 Mdot
.039 .916 .04 r
.5 Mabswid
.60654 1.36114 m
.60719 1.34515 L
s
0 0 0 r
2.5 Mabswid
.60719 1.34515 Mdot
.039 .916 .04 r
.5 Mabswid
.59558 1.36186 m
.59617 1.34587 L
s
0 0 0 r
2.5 Mabswid
.59617 1.34587 Mdot
.039 .916 .04 r
.5 Mabswid
.56489 1.52194 m
.56531 1.50598 L
s
0 0 0 r
2.5 Mabswid
.56531 1.50598 Mdot
.039 .916 .04 r
.5 Mabswid
.53982 1.52381 m
.54008 1.50786 L
s
0 0 0 r
2.5 Mabswid
.54008 1.50786 Mdot
.039 .916 .04 r
.5 Mabswid
.53327 1.5243 m
.53349 1.50835 L
s
0 0 0 r
2.5 Mabswid
.53349 1.50835 Mdot
.039 .916 .04 r
.5 Mabswid
.50367 1.5265 m
.50369 1.51057 L
s
0 0 0 r
2.5 Mabswid
.50369 1.51057 Mdot
.039 .916 .04 r
.5 Mabswid
.49498 1.52715 m
.49494 1.51122 L
s
0 0 0 r
2.5 Mabswid
.49494 1.51122 Mdot
.039 .916 .04 r
.5 Mabswid
.49284 1.52731 m
.49279 1.51138 L
s
0 0 0 r
2.5 Mabswid
.49279 1.51138 Mdot
.039 .916 .04 r
.5 Mabswid
.47204 1.52886 m
.47186 1.51294 L
s
0 0 0 r
2.5 Mabswid
.47186 1.51294 Mdot
.039 .916 .04 r
.5 Mabswid
.4682 1.52914 m
.46799 1.51323 L
s
0 0 0 r
2.5 Mabswid
.46799 1.51323 Mdot
.039 .916 .04 r
.5 Mabswid
.45882 1.52984 m
.45855 1.51393 L
s
0 0 0 r
2.5 Mabswid
.45855 1.51393 Mdot
.039 .916 .04 r
.5 Mabswid
.44421 1.53093 m
.44385 1.51503 L
s
0 0 0 r
2.5 Mabswid
.44385 1.51503 Mdot
.039 .916 .04 r
.5 Mabswid
.43236 1.53181 m
.43191 1.51592 L
s
0 0 0 r
2.5 Mabswid
.43191 1.51592 Mdot
.039 .916 .04 r
.5 Mabswid
.42655 1.53225 m
.42606 1.51635 L
s
0 0 0 r
2.5 Mabswid
.42606 1.51635 Mdot
.039 .916 .04 r
.5 Mabswid
.40845 1.37417 m
.42805 1.50032 L
s
0 0 0 r
2.5 Mabswid
.42805 1.50032 Mdot
.039 .916 .04 r
.5 Mabswid
.40419 1.37445 m
.4036 1.35854 L
s
0 0 0 r
2.5 Mabswid
.4036 1.35854 Mdot
.039 .916 .04 r
.5 Mabswid
.39538 1.37503 m
.42148 1.53269 L
s
0 0 0 r
2.5 Mabswid
.42148 1.53269 Mdot
.039 .916 .04 r
.5 Mabswid
.36705 1.3769 m
.36623 1.361 L
s
0 0 0 r
2.5 Mabswid
.36623 1.361 Mdot
.039 .916 .04 r
.5 Mabswid
.35585 1.37763 m
.35496 1.36174 L
s
0 0 0 r
2.5 Mabswid
.35496 1.36174 Mdot
.039 .916 .04 r
.5 Mabswid
.34439 1.37839 m
.34343 1.3625 L
s
0 0 0 r
2.5 Mabswid
.34343 1.3625 Mdot
.039 .916 .04 r
.5 Mabswid
.3437 1.37843 m
.34273 1.36255 L
s
0 0 0 r
2.5 Mabswid
.34273 1.36255 Mdot
.039 .916 .04 r
.5 Mabswid
.32426 1.21301 m
.32324 1.1971 L
s
0 0 0 r
2.5 Mabswid
.32324 1.1971 Mdot
.039 .916 .04 r
.5 Mabswid
.31464 1.2132 m
.34215 1.36261 L
s
0 0 0 r
2.5 Mabswid
.34215 1.36261 Mdot
.039 .916 .04 r
.5 Mabswid
.29812 1.21353 m
.29695 1.19763 L
s
0 0 0 r
2.5 Mabswid
.29695 1.19763 Mdot
.039 .916 .04 r
.5 Mabswid
.28229 1.21384 m
.28102 1.19794 L
s
0 0 0 r
2.5 Mabswid
.28102 1.19794 Mdot
.039 .916 .04 r
.5 Mabswid
.27113 1.21406 m
.2698 1.19817 L
s
0 0 0 r
2.5 Mabswid
.2698 1.19817 Mdot
.039 .916 .04 r
.5 Mabswid
.24726 1.0735 m
.24588 1.05769 L
s
0 0 0 r
2.5 Mabswid
.24588 1.05769 Mdot
.039 .916 .04 r
.5 Mabswid
.24236 1.07393 m
.26231 1.18238 L
s
0 0 0 r
2.5 Mabswid
.26231 1.18238 Mdot
.039 .916 .04 r
.5 Mabswid
.22136 1.07581 m
.21984 1.06002 L
s
0 0 0 r
2.5 Mabswid
.21984 1.06002 Mdot
.039 .916 .04 r
.5 Mabswid
.20978 1.07684 m
.20819 1.06106 L
s
0 0 0 r
2.5 Mabswid
.20819 1.06106 Mdot
.039 .916 .04 r
.5 Mabswid
.18494 1.07906 m
.18321 1.06329 L
s
0 0 0 r
2.5 Mabswid
.18321 1.06329 Mdot
.039 .916 .04 r
.5 Mabswid
.15029 .90831 m
.18497 1.07909 L
s
0 0 0 r
2.5 Mabswid
.18497 1.07909 Mdot
.039 .916 .04 r
.5 Mabswid
.14423 .90859 m
.14239 .8928 L
s
0 0 0 r
2.5 Mabswid
.14239 .8928 Mdot
.039 .916 .04 r
.5 Mabswid
.12951 .90927 m
.12759 .89348 L
s
0 0 0 r
2.5 Mabswid
.12759 .89348 Mdot
.039 .916 .04 r
.5 Mabswid
.11383 .90999 m
.11182 .8942 L
s
0 0 0 r
2.5 Mabswid
.11182 .8942 Mdot
.039 .916 .04 r
.5 Mabswid
.11178 .91008 m
.10977 .89429 L
s
0 0 0 r
2.5 Mabswid
.10977 .89429 Mdot
.039 .916 .04 r
.5 Mabswid
.07376 .74421 m
.07166 .72838 L
s
0 0 0 r
2.5 Mabswid
.07166 .72838 Mdot
.039 .916 .04 r
.5 Mabswid
.07077 .74428 m
.06865 .72846 L
s
0 0 0 r
2.5 Mabswid
.06865 .72846 Mdot
.039 .916 .04 r
.5 Mabswid
.05545 .74466 m
.05326 .72884 L
s
0 0 0 r
2.5 Mabswid
.05326 .72884 Mdot
.039 .916 .04 r
.5 Mabswid
.04511 .74492 m
.04287 .7291 L
s
0 0 0 r
2.5 Mabswid
.04287 .7291 Mdot
.039 .916 .04 r
.5 Mabswid
.03875 .74508 m
.03648 .72926 L
s
0 0 0 r
2.5 Mabswid
.03648 .72926 Mdot
.039 .916 .04 r
.5 Mabswid
.95728 .70643 m
.95951 .6905 L
s
0 0 0 r
2.5 Mabswid
.95951 .6905 Mdot
.039 .916 .04 r
.5 Mabswid
.94929 .70663 m
.95149 .6907 L
s
0 0 0 r
2.5 Mabswid
.95149 .6907 Mdot
.039 .916 .04 r
.5 Mabswid
.94101 .70683 m
.94317 .6909 L
s
0 0 0 r
2.5 Mabswid
.94317 .6909 Mdot
.039 .916 .04 r
.5 Mabswid
.92504 .70723 m
.92712 .6913 L
s
0 0 0 r
2.5 Mabswid
.92712 .6913 Mdot
.039 .916 .04 r
.5 Mabswid
.91927 .70737 m
.92133 .69144 L
s
0 0 0 r
2.5 Mabswid
.92133 .69144 Mdot
.039 .916 .04 r
.5 Mabswid
.89039 .85848 m
.8924 .84251 L
s
0 0 0 r
2.5 Mabswid
.8924 .84251 Mdot
.039 .916 .04 r
.5 Mabswid
.87107 .85937 m
.87298 .8434 L
s
0 0 0 r
2.5 Mabswid
.87298 .8434 Mdot
.039 .916 .04 r
.5 Mabswid
.85735 .86 m
.85919 .84404 L
s
0 0 0 r
2.5 Mabswid
.85919 .84404 Mdot
.039 .916 .04 r
.5 Mabswid
.85662 .86003 m
.85845 .84407 L
s
0 0 0 r
2.5 Mabswid
.85845 .84407 Mdot
.039 .916 .04 r
.5 Mabswid
.80837 1.00742 m
.81004 .99134 L
s
0 0 0 r
2.5 Mabswid
.81004 .99134 Mdot
.039 .916 .04 r
.5 Mabswid
.77737 1.01019 m
.77888 .99413 L
s
0 0 0 r
2.5 Mabswid
.77888 .99413 Mdot
.039 .916 .04 r
.5 Mabswid
.73769 1.18886 m
.75143 1.02844 L
s
0 0 0 r
2.5 Mabswid
.75143 1.02844 Mdot
.039 .916 .04 r
.5 Mabswid
.72277 1.18916 m
.72405 1.17321 L
s
0 0 0 r
2.5 Mabswid
.72405 1.17321 Mdot
.039 .916 .04 r
.5 Mabswid
.71439 1.18932 m
.71562 1.17337 L
s
0 0 0 r
2.5 Mabswid
.71562 1.17337 Mdot
.039 .916 .04 r
.5 Mabswid
.70183 1.18957 m
.70299 1.17363 L
s
0 0 0 r
2.5 Mabswid
.70299 1.17363 Mdot
.039 .916 .04 r
.5 Mabswid
.6706 1.19019 m
.67158 1.17425 L
s
0 0 0 r
2.5 Mabswid
.67158 1.17425 Mdot
.039 .916 .04 r
.5 Mabswid
.65605 1.34193 m
.66413 1.20625 L
s
0 0 0 r
2.5 Mabswid
.66413 1.20625 Mdot
.039 .916 .04 r
.5 Mabswid
.64797 1.34246 m
.64888 1.32645 L
s
0 0 0 r
2.5 Mabswid
.64888 1.32645 Mdot
.039 .916 .04 r
.5 Mabswid
.63852 1.34309 m
.63937 1.32708 L
s
0 0 0 r
2.5 Mabswid
.63937 1.32708 Mdot
.039 .916 .04 r
.5 Mabswid
.63336 1.34342 m
.63417 1.32742 L
s
0 0 0 r
2.5 Mabswid
.63417 1.32742 Mdot
.039 .916 .04 r
.5 Mabswid
.62049 1.34427 m
.62122 1.32827 L
s
0 0 0 r
2.5 Mabswid
.62122 1.32827 Mdot
.039 .916 .04 r
.5 Mabswid
.61601 1.34457 m
.61672 1.32857 L
s
0 0 0 r
2.5 Mabswid
.61672 1.32857 Mdot
.039 .916 .04 r
.5 Mabswid
.60719 1.34515 m
.60785 1.32915 L
s
0 0 0 r
2.5 Mabswid
.60785 1.32915 Mdot
.039 .916 .04 r
.5 Mabswid
.59617 1.34587 m
.59675 1.32988 L
s
0 0 0 r
2.5 Mabswid
.59675 1.32988 Mdot
.039 .916 .04 r
.5 Mabswid
.56531 1.50598 m
.56574 1.49002 L
s
0 0 0 r
2.5 Mabswid
.56574 1.49002 Mdot
.039 .916 .04 r
.5 Mabswid
.54008 1.50786 m
.54034 1.49191 L
s
0 0 0 r
2.5 Mabswid
.54034 1.49191 Mdot
.039 .916 .04 r
.5 Mabswid
.53349 1.50835 m
.5337 1.49241 L
s
0 0 0 r
2.5 Mabswid
.5337 1.49241 Mdot
.039 .916 .04 r
.5 Mabswid
.50369 1.51057 m
.50371 1.49464 L
s
0 0 0 r
2.5 Mabswid
.50371 1.49464 Mdot
.039 .916 .04 r
.5 Mabswid
.49494 1.51122 m
.49491 1.4953 L
s
0 0 0 r
2.5 Mabswid
.49491 1.4953 Mdot
.039 .916 .04 r
.5 Mabswid
.49279 1.51138 m
.49274 1.49546 L
s
0 0 0 r
2.5 Mabswid
.49274 1.49546 Mdot
.039 .916 .04 r
.5 Mabswid
.47186 1.51294 m
.47167 1.49703 L
s
0 0 0 r
2.5 Mabswid
.47167 1.49703 Mdot
.039 .916 .04 r
.5 Mabswid
.46799 1.51323 m
.46778 1.49732 L
s
0 0 0 r
2.5 Mabswid
.46778 1.49732 Mdot
.039 .916 .04 r
.5 Mabswid
.45855 1.51393 m
.45828 1.49803 L
s
0 0 0 r
2.5 Mabswid
.45828 1.49803 Mdot
.039 .916 .04 r
.5 Mabswid
.44385 1.51503 m
.44348 1.49913 L
s
0 0 0 r
2.5 Mabswid
.44348 1.49913 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 1.51592 m
.43147 1.50002 L
s
0 0 0 r
2.5 Mabswid
.43147 1.50002 Mdot
.039 .916 .04 r
.5 Mabswid
.42606 1.51635 m
.42558 1.50046 L
s
0 0 0 r
2.5 Mabswid
.42558 1.50046 Mdot
.039 .916 .04 r
.5 Mabswid
.42805 1.50032 m
.42908 1.37399 L
s
0 0 0 r
2.5 Mabswid
.42908 1.37399 Mdot
.039 .916 .04 r
.5 Mabswid
.4036 1.35854 m
.40301 1.34263 L
s
0 0 0 r
2.5 Mabswid
.40301 1.34263 Mdot
.039 .916 .04 r
.5 Mabswid
.36623 1.361 m
.36541 1.3451 L
s
0 0 0 r
2.5 Mabswid
.36541 1.3451 Mdot
.039 .916 .04 r
.5 Mabswid
.35496 1.36174 m
.35407 1.34585 L
s
0 0 0 r
2.5 Mabswid
.35407 1.34585 Mdot
.039 .916 .04 r
.5 Mabswid
.34343 1.3625 m
.34247 1.34661 L
s
0 0 0 r
2.5 Mabswid
.34247 1.34661 Mdot
.039 .916 .04 r
.5 Mabswid
.34273 1.36255 m
.34177 1.34666 L
s
0 0 0 r
2.5 Mabswid
.34177 1.34666 Mdot
.039 .916 .04 r
.5 Mabswid
.32324 1.1971 m
.32222 1.1812 L
s
0 0 0 r
2.5 Mabswid
.32222 1.1812 Mdot
.039 .916 .04 r
.5 Mabswid
.34215 1.36261 m
.34506 1.37837 L
s
0 0 0 r
2.5 Mabswid
.34506 1.37837 Mdot
.039 .916 .04 r
.5 Mabswid
.29695 1.19763 m
.29578 1.18172 L
s
0 0 0 r
2.5 Mabswid
.29578 1.18172 Mdot
.039 .916 .04 r
.5 Mabswid
.28102 1.19794 m
.27976 1.18204 L
s
0 0 0 r
2.5 Mabswid
.27976 1.18204 Mdot
.039 .916 .04 r
.5 Mabswid
.2698 1.19817 m
.26847 1.18227 L
s
0 0 0 r
2.5 Mabswid
.26847 1.18227 Mdot
.039 .916 .04 r
.5 Mabswid
.24588 1.05769 m
.24449 1.04188 L
s
0 0 0 r
2.5 Mabswid
.24449 1.04188 Mdot
.039 .916 .04 r
.5 Mabswid
.26231 1.18238 m
.26523 1.19824 L
s
0 0 0 r
2.5 Mabswid
.26523 1.19824 Mdot
.039 .916 .04 r
.5 Mabswid
.21984 1.06002 m
.21831 1.04422 L
s
0 0 0 r
2.5 Mabswid
.21831 1.04422 Mdot
.039 .916 .04 r
.5 Mabswid
.20819 1.06106 m
.2066 1.04527 L
s
0 0 0 r
2.5 Mabswid
.2066 1.04527 Mdot
.039 .916 .04 r
.5 Mabswid
.18321 1.06329 m
.16616 .90759 L
s
0 0 0 r
2.5 Mabswid
.16616 .90759 Mdot
.039 .916 .04 r
.5 Mabswid
.14239 .8928 m
.14054 .877 L
s
0 0 0 r
2.5 Mabswid
.14054 .877 Mdot
.039 .916 .04 r
.5 Mabswid
.12759 .89348 m
.12567 .87769 L
s
0 0 0 r
2.5 Mabswid
.12567 .87769 Mdot
.039 .916 .04 r
.5 Mabswid
.11182 .8942 m
.10982 .87841 L
s
0 0 0 r
2.5 Mabswid
.10982 .87841 Mdot
.039 .916 .04 r
.5 Mabswid
.10977 .89429 m
.10776 .87851 L
s
0 0 0 r
2.5 Mabswid
.10776 .87851 Mdot
.039 .916 .04 r
.5 Mabswid
.07166 .72838 m
.06956 .71256 L
s
0 0 0 r
2.5 Mabswid
.06956 .71256 Mdot
.039 .916 .04 r
.5 Mabswid
.06865 .72846 m
.06654 .71263 L
s
0 0 0 r
2.5 Mabswid
.06654 .71263 Mdot
.039 .916 .04 r
.5 Mabswid
.05326 .72884 m
.05107 .71302 L
s
0 0 0 r
2.5 Mabswid
.05107 .71302 Mdot
.039 .916 .04 r
.5 Mabswid
.04287 .7291 m
.04063 .71328 L
s
0 0 0 r
2.5 Mabswid
.04063 .71328 Mdot
.039 .916 .04 r
.5 Mabswid
.03648 .72926 m
.03421 .71344 L
s
0 0 0 r
2.5 Mabswid
.03421 .71344 Mdot
.039 .916 .04 r
.5 Mabswid
.8924 .84251 m
.90737 .72354 L
s
0 0 0 r
2.5 Mabswid
.90737 .72354 Mdot
.039 .916 .04 r
.5 Mabswid
.87298 .8434 m
.88725 .72404 L
s
0 0 0 r
2.5 Mabswid
.88725 .72404 Mdot
.039 .916 .04 r
.5 Mabswid
.85919 .84404 m
.87297 .7244 L
s
0 0 0 r
2.5 Mabswid
.87297 .7244 Mdot
.039 .916 .04 r
.5 Mabswid
.85845 .84407 m
.87221 .72441 L
s
0 0 0 r
2.5 Mabswid
.87221 .72441 Mdot
.039 .916 .04 r
.5 Mabswid
.81004 .99134 m
.82193 .8775 L
s
0 0 0 r
2.5 Mabswid
.82193 .8775 Mdot
.039 .916 .04 r
.5 Mabswid
.77888 .99413 m
.7897 .87898 L
s
0 0 0 r
2.5 Mabswid
.7897 .87898 Mdot
.039 .916 .04 r
.5 Mabswid
.75143 1.02844 m
.75281 1.01239 L
s
0 0 0 r
2.5 Mabswid
.75281 1.01239 Mdot
.039 .916 .04 r
.5 Mabswid
.72405 1.17321 m
.72595 1.18887 L
s
0 0 0 r
2.5 Mabswid
.72595 1.18887 Mdot
.039 .916 .04 r
.5 Mabswid
.71562 1.17337 m
.72665 1.03065 L
s
0 0 0 r
2.5 Mabswid
.72665 1.03065 Mdot
.039 .916 .04 r
.5 Mabswid
.70299 1.17363 m
.71331 1.03185 L
s
0 0 0 r
2.5 Mabswid
.71331 1.03185 Mdot
.039 .916 .04 r
.5 Mabswid
.67158 1.17425 m
.68015 1.03481 L
s
0 0 0 r
2.5 Mabswid
.68015 1.03481 Mdot
.039 .916 .04 r
.5 Mabswid
.64888 1.32645 m
.65565 1.20642 L
s
0 0 0 r
2.5 Mabswid
.65565 1.20642 Mdot
.039 .916 .04 r
.5 Mabswid
.63937 1.32708 m
.64573 1.20661 L
s
0 0 0 r
2.5 Mabswid
.64573 1.20661 Mdot
.039 .916 .04 r
.5 Mabswid
.63417 1.32742 m
.637 1.34297 L
s
0 0 0 r
2.5 Mabswid
.637 1.34297 Mdot
.039 .916 .04 r
.5 Mabswid
.62122 1.32827 m
.6268 1.20699 L
s
0 0 0 r
2.5 Mabswid
.6268 1.20699 Mdot
.039 .916 .04 r
.5 Mabswid
.61672 1.32857 m
.6221 1.20708 L
s
0 0 0 r
2.5 Mabswid
.6221 1.20708 Mdot
.039 .916 .04 r
.5 Mabswid
.60785 1.32915 m
.61059 1.34472 L
s
0 0 0 r
2.5 Mabswid
.61059 1.34472 Mdot
.039 .916 .04 r
.5 Mabswid
.59675 1.32988 m
.60124 1.2075 L
s
0 0 0 r
2.5 Mabswid
.60124 1.2075 Mdot
.039 .916 .04 r
.5 Mabswid
.56574 1.49002 m
.56909 1.3636 L
s
0 0 0 r
2.5 Mabswid
.56909 1.3636 Mdot
.039 .916 .04 r
.5 Mabswid
.54034 1.49191 m
.54239 1.36536 L
s
0 0 0 r
2.5 Mabswid
.54239 1.36536 Mdot
.039 .916 .04 r
.5 Mabswid
.5337 1.49241 m
.53542 1.36582 L
s
0 0 0 r
2.5 Mabswid
.53542 1.36582 Mdot
.039 .916 .04 r
.5 Mabswid
.50371 1.49464 m
.50389 1.36789 L
s
0 0 0 r
2.5 Mabswid
.50389 1.36789 Mdot
.039 .916 .04 r
.5 Mabswid
.49491 1.4953 m
.49463 1.3685 L
s
0 0 0 r
2.5 Mabswid
.49463 1.3685 Mdot
.039 .916 .04 r
.5 Mabswid
.49274 1.49546 m
.49235 1.36865 L
s
0 0 0 r
2.5 Mabswid
.49235 1.36865 Mdot
.039 .916 .04 r
.5 Mabswid
.47167 1.49703 m
.4702 1.37011 L
s
0 0 0 r
2.5 Mabswid
.4702 1.37011 Mdot
.039 .916 .04 r
.5 Mabswid
.46778 1.49732 m
.4661 1.37038 L
s
0 0 0 r
2.5 Mabswid
.4661 1.37038 Mdot
.039 .916 .04 r
.5 Mabswid
.45828 1.49803 m
.45611 1.37104 L
s
0 0 0 r
2.5 Mabswid
.45611 1.37104 Mdot
.039 .916 .04 r
.5 Mabswid
.44348 1.49913 m
.44537 1.51483 L
s
0 0 0 r
2.5 Mabswid
.44537 1.51483 Mdot
.039 .916 .04 r
.5 Mabswid
.43147 1.50002 m
.42791 1.37289 L
s
0 0 0 r
2.5 Mabswid
.42791 1.37289 Mdot
.039 .916 .04 r
.5 Mabswid
.42558 1.50046 m
.42171 1.3733 L
s
0 0 0 r
2.5 Mabswid
.42171 1.3733 Mdot
.039 .916 .04 r
.5 Mabswid
.42908 1.37399 m
.44808 1.49955 L
s
0 0 0 r
2.5 Mabswid
.44808 1.49955 Mdot
.039 .916 .04 r
.5 Mabswid
.40301 1.34263 m
.39813 1.21154 L
s
0 0 0 r
2.5 Mabswid
.39813 1.21154 Mdot
.039 .916 .04 r
.5 Mabswid
.36541 1.3451 m
.35856 1.21232 L
s
0 0 0 r
2.5 Mabswid
.35856 1.21232 Mdot
.039 .916 .04 r
.5 Mabswid
.35407 1.34585 m
.34661 1.21256 L
s
0 0 0 r
2.5 Mabswid
.34661 1.21256 Mdot
.039 .916 .04 r
.5 Mabswid
.34247 1.34661 m
.33439 1.2128 L
s
0 0 0 r
2.5 Mabswid
.33439 1.2128 Mdot
.039 .916 .04 r
.5 Mabswid
.34177 1.34666 m
.34276 1.36232 L
s
0 0 0 r
2.5 Mabswid
.34276 1.36232 Mdot
.039 .916 .04 r
.5 Mabswid
.32222 1.1812 m
.31493 1.06745 L
s
0 0 0 r
2.5 Mabswid
.31493 1.06745 Mdot
.039 .916 .04 r
.5 Mabswid
.29578 1.18172 m
.28754 1.0699 L
s
0 0 0 r
2.5 Mabswid
.28754 1.0699 Mdot
.039 .916 .04 r
.5 Mabswid
.27976 1.18204 m
.27097 1.07138 L
s
0 0 0 r
2.5 Mabswid
.27097 1.07138 Mdot
.039 .916 .04 r
.5 Mabswid
.26847 1.18227 m
.2593 1.07242 L
s
0 0 0 r
2.5 Mabswid
.2593 1.07242 Mdot
.039 .916 .04 r
.5 Mabswid
.24449 1.04188 m
.24578 1.05768 L
s
0 0 0 r
2.5 Mabswid
.24578 1.05768 Mdot
.039 .916 .04 r
.5 Mabswid
.26523 1.19824 m
.26815 1.21411 L
s
0 0 0 r
2.5 Mabswid
.26815 1.21411 Mdot
.039 .916 .04 r
.5 Mabswid
.21831 1.04422 m
.20492 .90581 L
s
0 0 0 r
2.5 Mabswid
.20492 .90581 Mdot
.039 .916 .04 r
.5 Mabswid
.2066 1.04527 m
.1926 .90637 L
s
0 0 0 r
2.5 Mabswid
.1926 .90637 Mdot
.039 .916 .04 r
.5 Mabswid
.16616 .90759 m
.16443 .89179 L
s
0 0 0 r
2.5 Mabswid
.16443 .89179 Mdot
.039 .916 .04 r
.5 Mabswid
.14054 .877 m
.12489 .74294 L
s
0 0 0 r
2.5 Mabswid
.12489 .74294 Mdot
.039 .916 .04 r
.5 Mabswid
.12567 .87769 m
.10934 .74333 L
s
0 0 0 r
2.5 Mabswid
.10934 .74333 Mdot
.039 .916 .04 r
.5 Mabswid
.10982 .87841 m
.09275 .74374 L
s
0 0 0 r
2.5 Mabswid
.09275 .74374 Mdot
.039 .916 .04 r
.5 Mabswid
.10776 .87851 m
.09059 .74379 L
s
0 0 0 r
2.5 Mabswid
.09059 .74379 Mdot
.039 .916 .04 r
.5 Mabswid
.90737 .72354 m
.90937 .70762 L
s
0 0 0 r
2.5 Mabswid
.90937 .70762 Mdot
.039 .916 .04 r
.5 Mabswid
.88725 .72404 m
.88916 .70812 L
s
0 0 0 r
2.5 Mabswid
.88916 .70812 Mdot
.039 .916 .04 r
.5 Mabswid
.87297 .7244 m
.87481 .70847 L
s
0 0 0 r
2.5 Mabswid
.87481 .70847 Mdot
.039 .916 .04 r
.5 Mabswid
.87221 .72441 m
.87071 .84351 L
s
0 0 0 r
2.5 Mabswid
.87071 .84351 Mdot
.039 .916 .04 r
.5 Mabswid
.82193 .8775 m
.82359 .86155 L
s
0 0 0 r
2.5 Mabswid
.82359 .86155 Mdot
.039 .916 .04 r
.5 Mabswid
.7897 .87898 m
.78971 .99314 L
s
0 0 0 r
2.5 Mabswid
.78971 .99314 Mdot
.039 .916 .04 r
.5 Mabswid
.75281 1.01239 m
.75419 .99633 L
s
0 0 0 r
2.5 Mabswid
.75419 .99633 Mdot
.039 .916 .04 r
.5 Mabswid
.72595 1.18887 m
.72784 1.20453 L
s
0 0 0 r
2.5 Mabswid
.72784 1.20453 Mdot
.039 .916 .04 r
.5 Mabswid
.72665 1.03065 m
.72789 1.01461 L
s
0 0 0 r
2.5 Mabswid
.72789 1.01461 Mdot
.039 .916 .04 r
.5 Mabswid
.71331 1.03185 m
.71447 1.01581 L
s
0 0 0 r
2.5 Mabswid
.71447 1.01581 Mdot
.039 .916 .04 r
.5 Mabswid
.68015 1.03481 m
.68528 1.17403 L
s
0 0 0 r
2.5 Mabswid
.68528 1.17403 Mdot
.039 .916 .04 r
.5 Mabswid
.65565 1.20642 m
.65655 1.19047 L
s
0 0 0 r
2.5 Mabswid
.65655 1.19047 Mdot
.039 .916 .04 r
.5 Mabswid
.64573 1.20661 m
.64657 1.19067 L
s
0 0 0 r
2.5 Mabswid
.64657 1.19067 Mdot
.039 .916 .04 r
.5 Mabswid
.637 1.34297 m
.63982 1.35851 L
s
0 0 0 r
2.5 Mabswid
.63982 1.35851 Mdot
.039 .916 .04 r
.5 Mabswid
.6268 1.20699 m
.63401 1.32751 L
s
0 0 0 r
2.5 Mabswid
.63401 1.32751 Mdot
.039 .916 .04 r
.5 Mabswid
.6221 1.20708 m
.6228 1.19114 L
s
0 0 0 r
2.5 Mabswid
.6228 1.19114 Mdot
.039 .916 .04 r
.5 Mabswid
.61059 1.34472 m
.61333 1.36028 L
s
0 0 0 r
2.5 Mabswid
.61333 1.36028 Mdot
.039 .916 .04 r
.5 Mabswid
.60124 1.2075 m
.61095 1.32888 L
s
0 0 0 r
2.5 Mabswid
.61095 1.32888 Mdot
.039 .916 .04 r
.5 Mabswid
.56909 1.3636 m
.56951 1.34763 L
s
0 0 0 r
2.5 Mabswid
.56951 1.34763 Mdot
.039 .916 .04 r
.5 Mabswid
.54239 1.36536 m
.54265 1.34939 L
s
0 0 0 r
2.5 Mabswid
.54265 1.34939 Mdot
.039 .916 .04 r
.5 Mabswid
.53542 1.36582 m
.53563 1.34985 L
s
0 0 0 r
2.5 Mabswid
.53563 1.34985 Mdot
.039 .916 .04 r
.5 Mabswid
.50389 1.36789 m
.50391 1.35194 L
s
0 0 0 r
2.5 Mabswid
.50391 1.35194 Mdot
.039 .916 .04 r
.5 Mabswid
.49463 1.3685 m
.49459 1.35255 L
s
0 0 0 r
2.5 Mabswid
.49459 1.35255 Mdot
.039 .916 .04 r
.5 Mabswid
.49235 1.36865 m
.4923 1.35271 L
s
0 0 0 r
2.5 Mabswid
.4923 1.35271 Mdot
.039 .916 .04 r
.5 Mabswid
.4702 1.37011 m
.47001 1.35417 L
s
0 0 0 r
2.5 Mabswid
.47001 1.35417 Mdot
.039 .916 .04 r
.5 Mabswid
.4661 1.37038 m
.46589 1.35444 L
s
0 0 0 r
2.5 Mabswid
.46589 1.35444 Mdot
.039 .916 .04 r
.5 Mabswid
.45611 1.37104 m
.45584 1.3551 L
s
0 0 0 r
2.5 Mabswid
.45584 1.3551 Mdot
.039 .916 .04 r
.5 Mabswid
.44537 1.51483 m
.44725 1.53053 L
s
0 0 0 r
2.5 Mabswid
.44725 1.53053 Mdot
.039 .916 .04 r
.5 Mabswid
.42791 1.37289 m
.42746 1.35697 L
s
0 0 0 r
2.5 Mabswid
.42746 1.35697 Mdot
.039 .916 .04 r
.5 Mabswid
.42171 1.3733 m
.44127 1.4993 L
s
0 0 0 r
2.5 Mabswid
.44127 1.4993 Mdot
.039 .916 .04 r
.5 Mabswid
.44808 1.49955 m
.45047 1.51531 L
s
0 0 0 r
2.5 Mabswid
.45047 1.51531 Mdot
.039 .916 .04 r
.5 Mabswid
.39813 1.21154 m
.39754 1.19562 L
s
0 0 0 r
2.5 Mabswid
.39754 1.19562 Mdot
.039 .916 .04 r
.5 Mabswid
.35856 1.21232 m
.38083 1.34407 L
s
0 0 0 r
2.5 Mabswid
.38083 1.34407 Mdot
.039 .916 .04 r
.5 Mabswid
.34661 1.21256 m
.36864 1.34485 L
s
0 0 0 r
2.5 Mabswid
.36864 1.34485 Mdot
.039 .916 .04 r
.5 Mabswid
.33439 1.2128 m
.35624 1.34567 L
s
0 0 0 r
2.5 Mabswid
.35624 1.34567 Mdot
.039 .916 .04 r
.5 Mabswid
.34276 1.36232 m
.34376 1.37799 L
s
0 0 0 r
2.5 Mabswid
.34376 1.37799 Mdot
.039 .916 .04 r
.5 Mabswid
.31493 1.06745 m
.334 1.18104 L
s
0 0 0 r
2.5 Mabswid
.334 1.18104 Mdot
.039 .916 .04 r
.5 Mabswid
.28754 1.0699 m
.28638 1.05407 L
s
0 0 0 r
2.5 Mabswid
.28638 1.05407 Mdot
.039 .916 .04 r
.5 Mabswid
.27097 1.07138 m
.26971 1.05556 L
s
0 0 0 r
2.5 Mabswid
.26971 1.05556 Mdot
.039 .916 .04 r
.5 Mabswid
.2593 1.07242 m
.25798 1.05661 L
s
0 0 0 r
2.5 Mabswid
.25798 1.05661 Mdot
.039 .916 .04 r
.5 Mabswid
.24578 1.05768 m
.24707 1.07348 L
s
0 0 0 r
2.5 Mabswid
.24707 1.07348 Mdot
.039 .916 .04 r
.5 Mabswid
.20492 .90581 m
.23272 1.04291 L
s
0 0 0 r
2.5 Mabswid
.23272 1.04291 Mdot
.039 .916 .04 r
.5 Mabswid
.1926 .90637 m
.19101 .89057 L
s
0 0 0 r
2.5 Mabswid
.19101 .89057 Mdot
.039 .916 .04 r
.5 Mabswid
.16443 .89179 m
.1627 .87599 L
s
0 0 0 r
2.5 Mabswid
.1627 .87599 Mdot
.039 .916 .04 r
.5 Mabswid
.12489 .74294 m
.12305 .72711 L
s
0 0 0 r
2.5 Mabswid
.12305 .72711 Mdot
.039 .916 .04 r
.5 Mabswid
.10934 .74333 m
.13793 .87712 L
s
0 0 0 r
2.5 Mabswid
.13793 .87712 Mdot
.039 .916 .04 r
.5 Mabswid
.09275 .74374 m
.09074 .72791 L
s
0 0 0 r
2.5 Mabswid
.09074 .72791 Mdot
.039 .916 .04 r
.5 Mabswid
.09059 .74379 m
.12105 .8779 L
s
0 0 0 r
2.5 Mabswid
.12105 .8779 Mdot
.039 .916 .04 r
.5 Mabswid
.90937 .70762 m
.91138 .69169 L
s
0 0 0 r
2.5 Mabswid
.91138 .69169 Mdot
.039 .916 .04 r
.5 Mabswid
.88916 .70812 m
.89106 .69219 L
s
0 0 0 r
2.5 Mabswid
.89106 .69219 Mdot
.039 .916 .04 r
.5 Mabswid
.87481 .70847 m
.87664 .69255 L
s
0 0 0 r
2.5 Mabswid
.87664 .69255 Mdot
.039 .916 .04 r
.5 Mabswid
.87071 .84351 m
.87051 .8594 L
s
0 0 0 r
2.5 Mabswid
.87051 .8594 Mdot
.039 .916 .04 r
.5 Mabswid
.82359 .86155 m
.82526 .84559 L
s
0 0 0 r
2.5 Mabswid
.82526 .84559 Mdot
.039 .916 .04 r
.5 Mabswid
.78971 .99314 m
.78972 1.00906 L
s
0 0 0 r
2.5 Mabswid
.78972 1.00906 Mdot
.039 .916 .04 r
.5 Mabswid
.75419 .99633 m
.76414 .88015 L
s
0 0 0 r
2.5 Mabswid
.76414 .88015 Mdot
.039 .916 .04 r
.5 Mabswid
.72789 1.01461 m
.72913 .99857 L
s
0 0 0 r
2.5 Mabswid
.72913 .99857 Mdot
.039 .916 .04 r
.5 Mabswid
.71447 1.01581 m
.71564 .99978 L
s
0 0 0 r
2.5 Mabswid
.71564 .99978 Mdot
.039 .916 .04 r
.5 Mabswid
.68528 1.17403 m
.68587 1.18995 L
s
0 0 0 r
2.5 Mabswid
.68587 1.18995 Mdot
.039 .916 .04 r
.5 Mabswid
.65655 1.19047 m
.65745 1.17453 L
s
0 0 0 r
2.5 Mabswid
.65745 1.17453 Mdot
.039 .916 .04 r
.5 Mabswid
.64657 1.19067 m
.64741 1.17473 L
s
0 0 0 r
2.5 Mabswid
.64741 1.17473 Mdot
.039 .916 .04 r
.5 Mabswid
.63401 1.32751 m
.63496 1.34341 L
s
0 0 0 r
2.5 Mabswid
.63496 1.34341 Mdot
.039 .916 .04 r
.5 Mabswid
.6228 1.19114 m
.62351 1.17521 L
s
0 0 0 r
2.5 Mabswid
.62351 1.17521 Mdot
.039 .916 .04 r
.5 Mabswid
.61095 1.32888 m
.61222 1.34474 L
s
0 0 0 r
2.5 Mabswid
.61222 1.34474 Mdot
.039 .916 .04 r
.5 Mabswid
.56951 1.34763 m
.56993 1.33165 L
s
0 0 0 r
2.5 Mabswid
.56993 1.33165 Mdot
.039 .916 .04 r
.5 Mabswid
.54265 1.34939 m
.54291 1.33343 L
s
0 0 0 r
2.5 Mabswid
.54291 1.33343 Mdot
.039 .916 .04 r
.5 Mabswid
.53563 1.34985 m
.53585 1.33389 L
s
0 0 0 r
2.5 Mabswid
.53585 1.33389 Mdot
.039 .916 .04 r
.5 Mabswid
.50391 1.35194 m
.50393 1.33599 L
s
0 0 0 r
2.5 Mabswid
.50393 1.33599 Mdot
.039 .916 .04 r
.5 Mabswid
.49459 1.35255 m
.49456 1.33661 L
s
0 0 0 r
2.5 Mabswid
.49456 1.33661 Mdot
.039 .916 .04 r
.5 Mabswid
.4923 1.35271 m
.49225 1.33676 L
s
0 0 0 r
2.5 Mabswid
.49225 1.33676 Mdot
.039 .916 .04 r
.5 Mabswid
.47001 1.35417 m
.46982 1.33823 L
s
0 0 0 r
2.5 Mabswid
.46982 1.33823 Mdot
.039 .916 .04 r
.5 Mabswid
.46589 1.35444 m
.46568 1.33851 L
s
0 0 0 r
2.5 Mabswid
.46568 1.33851 Mdot
.039 .916 .04 r
.5 Mabswid
.45584 1.3551 m
.45557 1.33917 L
s
0 0 0 r
2.5 Mabswid
.45557 1.33917 Mdot
.039 .916 .04 r
.5 Mabswid
.42746 1.35697 m
.42701 1.34105 L
s
0 0 0 r
2.5 Mabswid
.42701 1.34105 Mdot
.039 .916 .04 r
.5 Mabswid
.44127 1.4993 m
.44371 1.51504 L
s
0 0 0 r
2.5 Mabswid
.44371 1.51504 Mdot
.039 .916 .04 r
.5 Mabswid
.45047 1.51531 m
.45285 1.53106 L
s
0 0 0 r
2.5 Mabswid
.45285 1.53106 Mdot
.039 .916 .04 r
.5 Mabswid
.39754 1.19562 m
.39695 1.17971 L
s
0 0 0 r
2.5 Mabswid
.39695 1.17971 Mdot
.039 .916 .04 r
.5 Mabswid
.38083 1.34407 m
.38349 1.35984 L
s
0 0 0 r
2.5 Mabswid
.38349 1.35984 Mdot
.039 .916 .04 r
.5 Mabswid
.36864 1.34485 m
.37396 1.21016 L
s
0 0 0 r
2.5 Mabswid
.37396 1.21016 Mdot
.039 .916 .04 r
.5 Mabswid
.35624 1.34567 m
.35884 1.36144 L
s
0 0 0 r
2.5 Mabswid
.35884 1.36144 Mdot
.039 .916 .04 r
.5 Mabswid
.334 1.18104 m
.33666 1.19692 L
s
0 0 0 r
2.5 Mabswid
.33666 1.19692 Mdot
.039 .916 .04 r
.5 Mabswid
.28638 1.05407 m
.28521 1.03824 L
s
0 0 0 r
2.5 Mabswid
.28521 1.03824 Mdot
.039 .916 .04 r
.5 Mabswid
.26971 1.05556 m
.26846 1.03974 L
s
0 0 0 r
2.5 Mabswid
.26846 1.03974 Mdot
.039 .916 .04 r
.5 Mabswid
.25798 1.05661 m
.25666 1.04079 L
s
0 0 0 r
2.5 Mabswid
.25666 1.04079 Mdot
.039 .916 .04 r
.5 Mabswid
.24707 1.07348 m
.26754 1.18211 L
s
0 0 0 r
2.5 Mabswid
.26754 1.18211 Mdot
.039 .916 .04 r
.5 Mabswid
.23272 1.04291 m
.23589 1.05856 L
s
0 0 0 r
2.5 Mabswid
.23589 1.05856 Mdot
.039 .916 .04 r
.5 Mabswid
.19101 .89057 m
.18941 .87476 L
s
0 0 0 r
2.5 Mabswid
.18941 .87476 Mdot
.039 .916 .04 r
.5 Mabswid
.1627 .87599 m
.14807 .74237 L
s
0 0 0 r
2.5 Mabswid
.14807 .74237 Mdot
.039 .916 .04 r
.5 Mabswid
.12305 .72711 m
.1212 .71128 L
s
0 0 0 r
2.5 Mabswid
.1212 .71128 Mdot
.039 .916 .04 r
.5 Mabswid
.13793 .87712 m
.14129 .89285 L
s
0 0 0 r
2.5 Mabswid
.14129 .89285 Mdot
.039 .916 .04 r
.5 Mabswid
.09074 .72791 m
.08874 .71208 L
s
0 0 0 r
2.5 Mabswid
.08874 .71208 Mdot
.039 .916 .04 r
.5 Mabswid
.12105 .8779 m
.12462 .89362 L
s
0 0 0 r
2.5 Mabswid
.12462 .89362 Mdot
.039 .916 .04 r
.5 Mabswid
.87051 .8594 m
.87031 .87529 L
s
0 0 0 r
2.5 Mabswid
.87031 .87529 Mdot
.039 .916 .04 r
.5 Mabswid
.82526 .84559 m
.83781 .72527 L
s
0 0 0 r
2.5 Mabswid
.83781 .72527 Mdot
.039 .916 .04 r
.5 Mabswid
.78972 1.00906 m
.78972 1.02499 L
s
0 0 0 r
2.5 Mabswid
.78972 1.02499 Mdot
.039 .916 .04 r
.5 Mabswid
.76414 .88015 m
.76518 .99537 L
s
0 0 0 r
2.5 Mabswid
.76518 .99537 Mdot
.039 .916 .04 r
.5 Mabswid
.72913 .99857 m
.73819 .88135 L
s
0 0 0 r
2.5 Mabswid
.73819 .88135 Mdot
.039 .916 .04 r
.5 Mabswid
.71564 .99978 m
.72421 .88199 L
s
0 0 0 r
2.5 Mabswid
.72421 .88199 Mdot
.039 .916 .04 r
.5 Mabswid
.68587 1.18995 m
.68646 1.20587 L
s
0 0 0 r
2.5 Mabswid
.68646 1.20587 Mdot
.039 .916 .04 r
.5 Mabswid
.65745 1.17453 m
.66526 1.03614 L
s
0 0 0 r
2.5 Mabswid
.66526 1.03614 Mdot
.039 .916 .04 r
.5 Mabswid
.64741 1.17473 m
.65469 1.03709 L
s
0 0 0 r
2.5 Mabswid
.65469 1.03709 Mdot
.039 .916 .04 r
.5 Mabswid
.63496 1.34341 m
.63591 1.35931 L
s
0 0 0 r
2.5 Mabswid
.63591 1.35931 Mdot
.039 .916 .04 r
.5 Mabswid
.62351 1.17521 m
.62952 1.03934 L
s
0 0 0 r
2.5 Mabswid
.62952 1.03934 Mdot
.039 .916 .04 r
.5 Mabswid
.61222 1.34474 m
.61348 1.3606 L
s
0 0 0 r
2.5 Mabswid
.61348 1.3606 Mdot
.039 .916 .04 r
.5 Mabswid
.56993 1.33165 m
.57321 1.20805 L
s
0 0 0 r
2.5 Mabswid
.57321 1.20805 Mdot
.039 .916 .04 r
.5 Mabswid
.54291 1.33343 m
.54493 1.20862 L
s
0 0 0 r
2.5 Mabswid
.54493 1.20862 Mdot
.039 .916 .04 r
.5 Mabswid
.53585 1.33389 m
.53801 1.34949 L
s
0 0 0 r
2.5 Mabswid
.53801 1.34949 Mdot
.039 .916 .04 r
.5 Mabswid
.50393 1.33599 m
.50411 1.20943 L
s
0 0 0 r
2.5 Mabswid
.50411 1.20943 Mdot
.039 .916 .04 r
.5 Mabswid
.49456 1.33661 m
.49428 1.20962 L
s
0 0 0 r
2.5 Mabswid
.49428 1.20962 Mdot
.039 .916 .04 r
.5 Mabswid
.49225 1.33676 m
.49186 1.20967 L
s
0 0 0 r
2.5 Mabswid
.49186 1.20967 Mdot
.039 .916 .04 r
.5 Mabswid
.46982 1.33823 m
.4686 1.2326 L
s
0 0 0 r
2.5 Mabswid
.4686 1.2326 Mdot
.039 .916 .04 r
.5 Mabswid
.46568 1.33851 m
.46398 1.21023 L
s
0 0 0 r
2.5 Mabswid
.46398 1.21023 Mdot
.039 .916 .04 r
.5 Mabswid
.45557 1.33917 m
.45337 1.21044 L
s
0 0 0 r
2.5 Mabswid
.45337 1.21044 Mdot
.039 .916 .04 r
.5 Mabswid
.42701 1.34105 m
.42337 1.21104 L
s
0 0 0 r
2.5 Mabswid
.42337 1.21104 Mdot
.039 .916 .04 r
.5 Mabswid
.44371 1.51504 m
.44616 1.53079 L
s
0 0 0 r
2.5 Mabswid
.44616 1.53079 Mdot
.039 .916 .04 r
.5 Mabswid
.39695 1.17971 m
.39251 1.06052 L
s
0 0 0 r
2.5 Mabswid
.39251 1.06052 Mdot
.039 .916 .04 r
.5 Mabswid
.38349 1.35984 m
.38616 1.37561 L
s
0 0 0 r
2.5 Mabswid
.38616 1.37561 Mdot
.039 .916 .04 r
.5 Mabswid
.37396 1.21016 m
.37459 1.19399 L
s
0 0 0 r
2.5 Mabswid
.37459 1.19399 Mdot
.039 .916 .04 r
.5 Mabswid
.35884 1.36144 m
.36143 1.37722 L
s
0 0 0 r
2.5 Mabswid
.36143 1.37722 Mdot
.039 .916 .04 r
.5 Mabswid
.33666 1.19692 m
.33933 1.2128 L
s
0 0 0 r
2.5 Mabswid
.33933 1.2128 Mdot
.039 .916 .04 r
.5 Mabswid
.28521 1.03824 m
.27522 .90258 L
s
0 0 0 r
2.5 Mabswid
.27522 .90258 Mdot
.039 .916 .04 r
.5 Mabswid
.26846 1.03974 m
.25763 .90339 L
s
0 0 0 r
2.5 Mabswid
.25763 .90339 Mdot
.039 .916 .04 r
.5 Mabswid
.25666 1.04079 m
.24524 .90396 L
s
0 0 0 r
2.5 Mabswid
.24524 .90396 Mdot
.039 .916 .04 r
.5 Mabswid
.26754 1.18211 m
.27053 1.19796 L
s
0 0 0 r
2.5 Mabswid
.27053 1.19796 Mdot
.039 .916 .04 r
.5 Mabswid
.23589 1.05856 m
.23906 1.0742 L
s
0 0 0 r
2.5 Mabswid
.23906 1.0742 Mdot
.039 .916 .04 r
.5 Mabswid
.18941 .87476 m
.176 .74167 L
s
0 0 0 r
2.5 Mabswid
.176 .74167 Mdot
.039 .916 .04 r
.5 Mabswid
.14807 .74237 m
.17546 .8754 L
s
0 0 0 r
2.5 Mabswid
.17546 .8754 Mdot
.039 .916 .04 r
.5 Mabswid
.14129 .89285 m
.14465 .90857 L
s
0 0 0 r
2.5 Mabswid
.14465 .90857 Mdot
.039 .916 .04 r
.5 Mabswid
.12462 .89362 m
.12819 .90933 L
s
0 0 0 r
2.5 Mabswid
.12819 .90933 Mdot
.039 .916 .04 r
.5 Mabswid
.83781 .72527 m
.83948 .70935 L
s
0 0 0 r
2.5 Mabswid
.83948 .70935 Mdot
.039 .916 .04 r
.5 Mabswid
.76518 .99537 m
.76533 1.01129 L
s
0 0 0 r
2.5 Mabswid
.76533 1.01129 Mdot
.039 .916 .04 r
.5 Mabswid
.73819 .88135 m
.73943 .86541 L
s
0 0 0 r
2.5 Mabswid
.73943 .86541 Mdot
.039 .916 .04 r
.5 Mabswid
.72421 .88199 m
.72765 .99871 L
s
0 0 0 r
2.5 Mabswid
.72765 .99871 Mdot
.039 .916 .04 r
.5 Mabswid
.66526 1.03614 m
.66616 1.02013 L
s
0 0 0 r
2.5 Mabswid
.66616 1.02013 Mdot
.039 .916 .04 r
.5 Mabswid
.65469 1.03709 m
.65553 1.02108 L
s
0 0 0 r
2.5 Mabswid
.65553 1.02108 Mdot
.039 .916 .04 r
.5 Mabswid
.62952 1.03934 m
.63023 1.02334 L
s
0 0 0 r
2.5 Mabswid
.63023 1.02334 Mdot
.039 .916 .04 r
.5 Mabswid
.57321 1.20805 m
.57363 1.19212 L
s
0 0 0 r
2.5 Mabswid
.57363 1.19212 Mdot
.039 .916 .04 r
.5 Mabswid
.54493 1.20862 m
.54519 1.19269 L
s
0 0 0 r
2.5 Mabswid
.54519 1.19269 Mdot
.039 .916 .04 r
.5 Mabswid
.53801 1.34949 m
.54017 1.36509 L
s
0 0 0 r
2.5 Mabswid
.54017 1.36509 Mdot
.039 .916 .04 r
.5 Mabswid
.50411 1.20943 m
.51685 1.33505 L
s
0 0 0 r
2.5 Mabswid
.51685 1.33505 Mdot
.039 .916 .04 r
.5 Mabswid
.49428 1.20962 m
.49424 1.1937 L
s
0 0 0 r
2.5 Mabswid
.49424 1.1937 Mdot
.039 .916 .04 r
.5 Mabswid
.49186 1.20967 m
.49182 1.19375 L
s
0 0 0 r
2.5 Mabswid
.49182 1.19375 Mdot
.039 .916 .04 r
.5 Mabswid
.4686 1.2326 m
.46876 1.21015 L
s
0 0 0 r
2.5 Mabswid
.46876 1.21015 Mdot
.039 .916 .04 r
.5 Mabswid
.46398 1.21023 m
.4686 1.24965 L
s
0 0 0 r
2.5 Mabswid
.4686 1.24965 Mdot
.039 .916 .04 r
.5 Mabswid
.45337 1.21044 m
.4531 1.19452 L
s
0 0 0 r
2.5 Mabswid
.4531 1.19452 Mdot
.039 .916 .04 r
.5 Mabswid
.42337 1.21104 m
.42293 1.19512 L
s
0 0 0 r
2.5 Mabswid
.42293 1.19512 Mdot
.039 .916 .04 r
.5 Mabswid
.39251 1.06052 m
.41036 1.17936 L
s
0 0 0 r
2.5 Mabswid
.41036 1.17936 Mdot
.039 .916 .04 r
.5 Mabswid
.37459 1.19399 m
.37523 1.17783 L
s
0 0 0 r
2.5 Mabswid
.37523 1.17783 Mdot
.039 .916 .04 r
.5 Mabswid
.33933 1.2128 m
.36156 1.34519 L
s
0 0 0 r
2.5 Mabswid
.36156 1.34519 Mdot
.039 .916 .04 r
.5 Mabswid
.27522 .90258 m
.27406 .88676 L
s
0 0 0 r
2.5 Mabswid
.27406 .88676 Mdot
.039 .916 .04 r
.5 Mabswid
.25763 .90339 m
.28068 1.03865 L
s
0 0 0 r
2.5 Mabswid
.28068 1.03865 Mdot
.039 .916 .04 r
.5 Mabswid
.24524 .90396 m
.24392 .88814 L
s
0 0 0 r
2.5 Mabswid
.24392 .88814 Mdot
.039 .916 .04 r
.5 Mabswid
.27053 1.19796 m
.27352 1.21382 L
s
0 0 0 r
2.5 Mabswid
.27352 1.21382 Mdot
.039 .916 .04 r
.5 Mabswid
.23906 1.0742 m
.26419 1.19812 L
s
0 0 0 r
2.5 Mabswid
.26419 1.19812 Mdot
.039 .916 .04 r
.5 Mabswid
.176 .74167 m
.20089 .87424 L
s
0 0 0 r
2.5 Mabswid
.20089 .87424 Mdot
.039 .916 .04 r
.5 Mabswid
.17546 .8754 m
.1787 .89113 L
s
0 0 0 r
2.5 Mabswid
.1787 .89113 Mdot
.039 .916 .04 r
.5 Mabswid
.83948 .70935 m
.84114 .69343 L
s
0 0 0 r
2.5 Mabswid
.84114 .69343 Mdot
.039 .916 .04 r
.5 Mabswid
.76533 1.01129 m
.76547 1.02721 L
s
0 0 0 r
2.5 Mabswid
.76547 1.02721 Mdot
.039 .916 .04 r
.5 Mabswid
.73943 .86541 m
.74066 .84947 L
s
0 0 0 r
2.5 Mabswid
.74066 .84947 Mdot
.039 .916 .04 r
.5 Mabswid
.72765 .99871 m
.71049 .88266 L
s
0 0 0 r
2.5 Mabswid
.71049 .88266 Mdot
.039 .916 .04 r
.5 Mabswid
.66616 1.02013 m
.66707 1.00412 L
s
0 0 0 r
2.5 Mabswid
.66707 1.00412 Mdot
.039 .916 .04 r
.5 Mabswid
.65553 1.02108 m
.65638 1.00507 L
s
0 0 0 r
2.5 Mabswid
.65638 1.00507 Mdot
.039 .916 .04 r
.5 Mabswid
.63023 1.02334 m
.63094 1.00735 L
s
0 0 0 r
2.5 Mabswid
.63094 1.00735 Mdot
.039 .916 .04 r
.5 Mabswid
.57363 1.19212 m
.57405 1.17619 L
s
0 0 0 r
2.5 Mabswid
.57405 1.17619 Mdot
.039 .916 .04 r
.5 Mabswid
.54519 1.19269 m
.54545 1.17676 L
s
0 0 0 r
2.5 Mabswid
.54545 1.17676 Mdot
.039 .916 .04 r
.5 Mabswid
.54017 1.36509 m
.55268 1.49078 L
s
0 0 0 r
2.5 Mabswid
.55268 1.49078 Mdot
.039 .916 .04 r
.5 Mabswid
.51685 1.33505 m
.51846 1.35089 L
s
0 0 0 r
2.5 Mabswid
.51846 1.35089 Mdot
.039 .916 .04 r
.5 Mabswid
.49424 1.1937 m
.49421 1.17778 L
s
0 0 0 r
2.5 Mabswid
.49421 1.17778 Mdot
.039 .916 .04 r
.5 Mabswid
.49182 1.19375 m
.49177 1.17783 L
s
0 0 0 r
2.5 Mabswid
.49177 1.17783 Mdot
.039 .916 .04 r
.5 Mabswid
.46876 1.21015 m
.48401 1.33736 L
s
0 0 0 r
2.5 Mabswid
.48401 1.33736 Mdot
.039 .916 .04 r
.5 Mabswid
.4686 1.24965 m
.45841 1.33889 L
s
0 0 0 r
2.5 Mabswid
.45841 1.33889 Mdot
.039 .916 .04 r
.5 Mabswid
.4531 1.19452 m
.45282 1.1786 L
s
0 0 0 r
2.5 Mabswid
.45282 1.1786 Mdot
.039 .916 .04 r
.5 Mabswid
.42293 1.19512 m
.42248 1.1792 L
s
0 0 0 r
2.5 Mabswid
.42248 1.1792 Mdot
.039 .916 .04 r
.5 Mabswid
.41036 1.17936 m
.41274 1.19522 L
s
0 0 0 r
2.5 Mabswid
.41274 1.19522 Mdot
.039 .916 .04 r
.5 Mabswid
.37523 1.17783 m
.37986 1.06053 L
s
0 0 0 r
2.5 Mabswid
.37986 1.06053 Mdot
.039 .916 .04 r
.5 Mabswid
.36156 1.34519 m
.36421 1.36096 L
s
0 0 0 r
2.5 Mabswid
.36421 1.36096 Mdot
.039 .916 .04 r
.5 Mabswid
.27406 .88676 m
.27289 .87093 L
s
0 0 0 r
2.5 Mabswid
.27289 .87093 Mdot
.039 .916 .04 r
.5 Mabswid
.28068 1.03865 m
.28335 1.05434 L
s
0 0 0 r
2.5 Mabswid
.28335 1.05434 Mdot
.039 .916 .04 r
.5 Mabswid
.24392 .88814 m
.24259 .87232 L
s
0 0 0 r
2.5 Mabswid
.24259 .87232 Mdot
.039 .916 .04 r
.5 Mabswid
.26419 1.19812 m
.26741 1.21397 L
s
0 0 0 r
2.5 Mabswid
.26741 1.21397 Mdot
.039 .916 .04 r
.5 Mabswid
.20089 .87424 m
.20385 .88998 L
s
0 0 0 r
2.5 Mabswid
.20385 .88998 Mdot
.039 .916 .04 r
.5 Mabswid
.1787 .89113 m
.18194 .90686 L
s
0 0 0 r
2.5 Mabswid
.18194 .90686 Mdot
.039 .916 .04 r
.5 Mabswid
.74066 .84947 m
.75009 .72744 L
s
0 0 0 r
2.5 Mabswid
.75009 .72744 Mdot
.039 .916 .04 r
.5 Mabswid
.71049 .88266 m
.71484 .99999 L
s
0 0 0 r
2.5 Mabswid
.71484 .99999 Mdot
.039 .916 .04 r
.5 Mabswid
.66707 1.00412 m
.67383 .8843 L
s
0 0 0 r
2.5 Mabswid
.67383 .8843 Mdot
.039 .916 .04 r
.5 Mabswid
.65638 1.00507 m
.66273 .88481 L
s
0 0 0 r
2.5 Mabswid
.66273 .88481 Mdot
.039 .916 .04 r
.5 Mabswid
.63094 1.00735 m
.63631 .88602 L
s
0 0 0 r
2.5 Mabswid
.63631 .88602 Mdot
.039 .916 .04 r
.5 Mabswid
.57405 1.17619 m
.57756 1.04398 L
s
0 0 0 r
2.5 Mabswid
.57756 1.04398 Mdot
.039 .916 .04 r
.5 Mabswid
.54545 1.17676 m
.54756 1.04666 L
s
0 0 0 r
2.5 Mabswid
.54756 1.04666 Mdot
.039 .916 .04 r
.5 Mabswid
.55268 1.49078 m
.55425 1.5066 L
s
0 0 0 r
2.5 Mabswid
.55425 1.5066 Mdot
.039 .916 .04 r
.5 Mabswid
.51846 1.35089 m
.52007 1.36672 L
s
0 0 0 r
2.5 Mabswid
.52007 1.36672 Mdot
.039 .916 .04 r
.5 Mabswid
.49421 1.17778 m
.49393 1.05145 L
s
0 0 0 r
2.5 Mabswid
.49393 1.05145 Mdot
.039 .916 .04 r
.5 Mabswid
.49177 1.17783 m
.49138 1.05168 L
s
0 0 0 r
2.5 Mabswid
.49138 1.05168 Mdot
.039 .916 .04 r
.5 Mabswid
.48401 1.33736 m
.4859 1.35319 L
s
0 0 0 r
2.5 Mabswid
.4859 1.35319 Mdot
.039 .916 .04 r
.5 Mabswid
.45841 1.33889 m
.45658 1.35495 L
s
0 0 0 r
2.5 Mabswid
.45658 1.35495 Mdot
.039 .916 .04 r
.5 Mabswid
.45282 1.1786 m
.45072 1.05531 L
s
0 0 0 r
2.5 Mabswid
.45072 1.05531 Mdot
.039 .916 .04 r
.5 Mabswid
.42248 1.1792 m
.41909 1.05814 L
s
0 0 0 r
2.5 Mabswid
.41909 1.05814 Mdot
.039 .916 .04 r
.5 Mabswid
.41274 1.19522 m
.41512 1.21109 L
s
0 0 0 r
2.5 Mabswid
.41512 1.21109 Mdot
.039 .916 .04 r
.5 Mabswid
.37986 1.06053 m
.3805 1.04448 L
s
0 0 0 r
2.5 Mabswid
.3805 1.04448 Mdot
.039 .916 .04 r
.5 Mabswid
.36421 1.36096 m
.36686 1.37672 L
s
0 0 0 r
2.5 Mabswid
.36686 1.37672 Mdot
.039 .916 .04 r
.5 Mabswid
.27289 .87093 m
.26321 .73951 L
s
0 0 0 r
2.5 Mabswid
.26321 .73951 Mdot
.039 .916 .04 r
.5 Mabswid
.28335 1.05434 m
.28603 1.07003 L
s
0 0 0 r
2.5 Mabswid
.28603 1.07003 Mdot
.039 .916 .04 r
.5 Mabswid
.24259 .87232 m
.23157 .7403 L
s
0 0 0 r
2.5 Mabswid
.23157 .7403 Mdot
.039 .916 .04 r
.5 Mabswid
.20385 .88998 m
.2068 .90573 L
s
0 0 0 r
2.5 Mabswid
.2068 .90573 Mdot
.039 .916 .04 r
.5 Mabswid
.18194 .90686 m
.21025 1.04493 L
s
0 0 0 r
2.5 Mabswid
.21025 1.04493 Mdot
.039 .916 .04 r
.5 Mabswid
.75009 .72744 m
.75132 .71153 L
s
0 0 0 r
2.5 Mabswid
.75132 .71153 Mdot
.039 .916 .04 r
.5 Mabswid
.71484 .99999 m
.71543 1.01587 L
s
0 0 0 r
2.5 Mabswid
.71543 1.01587 Mdot
.039 .916 .04 r
.5 Mabswid
.67383 .8843 m
.6799 1.00299 L
s
0 0 0 r
2.5 Mabswid
.6799 1.00299 Mdot
.039 .916 .04 r
.5 Mabswid
.66273 .88481 m
.66923 1.00392 L
s
0 0 0 r
2.5 Mabswid
.66923 1.00392 Mdot
.039 .916 .04 r
.5 Mabswid
.63631 .88602 m
.63701 .87011 L
s
0 0 0 r
2.5 Mabswid
.63701 .87011 Mdot
.039 .916 .04 r
.5 Mabswid
.57756 1.04398 m
.57798 1.02801 L
s
0 0 0 r
2.5 Mabswid
.57798 1.02801 Mdot
.039 .916 .04 r
.5 Mabswid
.54756 1.04666 m
.55815 1.17657 L
s
0 0 0 r
2.5 Mabswid
.55815 1.17657 Mdot
.039 .916 .04 r
.5 Mabswid
.55425 1.5066 m
.55583 1.52242 L
s
0 0 0 r
2.5 Mabswid
.55583 1.52242 Mdot
.039 .916 .04 r
.5 Mabswid
.52007 1.36672 m
.532 1.46802 L
s
0 0 0 r
2.5 Mabswid
.532 1.46802 Mdot
.039 .916 .04 r
.5 Mabswid
.49393 1.05145 m
.4939 1.03552 L
s
0 0 0 r
2.5 Mabswid
.4939 1.03552 Mdot
.039 .916 .04 r
.5 Mabswid
.49138 1.05168 m
.49133 1.03575 L
s
0 0 0 r
2.5 Mabswid
.49133 1.03575 Mdot
.039 .916 .04 r
.5 Mabswid
.4859 1.35319 m
.4878 1.36903 L
s
0 0 0 r
2.5 Mabswid
.4878 1.36903 Mdot
.039 .916 .04 r
.5 Mabswid
.45658 1.35495 m
.45475 1.37101 L
s
0 0 0 r
2.5 Mabswid
.45475 1.37101 Mdot
.039 .916 .04 r
.5 Mabswid
.45072 1.05531 m
.45045 1.03941 L
s
0 0 0 r
2.5 Mabswid
.45045 1.03941 Mdot
.039 .916 .04 r
.5 Mabswid
.41909 1.05814 m
.41865 1.04225 L
s
0 0 0 r
2.5 Mabswid
.41865 1.04225 Mdot
.039 .916 .04 r
.5 Mabswid
.41512 1.21109 m
.43458 1.34075 L
s
0 0 0 r
2.5 Mabswid
.43458 1.34075 Mdot
.039 .916 .04 r
.5 Mabswid
.3805 1.04448 m
.38113 1.02843 L
s
0 0 0 r
2.5 Mabswid
.38113 1.02843 Mdot
.039 .916 .04 r
.5 Mabswid
.26321 .73951 m
.28614 .87032 L
s
0 0 0 r
2.5 Mabswid
.28614 .87032 Mdot
.039 .916 .04 r
.5 Mabswid
.28603 1.07003 m
.3063 1.18145 L
s
0 0 0 r
2.5 Mabswid
.3063 1.18145 Mdot
.039 .916 .04 r
.5 Mabswid
.23157 .7403 m
.23025 .72445 L
s
0 0 0 r
2.5 Mabswid
.23025 .72445 Mdot
.039 .916 .04 r
.5 Mabswid
.2068 .90573 m
.23257 1.04298 L
s
0 0 0 r
2.5 Mabswid
.23257 1.04298 Mdot
.039 .916 .04 r
.5 Mabswid
.21025 1.04493 m
.2125 .9055 L
s
0 0 0 r
2.5 Mabswid
.2125 .9055 Mdot
.039 .916 .04 r
.5 Mabswid
.75132 .71153 m
.75255 .69563 L
s
0 0 0 r
2.5 Mabswid
.75255 .69563 Mdot
.039 .916 .04 r
.5 Mabswid
.71543 1.01587 m
.71602 1.03175 L
s
0 0 0 r
2.5 Mabswid
.71602 1.03175 Mdot
.039 .916 .04 r
.5 Mabswid
.6799 1.00299 m
.66543 .88473 L
s
0 0 0 r
2.5 Mabswid
.66543 .88473 Mdot
.039 .916 .04 r
.5 Mabswid
.66923 1.00392 m
.65474 .8852 L
s
0 0 0 r
2.5 Mabswid
.65474 .8852 Mdot
.039 .916 .04 r
.5 Mabswid
.63701 .87011 m
.63771 .8542 L
s
0 0 0 r
2.5 Mabswid
.63771 .8542 Mdot
.039 .916 .04 r
.5 Mabswid
.57798 1.02801 m
.5784 1.01204 L
s
0 0 0 r
2.5 Mabswid
.5784 1.01204 Mdot
.039 .916 .04 r
.5 Mabswid
.55815 1.17657 m
.55945 1.19248 L
s
0 0 0 r
2.5 Mabswid
.55945 1.19248 Mdot
.039 .916 .04 r
.5 Mabswid
.532 1.46802 m
.52913 1.49266 L
s
0 0 0 r
2.5 Mabswid
.52913 1.49266 Mdot
.039 .916 .04 r
.5 Mabswid
.4939 1.03552 m
.49386 1.0196 L
s
0 0 0 r
2.5 Mabswid
.49386 1.0196 Mdot
.039 .916 .04 r
.5 Mabswid
.49133 1.03575 m
.49128 1.01983 L
s
0 0 0 r
2.5 Mabswid
.49128 1.01983 Mdot
.039 .916 .04 r
.5 Mabswid
.4878 1.36903 m
.50257 1.49481 L
s
0 0 0 r
2.5 Mabswid
.50257 1.49481 Mdot
.039 .916 .04 r
.5 Mabswid
.45475 1.37101 m
.44012 1.49924 L
s
0 0 0 r
2.5 Mabswid
.44012 1.49924 Mdot
.039 .916 .04 r
.5 Mabswid
.45045 1.03941 m
.45018 1.0235 L
s
0 0 0 r
2.5 Mabswid
.45018 1.0235 Mdot
.039 .916 .04 r
.5 Mabswid
.41865 1.04225 m
.4182 1.02636 L
s
0 0 0 r
2.5 Mabswid
.4182 1.02636 Mdot
.039 .916 .04 r
.5 Mabswid
.43458 1.34075 m
.43696 1.35655 L
s
0 0 0 r
2.5 Mabswid
.43696 1.35655 Mdot
.039 .916 .04 r
.5 Mabswid
.38113 1.02843 m
.38632 .897 L
s
0 0 0 r
2.5 Mabswid
.38632 .897 Mdot
.039 .916 .04 r
.5 Mabswid
.28614 .87032 m
.2889 .88607 L
s
0 0 0 r
2.5 Mabswid
.2889 .88607 Mdot
.039 .916 .04 r
.5 Mabswid
.3063 1.18145 m
.30918 1.19731 L
s
0 0 0 r
2.5 Mabswid
.30918 1.19731 Mdot
.039 .916 .04 r
.5 Mabswid
.23025 .72445 m
.22893 .70861 L
s
0 0 0 r
2.5 Mabswid
.22893 .70861 Mdot
.039 .916 .04 r
.5 Mabswid
.23257 1.04298 m
.23552 1.05865 L
s
0 0 0 r
2.5 Mabswid
.23552 1.05865 Mdot
.039 .916 .04 r
.5 Mabswid
.2125 .9055 m
.21276 .88962 L
s
0 0 0 r
2.5 Mabswid
.21276 .88962 Mdot
.039 .916 .04 r
.5 Mabswid
.71602 1.03175 m
.7213 1.17368 L
s
0 0 0 r
2.5 Mabswid
.7213 1.17368 Mdot
.039 .916 .04 r
.5 Mabswid
.66543 .88473 m
.6635 .86895 L
s
0 0 0 r
2.5 Mabswid
.6635 .86895 Mdot
.039 .916 .04 r
.5 Mabswid
.65474 .8852 m
.65281 .86941 L
s
0 0 0 r
2.5 Mabswid
.65281 .86941 Mdot
.039 .916 .04 r
.5 Mabswid
.63771 .8542 m
.63979 .86998 L
s
0 0 0 r
2.5 Mabswid
.63979 .86998 Mdot
.039 .916 .04 r
.5 Mabswid
.5784 1.01204 m
.58174 1.02766 L
s
0 0 0 r
2.5 Mabswid
.58174 1.02766 Mdot
.039 .916 .04 r
.5 Mabswid
.55945 1.19248 m
.56075 1.20838 L
s
0 0 0 r
2.5 Mabswid
.56075 1.20838 Mdot
.039 .916 .04 r
.5 Mabswid
.52913 1.49266 m
.52726 1.50873 L
s
0 0 0 r
2.5 Mabswid
.52726 1.50873 Mdot
.039 .916 .04 r
.5 Mabswid
.49386 1.0196 m
.49358 .89257 L
s
0 0 0 r
2.5 Mabswid
.49358 .89257 Mdot
.039 .916 .04 r
.5 Mabswid
.49128 1.01983 m
.49089 .89269 L
s
0 0 0 r
2.5 Mabswid
.49089 .89269 Mdot
.039 .916 .04 r
.5 Mabswid
.50257 1.49481 m
.50442 1.5106 L
s
0 0 0 r
2.5 Mabswid
.50442 1.5106 Mdot
.039 .916 .04 r
.5 Mabswid
.44012 1.49924 m
.43829 1.51529 L
s
0 0 0 r
2.5 Mabswid
.43829 1.51529 Mdot
.039 .916 .04 r
.5 Mabswid
.45018 1.0235 m
.44797 .89466 L
s
0 0 0 r
2.5 Mabswid
.44797 .89466 Mdot
.039 .916 .04 r
.5 Mabswid
.4182 1.02636 m
.41456 .89619 L
s
0 0 0 r
2.5 Mabswid
.41456 .89619 Mdot
.039 .916 .04 r
.5 Mabswid
.43696 1.35655 m
.43933 1.37236 L
s
0 0 0 r
2.5 Mabswid
.43933 1.37236 Mdot
.039 .916 .04 r
.5 Mabswid
.38632 .897 m
.38695 .88107 L
s
0 0 0 r
2.5 Mabswid
.38695 .88107 Mdot
.039 .916 .04 r
.5 Mabswid
.2889 .88607 m
.29166 .90182 L
s
0 0 0 r
2.5 Mabswid
.29166 .90182 Mdot
.039 .916 .04 r
.5 Mabswid
.30918 1.19731 m
.31207 1.21317 L
s
0 0 0 r
2.5 Mabswid
.31207 1.21317 Mdot
.039 .916 .04 r
.5 Mabswid
.23552 1.05865 m
.23846 1.07432 L
s
0 0 0 r
2.5 Mabswid
.23846 1.07432 Mdot
.039 .916 .04 r
.5 Mabswid
.21276 .88962 m
.21301 .87373 L
s
0 0 0 r
2.5 Mabswid
.21301 .87373 Mdot
.039 .916 .04 r
.5 Mabswid
.7213 1.17368 m
.7219 1.18959 L
s
0 0 0 r
2.5 Mabswid
.7219 1.18959 Mdot
.039 .916 .04 r
.5 Mabswid
.6635 .86895 m
.66157 .85316 L
s
0 0 0 r
2.5 Mabswid
.66157 .85316 Mdot
.039 .916 .04 r
.5 Mabswid
.65281 .86941 m
.65089 .85363 L
s
0 0 0 r
2.5 Mabswid
.65089 .85363 Mdot
.039 .916 .04 r
.5 Mabswid
.63979 .86998 m
.64187 .88576 L
s
0 0 0 r
2.5 Mabswid
.64187 .88576 Mdot
.039 .916 .04 r
.5 Mabswid
.58174 1.02766 m
.58507 1.04327 L
s
0 0 0 r
2.5 Mabswid
.58507 1.04327 Mdot
.039 .916 .04 r
.5 Mabswid
.56075 1.20838 m
.57132 1.33141 L
s
0 0 0 r
2.5 Mabswid
.57132 1.33141 Mdot
.039 .916 .04 r
.5 Mabswid
.52726 1.50873 m
.52538 1.5248 L
s
0 0 0 r
2.5 Mabswid
.52538 1.5248 Mdot
.039 .916 .04 r
.5 Mabswid
.49358 .89257 m
.49355 .87669 L
s
0 0 0 r
2.5 Mabswid
.49355 .87669 Mdot
.039 .916 .04 r
.5 Mabswid
.49089 .89269 m
.49084 .87681 L
s
0 0 0 r
2.5 Mabswid
.49084 .87681 Mdot
.039 .916 .04 r
.5 Mabswid
.50442 1.5106 m
.50628 1.5264 L
s
0 0 0 r
2.5 Mabswid
.50628 1.5264 Mdot
.039 .916 .04 r
.5 Mabswid
.43829 1.51529 m
.43646 1.53135 L
s
0 0 0 r
2.5 Mabswid
.43646 1.53135 Mdot
.039 .916 .04 r
.5 Mabswid
.44797 .89466 m
.4477 .87879 L
s
0 0 0 r
2.5 Mabswid
.4477 .87879 Mdot
.039 .916 .04 r
.5 Mabswid
.41456 .89619 m
.43025 1.02527 L
s
0 0 0 r
2.5 Mabswid
.43025 1.02527 Mdot
.039 .916 .04 r
.5 Mabswid
.43933 1.37236 m
.45704 1.49829 L
s
0 0 0 r
2.5 Mabswid
.45704 1.49829 Mdot
.039 .916 .04 r
.5 Mabswid
.38695 .88107 m
.38758 .86515 L
s
0 0 0 r
2.5 Mabswid
.38758 .86515 Mdot
.039 .916 .04 r
.5 Mabswid
.29166 .90182 m
.31509 1.03551 L
s
0 0 0 r
2.5 Mabswid
.31509 1.03551 Mdot
.039 .916 .04 r
.5 Mabswid
.31207 1.21317 m
.34218 1.3787 L
s
0 0 0 r
2.5 Mabswid
.34218 1.3787 Mdot
.039 .916 .04 r
.5 Mabswid
.23846 1.07432 m
.26475 1.21436 L
s
0 0 0 r
2.5 Mabswid
.26475 1.21436 Mdot
.039 .916 .04 r
.5 Mabswid
.21301 .87373 m
.21515 .74121 L
s
0 0 0 r
2.5 Mabswid
.21515 .74121 Mdot
.039 .916 .04 r
.5 Mabswid
.7219 1.18959 m
.72249 1.20549 L
s
0 0 0 r
2.5 Mabswid
.72249 1.20549 Mdot
.039 .916 .04 r
.5 Mabswid
.66157 .85316 m
.64656 .73053 L
s
0 0 0 r
2.5 Mabswid
.64656 .73053 Mdot
.039 .916 .04 r
.5 Mabswid
.65089 .85363 m
.63587 .7306 L
s
0 0 0 r
2.5 Mabswid
.63587 .7306 Mdot
.039 .916 .04 r
.5 Mabswid
.64187 .88576 m
.64827 1.00576 L
s
0 0 0 r
2.5 Mabswid
.64827 1.00576 Mdot
.039 .916 .04 r
.5 Mabswid
.58507 1.04327 m
.61317 1.17477 L
s
0 0 0 r
2.5 Mabswid
.61317 1.17477 Mdot
.039 .916 .04 r
.5 Mabswid
.57132 1.33141 m
.57268 1.34727 L
s
0 0 0 r
2.5 Mabswid
.57268 1.34727 Mdot
.039 .916 .04 r
.5 Mabswid
.49355 .87669 m
.49351 .86081 L
s
0 0 0 r
2.5 Mabswid
.49351 .86081 Mdot
.039 .916 .04 r
.5 Mabswid
.49084 .87681 m
.49079 .86094 L
s
0 0 0 r
2.5 Mabswid
.49079 .86094 Mdot
.039 .916 .04 r
.5 Mabswid
.4477 .87879 m
.44743 .86292 L
s
0 0 0 r
2.5 Mabswid
.44743 .86292 Mdot
.039 .916 .04 r
.5 Mabswid
.43025 1.02527 m
.43216 1.04102 L
s
0 0 0 r
2.5 Mabswid
.43216 1.04102 Mdot
.039 .916 .04 r
.5 Mabswid
.45704 1.49829 m
.45926 1.51406 L
s
0 0 0 r
2.5 Mabswid
.45926 1.51406 Mdot
.039 .916 .04 r
.5 Mabswid
.38758 .86515 m
.38976 .88091 L
s
0 0 0 r
2.5 Mabswid
.38976 .88091 Mdot
.039 .916 .04 r
.5 Mabswid
.31509 1.03551 m
.31466 .90079 L
s
0 0 0 r
2.5 Mabswid
.31466 .90079 Mdot
.039 .916 .04 r
.5 Mabswid
.21515 .74121 m
.23871 .8726 L
s
0 0 0 r
2.5 Mabswid
.23871 .8726 Mdot
.039 .916 .04 r
.5 Mabswid
.64656 .73053 m
.64463 .71473 L
s
0 0 0 r
2.5 Mabswid
.64463 .71473 Mdot
.039 .916 .04 r
.5 Mabswid
.63587 .7306 m
.63394 .71479 L
s
0 0 0 r
2.5 Mabswid
.63394 .71479 Mdot
.039 .916 .04 r
.5 Mabswid
.64827 1.00576 m
.64911 1.02161 L
s
0 0 0 r
2.5 Mabswid
.64911 1.02161 Mdot
.039 .916 .04 r
.5 Mabswid
.61317 1.17477 m
.61655 1.19056 L
s
0 0 0 r
2.5 Mabswid
.61655 1.19056 Mdot
.039 .916 .04 r
.5 Mabswid
.57268 1.34727 m
.57405 1.36312 L
s
0 0 0 r
2.5 Mabswid
.57405 1.36312 Mdot
.039 .916 .04 r
.5 Mabswid
.49351 .86081 m
.49323 .73381 L
s
0 0 0 r
2.5 Mabswid
.49323 .73381 Mdot
.039 .916 .04 r
.5 Mabswid
.49079 .86094 m
.4904 .73388 L
s
0 0 0 r
2.5 Mabswid
.4904 .73388 Mdot
.039 .916 .04 r
.5 Mabswid
.44743 .86292 m
.44525 .735 L
s
0 0 0 r
2.5 Mabswid
.44525 .735 Mdot
.039 .916 .04 r
.5 Mabswid
.43216 1.04102 m
.43408 1.05678 L
s
0 0 0 r
2.5 Mabswid
.43408 1.05678 Mdot
.039 .916 .04 r
.5 Mabswid
.45926 1.51406 m
.46147 1.52982 L
s
0 0 0 r
2.5 Mabswid
.46147 1.52982 Mdot
.039 .916 .04 r
.5 Mabswid
.38976 .88091 m
.39194 .89667 L
s
0 0 0 r
2.5 Mabswid
.39194 .89667 Mdot
.039 .916 .04 r
.5 Mabswid
.31466 .90079 m
.33565 1.03383 L
s
0 0 0 r
2.5 Mabswid
.33565 1.03383 Mdot
.039 .916 .04 r
.5 Mabswid
.23871 .8726 m
.24154 .88835 L
s
0 0 0 r
2.5 Mabswid
.24154 .88835 Mdot
.039 .916 .04 r
.5 Mabswid
.64463 .71473 m
.6427 .69893 L
s
0 0 0 r
2.5 Mabswid
.6427 .69893 Mdot
.039 .916 .04 r
.5 Mabswid
.63394 .71479 m
.63201 .69898 L
s
0 0 0 r
2.5 Mabswid
.63201 .69898 Mdot
.039 .916 .04 r
.5 Mabswid
.64911 1.02161 m
.64996 1.03747 L
s
0 0 0 r
2.5 Mabswid
.64996 1.03747 Mdot
.039 .916 .04 r
.5 Mabswid
.61655 1.19056 m
.61992 1.20636 L
s
0 0 0 r
2.5 Mabswid
.61992 1.20636 Mdot
.039 .916 .04 r
.5 Mabswid
.49323 .73381 m
.4932 .71793 L
s
0 0 0 r
2.5 Mabswid
.4932 .71793 Mdot
.039 .916 .04 r
.5 Mabswid
.4904 .73388 m
.49035 .718 L
s
0 0 0 r
2.5 Mabswid
.49035 .718 Mdot
.039 .916 .04 r
.5 Mabswid
.44525 .735 m
.44498 .71913 L
s
0 0 0 r
2.5 Mabswid
.44498 .71913 Mdot
.039 .916 .04 r
.5 Mabswid
.43408 1.05678 m
.44888 1.17856 L
s
0 0 0 r
2.5 Mabswid
.44888 1.17856 Mdot
.039 .916 .04 r
.5 Mabswid
.39194 .89667 m
.40982 1.02515 L
s
0 0 0 r
2.5 Mabswid
.40982 1.02515 Mdot
.039 .916 .04 r
.5 Mabswid
.33565 1.03383 m
.33813 1.04954 L
s
0 0 0 r
2.5 Mabswid
.33813 1.04954 Mdot
.039 .916 .04 r
.5 Mabswid
.24154 .88835 m
.24436 .9041 L
s
0 0 0 r
2.5 Mabswid
.24436 .9041 Mdot
.039 .916 .04 r
.5 Mabswid
.64996 1.03747 m
.65725 1.17429 L
s
0 0 0 r
2.5 Mabswid
.65725 1.17429 Mdot
.039 .916 .04 r
.5 Mabswid
.61992 1.20636 m
.62902 1.32853 L
s
0 0 0 r
2.5 Mabswid
.62902 1.32853 Mdot
.039 .916 .04 r
.5 Mabswid
.4932 .71793 m
.49316 .70206 L
s
0 0 0 r
2.5 Mabswid
.49316 .70206 Mdot
.039 .916 .04 r
.5 Mabswid
.49035 .718 m
.4903 .70213 L
s
0 0 0 r
2.5 Mabswid
.4903 .70213 Mdot
.039 .916 .04 r
.5 Mabswid
.44498 .71913 m
.4447 .70326 L
s
0 0 0 r
2.5 Mabswid
.4447 .70326 Mdot
.039 .916 .04 r
.5 Mabswid
.44888 1.17856 m
.45081 1.19444 L
s
0 0 0 r
2.5 Mabswid
.45081 1.19444 Mdot
.039 .916 .04 r
.5 Mabswid
.40982 1.02515 m
.41201 1.04089 L
s
0 0 0 r
2.5 Mabswid
.41201 1.04089 Mdot
.039 .916 .04 r
.5 Mabswid
.33813 1.04954 m
.34061 1.06525 L
s
0 0 0 r
2.5 Mabswid
.34061 1.06525 Mdot
.039 .916 .04 r
.5 Mabswid
.24436 .9041 m
.26875 1.04007 L
s
0 0 0 r
2.5 Mabswid
.26875 1.04007 Mdot
.039 .916 .04 r
.5 Mabswid
.65725 1.17429 m
.65949 1.03714 L
s
0 0 0 r
2.5 Mabswid
.65949 1.03714 Mdot
.039 .916 .04 r
.5 Mabswid
.62902 1.32853 m
.6302 1.34441 L
s
0 0 0 r
2.5 Mabswid
.6302 1.34441 Mdot
.039 .916 .04 r
.5 Mabswid
.49316 .70206 m
.49408 .71788 L
s
0 0 0 r
2.5 Mabswid
.49408 .71788 Mdot
.039 .916 .04 r
.5 Mabswid
.45081 1.19444 m
.45274 1.21032 L
s
0 0 0 r
2.5 Mabswid
.45274 1.21032 Mdot
.039 .916 .04 r
.5 Mabswid
.41201 1.04089 m
.4142 1.05664 L
s
0 0 0 r
2.5 Mabswid
.4142 1.05664 Mdot
.039 .916 .04 r
.5 Mabswid
.34061 1.06525 m
.35901 1.1808 L
s
0 0 0 r
2.5 Mabswid
.35901 1.1808 Mdot
.039 .916 .04 r
.5 Mabswid
.26875 1.04007 m
.27156 1.05575 L
s
0 0 0 r
2.5 Mabswid
.27156 1.05575 Mdot
.039 .916 .04 r
.5 Mabswid
.65949 1.03714 m
.65975 1.02125 L
s
0 0 0 r
2.5 Mabswid
.65975 1.02125 Mdot
.039 .916 .04 r
.5 Mabswid
.6302 1.34441 m
.63138 1.36028 L
s
0 0 0 r
2.5 Mabswid
.63138 1.36028 Mdot
.039 .916 .04 r
.5 Mabswid
.49408 .71788 m
.495 .7337 L
s
0 0 0 r
2.5 Mabswid
.495 .7337 Mdot
.039 .916 .04 r
.5 Mabswid
.45274 1.21032 m
.46833 1.33851 L
s
0 0 0 r
2.5 Mabswid
.46833 1.33851 Mdot
.039 .916 .04 r
.5 Mabswid
.4142 1.05664 m
.43031 1.17239 L
s
0 0 0 r
2.5 Mabswid
.43031 1.17239 Mdot
.039 .916 .04 r
.5 Mabswid
.35901 1.1808 m
.36154 1.19667 L
s
0 0 0 r
2.5 Mabswid
.36154 1.19667 Mdot
.039 .916 .04 r
.5 Mabswid
.27156 1.05575 m
.27437 1.07143 L
s
0 0 0 r
2.5 Mabswid
.27437 1.07143 Mdot
.039 .916 .04 r
.5 Mabswid
.65975 1.02125 m
.66001 1.00536 L
s
0 0 0 r
2.5 Mabswid
.66001 1.00536 Mdot
.039 .916 .04 r
.5 Mabswid
.495 .7337 m
.50236 .86034 L
s
0 0 0 r
2.5 Mabswid
.50236 .86034 Mdot
.039 .916 .04 r
.5 Mabswid
.46833 1.33851 m
.46867 1.34134 L
s
0 0 0 r
2.5 Mabswid
.46867 1.34134 Mdot
.039 .916 .04 r
.5 Mabswid
.43031 1.17239 m
.43253 1.1883 L
s
0 0 0 r
2.5 Mabswid
.43253 1.1883 Mdot
.039 .916 .04 r
.5 Mabswid
.36154 1.19667 m
.36407 1.21254 L
s
0 0 0 r
2.5 Mabswid
.36407 1.21254 Mdot
.039 .916 .04 r
.5 Mabswid
.27437 1.07143 m
.29439 1.18301 L
s
0 0 0 r
2.5 Mabswid
.29439 1.18301 Mdot
.039 .916 .04 r
.5 Mabswid
.66001 1.00536 m
.66197 .88515 L
s
0 0 0 r
2.5 Mabswid
.66197 .88515 Mdot
.039 .916 .04 r
.5 Mabswid
.50236 .86034 m
.49838 .73314 L
s
0 0 0 r
2.5 Mabswid
.49838 .73314 Mdot
.039 .916 .04 r
.5 Mabswid
.46867 1.34134 m
.46717 1.35456 L
s
0 0 0 r
2.5 Mabswid
.46717 1.35456 Mdot
.039 .916 .04 r
.5 Mabswid
.43253 1.1883 m
.43474 1.20421 L
s
0 0 0 r
2.5 Mabswid
.43474 1.20421 Mdot
.039 .916 .04 r
.5 Mabswid
.36407 1.21254 m
.3853 1.3435 L
s
0 0 0 r
2.5 Mabswid
.3853 1.3435 Mdot
.039 .916 .04 r
.5 Mabswid
.29439 1.18301 m
.29723 1.19888 L
s
0 0 0 r
2.5 Mabswid
.29723 1.19888 Mdot
.039 .916 .04 r
.5 Mabswid
.66197 .88515 m
.66223 .86927 L
s
0 0 0 r
2.5 Mabswid
.66223 .86927 Mdot
.039 .916 .04 r
.5 Mabswid
.49838 .73314 m
.49788 .71725 L
s
0 0 0 r
2.5 Mabswid
.49788 .71725 Mdot
.039 .916 .04 r
.5 Mabswid
.46717 1.35456 m
.46534 1.37065 L
s
0 0 0 r
2.5 Mabswid
.46534 1.37065 Mdot
.039 .916 .04 r
.5 Mabswid
.43474 1.20421 m
.4524 1.34536 L
s
0 0 0 r
2.5 Mabswid
.4524 1.34536 Mdot
.039 .916 .04 r
.5 Mabswid
.3853 1.3435 m
.38786 1.35929 L
s
0 0 0 r
2.5 Mabswid
.38786 1.35929 Mdot
.039 .916 .04 r
.5 Mabswid
.29723 1.19888 m
.30008 1.21474 L
s
0 0 0 r
2.5 Mabswid
.30008 1.21474 Mdot
.039 .916 .04 r
.5 Mabswid
.66223 .86927 m
.66249 .8534 L
s
0 0 0 r
2.5 Mabswid
.66249 .8534 Mdot
.039 .916 .04 r
.5 Mabswid
.49788 .71725 m
.49738 .70136 L
s
0 0 0 r
2.5 Mabswid
.49738 .70136 Mdot
.039 .916 .04 r
.5 Mabswid
.46534 1.37065 m
.45076 1.49884 L
s
0 0 0 r
2.5 Mabswid
.45076 1.49884 Mdot
.039 .916 .04 r
.5 Mabswid
.4524 1.34536 m
.45437 1.36115 L
s
0 0 0 r
2.5 Mabswid
.45437 1.36115 Mdot
.039 .916 .04 r
.5 Mabswid
.38786 1.35929 m
.39042 1.37507 L
s
0 0 0 r
2.5 Mabswid
.39042 1.37507 Mdot
.039 .916 .04 r
.5 Mabswid
.66249 .8534 m
.66447 .732 L
s
0 0 0 r
2.5 Mabswid
.66447 .732 Mdot
.039 .916 .04 r
.5 Mabswid
.45076 1.49884 m
.44893 1.51491 L
s
0 0 0 r
2.5 Mabswid
.44893 1.51491 Mdot
.039 .916 .04 r
.5 Mabswid
.45437 1.36115 m
.45635 1.37693 L
s
0 0 0 r
2.5 Mabswid
.45635 1.37693 Mdot
.039 .916 .04 r
.5 Mabswid
.66447 .732 m
.66932 .8532 L
s
0 0 0 r
2.5 Mabswid
.66932 .8532 Mdot
.039 .916 .04 r
.5 Mabswid
.44893 1.51491 m
.44711 1.53099 L
s
0 0 0 r
2.5 Mabswid
.44711 1.53099 Mdot
.039 .916 .04 r
.5 Mabswid
.45635 1.37693 m
.47182 1.50062 L
s
0 0 0 r
2.5 Mabswid
.47182 1.50062 Mdot
.039 .916 .04 r
.5 Mabswid
.66932 .8532 m
.66996 .86905 L
s
0 0 0 r
2.5 Mabswid
.66996 .86905 Mdot
.039 .916 .04 r
.5 Mabswid
.47182 1.50062 m
.47379 1.51638 L
s
0 0 0 r
2.5 Mabswid
.47379 1.51638 Mdot
.039 .916 .04 r
.5 Mabswid
.66996 .86905 m
.6706 .88489 L
s
0 0 0 r
2.5 Mabswid
.6706 .88489 Mdot
.039 .916 .04 r
.5 Mabswid
.47379 1.51638 m
.47577 1.53213 L
s
0 0 0 r
2.5 Mabswid
.47577 1.53213 Mdot
.039 .916 .04 r
.5 Mabswid
.6706 .88489 m
.67626 1.00484 L
s
0 0 0 r
2.5 Mabswid
.67626 1.00484 Mdot
.039 .916 .04 r
.5 Mabswid
.67626 1.00484 m
.67701 1.0207 L
s
0 0 0 r
2.5 Mabswid
.67701 1.0207 Mdot
.039 .916 .04 r
.5 Mabswid
.67701 1.0207 m
.67776 1.03655 L
s
0 0 0 r
2.5 Mabswid
.67776 1.03655 Mdot
.039 .916 .04 r
.5 Mabswid
.67776 1.03655 m
.68449 1.17907 L
s
0 0 0 r
2.5 Mabswid
.68449 1.17907 Mdot
.039 .916 .04 r
.5 Mabswid
.68449 1.17907 m
.68483 1.03633 L
s
0 0 0 r
2.5 Mabswid
.68483 1.03633 Mdot
.039 .916 .04 r
.5 Mabswid
.68483 1.03633 m
.68487 1.02046 L
s
0 0 0 r
2.5 Mabswid
.68487 1.02046 Mdot
.039 .916 .04 r
.5 Mabswid
.68487 1.02046 m
.6849 1.00458 L
s
0 0 0 r
2.5 Mabswid
.6849 1.00458 Mdot
.039 .916 .04 r
.5 Mabswid
.6849 1.00458 m
.68519 .88446 L
s
0 0 0 r
2.5 Mabswid
.68519 .88446 Mdot
.039 .916 .04 r
.5 Mabswid
.68519 .88446 m
.68523 .8686 L
s
0 0 0 r
2.5 Mabswid
.68523 .8686 Mdot
.039 .916 .04 r
.5 Mabswid
.68523 .8686 m
.68527 .85273 L
s
0 0 0 r
2.5 Mabswid
.68527 .85273 Mdot
.039 .916 .04 r
.5 Mabswid
.68527 .85273 m
.68555 .73334 L
s
0 0 0 r
2.5 Mabswid
.68555 .73334 Mdot
.039 .916 .04 r
.5 Mabswid
.68555 .73334 m
.69099 .85255 L
s
0 0 0 r
2.5 Mabswid
.69099 .85255 Mdot
.039 .916 .04 r
.5 Mabswid
.69099 .85255 m
.69171 .86839 L
s
0 0 0 r
2.5 Mabswid
.69171 .86839 Mdot
.039 .916 .04 r
.5 Mabswid
.69171 .86839 m
.69244 .88423 L
s
0 0 0 r
2.5 Mabswid
.69244 .88423 Mdot
.039 .916 .04 r
.5 Mabswid
.69244 .88423 m
.6979 1.00409 L
s
0 0 0 r
2.5 Mabswid
.6979 1.00409 Mdot
.039 .916 .04 r
.5 Mabswid
.6979 1.00409 m
.69863 1.01994 L
s
0 0 0 r
2.5 Mabswid
.69863 1.01994 Mdot
.039 .916 .04 r
.5 Mabswid
.69863 1.01994 m
.69935 1.03578 L
s
0 0 0 r
2.5 Mabswid
.69935 1.03578 Mdot
.039 .916 .04 r
.5 Mabswid
.69935 1.03578 m
.70391 1.18272 L
s
0 0 0 r
2.5 Mabswid
.70391 1.18272 Mdot
.039 .916 .04 r
.5 Mabswid
.70391 1.18272 m
.70441 1.19859 L
s
0 0 0 r
2.5 Mabswid
.70441 1.19859 Mdot
.039 .916 .04 r
.5 Mabswid
.70441 1.19859 m
.7049 1.21445 L
s
0 0 0 r
2.5 Mabswid
.7049 1.21445 Mdot
.039 .916 .04 r
.5 Mabswid
.53152 3.7498 m
.97619 .76881 L
s
0 0 0 r
2.5 Mabswid
.97619 .76881 Mdot
.039 .916 .04 r
.5 Mabswid
.46893 3.74982 m
.02445 .7884 L
s
0 0 0 r
2.5 Mabswid
.02445 .7884 Mdot
.039 .916 .04 r
.5 Mabswid
.97377 .7219 m
.97619 .70537 L
s
0 0 0 r
2.5 Mabswid
.97619 .70537 Mdot
.039 .916 .04 r
.5 Mabswid
.97102 .72196 m
.814 4.06473 L
s
0 0 0 r
2.5 Mabswid
.814 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.87891 .87489 m
.80006 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80006 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.84295 .87654 m
.79864 4.06473 L
s
0 0 0 r
2.5 Mabswid
.79864 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.81548 1.02272 m
.79429 4.06473 L
s
0 0 0 r
2.5 Mabswid
.79429 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.79742 1.02433 m
.8275 4.06473 L
s
0 0 0 r
2.5 Mabswid
.8275 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.78801 1.02517 m
.79295 4.06473 L
s
0 0 0 r
2.5 Mabswid
.79295 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.77163 1.02664 m
.84177 4.06473 L
s
0 0 0 r
2.5 Mabswid
.84177 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.76445 1.02728 m
.79184 4.06473 L
s
0 0 0 r
2.5 Mabswid
.79184 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.73171 1.2049 m
.817 4.06473 L
s
0 0 0 r
2.5 Mabswid
.817 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.6984 1.20556 m
.80451 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80451 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.68504 1.20583 m
.79466 4.06473 L
s
0 0 0 r
2.5 Mabswid
.79466 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.68346 1.20586 m
.80099 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80099 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.59275 1.36205 m
.83889 4.06473 L
s
0 0 0 r
2.5 Mabswid
.83889 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.57539 1.52116 m
.80902 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80902 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.56741 1.52175 m
.82692 4.06473 L
s
0 0 0 r
2.5 Mabswid
.82692 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.55747 1.52249 m
.8022 4.06473 L
s
0 0 0 r
2.5 Mabswid
.8022 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.54926 1.52311 m
.82516 4.06473 L
s
0 0 0 r
2.5 Mabswid
.82516 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.52255 1.5251 m
.80691 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80691 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.516 1.52558 m
.81042 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81042 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.51393 1.52574 m
.79573 4.06473 L
s
0 0 0 r
2.5 Mabswid
.79573 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.48481 1.52791 m
.81121 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81121 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.45219 1.53034 m
.80569 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80569 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.43758 1.53143 m
.83283 4.06473 L
s
0 0 0 r
2.5 Mabswid
.83283 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.3898 1.3754 m
.82977 4.06473 L
s
0 0 0 r
2.5 Mabswid
.82977 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.37921 1.3761 m
.80991 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80991 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.37499 1.37637 m
.81861 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81861 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.30568 1.21338 m
.80728 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80728 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.29115 1.21366 m
.80835 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80835 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.23226 1.07484 m
.81505 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81505 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.21717 1.07618 m
.80991 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80991 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.1979 1.07791 m
.81367 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81367 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.19306 1.07834 m
.81004 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81004 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.13317 .9091 m
.82945 4.06473 L
s
0 0 0 r
2.5 Mabswid
.82945 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.02519 .74541 m
.02445 .74043 L
s
0 0 0 r
2.5 Mabswid
.02445 .74043 Mdot
.039 .916 .04 r
.5 Mabswid
.42148 1.53269 m
.80261 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80261 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.18497 1.07909 m
.79119 4.06473 L
s
0 0 0 r
2.5 Mabswid
.79119 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.95951 .6905 m
.97619 .57179 L
s
0 0 0 r
2.5 Mabswid
.97619 .57179 Mdot
.039 .916 .04 r
.5 Mabswid
.95149 .6907 m
.97619 .51176 L
s
0 0 0 r
2.5 Mabswid
.97619 .51176 Mdot
.039 .916 .04 r
.5 Mabswid
.94317 .6909 m
.97619 .44721 L
s
0 0 0 r
2.5 Mabswid
.97619 .44721 Mdot
.039 .916 .04 r
.5 Mabswid
.92712 .6913 m
.97619 .31562 L
s
0 0 0 r
2.5 Mabswid
.97619 .31562 Mdot
.039 .916 .04 r
.5 Mabswid
.92133 .69144 m
.97619 .26564 L
s
0 0 0 r
2.5 Mabswid
.97619 .26564 Mdot
.039 .916 .04 r
.5 Mabswid
.66413 1.20625 m
.8051 4.06473 L
s
0 0 0 r
2.5 Mabswid
.8051 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.34506 1.37837 m
.83969 4.06473 L
s
0 0 0 r
2.5 Mabswid
.83969 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.06956 .71256 m
.02445 .37257 L
s
0 0 0 r
2.5 Mabswid
.02445 .37257 Mdot
.039 .916 .04 r
.5 Mabswid
.06654 .71263 m
.02445 .39765 L
s
0 0 0 r
2.5 Mabswid
.02445 .39765 Mdot
.039 .916 .04 r
.5 Mabswid
.05107 .71302 m
.02445 .52068 L
s
0 0 0 r
2.5 Mabswid
.02445 .52068 Mdot
.039 .916 .04 r
.5 Mabswid
.04063 .71328 m
.02445 .59907 L
s
0 0 0 r
2.5 Mabswid
.02445 .59907 Mdot
.039 .916 .04 r
.5 Mabswid
.03421 .71344 m
.02445 .64547 L
s
0 0 0 r
2.5 Mabswid
.02445 .64547 Mdot
.039 .916 .04 r
.5 Mabswid
.26815 1.21411 m
.79752 4.06473 L
s
0 0 0 r
2.5 Mabswid
.79752 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.72784 1.20453 m
.97619 3.26092 L
s
0 0 0 r
2.5 Mabswid
.97619 3.26092 Mdot
.039 .916 .04 r
.5 Mabswid
.63982 1.35851 m
.8027 4.06473 L
s
0 0 0 r
2.5 Mabswid
.8027 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.61333 1.36028 m
.83859 4.06473 L
s
0 0 0 r
2.5 Mabswid
.83859 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.44725 1.53053 m
.80898 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80898 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.34376 1.37799 m
.81363 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81363 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.91138 .69169 m
.97619 .17651 L
s
0 0 0 r
2.5 Mabswid
.97619 .17651 Mdot
.039 .916 .04 r
.5 Mabswid
.89106 .69219 m
.962 .09914 L
s
0 0 0 r
2.5 Mabswid
.962 .09914 Mdot
.039 .916 .04 r
.5 Mabswid
.87664 .69255 m
.94501 .09914 L
s
0 0 0 r
2.5 Mabswid
.94501 .09914 Mdot
.039 .916 .04 r
.5 Mabswid
.45285 1.53106 m
.7975 4.06473 L
s
0 0 0 r
2.5 Mabswid
.7975 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.1212 .71128 m
.04974 .09914 L
s
0 0 0 r
2.5 Mabswid
.04974 .09914 Mdot
.039 .916 .04 r
.5 Mabswid
.08874 .71208 m
.02445 .20492 L
s
0 0 0 r
2.5 Mabswid
.02445 .20492 Mdot
.039 .916 .04 r
.5 Mabswid
.87031 .87529 m
.83006 4.06473 L
s
0 0 0 r
2.5 Mabswid
.83006 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.78972 1.02499 m
.79002 4.06473 L
s
0 0 0 r
2.5 Mabswid
.79002 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.68646 1.20587 m
.79855 4.06473 L
s
0 0 0 r
2.5 Mabswid
.79855 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.63591 1.35931 m
.81613 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81613 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.61348 1.3606 m
.82972 4.06473 L
s
0 0 0 r
2.5 Mabswid
.82972 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.44616 1.53079 m
.83946 4.06473 L
s
0 0 0 r
2.5 Mabswid
.83946 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.38616 1.37561 m
.83233 4.06473 L
s
0 0 0 r
2.5 Mabswid
.83233 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.36143 1.37722 m
.80341 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80341 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.14465 .90857 m
.81909 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81909 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.12819 .90933 m
.84487 4.06473 L
s
0 0 0 r
2.5 Mabswid
.84487 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.27352 1.21382 m
.81079 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81079 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.84114 .69343 m
.90316 .09914 L
s
0 0 0 r
2.5 Mabswid
.90316 .09914 Mdot
.039 .916 .04 r
.5 Mabswid
.76547 1.02721 m
.82514 4.06473 L
s
0 0 0 r
2.5 Mabswid
.82514 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.26741 1.21397 m
.84551 4.06473 L
s
0 0 0 r
2.5 Mabswid
.84551 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.36686 1.37672 m
.81819 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81819 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.55583 1.52242 m
.80883 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80883 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.75255 .69563 m
.79865 .09914 L
s
0 0 0 r
2.5 Mabswid
.79865 .09914 Mdot
.039 .916 .04 r
.5 Mabswid
.22893 .70861 m
.17804 .09914 L
s
0 0 0 r
2.5 Mabswid
.17804 .09914 Mdot
.039 .916 .04 r
.5 Mabswid
.52538 1.5248 m
.2292 4.06473 L
s
0 0 0 r
2.5 Mabswid
.2292 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.50628 1.5264 m
.80428 4.06473 L
s
0 0 0 r
2.5 Mabswid
.80428 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.43646 1.53135 m
.82526 4.06473 L
s
0 0 0 r
2.5 Mabswid
.82526 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.34218 1.3787 m
.83085 4.06473 L
s
0 0 0 r
2.5 Mabswid
.83085 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.26475 1.21436 m
.81491 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81491 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.72249 1.20549 m
.83958 4.06473 L
s
0 0 0 r
2.5 Mabswid
.83958 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.57405 1.36312 m
.83966 4.06473 L
s
0 0 0 r
2.5 Mabswid
.83966 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.46147 1.52982 m
.81793 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81793 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.6427 .69893 m
.5693 .09914 L
s
0 0 0 r
2.5 Mabswid
.5693 .09914 Mdot
.039 .916 .04 r
.5 Mabswid
.63201 .69898 m
.55882 .09914 L
s
0 0 0 r
2.5 Mabswid
.55882 .09914 Mdot
.039 .916 .04 r
.5 Mabswid
.4903 .70213 m
.48845 .09914 L
s
0 0 0 r
2.5 Mabswid
.48845 .09914 Mdot
.039 .916 .04 r
.5 Mabswid
.4447 .70326 m
.43439 .09914 L
s
0 0 0 r
2.5 Mabswid
.43439 .09914 Mdot
.039 .916 .04 r
.5 Mabswid
.63138 1.36028 m
.79894 4.06473 L
s
0 0 0 r
2.5 Mabswid
.79894 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.30008 1.21474 m
.81122 4.06473 L
s
0 0 0 r
2.5 Mabswid
.81122 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.49738 .70136 m
.47853 .09914 L
s
0 0 0 r
2.5 Mabswid
.47853 .09914 Mdot
.039 .916 .04 r
.5 Mabswid
.39042 1.37507 m
.7951 4.06473 L
s
0 0 0 r
2.5 Mabswid
.7951 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.44711 1.53099 m
.15897 4.06473 L
s
0 0 0 r
2.5 Mabswid
.15897 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.47577 1.53213 m
.79262 4.06473 L
s
0 0 0 r
2.5 Mabswid
.79262 4.06473 Mdot
.039 .916 .04 r
.5 Mabswid
.7049 1.21445 m
.79348 4.06473 L
s
0 0 0 r
2.5 Mabswid
.79348 4.06473 Mdot
0 0 m
1 0 L
1 4.16387 L
0 4.16387 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{303.5, 1263.69},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004_0004kb000`400?l00000o`00003oo`3oool`
0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`
0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`
0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`
0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`
0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`
0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`
0?ooo`001`3ooooo0000028000001`3oool000L0oooo00<000000?ooo`3oool0103oool2000002D0
oooo0P00001;0?ooo`800000303oool2000000030?ooo`000000000001<0oooo0P0000000`3oool0
0000000000130?ooo`8000007P3oool2000000/0oooo0P0000030?ooo`8000000`3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo02<0oooo
00<02NX:0?ooo`3oool0B`3oool00`09jPX0oooo0?ooo`0:0?ooo`0400WZ2P3oool0oooo00WZ2QD0
oooo00@02NX:0?ooo`3oool02NX:A03oool00`09jPX0oooo0?ooo`0M0?ooo`0300WZ2P3oool0oooo
00T0oooo00<02NX:0?ooo`3oool00`3oool01@09jPX0oooo0?ooo`3oool0000000L0oooo00070?oo
o`030000003oool0oooo00D0oooo00<02NX:0?ooo`3oool08`3oool00`09jPX0oooo0?ooo`1;0?oo
o`0300WZ2P3oool0oooo00X0oooo00@02NX:0?ooo`3oool02NX:5@3oool01009jPX0oooo0?ooo`09
jPY40?ooo`0300WZ2P3oool0oooo01d0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?oo
o`030?ooo`0500WZ2P3oool0oooo0?ooo`0000001`3oool000L0oooo00<000000?ooo`3oool01@3o
ool00`09jPX0oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo04/0oooo00<02NX:0?ooo`3oool02P3o
ool01009jPX0oooo0?ooo`09jPXE0?ooo`0400WZ2P3oool0oooo00WZ2T@0oooo00<02NX:0?ooo`3o
ool07@3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00<0oooo00D02NX:0?ooo`3o
ool0oooo000000070?ooo`001`3oool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0280
oooo00<02NX:0?ooo`3oool0B`3oool00`09jPX0oooo0?ooo`0:0?ooo`0400WZ2P3oool0oooo00WZ
2QH0oooo00@02NX:0?ooo`3oool02NX:@`3oool00`09jPX0oooo0?ooo`0M0?ooo`0300WZ2P3oool0
oooo00P0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo00H0oooo00<02NX:0?ooo`3oool08P3oool00`09
jPX0oooo0?ooo`1;0?ooo`0300WZ2P3oool0oooo00X0oooo00@02NX:0?ooo`3oool02NX:5P3oool0
1009jPX0oooo0?ooo`09jPY30?ooo`0300WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3oool02@3o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool000L0oooo00<000000?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0S0?ooo`0300WZ2P3oool0
oooo04X0oooo00<02NX:0?ooo`3oool02P3oool01009jPX0oooo0?ooo`09jPXF0?ooo`0400WZ2P3o
ool0oooo00WZ2T80oooo00<02NX:0?ooo`3oool07@3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo02<0oooo00<02NX:0?ooo`3oool0BP3o
ool00`09jPX0oooo0?ooo`0:0?ooo`0400WZ2P3oool0oooo00WZ2QH0oooo00@02NX:0?ooo`3oool0
2NX:@P3oool00`09jPX0oooo0?ooo`0M0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3o
ool00`3oool00`09jPX0oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo00H0oooo00<02NX:0?ooo`3oool08`3oool00`09jPX0oooo0?ooo`1:0?ooo`0300WZ
2P3oool0oooo00X0oooo00@02NX:0?ooo`3oool02NX:5P3oool01009jPX0oooo0?ooo`09jPY20?oo
o`0300WZ2P3oool0oooo01d0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`030?oo
o`0300WZ2P3oool0oooo0080oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool01P3oool00`09jPX0oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo04X0oooo00<02NX:0?ooo`3o
ool02P3oool01009jPX0oooo0?ooo`09jPXF0?ooo`0400WZ2P3oool0oooo00WZ2T80oooo00<02NX:
0?ooo`3oool07@3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`060?oo
o`0300WZ2P3oool0oooo02<0oooo00<02NX:0?ooo`3oool0BP3oool00`09jPX0oooo0?ooo`0:0?oo
o`0400WZ2P3oool0oooo00WZ2QH0oooo00@02NX:0?ooo`3oool02NX:@P3oool00`09jPX0oooo0?oo
o`0M0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00H0oooo00<02NX:
0?ooo`3oool08`3oool00`09jPX0oooo0?ooo`1:0?ooo`0300WZ2P3oool0oooo00X0oooo00@02NX:
0?ooo`3oool02NX:5P3oool01009jPX0oooo0?ooo`09jPY20?ooo`0300WZ2P3oool0oooo01d0oooo
00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0080oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool01P3oool00`09jPX0oooo0?oo
o`0S0?ooo`0300WZ2P3oool0oooo04X0oooo00<02NX:0?ooo`3oool02P3oool01009jPX0oooo0?oo
o`09jPXG0?ooo`0400WZ2P3oool0oooo00WZ2T40oooo00<02NX:0?ooo`3oool07@3oool00`09jPX0
oooo0?ooo`090?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0280oooo
00<02NX:0?ooo`3oool0BP3oool00`09jPX0oooo0?ooo`0:0?ooo`0400WZ2P3oool0oooo00WZ2QL0
oooo00@02NX:0?ooo`3oool02NX:@@3oool00`09jPX0oooo0?ooo`0M0?ooo`0300WZ2P3oool0oooo
00P0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo00L0oooo00<02NX:0?ooo`3oool08P3oool00`09jPX0
oooo0?ooo`1:0?ooo`0300WZ2P3oool0oooo00X0oooo00@02NX:0?ooo`3oool02NX:5`3oool01009
jPX0oooo0?ooo`09jPY10?ooo`0300WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3oool02@3oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo
04X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo00WZ2P0G0?ooo`0400WZ2P3oool0oooo
00WZ2T40oooo00<02NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0280oooo00<02NX:0?ooo`3oool0BP3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool02NX:01L0oooo00@02NX:0?ooo`3oool02NX:@@3oool0
0`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
00L0oooo00<02NX:0?ooo`3oool08`3oool00`09jPX0oooo0?ooo`190?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`09jPX05`3oool01009jPX0oooo0?ooo`09jPY10?ooo`0300WZ2P3oool0
oooo01`0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool01`3oool00`09
jPX0oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo04T0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo00WZ2P0G0?ooo`0400WZ2P3oool0oooo00WZ2T40oooo00<02NX:0?ooo`3oool0703oool0
0`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`070?ooo`0300WZ2P3oool0oooo
02<0oooo00<02NX:0?ooo`3oool0B@3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool02NX:
01L0oooo00@02NX:0?ooo`3oool02NX:@03oool00`09jPX0oooo0?ooo`0M0?ooo`0300WZ2P3oool0
oooo00T0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`030?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo00L0oooo00<02NX:0?ooo`3oool08`3oool00`09
jPX0oooo0?ooo`190?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`09jPX05`3oool01009
jPX0oooo0?ooo`09jPY00?ooo`0300WZ2P3oool0oooo01d0oooo00<02NX:0?ooo`3oool02@3oool0
0`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo
04T0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo00WZ2P0H0?ooo`0400WZ2P3oool0oooo
00WZ2Sl0oooo00<02NX:0?ooo`3oool07@3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0
oooo0080oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0280oooo00<02NX:0?ooo`3oool0B@3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool02NX:01P0oooo00@02NX:0?ooo`3oool02NX:?`3oool0
0`09jPX0oooo0?ooo`0M0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
00P0oooo00<02NX:0?ooo`3oool08P3oool00`09jPX0oooo0?ooo`190?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`09jPX0603oool01009jPX0oooo0?ooo`09jPXo0?ooo`0300WZ2P3oool0
oooo01d0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo00<0oooo0P0000070?ooo`001`3oool00`000000oooo0?ooo`080?ooo`0300WZ2P3oool0oooo
0280oooo00<02NX:0?ooo`3oool0B@3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool02NX:
01P0oooo00@02NX:0?ooo`3oool02NX:?`3oool00`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0
oooo00T0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`030?ooo`8000001`3oool0
00L0oooo00<000000?ooo`3oool0203oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo
04T0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo00WZ2P0H0?ooo`0400WZ2P3oool0oooo
00WZ2Sl0oooo00<02NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0280oooo00<02NX:0?ooo`3oool0B@3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool02NX:01P0oooo00@02NX:0?ooo`3oool02NX:?`3oool0
0`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00D0oooo00070?ooo`030000003oool0oooo
00P0oooo00<02NX:0?ooo`3oool08P3oool00`09jPX0oooo0?ooo`190?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`09jPX0603oool01009jPX0oooo0?ooo`09jPXo0?ooo`0300WZ2P3oool0
oooo01`0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0203oool00`09
jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo04T0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo00WZ2P0H0?ooo`0400WZ2P3oool0oooo00WZ2Sl0oooo00<02NX:0?ooo`3oool0703oool0
0`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX000000?ooo`060?ooo`001`3oool00`000000oooo0?ooo`080?ooo`0300WZ2P3oool0oooo
02<0oooo00<02NX:0?ooo`3oool0B03oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool02NX:
01T0oooo00@02NX:0?ooo`3oool02NX:?P3oool00`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0
oooo00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P000000
oooo00H0oooo00070?ooo`030000003oool0oooo00P0oooo00<02NX:0?ooo`3oool08`3oool00`09
jPX0oooo0?ooo`190?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`09jPX06@3oool01009
jPX0oooo0?ooo`09jPXn0?ooo`0300WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3oool02@3oool0
0`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0000003oool01P3oool0
00H0oooo0P00000;0?ooo`0300WZ2P3oool0oooo0280oooo00<02NX:0?ooo`3oool0B@3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool02NX:01T0oooo00@02NX:0?ooo`3oool02NX:?P3oool0
0`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P000000oooo00H0oooo00060?ooo`8000002`3oool00`09
jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo04T0oooo00<02NX:0?ooo`3oool02P3oool00`09
jPX0oooo00WZ2P0I0?ooo`0400WZ2P3oool0oooo00WZ2Sd0oooo00<02NX:0?ooo`3oool07@3oool0
0`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX000000?ooo`060?ooo`001`3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo
0280oooo00<02NX:0?ooo`3oool0B@3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool02NX:
01T0oooo00@02NX:0?ooo`3oool02NX:?@3oool00`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0
oooo00T0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P000000
oooo00H0oooo00070?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool08P3oool00`09
jPX0oooo0?ooo`190?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`09jPX06@3oool01009
jPX0oooo0?ooo`09jPXm0?ooo`0300WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3oool02@3oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0000003oool01P3oool0
00L0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo
04T0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo00WZ2P0I0?ooo`0400WZ2P3oool0oooo
00WZ2Sd0oooo00<02NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX000000?ooo`060?ooo`001`3oool00`00
00002NX:0?ooo`090?ooo`0300WZ2P3oool0oooo0280oooo00<02NX:0?ooo`3oool0B@3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool02NX:01T0oooo00@02NX:0?ooo`3oool02NX:?@3oool0
0`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0000000L0oooo00070?ooo`0300000009jPX0oooo
00T0oooo00<02NX:0?ooo`3oool08P3oool00`09jPX0oooo0?ooo`190?ooo`0300WZ2P3oool0oooo
00X0oooo00<02NX:0?ooo`09jPX06P3oool01009jPX0oooo0?ooo`09jPXl0?ooo`0300WZ2P3oool0
oooo01`0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`0000001`3oool000L0oooo00<0000000WZ2P3oool02@3oool00`09
jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo04T0oooo00<02NX:0?ooo`3oool02P3oool00`09
jPX0oooo00WZ2P0J0?ooo`0400WZ2P3oool0oooo00WZ2S`0oooo00<02NX:0?ooo`3oool0703oool0
0`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo000000070?ooo`001`3oool00`0000002NX:0?ooo`090?ooo`0300WZ2P3oool0oooo
0280oooo00<02NX:0?ooo`3oool0B@3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool02NX:
01X0oooo00@02NX:0?ooo`3oool02NX:?03oool00`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0
oooo00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
000000L0oooo00070?ooo`0300000009jPX0oooo00X0oooo00<02NX:0?ooo`3oool08P3oool00`09
jPX0oooo0?ooo`180?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`09jPX06P3oool01009
jPX0oooo0?ooo`09jPXl0?ooo`0300WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3oool0203oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`0000001`3oool0
00L0oooo00<0000000WZ2P3oool02P3oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo
04P0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo00WZ2P0J0?ooo`0400WZ2P3oool0oooo
00WZ2S`0oooo00<02NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo000000070?ooo`001`3oool00`00
00002NX:0?ooo`0:0?ooo`0300WZ2P3oool0oooo0280oooo00<02NX:0?ooo`3oool0B03oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool02NX:01X0oooo00@02NX:0?ooo`3oool02NX:?03oool0
0`09jPX0oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0000000L0oooo00070?ooo`0300000009jPX0oooo
00X0oooo00<02NX:0?ooo`3oool08P3oool00`09jPX0oooo0?ooo`180?ooo`0300WZ2P3oool0oooo
00X0oooo00<02NX:0?ooo`09jPX06P3oool01009jPX0oooo0?ooo`09jPXl0?ooo`0300WZ2P3oool0
oooo01/0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo00<0oooo00@02NX:0?ooo`3oool000001`3oool000L0oooo00<000000?ooo`09jPX02P3oool0
0`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo04P0oooo00<02NX:0?ooo`3oool02P3oool0
0`09jPX0oooo00WZ2P0J0?ooo`0400WZ2P3oool0oooo00WZ2S`0oooo00<02NX:0?ooo`3oool06`3o
ool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool00`3o
ool01009jPX0oooo0?ooo`0000070?ooo`001`3oool00`000000oooo00WZ2P0:0?ooo`0300WZ2P3o
ool0oooo0280oooo00<02NX:0?ooo`3oool0B03oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3o
ool02NX:01/0oooo00@02NX:0?ooo`3oool02NX:>P3oool00`09jPX0oooo0?ooo`0L0?ooo`0300WZ
2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`0400WZ
2P3oool0oooo000000L0oooo00070?ooo`030000003oool02NX:00X0oooo00<02NX:0?ooo`3oool0
8P3oool00`09jPX0oooo0?ooo`180?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPXK0?ooo`0400WZ
2P3oool0oooo00WZ2SX0oooo00<02NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`090?ooo`03
00WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool01009jPX0oooo0?ooo`0000070?oo
o`001`3oool00`000000oooo00WZ2P0:0?ooo`0300WZ2P3oool0oooo0280oooo00<02NX:0?ooo`3o
ool0B03oool00`09jPX0oooo0?ooo`0;0?ooo`802NX:6`3oool01009jPX0oooo0?ooo`09jPXj0?oo
o`0300WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`020?oo
o`0300WZ2P3oool0oooo00@0oooo00@02NX:0?ooo`3oool000001`3oool000L0oooo00<000000?oo
o`09jPX02P3oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo04P0oooo00<02NX:0?oo
o`3oool02`3oool200WZ2Q/0oooo00@02NX:0?ooo`3oool02NX:>P3oool00`09jPX0oooo0?ooo`0L
0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`04
0?ooo`0400WZ2P3oool0oooo000000L0oooo00070?ooo`030000003oool02NX:00/0oooo00<02NX:
0?ooo`3oool08@3oool00`09jPX0oooo0?ooo`180?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPXK
0?ooo`0400WZ2P3oool0oooo00WZ2SX0oooo00<02NX:0?ooo`3oool0703oool00`09jPX0oooo0?oo
o`080?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool01009jPX0oooo0000
000000070?ooo`001`3oool00`000000oooo00WZ2P0;0?ooo`0300WZ2P3oool0oooo0240oooo00<0
2NX:0?ooo`3oool0B03oool00`09jPX0oooo0?ooo`0;0?ooo`802NX:6`3oool01009jPX0oooo0?oo
o`09jPXj0?ooo`0300WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00@02NX:0?ooo`00000000001`3oool000L0oooo
00<000000?ooo`09jPX02`3oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo04P0oooo
00<02NX:0?ooo`3oool02`3oool200WZ2Q/0oooo00@02NX:0?ooo`3oool02NX:>P3oool00`09jPX0
oooo0?ooo`0L0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0
oooo0?ooo`030?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01`3oool000L0oooo00@000000?ooo`3o
ool02NX:2P3oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo04L0oooo00<02NX:0?oo
o`3oool02`3oool200WZ2Q/0oooo00@02NX:0?ooo`3oool02NX:>P3oool00`09jPX0oooo0?ooo`0K
0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`03
0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01`3oool000L0oooo00@000000?ooo`3oool02NX:2P3o
ool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo04L0oooo00<02NX:0?ooo`3oool02`3o
ool200WZ2Q/0oooo00@02NX:0?ooo`3oool02NX:>P3oool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ
2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX01`3oool000L0oooo00@000000?ooo`3oool02NX:2P3oool00`09jPX0
oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo04L0oooo00<02NX:0?ooo`3oool02`3oool200WZ2Q`0
oooo00@02NX:0?ooo`3oool02NX:>@3oool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo
00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`0500WZ2P3oool0oooo
0?ooo`09jPX01`3oool000L0oooo00@000000?ooo`3oool02NX:2P3oool00`09jPX0oooo0?ooo`0R
0?ooo`0300WZ2P3oool0oooo04L0oooo00<02NX:0?ooo`3oool02`3oool200WZ2Q`0oooo00@02NX:
0?ooo`3oool02NX:>@3oool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo00T0oooo00<0
2NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`0500WZ2P3oool0oooo00WZ2P000000
1`3oool000L0oooo00@000000?ooo`3oool02NX:2P3oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ
2P3oool0oooo04L0oooo00<02NX:0?ooo`3oool02`3oool200WZ2Q`0oooo00@02NX:0?ooo`3oool0
2NX:>@3oool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3o
ool00P3oool00`09jPX0oooo0?ooo`040?ooo`0500WZ2P3oool0oooo00WZ2P0000001`3oool000L0
oooo00@000000?ooo`3oool02NX:2P3oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo
04L0oooo00<02NX:0?ooo`3oool02`3oool200WZ2Q`0oooo00@02NX:0?ooo`3oool02NX:>@3oool0
0`09jPX0oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3oool0
0`09jPX0oooo0?ooo`040?ooo`0500WZ2P3oool0oooo00WZ2P0000001`3oool000L0oooo00@00000
0?ooo`3oool02NX:2`3oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo04L0oooo00<0
2NX:0?ooo`3oool02`3oool200WZ2Q`0oooo00@02NX:0?ooo`3oool02NX:>03oool00`09jPX0oooo
0?ooo`0L0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`040?ooo`0500WZ2P3oool0oooo00WZ2P0000001`3oool000L0oooo00@000000?ooo`3oool0
2NX:2`3oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo04L0oooo00<02NX:0?ooo`3o
ool02`3oool200WZ2Q`0oooo00@02NX:0?ooo`3oool02NX:>03oool00`09jPX0oooo0?ooo`0L0?oo
o`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`030?oo
o`0600WZ2P3oool0oooo0?ooo`09jPX000001`3oool000L0oooo00D000000?ooo`3oool0oooo00WZ
2P0:0?ooo`0300WZ2P3oool0oooo0240oooo00<02NX:0?ooo`3oool0A`3oool00`09jPX0oooo0?oo
o`0;0?ooo`802NX:703oool01009jPX0oooo0?ooo`09jPXh0?ooo`0300WZ2P3oool0oooo01`0oooo
00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00<0oooo
00H02NX:0?ooo`3oool0oooo00WZ2P0000070?ooo`001`3oool01@000000oooo0?ooo`3oool02NX:
00X0oooo00<02NX:0?ooo`3oool08@3oool00`09jPX0oooo0?ooo`170?ooo`0300WZ2P3oool0oooo
00/0oooo0P09jPXL0?ooo`0400WZ2P3oool0oooo00WZ2SP0oooo00<02NX:0?ooo`3oool0703oool0
0`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool0
1P09jPX0oooo0?ooo`3oool02NX:000000L0oooo00070?ooo`050000003oool0oooo0?ooo`09jPX0
2P3oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo04L0oooo00<02NX:0?ooo`3oool0
2`3oool200WZ2Qd0oooo00@02NX:0?ooo`3oool02NX:=`3oool00`09jPX0oooo0?ooo`0K0?ooo`03
00WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`06
00WZ2P3oool0oooo00WZ2P3oool000001`3oool000L0oooo00D000000?ooo`3oool0oooo00WZ2P0:
0?ooo`0300WZ2P3oool0oooo0240oooo00<02NX:0?ooo`3oool0A`3oool00`09jPX0oooo0?ooo`0;
0?ooo`802NX:7@3oool01009jPX0oooo0?ooo`09jPXg0?ooo`0300WZ2P3oool0oooo01/0oooo00<0
2NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00H0
2NX:0?ooo`3oool02NX:0?ooo`0000070?ooo`001`3oool01@000000oooo0?ooo`3oool02NX:00X0
oooo00<02NX:0?ooo`3oool08P3oool00`09jPX0oooo0?ooo`160?ooo`0300WZ2P3oool0oooo00/0
oooo0P09jPXM0?ooo`0400WZ2P3oool0oooo00WZ2SL0oooo00<02NX:0?ooo`3oool06`3oool00`09
jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool01P09
jPX0oooo0?ooo`09jPX0oooo000000L0oooo00070?ooo`050000003oool0oooo0?ooo`09jPX02P3o
ool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo04H0oooo00<02NX:0?ooo`3oool02`3o
ool200WZ2Qd0oooo00@02NX:0?ooo`3oool02NX:=`3oool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ
2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`0400WZ
2P3oool0oooo00WZ2P8000001`3oool000L0oooo00D000000?ooo`3oool0oooo00WZ2P0;0?ooo`03
00WZ2P3oool0oooo0240oooo00<02NX:0?ooo`3oool0AP3oool00`09jPX0oooo0?ooo`0;0?ooo`80
2NX:7@3oool01009jPX0oooo0?ooo`09jPXg0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?oo
o`3oool02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00@02NX:0?oo
o`3oool02NX:0P0000070?ooo`001`3oool01@000000oooo0?ooo`3oool02NX:00/0oooo00<02NX:
0?ooo`3oool08@3oool00`09jPX0oooo0?ooo`160?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPXM
0?ooo`0400WZ2P3oool0oooo00WZ2SL0oooo00<02NX:0?ooo`3oool06`3oool00`09jPX0oooo0?oo
o`080?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool00`3oool01`09jPX0oooo0?oo
o`3oool02NX:0?ooo`09jPX01`3oool000L0oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo
0?ooo`080?ooo`0300WZ2P3oool0oooo0240oooo00<02NX:0?ooo`3oool0AP3oool00`09jPX0oooo
0?ooo`0;0?ooo`802NX:7@3oool01009jPX0oooo0?ooo`09jPXg0?ooo`0300WZ2P3oool0oooo01/0
oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00<0
oooo00L02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:00L0oooo00070?ooo`030000003oool0oooo
0080oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo
04H0oooo00<02NX:0?ooo`3oool02`3oool200WZ2Qd0oooo00@02NX:0?ooo`3oool02NX:=`3oool0
0`09jPX0oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`030?ooo`0700WZ2P3oool0oooo0?ooo`09jPX0oooo00WZ2P070?ooo`001`3o
ool00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool08@3o
ool00`09jPX0oooo0?ooo`160?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPXN0?ooo`0400WZ2P3o
ool0oooo00WZ2SH0oooo00<02NX:0?ooo`3oool06`3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool01`09jPX0oooo0?ooo`09jPX0oooo00WZ
2P0000001`3oool000L0oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`080?ooo`03
00WZ2P3oool0oooo0240oooo00<02NX:0?ooo`3oool0AP3oool00`09jPX0oooo0?ooo`0;0?ooo`80
2NX:7P3oool01009jPX0oooo0?ooo`09jPXe0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?oo
o`3oool02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00L02NX:0?oo
o`3oool02NX:0?ooo`09jPX0000000L0oooo00070?ooo`030000003oool0oooo0080oooo00<02NX:
0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo04H0oooo00<02NX:
0?ooo`3oool02`3oool200WZ2Qh0oooo00@02NX:0?ooo`3oool02NX:=@3oool00`09jPX0oooo0?oo
o`0K0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?oo
o`040?ooo`0700WZ2P3oool0oooo00WZ2P3oool02NX:000000070?ooo`001`3oool00`000000oooo
0?ooo`020?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool08@3oool00`09jPX0oooo
0?ooo`160?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPXN0?ooo`0400WZ2P3oool0oooo00WZ2SD0
oooo00<02NX:0?ooo`3oool06`3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo0080
oooo00<02NX:0?ooo`3oool0103oool01`09jPX0oooo0?ooo`09jPX0oooo00WZ2P0000001`3oool0
00L0oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo
0240oooo00<02NX:0?ooo`3oool0AP3oool00`09jPX0oooo0?ooo`0;0?ooo`802NX:7P3oool01009
jPX0oooo0?ooo`09jPXe0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool02@3oool0
0`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00L02NX:0?ooo`3oool02NX:0?oo
o`09jPX0000000L0oooo00070?ooo`030000003oool0oooo0080oooo00<02NX:0?ooo`3oool02@3o
ool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo04D0oooo00<02NX:0?ooo`3oool02`3o
ool200WZ2Qh0oooo00@02NX:0?ooo`3oool02NX:=@3oool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ
2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`0800WZ
2P3oool0oooo0?ooo`09jPX0oooo00WZ2P0000070?ooo`001`3oool00`000000oooo0?ooo`020?oo
o`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool08@3oool00`09jPX0oooo0?ooo`150?oo
o`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool0703oool01009jPX0oooo0?ooo`09jPXe
0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo00<0oooo00P02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:000000L0
oooo00070?ooo`030000003oool0oooo00<0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo
0?ooo`0Q0?ooo`0300WZ2P3oool0oooo04D0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo
0?ooo`0L0?ooo`0400WZ2P3oool0oooo00WZ2SD0oooo00<02NX:0?ooo`3oool06`3oool00`09jPX0
oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool00`3oool01009jPX0
oooo0?ooo`3oool200WZ2P030?ooo`000000oooo00H0oooo00070?ooo`030000003oool0oooo00<0
oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo04D0
oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0L0?ooo`0400WZ2P3oool0oooo00WZ
2SD0oooo00<02NX:0?ooo`3oool06`3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo
0080oooo00<02NX:0?ooo`3oool0103oool02009jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool00000
1`3oool000L0oooo00<000000?ooo`3oool00`3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3o
ool0oooo0240oooo00<02NX:0?ooo`3oool0A@3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3o
ool0oooo01d0oooo00@02NX:0?ooo`3oool02NX:=03oool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ
2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`0800WZ
2P3oool0oooo00WZ2P3oool02NX:0?ooo`0000070?ooo`001`3oool00`000000oooo0?ooo`030?oo
o`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool08@3oool00`09jPX0oooo0?ooo`150?oo
o`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool07@3oool01009jPX0oooo0?ooo`09jPXd
0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`02
0?ooo`0300WZ2P3oool0oooo00@0oooo00P02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo000000L0
oooo00070?ooo`030000003oool0oooo00<0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo
0?ooo`0Q0?ooo`0300WZ2P3oool0oooo04D0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo
0?ooo`0M0?ooo`0400WZ2P3oool0oooo00WZ2S@0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0
oooo0?ooo`090?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool02009jPX0
oooo0?ooo`09jPX0oooo00WZ2P3oool000001`3oool000H0oooo0P0000050?ooo`0300WZ2P3oool0
oooo00P0oooo00<02NX:0?ooo`3oool08@3oool00`09jPX0oooo0?ooo`150?ooo`0300WZ2P3oool0
oooo00`0oooo00<02NX:0?ooo`3oool07@3oool01009jPX0oooo0?ooo`09jPXd0?ooo`0300WZ2P3o
ool0oooo01X0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3o
ool0oooo00<0oooo00T02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:0?ooo`0000001`3oool000H0
oooo0P0000050?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool08@3oool00`09jPX0
oooo0?ooo`150?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool07@3oool01009jPX0
oooo0?ooo`09jPXd0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool02@3oool00`09
jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00T02NX:0?ooo`3oool0oooo00WZ2P3o
ool02NX:0?ooo`0000001`3oool000L0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`090?ooo`0300WZ2P3oool0oooo0200oooo00<02NX:0?ooo`3oool0A@3oool00`09jPX0oooo0?oo
o`0<0?ooo`0300WZ2P3oool0oooo01d0oooo00@02NX:0?ooo`3oool02NX:<`3oool00`09jPX0oooo
0?ooo`0K0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo
0?ooo`030?ooo`0900WZ2P3oool0oooo0?ooo`09jPX0oooo00WZ2P3oool0000000L0oooo00070?oo
o`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0P0?oo
o`0300WZ2P3oool0oooo04D0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0M0?oo
o`0400WZ2P3oool0oooo00WZ2S<0oooo00<02NX:0?ooo`3oool06`3oool00`09jPX0oooo0?ooo`08
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool00`3oool01P09jPX0oooo0?ooo`09
jPX0oooo00WZ2P80oooo00<000000?ooo`3oool01@3oool000L0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0200oooo00<02NX:0?ooo`3oool0A@3o
ool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo01d0oooo00@02NX:0?ooo`3oool02NX:
<`3oool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0
0P3oool00`09jPX0oooo0?ooo`040?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:0P3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`0000002NX:0?ooo`040?ooo`0300WZ2P3oool0oooo00P0
oooo00<02NX:0?ooo`3oool08@3oool00`09jPX0oooo0?ooo`140?ooo`0300WZ2P3oool0oooo00`0
oooo00<02NX:0?ooo`3oool07P3oool01009jPX0oooo0?ooo`09jPXb0?ooo`0300WZ2P3oool0oooo
01/0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo
00@0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX20?ooo`030000003oool0oooo00D0oooo0007
0?ooo`0300000009jPX0oooo00@0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0Q
0?ooo`0300WZ2P3oool0oooo04@0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0N
0?ooo`0400WZ2P3oool0oooo00WZ2S80oooo00<02NX:0?ooo`3oool06`3oool00`09jPX0oooo0?oo
o`080?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool01P09jPX0oooo0?oo
o`09jPX0oooo00WZ2P80oooo00<000000?ooo`3oool01@3oool000H0oooo0P0000000`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool08@3oool00`09jPX0oooo
0?ooo`140?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool07P3oool01009jPX0oooo
0?ooo`09jPXb0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX2
0?ooo`030000003oool0oooo00D0oooo00060?ooo`80000000<02NX:0?ooo`3oool00`3oool00`09
jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0240oooo00<02NX:0?ooo`3oool0A03oool00`09
jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo01h0oooo00@02NX:0?ooo`3oool02NX:<P3oool0
0`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3oool0
0`09jPX0oooo0?ooo`030?ooo`0700WZ2P3oool0oooo0?ooo`09jPX0oooo00WZ2P020?ooo`030000
003oool0oooo00D0oooo00070?ooo`802NX:1@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3o
ool0oooo0240oooo00<02NX:0?ooo`3oool0A@3oool00`09jPX0oooo0?ooo`0;0?ooo`802NX:7`3o
ool01009jPX0oooo0?ooo`09jPXb0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool0
2@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00L02NX:0?ooo`3oool0
oooo00WZ2P3oool02NX:0080oooo00<000000?ooo`3oool01@3oool000L0oooo0P09jPX50?ooo`03
00WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool08@3oool00`09jPX0oooo0?ooo`150?ooo`03
00WZ2P3oool0oooo00/0oooo0P09jPXO0?ooo`0400WZ2P3oool0oooo00WZ2S80oooo00<02NX:0?oo
o`3oool06P3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?oo
o`3oool00`3oool01009jPX0oooo0?ooo`3oool200WZ2P<0oooo00<000000?ooo`3oool01@3oool0
00L0oooo0P09jPX60?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0803oool00`09
jPX0oooo0?ooo`150?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPXO0?ooo`0400WZ2P3oool0oooo
00WZ2S80oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0
oooo0080oooo00<02NX:0?ooo`3oool00`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P<0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<02NX:0?ooo`09jPX01@3oool00`09jPX0oooo0?oo
o`080?ooo`0300WZ2P3oool0oooo0200oooo00<02NX:0?ooo`3oool0A@3oool00`09jPX0oooo0?oo
o`0;0?ooo`802NX:7`3oool01009jPX0oooo0?ooo`09jPXb0?ooo`0300WZ2P3oool0oooo01X0oooo
00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo
00H02NX:0?ooo`3oool02NX:0?ooo`09jPX30?ooo`030000003oool0oooo00D0oooo00070?ooo`03
00000009jPX02NX:00D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0P0?ooo`03
00WZ2P3oool0oooo04D0oooo00<02NX:0?ooo`3oool02`3oool200WZ2R00oooo00@02NX:0?ooo`3o
ool02NX:<@3oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?oo
o`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:0`3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`0000002NX:00WZ2P050?ooo`0300WZ2P3oool0
oooo00P0oooo00<02NX:0?ooo`3oool0803oool00`09jPX0oooo0?ooo`150?ooo`0300WZ2P3oool0
oooo00/0oooo0P09jPXP0?ooo`0400WZ2P3oool0oooo00WZ2S40oooo00<02NX:0?ooo`3oool06P3o
ool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103o
ool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P<0oooo00<000000?ooo`3oool01@3oool000L0oooo
00<0000000WZ2P09jPX01@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0200oooo
00<02NX:0?ooo`3oool0A@3oool00`09jPX0oooo0?ooo`0;0?ooo`802NX:803oool01009jPX0oooo
0?ooo`09jPX`0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX3
0?ooo`030000003oool0oooo00D0oooo00070?ooo`0300000009jPX02NX:00D0oooo00<02NX:0?oo
o`3oool0203oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo04@0oooo00<02NX:0?oo
o`3oool02`3oool200WZ2R00oooo00@02NX:0?ooo`3oool02NX:<03oool00`09jPX0oooo0?ooo`0K
0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`03
0?ooo`0700WZ2P3oool0oooo0?ooo`09jPX0oooo00WZ2P030?ooo`030000003oool0oooo00D0oooo
00070?ooo`0300000009jPX02NX:00D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?oo
o`0Q0?ooo`0300WZ2P3oool0oooo04@0oooo00<02NX:0?ooo`3oool02`3oool200WZ2R00oooo00@0
2NX:0?ooo`3oool02NX:<03oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00T0oooo
00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`0700WZ2P3oool0oooo0?ooo`09
jPX0oooo00WZ2P030?ooo`030000003oool0oooo00D0oooo00070?ooo`0300000009jPX02NX:00D0
oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0Q0?ooo`0300WZ2P3oool0oooo04@0
oooo00<02NX:0?ooo`3oool02`3oool200WZ2R00oooo00@02NX:0?ooo`3oool02NX:<03oool00`09
jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`030?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool00`000000oooo0?oo
o`050?ooo`001`3oool0100000002NX:0?ooo`09jPX50?ooo`0300WZ2P3oool0oooo00L0oooo00<0
2NX:0?ooo`3oool08@3oool00`09jPX0oooo0?ooo`140?ooo`0300WZ2P3oool0oooo00/0oooo0P09
jPXP0?ooo`0400WZ2P3oool0oooo00WZ2S00oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo
0?ooo`090?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool01P09jPX0oooo
0?ooo`09jPX0oooo00WZ2P@0oooo00<000000?ooo`3oool01@3oool000L0oooo00@000000?ooo`09
jPX02NX:1@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0200oooo00<02NX:0?oo
o`3oool0A03oool00`09jPX0oooo0?ooo`0;0?ooo`802NX:803oool01009jPX0oooo0?ooo`09jPX`
0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool02@3oool01@09jPX0oooo0?ooo`3o
ool02NX:00H0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`030000003oool0oooo00D0
oooo00070?ooo`040000003oool02NX:00WZ2PD0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0
oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo04@0oooo00<02NX:0?ooo`3oool02`3oool200WZ2R40
oooo00@02NX:0?ooo`3oool02NX:;`3oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo
00P0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`0600WZ2P3oool0oooo
00WZ2P3oool02NX:103oool00`000000oooo0?ooo`050?ooo`001`3oool010000000oooo00WZ2P09
jPX50?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0803oool00`09jPX0oooo0?oo
o`140?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPXQ0?ooo`0400WZ2P3oool0oooo00WZ2Rl0oooo
00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo
00<02NX:0?ooo`3oool0103oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P<0oooo0P0000070?oo
o`001`3oool010000000oooo00WZ2P09jPX50?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?oo
o`3oool0803oool00`09jPX0oooo0?ooo`140?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPXQ0?oo
o`0400WZ2P3oool0oooo00WZ2Rl0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`08
0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool01P09jPX0oooo0?ooo`09
jPX0oooo00WZ2P<0oooo0P0000070?ooo`001`3oool010000000oooo00WZ2P09jPX50?ooo`0300WZ
2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0803oool00`09jPX0oooo0?ooo`140?ooo`0300WZ
2P3oool0oooo00/0oooo0P09jPXQ0?ooo`0400WZ2P3oool0oooo00WZ2Rl0oooo00<02NX:0?ooo`3o
ool06P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3o
ool00`3oool01`09jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX0103oool00`09jPX0oooo0?ooo`05
0?ooo`001`3oool010000000oooo00WZ2P09jPX50?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:
0?ooo`3oool0803oool00`09jPX0oooo0?ooo`140?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:
0?ooo`3oool07`3oool01009jPX0oooo0?ooo`09jPX_0?ooo`0300WZ2P3oool0oooo01X0oooo00<0
2NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00@0
2NX:0?ooo`3oool0oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00D0oooo00070?ooo`040000003o
ool02NX:00WZ2PD0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0P0?ooo`0300WZ
2P3oool0oooo04@0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0O0?ooo`0400WZ
2P3oool0oooo00WZ2Rl0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`080?ooo`03
00WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool01P09jPX0oooo0?ooo`09jPX0oooo
00WZ2PD0oooo00<02NX:0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool00P09jPX50?oo
o`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool0803oool00`09jPX0oooo0?ooo`140?oo
o`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool07`3oool01009jPX0oooo0?ooo`09jPX_
0?ooo`0300WZ2P3oool0oooo01T0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`02
0?ooo`0300WZ2P3oool0oooo00<0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX50?ooo`0300WZ
2P3oool0oooo00D0oooo00070?ooo`030000003oool0oooo00802NX:1@3oool00`09jPX0oooo0?oo
o`070?ooo`0300WZ2P3oool0oooo0240oooo00<02NX:0?ooo`3oool0@`3oool00`09jPX0oooo0?oo
o`0<0?ooo`0300WZ2P3oool0oooo01l0oooo00@02NX:0?ooo`3oool02NX:;P3oool00`09jPX0oooo
0?ooo`0J0?ooo`0300WZ2P3oool0oooo00T0oooo00D02NX:0?ooo`3oool0oooo00WZ2P060?ooo`06
00WZ2P3oool0oooo00WZ2P3oool02NX:103oool00`09jPX000000?ooo`060?ooo`001`3oool00`00
0000oooo0?ooo`0200WZ2PD0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0P0?oo
o`0300WZ2P3oool0oooo04<0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0O0?oo
o`0400WZ2P3oool0oooo00WZ2Rh0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`09
0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01P3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0
oooo00<02NX:0000003oool01P3oool000L0oooo00<000000?ooo`3oool00P09jPX50?ooo`0300WZ
2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0803oool00`09jPX0oooo0?ooo`130?ooo`0300WZ
2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool0803oool01009jPX0oooo0?ooo`09jPX]0?ooo`03
00WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`020?ooo`03
00WZ2P3oool0oooo00@0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`0300WZ2P000000
oooo00H0oooo00070?ooo`030000003oool0oooo00802NX:1@3oool00`09jPX0oooo0?ooo`080?oo
o`0300WZ2P3oool0oooo0200oooo00<02NX:0?ooo`3oool0@`3oool00`09jPX0oooo0?ooo`0<0?oo
o`0300WZ2P3oool0oooo0200oooo00@02NX:0?ooo`3oool02NX:;@3oool00`09jPX0oooo0?ooo`0J
0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`04
0?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool00`09jPX000000?ooo`060?ooo`001`3o
ool00`000000oooo0?ooo`0200WZ2PD0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?oo
o`0P0?ooo`0300WZ2P3oool0oooo04<0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?oo
o`0P0?ooo`0400WZ2P3oool0oooo00WZ2Rd0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo
0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool01`09jPX0oooo
0?ooo`3oool02NX:0?ooo`09jPX0103oool00`09jPX000000?ooo`060?ooo`001`3oool00`000000
oooo0?ooo`0200WZ2PD0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0P0?ooo`03
00WZ2P3oool0oooo04<0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0P0?ooo`04
00WZ2P3oool0oooo00WZ2Rd0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`080?oo
o`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool01P09jPX0oooo0?ooo`09jPX0
oooo00WZ2PD0oooo00<02NX:0000003oool01P3oool000L0oooo00H000000?ooo`3oool02NX:0?oo
o`09jPX40?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0803oool00`09jPX0oooo
0?ooo`130?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool0803oool01009jPX0oooo
0?ooo`09jPX]0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX5
0?ooo`0300WZ2P000000oooo00H0oooo00070?ooo`040000003oool0oooo0?ooo`802NX:1@3oool0
0`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0200oooo00<02NX:0?ooo`3oool0@`3oool0
0`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo0200oooo00@02NX:0?ooo`3oool02NX:;@3o
ool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00P3o
ool00`09jPX0oooo0?ooo`030?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool00`09jPX0
oooo000000070?ooo`001`3oool010000000oooo0?ooo`3oool200WZ2PD0oooo00<02NX:0?ooo`3o
ool01`3oool00`09jPX0oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo04<0oooo00<02NX:0?ooo`3o
ool0303oool00`09jPX0oooo0?ooo`0P0?ooo`0400WZ2P3oool0oooo00WZ2Rd0oooo00<02NX:0?oo
o`3oool06@3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?oo
o`3oool00`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00<02NX:0?ooo`0000001`3o
ool000L0oooo00@000000?ooo`3oool0oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00L0oooo00<0
2NX:0?ooo`3oool0803oool00`09jPX0oooo0?ooo`130?ooo`0300WZ2P3oool0oooo00`0oooo00<0
2NX:0?ooo`3oool0803oool01009jPX0oooo0?ooo`09jPX]0?ooo`0300WZ2P3oool0oooo01T0oooo
00<02NX:0?ooo`3oool02@3oool01@09jPX0oooo0?ooo`3oool02NX:00H0oooo00H02NX:0?ooo`3o
ool02NX:0?ooo`09jPX40?ooo`0300WZ2P3oool0000000L0oooo00070?ooo`040000003oool0oooo
0?ooo`802NX:1@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:
0?ooo`3oool0@`3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo0240oooo00@02NX:
0?ooo`3oool02NX:;03oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo00T0oooo00D0
2NX:0?ooo`3oool0oooo00WZ2P060?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool00`09
jPX0oooo000000070?ooo`001`3oool010000000oooo0?ooo`3oool200WZ2PD0oooo00<02NX:0?oo
o`3oool0203oool00`09jPX0oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo0480oooo00<02NX:0?oo
o`3oool0303oool00`09jPX0oooo0?ooo`0Q0?ooo`0400WZ2P3oool0oooo00WZ2R`0oooo00<02NX:
0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:
0?ooo`3oool00`3oool01`09jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX0103oool00`09jPX0oooo
000000070?ooo`001`3oool010000000oooo0?ooo`3oool200WZ2PD0oooo00<02NX:0?ooo`3oool0
203oool00`09jPX0oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo0480oooo00<02NX:0?ooo`3oool0
303oool00`09jPX0oooo0?ooo`0Q0?ooo`0400WZ2P3oool0oooo00WZ2R`0oooo00<02NX:0?ooo`3o
ool06@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3o
ool00`3oool01009jPX0oooo0?ooo`3oool200WZ2PD0oooo00<02NX:0?ooo`0000001`3oool000L0
oooo00L000000?ooo`3oool0oooo00WZ2P3oool02NX:00@0oooo00<02NX:0?ooo`3oool0203oool0
0`09jPX0oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo0480oooo00<02NX:0?ooo`3oool0303oool0
0`09jPX0oooo0?ooo`0Q0?ooo`0400WZ2P3oool0oooo00WZ2R/0oooo00<02NX:0?ooo`3oool06P3o
ool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3o
ool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2PD0oooo00<02NX:0?ooo`0000001`3oool000L0oooo
00<000000?ooo`3oool00P3oool200WZ2P@0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo
0?ooo`0P0?ooo`0300WZ2P3oool0oooo0480oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo
0?ooo`0Q0?ooo`0400WZ2P3oool0oooo00WZ2R/0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0
oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool01P09jPX0
oooo0?ooo`09jPX0oooo00WZ2P@0oooo00@02NX:0?ooo`00000000001`3oool000L0oooo00<00000
0?ooo`3oool00P3oool200WZ2PD0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0P
0?ooo`0300WZ2P3oool0oooo0480oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0Q
0?ooo`0400WZ2P3oool0oooo00WZ2R/0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?oo
o`080?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool01P09jPX0oooo0?oo
o`09jPX0oooo00WZ2P@0oooo00@02NX:0?ooo`00000000001`3oool000L0oooo00<000000?ooo`3o
ool00P3oool200WZ2PD0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0P0?ooo`03
00WZ2P3oool0oooo0480oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0Q0?ooo`04
00WZ2P3oool0oooo00WZ2R/0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`080?oo
o`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool01P09jPX0oooo0?ooo`09jPX0
oooo00WZ2P@0oooo00@02NX:0?ooo`3oool02NX:1`3oool000H0oooo0P0000040?ooo`802NX:1@3o
ool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0200oooo00<02NX:0?ooo`3oool0@P3o
ool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo0240oooo00@02NX:0?ooo`3oool02NX:
:`3oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00P0oooo00D02NX:0?ooo`3oool0
oooo00WZ2P060?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool01009jPX0oooo0?ooo`09
jPX70?ooo`001P3oool2000000@0oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:
0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`120?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:
0?ooo`3oool08P3oool01009jPX0oooo0?ooo`09jPXZ0?ooo`0300WZ2P3oool0oooo01T0oooo00<0
2NX:0?ooo`3oool02@3oool01@09jPX0oooo0?ooo`3oool02NX:00H0oooo00H02NX:0?ooo`3oool0
2NX:0?ooo`09jPX40?ooo`0400WZ2P3oool02NX:000000L0oooo00070?ooo`0300WZ2P3oool0oooo
0080oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool07`3oool00`09
jPX0oooo0?ooo`120?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool08P3oool01009
jPX0oooo0?ooo`09jPXZ0?ooo`0300WZ2P3oool0oooo01T0oooo00<02NX:0?ooo`3oool02@3oool0
1@09jPX0oooo0?ooo`3oool02NX:00D0oooo00L02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:00@0
oooo00@02NX:0?ooo`09jPX000001`3oool000L0oooo00<02NX:0?ooo`3oool00P3oool200WZ2PD0
oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo0480
oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0R0?ooo`0400WZ2P3oool0oooo00WZ
2RX0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo
0080oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`3oool200WZ2PD0oooo00@02NX:
0?ooo`09jPX000001`3oool000L0oooo00<02NX:0?ooo`3oool00`3oool200WZ2P@0oooo00<02NX:
0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo0480oooo00<02NX:
0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0R0?ooo`0400WZ2P3oool0oooo00WZ2RX0oooo00<0
2NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo00<0
2NX:0?ooo`3oool00`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2PD0oooo00@02NX:0?ooo`09
jPX000001`3oool000L0oooo00<0000000WZ2P3oool00`3oool200WZ2P@0oooo00<02NX:0?ooo`3o
ool0203oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo0480oooo00<02NX:0?ooo`3o
ool0303oool00`09jPX0oooo0?ooo`0R0?ooo`0400WZ2P3oool0oooo00WZ2RX0oooo00<02NX:0?oo
o`3oool06@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?oo
o`3oool00`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00D02NX:0?ooo`3oool02NX:
000000070?ooo`001`3oool00`0000002NX:0?ooo`030?ooo`802NX:1@3oool00`09jPX0oooo0?oo
o`070?ooo`0300WZ2P3oool0oooo0200oooo00<02NX:0?ooo`3oool0@@3oool00`09jPX0oooo0?oo
o`0<0?ooo`0300WZ2P3oool0oooo0280oooo00@02NX:0?ooo`3oool02NX::P3oool00`09jPX0oooo
0?ooo`0I0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo
0?ooo`030?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool01@09jPX0oooo0?ooo`09jPX0
000000L0oooo00070?ooo`0300000009jPX0oooo00<0oooo0P09jPX50?ooo`0300WZ2P3oool0oooo
00L0oooo00<02NX:0?ooo`3oool0803oool00`09jPX0oooo0?ooo`110?ooo`0300WZ2P3oool0oooo
00`0oooo00<02NX:0?ooo`3oool08P3oool01009jPX0oooo0?ooo`09jPXZ0?ooo`0300WZ2P3oool0
oooo01T0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0
oooo00<0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`0500WZ2P3oool0oooo00WZ2P00
00001`3oool000L0oooo00<0000000WZ2P3oool00`3oool200WZ2PD0oooo00<02NX:0?ooo`3oool0
1`3oool00`09jPX0oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo0440oooo00<02NX:0?ooo`3oool0
303oool00`09jPX0oooo0?ooo`0R0?ooo`0400WZ2P3oool0oooo00WZ2RX0oooo00<02NX:0?ooo`3o
ool06@3oool00`09jPX0oooo0?ooo`080?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01P3oool01P09
jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00D02NX:0?ooo`09jPX0oooo000000070?ooo`001`3o
ool00`0000002NX:0?ooo`030?ooo`802NX:1@3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3o
ool0oooo0200oooo00<02NX:0?ooo`3oool0@@3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3o
ool0oooo02<0oooo00@02NX:0?ooo`3oool02NX::03oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ
2P3oool0oooo00P0oooo00D02NX:0?ooo`3oool0oooo00WZ2P060?ooo`0600WZ2P3oool0oooo00WZ
2P3oool02NX:103oool01@09jPX0oooo00WZ2P3oool0000000L0oooo00070?ooo`0300000009jPX0
oooo00<0oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool07`3oool0
0`09jPX0oooo0?ooo`110?ooo`0300WZ2P3oool0oooo00`0oooo0P09jPXT0?ooo`0400WZ2P3oool0
oooo00WZ2RP0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`090?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX01@3oool01`09jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX0103oool01@09
jPX0oooo00WZ2P3oool0000000L0oooo00070?ooo`0300000009jPX0oooo00@0oooo0P09jPX40?oo
o`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`110?oo
o`0300WZ2P3oool0oooo00`0oooo0P09jPXT0?ooo`0400WZ2P3oool0oooo00WZ2RP0oooo00<02NX:
0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`090?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01@3o
ool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2PD0oooo00D02NX:0?ooo`09jPX0oooo000000070?oo
o`001`3oool00`000000oooo00WZ2P040?ooo`802NX:103oool00`09jPX0oooo0?ooo`080?ooo`03
00WZ2P3oool0oooo01l0oooo00<02NX:0?ooo`3oool0@@3oool00`09jPX0oooo0?ooo`0<0?ooo`80
2NX:903oool01009jPX0oooo0?ooo`09jPXX0?ooo`0300WZ2P3oool0oooo01T0oooo00<02NX:0?oo
o`3oool0203oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00H02NX:0?oo
o`3oool02NX:0?ooo`09jPX40?ooo`0600WZ2P3oool0oooo00WZ2P3oool000001`3oool000L0oooo
00<000000?ooo`09jPX0103oool200WZ2P@0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo
0?ooo`0O0?ooo`0300WZ2P3oool0oooo0440oooo00<02NX:0?ooo`3oool0303oool200WZ2R@0oooo
00@02NX:0?ooo`3oool02NX::03oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo00P0
oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`0600WZ2P3oool0oooo00WZ
2P3oool02NX:103oool01P09jPX0oooo0?ooo`09jPX0oooo000000L0oooo00070?ooo`030000003o
ool02NX:00@0oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool07`3o
ool00`09jPX0oooo0?ooo`110?ooo`0300WZ2P3oool0oooo00`0oooo0P09jPXT0?ooo`0400WZ2P3o
ool0oooo00WZ2RP0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ
2P@0oooo00H02NX:0?ooo`3oool02NX:0?ooo`0000070?ooo`001`3oool00`000000oooo00WZ2P04
0?ooo`802NX:1@3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:
0?ooo`3oool0@@3oool00`09jPX0oooo0?ooo`0<0?ooo`802NX:903oool01009jPX0oooo0?ooo`09
jPXX0?ooo`0300WZ2P3oool0oooo01T0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?oo
o`020?ooo`0300WZ2P3oool0oooo00<0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`04
00WZ2P3oool02NX:0?ooo`8000001`3oool000L0oooo00<000000?ooo`09jPX0103oool200WZ2PD0
oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo0440
oooo00<02NX:0?ooo`3oool01@3oool7000000802NX:2`00000I0?ooo`0400WZ2P3oool0oooo00WZ
2RP0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`080?ooo`0500WZ2P3oool0oooo
0?ooo`09jPX01P3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00@02NX:0?ooo`09jPX0
oooo0P0000070?ooo`001`3oool00`000000oooo00WZ2P040?ooo`802NX:1@3oool00`09jPX0oooo
0?ooo`070?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:0?ooo`3oool0@@3oool00`09jPX0oooo
0?ooo`050?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo
00<000000?ooo`3oool0603oool01009jPX0oooo0?ooo`09jPXX0?ooo`0300WZ2P3oool0oooo01T0
oooo00<02NX:0?ooo`3oool0203oool01@09jPX0oooo0?ooo`3oool02NX:00H0oooo00H02NX:0?oo
o`3oool02NX:0?ooo`09jPX40?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool01@3o
ool000L0oooo00<000000?ooo`09jPX0103oool200WZ2PD0oooo00<02NX:0?ooo`3oool01`3oool0
0`09jPX0oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo0400oooo00<02NX:0?ooo`3oool01@3oool2
07moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0
oooo01T0oooo00@02NX:0?ooo`3oool02NX:9`3oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3o
ool0oooo00P0oooo00D02NX:0?ooo`3oool0oooo00WZ2P050?ooo`0400WZ2P3oool0oooo0?ooo`80
2NX:1@3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00D0oooo00070?ooo`040000
003oool0oooo00WZ2P@0oooo0P09jPX40?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3o
ool07`3oool00`09jPX0oooo0?ooo`100?ooo`0300WZ2P3oool0oooo00D0oooo0P1oOgl00`000000
Ogmo07moO`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`0I0?ooo`04
00WZ2P3oool0oooo00WZ2RL0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`080?oo
o`0500WZ2P3oool0oooo0?ooo`09jPX01@3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo
00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`050?ooo`001`3oool010000000oooo
0?ooo`09jPX40?ooo`802NX:103oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01l0
oooo00<02NX:0?ooo`3oool0@03oool00`09jPX0oooo0?ooo`050?ooo`80Ogmo00<0000007moO`1o
Ogl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<000000?ooo`3oool06@3oool01009jPX0
oooo0?ooo`09jPXW0?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool02@3oool01@09
jPX0oooo0?ooo`3oool02NX:00D0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`0700WZ
2P3oool0oooo00WZ2P3oool02NX:000000070?ooo`001`3oool010000000oooo0?ooo`09jPX40?oo
o`802NX:103oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:0?oo
o`3oool0@03oool00`09jPX0oooo0?ooo`050?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ
2P0307moO`000000Ogmo00H0Ogmo00<000000?ooo`3oool06@3oool01009jPX0oooo0?ooo`09jPXW
0?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`02
0?ooo`0300WZ2P3oool0oooo00<0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`0700WZ
2P3oool0oooo00WZ2P3oool02NX:000000070?ooo`001`3oool010000000oooo0?ooo`09jPX40?oo
o`802NX:103oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:0?oo
o`3oool0@03oool00`09jPX0oooo0?ooo`050?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ
2P0307moO`000000Ogmo00H0Ogmo00<000000?ooo`3oool06@3oool01009jPX0oooo0?ooo`09jPXV
0?ooo`0300WZ2P3oool0oooo01T0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`02
0?ooo`0300WZ2P3oool0oooo00<0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`0300WZ
2P3oool02NX:0080oooo00<02NX:0000003oool01P3oool000H0oooo0P0000020?ooo`0300WZ2P3o
ool0oooo0080oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool07`3o
ool00`09jPX0oooo0?ooo`100?ooo`0300WZ2P3oool0oooo00D0oooo0P1oOgl00`000000Ogmo07mo
O`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`0I0?ooo`0400WZ2P3o
ool0oooo00WZ2RH0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ
2P@0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX000000?ooo`060?ooo`001P3oool200000080
oooo00<02NX:0?ooo`3oool00P3oool200WZ2PD0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0
oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo0400oooo00<02NX:0?ooo`3oool01@3oool207moO`03
0000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01T0
oooo00@02NX:0?ooo`3oool02NX:9P3oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo
00P0oooo00D02NX:0?ooo`3oool0oooo00WZ2P060?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:
103oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P000000oooo00H0oooo00070?ooo`0400WZ2P3o
ool0oooo00WZ2P@0oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool0
7`3oool00`09jPX0oooo0?ooo`110?ooo`0300WZ2P3oool0oooo00@0oooo0P1oOgl00`000000Ogmo
07moO`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`0I0?ooo`0400WZ
2P3oool0oooo00WZ2RH0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`080?ooo`05
00WZ2P3oool0oooo0?ooo`09jPX01P3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00<0
2NX:0?ooo`09jPX00P3oool00`09jPX000000?ooo`060?ooo`001`3oool01@09jPX0oooo0?ooo`3o
ool02NX:00@0oooo0P09jPX40?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool07`3o
ool00`09jPX0oooo0?ooo`110?ooo`0300WZ2P3oool0oooo00@0oooo0P1oOgl00`000000Ogmo07mo
O`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`0J0?ooo`0400WZ2P3o
ool0oooo00WZ2RD0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`080?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX01@3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00@02NX:
0?ooo`3oool02NX:0P3oool00`09jPX000000?ooo`060?ooo`001`3oool01@09jPX0oooo0?ooo`3o
ool02NX:00@0oooo0P09jPX40?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool07`3o
ool00`09jPX0oooo0?ooo`110?ooo`0300WZ2P3oool0oooo00@0oooo0P1oOgl00`000000Ogmo07mo
O`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`0J0?ooo`0400WZ2P3o
ool0oooo00WZ2RD0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`080?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX01@3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00P02NX:
0?ooo`3oool02NX:0?ooo`09jPX0oooo000000L0oooo00070?ooo`0500000009jPX0oooo0?ooo`09
jPX0103oool200WZ2P@0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0N0?ooo`03
00WZ2P3oool0oooo0440oooo00<02NX:0?ooo`3oool0103oool207moO`030000001oOgl0Ogmo0080
Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01X0oooo00@02NX:0?ooo`3o
ool02NX:9@3oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo00P0oooo00D02NX:0?oo
o`3oool0oooo00WZ2P050?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool00`09jPX0oooo
00WZ2P020?ooo`0300WZ2P3oool0000000L0oooo00070?ooo`0500000009jPX0oooo0?ooo`09jPX0
103oool200WZ2P@0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ
2P3oool0oooo0400oooo00<02NX:0?ooo`3oool0103oool207moO`030000001oOgl0Ogmo0080Ogmo
0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01X0oooo00@02NX:0?ooo`3oool0
2NX:9@3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00T0oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P050?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool00`09jPX0oooo00WZ
2P020?ooo`0300WZ2P3oool0000000L0oooo00070?ooo`0500000009jPX0oooo0?ooo`09jPX0103o
ool200WZ2P@0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3o
ool0oooo0400oooo00<02NX:0?ooo`3oool0103oool207moO`030000001oOgl0Ogmo0080Ogmo0P09
jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01X0oooo00@02NX:0?ooo`3oool02NX:
9@3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0
0P3oool00`09jPX0oooo0?ooo`030?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool00`09
jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0000000L0oooo00070?ooo`0500000009jPX0oooo0?oo
o`09jPX0103oool200WZ2PD0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0O0?oo
o`0300WZ2P3oool0oooo0400oooo00<02NX:0?ooo`3oool0103oool207moO`030000001oOgl0Ogmo
0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01X0oooo00@02NX:0?oo
o`3oool02NX:9@3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:
0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:
103oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0000000L0oooo00070?ooo`0500000009
jPX0oooo0?ooo`09jPX0103oool200WZ2PD0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo
0?ooo`0O0?ooo`0300WZ2P3oool0oooo0400oooo00<02NX:0?ooo`3oool0103oool207moO`030000
001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01X0oooo
00@02NX:0?ooo`3oool02NX:9@3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00P0
oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`0600WZ2P3oool0oooo00WZ
2P3oool02NX:103oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0000000L0oooo00070?oo
o`0500000009jPX0oooo0?ooo`09jPX01@3oool200WZ2P@0oooo00<02NX:0?ooo`3oool01`3oool0
0`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo0400oooo00<02NX:0?ooo`3oool0103oool2
07moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0
oooo01X0oooo00@02NX:0?ooo`3oool02NX:9@3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3o
ool0oooo00P0oooo00D02NX:0?ooo`3oool0oooo00WZ2P050?ooo`0400WZ2P3oool0oooo0?ooo`80
2NX:1@3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0000000L0oooo00070?ooo`030000
0009jPX0oooo0080oooo00<02NX:0?ooo`3oool00P3oool200WZ2P@0oooo00<02NX:0?ooo`3oool0
1`3oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo0400oooo00<02NX:0?ooo`3oool0
103oool207moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000
003oool0oooo01/0oooo00@02NX:0?ooo`3oool02NX:903oool00`09jPX0oooo0?ooo`0H0?ooo`03
00WZ2P3oool0oooo00P0oooo00D02NX:0?ooo`3oool0oooo00WZ2P050?ooo`0600WZ2P3oool0oooo
00WZ2P3oool02NX:103oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P80oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:
103oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:0?ooo`3oool0
@03oool00`09jPX0oooo0?ooo`040?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307mo
O`000000Ogmo00H0Ogmo00<000000?ooo`3oool06`3oool01009jPX0oooo0?ooo`09jPXS0?ooo`03
00WZ2P3oool0oooo01T0oooo00<02NX:0?ooo`3oool0203oool01@09jPX0oooo0?ooo`3oool02NX:
00D0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`0300WZ2P3oool02NX:0080oooo00@0
2NX:0?ooo`3oool000001`3oool000L0oooo00<000000?ooo`09jPX00P3oool00`09jPX0oooo0?oo
o`020?ooo`802NX:103oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo01l0oooo00<0
2NX:0?ooo`3oool0@03oool00`09jPX0oooo0?ooo`040?ooo`80Ogmo00<0000007moO`1oOgl00P1o
Ogl200WZ2P0307moO`000000Ogmo00H0Ogmo00<000000?ooo`3oool06`3oool01009jPX0oooo0?oo
o`09jPXS0?ooo`0300WZ2P3oool0oooo01T0oooo00<02NX:0?ooo`3oool0203oool01@09jPX0oooo
0?ooo`3oool02NX:00D0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`0300WZ2P3oool0
2NX:0080oooo00@02NX:0?ooo`3oool000001`3oool000H0oooo0P0000001@3oool02NX:0?ooo`3o
ool02NX:00@0oooo0P09jPX40?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool07P3o
ool00`09jPX0oooo0?ooo`100?ooo`0300WZ2P3oool0oooo00@0oooo0P1oOgl00`000000Ogmo07mo
O`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`0K0?ooo`0400WZ2P3o
ool0oooo00WZ2R<0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`080?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX01@3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00<02NX:
0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`0000070?ooo`001P3oool2000000050?ooo`09jPX0
oooo0?ooo`09jPX0103oool200WZ2P@0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?oo
o`0N0?ooo`0300WZ2P3oool0oooo0400oooo00<02NX:0?ooo`3oool0103oool207moO`030000001o
Ogl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01/0oooo00@0
2NX:0?ooo`3oool02NX:8`3oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo00P0oooo
00D02NX:0?ooo`3oool0oooo00WZ2P050?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool0
0`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo000000L0oooo00070?ooo`0300WZ2P3oool0
2NX:0080oooo00<02NX:0?ooo`3oool00P3oool200WZ2PD0oooo00<02NX:0?ooo`3oool01`3oool0
0`09jPX0oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo0400oooo00<02NX:0?ooo`3oool0103oool2
07moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0
oooo01/0oooo00@02NX:0?ooo`3oool02NX:8`3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3o
ool0oooo00P0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`0600WZ2P3o
ool0oooo00WZ2P3oool02NX:103oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo0000
00L0oooo00070?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P3oool200WZ2PD0
oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo0400
oooo00<02NX:0?ooo`3oool0103oool207moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0
000007moO`0607moO`030000003oool0oooo01/0oooo00@02NX:0?ooo`3oool02NX:8`3oool00`09
jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`030?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool00`09jPX0oooo00WZ
2P020?ooo`0400WZ2P3oool0oooo000000L0oooo00070?ooo`0300WZ2P3oool02NX:00<0oooo00<0
2NX:0?ooo`3oool00P3oool200WZ2P@0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?oo
o`0O0?ooo`0300WZ2P3oool0oooo03l0oooo00<02NX:0?ooo`3oool0103oool207moO`030000001o
Ogl0Ogmo0080Ogmo00@02NX:07moO`09jPX000001`1oOgl00`000000oooo0?ooo`0K0?ooo`0400WZ
2P3oool0oooo00WZ2R<0oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`080?ooo`05
00WZ2P3oool0oooo0?ooo`09jPX01@3oool01009jPX0oooo0?ooo`3oool200WZ2P@0oooo00H02NX:
0?ooo`3oool02NX:0?ooo`09jPX30?ooo`030000003oool0oooo00D0oooo00070?ooo`0400000009
jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00P3oool200WZ2P@0oooo00<02NX:0?ooo`3oool0
1`3oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo03l0oooo00<02NX:0?ooo`3oool0
103oool207moO`030000001oOgl0Ogmo0080Ogmo00@02NX:07moO`09jPX000001`1oOgl00`000000
oooo0?ooo`0K0?ooo`0400WZ2P3oool0oooo00WZ2R<0oooo00<02NX:0?ooo`3oool0603oool00`09
jPX0oooo0?ooo`080?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01@3oool01P09jPX0oooo0?ooo`09
jPX0oooo00WZ2P@0oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo0?ooo`3oool0000000L0
oooo00070?ooo`0400000009jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00P3oool200WZ2P@0
oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo03l0
oooo00<02NX:0?ooo`3oool0103oool207moO`030000001oOgl0Ogmo0080Ogmo00@02NX:07moO`09
jPX000001`1oOgl00`000000oooo0?ooo`0L0?ooo`0400WZ2P3oool0oooo00WZ2R80oooo00<02NX:
0?ooo`3oool0603oool00`09jPX0oooo0?ooo`080?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01@3o
ool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0
oooo0?ooo`3oool0000000L0oooo00070?ooo`0400000009jPX0oooo00WZ2P80oooo00<02NX:0?oo
o`3oool00P3oool200WZ2P@0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0O0?oo
o`0300WZ2P3oool0oooo03l0oooo00<02NX:0?ooo`3oool0103oool207moO`030000001oOgl0Ogmo
0080Ogmo00@02NX:07moO`09jPX000001`1oOgl00`000000oooo0?ooo`0L0?ooo`0400WZ2P3oool0
oooo00WZ2R80oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`080?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX01@3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00<02NX:0?oo
o`09jPX00P3oool01@09jPX0oooo0?ooo`3oool0000000L0oooo00070?ooo`0400000009jPX0oooo
00WZ2P80oooo00<02NX:0?ooo`3oool00P3oool200WZ2P@0oooo00<02NX:0?ooo`3oool01`3oool0
0`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo03l0oooo00<02NX:0?ooo`3oool0103oool2
07moO`030000001oOgl0Ogmo0080Ogmo00@02NX:07moO`09jPX000001`1oOgl00`000000oooo0?oo
o`0L0?ooo`0400WZ2P3oool0oooo00WZ2R80oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo
0?ooo`080?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01@3oool01P09jPX0oooo0?ooo`09jPX0oooo
00WZ2P@0oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo0?ooo`3oool0000000L0oooo0007
0?ooo`0400000009jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00P3oool200WZ2P@0oooo00<0
2NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo03l0oooo00<0
2NX:0?ooo`3oool0103oool207moO`030000001oOgl0Ogmo0080Ogmo00@02NX:07moO`09jPX00000
1`1oOgl00`000000oooo0?ooo`0L0?ooo`0400WZ2P3oool0oooo00WZ2R80oooo00<02NX:0?ooo`3o
ool0603oool00`09jPX0oooo0?ooo`080?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01@3oool01P09
jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo0?oo
o`3oool0000000L0oooo00070?ooo`0400000009jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool0
0P3oool200WZ2PD0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0N0?ooo`0300WZ
2P3oool0oooo03l0oooo00<02NX:0?ooo`3oool0103oool207moO`030000001oOgl0Ogmo0080Ogmo
00@02NX:07moO`09jPX000001`1oOgl00`000000oooo0?ooo`0L0?ooo`0400WZ2P3oool0oooo00WZ
2R80oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`080?ooo`0500WZ2P3oool0oooo
0?ooo`09jPX01@3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00<02NX:0?ooo`09jPX0
0P3oool01@09jPX0oooo0?ooo`3oool0000000L0oooo00070?ooo`0400000009jPX0oooo00WZ2P<0
oooo00<02NX:0?ooo`3oool00P3oool200WZ2P@0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0
oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo03l0oooo00<02NX:0?ooo`3oool0103oool207moO`03
0000001oOgl0Ogmo0080Ogmo00@02NX:07moO`09jPX000001`1oOgl00`000000oooo0?ooo`0L0?oo
o`0400WZ2P3oool0oooo00WZ2R40oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`08
0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`02
00WZ2P@0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`030000003oool0oooo00D0oooo
00070?ooo`050000003oool02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:
103oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo01h0oooo00<02NX:0?ooo`3oool0
?`3oool00`09jPX0oooo0?ooo`040?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl01009jPX0Ogmo
00WZ2P00000707moO`030000003oool0oooo00L0oooo5@0000001009jPX0000000000009jPXQ0000
000300WZ2P000000000001P0000000<02NX:000000000000200000001@09jPX00000000000000000
2NX:00D0000000H02NX:0000000000002NX:00000009jPX3000000040?ooo`09jPX0oooo00WZ2P80
oooo00<02NX:0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`001`3oool01@000000oooo
00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P3oool200WZ2P@0oooo00<02NX:0?ooo`3o
ool01`3oool00`09jPX0oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo03d0oooo0P0000000`09jPX0
00000000000400000080Ogmo00<0000007moO`1oOgl00P1oOgl01009jPX0Ogmo00WZ2P00000707mo
O`X000005@1oOgl01009jPX0Ogmo07moO`09jPXQ07moO`0300WZ2P1oOgl0Ogmo01P0Ogmo00<02NX:
07moO`1oOgl0201oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00D0Ogmo00H02NX:07moO`1oOgl02NX:
07moO`09jPX307moO`0400000009jPX0000000WZ2P80000000H02NX:00000000000000000?ooo`00
00070?ooo`001`3oool01@000000oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P3o
ool200WZ2P@0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0N0?ooo`0300WZ2P3o
ool0oooo01T0oooo9000000207moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl00P1o
Ogl01009jPX0Ogmo00WZ2P00000707moO`030000001oOgl0Ogmo01d0Ogmo00@02NX:07moO`1oOgl0
2NX:801oOgl00`09jPX0Ogmo07moO`0H07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00D02NX:07moO`1o
Ogl0Ogmo00WZ2P0407moO`0700000009jPX0Ogmo00000009jPX0000000WZ2P0307moO`0400000009
jPX0Ogmo00WZ2P80000000@02NX:07moO`1oOgl0Ogmo0P0000070?ooo`001`3oool01@000000oooo
00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P3oool200WZ2P@0oooo00<02NX:0?ooo`3o
ool01`3oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0oooo01P000009P1oOgl00`09jPX0
Ogmo07moO`0607moO`030000001oOgl0Ogmo0080Ogmo00@02NX:07moO`09jPX000001`1oOgl00`00
0000Ogmo07moO`0M07moO`0400WZ2P1oOgl0Ogmo00WZ2R00Ogmo00<02NX:07moO`1oOgl05`1oOgl0
0`0000002NX:07moO`0807moO`0600000009jPX0Ogmo07moO`0000002NX:101oOgl01@0000002NX:
07moO`0000002NX:008000000`1oOgl20000000307moO`000000000000800000101oOgl00`000000
oooo0?ooo`050?ooo`001`3oool01@000000oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3o
ool00P3oool200WZ2P@0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0C0?ooo``0
000000<02NX:000000000000?P1oOgl00`09jPX0Ogmo07moO`0607moO`030000001oOgl0Ogmo0080
Ogmo00@02NX:07moO`09jPX000001`1oOgl00`000000Ogmo07moO`0M07moO`0400WZ2P1oOgl0Ogmo
00WZ2Ql0Ogmo00<0000000WZ2P1oOgl0601oOgl2000000T0Ogmo0P00000207moO`8000001@1oOgl0
1P09jPX0Ogmo07moO`09jPX0Ogmo00WZ2P@0Ogmo00<02NX:07moO`09jPX00P1oOgl00`09jPX0Ogmo
07moO`0207moO`030000003oool0oooo00D0oooo00070?ooo`050000003oool02NX:0?ooo`09jPX0
0P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:103oool00`09jPX0oooo0?ooo`070?ooo`0300WZ
2P3oool0oooo01<00000301oOgl00`09jPX0Ogmo07moO`0n07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo
00<0000007moO`1oOgl00P1oOgl01009jPX0000000WZ2P00000707moO`030000001oOgl0Ogmo01`0
Ogmo00D0000000WZ2P1oOgl0000000WZ2P0O07moO`8000006P1oOgl00`09jPX0Ogmo07moO`0807mo
O`0500WZ2P1oOgl0Ogmo07moO`09jPX01@1oOgl00`09jPX0Ogmo07moO`0200WZ2P@0Ogmo00H02NX:
07moO`1oOgl02NX:07moO`09jPX507moO`030000003oool0oooo00D0oooo00070?ooo`050000003o
ool02NX:0?ooo`09jPX00`3oool00`09jPX0oooo0?ooo`020?ooo`802NX:00D0oooo000000000000
000000WZ2P090000000300WZ2P000000Ogmo01h0Ogmo00<02NX:07moO`1oOgl0?@1oOgl00`000000
2NX:07moO`0707moO`090000001oOgl0Ogmo07moO`0000002NX:00000009jPX0000000L0Ogmo00<0
000007moO`1oOgl0701oOgl20000000307moO`00000000000200Ogmo00<02NX:07moO`1oOgl05`1o
Ogl00`09jPX0Ogmo07moO`0807moO`0500WZ2P1oOgl0Ogmo07moO`09jPX01P1oOgl00`09jPX0Ogmo
07moO`0200WZ2P@0Ogmo00H02NX:07moO`1oOgl02NX:07moO`09jPX407moO`8000001`3oool000L0
oooo00H000000?ooo`3oool02NX:0?ooo`09jPX20?ooo`0300WZ2P0000000000008000000P09jPX0
1@000000Ogmo07moO`1oOgl02NX:00T0Ogmo00<02NX:07moO`1oOgl07@1oOgl00`0000002NX:07mo
O`0n07moO`800000201oOgl010000000Ogmo07moO`1oOgl2000000802NX:00<0000007moO`1oOgl0
1@1oOgl00`000000Ogmo07moO`0M07moO`0400WZ2P1oOgl0Ogmo00WZ2R00Ogmo00<02NX:07moO`1o
Ogl05`1oOgl00`09jPX0Ogmo07moO`0707moO`0300000009jPX0Ogmo0080Ogmo00<02NX:0000001o
Ogl00`1oOgl0100000002NX:07moO`00000200WZ2P0:0000001oOgl0Ogmo00000009jPX0Ogmo0000
0009jPX0000000WZ2P@0Ogmo0P0000070?ooo`001`3oool01P000000oooo0?ooo`09jPX0000000WZ
2P80000000<02NX:07moO`1oOgl00P1oOgl200WZ2P@0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`00
00002NX:07moO`0N07moO`0300000009jPX0Ogmo03l0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`00
0000Ogmo07moO`0207moO`<02NX:00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0M07mo
O`0500WZ2P1oOgl0Ogmo07moO`09jPX07P1oOgl00`0000002NX:07moO`0H07moO`0300WZ2P000000
Ogmo00L0Ogmo00<0000000WZ2P1oOgl00P1oOgl00`09jPX0000007moO`0307moO`80000000<0Ogmo
0000000000000P00000207moO`80000000<0Ogmo0000000000000P00000507moO`0300WZ2P3oool0
oooo00D0oooo00070?ooo`<0000000H02NX:00000009jPX0Ogmo00000009jPX307moO`0300000009
jPX02NX:00@0Ogmo00<02NX:0000001oOgl01P1oOgl00`0000002NX:07moO`0O07moO`0300WZ2P1o
Ogl0Ogmo03h0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000Ogmo07moO`0207moO`<02NX:00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0M07moO`0500WZ2P000000Ogmo00000009jPX0
7P1oOgl00`0000002NX:07moO`0H07moO`8000002@1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00H0
Ogmo00<02NX:07moO`1oOgl00P09jPX407moO`0600WZ2P1oOgl0Ogmo00WZ2P1oOgl02NX:1@1oOgl0
0`09jPX0oooo0?ooo`050?ooo`001`3oool00`000000Ogmo000000030000000307moO`0000000000
00<0Ogmo0`00000407moO`800000201oOgl00`09jPX0Ogmo07moO`0N07moO`0300WZ2P1oOgl0Ogmo
03h0Ogmo00<02NX:07moO`1oOgl01P1oOgl010000000Ogmo07moO`1oOgl30000000300WZ2P000000
Ogmo00H0Ogmo00<0000007moO`1oOgl07@1oOgl01@09jPX0000007moO`0000002NX:01l0Ogmo00<0
2NX:07moO`1oOgl05`1oOgl00`09jPX0Ogmo07moO`0807moO`0500WZ2P1oOgl0Ogmo07moO`09jPX0
1@1oOgl01P09jPX0Ogmo07moO`09jPX0Ogmo00WZ2P@0Ogmo00D02NX:07moO`09jPX0Ogmo00WZ2P05
07moO`0300WZ2P000000oooo00H0oooo00070?ooo`060000001oOgl0Ogmo00WZ2P1oOgl02NX:0P1o
Ogl00`09jPX0Ogmo07moO`0207moO`802NX:101oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1o
Ogl0Ogmo01h0Ogmo00<02NX:07moO`1oOgl0?01oOgl20000000300WZ2P000000000000@000000P1o
Ogl010000000Ogmo07moO`1oOgl5000000L0Ogmo2`00000E07moO`0500WZ2P1oOgl0Ogmo07moO`09
jPX07`1oOgl00`09jPX0Ogmo07moO`0G07moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00D02NX:07moO`1o
Ogl0Ogmo00WZ2P0507moO`0600WZ2P1oOgl0Ogmo00WZ2P1oOgl02NX:101oOgl01@09jPX0Ogmo00WZ
2P1oOgl02NX:00@0Ogmo00<0000000WZ2P0000001`3oool000L0oooo00@0000007moO`1oOgl0Ogmo
0P09jPX307moO`0400WZ2P1oOgl0Ogmo07moO`802NX:1@1oOgl00`09jPX0Ogmo07moO`0707moO`03
00WZ2P1oOgl0Ogmo01`0Ogmo00<0000000WZ2P1oOgl0?P1oOgl2000000P0Ogmo00<0000007moO`1o
Ogl00P1oOgl300WZ2P030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl07@1oOgl01@09jPX0
Ogmo07moO`1oOgl02NX:01h0Ogmo00<02NX:07moO`1oOgl0601oOgl00`09jPX0Ogmo07moO`0707mo
O`0600000009jPX0Ogmo07moO`0000002NX:101oOgl01`0000002NX:07moO`0000002NX:00000009
jPX00`1oOgl01`0000002NX:00000009jPX0Ogmo00WZ2P0000000P1oOgl0100000002NX:00WZ2P00
00070?ooo`001`3oool010000000Ogmo07moO`1oOgl200WZ2P<0Ogmo00@02NX:07moO`1oOgl0Ogmo
0P09jPX407moO`0300000009jPX0Ogmo00L0Ogmo00<0000000WZ2P1oOgl07@1oOgl00`0000002NX:
07moO`0o07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl00P1oOgl300WZ2P030000
001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl07P1oOgl01009jPX0Ogmo07moO`09jPXN07moO`03
00WZ2P000000Ogmo01L0Ogmo00<0000000WZ2P1oOgl0201oOgl200WZ2P80Ogmo0P00000407moO`80
000000<0Ogmo0000000000000P00000307moO`@0000000<0Ogmo0000000000000P1oOgl010000000
2NX:00WZ2P0000070?ooo`001`3oool010000000Ogmo07moO`00000200WZ2P040000001oOgl00000
00WZ2P<0Ogmo0P09jPX407moO`0300000009jPX0Ogmo00L0Ogmo0P00000O07moO`0300WZ2P1oOgl0
Ogmo03h0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`000000Ogmo07moO`0207moO`<02NX:00<00000
07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0M07moO`0500000009jPX0Ogmo00000009jPX07P1o
Ogl2000001P0Ogmo0P00000907moO`802NX:0`1oOgl00`09jPX0Ogmo07moO`0307moO`0600WZ2P1o
Ogl0Ogmo00WZ2P1oOgl02NX:101oOgl01@09jPX0Ogmo00WZ2P3oool02NX:00@0oooo0P09jPX00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000Ogmo07moO`040000000307moO`000000000000<0
Ogmo0P09jPX507moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<02NX:07moO`1oOgl07@1oOgl00`09jPX0
Ogmo07moO`0m07moO`0300000009jPX0Ogmo00L0Ogmo00@0000007moO`1oOgl0Ogmo0P00000200WZ
2P030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl07@1oOgl20000000307moO`0000000000
00@0Ogmo00<0000000WZ2P1oOgl00`1oOgl00`0000002NX:07moO`0A07moO`0300WZ2P1oOgl0Ogmo
01P0Ogmo00<02NX:07moO`1oOgl01`1oOgl200WZ2P<0Ogmo00<02NX:07moO`1oOgl00`1oOgl01P09
jPX0Ogmo07moO`09jPX0Ogmo00WZ2P@0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:
00<000000?ooo`3oool01@3oool000L0oooo00@0000007moO`1oOgl0Ogmo0P09jPX307moO`0400WZ
2P1oOgl0Ogmo07moO`802NX:1@1oOgl00`09jPX0Ogmo07moO`0707moO`0300WZ2P1oOgl0Ogmo01h0
Ogmo00<02NX:07moO`1oOgl0?01oOgl00`0000002NX:07moO`0707moO`040000001oOgl0Ogmo07mo
O`80000000<02NX:0000000000001`1oOgl00`000000Ogmo07moO`0N07moO`0400WZ2P1oOgl0Ogmo
00WZ2P@0Ogmo00<0000000WZ2P1oOgl00`1oOgl00`0000002NX:07moO`0A07moO`0300WZ2P1oOgl0
Ogmo01P0Ogmo00<02NX:07moO`1oOgl01`1oOgl200WZ2P<0oooo00<02NX:0?ooo`3oool00`3oool0
1P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00@02NX:0?ooo`09jPX02NX:103oool200WZ2P03
0?ooo`000000oooo00H0oooo00060?ooo`8000000`1oOgl00`09jPX0Ogmo00WZ2P0207moO`0300WZ
2P1oOgl0Ogmo0080Ogmo0P09jPX507moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl0
301oOgl2000000X0Ogmo0P00000307moO`0300000009jPX0Ogmo00H0Ogmo00<0000000WZ2P1oOgl0
=@1oOgl00`09jPX0Ogmo07moO`0607moO`030000001oOgl0Ogmo0080Ogmo0`09jPX00`000000Ogmo
07moO`0507moO`030000001oOgl0Ogmo01h0Ogmo00@02NX:07moO`1oOgl02NX:1@1oOgl00`09jPX0
Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo0100Ogmo00<02NX:07moO`1oOgl04@1oOgl70?ooo`03
00WZ2P3oool0oooo00L0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo0080oooo00H02NX:0?ooo`3o
ool02NX:0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P030?ooo`00
0000oooo00H0oooo00060?ooo`8000000`1oOgl00`09jPX0000000WZ2P0207moO`0500WZ2P000000
Ogmo07moO`0000000P09jPX307moO`0300000009jPX02NX:00<0Ogmo00<0000000WZ2P1oOgl00P1o
Ogl00`09jPX0000007moO`0407moO`0300WZ2P000000Ogmo00D0Ogmo00<0000000WZ2P1oOgl02@1o
Ogl00`0000002NX:07moO`0207moO`8000001`1oOgl00`0000002NX:07moO`0e07moO`0300WZ2P1o
Ogl0Ogmo00H0Ogmo00<0000007moO`1oOgl00P1oOgl300WZ2P030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl07P1oOgl01009jPX0Ogmo07moO`09jPX507moO`0300WZ2P1oOgl0Ogmo00<0Ogmo
00<02NX:07moO`1oOgl0401oOgl00`09jPX0Ogmo07moO`0207moOaD0oooo00<02NX:0?ooo`3oool0
1`3oool200WZ2P<0oooo00<02NX:0?ooo`3oool00`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ
2P@0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:00<0oooo0000003oool01P3oool0
00H0oooo00P0000000WZ2P1oOgl0Ogmo00000009jPX0000000WZ2P80Ogmo00L02NX:0000001oOgl0
Ogmo00000009jPX0000000<0Ogmo00<0000000WZ2P0000000`1oOgl00`0000002NX:07moO`0207mo
O`8000001@1oOgl00`09jPX0000007moO`0607moO`0300WZ2P1oOgl0Ogmo00T0Ogmo00<02NX:07mo
O`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo03@0Ogmo00<02NX:07mo
O`1oOgl01P1oOgl00`000000Ogmo07moO`0207moO`<02NX:00<0000007moO`1oOgl01@1oOgl00`00
0000Ogmo07moO`0N07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX0101oOgl00`09jPX0Ogmo07moO`02
07moO`030?ooo`09jPX0oooo0140oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`07
0?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`030?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:
103oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX00`3oool000000?ooo`060?ooo`00
1P3oool200000080oooo0P0000001@1oOgl02NX:07moO`1oOgl02NX:00@0Ogmo0P09jPX407moO`80
2NX:101oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00H0Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09
jPX0Ogmo07moO`0907moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl01P1oOgl00`09
jPX0Ogmo07moO`0d07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl00P1oOgl300WZ
2P030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0201oOglG0?ooo`0400WZ2P3oool0oooo
00WZ2P@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0
oooo01L0oooo00<02NX:0?ooo`3oool01`3oool200WZ2P<0oooo00<02NX:0?ooo`3oool00`3oool0
1P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`80
2NX:00<0oooo0000003oool01P3oool000L0oooo00L02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:
0080oooo00D02NX:0?ooo`3oool0oooo07moO`0200WZ2P@0Ogmo0P09jPX407moO`0500WZ2P1oOgl0
Ogmo07moO`09jPX01P1oOgl200WZ2PL0Ogmo00<02NX:07moO`1oOgl02@1oOgl00`09jPX0Ogmo07mo
O`0207moO`0300WZ2P1oOgl0Ogmo00H0Ogmo0P09jPXd07moO`030?ooo`09jPX0oooo00D0oooo0P1o
Ogl00`000000Ogmo07moO`0207moO`<02NX:00<0000007moO`1oOgl01@1oOgl00`000000oooo0?oo
o`0O0?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`0@0?ooo`0300WZ2P3oool0oooo01L0oooo00<02NX:0?ooo`3oool01`3oool200WZ2P<0oooo
00<02NX:0?ooo`3oool00`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00D02NX:0?oo
o`09jPX0oooo00WZ2P040?ooo`802NX:00<0oooo0000003oool01P3oool000L0oooo00L02NX:0?oo
o`3oool0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P3oool200WZ2P@0oooo0P09
jPX40?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`802NX:1`3oool200WZ2PX0oooo0P09
jPX30?ooo`0300WZ2P3oool0oooo00H0oooo0P09jPXe0?ooo`0300WZ2P3oool0oooo00@0oooo0P1o
Ogl00`000000Ogmo07moO`0207moO`<02NX:00<0000007moO`1oOgl01@1oOgl00`000000oooo0?oo
o`0O0?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`0@0?ooo`0300WZ2P3oool0oooo01L0oooo00<02NX:0?ooo`3oool01`3oool200WZ2P<0oooo
00<02NX:0?ooo`3oool00`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00D02NX:0?oo
o`09jPX0oooo00WZ2P040?ooo`802NX:00<0oooo0000003oool01P3oool000L0oooo00<0000000WZ
2P3oool00P3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo00<02NX:0?ooo`09jPX0103oool2
00WZ2P@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P060?ooo`0300WZ2P3oool0oooo00D0oooo0P09
jPX:0?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`060?ooo`802NX:=@3oool00`09jPX0oooo0?oo
o`040?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl300WZ2P030000001oOgl0Ogmo00D0Ogmo00<0
00000?ooo`3oool07`3oool01009jPX0oooo0?ooo`09jPX40?ooo`0300WZ2P3oool0oooo00<0oooo
00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00L0oooo
0P09jPX30?ooo`0300WZ2P3oool0oooo00<0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?oo
o`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool300WZ2P030?ooo`000000oooo00H0oooo00070?oo
o`0300000009jPX0oooo0080oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?oo
o`802NX:103oool200WZ2P@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P060?ooo`0300WZ2P3oool0
oooo00H0oooo00<02NX:0?ooo`3oool0203oool200WZ2P<0oooo00<02NX:0?ooo`3oool01P3oool2
00WZ2SD0oooo00<02NX:0?ooo`3oool0103oool207moO`030000001oOgl0Ogmo0080Ogmo0`09jPX0
0`000000Ogmo07moO`0507moO`030000003oool0oooo01l0oooo00@02NX:0?ooo`3oool02NX:103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:0?ooo`3oool0603o
ool00`09jPX0oooo0?ooo`070?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`020?ooo`0400WZ2P3o
ool0oooo0?ooo`802NX:103oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX20?ooo`03
0000003oool0oooo00D0oooo00070?ooo`0300000009jPX0oooo0080oooo00<02NX:0?ooo`09jPX0
0P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:103oool200WZ2P@0oooo00D02NX:0?ooo`3oool0
oooo00WZ2P060?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0203oool200WZ2P@0
oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0c0?ooo`0300WZ2P3oool0oooo00@0
oooo0P1oOgl00`000000Ogmo07moO`0207moO`<02NX:00<0000007moO`1oOgl01@1oOgl00`000000
oooo0?ooo`0O0?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo00<02NX:0?ooo`3oool00`3oool200WZ
2Q00oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`070?ooo`802NX:0`3oool00`09
jPX0oooo0?ooo`020?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool01@09jPX0oooo00WZ
2P3oool02NX:00@0oooo0P09jPX20?ooo`030000003oool0oooo00D0oooo00070?ooo`0300000009
jPX0oooo0080oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:103o
ool200WZ2P@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P060?ooo`802NX:1`3oool00`09jPX0oooo
0?ooo`080?ooo`802NX:103oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo03<0oooo
00<02NX:0?ooo`3oool0103oool207moO`030000001oOgl0Ogmo0080Ogmo0`09jPX00`000000Ogmo
07moO`0507moO`030000003oool0oooo01l0oooo00D02NX:0?ooo`3oool0oooo00WZ2P030?ooo`03
00WZ2P3oool0oooo00<0oooo0P09jPX@0?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3o
ool01`3oool200WZ2P<0oooo00<02NX:0?ooo`3oool00P3oool01P09jPX0oooo0?ooo`09jPX0oooo
00WZ2P@0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:00<0oooo0000000000001`3o
ool000L0oooo00<0000000WZ2P3oool00P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0
oooo0080oooo0P09jPX40?ooo`802NX:103oool200WZ2P80oooo00<02NX:0?ooo`3oool0103oool2
00WZ2PL0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool0
oooo00H0oooo0P09jPXd0?ooo`0300WZ2P3oool0oooo00@0oooo0P1oOgl00`000000Ogmo07moO`02
07moO`<02NX:00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0O0?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX00`3oool00`09jPX0oooo0?ooo`030?ooo`802NX:403oool00`09jPX0oooo0?oo
o`0G0?ooo`0300WZ2P3oool0oooo00L0oooo0`09jPX20?ooo`0300WZ2P3oool0oooo00<0oooo00H0
2NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ
2P030?ooo`000000000000L0oooo00070?ooo`0300000009jPX0oooo0080oooo00<02NX:0?ooo`09
jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:103oool200WZ2P@0oooo0P09jPX20?ooo`03
00WZ2P3oool0oooo00@0oooo0P09jPX70?ooo`802NX:2@3oool00`09jPX0oooo00WZ2P030?ooo`03
00WZ2P3oool0oooo00H0oooo0P09jPXd0?ooo`0300WZ2P3oool0oooo00@0oooo0P1oOgl00`000000
Ogmo07moO`0207moO`<02NX:00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0O0?ooo`05
00WZ2P3oool0oooo0?ooo`09jPX00`3oool00`09jPX0oooo0?ooo`030?ooo`802NX:403oool00`09
jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo00L0oooo0`09jPX20?ooo`0300WZ2P3oool0oooo
00<0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0
103oool200WZ2P80oooo00<02NX:0?ooo`3oool01@3oool000L0oooo00<0000000WZ2P3oool00P3o
ool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX40?ooo`802NX:103o
ool200WZ2P80oooo00<02NX:0?ooo`3oool0103oool200WZ2PL0oooo0P09jPX90?ooo`0300WZ2P3o
ool02NX:00<0oooo00<02NX:0?ooo`3oool01P3oool200WZ2S@0oooo00<02NX:0?ooo`3oool0103o
ool207moO`030000001oOgl0Ogmo0080Ogmo0`09jPX00`000000Ogmo07moO`0507moO`030000003o
ool0oooo0200oooo00@02NX:0?ooo`3oool02NX:0`3oool00`09jPX0oooo0?ooo`030?ooo`802NX:
403oool00`09jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo00L0oooo0`09jPX20?ooo`0300WZ
2P3oool0oooo00<0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:
0?ooo`09jPX0103oool200WZ2P80oooo00<02NX:0?ooo`3oool01@3oool000L0oooo00<000000?oo
o`09jPX00`3oool200WZ2P80oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo00WZ2P030?oo
o`<02NX:0`3oool200WZ2P80oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo00WZ2P060?oo
o`802NX:2@3oool00`09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo00H0oooo0P09jPXd0?oo
o`0300WZ2P3oool0oooo00@0oooo0P1oOgl00`000000Ogmo07moO`0207moO`<02NX:00<0000007mo
O`1oOgl01@1oOgl00`000000oooo0?ooo`0P0?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00<02NX:
0?ooo`3oool00`3oool200WZ2Q00oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`07
0?ooo`<02NX:0P3oool00`09jPX0oooo0?ooo`030?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:
103oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0`09jPX00`3oool02NX:000000070?ooo`00
1`3oool00`000000oooo00WZ2P030?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool0
0P3oool200WZ2P@0oooo0P09jPX40?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01P3oool200WZ2PH0
oooo0P09jPX90?ooo`0300WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`3oool01P3oool200WZ2S@0
oooo00<02NX:0?ooo`3oool0103oool207moO`030000001oOgl0Ogmo0080Ogmo0`09jPX00`000000
Ogmo07moO`0507moO`030000003oool0oooo0200oooo00@02NX:0?ooo`3oool02NX:0`3oool00`09
jPX0oooo0?ooo`030?ooo`802NX:403oool00`09jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo
00L0oooo0`09jPX20?ooo`0300WZ2P3oool0oooo0080oooo00L02NX:0?ooo`3oool0oooo00WZ2P3o
ool02NX:00<0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`<02NX:00<0oooo00WZ2P000000
1`3oool000H0oooo0P0000000`3oool02NX:0?ooo`020?ooo`0300WZ2P3oool02NX:0080oooo00<0
2NX:0?ooo`3oool00P3oool200WZ2P@0oooo0P09jPX40?ooo`802NX:0P3oool00`09jPX0oooo0?oo
o`040?ooo`802NX:1P3oool200WZ2PT0oooo00<02NX:0?ooo`09jPX00`3oool00`09jPX0oooo0?oo
o`060?ooo`0300WZ2P3oool02NX:03<0oooo00<02NX:0?ooo`3oool0103oool207moO`030000001o
Ogl0Ogmo0080Ogmo0`09jPX00`000000Ogmo07moO`0507moO`030000003oool0oooo0200oooo00@0
2NX:0?ooo`3oool02NX:0`3oool00`09jPX0oooo0?ooo`030?ooo`802NX:403oool00`09jPX0oooo
0?ooo`0G0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo
0?ooo`020?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool01@09jPX0oooo00WZ2P3oool0
2NX:00@0oooo0`09jPX00`3oool02NX:000000070?ooo`001P3oool2000000030?ooo`09jPX0oooo
0080oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:103oool200WZ
2P@0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00@0oooo0P09jPX60?ooo`0300WZ2P3oool02NX:
00P0oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0
2NX:03<0oooo00<02NX:0?ooo`3oool0103oool207moO`030000001oOgl0Ogmo0080Ogmo0`09jPX0
0`000000Ogmo07moO`0507moO`030000003oool0oooo0200oooo00D02NX:0?ooo`3oool0oooo00WZ
2P020?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPX@0?ooo`0300WZ2P3oool0oooo01L0oooo00<0
2NX:0?ooo`3oool01`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080oooo00H0
2NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool300WZ
2P030?ooo`09jPX0000000L0oooo00070?ooo`0300WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`09
jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:103oool200WZ2P@0oooo0P09jPX20?ooo`03
00WZ2P3oool0oooo00@0oooo0P09jPX70?ooo`802NX:203oool01009jPX0oooo0?ooo`09jPX20?oo
o`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`09jPX0<`3oool00`09jPX0oooo0?ooo`040?oo
o`80Ogmo00<0000007moO`1oOgl00P1oOgl300WZ2P030000001oOgl0Ogmo00D0Ogmo00<000000?oo
o`3oool0803oool02@09jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:
403oool00`09jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`09jPX0
0P3oool00`09jPX0oooo0?ooo`020?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool01@09
jPX0oooo00WZ2P3oool02NX:00@0oooo0`09jPX00`3oool02NX:000000070?ooo`001`3oool00`09
jPX0oooo00WZ2P030?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P3oool200WZ
2P@0oooo0`09jPX30?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool02NX:
00H0oooo0P09jPX80?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool01P3oool0
0`09jPX0oooo00WZ2P0c0?ooo`0300WZ2P3oool0oooo00@0oooo0P1oOgl00`000000Ogmo07moO`02
07moO`@02NX:1`1oOgl00`000000oooo0?ooo`0P0?ooo`0900WZ2P3oool0oooo0?ooo`09jPX0oooo
00WZ2P3oool02NX:00@0oooo0P09jPX@0?ooo`0300WZ2P3oool0oooo01L0oooo00<02NX:0?ooo`3o
ool01`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080oooo00H02NX:0?ooo`3o
ool02NX:0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool300WZ2P030?ooo`09
jPX0000000L0oooo00070?ooo`0300000009jPX02NX:00<0oooo00<02NX:0?ooo`09jPX00P3oool0
0`09jPX0oooo0?ooo`020?ooo`802NX:103oool300WZ2P<0oooo0P09jPX20?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`09jPX01P3oool200WZ2PP0oooo00@02NX:0?ooo`3oool02NX:0P3o
ool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool02NX:03@0oooo00<02NX:0?ooo`3oool00`3o
ool207moO`030000001oOgl0Ogmo0080Ogmo1009jPX707moO`030000003oool0oooo0200oooo00T0
2NX:0?ooo`3oool0oooo00WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2Q00oooo00<02NX:0?oo
o`3oool05P3oool00`09jPX0oooo0?ooo`070?ooo`802NX:00@0oooo00WZ2P3oool02NX:1@3oool0
1P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`<0
2NX:00<0oooo00WZ2P0000001`3oool000L0oooo00@0000000WZ2P3oool02NX:0`3oool200WZ2P80
oooo00<02NX:0?ooo`3oool00P3oool200WZ2P@0oooo0`09jPX30?ooo`0500WZ2P3oool02NX:0?oo
o`09jPX01P3oool00`09jPX0oooo00WZ2P060?ooo`802NX:203oool01009jPX0oooo0?ooo`09jPX2
0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`09jPX0=03oool00`09jPX0oooo0?ooo`03
0?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl400WZ2PL0Ogmo00<000000?ooo`3oool0803oool0
2@09jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:403oool00`09jPX0
oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo00L0oooo0P09jPX0103oool02NX:0?ooo`09jPX50?oo
o`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo
0P09jPX01@3oool02NX:00WZ2P3oool0000000L0oooo00070?ooo`0400000009jPX0oooo00WZ2P<0
oooo00<02NX:0?ooo`09jPX00P3oool01`09jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX00`3oool3
00WZ2P<0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P060?ooo`0300WZ2P3oool02NX:00H0oooo0P09
jPX80?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ
2P3oool02NX:03<0oooo00<02NX:0?ooo`3oool00`3oool207moO`030000001oOgl0Ogmo0080Ogmo
1009jPX707moO`030000003oool0oooo0200oooo00T02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:
0?ooo`09jPX0103oool200WZ2Q00oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`07
0?ooo`802NX:00@0oooo00WZ2P3oool02NX:103oool01`09jPX0oooo0?ooo`3oool02NX:0?ooo`09
jPX0103oool200WZ2P030?ooo`09jPX0oooo00<0oooo0P09jPX01@3oool02NX:00WZ2P3oool00000
00L0oooo00070?ooo`0400000009jPX0oooo00WZ2P<0oooo00<02NX:0?ooo`09jPX00P3oool00`09
jPX0oooo0?ooo`020?ooo`802NX:103oool300WZ2P<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo
00@0oooo00<02NX:0?ooo`09jPX01@3oool00`09jPX0oooo00WZ2P060?ooo`0300WZ2P3oool0oooo
0080oooo00@02NX:0?ooo`3oool02NX:203oool00`09jPX0oooo00WZ2P0c0?ooo`0300WZ2P3oool0
oooo00<0oooo0P1oOgl00`000000Ogmo07moO`0207moO`@02NX:1`1oOgl00`000000oooo0?ooo`0Q
0?ooo`0800WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`09jPX40?ooo`802NX:403oool00`09jPX0
oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo00L0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX4
0?ooo`0700WZ2P3oool0oooo0?ooo`09jPX0oooo00WZ2P030?ooo`0500WZ2P3oool02NX:0?ooo`09
jPX0103oool200WZ2P050?ooo`09jPX02NX:0?ooo`0000001`3oool000L0oooo00@0000000WZ2P3o
ool02NX:0`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX40?oo
o`<02NX:0`3oool200WZ2P80oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo00WZ2P050?oo
o`0300WZ2P3oool02NX:00H0oooo00<02NX:0?ooo`3oool00P3oool01009jPX0oooo0?ooo`09jPX8
0?ooo`0300WZ2P3oool02NX:03<0oooo00<02NX:0?ooo`3oool00`3oool207moO`030000001oOgl0
Ogmo0080Ogmo1009jPX707moO`030000003oool0oooo0240oooo00P02NX:0?ooo`3oool02NX:0?oo
o`09jPX0oooo00WZ2P@0oooo0P09jPX@0?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3o
ool01`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00H02NX:0?ooo`3oool02NX:0?oo
o`09jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P050?ooo`09jPX02NX:0?oo
o`0000001`3oool000L0oooo00@0000000WZ2P3oool02NX:0`3oool00`09jPX0oooo00WZ2P020?oo
o`0300WZ2P3oool0oooo0080oooo0P09jPX40?ooo`<02NX:0`3oool200WZ2P80oooo00<02NX:0?oo
o`3oool0103oool00`09jPX0oooo00WZ2P050?ooo`0300WZ2P3oool02NX:00H0oooo00<02NX:0?oo
o`3oool00P3oool01009jPX0oooo0?ooo`09jPX80?ooo`0300WZ2P3oool02NX:03<0oooo00<02NX:
0?ooo`3oool00`3oool207moO`030000001oOgl0Ogmo0080Ogmo1009jPX707moO`030000003oool0
oooo0240oooo00@02NX:0?ooo`3oool0oooo0P09jPX00`3oool02NX:0?ooo`030?ooo`802NX:403o
ool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo00L0oooo00H02NX:0?ooo`3oool02NX:
0?ooo`09jPX40?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool01@09jPX0oooo00WZ2P3o
ool02NX:00@0oooo0P09jPX01@3oool02NX:00WZ2P3oool0000000L0oooo00070?ooo`0400000009
jPX0oooo00WZ2P<0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:
103oool300WZ2P<0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P060?ooo`0300WZ2P3oool02NX:00D0
oooo00<02NX:0?ooo`09jPX01P3oool00`09jPX0oooo0?ooo`020?ooo`0400WZ2P3oool0oooo00WZ
2PP0oooo00<02NX:0?ooo`09jPX0<`3oool00`09jPX0oooo0?ooo`030?ooo`80Ogmo00<0000007mo
O`1oOgl00P1oOgl400WZ2PL0Ogmo00<000000?ooo`3oool08@3oool01009jPX0oooo0?ooo`3oool2
00WZ2P030?ooo`09jPX0oooo00<0oooo0P09jPX?0?ooo`0300WZ2P3oool0oooo01L0oooo00<02NX:
0?ooo`3oool01`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00H02NX:0?ooo`3oool0
2NX:0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P050?ooo`09jPX0
2NX:0?ooo`0000001`3oool000L0oooo00@000000?ooo`09jPX02NX:0`3oool00`09jPX0oooo00WZ
2P020?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX40?ooo`<02NX:0`3oool01@09jPX0oooo00WZ
2P3oool02NX:00H0oooo00@02NX:0?ooo`3oool02NX:103oool00`09jPX0oooo00WZ2P060?ooo`03
00WZ2P3oool0oooo0080oooo00@02NX:0?ooo`3oool02NX:203oool00`09jPX0oooo00WZ2P0c0?oo
o`0300WZ2P3oool0oooo00<0oooo0P1oOgl00`000000Ogmo07moO`0207moO`@02NX:1`1oOgl00`00
0000oooo0?ooo`0Q0?ooo`0400WZ2P3oool0oooo0?ooo`802NX:00<0oooo00WZ2P3oool00`3oool0
0`09jPX0oooo00WZ2P0>0?ooo`0300WZ2P3oool0oooo01L0oooo00<02NX:0?ooo`3oool01`3oool0
1P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX40?oo
o`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P050?ooo`09jPX02NX:0?ooo`0000001`3o
ool000L0oooo00D000000?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool00`09jPX0oooo0?oo
o`020?ooo`802NX:103oool200WZ2P090?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:
00H0oooo00@02NX:0?ooo`3oool02NX:1@3oool200WZ2PH0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo00WZ2P080?ooo`0400WZ2P3oool0oooo00WZ2S80oooo00<02NX:0?ooo`3oool00`3o
ool207moO`030000001oOgl0Ogmo0080Ogmo1009jPX707moO`030000003oool0oooo0240oooo00@0
2NX:0?ooo`3oool0oooo0P09jPX00`3oool02NX:0?ooo`030?ooo`0300WZ2P3oool02NX:00h0oooo
00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`070?ooo`0600WZ2P3oool0oooo00WZ2P3o
ool02NX:103oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P@0oooo00D02NX:0?ooo`09jPX0oooo
00WZ2P030?ooo`802NX:0P3oool01009jPX0oooo0?ooo`0000070?ooo`001`3oool01@000000oooo
00WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`3oool200WZ
2P@0oooo0P09jPX02@3oool02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P060?ooo`0400WZ
2P3oool0oooo00WZ2PD0oooo00<02NX:0?ooo`09jPX01@3oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool02NX:00P0oooo00@02NX:0?ooo`3oool02NX:<P3oool00`09jPX0oooo0?ooo`030?oo
o`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`09jPX0Ogmo00H0Ogmo00<000000?oo
o`3oool08@3oool01009jPX0oooo0?ooo`3oool200WZ2P030?ooo`09jPX0oooo00<0oooo00<02NX:
0?ooo`09jPX03P3oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo00L0oooo0P09jPX2
0?ooo`802NX:103oool01`09jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX0103oool01009jPX0oooo
00WZ2P09jPX40?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool00`000000oooo0?ooo`050?ooo`00
1`3oool01@000000oooo00WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0
oooo0?ooo`020?ooo`802NX:0`3oool200WZ2P090?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3o
ool02NX:00H0oooo00@02NX:0?ooo`3oool02NX:1@3oool00`09jPX0oooo00WZ2P050?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`09jPX0203oool01009jPX0oooo0?ooo`09jPXb0?ooo`03
00WZ2P3oool0oooo00<0oooo0P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo00WZ2P1o
Ogl01P1oOgl00`000000oooo0?ooo`0Q0?ooo`0400WZ2P3oool0oooo0?ooo`802NX:00<0oooo00WZ
2P3oool00`3oool00`09jPX0oooo00WZ2P0>0?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?oo
o`3oool01`3oool01009jPX0oooo0?ooo`3oool200WZ2P@0oooo00L02NX:0?ooo`3oool0oooo00WZ
2P3oool02NX:00<0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:00<0oooo00WZ2P09
jPX00P3oool00`000000oooo0?ooo`050?ooo`001`3oool01@000000oooo00WZ2P3oool02NX:00<0
oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:0`3oool200WZ2P05
0?ooo`09jPX0oooo0?ooo`09jPX00P3oool200WZ2PL0oooo00<02NX:0?ooo`09jPX01@3oool00`09
jPX0oooo00WZ2P050?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`09jPX0203oool01009
jPX0oooo0?ooo`09jPXb0?ooo`0300WZ2P3oool0oooo00<0oooo0P1oOgl00`000000Ogmo07moO`02
07moO`802NX:00<0Ogmo00WZ2P1oOgl01P1oOgl00`000000oooo0?ooo`0Q0?ooo`0400WZ2P3oool0
oooo0?ooo`802NX:00<0oooo00WZ2P3oool00`3oool00`09jPX0oooo00WZ2P0>0?ooo`0300WZ2P3o
ool0oooo01H0oooo00<02NX:0?ooo`3oool01`3oool01009jPX0oooo0?ooo`3oool200WZ2P@0oooo
00@02NX:0?ooo`3oool0oooo0P09jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ
2P030?ooo`09jPX02NX:0080oooo00<000000?ooo`3oool01@3oool000L0oooo00D000000?ooo`09
jPX0oooo00WZ2P030?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P3oool200WZ
2P@0oooo0`09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09jPX01P3oool01009jPX0oooo0?ooo`09
jPX40?ooo`0300WZ2P3oool02NX:00D0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo00WZ
2P080?ooo`0400WZ2P3oool0oooo00WZ2S80oooo00<02NX:0?ooo`3oool00`3oool207moO`030000
001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl02NX:07moO`0607moO`030000003oool0oooo0280oooo
00L02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:00@0oooo00<02NX:0?ooo`09jPX03P3oool00`09
jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo00H0oooo00<0000000WZ2P0000000`0000000`09
jPX00000000000020000000600WZ2P000000oooo00WZ2P3oool02NX:103oool01@09jPX0oooo00WZ
2P3oool02NX:00@0oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`030000003oool0oooo00D0oooo
00070?ooo`050000003oool02NX:0?ooo`09jPX00`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ
2P3oool0oooo0080oooo0P09jPX40?ooo`802NX:00T0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:
0?ooo`09jPX01P3oool01009jPX0oooo0?ooo`09jPX40?ooo`0300WZ2P3oool02NX:00D0oooo00<0
2NX:0?ooo`3oool00`3oool00`09jPX0oooo00WZ2P080?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0
<@3oool00`09jPX0oooo0?ooo`030?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307mo
O`09jPX0Ogmo00H0Ogmo00<000000?ooo`3oool08P3oool01`09jPX0oooo0?ooo`3oool02NX:0?oo
o`09jPX0103oool00`09jPX0oooo00WZ2P0=0?ooo`0300000009jPX0000001L0000000<02NX:0000
000000001`0000001009jPX0000007moO`00000200WZ2P@0Ogmo0P000000103oool02NX:0?ooo`09
jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P030?ooo`09jPX02NX:0080oooo
00<000000?ooo`3oool01@3oool000L0oooo00H000000?ooo`3oool02NX:0?ooo`09jPX20?ooo`03
00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P3oool200WZ2P@0oooo0P09jPX02@3oool0
2NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P060?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo
00@02NX:0?ooo`3oool02NX:103oool00`09jPX0oooo0?ooo`040?ooo`802NX:203oool01@09jPX0
oooo0?ooo`3oool02NX:0340oooo00<02NX:0?ooo`3oool00`3oool207moO`030000001oOgl0Ogmo
0080Ogmo0P09jPX00`1oOgl02NX:07moO`0607moO`030000003oool0oooo0280oooo00L02NX:0000
00000000000000WZ2P0000002NX:00@0000000<02NX:00000009jPX03P0000000`09jPX0Ogmo07mo
O`0E07moO`8000002@1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2P@0Ogmo00H02NX:0?ooo`3oool0
2NX:0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P030?ooo`09jPX0
oooo0080oooo00<000000?ooo`3oool01@3oool000L0oooo00H000000?ooo`3oool02NX:0?ooo`09
jPX30?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:103oool200WZ2P090?ooo`09
jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:00H0oooo00@02NX:0?ooo`3oool02NX:103oool0
1009jPX0oooo0?ooo`09jPX40?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`09jPX0203o
ool01009jPX0oooo0?ooo`09jPXa0?ooo`0300WZ2P3oool0oooo00<0oooo0P1oOgl00`000000Ogmo
07moO`0207moO`802NX:00<0Ogmo00WZ2P1oOgl01P1oOgl00`000000oooo0?ooo`0;0?oooaL00000
00L02NX:0000001oOgl0000000WZ2P0000002NX:00<0Ogmo00@0000000WZ2P0000002NX:3@1oOgl2
000001P0Ogmo00<02NX:07moO`1oOgl01`1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2P@0Ogmo00H0
2NX:0?ooo`3oool02NX:0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ
2P80oooo00D02NX:0?ooo`3oool0oooo000000070?ooo`001`3oool01P000000oooo0?ooo`09jPX0
oooo00WZ2P<0oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`3oool200WZ2P@0oooo
0P09jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo0P09jPX60?ooo`0500WZ2P3oool0oooo0?oo
o`09jPX00`3oool01009jPX0oooo0?ooo`09jPX40?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:
0?ooo`09jPX0203oool01009jPX0oooo0?ooo`09jPXa0?ooo`0300WZ2P3oool0oooo00<0oooo0P1o
Ogl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo00WZ2P1oOgl01P1oOgl>000001<0Ogmo00/0
2NX:0000001oOgl0Ogmo00WZ2P000000Ogmo00000009jPX0000000WZ2P0307moO`<0000000<02NX:
07moO`1oOgl0301oOgl00`09jPX0Ogmo07moO`0F07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00D02NX:
07moO`1oOgl0Ogmo00WZ2P0507moO`0600WZ2P3oool0oooo00WZ2P3oool02NX:103oool01009jPX0
oooo00WZ2P09jPX40?ooo`802NX:0P3oool01@09jPX0oooo0?ooo`3oool0000000L0oooo00070?oo
o`060000003oool0oooo00WZ2P3oool02NX:0`3oool00`09jPX0oooo00WZ2P020?ooo`0700WZ2P3o
ool0oooo0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`80
2NX:1P3oool01@09jPX0oooo0?ooo`3oool02NX:00<0oooo00@02NX:0?ooo`3oool02NX:103oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool02NX:00P0oooo00@02NX:0?ooo`3oool02NX:<@3o
ool00`09jPX000000000000300000080Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`09
jPX0000000H0Ogmo00<0000007moO`1oOgl07P1oOgl01@09jPX0000007moO`1oOgl02NX:00<0Ogmo
00<02NX:07moO`09jPX0101oOgl00`09jPX0Ogmo00WZ2P0=07moO`0300WZ2P1oOgl0Ogmo01L0Ogmo
00<02NX:07moO`1oOgl01P1oOgl01P0000002NX:07moO`1oOgl0000000WZ2P@0Ogmo00L0000000WZ
2P000000oooo00WZ2P3oool02NX:00<0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:
0P3oool01@09jPX0oooo0?ooo`3oool0000000L0oooo00070?ooo`060000003oool0oooo00WZ2P3o
ool02NX:0`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX30?oo
o`802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`802NX:1P3oool01@09jPX0oooo0?ooo`3oool0
2NX:00@0oooo00<02NX:0?ooo`09jPX0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
2NX:00P0oooo00@02NX:0?ooo`3oool02NX:6P3ooolG0000000300WZ2P1oOgl0Ogmo00D0Ogmo00D0
000007moO`1oOgl0Ogmo0000000200WZ2P0307moO`09jPX0000000H0Ogmo00<0000007moO`1oOgl0
7P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00<0Ogmo00<02NX:07moO`09jPX0101oOgl00`09jPX0
Ogmo00WZ2P0=07moO`0300WZ2P1oOgl0Ogmo01H0Ogmo00<0000000WZ2P1oOgl01`1oOgl01P000000
2NX:07moO`1oOgl0000000WZ2P@0Ogmo0P0000020?ooo`0300WZ2P3oool02NX:00<0oooo00D02NX:
0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:0P3oool01@09jPX0oooo0?ooo`3oool0000000L0oooo
00070?ooo`060000003oool0oooo00WZ2P3oool02NX:0`3oool00`09jPX0oooo00WZ2P020?ooo`03
00WZ2P3oool0oooo0080oooo0P09jPX30?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`80
2NX:1`3oool01009jPX0oooo0?ooo`09jPX40?ooo`0300WZ2P3oool02NX:00@0oooo00<02NX:0?oo
o`3oool01@3oool200WZ2PP0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0:0?ooo`l00000101oOgl0
0`0000002NX:07moO`0?07moO`8000001`1oOgl010000000Ogmo07moO`1oOgl30000000307moO`00
0000Ogmo00H0Ogmo00<0000007moO`1oOgl07P1oOgl200WZ2P<0Ogmo00H02NX:07moO`1oOgl02NX:
07moO`09jPX407moO`0300WZ2P1oOgl02NX:00`0Ogmo00<0000000WZ2P1oOgl05`1oOgl2000000T0
Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0507moO`0300WZ2P3oool0oooo00802NX:103oool01@09
jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX20?ooo`0500WZ2P3oool0oooo0?ooo`0000001`3o
ool000L0oooo00@000000?ooo`3oool0oooo0P09jPX30?ooo`0300WZ2P3oool02NX:0080oooo00<0
2NX:0?ooo`3oool00P3oool200WZ2P@0oooo0P09jPX02@3oool02NX:0?ooo`3oool02NX:0?ooo`09
jPX0oooo00WZ2P060?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo00@02NX:0?ooo`3oool02NX:0`3o
ool00`09jPX0oooo0?ooo`050?ooo`802NX:103oool40000000300WZ2P000000000000`000004`1o
Ogl00`0000002NX:07moO`0@07moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00P1o
Ogl200WZ2P0307moO`000000Ogmo00H0Ogmo00<0000007moO`1oOgl07@1oOgl300000080Ogmo00L0
000000WZ2P1oOgl0000000WZ2P0000002NX:00<0Ogmo00@0000000WZ2P0000002NX:301oOgl20000
01T0Ogmo00<02NX:07moO`1oOgl01`1oOgl00`09jPX0Ogmo07moO`0200WZ2P@0Ogmo00H02NX:07mo
O`1oOgl02NX:0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P80oooo
00D02NX:0?ooo`3oool0oooo000000070?ooo`001`3oool01`000000oooo0?ooo`3oool02NX:0?oo
o`09jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX40?oo
o`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`802NX:1P3oool01@09jPX0oooo0?ooo`3o
ool02NX:00<0oooo00@02NX:0000000000002NX:0`0000000`09jPX0000000000005000000802NX:
1000000307moO`0600000009jPX0Ogmo07moO`0000002NX:7P1oOgl00`09jPX0Ogmo07moO`0?07mo
O`0300WZ2P1oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo
00H0Ogmo00<0000007moO`1oOgl07@1oOgl20000000300WZ2P1oOgl0Ogmo0080000000D0Ogmo0000
00000000000000WZ2P0307moO`<0000000<02NX:07moO`1oOgl02`1oOgl00`09jPX0Ogmo07moO`0F
07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX407moO`0600WZ2P1o
Ogl0Ogmo00WZ2P3oool02NX:103oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo00<02NX:0?oo
o`3oool00P09jPX30?ooo`030000003oool0oooo00D0oooo00070?ooo`070000003oool0oooo0?oo
o`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:103oool2
00WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0P0000000`09jPX00000000000040000000500WZ2P00
0000000000000009jPX00`0000002009jPX0Ogmo07moO`09jPX0000007moO`0000002NX:1P1oOgl0
0`0000002NX:0000000707moO`8000000`1oOgl00`09jPX0Ogmo07moO`0L07moO`0300WZ2P1oOgl0
Ogmo00l0Ogmo00<02NX:07moO`1oOgl01@1oOgl01@000000Ogmo07moO`1oOgl0000000802NX:00<0
Ogmo0000001oOgl01P1oOgl00`000000Ogmo07moO`0N07moO`802NX:0`1oOgl01P09jPX0Ogmo07mo
O`09jPX0Ogmo00WZ2P@0Ogmo00<02NX:07moO`09jPX03@1oOgl00`09jPX0Ogmo07moO`0F07moO`03
00WZ2P1oOgl0Ogmo00<0Ogmo0P000000101oOgl0000000WZ2P00000207moO`0400000009jPX0Ogmo
00WZ2P80000000H02NX:07moO`1oOgl02NX:0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09
jPX00`3oool200WZ2P80oooo0P09jPX30?ooo`030000003oool0oooo00D0oooo00070?ooo`070000
003oool0oooo0?ooo`09jPX0oooo00WZ2P030?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool2
00WZ2P<0oooo00<0000000WZ2P09jPX00P0000000`09jPX0000000WZ2P02000000802NX:1@1oOgl2
00000080Ogmo00@0000000WZ2P1oOgl0Ogmo0P00000207moO`0500WZ2P000000Ogmo07moO`09jPX0
1`1oOgl200WZ2PP0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0N07moO`0300WZ2P1oOgl0Ogmo00h0
Ogmo00<0000000WZ2P1oOgl01P1oOgl01@000000Ogmo07moO`1oOgl0000000802NX:00<0Ogmo0000
001oOgl01P1oOgl00`000000Ogmo07moO`0N07moO`802NX:101oOgl00`09jPX0Ogmo00WZ2P0200WZ
2P@0Ogmo00<02NX:07moO`09jPX03@1oOgl00`09jPX0Ogmo07moO`0407moO`8000001P1oOgl00`09
jPX0000007moO`0607moO`0300000009jPX0Ogmo00@0Ogmo00<02NX:0000001oOgl00`0000001P1o
Ogl0oooo00000009jPX0oooo00WZ2P<000000P3oool00`09jPX0oooo00WZ2P040?ooo`0400WZ2P3o
ool02NX:00WZ2P@0oooo0P09jPX20?ooo`802NX:0`3oool00`000000oooo0?ooo`050?ooo`001`3o
ool01`000000oooo0?ooo`3oool02NX:0?ooo`09jPX00`3oool00`09jPX0oooo00WZ2P020?ooo`04
00WZ2P3oool0oooo0?ooo`802NX:0`3oool30000000307moO`0000002NX:008000000P1oOgl200WZ
2PH0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0307moO`0400WZ2P1oOgl0Ogmo00WZ2P<0Ogmo00<0
2NX:07moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0
2NX:07moO`1oOgl06P1oOgl00`0000002NX:0000000?07moO`8000001`1oOgl00`000000Ogmo07mo
O`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000Ogmo07moO`0N07moO`0300WZ2P1o
Ogl02NX:00<0Ogmo00<02NX:07moO`09jPX00P09jPX407moO`0300WZ2P1oOgl02NX:00@0Ogmo00H0
2NX:0000001oOgl0Ogmo00000009jPX207moO`0300000009jPX0Ogmo00D0Ogmo00<0000000WZ2P1o
Ogl01@1oOgl00`09jPX0000007moO`0507moO`030?ooo`000000000000D0oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P030?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`0300WZ2P3oool0
2NX:00@0oooo0P09jPX00`3oool02NX:0?ooo`030?ooo`802NX:0P3oool200WZ2P<0oooo00<00000
0?ooo`3oool01@3oool000L0oooo00L000000?ooo`3oool0oooo00WZ2P3oool02NX:00<0oooo00<0
2NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:0P3oool00`1oOgl02NX:00WZ
2P0207moO`0300WZ2P1oOgl02NX:0080Ogmo0P09jPX607moO`0300WZ2P1oOgl0Ogmo0080Ogmo00@0
2NX:07moO`1oOgl02NX:0`1oOgl01009jPX0Ogmo07moO`09jPX807moO`0300WZ2P1oOgl0Ogmo00H0
Ogmo00H02NX:0000001oOgl0Ogmo00000009jPXL07moO`0300000009jPX000000100Ogmo00<02NX:
07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl0
0`000000Ogmo07moO`0M07moO`0400000009jPX0000000WZ2P80Ogmo00<0000000WZ2P0000000`09
jPX20000000507moO`0000002NX:00000009jPX0101oOgl01P09jPX0000007moO`1oOgl0000000WZ
2P80Ogmo0P0000070?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool01`3oool00`09
jPX0oooo0?ooo`030?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00`3oool200WZ2P050?ooo`09jPX0
oooo0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P030?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0
103oool200WZ2P80oooo0P09jPX30?ooo`030000003oool0oooo00D0oooo00070?ooo`070000003o
ool0oooo0?ooo`09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3o
ool00P3oool200WZ2P80oooo0P1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2P<0Ogmo0P09jPX507mo
O`0300WZ2P1oOgl0Ogmo0080Ogmo00@02NX:07moO`1oOgl02NX:0P1oOgl20000000307moO`000000
2NX:00L0Ogmo00<0000000WZ2P0000001`1oOgl01P09jPX0000007moO`1oOgl0000000WZ2Qd0Ogmo
00<02NX:07moO`1oOgl03`1oOgl00`09jPX0Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo
0P09jPX00`1oOgl0000007moO`0607moO`030000001oOgl0Ogmo01d0Ogmo0`0000000`09jPX0Ogmo
07moO`050000000400WZ2P00000000000?ooo`<0000000<02NX:0?ooo`3oool00P3oool00`09jPX0
oooo0?ooo`020?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01`3oool00`09jPX0oooo0?ooo`040?oo
o`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool00`3oool01@09jPX0oooo0?ooo`3oool0
2NX:00<0oooo0P09jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo00<02NX:0?ooo`09jPX00`3o
ool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX20?ooo`802NX:0`3oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`020?ooo`802NX:0`3oool00`09jPX0oooo00WZ
2P020?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX20?ooo`80Ogmo00<02NX:07moO`1oOgl00P00
00001009jPX0Ogmo07moO`00000200WZ2P@0Ogmo00<0000000WZ2P1oOgl00P1oOgl02P0000002NX:
07moO`1oOgl02NX:0000001oOgl0000000WZ2P1oOgl2000000L0Ogmo00<0000000WZ2P0000001`1o
Ogl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo01X0Ogmo00<02NX:07moO`09jPX0401o
Ogl00`09jPX0Ogmo07moO`0507moO`050000001oOgl0Ogmo07moO`0000000P09jPX00`1oOgl00000
07moO`0607moO`030000001oOgl0Ogmo01/0Ogmo0`3oool00`09jPX0oooo00WZ2P030?ooo`0300WZ
2P3oool02NX:00<02NX:0`3oool00`09jPX0oooo00WZ2P040?ooo`0300WZ2P3oool0oooo0080oooo
00D02NX:0?ooo`3oool0oooo00WZ2P070?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool01`3oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00<02NX:0?oo
o`09jPX00P09jPX01`3oool02NX:0?ooo`3oool02NX:0?ooo`09jPX0103oool01@09jPX0oooo00WZ
2P3oool02NX:00@0oooo0P09jPX20?ooo`802NX:0`3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`020?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3o
ool00`09jPX0oooo0?ooo`020?ooo`802NX:0P3oool01P1oOgl0000000WZ2P000000Ogmo00000080
2NX:0P1oOgl00`0000002NX:0000000407moO`8000000`1oOgl0100000002NX:07moO`1oOgl20000
0080Ogmo00@02NX:07moO`1oOgl02NX:201oOgl00`09jPX0Ogmo07moO`0607moO`0300WZ2P1oOgl0
Ogmo00<0Ogmo00<02NX:07moO`1oOgl06@1oOgl00`09jPX000000000000507moO`0300000009jPX0
Ogmo00L0Ogmo00<0000000WZ2P1oOgl01P1oOgl010000000Ogmo07moO`1oOgl30000000307moO`00
0000Ogmo00H0Ogmo00<0000007moO`1oOgl01@1oOglI0?ooo`0300WZ2P3oool02NX:00<0oooo00<0
2NX:0?ooo`09jPX00`09jPX30?ooo`0300WZ2P3oool02NX:00@0oooo0P09jPX30?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX01`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00L0oooo
00<02NX:0?ooo`3oool00P3oool200WZ2P80oooo00H02NX:0?ooo`3oool0oooo00WZ2P3oool300WZ
2P070?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P040?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0
103oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P<0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool00`09jPX0
oooo0?ooo`020?ooo`802NX:0P3oool0101oOgl0000000000000000207moO`802NX:0`1oOgl200WZ
2PD0Ogmo00<02NX:07moO`1oOgl00P1oOgl01009jPX0Ogmo07moO`09jPX307moO`0400WZ2P1oOgl0
Ogmo00WZ2PP0Ogmo0P09jPX807moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl06@1o
Ogl00`09jPX0000000WZ2P0507moO`0300000009jPX0Ogmo00L0Ogmo0P00000707moO`030000001o
Ogl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01h0oooo00<0
2NX:0?ooo`09jPX00`3oool00`09jPX0oooo00WZ2P0300WZ2P<0oooo00<02NX:0?ooo`09jPX0103o
ool200WZ2P<0oooo00D02NX:0?ooo`3oool0oooo00WZ2P070?ooo`0300WZ2P3oool0oooo00@0oooo
00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`020?ooo`802NX:0P3oool01P09jPX0oooo
0?ooo`3oool02NX:0?ooo`<02NX:00L0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:00@0oooo00D0
2NX:0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P030?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0080oooo00<02NX:0?ooo`09jPX00`3o
ool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX20?ooo`80Ogmo00@02NX:07moO`1oOgl0
Ogmo0P09jPX407moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00P1oOgl01009jPX0
Ogmo07moO`09jPX307moO`0300WZ2P1oOgl02NX:00P0Ogmo0P09jPX207moO`8000000`1oOgl00`00
00002NX:07moO`0207moO`0300000009jPX0Ogmo00@0Ogmo00<0000000WZ2P1oOgl04`1oOgl00`09
jPX0Ogmo00WZ2P0207moO`@0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`030?oo
o`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<000000?oo
o`3oool07P3oool00`09jPX0oooo00WZ2P040?ooo`802NX:00<0oooo00WZ2P09jPX00`3oool00`09
jPX0oooo00WZ2P040?ooo`802NX:0`3oool01@09jPX0oooo0?ooo`3oool02NX:00L0oooo00<02NX:
0?ooo`3oool00`3oool200WZ2PP0oooo00<02NX:0?ooo`3oool00`3oool200WZ2P80oooo00H02NX:
0?ooo`3oool0oooo00WZ2P3oool300WZ2P070?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P040?oo
o`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo00<02NX:0?ooo`09jPX00`3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`020?ooo`0300WZ2P3oool02NX:
00<0oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`3oool200WZ2P80oooo0P1oOgl2
00WZ2P<0Ogmo0P09jPX307moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00@02NX:07moO`1oOgl0Ogmo0P00
00000`1oOgl0000000WZ2P0207moO`0400000009jPX0000000WZ2PP0Ogmo00H02NX:0000001oOgl0
Ogmo00WZ2P00000307moO`8000000`1oOgl00`0000002NX:07moO`0407moO`0300000009jPX0Ogmo
00@0Ogmo3`3oool00`09jPX0oooo00WZ2P060?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?oo
o`3oool00`3oool207moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607mo
O`030000003oool0oooo01h0oooo00<02NX:0?ooo`09jPX0103oool200WZ2P030?ooo`09jPX02NX:
00<0oooo00<02NX:0?ooo`09jPX0103oool200WZ2P80oooo0P09jPX20?ooo`0300WZ2P3oool0oooo
00D0oooo0P09jPX50?ooo`802NX:203oool00`09jPX0oooo0?ooo`030?ooo`802NX:0P3oool01P09
jPX0oooo0?ooo`3oool02NX:0?ooo`<02NX:00L0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:00@0
oooo0P09jPX00`3oool02NX:0?ooo`030?ooo`802NX:0P3oool200WZ2P@0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo00WZ2P030?ooo`0300WZ
2P3oool02NX:0080oooo00P02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:0?ooo`80Ogmo0P09jPX3
07moO`0800WZ2P0000002NX:07moO`0000002NX:00000009jPX307moO`0300000009jPX0Ogmo0080
Ogmo00D0000000WZ2P1oOgl0000000WZ2P0207moO`0400000009jPX00000000000P0Ogmo00H02NX:
0000001oOgl0Ogmo00WZ2P1oOgl40?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool02NX:00H0oooo00<02NX:0?ooo`3oool0
1`3oool00`09jPX0oooo0?ooo`030?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307mo
O`000000Ogmo00H0Ogmo00<000000?ooo`3oool07P3oool00`09jPX0oooo00WZ2P040?ooo`802NX:
00<0oooo00WZ2P09jPX00`3oool00`09jPX0oooo00WZ2P040?ooo`802NX:0P3oool200WZ2P80oooo
00<02NX:0?ooo`3oool01@3oool200WZ2PD0oooo0P09jPX80?ooo`0300WZ2P3oool0oooo00<0oooo
0P09jPX20?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo0`09jPX01`3oool02NX:0?ooo`3oool0
2NX:0?ooo`09jPX00`3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX20?ooo`802NX:
103oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`020?ooo`0300WZ2P3o
ool02NX:00<0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:00<0
oooo07moO`1oOgl00P09jPX307moO`0800WZ2P0000002NX:07moO`0000002NX:00000009jPX30?oo
o`800000103oool01009jPX0oooo0?ooo`09jPX20?ooo`802NX:00<0oooo00WZ2P3oool01`3oool2
00WZ2P80oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo00WZ2P060?ooo`802NX:203oool0
0`09jPX0oooo0?ooo`030?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000
Ogmo00H0Ogmo00<000000?ooo`3oool07P3oool00`09jPX0oooo00WZ2P040?ooo`802NX:00<0oooo
00WZ2P09jPX00`3oool00`09jPX0oooo00WZ2P040?ooo`802NX:0P3oool200WZ2P80oooo00<02NX:
0?ooo`3oool01@3oool200WZ2PD0oooo0P09jPX80?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPX2
0?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo0`09jPX01`3oool02NX:0?ooo`3oool02NX:0?oo
o`09jPX00`3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX20?ooo`802NX:103oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`030?ooo`802NX:0`3oool00`09
jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX30?ooo`802NX:0`3oool300WZ
2P80oooo00<02NX:0?ooo`09jPX0103oool00`09jPX0oooo0?ooo`020?ooo`0400WZ2P3oool0oooo
00WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`070?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool00`3oool200WZ2Q<0oooo00@02NX:
0?ooo`3oool02NX:1@3oool200WZ2PP0oooo00<02NX:0?ooo`3oool00`3oool207moO`030000001o
Ogl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01h0oooo00<0
2NX:0?ooo`09jPX0103oool200WZ2P030?ooo`09jPX02NX:00<0oooo00<02NX:0?ooo`09jPX01@3o
ool200WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?ooo`3oool01@3oool200WZ2PD0oooo0P09
jPX80?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPX20?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0
oooo0`09jPX0103oool02NX:0?ooo`3oool200WZ2P@0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P04
0?ooo`802NX:00@0oooo00WZ2P3oool02NX:103oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`030?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool0
0`09jPX0oooo0?ooo`020?ooo`802NX:0`3oool200WZ2P@0oooo0`09jPX0103oool02NX:00WZ2P09
jPX40?ooo`0300WZ2P3oool0oooo0080oooo00@02NX:0?ooo`3oool02NX:0P3oool400WZ2PT0oooo
00<02NX:0?ooo`3oool00P09jPX40?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
0`3oool200WZ2Q<0oooo00@02NX:0?ooo`3oool02NX:1@3oool200WZ2PP0oooo00<02NX:0?ooo`3o
ool00`3oool207moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`03
0000003oool0oooo01d0oooo00D02NX:0?ooo`3oool0oooo00WZ2P030?ooo`H02NX:0P3oool01009
jPX0oooo0?ooo`09jPX40?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo0?ooo`05
0?ooo`802NX:1@3oool200WZ2PP0oooo00<02NX:0?ooo`3oool00`3oool200WZ2P80oooo00P02NX:
0?ooo`3oool0oooo00WZ2P3oool02NX:0?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P040?ooo`05
00WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo00<02NX:0?ooo`09jPX0103oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`030?ooo`0300WZ2P3oool02NX:00<0
oooo0P09jPX20?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX30?ooo`802NX:103oool300WZ2P03
0?ooo`09jPX02NX:00802NX:0`3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool02NX:00<0
oooo0`09jPX90?ooo`0300WZ2P3oool0oooo00802NX:103oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool0oooo00<0oooo0P09jPXC0?ooo`0400WZ2P3oool0oooo00WZ2PD0oooo0P09jPX80?oo
o`0300WZ2P3oool0oooo00<0oooo0P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo0000
001oOgl01P1oOgl00`000000oooo0?ooo`0M0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00`3oool6
00WZ2P80oooo00@02NX:0?ooo`3oool02NX:103oool200WZ2P030?ooo`09jPX02NX:0080oooo00<0
2NX:0?ooo`3oool01@3oool200WZ2PD0oooo0P09jPX80?ooo`0300WZ2P3oool0oooo00<0oooo0P09
jPX00`3oool02NX:0?ooo`020?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX20?ooo`0300WZ
2P3oool02NX:00@0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool00`09jPX0
oooo00WZ2P040?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00<0oooo
00<02NX:0?ooo`09jPX00`3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX30?ooo`80
2NX:103oool300WZ2P80oooo00<02NX:0?ooo`09jPX00`3oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool02NX:00<0oooo0`09jPX90?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0103oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPXC0?ooo`0400WZ2P3oool0oooo
00WZ2PD0oooo0P09jPX80?ooo`0300WZ2P3oool0oooo00<0oooo0P1oOgl00`000000Ogmo07moO`02
07moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`0M0?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX00`3oool600WZ2P80oooo00@02NX:0?ooo`3oool02NX:103oool200WZ2P030?oo
o`09jPX02NX:0080oooo00<02NX:0?ooo`3oool01@3oool200WZ2PD0oooo0P09jPX80?ooo`0300WZ
2P3oool0oooo00<0oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`0500WZ2P3oool0oooo00WZ2P3o
ool00P09jPX20?ooo`0300WZ2P3oool02NX:00@0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?oo
o`802NX:0P3oool00`09jPX0oooo00WZ2P040?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo00<0oooo00<02NX:0?ooo`09jPX00`3oool00`09jPX0oooo00WZ2P020?ooo`04
00WZ2P3oool0oooo0?ooo`802NX:103oool200WZ2P<0oooo0`09jPX20?ooo`0300WZ2P3oool02NX:
00@0oooo00<02NX:0?ooo`3oool00P3oool01009jPX0oooo0?ooo`09jPX20?ooo`<02NX:2@3oool0
1@09jPX0oooo0?ooo`3oool02NX:00D0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?oo
o`030?ooo`802NX:4`3oool01009jPX0oooo0?ooo`09jPX50?ooo`802NX:203oool00`09jPX0oooo
0?ooo`030?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo
00<000000?ooo`3oool07@3oool01@09jPX0oooo0?ooo`3oool02NX:00<0oooo1P09jPX20?ooo`04
00WZ2P3oool0oooo00WZ2P@0oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`0300WZ2P3oool0oooo
00D0oooo0P09jPX50?ooo`802NX:203oool00`09jPX0oooo0?ooo`020?ooo`0500WZ2P3oool02NX:
0?ooo`09jPX00`3oool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ
2P040?ooo`0400WZ2P3oool02NX:00WZ2P@0oooo0P09jPX20?ooo`0300WZ2P3oool02NX:00@0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool00`3oool00`09jPX0oooo00WZ
2P030?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`3oool0oooo0P09jPX40?ooo`802NX:
0`3oool300WZ2P80oooo00<02NX:0?ooo`09jPX0103oool00`09jPX0oooo0?ooo`020?ooo`0400WZ
2P3oool0oooo00WZ2P80oooo0`09jPX90?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool200WZ2Q<0oooo00@02NX:0?ooo`3o
ool02NX:1@3oool200WZ2PP0oooo00<02NX:0?ooo`3oool00`3oool207moO`030000001oOgl0Ogmo
0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01d0oooo00D02NX:0?oo
o`3oool0oooo00WZ2P030?ooo`H02NX:0P3oool01009jPX0oooo0?ooo`09jPX40?ooo`802NX:00<0
oooo00WZ2P09jPX00P3oool00`09jPX0oooo0?ooo`050?ooo`802NX:1@3oool200WZ2PP0oooo00<0
2NX:0?ooo`3oool00P3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo00D02NX:0?ooo`3oool0
2NX:0?ooo`0200WZ2P80oooo00<02NX:0?ooo`09jPX00`3oool01@09jPX0oooo00WZ2P3oool02NX:
00@0oooo0P09jPX20?ooo`0300WZ2P3oool02NX:00@0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0103oool200WZ2P<0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0
oooo0?ooo`020?ooo`802NX:0`3oool200WZ2P@0oooo0`09jPX0103oool02NX:00WZ2P09jPX40?oo
o`0300WZ2P3oool0oooo0080oooo00@02NX:0?ooo`3oool02NX:0P3oool300WZ2PX0oooo00@02NX:
0?ooo`3oool02NX:1@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0080oooo0P09
jPXC0?ooo`0400WZ2P3oool0oooo00WZ2PD0oooo0P09jPX80?ooo`0300WZ2P3oool0oooo00<0oooo
0P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo
0?ooo`0M0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00`3oool600WZ2P80oooo00@02NX:0?ooo`3o
ool02NX:103oool00`09jPX0oooo00WZ2P0200WZ2P80oooo00<02NX:0?ooo`3oool01@3oool200WZ
2PD0oooo0P09jPX80?ooo`0300WZ2P3oool0oooo0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P03
0?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX20?ooo`0300WZ2P3oool02NX:00<0oooo00D0
2NX:0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P040?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00@0oooo0P09jPX30?ooo`0300WZ2P3o
ool02NX:0080oooo00<02NX:0?ooo`3oool00P3oool200WZ2P<0oooo0P09jPX40?ooo`<02NX:00<0
oooo00WZ2P09jPX00P09jPX30?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`09jPX00P3o
ool300WZ2PX0oooo00<02NX:0?ooo`3oool00P09jPX40?ooo`0300WZ2P3oool0oooo00<0oooo00<0
2NX:0?ooo`3oool00P3oool00`09jPX0oooo00WZ2P0B0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0
103oool00`09jPX0oooo00WZ2P070?ooo`0300WZ2P3oool0oooo00<0oooo0P1oOgl00`000000Ogmo
07moO`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`0M0?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX00`3oool600WZ2P80oooo00@02NX:0?ooo`3oool02NX:103oool00`09
jPX0oooo00WZ2P0200WZ2P80oooo00<02NX:0?ooo`3oool01@3oool200WZ2P@0oooo00<02NX:0?oo
o`09jPX01`3oool00`09jPX0oooo0?ooo`030?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool0
1@09jPX0oooo0?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P030?ooo`0500WZ2P3o
ool02NX:0?ooo`09jPX0103oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX0103oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`040?ooo`0300WZ2P3oool02NX:0080oooo
00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:0`3oool200WZ2P@0oooo
0`09jPX00`3oool02NX:00WZ2P0200WZ2P<0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
00WZ2P020?ooo`<02NX:2P3oool00`09jPX0oooo0?ooo`0200WZ2P@0oooo00<02NX:0?ooo`3oool0
0`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool02NX:0180oooo00D02NX:0?ooo`3oool0
oooo00WZ2P040?ooo`0300WZ2P3oool02NX:00L0oooo00<02NX:0?ooo`3oool00`3oool207moO`03
0000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01d0
oooo00D02NX:0?ooo`3oool0oooo00WZ2P030?ooo`H02NX:0P3oool01009jPX0oooo0?ooo`09jPX4
0?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX70?ooo`0300WZ2P3oool02NX:00@0oooo00<0
2NX:0?ooo`09jPX01`3oool00`09jPX0oooo0?ooo`030?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0
0`3oool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:0P3oool200WZ2P@0oooo00D02NX:0?ooo`09
jPX0oooo00WZ2P030?ooo`802NX:0P3oool01009jPX0oooo0?ooo`09jPX40?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo00@0oooo00<02NX:0?ooo`09jPX00`3oool200WZ
2P80oooo00<02NX:0?ooo`3oool00P3oool200WZ2P<0oooo0P09jPX40?ooo`<02NX:00<0oooo00WZ
2P09jPX00P09jPX30?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`09jPX00P3oool300WZ
2PX0oooo00<02NX:0?ooo`3oool00P09jPX40?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?oo
o`3oool00P3oool00`09jPX0oooo00WZ2P0B0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0103oool0
0`09jPX0oooo00WZ2P070?ooo`0300WZ2P3oool0oooo00<0oooo0P1oOgl00`000000Ogmo07moO`02
07moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`0M0?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX00`3oool600WZ2P80oooo00@02NX:0?ooo`3oool02NX:103oool00`09jPX0oooo
00WZ2P020?ooo`802NX:1`3oool00`09jPX0oooo00WZ2P040?ooo`0300WZ2P3oool02NX:00L0oooo
00<02NX:0?ooo`3oool00`3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`09
jPX00`09jPX20?ooo`0300WZ2P3oool02NX:00@0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?oo
o`802NX:0P3oool01009jPX0oooo0?ooo`09jPX40?ooo`030000003oool0oooo00D0oooo00070?oo
o`030000003oool0oooo00@0oooo00<02NX:0?ooo`09jPX00`3oool01@09jPX0oooo00WZ2P3oool0
2NX:00@0oooo0P09jPX30?ooo`802NX:103oool200WZ2P030?ooo`09jPX02NX:00<02NX:0`3oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX02P3oool0
0`09jPX0oooo0?ooo`0200WZ2P@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`02
0?ooo`0300WZ2P3oool02NX:0180oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?ooo`0300WZ2P3o
ool02NX:00L0oooo00<02NX:0?ooo`3oool00`3oool207moO`030000001oOgl0Ogmo0080Ogmo0P09
jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01d0oooo00D02NX:0?ooo`3oool0oooo
00WZ2P030?ooo`H02NX:0P3oool01009jPX0oooo0?ooo`09jPX40?ooo`0300WZ2P3oool02NX:0080
oooo0P09jPX70?ooo`0300WZ2P3oool02NX:00@0oooo00<02NX:0?ooo`09jPX01`3oool00`09jPX0
oooo0?ooo`030?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0400WZ
2P80oooo00<02NX:0?ooo`09jPX0103oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX2
0?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo00<000000?ooo`3oool01@3oool000L0oooo00<00000
0?ooo`3oool0103oool00`09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:
0?ooo`3oool0oooo0P09jPX30?ooo`802NX:1@3oool400WZ2P030?ooo`09jPX02NX:00<0oooo00<0
2NX:0?ooo`3oool00`3oool00`09jPX0oooo00WZ2P030?ooo`<02NX:2@3oool200WZ2P030?ooo`09
jPX02NX:00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3o
ool02NX:0180oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?ooo`0300WZ2P3oool02NX:00L0oooo
00<02NX:0?ooo`3oool00`3oool207moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl00000
07moO`0607moO`030000003oool0oooo01d0oooo00D02NX:0?ooo`3oool0oooo00WZ2P030?ooo`H0
2NX:0P3oool01009jPX0oooo0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX7
0?ooo`0300WZ2P3oool02NX:00@0oooo00<02NX:0?ooo`09jPX01`3oool00`09jPX0oooo0?ooo`03
0?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00<02NX:0?ooo`3oool01009jPX20?ooo`0300WZ2P3o
ool02NX:00@0oooo00@02NX:0?ooo`09jPX02NX:103oool200WZ2P80oooo00@02NX:0?ooo`3oool0
2NX:103oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`040?ooo`0300WZ
2P3oool02NX:00<0oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`3oool200WZ2P@0
oooo0P09jPX40?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`0300WZ2P3oool0oooo00@0
oooo0P09jPX30?ooo`<02NX:2@3oool200WZ2P030?ooo`09jPX02NX:00@0oooo00<02NX:0?ooo`3o
ool0103oool01`09jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX04P3oool01@09jPX0oooo0?ooo`3o
ool02NX:00@0oooo00<02NX:0?ooo`09jPX01`3oool00`09jPX0oooo0?ooo`030?ooo`80Ogmo00<0
000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<000000?ooo`3oool07@3o
ool01@09jPX0oooo0?ooo`3oool02NX:00<0oooo1P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P@0
oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2PL0oooo00<02NX:0?ooo`09jPX0103oool00`09
jPX0oooo00WZ2P070?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`09jPX02NX:0`3oool0
0`09jPX0oooo0?ooo`0400WZ2P80oooo00<02NX:0?ooo`09jPX0103oool200WZ2P030?ooo`09jPX0
oooo00<0oooo0P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo00<000000?ooo`3oool01@3o
ool000L0oooo00<000000?ooo`3oool01@3oool200WZ2P<0oooo00<02NX:0?ooo`09jPX00P3oool0
1`09jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX00`3oool200WZ2P@0oooo0`09jPX00`3oool02NX:
00WZ2P0200WZ2P<0oooo00<02NX:0?ooo`3oool00`3oool200WZ2P<0oooo0`09jPX90?ooo`802NX:
0P3oool200WZ2P<0oooo00<02NX:0?ooo`3oool0103oool01`09jPX0oooo0?ooo`3oool02NX:0?oo
o`09jPX04P3oool01@09jPX0oooo0?ooo`3oool02NX:00@0oooo00<02NX:0?ooo`09jPX01`3oool0
0`09jPX0oooo0?ooo`030?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000
Ogmo00H0Ogmo00<000000?ooo`3oool07@3oool01@09jPX0oooo0?ooo`3oool02NX:00<0oooo1P09
jPX20?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2PL0
oooo00<02NX:0?ooo`09jPX0103oool00`09jPX0oooo00WZ2P070?ooo`0300WZ2P3oool0oooo0080
oooo00<02NX:0?ooo`3oool00P09jPX30?ooo`0300WZ2P3oool0oooo00@02NX:0P3oool00`09jPX0
oooo00WZ2P030?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P80oooo00@02NX:0?oo
o`3oool02NX:103oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`050?oo
o`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?oo
o`802NX:0`3oool200WZ2P@0oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P<0oooo00<02NX:0?oo
o`3oool00`3oool200WZ2P<0oooo0`09jPX90?ooo`802NX:0P3oool200WZ2P<0oooo00<02NX:0?oo
o`3oool0103oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo00<02NX:0?ooo`3oool03`3oool0
1@09jPX0oooo0?ooo`3oool02NX:00@0oooo00<02NX:0?ooo`09jPX0203oool00`09jPX0oooo0?oo
o`020?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<0
00000?ooo`3oool07@3oool01@09jPX0oooo0?ooo`3oool02NX:00<0oooo00<02NX:0?ooo`09jPX0
0`09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ
2PL0oooo00<02NX:0?ooo`09jPX0103oool00`09jPX0oooo00WZ2P070?ooo`0300WZ2P3oool0oooo
0080oooo00<02NX:0?ooo`3oool00P09jPX30?ooo`0300WZ2P3oool0oooo00@02NX:0P3oool00`09
jPX0oooo00WZ2P030?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P030?ooo`09jPX0
oooo0080oooo00<02NX:0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`050?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool00`09
jPX0oooo0?ooo`020?ooo`802NX:0`3oool200WZ2P@0oooo0P09jPX0103oool02NX:00WZ2P3oool2
00WZ2P<0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo00WZ2P020?ooo`<02NX:2@3oool2
00WZ2P80oooo0P09jPX30?ooo`0300WZ2P3oool0oooo00@0oooo00D02NX:0?ooo`3oool0oooo00WZ
2P020?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`020?ooo`0300WZ2P3oool02NX:00L0oooo00<02NX:0?ooo`3oool00P3oool207moO`030000001o
Ogl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01d0oooo00D0
2NX:0?ooo`3oool0oooo00WZ2P030?ooo`0300WZ2P3oool02NX:00<02NX:0P3oool01009jPX0oooo
0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX70?ooo`0300WZ2P3oool02NX:
00@0oooo00<02NX:0?ooo`09jPX01`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo
00802NX:0`3oool00`09jPX0oooo0?ooo`0400WZ2P80oooo0P09jPX40?ooo`0500WZ2P3oool02NX:
0?ooo`09jPX00`3oool200WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?ooo`030000003o
ool0oooo00D0oooo00070?ooo`030000003oool0oooo00D0oooo00<02NX:0?ooo`09jPX00`3oool2
00WZ2P80oooo00<02NX:0?ooo`3oool00P3oool200WZ2P<0oooo0P09jPX40?ooo`802NX:00@0oooo
00WZ2P09jPX0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`09jPX00P3o
ool400WZ2PP0oooo00@02NX:0?ooo`09jPX0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo00@0oooo
00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3o
ool00`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool02NX:00L0oooo00<02NX:0?ooo`3o
ool00P3oool207moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`03
0000003oool0oooo01d0oooo00D02NX:0?ooo`3oool0oooo00WZ2P030?ooo`0300WZ2P3oool02NX:
00<02NX:0P3oool01009jPX0oooo0?ooo`09jPX40?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09
jPX70?ooo`0300WZ2P3oool02NX:00@0oooo00<02NX:0?ooo`09jPX01`3oool00`09jPX0oooo0?oo
o`020?ooo`0300WZ2P3oool0oooo00802NX:0`3oool00`09jPX0oooo0?ooo`0400WZ2P80oooo0P09
jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo00D02NX:0?ooo`3oool0
oooo00WZ2P040?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00D0oooo
00<02NX:0?ooo`09jPX00`3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX30?ooo`80
2NX:103oool200WZ2P070?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0
oooo00@0oooo0P09jPX20?ooo`@02NX:203oool01009jPX0oooo00WZ2P3oool200WZ2P@0oooo00<0
2NX:0?ooo`3oool0103oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00h0oooo
00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool02NX:00L0oooo
00<02NX:0?ooo`3oool00P3oool207moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl00000
07moO`0607moO`030000003oool0oooo01d0oooo00D02NX:0?ooo`3oool0oooo00WZ2P030?ooo`03
00WZ2P3oool02NX:00<02NX:0P3oool01009jPX0oooo0?ooo`09jPX40?ooo`0400WZ2P3oool02NX:
0?ooo`<02NX:1`3oool00`09jPX0oooo00WZ2P040?ooo`0300WZ2P3oool02NX:00L0oooo00<02NX:
0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0200WZ2P<0oooo00<02NX:0?ooo`3oool00`09jPX2
0?ooo`0300WZ2P3oool02NX:00@0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0P3o
ool01@09jPX0oooo0?ooo`3oool02NX:00@0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
00000?ooo`3oool01@3oool00`09jPX0oooo00WZ2P030?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0
103oool200WZ2P<0oooo0P09jPX40?ooo`802NX:00L0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:
0080oooo00<02NX:0?ooo`3oool0103oool200WZ2P80oooo1009jPX90?ooo`802NX:00@0oooo00WZ
2P3oool02NX:0`3oool00`09jPX0oooo0?ooo`040?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<0
2NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0080oooo00<0
2NX:0?ooo`09jPX01`3oool00`09jPX0oooo0?ooo`020?ooo`80Ogmo00<0000007moO`1oOgl00P1o
Ogl200WZ2P0307moO`000000Ogmo00H0Ogmo00<000000?ooo`3oool07@3oool01@09jPX0oooo0?oo
o`3oool02NX:00<0oooo00<02NX:0?ooo`09jPX00`09jPX20?ooo`0400WZ2P3oool0oooo00WZ2PD0
oooo0P09jPX0103oool02NX:00WZ2P09jPX70?ooo`0300WZ2P3oool02NX:00@0oooo00<02NX:0?oo
o`09jPX01P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00802NX:0P3oool01@09
jPX0oooo0?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P040?ooo`0400WZ2P3oool0
2NX:00WZ2P@0oooo0P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2PD0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool01@3oool00`09jPX0oooo00WZ2P030?ooo`0300WZ2P3o
ool02NX:0080oooo00@02NX:0?ooo`3oool0oooo0P09jPX40?ooo`0300WZ2P3oool0oooo0080oooo
0`09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool0103oool200WZ
2P80oooo0P09jPX00`3oool02NX:0?ooo`080?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool0
0`09jPX0oooo0?ooo`040?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool03P3o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`09jPX01`3o
ool00`09jPX0oooo0?ooo`020?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`00
0000Ogmo00H0Ogmo00<000000?ooo`3oool07@3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo
0P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?ooo`3o
ool00P3oool200WZ2P040?ooo`09jPX02NX:00WZ2PL0oooo00<02NX:0?ooo`09jPX00`3oool01009
jPX0oooo0?ooo`09jPX60?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3oool02NX:0`3o
ool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P040?ooo`802NX:
00<0oooo00WZ2P3oool00`3oool200WZ2P80oooo00@02NX:0?ooo`3oool02NX:1@3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`060?ooo`802NX:0`3oool00`09jPX0oooo
00WZ2P020?ooo`0400WZ2P3oool0oooo0?ooo`802NX:103oool200WZ2P@0oooo0P09jPX00`3oool0
2NX:00WZ2P0300WZ2P80oooo00<02NX:0?ooo`3oool0103oool200WZ2P80oooo0P09jPX00`3oool0
2NX:0?ooo`080?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool00`09jPX0oooo0?ooo`040?oo
o`0400WZ2P3oool0oooo00WZ2P<0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`09jPX01`3oool00`09jPX0oooo0?ooo`02
0?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<00000
0?ooo`3oool0703oool00`09jPX0oooo0?ooo`030?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09
jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`3oool00P3oool200WZ2P030?oo
o`09jPX02NX:00L0oooo00@02NX:0?ooo`3oool02NX:0`3oool01009jPX0oooo0?ooo`09jPX60?oo
o`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3oool02NX:0`3oool01@09jPX0oooo0?ooo`09
jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P030?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0
103oool200WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool02NX:0080oooo00<0
2NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:0`3oool200WZ2P@0oooo0P09
jPX0103oool02NX:00WZ2P3oool200WZ2P80oooo00<02NX:0?ooo`3oool0103oool200WZ2P80oooo
0P09jPX00`3oool02NX:0?ooo`080?ooo`0600WZ2P3oool02NX:00WZ2P3oool02NX:0`3oool00`09
jPX0oooo0?ooo`040?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00<02NX:0?ooo`3oool03@3oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`09jPX01`3oool0
0`09jPX0oooo0?ooo`020?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000
Ogmo00H0Ogmo00<000000?ooo`3oool0703oool00`09jPX0oooo0?ooo`030?ooo`0500WZ2P3oool0
2NX:00WZ2P3oool00P09jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`3oool0
0P3oool00`09jPX0oooo0?ooo`0200WZ2PL0oooo00@02NX:0?ooo`3oool02NX:0`3oool01009jPX0
oooo0?ooo`09jPX60?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3oool02NX:0`3oool0
1@09jPX0oooo0?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P030?ooo`0500WZ2P3o
ool02NX:0?ooo`09jPX0103oool200WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`060?ooo`0300WZ2P3o
ool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:0`3o
ool200WZ2P@0oooo0P09jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool00`09jPX0
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo00WZ2P09jPX0203oool01P09jPX0
oooo00WZ2P09jPX0oooo00WZ2P<0oooo00<02NX:0?ooo`3oool0103oool01009jPX0oooo0?ooo`09
jPX30?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`020?ooo`0300WZ2P3oool02NX:00L0oooo00<02NX:0?ooo`3oool00P3oool207moO`030000001o
Ogl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo01`0oooo00<0
2NX:0?ooo`3oool00`3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:00D0oooo00WZ2P09jPX0
oooo00WZ2P030?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00P09jPX70?ooo`04
00WZ2P3oool0oooo00WZ2P<0oooo00@02NX:0?ooo`3oool02NX:1P3oool00`09jPX0oooo0?ooo`02
0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00`3oool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:
0P3oool00`09jPX0oooo00WZ2P030?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80
oooo00D02NX:0?ooo`3oool0oooo00WZ2P050?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo00H0oooo00<02NX:0?ooo`09jPX00`3oool200WZ2P80oooo00<02NX:0?ooo`3o
ool00P3oool200WZ2P<0oooo0P09jPX40?ooo`D02NX:00@0oooo00WZ2P3oool02NX:0P3oool00`09
jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo00WZ2P09jPX0203oool01P09
jPX0oooo00WZ2P09jPX0oooo00WZ2P<0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo00WZ
2P030?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool0103oool01@09jPX0oooo0?oo
o`3oool02NX:0080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`020?ooo`80Ogmo
00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<000000?ooo`3oool0
703oool00`09jPX0oooo0?ooo`030?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX01@3oool0
2NX:00WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`3oool00P3oool01@09jPX0oooo0?ooo`3oool0
2NX:00@0oooo0`0000001009jPX0000000000009jPX30000000400WZ2P000000000000WZ2PH00000
00<02NX:0000003oool00P3oool01@09jPX0oooo0?ooo`3oool02NX:00<0oooo00D02NX:0?ooo`3o
ool02NX:0?ooo`0200WZ2P80oooo0P09jPX40?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool2
00WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P050?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo00H0oooo00<02NX:0?ooo`09jPX00`3oool01@09jPX0oooo00WZ2P3o
ool02NX:00@0oooo0P09jPX30?ooo`802NX:103oool300WZ2P060?ooo`09jPX0oooo00WZ2P3oool0
2NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00802NX:0P3oool00`09jPX0
oooo0?ooo`060?ooo`0700WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0
oooo00D0oooo00<02NX:0?ooo`09jPX00`3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0
oooo00@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`3oool00P3oool207moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007mo
O`0607moO`030000003oool0oooo01`0oooo00<02NX:0?ooo`3oool00`3oool01@09jPX0oooo00WZ
2P09jPX0oooo00802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P030000000300WZ2P00000000000080
000000D02NX:000000000000000000WZ2P04000000<0Ogmo00@02NX:07moO`0000002NX:0P1oOgl0
1P0000002NX:07moO`1oOgl02NX:000000@0Ogmo0P0000040?ooo`0500WZ2P3oool0oooo0?ooo`09
jPX00`3oool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool02NX:103oool0
1@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX20?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0
1@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`060?ooo`0300WZ2P3o
ool02NX:00<0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:0`3oool200WZ2P@0oooo
0`09jPX00`3oool02NX:0?ooo`0300WZ2P80oooo00<02NX:0?ooo`3oool0103oool200WZ2P030?oo
o`09jPX02NX:0080oooo00<02NX:0?ooo`3oool01P3oool01`09jPX0oooo00WZ2P3oool02NX:0?oo
o`09jPX00P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool02NX:00<0oooo00<02NX:0?oo
o`3oool03@3oool00`09jPX0oooo0?ooo`040?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00P3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0080oooo0P1oOgl00`000000Ogmo07moO`02
07moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`0L0?ooo`0300WZ2P3oool0
000000<0000000D02NX:00000009jPX02NX:0000000200WZ2P0500000009jPX02NX:00000009jPX0
0`1oOgl00`09jPX0Ogmo07moO`0207moO`0500WZ2P1oOgl0Ogmo00000009jPX01P1oOgl01@000000
2NX:07moO`0000002NX:0080Ogmo0P00000207moO`0300WZ2P000000Ogmo00@0Ogmo00<02NX:0?oo
o`3oool00P3oool01@09jPX0oooo0?ooo`3oool02NX:00<0oooo00D02NX:0?ooo`3oool02NX:0?oo
o`0200WZ2P040?ooo`09jPX0oooo00WZ2P@0oooo00@02NX:0?ooo`09jPX02NX:103oool200WZ2P80
oooo00D02NX:0?ooo`3oool0oooo00WZ2P050?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo00H0oooo00<02NX:0?ooo`09jPX00`3oool00`09jPX0oooo00WZ2P020?ooo`04
00WZ2P3oool0oooo0?ooo`802NX:0`3oool200WZ2P@0oooo0`09jPX00`3oool02NX:0?ooo`0300WZ
2P80oooo00<02NX:0?ooo`3oool0103oool200WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?oo
o`3oool01P3oool00`09jPX0oooo0?ooo`0200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX01`3oool0
0`09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool0103oool0
1@09jPX0oooo0?ooo`3oool02NX:0080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?oo
o`020?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<0
00000?ooo`3oool04`3oool90000000300WZ2P000000Ogmo00<0Ogmo00D02NX:07moO`09jPX02NX:
07moO`0200WZ2P0507moO`09jPX02NX:07moO`09jPX00`1oOgl01P09jPX0Ogmo07moO`1oOgl00000
00WZ2P80Ogmo0P00000607moO`8000000P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:0080Ogmo00<0
2NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo0?ooo`030?ooo`0300WZ2P3oool0oooo00802NX:0`3o
ool00`09jPX0oooo00WZ2P020?ooo`802NX:00@0oooo00WZ2P3oool02NX:103oool01009jPX0oooo
00WZ2P09jPX40?ooo`802NX:0P3oool01@09jPX0oooo0?ooo`3oool02NX:00D0oooo00<000000?oo
o`3oool01@3oool000L0oooo00<000000?ooo`3oool01`3oool200WZ2P<0oooo00<02NX:0?ooo`09
jPX00P3oool01009jPX0oooo0?ooo`3oool200WZ2P@0oooo0P09jPX30?ooo`<02NX:00<0oooo00WZ
2P3oool00`09jPX20?ooo`0300WZ2P3oool0oooo00D0oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3o
ool200WZ2PL0oooo00<02NX:0?ooo`3oool00P09jPX01@3oool02NX:0?ooo`3oool02NX:00L0oooo
00<02NX:0?ooo`09jPX0103oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00@0oooo
00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool00P3oool207moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`03
0000003oool0oooo00L0oooo3000000907moO`0300WZ2P1oOgl0Ogmo0080Ogmo100000001@09jPX0
Ogmo00000009jPX0000000802NX:00H0000000WZ2P1oOgl0Ogmo00000009jPX307moO`0300000009
jPX0Ogmo0080Ogmo00<02NX:07moO`1oOgl01@1oOgl01009jPX0Ogmo07moO`09jPX307moO`0400WZ
2P1oOgl0Ogmo00WZ2PD0Ogmo00<02NX:07moO`3oool00`3oool00`09jPX0oooo0?ooo`0200WZ2P80
oooo00@02NX:0?ooo`3oool02NX:0P3oool200WZ2P040?ooo`09jPX0oooo00WZ2P<0oooo00D02NX:
0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:00<0oooo00WZ2P3oool00`3oool00`09jPX0oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00L0oooo00<02NX:
0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo0?ooo`802NX:103o
ool200WZ2P@0oooo1009jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX01`3oool01@09jPX0
oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0200WZ
2P050?ooo`09jPX0oooo0?ooo`09jPX01`3oool00`09jPX0oooo00WZ2P040?ooo`0300WZ2P3oool0
oooo00`0oooo00<02NX:0?ooo`3oool0103oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`020?ooo`80Ogmo00<0000007moO`1oOgl00P1o
Ogl200WZ2P0307moO`000000Ogmo00H0Ogmo2P00000E07moO`0300WZ2P000000Ogmo0080Ogmo00<0
000000WZ2P0000000P0000001@1oOgl000000000000000002NX:00<000000P1oOgl00`0000002NX:
07moO`0307moO`0500WZ2P1oOgl0Ogmo07moO`09jPX01P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:
00<0Ogmo00<02NX:07moO`1oOgl00P00000307moO`0400000009jPX0Ogmo000000<0oooo00@02NX:
0?ooo`3oool02NX:0`3oool01@09jPX0oooo0?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P3oool0
2NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo00@02NX:0?ooo`3oool02NX:103oool0
0`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
00L0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo
0080oooo0P09jPX30?ooo`802NX:103oool300WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ
2P3oool01P3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool01@3oool0
0`09jPX0oooo0?ooo`0200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX0203oool200WZ2P@0oooo00<0
2NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`040?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0
0P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0080oooo0P1oOgl00`000000Ogmo
07moO`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000Ogmo07moO`0<07moO`800000
3P1oOgl2000000@0Ogmo00H02NX:07moO`09jPX02NX:07moO`09jPX207moO`0400WZ2P1oOgl0Ogmo
00WZ2P<0Ogmo00<02NX:07moO`1oOgl00P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00D0Ogmo00H0
000000WZ2P1oOgl0Ogmo00000009jPX207moO`0600000009jPX0Ogmo07moO`09jPX000000`1oOgl2
0000000307moO`3oool0oooo0080oooo00@02NX:0?ooo`3oool02NX:0`3oool01@09jPX0oooo0?oo
o`09jPX0oooo00<02NX:00@0oooo00WZ2P3oool02NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:
00<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`070?ooo`0300WZ2P3oool02NX:00<0
oooo0P09jPX20?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX30?ooo`802NX:103oool300WZ2P03
0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool01P3oool01@09jPX0oooo00WZ2P3oool02NX:
0080oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00<02NX:0?oo
o`09jPX0203oool200WZ2P@0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`050?oo
o`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool0103oool00`09jPX0000000000002
00000080Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<00000
07moO`1oOgl0301oOgl00`09jPX0000007moO`0=07moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00H02NX:
07moO`09jPX02NX:07moO`09jPX207moO`0400WZ2P1oOgl0Ogmo00WZ2P<0Ogmo00@02NX:07moO`1o
Ogl0Ogmo0P00000207moO`0300000009jPX0Ogmo00@0Ogmo00H0000000WZ2P1oOgl0Ogmo00000009
jPX207moO`8000000P1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0oooo00<0oooo00@0
2NX:0?ooo`3oool02NX:0`3oool01@09jPX0oooo0?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P3o
ool02NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX20?ooo`0300WZ2P3oool0
oooo0080oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`070?ooo`0300WZ2P3oool02NX:00<0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P04
0?ooo`802NX:0`3oool200WZ2P@0oooo0`09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0
oooo00H0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00D0oooo00D0
2NX:0?ooo`3oool0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo00WZ2PL0oooo0P09jPX40?ooo`03
00WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool01@3oool01009jPX0oooo0?ooo`09jPX20?oo
o`0300000009jPX0000000@0000000<02NX:07moO`1oOgl0101oOgl00`000000Ogmo07moO`0207mo
O`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000Ogmo07moO`0<07moO`0300WZ2P1oOgl0Ogmo
00d0Ogmo00<02NX:07moO`1oOgl00`1oOgl01P09jPX0Ogmo00WZ2P09jPX0Ogmo00WZ2P80Ogmo00@0
2NX:07moO`1oOgl02NX:0`1oOgl01P09jPX0Ogmo07moO`1oOgl0000000WZ2P80Ogmo0P00000607mo
O`0500WZ2P1oOgl0Ogmo07moO`09jPX00`1oOgl01009jPX0Ogmo07moO`09jPX507moO`0300WZ2P1o
Ogl0oooo0080oooo00D02NX:0?ooo`3oool0oooo00WZ2P030?ooo`0500WZ2P3oool0oooo00WZ2P3o
ool00`09jPX00`3oool02NX:00WZ2P040?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ
2P80oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo00L0oooo00<02NX:0?ooo`09jPX00`3oool01@09jPX0
oooo00WZ2P3oool02NX:00@0oooo0P09jPX30?ooo`802NX:103oool200WZ2P040?ooo`09jPX02NX:
0?ooo`<02NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`<02NX:00@0oooo00WZ2P3oool0oooo0P09
jPX70?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00@02NX:0?ooo`3oool02NX:1`3oool200WZ2P@0
oooo00<02NX:0?ooo`3oool0303oool01009jPX0oooo0?ooo`3oool40000000400WZ2P0000000000
00WZ2P80000000<0Ogmo00WZ2P1oOgl0101oOgl00`09jPX0Ogmo07moO`0407moO`050000001oOgl0
Ogmo07moO`0000000P09jPX00`1oOgl0000007moO`0607moO`030000001oOgl0Ogmo00`0Ogmo00<0
2NX:07moO`1oOgl03@1oOgl00`09jPX0Ogmo07moO`0207moO`0700000009jPX0000000000009jPX0
000000WZ2P0207moO`0400WZ2P000000000000WZ2P80Ogmo00<0000000WZ2P1oOgl00`1oOgl01@09
jPX0Ogmo07moO`1oOgl02NX:00H0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0207moO`0500WZ2P1o
Ogl0Ogmo07moO`09jPX01@1oOgl00`09jPX00000000000020?ooo`0500WZ2P3oool0oooo0?ooo`09
jPX00`3oool01@09jPX0oooo0?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P3oool00`3oool01009
jPX0oooo00WZ2P09jPX40?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0203oool200WZ
2P<0oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`3oool200WZ2P<0oooo0P09jPX4
0?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:0?ooo`09jPX60?ooo`<02NX:00<0
oooo00WZ2P3oool00P3oool00`09jPX0oooo0?ooo`050?ooo`0400WZ2P3oool0oooo00WZ2P80oooo
00@02NX:0?ooo`3oool02NX:1`3oool200WZ2P@0oooo00<02NX:0?ooo`3oool01@3oool700000004
00WZ2P0000000000000000@0Ogmo00@02NX:0000001oOgl02NX:0P1oOgl2000000@0Ogmo00<00000
00WZ2P1oOgl01@1oOgl010000000Ogmo07moO`1oOgl30000000307moO`000000Ogmo00H0Ogmo00<0
000007moO`1oOgl0301oOgl200WZ2Pd0Ogmo00<0000000WZ2P1oOgl00`1oOgl00`0000002NX:0000
000400000080Ogmo00@02NX:00000000000000000P1oOgl00`0000002NX:07moO`0307moO`0400WZ
2P1oOgl0Ogmo00WZ2PL0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0207moO`0500WZ2P1oOgl0Ogmo
00000009jPX00P0000001P09jPX0Ogmo00000009jPX0000000WZ2P80oooo00D02NX:0?ooo`3oool0
oooo00WZ2P030?ooo`0700WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0
oooo00<0oooo00@02NX:0?ooo`09jPX02NX:103oool200WZ2P80oooo00<02NX:0?ooo`3oool00P3o
ool00`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo00P0oooo0P09jPX30?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`3oool0oooo0P09
jPX30?ooo`802NX:103oool200WZ2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P09jPX0oooo
00WZ2P060?ooo`<02NX:00<0oooo00WZ2P3oool00P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ
2P3oool0oooo00802NX:00D0oooo00WZ2P3oool0oooo00WZ2P070?ooo`802NX:00<0oooo00000000
00000P0000000`09jPX0000000000004000000H0Ogmo00<0000000WZ2P1oOgl01P1oOgl01009jPX0
000000000009jPX207moO`0300000009jPX0Ogmo00<0Ogmo0P00000607moO`030000001oOgl0Ogmo
0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000001oOgl0Ogmo00`0Ogmo0P09jPX00`00
0000Ogmo07moO`0:07moO`8000001@1oOgl01P09jPX0Ogmo00WZ2P09jPX0Ogmo00WZ2P80Ogmo00@0
2NX:07moO`1oOgl02NX:0`1oOgl01009jPX0Ogmo07moO`1oOgl200WZ2P80Ogmo00<02NX:07moO`1o
Ogl0101oOgl01`0000002NX:07moO`1oOgl0000000WZ2P0000000P09jPX207moO`0600000009jPX0
000000000009jPX0Ogmo0P0000001@3oool02NX:0?ooo`3oool02NX:00<0oooo00L02NX:0?ooo`3o
ool0oooo00WZ2P3oool02NX:0080oooo00H02NX:0?ooo`09jPX02NX:0?ooo`09jPX40?ooo`802NX:
00<0oooo00WZ2P3oool00`3oool200WZ2P030?ooo`09jPX0oooo00@0oooo00<02NX:0?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`080?ooo`0300WZ2P3o
ool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`3oool200WZ2P@0oooo
0P09jPX30?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:00WZ2P3oool02NX:00H0
oooo0`09jPX00`3oool02NX:0?ooo`020?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3o
ool00P09jPX01@3oool02NX:0?ooo`3oool02NX:00P0000000<02NX:0000001oOgl00`1oOgl00`09
jPX0Ogmo07moO`0:07moO`8000001`1oOgl01009jPX0Ogmo00000000000307moO`0300WZ2P1oOgl0
Ogmo00<0Ogmo00<02NX:07moO`1oOgl0101oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo
0000001oOgl01P1oOgl00`000000Ogmo07moO`0<07moO`0300000009jPX0000000d0Ogmo00<02NX:
07moO`1oOgl00`1oOgl01P09jPX0Ogmo00WZ2P09jPX0Ogmo00WZ2P<0Ogmo00<02NX:07moO`09jPX0
0`1oOgl01P09jPX0Ogmo07moO`1oOgl0000000WZ2P80Ogmo00<02NX:0000001oOgl0101oOgl20000
0080Ogmo00D0000000WZ2P0000002NX:0000000307moO`0400WZ2P3oool0oooo00WZ2P80oooo00<0
2NX:0?ooo`09jPX00P3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo00@02NX:0?ooo`3oool0
2NX:0P3oool01P09jPX0oooo00WZ2P09jPX0oooo00WZ2P<0oooo00D02NX:0?ooo`09jPX0oooo00WZ
2P040?ooo`0400WZ2P3oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`080?ooo`0300WZ2P3oool02NX:0080oooo00<0
2NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:0`3oool200WZ2P@0oooo00<0
2NX:0?ooo`3oool00`09jPX01@3oool02NX:00WZ2P3oool02NX:00L0oooo0P09jPX20?ooo`0400WZ
2P3oool0oooo00WZ2PL0oooo00D02NX:000000000000000000WZ2P020000000300WZ2P0000002NX:
00L0Ogmo00<0000000WZ2P1oOgl00`1oOgl00`0000002NX:07moO`0<07moO`0300WZ2P1oOgl0Ogmo
00H0Ogmo00<02NX:07moO`09jPX00`1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo
00@0Ogmo00D0000007moO`1oOgl0Ogmo0000000200WZ2P0307moO`000000Ogmo00H0Ogmo00<00000
07moO`1oOgl0301oOgl200WZ2Ph0Ogmo00<02NX:07moO`1oOgl00`1oOgl01P09jPX0Ogmo00WZ2P09
jPX0Ogmo00WZ2P80Ogmo00@0000000WZ2P1oOgl02NX:0P1oOgl2000000<0Ogmo00@0000000WZ2P1o
Ogl0Ogmo0P00000607moO`0600WZ2P1oOgl0Ogmo0?ooo`09jPX0oooo0P09jPX30?ooo`0400WZ2P3o
ool0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo0?ooo`3oool02NX:0080
oooo00@02NX:0?ooo`3oool02NX:0P3oool01P09jPX0oooo00WZ2P09jPX0oooo00WZ2P<0oooo00D0
2NX:0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00<0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0203o
ool00`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:0`3o
ool200WZ2P@0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool0
1P3oool200WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX60000000500WZ2P1oOgl0Ogmo07moO`09
jPX00P1oOgl20000000300WZ2P1oOgl0Ogmo00D0Ogmo00<0000000WZ2P1oOgl00`1oOgl00`000000
2NX:07moO`0<07moO`0300WZ2P1oOgl0Ogmo00H0Ogmo00<02NX:07moO`09jPX00`1oOgl00`09jPX0
Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00D0000007moO`1oOgl0Ogmo0000000200WZ
2P0307moO`000000Ogmo00H0Ogmo00<0000007moO`1oOgl0301oOgl00`09jPX0Ogmo00WZ2P0=07mo
O`0300WZ2P1oOgl0Ogmo0080Ogmo00L0000000WZ2P000000000000WZ2P0000002NX:0080Ogmo00@0
000000WZ2P0000002NX:0P1oOgl00`0000002NX:07moO`0207moO`802NX:0P1oOgl01009jPX0Ogmo
07moO`1oOgl40?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo0P09jPX30?ooo`0400WZ2P3oool0
oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00@0
2NX:0?ooo`3oool02NX:0P3oool01P09jPX0oooo00WZ2P09jPX0oooo00WZ2P<0oooo00D02NX:0?oo
o`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0203oool00`09
jPX0oooo00WZ2P030?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P<0oooo0P09jPX4
0?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P070?ooo`802NX:0P000000
1@09jPX000000000000000002NX:0080Ogmo0P0000000`1oOgl0000000WZ2P0207moO`0500000009
jPX0Ogmo07moO`09jPX00P00000>07moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<02NX:07moO`1oOgl0
1@1oOgl0100000002NX:00000009jPX207moO`0300000009jPX0Ogmo00<0Ogmo00<0000000WZ2P1o
Ogl01@1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000
Ogmo07moO`0<07moO`0300WZ2P1oOgl02NX:00`0Ogmo00<0000000WZ2P1oOgl00`1oOgl00`000000
2NX:0000000400000080Ogmo00@0000000WZ2P00000000000`1oOgl01009jPX0Ogmo07moO`3oool2
00WZ2P80oooo00<02NX:0?ooo`3oool01@3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`802NX:
0`3oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3o
ool00P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00P09jPX40?oo
o`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
00P0oooo00<02NX:0?ooo`09jPX00`3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX3
0?ooo`802NX:103oool200WZ2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P09jPX02NX:0?oo
o`070000000400WZ2P1oOgl0000000WZ2P80Ogmo00L0000000WZ2P1oOgl0Ogmo00WZ2P000000Ogmo
008000000P1oOgl01`0000002NX:07moO`1oOgl02NX:07moO`09jPX03`1oOgl00`09jPX0Ogmo07mo
O`0907moO`0300000009jPX0Ogmo00H0Ogmo00@0000000WZ2P0000002NX:0P1oOgl00`0000002NX:
07moO`0307moO`8000001P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo0000001oOgl0
1P1oOgl00`000000Ogmo07moO`0;07moO`0500000009jPX0Ogmo00WZ2P0000002`1oOgl2000000D0
Ogmo00H02NX:07moO`09jPX02NX:07moO`09jPX207moO`040?ooo`09jPX0oooo00WZ2P<0oooo00@0
2NX:0?ooo`3oool0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00D0oooo00H02NX:0?ooo`3oool0
oooo00WZ2P3oool200WZ2P80oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:0P3o
ool00`09jPX0oooo0?ooo`0200WZ2P80oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo
00WZ2P0200WZ2P@0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?ooo`3oool01@3oool000L0oooo
00<000000?ooo`3oool02@3oool200WZ2P<0oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo
0?ooo`3oool200WZ2P<0oooo0P09jPX40?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool0
2NX:00WZ2P09jPX0000000D0Ogmo0`0000000`1oOgl000000000000207moO`0500000009jPX0Ogmo
07moO`09jPX00`1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:0080Ogmo00<02NX:07moO`09jPX03`1o
Ogl00`09jPX0Ogmo07moO`0907moO`800000201oOgl00`09jPX0Ogmo00WZ2P0307moO`0300WZ2P1o
Ogl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0101oOgl00`000000Ogmo07moO`0207moO`802NX:00<0
Ogmo0000001oOgl01P1oOgl00`000000Ogmo07moO`0207moO`0300000009jPX0Ogmo00H0Ogmo0P00
00000`1oOgl02NX:0000000<07moO`0300WZ2P1oOgl0Ogmo00<0oooo00H02NX:0?ooo`09jPX02NX:
0?ooo`09jPX30?ooo`0300WZ2P3oool02NX:00<0oooo00@02NX:0?ooo`3oool0oooo0P09jPX20?oo
o`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool01009jPX30?ooo`802NX:00H0oooo00WZ
2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0oooo0080oooo0P09jPX20?ooo`0400WZ2P3o
ool0oooo00WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`0400WZ2P3oool02NX:00WZ
2P@0oooo0P09jPX00`3oool02NX:0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool000L0oooo00<000000?ooo`3oool02@3oool00`09jPX0oooo00WZ2P020?ooo`03
00WZ2P3oool02NX:0080oooo00@02NX:0?ooo`3oool0oooo0P09jPX30?ooo`802NX:103oool200WZ
2P80oooo0`09jPX01@3oool02NX:00WZ2P1oOgl02NX:00H0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ
2P0307moO`0400WZ2P1oOgl0Ogmo00WZ2P@0Ogmo00<02NX:07moO`1oOgl00P09jPX207moO`802NX:
3P1oOgl00`0000002NX:07moO`0;07moO`0300WZ2P1oOgl0Ogmo00L0Ogmo0P09jPX407moO`0300WZ
2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl0101oOgl01@000000Ogmo07moO`1oOgl000000080
2NX:00<0Ogmo0000001oOgl01P1oOgl00`000000Ogmo07moO`0207moO`0300000009jPX0Ogmo00L0
Ogmo00<02NX:07moO`09jPX01@1oOgl80?ooo`0300WZ2P3oool0oooo00<0oooo00H02NX:0?ooo`09
jPX02NX:0?ooo`09jPX30?ooo`0300WZ2P3oool02NX:00<0oooo00@02NX:0?ooo`3oool0oooo0P09
jPX20?ooo`0300WZ2P3oool0oooo00@0oooo00@02NX:0?ooo`3oool0oooo1009jPX30?ooo`802NX:
00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0oooo0080oooo0P09jPX20?oo
o`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`09jPX40?ooo`802NX:00<0
oooo00WZ2P3oool00`3oool200WZ2P030?ooo`09jPX0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`090?ooo`0300WZ2P3oool0
2NX:0080oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`3oool200WZ2P<0oooo0P09
jPX40?ooo`802NX:0P3oool01009jPX0oooo00WZ2P3oool200WZ2P0307moO`09jPX0Ogmo00D0Ogmo
00D02NX:07moO`1oOgl0Ogmo00WZ2P0407moO`0400WZ2P1oOgl0Ogmo00WZ2P<0Ogmo00<02NX:07mo
O`0000000P000000101oOgl0000000WZ2P09jPX>07moO`0300000009jPX0Ogmo00X0Ogmo00<02NX:
07moO`1oOgl0201oOgl200WZ2P@0Ogmo00H02NX:07moO`1oOgl0Ogmo00000009jPX607moO`090000
001oOgl0Ogmo07moO`0000002NX:0000001oOgl0000000L0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`09jPX0Ogmo07moO`0407moO`80oooo00@02NX:0?ooo`3oool02NX:303oool00`09jPX0oooo0?oo
o`030?ooo`0600WZ2P3oool02NX:00WZ2P3oool02NX:0`3oool00`09jPX0oooo00WZ2P030?ooo`04
00WZ2P3oool0oooo0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`0400WZ2P3oool0oooo
0?ooo`@02NX:0`3oool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:
0?ooo`020?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`802NX:00@0oooo00WZ2P3oool0
2NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo00@02NX:0?ooo`3oool02NX:1@3oool0
0`09jPX0oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
00T0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo
0?ooo`802NX:103oool200WZ2P<0oooo0P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo0`09jPX6
07moO`0500WZ2P1oOgl0Ogmo07moO`09jPX00`1oOgl20000000307moO`0000002NX:0080Ogmo00<0
000000WZ2P1oOgl00P0000001@09jPX0Ogmo00000009jPX0000000l0Ogmo00<02NX:07moO`1oOgl0
2@1oOgl00`09jPX0Ogmo07moO`0707moO`0400000009jPX02NX:00000080Ogmo00<0000000WZ2P1o
Ogl00P1oOgl00`0000002NX:07moO`0507moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0
000007moO`0607moO`040000001oOgl0Ogmo07moO`80oooo00<02NX:0?ooo`3oool01P3oool01009
jPX0oooo0?ooo`09jPX<0?ooo`0300WZ2P3oool0oooo00<0oooo00H02NX:0?ooo`09jPX02NX:0?oo
o`09jPX30?ooo`0300WZ2P3oool02NX:00<0oooo00@02NX:0?ooo`3oool0oooo0P09jPX00`3oool0
2NX:0?ooo`060?ooo`0400WZ2P3oool0oooo0?ooo`@02NX:0`3oool200WZ2P060?ooo`09jPX02NX:
0?ooo`09jPX0oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`802NX:00D0oooo00WZ2P3oool0oooo
00WZ2P020?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:
00<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`090?ooo`0300WZ2P3oool02NX:00<0
oooo0P09jPX20?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX30?ooo`802NX:103oool01P09jPX0
oooo0?ooo`09jPX0oooo00WZ2P80oooo0`09jPX607moO`0500WZ2P000000Ogmo00000009jPX00`1o
Ogl01@0000002NX:07moO`0000002NX:0080Ogmo0P00000207moO`802NX:0P1oOgl200WZ2Q00Ogmo
00<02NX:07moO`1oOgl0201oOgl01@09jPX0000007moO`0000002NX:00D0Ogmo00@0000000WZ2P00
000000000P1oOgl00`0000002NX:07moO`0307moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<000000?ooo`3oool00`3oool00`09
jPX0oooo0?ooo`060?ooo`0400WZ2P3oool0oooo00WZ2P`0oooo00<02NX:0?ooo`3oool00`3oool0
1P09jPX0oooo00WZ2P09jPX0oooo00WZ2P<0oooo00<02NX:0?ooo`09jPX00`3oool02009jPX0oooo
0?ooo`09jPX0oooo00WZ2P3oool02NX:1`3oool01009jPX0oooo0?ooo`3oool400WZ2P<0oooo0P09
jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P3oool00P3oool200WZ2P05
0?ooo`09jPX0oooo0?ooo`09jPX00P3oool200WZ2P040?ooo`09jPX0oooo00WZ2P<0oooo00D02NX:
0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool02@3oool0
0`09jPX0oooo00WZ2P030?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P<0oooo0P09
jPX40?ooo`802NX:00@0oooo00WZ2P09jPX02NX:0P3oool300WZ2PH0Ogmo0P0000000`1oOgl00000
0000000407moO`0400WZ2P1oOgl0Ogmo00WZ2P<0Ogmo00<02NX:07moO`1oOgl00P09jPX307moO`03
00WZ2P1oOgl0Ogmo00d0Ogmo0P00000:07moO`80000000<0Ogmo00000009jPX01P1oOgl200WZ2P@0
Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0407moO`030000001oOgl0Ogmo0080
Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo00<0oooo00<02NX:0?ooo`3o
ool01P3oool01009jPX0oooo0?ooo`09jPX<0?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPX00`3o
ool02NX:00WZ2P040?ooo`0300WZ2P3oool02NX:00<0oooo00P02NX:0?ooo`3oool02NX:0?ooo`09
jPX0oooo00WZ2PL0oooo00@02NX:0?ooo`3oool0oooo1009jPX30?ooo`802NX:00H0oooo00WZ2P09
jPX0oooo00WZ2P3oool200WZ2P090?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0080
oooo00<02NX:0?ooo`3oool00P09jPX0103oool02NX:0?ooo`09jPX30?ooo`0500WZ2P3oool02NX:
0?ooo`09jPX00`3oool200WZ2P80oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00T0oooo00<02NX:0?oo
o`09jPX00`3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX30?ooo`802NX:103oool2
00WZ2P80oooo0P09jPX20?ooo`802NX:00<0000007moO`1oOgl0101oOgl01@09jPX0Ogmo07moO`1o
Ogl02NX:00@0Ogmo00@02NX:07moO`1oOgl02NX:0`1oOgl00`09jPX0Ogmo07moO`0200WZ2P<0Ogmo
00<02NX:07moO`1oOgl01@1oOgl00`0000002NX:07moO`0507moO`0300000009jPX0Ogmo00T0Ogmo
00D02NX:07moO`1oOgl0Ogmo00WZ2P0607moO`802NX:101oOgl00`09jPX0oooo0?ooo`020?ooo`03
00WZ2P3oool0oooo0080oooo0P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo0000001o
Ogl01P1oOgl00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00H0oooo00@02NX:0?ooo`3o
ool02NX:303oool00`09jPX0oooo0?ooo`030?ooo`802NX:00<0oooo00WZ2P09jPX0103oool00`09
jPX0oooo00WZ2P030?ooo`0800WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`09jPX70?ooo`0400WZ
2P3oool0oooo0?ooo`@02NX:0`3oool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX0
2@3oool02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080
2NX:00<0oooo00WZ2P09jPX0103oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX20?oo
o`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0:0?ooo`802NX:0`3oool00`09jPX0oooo00WZ2P020?ooo`04
00WZ2P3oool0oooo0?ooo`802NX:0`3oool200WZ2P@0oooo0P09jPX20?ooo`0400WZ2P3oool02NX:
0?ooo`<02NX:1`1oOgl01009jPX0Ogmo07moO`09jPX507moO`0300WZ2P1oOgl02NX:00<0Ogmo00<0
2NX:07moO`1oOgl00P09jPX01@000000Ogmo00000009jPX0000000H0Ogmo00<0000000WZ2P1oOgl0
1P1oOgl00`09jPX0Ogmo07moO`0807moO`0600WZ2P1oOgl0Ogmo07moO`09jPX0Ogmo1P3oool00`09
jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00P3oool207mo
O`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo
00<0oooo0P09jPX70?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02`3oool00`09jPX0oooo0?ooo`03
0?ooo`802NX:00<0oooo00WZ2P09jPX0103oool00`09jPX0oooo00WZ2P030?ooo`0400WZ2P3oool0
oooo00WZ2P80oooo0P09jPX70?ooo`0400WZ2P3oool0oooo0?ooo`@02NX:0`3oool200WZ2P060?oo
o`09jPX02NX:0?ooo`09jPX0oooo0P09jPX02@3oool02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo
00WZ2P020?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo00WZ2P09jPX0103oool01009jPX0oooo
00WZ2P09jPX40?ooo`802NX:00<0oooo00WZ2P3oool01@3oool00`09jPX0oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00X0oooo00<02NX:0?ooo`09jPX0
0P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0`3oool200WZ2P@0
oooo0P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo0P09jPX707moO`0400WZ2P1oOgl0Ogmo00WZ
2P80Ogmo0`0000001`09jPX0000000WZ2P000000Ogmo00000009jPX00P1oOgl01`0000002NX:0000
001oOgl0000000WZ2P0000001`1oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00<0
Ogmo1@3oool01009jPX0oooo0?ooo`3oool200WZ2PH0oooo00<02NX:0?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0080oooo0P1oOgl00`000000Ogmo07moO`0207mo
O`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`030?ooo`802NX:1`3oool01@09
jPX0oooo0?ooo`3oool02NX:00/0oooo00<02NX:0?ooo`3oool0103oool01009jPX0oooo00WZ2P09
jPX30?ooo`@02NX:0`3oool01009jPX0oooo0?ooo`09jPX20?ooo`802NX:1`3oool01009jPX0oooo
0?ooo`3oool400WZ2P<0oooo0P09jPX02P3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0?oo
o`09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0500WZ2P@0
oooo0P09jPX00`3oool02NX:0?ooo`030?ooo`802NX:00<0oooo00WZ2P3oool01@3oool00`09jPX0
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00X0oooo
00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo0?ooo`80
2NX:0`3oool200WZ2P@0oooo0P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo0P09jPX02@1oOgl0
000000000009jPX0000007moO`0000002NX:0000000200WZ2P0:0000001oOgl0000000WZ2P000000
2NX:00000009jPX0000007moO`8000000P1oOgl200WZ2P<0Ogmo00<02NX:07moO`1oOgl0101oOgl2
0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0203oool01009jPX0oooo0?ooo`3o
ool200WZ2PH0oooo00<02NX:0?ooo`3oool00`3oool01@09jPX0oooo0?ooo`3oool02NX:00@0oooo
0P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo
0?ooo`030?ooo`802NX:1`3oool01@09jPX0oooo0?ooo`3oool02NX:00X0oooo00<02NX:0?ooo`3o
ool01@3oool01009jPX0oooo00WZ2P09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00@02NX:
0?ooo`3oool02NX:0P3oool200WZ2PL0oooo00@02NX:0?ooo`3oool0oooo1009jPX20?ooo`0500WZ
2P3oool02NX:00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P<0oooo00D02NX:0?ooo`09
jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:0?ooo`@02NX:0`3oool01@09jPX0oooo00WZ2P3o
ool02NX:00@0oooo00@02NX:0?ooo`3oool02NX:1P3oool00`09jPX0oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00X0oooo00<02NX:0?ooo`09jPX00P3o
ool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0`3oool200WZ2P@0oooo
0P09jPX20?ooo`<02NX:0P3oool200WZ2P8000000P09jPX00`000000Ogmo000000020000000300WZ
2P00000000000080Ogmo00<02NX:07moO`09jPX00P09jPX0101oOgl0oooo0?ooo`09jPX20?ooo`03
00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool01P3oool200WZ2PL0oooo00<02NX:0?ooo`3o
ool01`3oool01009jPX0oooo0?ooo`3oool200WZ2PH0oooo00<02NX:0?ooo`3oool00`3oool01@09
jPX0oooo0?ooo`3oool02NX:00@0oooo0P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo
0000001oOgl01P1oOgl00`000000oooo0?ooo`030?ooo`802NX:1`3oool01@09jPX0oooo0?ooo`3o
ool02NX:00X0oooo00<02NX:0?ooo`3oool01@3oool01009jPX0oooo00WZ2P09jPX30?ooo`0400WZ
2P3oool02NX:00WZ2P<0oooo00@02NX:0?ooo`3oool02NX:0P3oool200WZ2PL0oooo00@02NX:0?oo
o`3oool0oooo1009jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX00`3oool02NX:0?oo
o`0200WZ2P<0oooo00L02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09
jPX00`09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo00<02NX:0?oo
o`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo00X0oooo00<02NX:0?ooo`09jPX00`3oool200WZ2P80oooo00<02NX:0?ooo`3o
ool00P3oool200WZ2P<0oooo0P09jPX30?ooo`802NX:0P3oool400WZ2P050?ooo`09jPX02NX:0000
003oool00P09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00<02NX:0?ooo`09jPX00P09jPX3
0?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:0P3oool200WZ2PL0oooo0P09jPX70?ooo`0300WZ
2P3oool0oooo00L0oooo00@02NX:0?ooo`3oool0oooo0P09jPX60?ooo`0300WZ2P3oool0oooo00<0
oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ
2P0307moO`000000Ogmo00H0Ogmo00<000000?ooo`3oool00`3oool200WZ2PL0oooo00<02NX:0?oo
o`3oool00P3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo00D0oooo00@02NX:0?oo
o`09jPX02NX:0`3oool01009jPX0oooo00WZ2P09jPX30?ooo`0400WZ2P3oool0oooo00WZ2P80oooo
0P09jPX70?ooo`0400WZ2P3oool0oooo0?ooo`@02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo
00802NX:00<0oooo00WZ2P3oool00P09jPX30?ooo`0700WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ
2P020?ooo`0600WZ2P3oool02NX:00WZ2P3oool02NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:
00<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0:0?ooo`0300WZ2P3oool02NX:00<0
oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:0`3oool200WZ2P<0oooo0P09jPX20?oo
o`@02NX:00<0oooo00WZ2P09jPX00P3oool300WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0`3oool0
0`09jPX0oooo0?ooo`0300WZ2P80oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX20?ooo`802NX:
1`3oool200WZ2PL0oooo00<02NX:0?ooo`3oool01`3oool01009jPX0oooo0?ooo`3oool200WZ2PH0
oooo00<02NX:0?ooo`3oool00`3oool01@09jPX0oooo0?ooo`3oool02NX:00@0oooo0P1oOgl00`00
0000Ogmo07moO`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`030?oo
o`802NX:1`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?oo
o`3oool01@3oool01009jPX0oooo00WZ2P09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00@0
2NX:0?ooo`3oool02NX:0P3oool200WZ2PL0oooo00D02NX:0?ooo`3oool02NX:0?ooo`0300WZ2P80
oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00802NX:0`3oool01009
jPX0oooo00WZ2P09jPX20?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?oo
o`020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo00/0oooo0P09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P<0oooo
0P09jPX40?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`802NX:00@0oooo00WZ2P09jPX0
2NX:0P3oool01009jPX0oooo00WZ2P09jPX30?ooo`802NX:00@0oooo00WZ2P09jPX02NX:0P3oool0
1P09jPX0oooo0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX70?ooo`802NX:1`3oool00`09jPX0oooo
0?ooo`070?ooo`0400WZ2P3oool0oooo0?ooo`802NX:1P3oool00`09jPX0oooo0?ooo`030?ooo`05
00WZ2P3oool0oooo0?ooo`09jPX0103oool207moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1o
Ogl0000007moO`0607moO`030000003oool0oooo00<0oooo0P09jPX70?ooo`0300WZ2P3oool0oooo
0080oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`050?ooo`0400WZ2P3oool02NX:
00WZ2P<0oooo00@02NX:0?ooo`09jPX02NX:0`3oool01009jPX0oooo0?ooo`09jPX20?ooo`802NX:
1P3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`<02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0
oooo00802NX:00<0oooo00WZ2P3oool00P09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00D0
2NX:0?ooo`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo0080oooo00D02NX:0?ooo`09jPX0
oooo00WZ2P030?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool02`3oool200WZ2P<0oooo
00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:0`3oool200WZ2P@0oooo0P09jPX00`3oool0
2NX:0?ooo`0200WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:
00WZ2P<0oooo0P09jPX0103oool02NX:00WZ2P09jPX30?ooo`0300WZ2P3oool0oooo00802NX:0`3o
ool00`09jPX0oooo0?ooo`050?ooo`802NX:1`3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3o
ool0oooo0080oooo0P09jPX50?ooo`802NX:103oool01@09jPX0oooo0?ooo`3oool02NX:00@0oooo
0P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo
0?ooo`030?ooo`802NX:1`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00L0oooo
00<02NX:0?ooo`3oool01@3oool01009jPX0oooo00WZ2P09jPX30?ooo`0400WZ2P3oool02NX:00WZ
2P<0oooo00@02NX:0?ooo`3oool02NX:0P3oool200WZ2PH0oooo00H02NX:0?ooo`3oool0oooo00WZ
2P3oool300WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo0080
2NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00D02NX:0?ooo`3oool02NX:0?ooo`0300WZ
2P@0oooo00@02NX:0?ooo`09jPX02NX:103oool200WZ2P030?ooo`09jPX0oooo00H0oooo00<02NX:
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0;0?oo
o`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`3oool2
00WZ2P<0oooo0P09jPX40?ooo`802NX:0P3oool300WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09
jPX30?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00<02NX:0?ooo`09jPX00P09jPX30?ooo`0600WZ
2P3oool0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo0?ooo`050?ooo`802NX:1`3oool00`09
jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX50?ooo`802NX:103oool01@09
jPX0oooo0?ooo`3oool02NX:00@0oooo0P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo
0000001oOgl01P1oOgl00`000000oooo0?ooo`030?ooo`802NX:1`3oool00`09jPX0oooo0?ooo`02
0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool01@3oool01009jPX0oooo00WZ2P09
jPX30?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00@02NX:0?ooo`3oool02NX:0P3oool200WZ2PH0
oooo00H02NX:0?ooo`3oool0oooo00WZ2P3oool300WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?oo
o`0200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00D0
2NX:0?ooo`3oool02NX:0?ooo`0300WZ2P@0oooo00@02NX:0?ooo`09jPX02NX:103oool200WZ2P03
0?ooo`09jPX0oooo00H0oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`0;0?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX0
0P3oool01009jPX0oooo0?ooo`3oool200WZ2P<0oooo0P09jPX40?ooo`802NX:0P3oool400WZ2P03
0?ooo`09jPX02NX:0080oooo0P09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00<02NX:0?oo
o`09jPX00P09jPX30?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:0P3oool200WZ2PL0oooo0P09
jPX60?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool00P3oool200WZ2PD0oooo0P09
jPX40?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0103oool207moO`030000001oOgl0Ogmo0080Ogmo
0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo00<0oooo0P09jPX70?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`050?ooo`0400WZ
2P3oool02NX:00WZ2P<0oooo00@02NX:0?ooo`09jPX02NX:0`3oool01009jPX0oooo0?ooo`09jPX2
0?ooo`802NX:1P3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`<02NX:0P3oool01@09jPX0oooo
00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0300WZ2P3oool0oooo0080
2NX:0P3oool01@09jPX0oooo0?ooo`09jPX0oooo00<02NX:103oool200WZ2P030?ooo`09jPX0oooo
00<0oooo00@02NX:0?ooo`3oool02NX:1`3oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo00/0oooo00<02NX:0?ooo`09jPX00`3oool200WZ
2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX30?ooo`802NX:103oool200WZ2P80oooo1009jPX2
0?ooo`0300WZ2P3oool0oooo00<02NX:0P3oool01009jPX0oooo00WZ2P09jPX30?ooo`0300WZ2P3o
ool0oooo00<02NX:0P3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX70?ooo`80
2NX:1`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX50?ooo`80
2NX:103oool01@09jPX0oooo0?ooo`3oool02NX:00@0oooo0P1oOgl00`000000Ogmo07moO`0207mo
O`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`030?ooo`802NX:1`3oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool01@3oool01009
jPX0oooo00WZ2P09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00@02NX:0?ooo`3oool02NX:
0P3oool00`09jPX0oooo0?ooo`050?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo0P09jPX01@3o
ool02NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX02NX:0P3oool200WZ2P80oooo00<0
2NX:0?ooo`3oool00P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo0`09jPX30?ooo`0500WZ2P3o
ool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00/0oooo00<0
2NX:0?ooo`09jPX00`3oool200WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX40?ooo`0300WZ
2P3oool0oooo0080oooo0P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo0P09jPX0103oool0
2NX:00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo0P09jPX0103oool02NX:00WZ2P09
jPX20?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:0P3oool200WZ2PL0oooo0P09jPX70?ooo`03
00WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool00P3oool200WZ2PD0oooo0P09jPX50?ooo`04
00WZ2P3oool0oooo00WZ2P@0oooo0P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo0000
001oOgl01P1oOgl00`000000oooo0?ooo`030?ooo`802NX:1`3oool00`09jPX0oooo0?ooo`030?oo
o`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool01@3oool01009jPX0oooo00WZ2P09jPX3
0?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00<02NX:0?ooo`09jPX00`3oool00`09jPX0oooo0?oo
o`050?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo0P09jPX01P3oool02NX:0?ooo`09jPX0oooo
00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo0P09
jPX20?ooo`0300WZ2P3oool02NX:0080oooo0`09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0
0`3oool200WZ2P80oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00/0oooo00<02NX:0?ooo`09jPX00`3o
ool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX30?ooo`802NX:0`3oool200WZ2P80oooo
00@02NX:0?ooo`09jPX02NX:0P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00@02NX:0?oo
o`09jPX02NX:0`3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00H02NX:0?ooo`3oool02NX:
0?ooo`09jPX20?ooo`802NX:1`3oool200WZ2PL0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`020?ooo`802NX:1@3oool200WZ2PD0oooo00@02NX:0?ooo`3oool02NX:103oool207mo
O`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo
00<0oooo0P09jPX70?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool01P3oool00`09
jPX0oooo0?ooo`040?ooo`@02NX:103oool01009jPX0oooo00WZ2P09jPX30?ooo`0300WZ2P3oool0
2NX:00<0oooo00<02NX:0?ooo`3oool01@3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`802NX:
00<0oooo00WZ2P09jPX00P3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P80oooo00D02NX:0?oo
o`3oool0oooo00WZ2P020?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`<02NX:0`3o
ool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00D0oooo
00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0<0?ooo`802NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX30?ooo`802NX:
0`3oool200WZ2P80oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX02NX:
00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0`3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo
00@02NX:0?ooo`3oool02NX:0P3oool01009jPX0oooo00WZ2P09jPX70?ooo`802NX:1`3oool00`09
jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`09jPX0103oool200WZ
2PD0oooo00@02NX:0?ooo`3oool02NX:103oool207moO`030000001oOgl0Ogmo0080Ogmo0P09jPX0
0`1oOgl0000007moO`0607moO`030000003oool0oooo00<0oooo00<02NX:0?ooo`09jPX01@3oool0
0`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0103oool4
00WZ2P@0oooo00@02NX:0?ooo`09jPX02NX:103oool200WZ2P<0oooo00<02NX:0?ooo`3oool01@3o
ool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool01P09jPX0
oooo0?ooo`09jPX0oooo00WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0400WZ2P3o
ool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00`09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09
jPX00`3oool200WZ2P80oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00`0oooo0P09jPX30?ooo`0500WZ
2P3oool02NX:0?ooo`09jPX0103oool200WZ2P<0oooo0P09jPX40?ooo`0900WZ2P3oool0oooo00WZ
2P3oool02NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX02NX:0P3oool01009jPX0oooo
00WZ2P09jPX30?ooo`802NX:00@0oooo00WZ2P09jPX02NX:0P3oool01009jPX0oooo0?ooo`09jPX2
0?ooo`0400WZ2P3oool02NX:00WZ2PL0oooo0P09jPX70?ooo`0300WZ2P3oool0oooo00H0oooo00<0
2NX:0?ooo`3oool00P3oool00`09jPX0oooo00WZ2P040?ooo`0300WZ2P3oool02NX:00@0oooo00@0
2NX:0?ooo`3oool02NX:103oool207moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl00000
07moO`0607moO`030000003oool0oooo00<0oooo00<02NX:0?ooo`09jPX01@3oool00`09jPX0oooo
0?ooo`050?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0103oool400WZ2P@0oooo
00@02NX:0?ooo`09jPX02NX:103oool200WZ2P<0oooo00<02NX:0?ooo`3oool01@3oool01P09jPX0
oooo0?ooo`3oool02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool01P09jPX0oooo0?ooo`09
jPX0oooo00WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo00WZ
2P80oooo00<02NX:0?ooo`3oool00P09jPX40?ooo`0400WZ2P3oool02NX:00WZ2P@0oooo0P09jPX0
0`3oool02NX:0?ooo`060?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0303oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:
0080oooo00@02NX:0?ooo`3oool0oooo0P09jPX30?ooo`802NX:103oool200WZ2P070?ooo`09jPX0
oooo00WZ2P3oool02NX:0?ooo`0200WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool2
00WZ2P<0oooo0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P80oooo
00D02NX:0?ooo`09jPX0oooo00WZ2P060?ooo`0300WZ2P3oool02NX:00H0oooo00<02NX:0?ooo`3o
ool01P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool02NX:00D0oooo0P09jPX40?ooo`04
00WZ2P3oool0oooo00WZ2P@0oooo0P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo0000
001oOgl01P1oOgl00`000000oooo0?ooo`030?ooo`0300WZ2P3oool02NX:00D0oooo00<02NX:0?oo
o`3oool01@3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00@0oooo1009jPX40?oo
o`0400WZ2P3oool02NX:00WZ2P@0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo00D0oooo00@02NX:
0?ooo`3oool0oooo1009jPX00`3oool02NX:00WZ2P020?ooo`0600WZ2P3oool0oooo00WZ2P3oool0
2NX:0P3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo00@02NX:0?ooo`3oool02NX:0P3oool0
0`09jPX0oooo0?ooo`0200WZ2P@0oooo00@02NX:0?ooo`09jPX02NX:103oool200WZ2P030?ooo`09
jPX0oooo00H0oooo00<02NX:0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0<0?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool0
1009jPX0oooo0?ooo`3oool200WZ2P<0oooo0P09jPX40?ooo`802NX:0P3oool400WZ2P030?ooo`09
jPX02NX:00D02NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`0300WZ2P3oool02NX:00@02NX:00D0
oooo00WZ2P3oool0oooo00WZ2P020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX01P3oool00`09jPX0
oooo00WZ2P060?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0
oooo00WZ2P050?ooo`802NX:103oool01009jPX0oooo0?ooo`09jPX40?ooo`80Ogmo00<0000007mo
O`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<000000?ooo`3oool00`3oool00`09
jPX0oooo00WZ2P050?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool01@3oool00`09
jPX0oooo0?ooo`040?ooo`@02NX:103oool01009jPX0oooo00WZ2P09jPX40?ooo`802NX:0`3oool0
0`09jPX0oooo0?ooo`050?ooo`0500WZ2P3oool0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ
2P020?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:0P3oool01009jPX0oooo0?ooo`09jPX30?oo
o`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00P09jPX40?ooo`802NX:00<0oooo
00WZ2P3oool00P3oool200WZ2P80oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00`0oooo00<02NX:0?oo
o`09jPX00`3oool200WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX30?ooo`802NX:103oool2
00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0400WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0
oooo0`09jPX20?ooo`0300WZ2P3oool02NX:00@02NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?oo
o`0500WZ2P3oool02NX:0?ooo`09jPX01P3oool00`09jPX0oooo00WZ2P070?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo00WZ2P050?ooo`802NX:103oool0
1009jPX0oooo0?ooo`09jPX40?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`00
0000Ogmo00H0Ogmo00<000000?ooo`3oool00`3oool00`09jPX0oooo00WZ2P050?ooo`0300WZ2P3o
ool0oooo00H0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`@02NX:103o
ool01009jPX0oooo00WZ2P09jPX40?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`050?ooo`0500WZ
2P3oool0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P020?ooo`0600WZ2P3oool0oooo00WZ
2P3oool02NX:0P3oool01009jPX0oooo0?ooo`09jPX30?ooo`0400WZ2P3oool0oooo00WZ2P80oooo
00<02NX:0?ooo`09jPX00P09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80
oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo00`0oooo00<02NX:0?ooo`09jPX00`3oool200WZ2P80oooo
00@02NX:0?ooo`3oool0oooo0P09jPX30?ooo`802NX:103oool200WZ2P80oooo00H02NX:0?ooo`09
jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:
0P3oool00`09jPX0oooo00WZ2P0400WZ2P80oooo00@02NX:0?ooo`3oool02NX:0P3oool01009jPX0
oooo00WZ2P09jPX60?ooo`0300WZ2P3oool02NX:00L0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool02NX:00D0oooo0P09jPX40?ooo`0400WZ2P3oool0oooo
00WZ2P@0oooo0P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl0
0`000000oooo0?ooo`030?ooo`0300WZ2P3oool02NX:00D0oooo00<02NX:0?ooo`3oool01P3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo1009jPX40?ooo`0400WZ2P3oool0
2NX:00WZ2P@0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo00D0oooo00D02NX:0?ooo`3oool02NX:
0?ooo`0300WZ2P030?ooo`09jPX02NX:0080oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX20?oo
o`0400WZ2P3oool0oooo00WZ2P<0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX20?ooo`<02NX:
0`3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00D0
oooo00<02NX:0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`0<0?ooo`0300WZ2P3oool02NX:00<0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`03
00WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00P3oool200WZ2P80oooo00H02NX:0?ooo`09
jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:
0`3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00@02NX:0?ooo`3oool02NX:0P3oool01009
jPX0oooo00WZ2P09jPX60?ooo`0300WZ2P3oool02NX:00L0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo0P09jPX40?ooo`0400WZ2P3o
ool0oooo00WZ2P@0oooo0P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo0000001oOgl0
1P1oOgl00`000000oooo0?ooo`030?ooo`0300WZ2P3oool02NX:00D0oooo00<02NX:0?ooo`3oool0
1P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo1009jPX40?ooo`0400WZ
2P3oool02NX:00WZ2P@0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo00@0oooo00H02NX:0?ooo`3o
ool0oooo00WZ2P3oool300WZ2P030?ooo`09jPX02NX:0080oooo00H02NX:0?ooo`3oool02NX:0?oo
o`09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX2
0?ooo`<02NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX20?ooo`0300WZ2P3o
ool0oooo00D0oooo00<02NX:0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0=0?ooo`802NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09
jPX30?ooo`802NX:0`3oool200WZ2P80oooo00<02NX:0?ooo`09jPX00P09jPX0103oool02NX:00WZ
2P3oool200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX30?ooo`802NX:00@0oooo00WZ2P09
jPX02NX:0P3oool01009jPX0oooo0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2PH0oooo00@0
2NX:0?ooo`3oool02NX:1P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo
00@02NX:0?ooo`3oool02NX:103oool200WZ2PD0oooo00<02NX:0?ooo`09jPX0103oool207moO`03
0000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo00<0
oooo00<02NX:0?ooo`09jPX01@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0?ooo`3oool0103oool400WZ2P@0oooo00@02NX:0?ooo`09jPX02NX:103oool200WZ
2P<0oooo00<02NX:0?ooo`3oool0103oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`<02NX:00<0
oooo00WZ2P09jPX00P3oool00`09jPX0oooo00WZ2P0200WZ2P80oooo0P09jPX20?ooo`0700WZ2P3o
ool0oooo0?ooo`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00<02NX:0`3oool01@09jPX0
oooo00WZ2P3oool02NX:00<0oooo0P09jPX00`3oool02NX:0?ooo`070?ooo`0300WZ2P3oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool03@3oool200WZ2P<0
oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`802NX:0`3oool200WZ2P<0oooo0P09jPX20?oo
o`0300WZ2P3oool02NX:00802NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:0?ooo`0300WZ
2P80oooo00<02NX:0?ooo`09jPX01009jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo00D02NX:
0?ooo`09jPX0oooo00WZ2P050?ooo`0400WZ2P3oool0oooo00WZ2PH0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo00<02NX:0?ooo`09
jPX0103oool00`09jPX0oooo00WZ2P040?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P03
07moO`000000Ogmo00H0Ogmo00<000000?ooo`3oool00`3oool00`09jPX0oooo00WZ2P050?ooo`03
00WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`@0
2NX:103oool01009jPX0oooo00WZ2P09jPX40?ooo`802NX:0`3oool200WZ2PD0oooo00H02NX:0?oo
o`3oool0oooo00WZ2P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0
2NX:0P3oool200WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX01@3oool02NX:0?ooo`3oool02NX:
0080oooo0`09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P@0oooo0P09jPX00`3oool02NX:0?ooo`07
0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool03@3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?oo
o`3oool0oooo0P09jPX30?ooo`802NX:103oool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:00<0
oooo00WZ2P09jPX01P09jPX00`3oool02NX:0?ooo`0300WZ2P80oooo00<02NX:0?ooo`09jPX01009
jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P050?ooo`04
00WZ2P3oool0oooo00WZ2PH0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?oo
o`0400WZ2P3oool0oooo00WZ2P@0oooo00<02NX:0?ooo`09jPX0103oool00`09jPX0oooo00WZ2P04
0?ooo`80Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<00000
0?ooo`3oool00`3oool00`09jPX0oooo00WZ2P050?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:
0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00<0
2NX:0?ooo`3oool00P09jPX40?ooo`802NX:0`3oool200WZ2PD0oooo00H02NX:0?ooo`3oool0oooo
00WZ2P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX02NX:0P3oool2
00WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo0`09
jPX30?ooo`0400WZ2P3oool02NX:00WZ2P@0oooo00@02NX:0?ooo`3oool02NX:203oool00`09jPX0
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00d0oooo
00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo0?ooo`80
2NX:0`3oool200WZ2P@0oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00H0
2NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`0300WZ2P3oool02NX:00@02NX:00D0oooo00WZ2P3o
ool0oooo00WZ2P030?ooo`802NX:00<0oooo00WZ2P3oool0103oool01009jPX0oooo0?ooo`09jPX6
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09
jPX40?ooo`0300WZ2P3oool02NX:00@0oooo00<02NX:0?ooo`09jPX0103oool207moO`030000001o
Ogl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo00<0oooo00<0
2NX:0?ooo`09jPX01@3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0080oooo00<0
2NX:0?ooo`3oool01@3oool01009jPX0oooo00WZ2P09jPX30?ooo`0500WZ2P3oool0oooo0?ooo`09
jPX0103oool200WZ2P<0oooo0P09jPX50?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo0`09jPX0
103oool02NX:0?ooo`3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo0P09jPX20?ooo`0300WZ
2P3oool0oooo00802NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`<02NX:0`3oool200WZ2P03
0?ooo`09jPX0oooo0080oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0=0?ooo`0300WZ
2P3oool02NX:00<0oooo0P09jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0`3oool200WZ2P@0
oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ2P3o
ool00`09jPX20?ooo`0300WZ2P3oool02NX:00@02NX:00D0oooo00WZ2P3oool0oooo00WZ2P030?oo
o`802NX:00<0oooo00WZ2P3oool0103oool01009jPX0oooo0?ooo`09jPX70?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09jPX40?ooo`0300WZ2P3o
ool02NX:00@0oooo00<02NX:0?ooo`09jPX0103oool207moO`030000001oOgl0Ogmo0080Ogmo0P09
jPX00`1oOgl0000007moO`0607moO`030000003oool0oooo00<0oooo00<02NX:0?ooo`09jPX01@3o
ool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool01@3o
ool01009jPX0oooo00WZ2P09jPX30?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0103oool200WZ2P<0
oooo0P09jPX50?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo0`09jPX0103oool02NX:0?ooo`3o
ool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`802NX:
00P0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P3o
ool02NX:00<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0=0?ooo`0300WZ2P3oool0
2NX:00<0oooo0P09jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0`3oool200WZ2P@0oooo0P09
jPX20?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P040?ooo`09jPX02NX:0?ooo`<0
2NX:0P3oool00`09jPX0oooo00WZ2P0400WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00`3oool200WZ
2P030?ooo`09jPX0oooo00@0oooo00@02NX:0?ooo`3oool02NX:1`3oool00`09jPX0oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo00@0oooo00@02NX:0?ooo`3oool02NX:0`3oool00`09jPX0oooo00WZ
2P040?ooo`0300WZ2P3oool02NX:00@0oooo0P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0
Ogmo0000001oOgl01P1oOgl00`000000oooo0?ooo`030?ooo`0300WZ2P3oool02NX:00D0oooo00<0
2NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00D0oooo00@0
2NX:0?ooo`09jPX02NX:0`3oool01@09jPX0oooo0?ooo`3oool02NX:00@0oooo00L02NX:0?ooo`3o
ool0oooo00WZ2P3oool02NX:00D0oooo00H02NX:0?ooo`3oool0oooo00WZ2P3oool300WZ2P040?oo
o`09jPX0oooo0?ooo`802NX:00@0oooo00WZ2P09jPX02NX:0P3oool200WZ2P030?ooo`09jPX0oooo
0080oooo0P09jPX0203oool02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`0500WZ
2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00h0oooo
0P09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P<0oooo0P09jPX40?ooo`80
2NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX01`3o
ool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool400WZ2P050?ooo`09jPX0oooo0?ooo`09jPX0
0`3oool200WZ2P80oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09jPX60?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool01009jPX0oooo0?ooo`09jPX30?oo
o`0300WZ2P3oool02NX:00@0oooo00<02NX:0?ooo`09jPX0103oool207moO`030000001oOgl0Ogmo
0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`H0000000@02NX:0000000000002NX:10000000
0`09jPX0000000000003000000D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P060?ooo`0400WZ2P3o
ool0oooo00WZ2P@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?ooo`0700WZ2P3oool0oooo0?oo
o`09jPX0oooo00WZ2P050?ooo`0400WZ2P3oool0oooo0?ooo`D02NX:00@0oooo00WZ2P3oool0oooo
0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`802NX:00<0oooo00WZ2P3oool00P3oool200WZ2P04
0?ooo`09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool01@09jPX0oooo00WZ2P3o
ool02NX:00<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0>0?ooo`802NX:0`3oool0
1@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo0080oooo0P09
jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool02@09jPX01`3oool02NX:00WZ2P3oool02NX:0?oo
o`09jPX00P3oool600WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX20?ooo`0300WZ2P3oool0
oooo00<0oooo00@02NX:0?ooo`3oool02NX:1P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3o
ool0oooo00@0oooo00@02NX:0?ooo`3oool02NX:0`0000000`09jPX0000000WZ2P040000000300WZ
2P0000002NX:00@000000P1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo0000001oOgl0
1P1oOgl00`000000Ogmo07moO`0307moO`0400WZ2P1oOgl0Ogmo00WZ2P@0Ogmo00<02NX:07moO`1o
Ogl00`1oOgl50000000500WZ2P000000000000000009jPX01P0000001009jPX0000000000009jPX4
0000000500WZ2P000000000000000009jPX0103oool01`09jPX0oooo0?ooo`3oool02NX:0?ooo`09
jPX01@3oool01@09jPX0oooo0?ooo`09jPX0oooo00@02NX:00@0oooo00WZ2P3oool0oooo0P09jPX0
103oool02NX:00WZ2P09jPX20?ooo`802NX:00<0oooo00WZ2P3oool00P3oool200WZ2P040?ooo`09
jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:
00<0oooo0P09jPX00`3oool02NX:0?ooo`080?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool000L0oooo00<000000?ooo`3oool03P3oool00`09jPX0oooo00WZ2P020?ooo`05
00WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P<0oooo0P09jPX30?ooo`802NX:0P3oool01@09
jPX0oooo00WZ2P09jPX0oooo00P02NX:00<0oooo00WZ2P3oool00`09jPX0103oool02NX:0?ooo`3o
ool600WZ2P80oooo00<02NX:0?ooo`3oool00P3oool01009jPX0oooo0?ooo`09jPX50?ooo`0400WZ
2P3oool0oooo00WZ2PH0oooo00<02NX:0000000000000`0000000`09jPX000000000000400000004
00WZ2P000000000000WZ2P<0Ogmo00@02NX:07moO`1oOgl02NX:0`1oOgl00`09jPX0Ogmo00WZ2P06
07moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000001oOgl0
Ogmo00<0Ogmo00@02NX:07moO`1oOgl02NX:101oOgl00`09jPX0Ogmo07moO`0807moO`0500WZ2P1o
Ogl0Ogmo07moO`09jPX01P1oOgl01009jPX0Ogmo07moO`09jPX407moO`0500WZ2P1oOgl0Ogmo07mo
O`09jPX0100000001`09jPX000000000000000002NX:0?ooo`09jPX01@3oool01@09jPX0oooo0?oo
o`09jPX0oooo00@02NX:00@0oooo00WZ2P3oool0oooo0P09jPX0103oool02NX:00WZ2P09jPX20?oo
o`802NX:00<0oooo00WZ2P3oool00P3oool300WZ2P80oooo00D02NX:0?ooo`3oool02NX:0?ooo`02
00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:103oool200WZ2P030?ooo`09jPX0oooo00P0oooo00<0
2NX:0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0>
0?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`3o
ool200WZ2P<0oooo0P09jPX30?ooo`802NX:0P3oool01009jPX0oooo00WZ2P3oool300WZ2P030?oo
o`09jPX02NX:00<02NX:00<0oooo00WZ2P3oool00`09jPX0103oool02NX:0?ooo`3oool500WZ2P05
0?ooo`09jPX0oooo0?ooo`09jPX00`3oool200WZ2P030?ooo`09jPX0oooo00@0oooo00@02NX:0000
000000002NX:1P0000000`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00@02NX:
07moO`1oOgl02NX:0`1oOgl01009jPX0Ogmo07moO`09jPX407moO`802NX:1P1oOgl00`000000Ogmo
07moO`0207moO`802NX:00<0Ogmo0000001oOgl01P1oOgl00`000000Ogmo07moO`0307moO`0400WZ
2P1oOgl0Ogmo00WZ2P@0Ogmo00<02NX:07moO`1oOgl0201oOgl01@09jPX0Ogmo07moO`1oOgl02NX:
00H0Ogmo00@02NX:07moO`1oOgl02NX:101oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00@0Ogmo00L0
2NX:07moO`1oOgl0Ogmo00WZ2P0000002NX:00D0oooo00D02NX:0?ooo`3oool02NX:0?ooo`0400WZ
2P040?ooo`09jPX0oooo0?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool01@09jPX0oooo00WZ2P3o
ool02NX:00<0oooo0`09jPX20?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX20?ooo`0400WZ
2P3oool02NX:00WZ2P@0oooo00@02NX:0?ooo`3oool02NX:2@3oool00`09jPX0oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00h0oooo00<02NX:0?ooo`09
jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0`3oool200WZ
2P@0oooo00L02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09
jPX0103oool02NX:00WZ2P3oool300WZ2P80oooo00<02NX:0?ooo`09jPX01009jPX01@3oool02NX:
0?ooo`3oool02NX:00<0oooo0P09jPX00`3oool02NX:000000040000000400WZ2P1oOgl0Ogmo00WZ
2PH0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0407moO`0400WZ2P1oOgl0Ogmo
00WZ2P<0Ogmo00@02NX:07moO`1oOgl02NX:101oOgl200WZ2PH0Ogmo00<0000007moO`1oOgl00P1o
Ogl200WZ2P0307moO`000000Ogmo00H0Ogmo00<0000007moO`1oOgl00`1oOgl01009jPX0Ogmo07mo
O`09jPX407moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0607moO`04
00WZ2P1oOgl0Ogmo00WZ2P@0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0407moO`0700WZ2P1oOgl0
Ogmo07moO`09jPX0Ogmo00WZ2P04000000060?ooo`09jPX0oooo0?ooo`09jPX0oooo1009jPX0103o
ool02NX:0?ooo`3oool300WZ2P090?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0080
oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo0?ooo`0400WZ2P80oooo0P09jPX00`3o
ool02NX:0?ooo`020?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool03P3oool00`09jPX0
oooo00WZ2P030?ooo`802NX:0P3oool01009jPX0oooo0?ooo`3oool200WZ2P<0oooo0P09jPX40?oo
o`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09
jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool400WZ2P050?ooo`09jPX0oooo0?oo
o`09jPX00`00000200WZ2P0300000009jPX0Ogmo00@0Ogmo00@02NX:07moO`1oOgl02NX:1`1oOgl0
0`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ
2P0207moO`0400WZ2P1oOgl0000000WZ2P@0Ogmo0P09jPX607moO`030000001oOgl0Ogmo0080Ogmo
0P09jPX00`1oOgl0000007moO`0607moO`030000001oOgl0Ogmo00<0Ogmo00@02NX:07moO`1oOgl0
2NX:101oOgl00`09jPX0Ogmo07moO`0807moO`8000000P1oOgl00`09jPX0Ogmo07moO`0407moO`05
00WZ2P000000Ogmo00WZ2P0000000P1oOgl01P0000002NX:07moO`1oOgl0000000WZ2P<0Ogmo00L0
000000WZ2P1oOgl0Ogmo00000009jPX0000000802NX:0`1oOgl01P09jPX0oooo0?ooo`3oool02NX:
0?ooo`@02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P090?ooo`09jPX0oooo0?ooo`09jPX0
oooo00WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo0?ooo`04
00WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`07
0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool03P3oool00`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool01009jPX0oooo0?ooo`3oool2
00WZ2P<0oooo0P09jPX40?ooo`802NX:00T0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3o
ool00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00@0oooo00WZ2P3oool02NX:0P3oool6
00WZ2P80000000@02NX:07moO`1oOgl0Ogmo0P09jPX207moO`0300WZ2P1oOgl0Ogmo0080Ogmo00D0
2NX:07moO`1oOgl0Ogmo00WZ2P0607moO`0600WZ2P1oOgl0Ogmo07moO`0000002NX:1P1oOgl01@09
jPX0Ogmo07moO`1oOgl02NX:0080Ogmo00@02NX:07moO`0000002NX:101oOgl200WZ2PH0Ogmo00<0
000007moO`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<0000007moO`1oOgl00P1o
Ogl01P0000002NX:07moO`1oOgl02NX:00000080Ogmo00<0000000WZ2P1oOgl02@1oOgl01@000000
2NX:07moO`0000002NX:00H0Ogmo00D02NX:0000001oOgl02NX:0000000207moO`0600000009jPX0
Ogmo07moO`0000002NX:0`1oOgl0100000002NX:07moO`1oOgl3000000802NX:0`1oOgl01P09jPX0
oooo0?ooo`3oool02NX:0?ooo`@02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P090?ooo`09
jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX02NX:0P3oool0
1009jPX0oooo00WZ2P3oool300WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:0`3oool200WZ2P80
oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo00l0oooo0P09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09
jPX00`3oool200WZ2P<0oooo0P09jPX40?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool200WZ
2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0
0P3oool600WZ2P80Ogmo00<02NX:07moO`1oOgl00P1oOgl01009jPX0Ogmo07moO`09jPX307moO`04
00000009jPX0Ogmo07moO`8000001@1oOgl2000000<0Ogmo00<0000000WZ2P1oOgl0101oOgl01P00
00002NX:07moO`1oOgl0000000WZ2P80Ogmo00@02NX:0000001oOgl02NX:101oOgl00`09jPX00000
0000000507moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000
001oOgl0Ogmo0080Ogmo0P00000207moO`0400WZ2P000000Ogmo07moO`8000002`1oOgl01009jPX0
Ogmo00000000000607moO`0400WZ2P1oOgl0Ogmo00WZ2P@0Ogmo00D02NX:07moO`1oOgl0000000WZ
2P0407moO`0600WZ2P1oOgl0Ogmo07moO`09jPX0Ogmo0P09jPX307moO`0600WZ2P3oool0oooo0?oo
o`09jPX0oooo1P09jPX00`3oool02NX:0?ooo`0200WZ2P060?ooo`09jPX0oooo0?ooo`09jPX0oooo
0P09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0`09jPX01P3o
ool02NX:0?ooo`09jPX0oooo00WZ2P<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00L0oooo00<0
2NX:0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0?
0?ooo`802NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo00@02NX:0?ooo`3oool0oooo
0P09jPX40?ooo`802NX:0P3oool01009jPX0oooo00WZ2P3oool200WZ2P80oooo0P09jPX01@3oool0
2NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool02NX:0P3oool500WZ2P040000001oOgl0
000000WZ2P<0Ogmo00D0000000WZ2P1oOgl0000000WZ2P0307moO`0600000009jPX0Ogmo07moO`00
00002NX:1@1oOgl00`0000002NX:07moO`0307moO`0300WZ2P1oOgl0Ogmo00<0Ogmo0P00000207mo
O`0400000009jPX0Ogmo07moO`80000000<0Ogmo00WZ2P1oOgl00`1oOgl00`09jPX0000000000005
07moO`030000001oOgl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000001oOgl0
Ogmo00<0Ogmo00@02NX:07moO`1oOgl02NX:101oOgl00`09jPX0Ogmo07moO`0907moO`0400WZ2P1o
Ogl0Ogmo00WZ2PH0Ogmo00@02NX:07moO`1oOgl02NX:101oOgl00`09jPX0Ogmo07moO`02000000@0
Ogmo00H02NX:0000001oOgl0Ogmo00WZ2P1oOgl200WZ2P<0Ogmo00H02NX:0?ooo`3oool0oooo00WZ
2P3oool600WZ2P030?ooo`09jPX0oooo00802NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool200WZ
2P<0oooo00H02NX:0?ooo`09jPX02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool02NX:00802NX:00H0
oooo00WZ2P3oool02NX:0?ooo`09jPX30?ooo`802NX:00<0oooo00WZ2P3oool02@3oool00`09jPX0
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00l0oooo
00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX30?ooo`03
00WZ2P3oool0oooo0080oooo0P09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`802NX:0P3oool200WZ
2P80oooo0P09jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool500WZ2P040000001o
Ogl00000000000<0Ogmo00D0000000WZ2P1oOgl0000000WZ2P0407moO`0500WZ2P1oOgl0Ogmo07mo
O`09jPX01P1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00D02NX:07mo
O`1oOgl0Ogmo00WZ2P0207moO`0400WZ2P1oOgl0Ogmo00WZ2P@0Ogmo0P09jPX607moO`030000001o
Ogl0Ogmo0080Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000001oOgl0Ogmo0080Ogmo00<0
2NX:07moO`1oOgl00P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00`0Ogmo00<02NX:07moO`09jPX0
1P1oOgl01009jPX0Ogmo07moO`09jPX307moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1o
Ogl00P1oOgl01P09jPX0000007moO`1oOgl02NX:07moO`802NX:0`1oOgl01P09jPX0oooo0?ooo`3o
ool02NX:0?ooo`H02NX:00<0oooo00WZ2P3oool00P09jPX01P3oool02NX:0?ooo`3oool02NX:0?oo
o`802NX:0`3oool01P09jPX0oooo00WZ2P09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00P09
jPX00`3oool02NX:0?ooo`0200WZ2P@0oooo0P09jPX00`3oool02NX:0?ooo`090?ooo`0300WZ2P3o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool03`3oool0
0`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`3oool0oooo0P09
jPX30?ooo`802NX:0`3oool200WZ2P80oooo00P02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?oo
o`<02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`802NX:0P3oool600WZ2P80Ogmo00<02NX:
07moO`1oOgl00P1oOgl01009jPX0Ogmo07moO`09jPX407moO`0500WZ2P1oOgl0Ogmo07moO`09jPX0
1P1oOgl00`09jPX0Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00D02NX:07moO`1oOgl0
Ogmo00WZ2P0207moO`0500WZ2P1oOgl0Ogmo00WZ2P000000101oOgl200WZ2PD0Ogmo00<0000007mo
O`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<0000007moO`1oOgl00P1oOgl00`09
jPX0Ogmo07moO`0207moO`0500WZ2P1oOgl0Ogmo07moO`09jPX02`1oOgl30000000300WZ2P1oOgl0
Ogmo00<0Ogmo00D0000000WZ2P1oOgl0000000WZ2P0307moO`0600WZ2P000000Ogmo07moO`000000
2NX:0`1oOgl01`0000002NX:07moO`1oOgl0000000WZ2P0000000P09jPX207moO`0300000009jPX0
oooo0080oooo00@02NX:0?ooo`09jPX0oooo1009jPX00`3oool02NX:0?ooo`0200WZ2P060?ooo`09
jPX0oooo0?ooo`09jPX0oooo0P09jPX30?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`3o
ool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00802NX:103oool01009jPX0oooo0?ooo`09jPX9
0?ooo`0300WZ2P3oool0oooo00H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool03`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?oo
o`3oool0oooo0P09jPX30?ooo`802NX:0`3oool200WZ2P80oooo00P02NX:0?ooo`09jPX0oooo00WZ
2P3oool02NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`802NX:0P3oool200WZ
2P040?ooo`09jPX02NX:00WZ2P<0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0307moO`0500WZ2P1o
Ogl0Ogmo07moO`09jPX00`1oOgl00`09jPX0Ogmo07moO`0507moO`0500WZ2P1oOgl0Ogmo00000009
jPX01P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:0080Ogmo00D02NX:07moO`1oOgl02NX:00000003
07moO`80000000<02NX:07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`802NX:00<0Ogmo
0000001oOgl01P1oOgl00`000000Ogmo07moO`0207moO`0600WZ2P000000Ogmo07moO`0000002NX:
0P1oOgl00`0000002NX:07moO`0307moO`P0000000<02NX:00000009jPX01P0000001009jPX0Ogmo
00000000000307moO`8000000P1oOgl00`0000002NX:07moO`0207moO`80000000<02NX:07moO`00
00000P00000200WZ2P80Ogmo0P0000030?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool0
2NX:0?ooo`0200WZ2P060?ooo`09jPX0oooo0?ooo`09jPX0oooo0P09jPX30?ooo`0300WZ2P3oool0
2NX:0080oooo00<02NX:0?ooo`3oool00P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:
0`3oool200WZ2P80oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00l0oooo00<02NX:0?ooo`09jPX00`3o
ool200WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX30?ooo`802NX:0`3oool200WZ2P80oooo
00<02NX:0?ooo`09jPX00P3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX0103oool0
2NX:0?ooo`3oool200WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09jPX207moO`0300000009jPX0
Ogmo0080Ogmo00<02NX:0000001oOgl00P00000307moO`0600WZ2P000000Ogmo07moO`09jPX00000
1@1oOgl01P0000002NX:07moO`1oOgl0000000WZ2PD0Ogmo00<0000000WZ2P1oOgl00P1oOgl01`09
jPX0000007moO`09jPX0000007moO`09jPX0101oOgl00`0000002NX:00WZ2P0507moO`030000001o
Ogl0Ogmo0080Ogmo0P0000000`1oOgl0000007moO`0607moO`X0000000<02NX:0000000000001P00
000807moO`0300WZ2P1oOgl02NX:00H0Ogmo00@02NX:07moO`1oOgl02NX:0`1oOgl00`09jPX0Ogmo
07moO`0207moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P09jPX207moO`0400WZ2P1oOgl02NX:00WZ2P<0
Ogmo00D02NX:0?ooo`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ
2P3oool00`09jPX00`3oool02NX:00WZ2P020?ooo`802NX:0P3oool01009jPX0oooo0?ooo`09jPX2
0?ooo`0300WZ2P3oool0oooo00802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:0?oo
o`020?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool03`3oool00`09jPX0oooo00WZ2P03
0?ooo`802NX:0P3oool01009jPX0oooo0?ooo`3oool200WZ2P<0oooo0P09jPX40?ooo`0600WZ2P3o
ool0oooo00WZ2P3oool02NX:0P3oool200WZ2P80oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo
00802NX:00<0oooo00WZ2P09jPX00P3oool200WZ2P080?ooo`09jPX0000000WZ2P000000Ogmo0000
0009jPX307moO`0500WZ2P000000Ogmo00000009jPX00`1oOgl200000080Ogmo00<02NX:0000001o
Ogl0101oOgl00`0000002NX:000000020000000300WZ2P000000000000P0000000<02NX:00000000
0000100000000`09jPX0000000000002000000802NX:0`00000207moO`030000001oOgl0Ogmo0080
Ogmo0P09jPX00`1oOgl0000007moO`0607moO`030000001oOgl0Ogmo0080Ogmo00<02NX:07moO`1o
Ogl00P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00`0Ogmo00<02NX:07moO`09jPX01P1oOgl01009
jPX0Ogmo07moO`09jPX307moO`0300WZ2P1oOgl0Ogmo0080Ogmo00T02NX:07moO`1oOgl0Ogmo00WZ
2P0000002NX:07moO`09jPX00P1oOgl01@09jPX0Ogmo00WZ2P1oOgl02NX:00<0oooo00D02NX:0?oo
o`09jPX02NX:0?ooo`0400WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo
0P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX0203oool0
2NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0`3oool200WZ2P80oooo00<02NX:0?ooo`3oool01`3o
ool00`09jPX0oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo0100oooo0P09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P<0oooo0P09
jPX40?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool200WZ2P80oooo0P09jPX20?ooo`802NX:
00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`802NX:00D0oooo00WZ2P0000002NX:0000000207mo
O`0600WZ2P1oOgl0Ogmo07moO`09jPX000000P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00<0Ogmo
00<02NX:07moO`1oOgl01@1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00H0Ogmo00D02NX:07moO`1o
Ogl0Ogmo00WZ2P0207moO`0300WZ2P1oOgl0Ogmo00800000101oOgl200WZ2PD0Ogmo00<0000007mo
O`1oOgl00P1oOgl200WZ2P0307moO`000000Ogmo00H0Ogmo00<0000007moO`1oOgl00P1oOgl00`09
jPX0Ogmo07moO`0207moO`0500WZ2P1oOgl0Ogmo07moO`09jPX03@1oOgl200WZ2PH0Ogmo00@02NX:
07moO`1oOgl02NX:0`1oOgl00`09jPX0Ogmo07moO`0207moO`0900WZ2P1oOgl0Ogmo07moO`09jPX0
000000WZ2P1oOgl02NX:0080Ogmo00D02NX:000000000000Ogmo00WZ2P030?ooo`0500WZ2P3oool0
2NX:00WZ2P3oool01009jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX20?ooo`80
2NX:0P3oool01009jPX0oooo0?ooo`09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo0`09
jPX0103oool02NX:0?ooo`09jPX30?ooo`802NX:00<0oooo00WZ2P3oool02@3oool00`09jPX0oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0100oooo0P09
jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P<0oooo0P09jPX40?ooo`802NX:
00@0oooo00WZ2P3oool02NX:0P3oool300WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX00`3oool0
2NX:00WZ2P020?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P<0Ogmo00D02NX:07moO`1o
Ogl0Ogmo00WZ2P0307moO`0300WZ2P1oOgl0Ogmo0080Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P07
07moO`0400WZ2P1oOgl0Ogmo00WZ2PH0Ogmo00<02NX:07moO`1oOgl00P1oOgl01`09jPX0Ogmo07mo
O`09jPX0Ogmo00000009jPX0101oOgl200WZ2PD0Ogmo00<0000007moO`1oOgl00P1oOgl200WZ2P03
07moO`000000Ogmo00H0Ogmo00<0000007moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0207moO`05
00WZ2P1oOgl0Ogmo07moO`09jPX01`1oOgl2000000<0Ogmo00@0000000WZ2P09jPX02NX:101oOgl0
2@0000002NX:07moO`0000002NX:07moO`09jPX0000000WZ2P0207moO`0300000009jPX02NX:0080
Ogmo00X0000000WZ2P0000002NX:00000009jPX0Ogmo00000009jPX000000`09jPX01@000000oooo
0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`0400WZ2P3oool02NX:0?oo
o`802NX:0P3oool200WZ2P80oooo00@02NX:0?ooo`3oool02NX:0P3oool01P09jPX0oooo00WZ2P3o
ool02NX:0?ooo`<02NX:00@0oooo00WZ2P3oool02NX:0`3oool200WZ2P030?ooo`09jPX0oooo00T0
oooo00<02NX:0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`0@0?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`80
2NX:0P3oool200WZ2P@0oooo0P09jPX20?ooo`802NX:0`3oool200WZ2P030?ooo`09jPX02NX:0080
oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`802NX:0P3oool200WZ2P0407moO`09jPX02NX:00WZ
2P80Ogmo00<02NX:07moO`1oOgl00P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00<0Ogmo00D02NX:
07moO`1oOgl0Ogmo00WZ2P0707moO`0400WZ2P1oOgl0000000WZ2PH0Ogmo00@02NX:07moO`1oOgl0
Ogmo0P0000000`1oOgl0000000WZ2P0207moO`0300WZ2P1oOgl0Ogmo0080Ogmo00@02NX:0000001o
Ogl000000P09jPX2000000@0Ogmo0P09jPX00`1oOgl0000000WZ2P0607moO`030000001oOgl0Ogmo
0080Ogmo00H02NX:0000001oOgl0Ogmo00000009jPX207moO`0300000009jPX0Ogmo00H0Ogmo00<0
2NX:0000001oOgl00P1oOgl0100000002NX:00WZ2P09jPX407moO`80000000D0Ogmo000000000000
Ogmo00WZ2P0200000080Ogmo00<0000000WZ2P09jPX00P1oOgl0100000002NX:00000009jPX20000
000407moO`0000002NX:07moO`802NX:00H000000?ooo`3oool0oooo00WZ2P3oool200WZ2P030?oo
o`09jPX02NX:00<02NX:0P3oool01009jPX0oooo00WZ2P3oool200WZ2P80oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX0oooo0`09jPX0
103oool02NX:0?ooo`09jPX30?ooo`802NX:00<0oooo00WZ2P3oool02@3oool00`09jPX0oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0100oooo00<02NX:
0?ooo`09jPX00P3oool01@09jPX0oooo00WZ2P3oool02NX:00@0oooo0P09jPX30?ooo`802NX:0`3o
ool200WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P030?ooo`09jPX02NX:0080oooo0P09
jPX00`3oool02NX:00WZ2P020?ooo`802NX:0P3oool200WZ2P@0000000@0Ogmo00000009jPX0Ogmo
0`0000001009jPX0000000WZ2P00000200WZ2P0407moO`0000002NX:07moO`80000000X02NX:07mo
O`09jPX0000007moO`0000002NX:00000009jPX0Ogmo0P00000507moO`0300000009jPX0Ogmo0080
Ogmo00D0000000WZ2P1oOgl0000000WZ2P0207moO`0300WZ2P1oOgl0Ogmo0080Ogmo00@02NX:0000
001oOgl000000P09jPX2000000@0Ogmo0P0000000`1oOgl0000000WZ2P0607moO`030000001oOgl0
Ogmo0080Ogmo0P00000207moO`0400000009jPX0Ogmo07moO`8000001`1oOgl00`09jPX0Ogmo07mo
O`0307moO`<02NX:1@1oOgl02009jPX0Ogmo07moO`09jPX0Ogmo00WZ2P1oOgl02NX:0`1oOgl200WZ
2P<0Ogmo00D02NX:000000000000Ogmo00WZ2P0207moO`0300WZ2P3oool02NX:00802NX:0`3oool0
1@09jPX0oooo00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00P3oool01009jPX0oooo00WZ
2P3oool200WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:0080
oooo00@02NX:0?ooo`09jPX0oooo0`09jPX00`3oool02NX:00WZ2P040?ooo`0400WZ2P3oool0oooo
00WZ2PX0oooo00<02NX:0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0@0?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool01009
jPX0oooo0?ooo`3oool200WZ2P<0oooo0P09jPX30?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P02
0?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool500WZ2P80oooo0P09jPX20?ooo`802NX:00l00000
00WZ2P09jPX02NX:07moO`0000002NX:07moO`0000002NX:00000009jPX0000000WZ2P0000000P09
jPX0101oOgl000000000001oOgl20000000900WZ2P1oOgl02NX:0000001oOgl0000000WZ2P000000
2NX:0080Ogmo00<02NX:07moO`1oOgl00`1oOgl2000000@0Ogmo00@02NX:07moO`1oOgl02NX:0P1o
Ogl00`09jPX0Ogmo07moO`0207moO`802NX:0P1oOgl200WZ2P0307moO`000000Ogmo00<0Ogmo0P09
jPX00`1oOgl0000000WZ2P0607moO`030000001oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl00P1o
Ogl01@09jPX0Ogmo07moO`1oOgl02NX:00L0Ogmo00<02NX:07moO`1oOgl00`1oOgl300WZ2PD0Ogmo
00P02NX:07moO`1oOgl02NX:07moO`09jPX0Ogmo00WZ2P<0Ogmo0P09jPX307moO`0500WZ2P000000
2NX:07moO`09jPX00P3oool00`09jPX0oooo00WZ2P0200WZ2P<0oooo00D02NX:0?ooo`09jPX02NX:
0?ooo`0200WZ2P030?ooo`09jPX02NX:0080oooo00@02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`06
00WZ2P3oool0oooo0?ooo`09jPX0oooo0P09jPX0203oool02NX:0?ooo`3oool02NX:0?ooo`09jPX0
oooo0`09jPX00`3oool02NX:00WZ2P030?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`080?ooo`03
00WZ2P3oool0oooo00H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
403oool00`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool01009jPX0oooo0?ooo`3oool200WZ2P<0
oooo0P09jPX30?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`D02NX:0`3oool400WZ2P80
oooo0P09jPX20?ooo`802NX:00@0oooo00WZ2P09jPX02NX:0P1oOgl02@09jPX0Ogmo07moO`09jPX0
Ogmo00WZ2P0000002NX:07moO`0200WZ2P80Ogmo00<02NX:07moO`1oOgl00P09jPX00`1oOgl02NX:
07moO`0207moO`0300WZ2P1oOgl02NX:0080Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo
07moO`0207moO`0400WZ2P1oOgl0Ogmo00WZ2P80Ogmo00<02NX:07moO`1oOgl00P1oOgl200WZ2P80
Ogmo0P09jPX00`1oOgl0000007moO`0307moO`802NX:00<0Ogmo00000009jPX01P1oOgl00`000000
Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo0080Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0707mo
O`0300WZ2P1oOgl0Ogmo00<0Ogmo0`09jPX507moO`0800WZ2P1oOgl0Ogmo00WZ2P1oOgl02NX:07mo
O`09jPX307moO`802NX:0P1oOgl01P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?oo
o`09jPX00P09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3o
ool01009jPX0oooo00WZ2P3oool200WZ2P80oooo00H02NX:0?ooo`3oool0oooo00WZ2P3oool200WZ
2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool400WZ2P030?ooo`09jPX0oooo0080oooo0P09jPX2
0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`0A0?ooo`802NX:0`3oool200WZ2P80oooo00@02NX:0?oo
o`3oool0oooo0P09jPX30?ooo`802NX:0`3oool200WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool3
00WZ2P030?ooo`09jPX02NX:0080oooo1009jPX30?ooo`0300WZ2P3oool0oooo00802NX:00L0oooo
00WZ2P09jPX02NX:0?ooo`1oOgl02NX:0080Ogmo00H02NX:07moO`09jPX0Ogmo00WZ2P1oOgl200WZ
2P80Ogmo00<02NX:07moO`1oOgl00P09jPX00`1oOgl02NX:07moO`0207moO`0300WZ2P1oOgl02NX:
0080Ogmo00<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0207moO`0400WZ2P1oOgl0Ogmo
00WZ2P<0Ogmo00@02NX:07moO`1oOgl0Ogmo0P09jPX207moO`802NX:00<0Ogmo0000001oOgl00`1o
Ogl200WZ2P0307moO`0000002NX:00H0Ogmo00<0000007moO`1oOgl00P1oOgl00`09jPX0Ogmo07mo
O`0207moO`0500WZ2P1oOgl0Ogmo07moO`09jPX01`1oOgl00`09jPX0Ogmo07moO`0307moO`<02NX:
1@1oOgl02009jPX0Ogmo07moO`09jPX0Ogmo00WZ2P1oOgl02NX:0P1oOgl00`3oool02NX:00WZ2P03
0?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2P<0oooo00@0
2NX:0?ooo`09jPX02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:0?oo
o`802NX:0P3oool01009jPX0oooo0?ooo`09jPX20?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09
jPX20?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool200WZ2P80oooo00<02NX:0?ooo`3oool0
203oool00`09jPX0oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo0140oooo0P09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P<0oooo
0P09jPX40?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:0`3oool200WZ2P030?ooo`09jPX02NX:
0080oooo1009jPX30?ooo`0300WZ2P3oool0oooo00H02NX:0P3oool01`09jPX0oooo0?ooo`09jPX0
Ogmo00WZ2P1oOgl00P09jPX01@1oOgl02NX:00WZ2P1oOgl02NX:0080Ogmo1@09jPX207moO`802NX:
00@0Ogmo00WZ2P1oOgl02NX:1P1oOgl00`09jPX0Ogmo07moO`0307moO`0300WZ2P1oOgl02NX:00<0
Ogmo00<02NX:07moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0300WZ2P030000001oOgl0Ogmo0080
Ogmo0P09jPX00`1oOgl0000000WZ2P0607moO`030000001oOgl0Ogmo0080Ogmo00<02NX:07moO`1o
Ogl00P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:00L0Ogmo00<02NX:07moO`1oOgl00`1oOgl300WZ
2PD0Ogmo00P02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P<0oooo0P09jPX30?ooo`0500WZ
2P3oool02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2P<0oooo0`09jPX30?ooo`04
00WZ2P3oool02NX:00WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`0400WZ2P3oool0
oooo00WZ2P80oooo0P09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX0103oool0
2NX:0?ooo`09jPX30?ooo`802NX:00<0oooo00WZ2P3oool02P3oool00`09jPX0oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0140oooo0P09jPX30?ooo`05
00WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P<0oooo0P09jPX40?ooo`802NX:00@0oooo00WZ
2P3oool02NX:0`3oool200WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX00`3oool02NX:0?ooo`02
0?ooo`0300WZ2P3oool0oooo00<02NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`H02NX:
00D0oooo00WZ2P09jPX0Ogmo00WZ2P0207moO`D02NX:0P1oOgl200WZ2P0407moO`09jPX0Ogmo00WZ
2PH0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo00WZ2P0307moO`0300WZ2P1oOgl0Ogmo
0080Ogmo00<02NX:07moO`1oOgl00`09jPX00`000000Ogmo07moO`0207moO`802NX:00@0Ogmo0000
0009jPX02NX:1@1oOgl00`000000Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo0080Ogmo00D02NX:
07moO`1oOgl0Ogmo00WZ2P0507moO`80oooo00<02NX:0?ooo`3oool0103oool200WZ2PD0oooo00P0
2NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P<0oooo0P09jPX30?ooo`0400WZ2P3oool02NX:
00WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P040?ooo`<02NX:0`3oool01009jPX0oooo00WZ2P09
jPX20?ooo`802NX:0P3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo00<02NX:0?ooo`3oool0
0P09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX0103oool02NX:0?ooo`09jPX3
0?ooo`802NX:00<0oooo00WZ2P3oool02P3oool00`09jPX0oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo0140oooo00<02NX:0?ooo`09jPX00P3oool01@09
jPX0oooo00WZ2P3oool02NX:00@0oooo00@02NX:0?ooo`3oool0oooo0P09jPX40?ooo`802NX:00@0
oooo00WZ2P3oool02NX:0`3oool200WZ2P030?ooo`09jPX02NX:0080oooo1@09jPX20?ooo`0300WZ
2P3oool0oooo00<02NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`H02NX:00D0oooo00WZ
2P09jPX0oooo00WZ2P020?ooo`D02NX:0P3oool200WZ2P040?ooo`09jPX0oooo00WZ2PH0oooo00<0
2NX:0?ooo`3oool00P3oool0101oOgl02NX:07moO`09jPX307moO`0300WZ2P1oOgl0Ogmo0080Ogmo
00<02NX:07moO`1oOgl00`09jPX00`000000Ogmo07moO`0207moO`802NX:00@0Ogmo00000009jPX0
2NX:1@1oOgl00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3o
ool02NX:1`3oool200WZ2PD0oooo0P09jPX50?ooo`0800WZ2P3oool0oooo00WZ2P3oool02NX:0?oo
o`09jPX20?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX00`3oool02NX:
00WZ2P030?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ
2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00802NX:00H0oooo
00WZ2P3oool02NX:0?ooo`09jPX20?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool200WZ2P03
0?ooo`09jPX0oooo00X0oooo00<02NX:0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`0A0?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0
oooo00WZ2P040?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`020?ooo`802NX:00@0oooo00WZ2P3o
ool02NX:0`3oool00`09jPX0oooo00WZ2P0200WZ2P<0oooo1009jPX20?ooo`0300WZ2P3oool0oooo
00<02NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`H02NX:00D0oooo00WZ2P09jPX0oooo
00WZ2P020?ooo`D02NX:0P3oool200WZ2P040?ooo`09jPX0oooo00WZ2PH0oooo00<02NX:0?ooo`3o
ool00`3oool00`09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3o
ool00`09jPX00`000000Ogmo07moO`0207moO`802NX:00@0Ogmo00000009jPX02NX:1@1oOgl00`00
0000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3oool02NX:1`3oool2
00WZ2PD0oooo0P09jPX50?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX30?ooo`<02NX:0P3o
ool200WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX00`3oool02NX:00WZ2P030?ooo`0400WZ2P3o
ool02NX:00WZ2P<0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P80oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00<02NX:0P3oool00`09jPX0oooo00WZ2P020?oo
o`802NX:00<0oooo00WZ2P09jPX0103oool01009jPX0oooo0?ooo`09jPX;0?ooo`0300WZ2P3oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool04@3oool00`09
jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`3oool0oooo0P09jPX3
0?ooo`802NX:0`3oool200WZ2P80oooo0P09jPX30?ooo`H02NX:0P3oool400WZ2P<0oooo00<02NX:
0?ooo`09jPX00P09jPX0103oool02NX:00WZ2P09jPX20?ooo`0900WZ2P3oool02NX:00WZ2P3oool0
2NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool0oooo0`09jPX0103oool02NX:0?ooo`3o
ool200WZ2P040?ooo`09jPX0oooo00WZ2PH0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
00WZ2P030?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`09jPX00`000000Ogmo
07moO`0207moO`802NX:00@0Ogmo00000009jPX02NX:1@1oOgl00`000000oooo0?ooo`020?ooo`03
00WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3oool02NX:1`3oool200WZ2PD0oooo00<02NX:0?oo
o`09jPX00`3oool01009jPX0oooo0?ooo`09jPX20?ooo`802NX:0`3oool300WZ2P80oooo0P09jPX0
0`3oool02NX:00WZ2P020?ooo`802NX:00<0oooo00WZ2P09jPX00`3oool01009jPX0oooo00WZ2P09
jPX30?ooo`0300WZ2P3oool02NX:0080oooo0`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3o
ool00`09jPX0oooo0?ooo`0300WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P030?ooo`09
jPX02NX:00<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0A0?ooo`0300WZ2P3oool0
2NX:00<0oooo0P09jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0`3oool200WZ2P<0oooo0P09
jPX20?ooo`0300WZ2P3oool02NX:0080oooo1P09jPX20?ooo`@02NX:0`3oool01@09jPX0oooo0?oo
o`09jPX0oooo00@02NX:0P3oool01`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool00P09jPX01P3o
ool02NX:0?ooo`3oool02NX:0?ooo`<02NX:00@0oooo00WZ2P3oool0oooo0P09jPX0103oool02NX:
0?ooo`09jPX60?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`09jPX00`3oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<02NX:00<0000007moO`1oOgl00P1oOgl200WZ2P04
07moO`0000002NX:00WZ2PD0Ogmo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?oo
o`0400WZ2P3oool0oooo00WZ2PL0oooo0P09jPX40?ooo`802NX:00<0oooo00WZ2P3oool00P3oool0
2009jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0`3oool300WZ2P80oooo0P09jPX00`3oool0
2NX:00WZ2P020?ooo`802NX:00<0oooo00WZ2P09jPX00`3oool01009jPX0oooo00WZ2P09jPX30?oo
o`0300WZ2P3oool02NX:0080oooo0`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool00`09
jPX0oooo0?ooo`0300WZ2P80oooo0P09jPX30?ooo`<02NX:00<0oooo00WZ2P3oool00P3oool200WZ
2P80oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo0180oooo0P09jPX30?ooo`802NX:0P3oool01009jPX0
oooo0?ooo`3oool200WZ2P<0oooo0P09jPX30?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P020?oo
o`H02NX:0P3oool400WZ2P<0oooo00<02NX:0?ooo`3oool00`09jPX01P3oool02NX:00WZ2P09jPX0
oooo00WZ2P80oooo1P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00L0oooo00WZ2P09
jPX02NX:0?ooo`09jPX0oooo00<02NX:1`3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0
2NX:00<0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0300WZ2P030000001oOgl0
Ogmo0080Ogmo0P09jPX0101oOgl0000000WZ2P09jPX507moO`030000003oool0oooo0080oooo00<0
2NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09jPX70?ooo`802NX:103oool200WZ2P030?oo
o`09jPX0oooo0080oooo00P02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P<0oooo0`09jPX2
0?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool200WZ2P030?ooo`09jPX02NX:00<0oooo00@02NX:
0?ooo`09jPX02NX:0P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:0P3oool00`09jPX0oooo
0?ooo`0200WZ2P80oooo00H02NX:0?ooo`09jPX02NX:0?ooo`09jPX20?ooo`802NX:0`3oool300WZ
2P030?ooo`09jPX0oooo0080oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0B0?ooo`80
2NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX30?ooo`802NX:0`3oool200WZ
2P80oooo00<02NX:0?ooo`09jPX00`3oool00`09jPX0oooo00WZ2P0200WZ2P80oooo00@02NX:0?oo
o`09jPX02NX:0`3oool00`09jPX0oooo0?ooo`0300WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:
0P3oool600WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool500WZ2P80oooo0P09jPX00`3oool0
2NX:0?ooo`060?ooo`0300WZ2P3oool0oooo00@0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo0080
oooo00<02NX:0?ooo`3oool00`09jPX00`000000Ogmo07moO`0207moO`802NX:00@0Ogmo00000009
jPX02NX:1@1oOgl00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?oo
o`3oool02NX:1`3oool200WZ2P@0oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`0800WZ2P3oool0
oooo00WZ2P3oool02NX:0?ooo`09jPX30?ooo`@02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?oo
o`0300WZ2P3oool02NX:00<02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`802NX:00@0oooo
00WZ2P09jPX0oooo0`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool01P09jPX0oooo00WZ
2P09jPX0oooo00WZ2P80oooo0P09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ
2P030?ooo`09jPX0oooo00/0oooo00<02NX:0?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0B0?ooo`802NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:
00<0oooo0P09jPX30?ooo`802NX:103oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P<0oooo0`09
jPX0103oool02NX:00WZ2P3oool400WZ2P<0oooo00<02NX:0?ooo`3oool00`09jPX01P3oool02NX:
00WZ2P09jPX0oooo00WZ2P80oooo1P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo1@09jPX2
0?ooo`802NX:00<0oooo00WZ2P3oool01P3oool00`09jPX0oooo0?ooo`040?ooo`802NX:103oool0
1009jPX0oooo0?ooo`3oool200WZ2P050?ooo`09jPX02NX:00000009jPX0101oOgl200WZ2P0407mo
O`0000002NX:00WZ2PD0Ogmo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`04
00WZ2P3oool0oooo00WZ2PL0oooo0P09jPX40?ooo`802NX:00<0oooo00WZ2P3oool00P3oool02009
jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0`3oool400WZ2P030?ooo`09jPX0oooo00<02NX:
0P3oool00`09jPX0oooo00WZ2P0300WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool200WZ2P04
0?ooo`09jPX02NX:0?ooo`<02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P040?ooo`09jPX0oooo
0?ooo`802NX:00H0oooo00WZ2P3oool02NX:0?ooo`09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09
jPX00`3oool200WZ2P030?ooo`09jPX0oooo00/0oooo00<02NX:0?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0B0?ooo`0300WZ2P3oool02NX:0080oooo
00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0`3oool200WZ2P@0oooo0P09jPX0103oool0
2NX:0?ooo`09jPX30?ooo`H02NX:00<0oooo00WZ2P09jPX00P09jPX30?ooo`802NX:00D0oooo00WZ
2P09jPX02NX:0?ooo`0300WZ2P040?ooo`09jPX0oooo0?ooo`H02NX:00D0oooo00WZ2P09jPX0oooo
00WZ2P020?ooo`D02NX:0P3oool200WZ2P030?ooo`09jPX0oooo00H0oooo00<02NX:0?ooo`3oool0
103oool200WZ2P@0oooo00@02NX:0?ooo`3oool0oooo0P09jPX01@3oool02NX:00WZ2P1oOgl02NX:
00@0Ogmo0P09jPX0101oOgl0000000WZ2P09jPX507moO`030000003oool0oooo0080oooo00<02NX:
0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09jPX70?ooo`802NX:103oool200WZ2P030?ooo`09
jPX0oooo0080oooo00P02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P<0oooo1009jPX00`3o
ool02NX:0?ooo`0300WZ2P80oooo00<02NX:0?ooo`09jPX00`09jPX20?ooo`0400WZ2P3oool02NX:
00WZ2P80oooo0P09jPX0103oool02NX:00WZ2P3oool300WZ2P030?ooo`09jPX02NX:0080oooo0P09
jPX0103oool02NX:0?ooo`3oool200WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:0`3oool01@09
jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX00`3oool02NX:0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool04P3oool00`09
jPX0oooo00WZ2P020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0103oool200WZ2P80oooo0P09jPX4
0?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool600WZ2P030?ooo`09jPX02NX:00802NX:0`3o
ool200WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00@0oooo00WZ2P3oool0oooo1P09jPX01@3oool0
2NX:00WZ2P3oool02NX:0080oooo1@09jPX20?ooo`802NX:00<0oooo00WZ2P3oool01P3oool00`09
jPX0oooo0?ooo`040?ooo`802NX:103oool01009jPX0oooo0?ooo`3oool200WZ2P050?ooo`09jPX0
2NX:07moO`09jPX0101oOgl200WZ2P0507moO`0000002NX:07moO`09jPX0101oOgl00`000000oooo
0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3oool02NX:1`3oool200WZ2P@0
oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`0800WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`09
jPX30?ooo`@02NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`0300WZ2P3oool02NX:00<02NX:0P3o
ool00`09jPX0oooo00WZ2P030?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`802NX:
0P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00H0oooo00WZ2P3oool02NX:0?ooo`09jPX3
0?ooo`0400WZ2P3oool02NX:00WZ2P@0oooo00@02NX:0?ooo`3oool02NX:2`3oool00`09jPX0oooo
0?ooo`070?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0180oooo00<0
2NX:0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo0?ooo`802NX:
0`3oool00`09jPX0oooo0?ooo`020?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool600WZ2P80
oooo0`09jPX30?ooo`802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool400WZ2P80oooo1@09jPX0
0`3oool02NX:00WZ2P0300WZ2P80oooo0P09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool0
0P09jPX70?ooo`0300WZ2P3oool0oooo00@0oooo0P09jPX40?ooo`0400WZ2P3oool0oooo0?ooo`80
2NX:00D0oooo00WZ2P09jPX0Ogmo00WZ2P0407moO`802NX:00D0Ogmo00000009jPX0Ogmo00WZ2P04
07moO`030000003oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09
jPX70?ooo`802NX:103oool200WZ2P030?ooo`09jPX0oooo0080oooo00P02NX:0?ooo`3oool02NX:
0?ooo`09jPX0oooo00WZ2P<0oooo1009jPX00`3oool02NX:0?ooo`0300WZ2P80oooo00<02NX:0?oo
o`09jPX00`09jPX20?ooo`<02NX:0`3oool200WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0P3o
ool200WZ2P80oooo0P09jPX0103oool02NX:0?ooo`3oool300WZ2P80oooo00<02NX:0?ooo`09jPX0
0`3oool01009jPX0oooo00WZ2P09jPX30?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`090?ooo`03
00WZ2P3oool0oooo00L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
4P3oool00`09jPX0oooo00WZ2P030?ooo`802NX:0P3oool01009jPX0oooo0?ooo`3oool200WZ2P<0
oooo0P09jPX30?ooo`802NX:0P3oool200WZ2P<0oooo0P09jPX0103oool02NX:00WZ2P09jPX20?oo
o`@02NX:0P3oool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1009jPX20?ooo`0600WZ2P3o
ool02NX:0?ooo`09jPX0oooo1@09jPX20?ooo`802NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0
oooo00802NX:1`3oool00`09jPX0oooo0?ooo`040?ooo`802NX:103oool01009jPX0oooo0?ooo`3o
ool200WZ2P050?ooo`09jPX02NX:07moO`09jPX0101oOgl200WZ2P0507moO`0000002NX:07moO`09
jPX0101oOgl00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3o
ool02NX:1`3oool200WZ2P@0oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`0800WZ2P3oool0oooo
00WZ2P3oool02NX:0?ooo`09jPX30?ooo`@02NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`0600WZ
2P3oool02NX:00WZ2P3oool02NX:0P3oool300WZ2P<0oooo0P09jPX01P3oool02NX:00WZ2P09jPX0
oooo00WZ2P80oooo0P09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0`09jPX20?ooo`03
00WZ2P3oool02NX:00<0oooo00@02NX:0?ooo`09jPX02NX:0`3oool200WZ2P80oooo00<02NX:0?oo
o`3oool02@3oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo01<0oooo0P09jPX30?ooo`802NX:0P3oool01009jPX0oooo0?ooo`3oool200WZ
2P<0oooo0P09jPX30?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:
00@02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3o
ool400WZ2P80oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool500WZ2P80oooo0P09jPX01`3oool0
2NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX70?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:
0?ooo`3oool00P3oool01009jPX0oooo0?ooo`3oool200WZ2P050?ooo`09jPX02NX:07moO`09jPX0
101oOgl200WZ2P0507moO`0000002NX:07moO`09jPX0101oOgl00`000000oooo0?ooo`020?ooo`03
00WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3oool02NX:1`3oool200WZ2P@0oooo1009jPX30?oo
o`0800WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`09jPX30?ooo`@02NX:00<0oooo00WZ2P3oool0
0`09jPX0103oool02NX:0?ooo`3oool200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX30?oo
o`<02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`802NX:00H0oooo00WZ2P3oool02NX:0?oo
o`09jPX20?ooo`<02NX:0P3oool200WZ2P@0oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`802NX:
00<0oooo00WZ2P3oool02`3oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo01<0oooo0P09jPX30?ooo`802NX:0P3oool01009jPX0oooo0?oo
o`3oool200WZ2P<0oooo0P09jPX30?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ
2P3oool02NX:00@02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`0300WZ2P3oool02NX:00802NX:
00<0oooo00WZ2P3oool01009jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo1@09jPX20?oo
o`0900WZ2P3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00<02NX:1P3oool00`09jPX0oooo
0?ooo`050?ooo`0300WZ2P3oool0oooo0080oooo00@02NX:0?ooo`3oool0oooo0P09jPX01@3oool0
2NX:00WZ2P1oOgl02NX:00@0Ogmo0P09jPX01@1oOgl0000000WZ2P1oOgl02NX:00@0Ogmo00<00000
0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`802NX:1`3oool01009jPX0oooo0?ooo`09
jPX30?ooo`@02NX:0`3oool02009jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0`3oool400WZ
2P080?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`802NX:00D0oooo00WZ2P3oool0
2NX:0?ooo`0200WZ2P<0oooo0`09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo0P09jPX02@3o
ool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo0P09jPX30?ooo`<02NX:
00<0oooo00WZ2P3oool00P3oool200WZ2P030?ooo`09jPX0oooo00/0oooo00<02NX:0?ooo`3oool0
1`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0C0?ooo`0300WZ2P3o
ool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0`3oool200WZ2P<0oooo
0P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P09jPX00`3oool02NX:
0?ooo`0400WZ2P<0oooo1009jPX20?ooo`D02NX:0P3oool01P09jPX0oooo00WZ2P3oool02NX:0?oo
o`D02NX:0P3oool02@09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`0300WZ2PH0oooo
00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`020?ooo`0600WZ2P3oool0oooo0?ooo`09
jPX0oooo0`09jPX00`1oOgl0000000WZ2P0307moO`802NX:00D0Ogmo00000009jPX0Ogmo00WZ2P04
07moO`030000003oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool200WZ2PL0oooo00@02NX:
0?ooo`3oool02NX:0`3oool400WZ2P<0oooo00P02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ
2P<0oooo1009jPX00`3oool02NX:0?ooo`0300WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00D0oooo
00WZ2P3oool02NX:0?ooo`0200WZ2P<0oooo0`09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo
0P09jPX02@3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo0P09jPX3
0?ooo`<02NX:00<0oooo00WZ2P3oool00P3oool200WZ2P030?ooo`09jPX0oooo00/0oooo00<02NX:
0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0C0?oo
o`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0`3oool2
00WZ2P@0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX30?ooo`@02NX:00<0oooo00WZ2P3oool0
1009jPX30?ooo`@02NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo00H02NX:0?ooo`09
jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00T02NX:0?ooo`09jPX02NX:0?oo
o`09jPX0oooo00WZ2P3oool00`09jPX60?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPX40?ooo`05
00WZ2P3oool0oooo00WZ2P3oool00`09jPX00`1oOgl0000000WZ2P0307moO`802NX:00D0Ogmo0000
0009jPX0Ogmo00WZ2P0407moO`030000003oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool2
00WZ2PL0oooo00@02NX:0?ooo`3oool02NX:0`3oool400WZ2P<0oooo00P02NX:0?ooo`3oool02NX:
0?ooo`09jPX0oooo00WZ2P<0oooo1@09jPX20?ooo`<02NX:00@0oooo00WZ2P3oool0oooo0P09jPX0
1@3oool02NX:00WZ2P09jPX0oooo00802NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:
00@0oooo00WZ2P3oool0oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo00P02NX:0?oo
o`09jPX02NX:0?ooo`09jPX0oooo00WZ2P<0oooo0`09jPX00`3oool02NX:0?ooo`020?ooo`0400WZ
2P3oool0oooo00WZ2P`0oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`0C0?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0
oooo00WZ2P040?ooo`0400WZ2P3oool0oooo0?ooo`802NX:103oool01P09jPX0oooo0?ooo`09jPX0
oooo00WZ2P<0oooo00T02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX30?oo
o`802NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool400WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:
00<0oooo00WZ2P3oool00P09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX20?oo
o`802NX:1`3oool00`09jPX0oooo0?ooo`040?ooo`802NX:103oool01@09jPX0oooo0?ooo`09jPX0
oooo00<02NX:00<0Ogmo00000009jPX00`1oOgl200WZ2P0507moO`0000002NX:07moO`09jPX0101o
Ogl00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo0P09jPX70?ooo`0400WZ2P3o
ool0oooo00WZ2P<0oooo1009jPX30?ooo`0800WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`09jPX3
0?ooo`0300WZ2P3oool02NX:00802NX:0P3oool300WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00D0
oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P04
0?ooo`09jPX0oooo0?ooo`802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`0800WZ2P3oool0
2NX:00WZ2P3oool02NX:0?ooo`09jPX30?ooo`@02NX:103oool01009jPX0oooo0?ooo`09jPX<0?oo
o`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool04`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`3o
ool0oooo0P09jPX20?ooo`802NX:103oool200WZ2P040?ooo`09jPX0oooo00WZ2P<0oooo00<02NX:
0?ooo`09jPX01@09jPX00`3oool02NX:00WZ2P030?ooo`802NX:00H0oooo00WZ2P09jPX0oooo00WZ
2P3oool400WZ2P80oooo00P02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:0P3oool0
1P09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:0P3oool200WZ2PL0oooo00<02NX:0?ooo`3oool0
103oool200WZ2P@0oooo00D02NX:0?ooo`3oool02NX:0?ooo`0300WZ2P0307moO`0000002NX:00<0
Ogmo0P09jPX01@1oOgl0000000WZ2P1oOgl02NX:00@0Ogmo00<000000?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`040?ooo`802NX:1`3oool01009jPX0oooo0?ooo`09jPX30?ooo`@02NX:0`3oool0
2009jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool200WZ2P040?ooo`09jPX02NX:00WZ
2P80oooo0`09jPX0103oool02NX:0?ooo`3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09
jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ
2P3oool00P09jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`802NX:00@0oooo00WZ2P3oool02NX:
0`3oool400WZ2P<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
1`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`802NX:0`3o
ool200WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo0080oooo
0P09jPX0103oool02NX:0?ooo`09jPX30?ooo`0300WZ2P3oool02NX:00D02NX:00<0oooo00WZ2P09
jPX00`3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX0oooo00@02NX:0P3oool01P09jPX0
oooo00WZ2P3oool02NX:0?ooo`@02NX:0P3oool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:
0P3oool200WZ2PL0oooo00<02NX:0?ooo`3oool0103oool200WZ2P@0oooo00D02NX:0?ooo`3oool0
2NX:0?ooo`0200WZ2P0407moO`09jPX0000000WZ2P<0Ogmo0P09jPX01@1oOgl0000000WZ2P1oOgl0
2NX:00@0Ogmo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`802NX:1`3oool0
1009jPX0oooo0?ooo`09jPX30?ooo`@02NX:0`3oool01@09jPX0oooo0?ooo`09jPX0oooo00<02NX:
0P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo0`09jPX0103oool02NX:0?ooo`3oool200WZ
2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool01009
jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00L0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:
0080oooo00<02NX:0?ooo`09jPX00`3oool400WZ2P<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo
00X0oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0D0?ooo`802NX:0`3oool200WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX30?oo
o`802NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P<0oooo00<02NX:0?ooo`09jPX00P09jPX0
103oool02NX:00WZ2P3oool200WZ2P<0oooo00<02NX:0?ooo`09jPX00P09jPX20?ooo`D02NX:0P3o
ool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`D02NX:00@0oooo00WZ2P3oool0oooo0P09jPX00`3o
ool02NX:00WZ2P020?ooo`0300WZ2P3oool02NX:00H0oooo00<02NX:0?ooo`3oool01@3oool00`09
jPX0oooo0?ooo`020?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX0101oOgl02NX:00000009
jPX307moO`802NX:00<0Ogmo00000009jPX00P1oOgl01@09jPX0Ogmo07moO`1oOgl0000000@0oooo
00<02NX:0?ooo`3oool0103oool200WZ2PL0oooo00@02NX:0?ooo`3oool02NX:0`3oool400WZ2P<0
oooo00D02NX:0?ooo`3oool02NX:0?ooo`0300WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09jPX2
0?ooo`<02NX:00@0oooo00WZ2P3oool0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:
0P3oool01`09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool00P09jPX01@3oool02NX:0?ooo`09jPX0
oooo00802NX:00L0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX0
0`3oool200WZ2P030?ooo`09jPX0oooo0080oooo0P09jPX00`3oool02NX:0?ooo`0<0?ooo`0300WZ
2P3oool0oooo00L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0503o
ool200WZ2P<0oooo0P09jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0`3oool200WZ2P<0oooo
0P09jPX20?ooo`802NX:0`3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX0oooo00@02NX:
0P3oool00`09jPX0oooo00WZ2P0200WZ2P80oooo1@09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09
jPX0oooo1@09jPX0103oool02NX:0?ooo`3oool200WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:
0?ooo`09jPX01P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo0080oooo00D02NX:
0?ooo`3oool02NX:0?ooo`0200WZ2P0407moO`09jPX0000000WZ2P<0Ogmo0P09jPX00`1oOgl00000
00WZ2P0207moO`0500WZ2P1oOgl0Ogmo07moO`000000103oool00`09jPX0oooo0?ooo`040?ooo`80
2NX:1`3oool01009jPX0oooo0?ooo`09jPX30?ooo`@02NX:0`3oool01@09jPX0oooo0?ooo`09jPX0
oooo00<02NX:0P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo0`09jPX0103oool02NX:0?oo
o`3oool200WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0`3oool01`09jPX0oooo00WZ2P09jPX0
oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo
00<02NX:0?ooo`09jPX00P3oool200WZ2P<0oooo0`09jPX00`3oool02NX:0?ooo`020?ooo`802NX:
00<0oooo00WZ2P3oool0303oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo01@0oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo00WZ
2P3oool02NX:00<0oooo0P09jPX30?ooo`802NX:0`3oool200WZ2P80oooo00<02NX:0?ooo`09jPX0
0P3oool00`09jPX0oooo0?ooo`0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX20?ooo`03
00WZ2P3oool02NX:00802NX:0P3oool500WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P020?oo
o`0600WZ2P3oool02NX:00WZ2P3oool02NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00<0
2NX:0?ooo`09jPX01P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo0080oooo00D0
2NX:0?ooo`3oool02NX:0?ooo`0200WZ2P0407moO`09jPX0000000WZ2P<0Ogmo0P09jPX00`1oOgl0
000000WZ2P0207moO`0500WZ2P1oOgl0Ogmo07moO`000000103oool00`09jPX0oooo0?ooo`040?oo
o`802NX:1`3oool01009jPX0oooo0?ooo`09jPX30?ooo`@02NX:0`3oool01@09jPX0oooo0?ooo`09
jPX0oooo00<02NX:0P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo0`09jPX0103oool02NX:
0?ooo`3oool200WZ2P030?ooo`09jPX02NX:00<02NX:0`3oool01`09jPX0oooo00WZ2P09jPX0oooo
00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:
0P3oool00`09jPX0oooo0?ooo`0200WZ2P<0oooo0`09jPX00`3oool02NX:0?ooo`020?ooo`802NX:
00<0oooo00WZ2P3oool0303oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo01@0oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo00WZ
2P3oool02NX:00<0oooo0P09jPX30?ooo`802NX:0`3oool200WZ2P80oooo00<02NX:0?ooo`09jPX0
0P3oool00`09jPX0oooo0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX20?ooo`03
00WZ2P3oool02NX:00802NX:0P3oool500WZ2P80oooo00<02NX:0?ooo`09jPX00`09jPX00`3oool0
2NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00@0oooo00WZ2P3oool0oooo0`09jPX6
0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool00P3oool01@09jPX0oooo0?ooo`09
jPX0oooo00802NX:00D0Ogmo00WZ2P000000Ogmo00WZ2P0207moO`802NX:00<0Ogmo00000009jPX0
0P1oOgl01@09jPX0Ogmo07moO`1oOgl0000000@0oooo00<02NX:0?ooo`3oool0103oool200WZ2PL0
oooo00@02NX:0?ooo`3oool02NX:0P3oool200WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:0P3o
ool00`09jPX0oooo0?ooo`0300WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`<02NX:
00@0oooo00WZ2P3oool0oooo0P09jPX00`3oool02NX:00WZ2P0300WZ2P<0oooo00L02NX:0?ooo`09
jPX02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX01P3oool02NX:0?ooo`09
jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX30?ooo`<02NX:00<0oooo00WZ2P3oool0
0P3oool01009jPX0oooo0?ooo`09jPX=0?ooo`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0503oool00`09jPX0oooo00WZ2P020?ooo`0500WZ
2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P<0oooo0P09jPX30?ooo`802NX:0P3oool00`09jPX0
oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00802NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080
oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`D02NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P03
0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool0oooo0`09jPX0103oool02NX:0?ooo`3oool3
00WZ2PH0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0
2NX:0?ooo`802NX:00D0Ogmo00WZ2P000000Ogmo00WZ2P0207moO`802NX:00<0Ogmo00000009jPX0
0P1oOgl01@09jPX0Ogmo07moO`1oOgl0000000@0oooo00<02NX:0?ooo`3oool0103oool200WZ2PL0
oooo00@02NX:0?ooo`3oool02NX:0P3oool200WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:0P3o
ool00`09jPX0oooo0?ooo`0300WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`<02NX:
00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`D02NX:0`3oool01`09jPX0oooo00WZ2P09jPX0oooo
00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:0080oooo00P02NX:
0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P<0oooo1009jPX40?ooo`0400WZ2P3oool0oooo00WZ
2Pd0oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0D0?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?oo
o`0400WZ2P3oool0oooo0?ooo`802NX:103oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P<0oooo
00@02NX:0?ooo`09jPX02NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?ooo`3o
ool00P09jPX30?ooo`@02NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P030?ooo`09jPX0oooo0080
2NX:00@0oooo00WZ2P3oool0oooo0`09jPX0103oool02NX:0?ooo`3oool300WZ2PH0oooo00<02NX:
0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool02NX:0?ooo`802NX:00D0
Ogmo00WZ2P000000Ogmo00WZ2P0207moO`802NX:00<0Ogmo00000009jPX00P1oOgl01@09jPX0Ogmo
07moO`1oOgl0000000@0oooo00<02NX:0?ooo`3oool0103oool200WZ2PL0oooo00@02NX:0?ooo`3o
ool02NX:0P3oool200WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo0?oo
o`0200WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX02NX:0P3oool300WZ2P030?oo
o`09jPX0oooo00802NX:0P3oool500WZ2P<0oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo
00802NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P020?ooo`0800WZ2P3oool0oooo
00WZ2P3oool02NX:0?ooo`09jPX30?ooo`@02NX:0`3oool200WZ2P80oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo01D0oooo0P09jPX30?ooo`802NX:0P3oool01009jPX0oooo0?ooo`3oool200WZ2P80oooo
0P09jPX40?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool00`09jPX0oooo00WZ2P0200WZ2P04
0?ooo`09jPX02NX:0?ooo`<02NX:0P3oool01009jPX0oooo00WZ2P09jPX30?ooo`@02NX:0P3oool0
0`09jPX0oooo00WZ2P0300WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool0oooo0`09
jPX0103oool02NX:0?ooo`3oool300WZ2PH0oooo00<02NX:0?ooo`3oool01@3oool200WZ2P@0oooo
00@02NX:0?ooo`09jPX0oooo0P09jPX01@1oOgl02NX:0000001oOgl02NX:0080Ogmo0P09jPX00`1o
Ogl0000000WZ2P0207moO`0500WZ2P1oOgl0Ogmo07moO`000000103oool00`09jPX0oooo0?ooo`04
0?ooo`802NX:1`3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`802NX:0P3oool200WZ2P0<0?oo
o`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX0103oool02NX:
00WZ2P09jPX20?ooo`@02NX:0P3oool200WZ2P80oooo1@09jPX20?ooo`0300WZ2P3oool0oooo0080
2NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:0080
oooo00P02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P<0oooo1009jPX30?ooo`802NX:0P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool000L0oooo00<000000?ooo`3oool05@3oool200WZ2P<0oooo0P09jPX20?ooo`0400WZ2P3oool0
oooo0?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`020?ooo`802NX:00@0oooo00WZ2P3oool02NX:
0`3oool00`09jPX0oooo0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:0P3oool01009jPX0
oooo00WZ2P09jPX30?ooo`0300WZ2P3oool02NX:00802NX:00<0oooo00WZ2P3oool01009jPX00`3o
ool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo0080oooo0P09jPX0203oool02NX:00WZ2P09jPX0
oooo00WZ2P3oool02NX:1@3oool00`09jPX0oooo0?ooo`050?ooo`802NX:103oool01009jPX0oooo
00WZ2P3oool200WZ2P0507moO`09jPX0000007moO`09jPX00P1oOgl200WZ2P0307moO`0000002NX:
0080Ogmo00D02NX:07moO`1oOgl0Ogmo000000040?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:
0?ooo`3oool01@3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`802NX:0P3oool200WZ2P0<0?oo
o`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX0103oool02NX:
00WZ2P09jPX20?ooo`@02NX:0P3oool200WZ2P80oooo1@09jPX20?ooo`0300WZ2P3oool0oooo0080
2NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool02009jPX0
oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0`3oool400WZ2P<0oooo0P09jPX00`3oool02NX:0?oo
o`0=0?ooo`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<00000
0?ooo`3oool05@3oool200WZ2P<0oooo0P09jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0`3o
ool200WZ2P<0oooo0P09jPX0103oool02NX:0?ooo`09jPX30?ooo`0300WZ2P3oool0oooo00802NX:
00@0oooo00WZ2P09jPX0oooo0`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo1@09jPX01@3o
ool02NX:0?ooo`09jPX0oooo00802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`0700WZ2P3o
ool0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00D0
oooo0P09jPX40?ooo`0400WZ2P3oool02NX:0?ooo`802NX:00D0Ogmo00WZ2P000000Ogmo00WZ2P02
07moO`802NX:00<0Ogmo00000009jPX00P1oOgl01@09jPX0Ogmo07moO`1oOgl0000000@0oooo00<0
2NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`050?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0
oooo0P09jPX20?ooo`802NX:00`0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo
00WZ2P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool2
00WZ2P80oooo1@09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo00WZ2P3oool00`09jPX2
0?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:103o
ool400WZ2P<0oooo0P09jPX00`3oool02NX:0?ooo`0=0?ooo`0300WZ2P3oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool05@3oool00`09jPX0oooo00WZ2P02
0?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P<0oooo0P09jPX30?ooo`802NX:00@0
oooo00WZ2P3oool02NX:0`3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00<02NX:0?ooo`09jPX0
0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool500WZ2P070?ooo`09jPX0oooo00WZ2P3o
ool02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool01009jPX0oooo00WZ2P3o
ool200WZ2P80oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPX40?ooo`0400WZ2P3o
ool02NX:0?ooo`802NX:00D0Ogmo00WZ2P000000Ogmo00WZ2P0207moO`802NX:00<0Ogmo00000009
jPX00`1oOgl00`09jPX0Ogmo07moO`050000000300WZ2P000000000000D0000000<02NX:00000000
00001@0000001P09jPX000000000000000002NX:000000802NX:0P00000200WZ2P0<00000009jPX0
00000?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:00WZ2P03
0?ooo`0400WZ2P3oool02NX:00WZ2P80oooo0P09jPX20?ooo`D02NX:0P3oool00`09jPX0oooo0?oo
o`0200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo
00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P<0oooo00<02NX:0?ooo`09jPX00P09jPX30?ooo`80
2NX:00<0oooo00WZ2P3oool03@3oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo01D0oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo
00WZ2P3oool02NX:00<0oooo0P09jPX30?ooo`802NX:0`3oool200WZ2P80oooo0P09jPX30?ooo`03
00WZ2P3oool0oooo00<02NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`0300WZ2P3oool0oooo0080
2NX:0`3oool400WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P050?ooo`09jPX0
2NX:0?ooo`09jPX00P3oool300WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX50?ooo`0300WZ2P3o
ool0oooo00D0oooo0P09jPX40?ooo`0;00WZ2P3oool02NX:00WZ2P3oool02NX:07moO`09jPX00000
07moO`09jPX00P1oOgl200WZ2P0307moO`0000002NX:00<0Ogmo00@02NX:07moO`1oOgl00000101o
Ogl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00H02NX:07moO`1oOgl0Ogmo
00WZ2P1oOgl200WZ2P80Ogmo0P09jPX0301oOgl02NX:07moO`0000002NX:00000009jPX0oooo00WZ
2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00`3oool01009jPX0oooo00WZ2P09jPX20?oo
o`802NX:0P3oool500WZ2P80oooo00<02NX:0?ooo`3oool01@09jPX00`3oool02NX:00WZ2P020?oo
o`0300WZ2P3oool0oooo00802NX:00@0oooo00WZ2P3oool0oooo0P09jPX00`3oool02NX:00WZ2P03
0?ooo`0300WZ2P3oool02NX:00802NX:0`3oool01009jPX0oooo0?ooo`09jPX>0?ooo`0300WZ2P3o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool05@3oool0
0`09jPX0oooo00WZ2P020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P<0oooo0P09
jPX30?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00<02NX:00<0
oooo00WZ2P09jPX00P09jPX0103oool02NX:0?ooo`09jPX20?ooo`802NX:0`3oool400WZ2P80oooo
00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool300WZ
2P030?ooo`09jPX02NX:0080oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPX01P3o
ool000000000000000002NX:000000802NX:00D0000000WZ2P09jPX02NX:0000000207moO`0700WZ
2P1oOgl02NX:00WZ2P1oOgl0000000WZ2P0307moO`0400WZ2P1oOgl0Ogmo000000@0Ogmo00<02NX:
07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0407moO`0400000009jPX0Ogmo07moO`802NX:00<0
000000WZ2P09jPX00P00000200WZ2P0<00000009jPX0Ogmo00000009jPX0Ogmo00WZ2P3oool02NX:
0?ooo`09jPX0oooo0P09jPX20?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo0P09jPX20?ooo`80
2NX:0P3oool500WZ2P80oooo00<02NX:0?ooo`3oool01@09jPX00`3oool02NX:00WZ2P020?ooo`03
00WZ2P3oool0oooo00802NX:00@0oooo00WZ2P3oool0oooo0`09jPX00`3oool02NX:0?ooo`020?oo
o`0400WZ2P3oool02NX:00WZ2P<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:
0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0E0?oo
o`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P040?ooo`0400WZ2P3oool0
oooo0?ooo`802NX:0`3oool200WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?oo
o`0300WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00@0oooo00WZ2P3oool0oooo0P09jPX30?ooo`03
00WZ2P3oool02NX:00802NX:00<0oooo00WZ2P3oool00P09jPX01@3oool02NX:00WZ2P09jPX0oooo
00802NX:00@0oooo00WZ2P3oool0oooo0`09jPX00`3oool02NX:00WZ2P020?ooo`802NX:1@3oool0
0`09jPX0000000000005000000802NX:00H0000007moO`1oOgl0Ogmo00WZ2P1oOgl200WZ2P0507mo
O`09jPX02NX:00WZ2P0000000P1oOgl01`09jPX0Ogmo00WZ2P09jPX0Ogmo00000009jPX00`1oOgl0
1009jPX0Ogmo07moO`00000307moO`0300000009jPX0Ogmo00D0Ogmo00<0000000WZ2P0000001@1o
Ogl0100000002NX:07moO`1oOgl200WZ2PD000000P09jPX200000080Ogmo00T02NX:07moO`09jPX0
oooo00WZ2P3oool02NX:0?ooo`09jPX00`3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`802NX:
0P3oool300WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool00`09jPX0oooo0?ooo`0500WZ2P03
0?ooo`09jPX02NX:0080oooo00<02NX:0?ooo`3oool00P09jPX0103oool02NX:0?ooo`3oool300WZ
2P030?ooo`09jPX0oooo0080oooo00@02NX:0?ooo`09jPX02NX:0`3oool200WZ2P80oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00070?oo
o`030000003oool0oooo01H0oooo0P09jPX30?ooo`802NX:0P3oool01009jPX0oooo0?ooo`3oool2
00WZ2P80oooo0P09jPX40?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo
0?ooo`0300WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00@0oooo00WZ2P3oool0oooo0P09jPX30?oo
o`0300WZ2P3oool02NX:00802NX:00<0oooo00WZ2P3oool01P09jPX01@3oool02NX:00WZ2P3oool0
2NX:0080oooo0`09jPX01@3oool02NX:00WZ2P3oool0000000802NX:1@0000000`09jPX0Ogmo07mo
O`0507moO`0300WZ2P1oOgl02NX:00@0Ogmo0`09jPX01@1oOgl02NX:00WZ2P09jPX000000080Ogmo
00L02NX:07moO`09jPX02NX:07moO`0000002NX:0080Ogmo00X0000000WZ2P1oOgl0Ogmo0000001o
Ogl0000000WZ2P0000002NX:1P1oOgl00`0000002NX:0000000607moO`0300WZ2P1oOgl0Ogmo0080
2NX:00<0Ogmo00WZ2P09jPX00P1oOgl200WZ2P0:07moO`09jPX0Ogmo07moO`09jPX0Ogmo00WZ2P3o
ool02NX:0?ooo`<02NX:0`3oool200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool300WZ2P03
0?ooo`09jPX02NX:00802NX:0`3oool00`09jPX0oooo00WZ2P0500WZ2P030?ooo`09jPX02NX:0080
oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`0300WZ2P030?ooo`09jPX0oooo
0080oooo00@02NX:0?ooo`09jPX02NX:0`3oool200WZ2P030?ooo`09jPX0oooo00d0oooo00<02NX:
0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0F0?oo
o`802NX:0`3oool200WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX20?ooo`802NX:103oool2
00WZ2P040?ooo`09jPX0oooo00WZ2P<0oooo00<02NX:0?ooo`09jPX00P09jPX20?ooo`0300WZ2P3o
ool02NX:00802NX:00@0oooo00WZ2P3oool0oooo0P09jPX30?ooo`0300WZ2P3oool02NX:00802NX:
00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00L02NX:0`3oool00`09jPX0000000WZ2P0200WZ
2P030000001oOgl0Ogmo00802NX:101oOgl00`09jPX0Ogmo07moO`0507moO`0300WZ2P1oOgl02NX:
00@0Ogmo00D02NX:00000009jPX0Ogmo0000000200WZ2P050000001oOgl0000000WZ2P1oOgl00P09
jPX00`1oOgl0000000WZ2P0207moO`0:00000009jPX0Ogmo07moO`000000Ogmo00000009jPX0Ogmo
00WZ2PL0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo07moO`0500WZ2P80Ogmo1009jPX2
07moO`0600WZ2P1oOgl02NX:0?ooo`09jPX0oooo0`09jPX30?ooo`802NX:0P3oool01009jPX0oooo
00WZ2P09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX30?ooo`0300WZ2P3oool02NX:00D0
2NX:00<0oooo00WZ2P09jPX00P3oool01009jPX0oooo0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:
0?ooo`802NX:00<0oooo00WZ2P3oool00P3oool400WZ2P<0oooo0P09jPX00`3oool02NX:0?ooo`0=
0?ooo`0300WZ2P3oool0oooo00P0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool05P3oool200WZ2P<0oooo0P09jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0`3oool0
0`09jPX0oooo0?ooo`020?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool00`09jPX0oooo00WZ
2P0300WZ2P030?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P3oool0oooo0P09jPX30?ooo`0300WZ
2P3oool02NX:00802NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00L02NX:00D0oooo0000
000000002NX:07moO`0300WZ2P<0Ogmo0P09jPX407moO`0300WZ2P000000Ogmo00@0Ogmo00@00000
00WZ2P0000002NX:101oOgl01P09jPX0000000WZ2P1oOgl0000000WZ2P80000000@0Ogmo00000009
jPX0Ogmo0P09jPX00`1oOgl0000000WZ2P0307moO`0400WZ2P1oOgl0Ogmo00000080Ogmo00<02NX:
07moO`09jPX01`1oOgl200WZ2PH0Ogmo00<02NX:07moO`1oOgl01@09jPX207moO`0<00WZ2P000000
2NX:00WZ2P1oOgl0000000WZ2P0000002NX:0?ooo`09jPX0oooo0`09jPX30?ooo`802NX:0P3oool4
00WZ2P80oooo0`09jPX00`3oool02NX:0?ooo`0200WZ2P<0oooo00<02NX:0?ooo`09jPX01@09jPX0
0`3oool02NX:00WZ2P020?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX0oooo
0P09jPX00`3oool02NX:0?ooo`020?ooo`@02NX:0`3oool200WZ2P030?ooo`09jPX0oooo00d0oooo
00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0F0?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:
0`3oool200WZ2P<0oooo0P09jPX0103oool02NX:0?ooo`09jPX30?ooo`0300WZ2P3oool02NX:00<0
2NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P020?ooo`802NX:0`3oool500WZ2P07
0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P0<0?ooo`09jPX0000000WZ2P000000Ogmo
00000009jPX0000000WZ2P0000002NX:0P1oOgl20000000300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:
0000001oOgl0101oOgl30000000300WZ2P1oOgl0Ogmo0080Ogmo00@02NX:00000009jPX0Ogmo0P09
jPX200000080Ogmo00L02NX:07moO`09jPX02NX:07moO`0000002NX:00<0Ogmo00@02NX:07moO`1o
Ogl000000P1oOgl00`09jPX0Ogmo00WZ2P0707moO`802NX:1@1oOgl00`0000002NX:07moO`030000
00<02NX:00@0Ogmo00000009jPX000000P09jPX00`1oOgl00000000000020000000300WZ2P3oool0
oooo00<02NX:0`3oool200WZ2P80oooo1009jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0
oooo0P09jPX30?ooo`0300WZ2P3oool02NX:00D02NX:00<0oooo00WZ2P3oool00P3oool01009jPX0
oooo0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:0`3oool00`09jPX0oooo00WZ2P02
00WZ2P<0oooo0P09jPX00`3oool02NX:0?ooo`0=0?ooo`0300WZ2P3oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool05P3oool00`09jPX0oooo00WZ2P020?oo
o`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P<0oooo0P09jPX30?ooo`802NX:00@0oooo
00WZ2P3oool02NX:0`3oool00`09jPX0oooo0?ooo`0300WZ2P030?ooo`09jPX0oooo00@02NX:00<0
oooo00WZ2P3oool00P09jPX30?ooo`802NX:00X0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?oo
o`09jPX0oooo0`09jPX0103oool02NX:00000009jPX207moO`0400000009jPX0000000WZ2P800000
0P1oOgl20000000300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl01@1oOgl00`09jPX0Ogmo
00WZ2P0407moO`0400WZ2P0000002NX:07moO`<02NX:00D0000007moO`1oOgl02NX:07moO`0200WZ
2P0307moO`0000002NX:00<0Ogmo00D02NX:07moO`1oOgl0000007moO`030000000300WZ2P1oOgl0
Ogmo00@0Ogmo0P0000000`09jPX0Ogmo07moO`0307moO`80000000D0Ogmo000000000000000000WZ
2P020000000407moO`0000002NX:000000802NX:0P1oOgl01009jPX0Ogmo00WZ2P09jPX20?ooo`<0
2NX:0`3oool200WZ2P80oooo1009jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09
jPX20?ooo`0300WZ2P3oool0oooo00H02NX:00<0oooo00WZ2P3oool00P3oool01009jPX0oooo0?oo
o`09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:0`3oool00`09jPX0oooo00WZ2P0200WZ2P<0
oooo00@02NX:0?ooo`3oool02NX:3P3oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo01H0oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0
oooo00WZ2P3oool02NX:00<0oooo0P09jPX30?ooo`802NX:0`3oool200WZ2P80oooo0P09jPX30?oo
o`0300WZ2P3oool0oooo00<02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:0?ooo`0200WZ
2P<0oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00`09jPX0
103oool02NX:00WZ2P09jPX307moO`0400WZ2P1oOgl02NX:00WZ2P@0Ogmo0P09jPX407moO`0300WZ
2P1oOgl0Ogmo00D0Ogmo00@02NX:07moO`1oOgl02NX:0`1oOgl300WZ2P0507moO`09jPX02NX:00WZ
2P0000000P1oOgl2000000802NX:00<0Ogmo00000009jPX00`1oOgl02@09jPX0000007moO`000000
Ogmo00000009jPX0000000WZ2P0607moO`80000000<02NX:07moO`1oOgl0101oOgl00`09jPX0Ogmo
07moO`0500WZ2P80Ogmo1009jPX0101oOgl02NX:07moO`1oOgl200WZ2P80oooo0`09jPX30?ooo`80
2NX:0P3oool300WZ2P80oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:0P3oool00`09
jPX0oooo0?ooo`0500WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`0300WZ2P3oool02NX:
0080oooo00<02NX:0?ooo`09jPX00P09jPX30?ooo`0300WZ2P3oool02NX:00802NX:0P3oool200WZ
2P80oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo01L0oooo0P09jPX20?ooo`0500WZ2P3oool02NX:0?oo
o`09jPX00`3oool200WZ2P<0oooo0P09jPX30?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P020?oo
o`0300WZ2P3oool0oooo00X02NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`802NX:00<0oooo
00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:00WZ2P<0Ogmo0P09
jPX00`1oOgl02NX:07moO`0407moO`802NX:101oOgl00`09jPX0Ogmo07moO`0407moO`0400WZ2P1o
Ogl00000000000@0Ogmo0P09jPX01@1oOgl0000000WZ2P09jPX000000080Ogmo00D02NX:00000009
jPX02NX:07moO`02000000<0Ogmo00@02NX:0000001oOgl000000P1oOgl00`09jPX0Ogmo00WZ2P07
07moO`802NX:1P1oOgl01@09jPX0Ogmo07moO`09jPX0Ogmo00<02NX:0P1oOgl400WZ2P0407moO`09
jPX0Ogmo07moO`802NX:0P3oool300WZ2P<0oooo0P09jPX20?ooo`<02NX:0P3oool200WZ2P050?oo
o`09jPX0oooo00WZ2P3oool00P09jPX20?ooo`0300WZ2P3oool0oooo00<02NX:00D0oooo00WZ2P3o
ool0oooo00WZ2P020?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0500WZ2P3oool02NX:
0?ooo`09jPX00`3oool00`09jPX0oooo00WZ2P0200WZ2P80oooo0P09jPX20?ooo`0300WZ2P3oool0
oooo00`0oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0G0?ooo`802NX:0`3oool200WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P03
0?ooo`802NX:0`3oool200WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0:
00WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0`3oool00`09jPX0oooo00WZ2P0300WZ2P030?ooo`09
jPX0oooo00802NX:00<0oooo00WZ2P3oool01009jPX307moO`802NX:00<0Ogmo00WZ2P1oOgl00`1o
Ogl3000000<0Ogmo00<0000000WZ2P1oOgl0101oOgl01@0000002NX:07moO`0000002NX:00@0Ogmo
0P09jPX00`1oOgl0000000WZ2P0200000080Ogmo00L02NX:07moO`09jPX02NX:07moO`0000002NX:
00<0Ogmo00@02NX:07moO`1oOgl000000P1oOgl00`09jPX0Ogmo00WZ2P0707moO`802NX:1P1oOgl0
1@09jPX0Ogmo07moO`09jPX0Ogmo00<02NX:0P1oOgl02009jPX0000000000009jPX0000000WZ2P1o
Ogl000000P09jPX20?ooo`<02NX:0`3oool200WZ2P80oooo0`09jPX20?ooo`802NX:00D0oooo00WZ
2P3oool02NX:0?ooo`0200WZ2P80oooo00<02NX:0?ooo`3oool00`09jPX01@3oool02NX:0?ooo`3o
ool02NX:0080oooo0P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo
00WZ2P030?ooo`0300WZ2P3oool02NX:00802NX:0P3oool200WZ2P030?ooo`09jPX0oooo00h0oooo
00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0G0?ooo`802NX:0`3oool200WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX20?ooo`802NX:
103oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool01009jPX01@3o
ool02NX:00WZ2P09jPX0oooo00<02NX:0P3oool200WZ2P<0oooo1P09jPX00`3oool02NX:0?ooo`02
00WZ2P030?ooo`09jPX0oooo00@02NX:00P0000007moO`000000000000WZ2P0000002NX:000000<0
Ogmo0P0000001009jPX0Ogmo07moO`1oOgl2000000D0Ogmo0P00000207moO`0500WZ2P1oOgl0Ogmo
07moO`0000000P09jPX01@1oOgl02NX:00WZ2P09jPX000000080Ogmo00L02NX:07moO`09jPX02NX:
07moO`0000002NX:00@0Ogmo00H02NX:07moO`000000Ogmo00WZ2P1oOgl200WZ2PL0Ogmo0P000004
07moO`0700000009jPX02NX:07moO`0000002NX:0000000300WZ2P80Ogmo00@02NX:00000009jPX0
2NX:0P000000101oOgl0000000000009jPX20?ooo`<02NX:0`3oool200WZ2P030?ooo`09jPX0oooo
00802NX:0P3oool200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00`09jPX0103oool02NX:0?ooo`3o
ool300WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00P3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09
jPX00P3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo00@02NX:0?ooo`09jPX02NX:0`3oool2
00WZ2P030?ooo`09jPX0oooo00h0oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`0G0?ooo`0300WZ2P3oool02NX:0080oooo0P09jPX20?oo
o`0400WZ2P3oool0oooo0?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`020?ooo`0600WZ2P3oool0
oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo0?ooo`0400WZ2P050?ooo`09jPX0oooo00WZ2P3o
ool00`09jPX20?ooo`802NX:0`3oool200WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`02
00WZ2P030?ooo`09jPX0oooo00@02NX:00P0000007moO`000000000000WZ2P0000002NX:000000@0
Ogmo0P09jPX407moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00@02NX:07moO`1oOgl02NX:0`1oOgl02000
00002NX:07moO`1oOgl02NX:07moO`09jPX000000`1oOgl300WZ2P0307moO`0000002NX:00@0Ogmo
00H02NX:07moO`000000Ogmo00WZ2P00000200WZ2PH0Ogmo0P0000000`09jPX0Ogmo07moO`0207mo
O`0400000009jPX0000007moO`<0000000<02NX:0000000000000P1oOgl01P09jPX0000000WZ2P09
jPX0Ogmo00WZ2P80oooo0P09jPX20?ooo`<02NX:0`3oool200WZ2P030?ooo`09jPX0oooo00802NX:
0P3oool200WZ2P0:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0`09
jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo0P09jPX01`3oool02NX:00WZ2P3oool02NX:0?oo
o`09jPX00P3oool00`09jPX0oooo00WZ2P030?ooo`802NX:00<0oooo00WZ2P3oool00P3oool200WZ
2P030?ooo`09jPX0oooo00h0oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0G0?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09
jPX0oooo00WZ2P030?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`020?ooo`802NX:00@0oooo00WZ
2P3oool02NX:0`3oool00`09jPX0oooo00WZ2P0300WZ2P030?ooo`09jPX02NX:00D02NX:0P3oool2
00WZ2P<0oooo0P09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:
0?ooo`0400WZ2P<0Ogmo0P09jPX00`1oOgl02NX:07moO`0407moO`802NX:101oOgl00`09jPX0Ogmo
07moO`0407moO`0400WZ2P1oOgl0Ogmo00WZ2P@0Ogmo00L02NX:07moO`1oOgl02NX:07moO`09jPX0
00000080Ogmo0P00000200WZ2P0307moO`0000002NX:00<0Ogmo00T0000000WZ2P1oOgl0000007mo
O`09jPX0000000WZ2P0000001P1oOgl20000000300WZ2P1oOgl0Ogmo00<0Ogmo0P09jPX207moO`03
00WZ2P1oOgl02NX:00802NX:0P1oOgl400WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool300WZ
2P80oooo0`09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo0P09jPX03@3oool02NX:0?ooo`09jPX0
oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX01@3oool02NX:0?ooo`3oool0
2NX:0080oooo0P09jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool00`09jPX0oooo
00WZ2P020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P030?ooo`09jPX0oooo00h0
oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`0G0?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`80
2NX:0`3oool200WZ2P<0oooo0P09jPX0103oool02NX:0?ooo`09jPX30?ooo`0500WZ2P3oool02NX:
00WZ2P3oool02@09jPX20?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX02NX:00<02NX:00H0oooo
00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0Ogmo0080Ogmo00<02NX:07moO`09jPX0
0P09jPX407moO`0300WZ2P1oOgl02NX:00<0Ogmo00<02NX:07moO`1oOgl00`1oOgl0100000002NX:
07moO`1oOgl200000080Ogmo00P0000000WZ2P09jPX0Ogmo00WZ2P0000002NX:00000080Ogmo00D0
000000WZ2P000000000007moO`02000000<0Ogmo00L0000000WZ2P1oOgl0000007moO`09jPX0Ogmo
00802NX:1`1oOgl200WZ2PD0Ogmo0P09jPX207moO`0300WZ2P1oOgl02NX:00802NX:0P3oool400WZ
2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool300WZ2P80oooo0`09jPX00`3oool02NX:0?ooo`02
00WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`0300WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:
0?ooo`0200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00P3oool200WZ2P070?ooo`09jPX02NX:0?oo
o`09jPX0oooo00WZ2P020?ooo`802NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo00@0
2NX:0?ooo`3oool02NX:3`3oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo01L0oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo00WZ
2P3oool02NX:00<0oooo0P09jPX30?ooo`802NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P<0
oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0700WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:0P3oool2
00WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:0?oo
o`0200WZ2P80Ogmo00<02NX:07moO`09jPX00P09jPX30000000307moO`09jPX02NX:00802NX:00@0
Ogmo00000009jPX02NX:0P1oOgl0200000002NX:00000009jPX0000007moO`09jPX000000P1oOgl0
1@0000002NX:00WZ2P1oOgl02NX:00<000000`1oOgl300WZ2P0307moO`0000002NX:00@0Ogmo00H0
2NX:07moO`000000Ogmo00WZ2P1oOgl200WZ2PL0Ogmo0P09jPX507moO`802NX:0P3oool00`09jPX0
oooo00WZ2P0200WZ2P80oooo1009jPX0103oool02NX:0?ooo`3oool200WZ2P<0oooo0P09jPX20?oo
o`<02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`802NX:00<0oooo00WZ2P3oool00`09jPX01`3o
ool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo0P09
jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P<0oooo00D02NX:0?ooo`09
jPX0oooo00WZ2P020?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo
00P0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0603oool200WZ2P80
oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0`3oool200WZ2P<0oooo0P09jPX0103o
ool02NX:0?ooo`09jPX30?ooo`0300WZ2P3oool0oooo00P02NX:00<0oooo00WZ2P09jPX00P3oool3
00WZ2P80oooo00<02NX:0?ooo`09jPX01009jPX0103oool02NX:00WZ2P3oool300WZ2P030?ooo`09
jPX0000000802NX:00@0Ogmo00000009jPX000000P09jPX2000000802NX:00<0Ogmo00WZ2P09jPX0
0P09jPX0101oOgl0000000000009jPX207moO`0700000009jPX0Ogmo00WZ2P000000Ogmo00WZ2P04
07moO`0700000009jPX0Ogmo00WZ2P1oOgl02NX:0000000307moO`<02NX:00<0Ogmo00000009jPX0
101oOgl01P09jPX0Ogmo0000001oOgl02NX:07moO`802NX:101oOgl30?ooo`802NX:1@3oool200WZ
2P80oooo00<02NX:0?ooo`09jPX00P09jPX20?ooo`@02NX:00@0oooo00WZ2P3oool0oooo0P09jPX3
0?ooo`802NX:0P3oool300WZ2P030?ooo`09jPX0oooo00<02NX:00H0oooo00WZ2P09jPX0oooo00WZ
2P3oool300WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo
00802NX:0P3oool200WZ2P070?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`802NX:0`3o
ool00`09jPX0oooo00WZ2P0200WZ2P80oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00d0oooo00<0
2NX:0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0H
0?ooo`802NX:0`3oool200WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX30?ooo`802NX:0`3oool2
00WZ2P80oooo0P09jPX30?ooo`0300WZ2P3oool0oooo00P02NX:00<0oooo00WZ2P09jPX00P3oool3
00WZ2P80oooo00<02NX:0?ooo`09jPX01009jPX00`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX0
000000802NX:00@0Ogmo00000000000000000P09jPX01@000000Ogmo00WZ2P09jPX0Ogmo00@02NX:
0P1oOgl200WZ2P<0Ogmo00<02NX:07moO`09jPX00P1oOgl00`09jPX0Ogmo07moO`0207moO`070000
0009jPX0Ogmo00WZ2P1oOgl02NX:0000000307moO`<02NX:00<0Ogmo00000009jPX0101oOgl01P09
jPX0Ogmo0000003oool02NX:0?ooo`802NX:1`3oool200WZ2PD0oooo0P09jPX20?ooo`0300WZ2P3o
ool02NX:00802NX:0P3oool400WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0`3oool01009jPX0oooo
0?ooo`3oool300WZ2P030?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P3oool0oooo0P09jPX0103o
ool02NX:00WZ2P3oool200WZ2P80oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00802NX:
00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P80oooo00<02NX:0?ooo`09jPX00P09jPX30?ooo`03
00WZ2P3oool02NX:00802NX:0P3oool200WZ2P030?ooo`09jPX0oooo00l0oooo00<02NX:0?ooo`3o
ool0203oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0H0?ooo`802NX:
0`3oool200WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX20?ooo`802NX:0`3oool200WZ2P80
oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2P040?ooo`09jPX02NX:0?oo
o`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P80oooo00<02NX:0?ooo`09jPX00P09jPX0
1@3oool02NX:0?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0300WZ2P3o
ool02NX:00802NX:00@0Ogmo00WZ2P09jPX0Ogmo1009jPX207moO`802NX:0`1oOgl00`09jPX0Ogmo
00WZ2P0207moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P09jPX01@1oOgl02NX:07moO`09jPX0000000<0
Ogmo0`09jPX00`1oOgl0000000WZ2P0407moO`0500WZ2P1oOgl000000?ooo`09jPX00P3oool00`09
jPX0oooo0?ooo`050?ooo`0300WZ2P3oool02NX:00@0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo
00802NX:0P3oool400WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool200WZ2P<0oooo0`09jPX0
0`3oool02NX:0?ooo`0500WZ2P80oooo0P09jPX0103oool02NX:00WZ2P3oool200WZ2P80oooo00<0
2NX:0?ooo`09jPX00`09jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0`09jPX20?oo
o`0300WZ2P3oool02NX:00802NX:0`3oool00`09jPX0oooo00WZ2P0200WZ2P80oooo0P09jPX00`3o
ool02NX:0?ooo`0?0?ooo`0300WZ2P3oool0oooo00P0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0603oool00`09jPX0oooo00WZ2P020?ooo`802NX:0P3oool01009jPX0
oooo0?ooo`3oool200WZ2P80oooo0P09jPX40?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:0P3o
ool00`09jPX0oooo0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool01@09jPX00`3oool02NX:0?ooo`0200WZ
2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX20?ooo`0300WZ2P3oool02NX:00802NX:00<0oooo
00WZ2P09jPX00P3oool400WZ2P040?ooo`09jPX02NX:00WZ2P80oooo1009jPX20?ooo`0400WZ2P3o
ool0oooo0?ooo`802NX:00D0oooo00WZ2P1oOgl02NX:0000000407moO`802NX:00<0Ogmo00000009
jPX01@1oOgl01009jPX000000?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?oo
o`09jPX0103oool200WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`<02NX:00L0oooo00WZ
2P09jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPX30?ooo`<02NX:00<0oooo00WZ2P3oool01@09
jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool01@09jPX0oooo0?ooo`09jPX0oooo00@02NX:
00P0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`<02NX:0P3oool00`09jPX0oooo00WZ2P02
00WZ2P<0oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`802NX:00<0oooo00WZ2P3oool03`3oool0
0`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
01P0oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX3
0?ooo`0300WZ2P3oool0oooo0080oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX20?ooo`0300WZ
2P3oool0oooo00802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0103oool02NX:0?ooo`09jPX20?oo
o`0600WZ2P3oool02NX:0?ooo`09jPX0oooo1@09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:
00<0oooo00WZ2P3oool00`09jPX0103oool02NX:0?ooo`3oool200WZ2P050?ooo`09jPX02NX:00WZ
2P3oool01009jPX0103oool02NX:00WZ2P09jPX20?ooo`@02NX:0P3oool00`09jPX0oooo0?ooo`05
00WZ2P0307moO`09jPX0000000@0Ogmo0P09jPX00`1oOgl0000000WZ2P0507moO`0400WZ2P000000
oooo00WZ2P80oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo00WZ2P040?ooo`802NX:0P3o
ool00`09jPX0oooo0?ooo`0200WZ2P<0oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo
00WZ2P020?ooo`802NX:0`3oool300WZ2P030?ooo`09jPX0oooo00D02NX:0P3oool200WZ2P030?oo
o`09jPX02NX:0080oooo00D02NX:0?ooo`3oool02NX:0?ooo`0300WZ2P070?ooo`09jPX02NX:00WZ
2P3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool300WZ2P<0oooo0P09
jPX00`3oool02NX:00WZ2P020?ooo`802NX:00<0oooo00WZ2P3oool03`3oool00`09jPX0oooo0?oo
o`080?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01P0oooo00<02NX:
0?ooo`09jPX00P3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX30?ooo`0300WZ2P3o
ool0oooo0080oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:
00<0oooo00WZ2P09jPX00`09jPX20?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:0080
oooo1009jPX01@3oool02NX:0?ooo`09jPX0oooo00P02NX:00@0oooo00WZ2P3oool0oooo0P09jPX0
1@3oool02NX:00WZ2P09jPX0oooo00@02NX:00@0oooo00WZ2P09jPX02NX:0P3oool400WZ2P80oooo
00<02NX:0?ooo`3oool01@09jPX00`1oOgl02NX:0000000407moO`802NX:00<0Ogmo00000009jPX0
1@1oOgl01009jPX000000?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`09
jPX0103oool200WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX30?ooo`0400WZ2P3oool02NX:00WZ
2P80oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P<0oooo0`09jPX01@3oool02NX:0?ooo`09jPX0
oooo00<02NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00D02NX:0?ooo`3oool02NX:0?oo
o`0300WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:0?oo
o`09jPX00P3oool200WZ2P<0oooo00@02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`0400WZ2P3oool0
oooo00WZ2Q00oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0H0?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo00WZ
2P030?ooo`802NX:0`3oool200WZ2P<0oooo0P09jPX0103oool02NX:0?ooo`09jPX30?ooo`0400WZ
2P3oool02NX:00WZ2P80oooo1009jPX20?ooo`802NX:0P3oool300WZ2P80oooo00@02NX:0?ooo`09
jPX0oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09jPX0
103oool02NX:0?ooo`3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX0103oool02NX:
00WZ2P09jPX20?ooo`@02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P060?ooo`09jPX02NX:07mo
O`09jPX00000101oOgl200WZ2P0307moO`0000002NX:00D0Ogmo00@02NX:0000003oool02NX:0P3o
ool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool02NX:00@0oooo0P09jPX20?ooo`0300WZ2P3o
ool0oooo00802NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX30?ooo`802NX:0`3o
ool300WZ2P050?ooo`09jPX0oooo00WZ2P3oool00`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX0
0P3oool01@09jPX0oooo0?ooo`09jPX0oooo00<02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0
oooo00802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`802NX:0`3oool01009jPX0oooo00WZ
2P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo
0?ooo`080?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01T0oooo0P09
jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P<0oooo0P09jPX30?ooo`802NX:
00@0oooo00WZ2P3oool02NX:0`3oool01009jPX0oooo00WZ2P09jPX20?ooo`802NX:00@0oooo00WZ
2P09jPX0oooo0P09jPX20?ooo`<02NX:0P3oool01009jPX0oooo00WZ2P3oool400WZ2P030?ooo`09
jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09jPX0103oool02NX:0?ooo`3oool200WZ2P050?oo
o`09jPX02NX:00WZ2P3oool01009jPX0103oool02NX:00WZ2P09jPX20?ooo`@02NX:0P3oool00`09
jPX0oooo0?ooo`0200WZ2P060?ooo`09jPX02NX:07moO`09jPX00000101oOgl200WZ2P0307moO`00
00002NX:00D0Ogmo00@02NX:0000003oool02NX:0P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ
2P3oool02NX:00@0oooo0P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo0P09jPX00`3oool0
2NX:00WZ2P020?ooo`802NX:0`3oool200WZ2P<0oooo0`09jPX01@3oool02NX:0?ooo`09jPX0oooo
00<02NX:0P3oool200WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?ooo`09jPX00P3oool300WZ
2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0
0P3oool200WZ2P<0oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ
2P3oool03`3oool00`09jPX0oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo01T0oooo0P09jPX30?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P<0
oooo0P09jPX30?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool01009jPX0oooo00WZ2P09jPX2
0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`802NX:00D0oooo00WZ2P3oool02NX:
0?ooo`0600WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09jPX0103oool02NX:
0?ooo`3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX0103oool02NX:00WZ2P09jPX2
0?ooo`@02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P060?ooo`09jPX02NX:07moO`09jPX00000
101oOgl200WZ2P0307moO`0000002NX:00D0Ogmo00@02NX:0000003oool02NX:0P3oool00`09jPX0
oooo0?ooo`050?ooo`0300WZ2P3oool02NX:00@0oooo0P09jPX0103oool02NX:0?ooo`3oool200WZ
2P<0oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`802NX:0`3oool200WZ2P<0oooo1009jPX20?oo
o`0300WZ2P3oool02NX:00802NX:0P3oool200WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?oo
o`09jPX00P3oool300WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P050?ooo`09
jPX02NX:0?ooo`09jPX00P3oool200WZ2P<0oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo
00802NX:00<0oooo00WZ2P3oool03`3oool00`09jPX0oooo0?ooo`090?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo01T0oooo0P09jPX30?ooo`802NX:0P3oool01@09jPX0
oooo0?ooo`3oool02NX:00<0oooo0P09jPX30?ooo`802NX:0P3oool200WZ2P<0oooo00@02NX:0?oo
o`09jPX02NX:0P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00P0oooo00WZ2P09jPX0oooo
00WZ2P3oool02NX:0?ooo`H02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0400WZ
2P80oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00`0oooo00WZ2P09jPX02NX:0?oo
o`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09
jPX00`1oOgl02NX:0000000407moO`802NX:00<0Ogmo00000009jPX01@1oOgl01009jPX000000?oo
o`09jPX20?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`09jPX0103oool200WZ2P040?oo
o`09jPX0oooo0?ooo`802NX:0`3oool200WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX30?ooo`80
2NX:0`3oool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:00802NX:0P3oool400WZ
2P<0oooo00<02NX:0?ooo`09jPX00P3oool300WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?oo
o`0200WZ2P090?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:00<0oooo00L02NX:0?oo
o`09jPX02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool03`3oool00`09jPX0oooo0?oo
o`090?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01T0oooo00<02NX:
0?ooo`09jPX00P3oool200WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX20?ooo`802NX:0`3o
ool200WZ2P80oooo0P09jPX30?ooo`0300WZ2P3oool0oooo00802NX:00@0oooo00WZ2P09jPX0oooo
0P09jPX20?ooo`802NX:00L0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0080oooo1@09jPX01P3o
ool02NX:0?ooo`3oool02NX:0?ooo`802NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`d0
2NX:00P0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:
0?ooo`0200WZ2P0307moO`09jPX0000000@0Ogmo0P09jPX00`1oOgl0000000WZ2P0507moO`0400WZ
2P000000oooo00WZ2P80oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo00WZ2P030?ooo`<0
2NX:00@0oooo00WZ2P3oool0oooo0P09jPX30?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool200WZ
2P<0oooo0P09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`09jPX00P09jPX2
0?ooo`@02NX:0`3oool00`09jPX0oooo00WZ2P020?ooo`<02NX:00<0oooo00WZ2P3oool00P09jPX2
0?ooo`802NX:00T0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P05
0?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0?0?ooo`0300WZ2P3oool0oooo
00T0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool06@3oool00`09jPX0
oooo00WZ2P020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo0P09jPX30?oo
o`802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00802NX:0P3oool400WZ
2P80oooo0P09jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool500WZ2P060?ooo`09
jPX0oooo0?ooo`09jPX0oooo1P09jPX0103oool02NX:0?ooo`3oool200WZ2P050?ooo`09jPX02NX:
00WZ2P3oool01P09jPX0203oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool01@09jPX0
oooo00WZ2P09jPX0oooo00802NX:00<0Ogmo00WZ2P000000101oOgl200WZ2P0307moO`0000002NX:
00D0Ogmo00@02NX:0000003oool02NX:0P3oool200WZ2PH0oooo00<02NX:0?ooo`09jPX00`3oool3
00WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0`3oool200WZ2P030?ooo`09jPX02NX:0080oooo0P09
jPX30?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00<02NX:0?ooo`09jPX00P09
jPX30?ooo`<02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`802NX:0P3oool01009jPX0oooo
00WZ2P09jPX20?ooo`802NX:00T0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`09jPX00`3o
ool200WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo0?ooo`0>0?ooo`03
00WZ2P3oool0oooo00T0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
6@3oool00`09jPX0oooo00WZ2P020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P<0
oooo00<02NX:0?ooo`3oool00P3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P80oooo00<02NX:
0?ooo`3oool00P09jPX20?ooo`@02NX:0P3oool200WZ2P070?ooo`09jPX02NX:0?ooo`09jPX0oooo
00WZ2P020?ooo`0300WZ2P3oool02NX:00802NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool600WZ
2P040?ooo`09jPX0oooo0?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0600WZ2P080?ooo`09
jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX0
0`1oOgl02NX:0000000407moO`802NX:00<0Ogmo00000009jPX01@1oOgl01009jPX000000?ooo`09
jPX20?ooo`802NX:1P3oool01009jPX0oooo0?ooo`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX0
0P3oool200WZ2P<0oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`802NX:0`3oool200WZ2P80oooo
00<02NX:0?ooo`3oool00P09jPX20?ooo`0300WZ2P3oool02NX:00802NX:0P3oool400WZ2P80oooo
00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool01P09
jPX0oooo0?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool02@09jPX0oooo00WZ
2P3oool02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?oo
o`3oool02@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0I0?ooo`03
00WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0`3oool200WZ
2P<0oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool4
00WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P04
00WZ2P80oooo00<02NX:0?ooo`09jPX01@09jPX0103oool02NX:0?ooo`3oool200WZ2P050?ooo`09
jPX02NX:00WZ2P3oool01P09jPX0203oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool0
1@09jPX0oooo00WZ2P09jPX0oooo00802NX:00<0Ogmo00WZ2P000000101oOgl200WZ2P0307moO`00
00002NX:00H0Ogmo00<02NX:0?ooo`09jPX00P3oool200WZ2PH0oooo00@02NX:0?ooo`3oool02NX:
0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX30?ooo`802NX:00<0oooo00WZ2P09jPX0
0P3oool200WZ2P<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool01009jPX0oooo
00WZ2P09jPX30?ooo`@02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00<02NX:0P3oool01009
jPX0oooo00WZ2P09jPX20?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:0P3oool300WZ2P80oooo
00H02NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ2P80oooo00<02NX:0?ooo`3oool03P3oool00`09
jPX0oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01X0
oooo0P09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P<0oooo0P09jPX30?oo
o`802NX:00@0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo1009jPX2
0?ooo`D02NX:0P3oool200WZ2P80oooo00<02NX:0?ooo`09jPX01009jPX20?ooo`0300WZ2P3oool0
2NX:00D02NX:00@0oooo00WZ2P3oool0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:
00X0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool200WZ2P030?ooo`09
jPX02NX:00802NX:00<0Ogmo00WZ2P000000101oOgl200WZ2P0307moO`0000002NX:00H0Ogmo00<0
2NX:0?ooo`09jPX00P3oool200WZ2PH0oooo00@02NX:0?ooo`3oool02NX:0P3oool200WZ2P030?oo
o`09jPX02NX:0080oooo0`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool200WZ2P<0oooo
0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool01009jPX0oooo00WZ2P09jPX30?ooo`@0
2NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00<02NX:0P3oool01009jPX0oooo00WZ2P09jPX2
0?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:0P3oool300WZ2P80oooo00@02NX:0?ooo`09jPX0
2NX:0P3oool300WZ2P030?ooo`09jPX0oooo0100oooo00<02NX:0?ooo`3oool02@3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0J0?ooo`802NX:0`3oool200WZ2P030?oo
o`09jPX0oooo0080oooo0P09jPX30?ooo`802NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P<0
oooo00@02NX:0?ooo`09jPX02NX:0`3oool300WZ2P<0oooo1009jPX20?ooo`802NX:0P3oool600WZ
2P050?ooo`09jPX0oooo00WZ2P3oool02009jPX20?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?oo
o`0300WZ2P030?ooo`09jPX02NX:00802NX:00H0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`80
2NX:00P0oooo00WZ2P09jPX0oooo00WZ2P1oOgl02NX:000000@0Ogmo0P09jPX00`1oOgl0000000WZ
2P0607moO`0300WZ2P3oool02NX:0080oooo0P09jPX60?ooo`0400WZ2P3oool0oooo00WZ2P80oooo
0P09jPX00`3oool02NX:00WZ2P020?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo
0P09jPX30?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX0
2NX:0`3oool400WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P80oooo00@02NX:0?oo
o`09jPX02NX:0P3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P80oooo0`09jPX20?ooo`0400WZ
2P3oool02NX:00WZ2P80oooo0`09jPX00`3oool02NX:0?ooo`0@0?ooo`0300WZ2P3oool0oooo00T0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool06P3oool200WZ2P<0oooo
0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0`3oool200WZ2P<0oooo0P09jPX0103oool02NX:
0?ooo`09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo1009jPX20?ooo`802NX:00@0oooo00WZ
2P3oool0oooo0P09jPX20?ooo`H02NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`05
00WZ2P<0oooo1@09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00@0oooo00WZ2P09jPX0oooo
0P09jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`802NX:00D0oooo00WZ2P1oOgl02NX:00000004
07moO`802NX:00<0Ogmo00000009jPX01P1oOgl01`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0
1@3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`<0
2NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX30?ooo`802NX:0P3oool00`09jPX0
oooo0?ooo`0200WZ2P80oooo1009jPX30?ooo`@02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo
00<02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0900WZ2P3oool0oooo00WZ2P3oool02NX:
0?ooo`09jPX0oooo00802NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`<02NX:00<0oooo00WZ
2P3oool0403oool00`09jPX0oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo01X0oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P80oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P030?ooo`802NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P<0oooo00@02NX:
0?ooo`09jPX02NX:0`3oool400WZ2P80oooo0P09jPX0103oool02NX:00WZ2P3oool200WZ2P80oooo
0P09jPX01P3oool02NX:00WZ2P09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX0oooo1@09jPX3
0?ooo`d02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`80
2NX:00D0oooo00WZ2P1oOgl02NX:0000000507moO`0400WZ2P1oOgl0000000WZ2PH0Ogmo00L02NX:
0?ooo`09jPX0oooo00WZ2P3oool02NX:00D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`80
2NX:00<0oooo00WZ2P09jPX00P3oool300WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`80
2NX:0P3oool300WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX00`3oool02NX:0?ooo`0300WZ2P<0
oooo1009jPX20?ooo`0300WZ2P3oool02NX:0080oooo0`09jPX0103oool02NX:00WZ2P3oool200WZ
2P80oooo00T02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX20?ooo`802NX:
00@0oooo00WZ2P3oool0oooo0`09jPX00`3oool02NX:0?ooo`0@0?ooo`0300WZ2P3oool0oooo00T0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool06P3oool00`09jPX0oooo
00WZ2P020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo0P09jPX30?ooo`80
2NX:0P3oool200WZ2P<0oooo00@02NX:0?ooo`09jPX02NX:0`3oool400WZ2P80oooo0P09jPX0203o
ool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX01P3oool02NX:00WZ2P09jPX0oooo00WZ
2P80oooo00@02NX:0?ooo`09jPX0oooo1@09jPX30?ooo`d02NX:00@0oooo00WZ2P09jPX0oooo0P09
jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P09jPX00`000000Ogmo
07moO`0307moO`802NX:00<0000000WZ2P1oOgl01@1oOgl01`09jPX0oooo00WZ2P3oool02NX:0?oo
o`09jPX01@3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo0P09jPX00`3oool02NX:00WZ2P02
0?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX20?ooo`<02NX:0P3oool0
0`09jPX0oooo0?ooo`0200WZ2P030?ooo`09jPX0oooo00<02NX:0`3oool400WZ2P80oooo00<02NX:
0?ooo`09jPX00P3oool300WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool02@09jPX0oooo00WZ
2P09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo0P09jPX0103oool02NX:0?ooo`3oool2
00WZ2P80oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`090?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo01X0oooo00<02NX:0?ooo`09jPX00P3oool01@09
jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX20?ooo`802NX:0`3oool200WZ2P80oooo0P09jPX3
0?ooo`0300WZ2P3oool0oooo00802NX:0P3oool400WZ2P80oooo00<02NX:0?ooo`09jPX00P09jPX2
0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX0203oool02NX:0?ooo`3oool02NX:0?ooo`09
jPX0oooo1@09jPX30?ooo`d02NX:00<0oooo00WZ2P3oool00`09jPX01@3oool02NX:0?ooo`3oool0
2NX:0080oooo00<02NX:0?ooo`09jPX00P09jPX00`000000Ogmo07moO`0307moO`802NX:00<00000
00WZ2P1oOgl01@1oOgl01`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX01@3oool01@09jPX0oooo
0?ooo`3oool02NX:0080oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`<02NX:0P3oool200WZ2P80
oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool200WZ
2P030?ooo`09jPX0oooo00<02NX:0`3oool400WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`03
00WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool02@09jPX0oooo00WZ2P09jPX0oooo00WZ2P3o
ool02NX:0?ooo`0200WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool200WZ2P80oooo00<0
2NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo01/0oooo0P09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3o
ool200WZ2P<0oooo00<02NX:0?ooo`3oool00P3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P80
oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`D02NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`80
2NX:00<0oooo00WZ2P3oool01009jPX0203oool02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo1@09
jPX30?ooo`d02NX:00<0oooo00WZ2P3oool00`09jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo
00<02NX:0?ooo`09jPX00P09jPX00`000000Ogmo07moO`0307moO`802NX:00<0000000WZ2P1oOgl0
1@1oOgl01`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX01@3oool01@09jPX0oooo0?ooo`3oool0
2NX:0080oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`<02NX:0P3oool300WZ2P060?ooo`09jPX0
2NX:00WZ2P3oool02NX:0P3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo0P09jPX00`3oool0
2NX:0?ooo`0300WZ2P<0oooo1009jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00`09jPX01@3o
ool02NX:00WZ2P3oool02NX:0080oooo0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`0:00WZ2P3o
ool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX20?ooo`0300WZ2P3oool0
oooo00l0oooo00<02NX:0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0K0?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX3
0?ooo`802NX:0`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool0
0P09jPX20?ooo`D02NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`802NX:0P3oool500WZ2P040?oo
o`09jPX0oooo0?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P<0oooo1`09jPX0103o
ool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00<02NX:00D0oooo00WZ2P3oool0oooo00WZ
2P020?ooo`0300WZ2P3oool02NX:00802NX:00<0000007moO`1oOgl00`1oOgl200WZ2P0300000009
jPX0Ogmo00D0Ogmo00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080oooo
00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool300WZ2P80
oooo1`09jPX0103oool02NX:0?ooo`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo0P09jPX0
0`3oool02NX:0?ooo`0300WZ2P<0oooo1009jPX0103oool02NX:0?ooo`3oool200WZ2P050?ooo`09
jPX02NX:00WZ2P3oool00P09jPX0103oool02NX:0?ooo`3oool200WZ2P040?ooo`09jPX02NX:00WZ
2P80oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:0`3oool200WZ2P030?ooo`09jPX0
oooo0140oooo00<02NX:0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0K0?ooo`802NX:0`3oool200WZ2P030?ooo`09jPX0oooo0080oooo0P09jPX30?oo
o`802NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX2
0?ooo`D02NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`802NX:0P3oool500WZ2P040?ooo`09jPX0
oooo0?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P<0oooo1009jPX0103oool02NX:
00WZ2P3oool200WZ2P030?ooo`09jPX02NX:0080oooo1@09jPX00`3oool02NX:0?ooo`0200WZ2P03
0?ooo`09jPX0oooo00<02NX:00<0000007moO`1oOgl00`1oOgl200WZ2P0300000009jPX0Ogmo00D0
Ogmo00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080oooo00D02NX:0?oo
o`3oool0oooo00WZ2P020?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool300WZ2P80oooo1`09jPX0
103oool02NX:0?ooo`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo0P09jPX00`3oool02NX:
0?ooo`0300WZ2P<0oooo1009jPX0103oool02NX:0?ooo`3oool300WZ2P030?ooo`09jPX0oooo00<0
2NX:00@0oooo00WZ2P3oool0oooo0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`802NX:00D0oooo
00WZ2P3oool02NX:0?ooo`0200WZ2P<0oooo0P09jPX00`3oool02NX:0?ooo`0A0?ooo`0300WZ2P3o
ool0oooo00T0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool06`3oool2
00WZ2P<0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0`3oool200WZ2P<0oooo0P09jPX0
103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool500WZ2P80oooo1009
jPX20?ooo`802NX:0P3oool700WZ2P80oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:
0`3oool400WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:0P3oool500WZ2P040?ooo`09jPX02NX:0?oo
o`<02NX:00D0oooo00WZ2P09jPX02NX:0000000507moO`802NX:00<0000000WZ2P1oOgl01@1oOgl0
1@0000002NX:00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?oo
o`020?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX20?ooo`<02NX:0P3oool00`09jPX0oooo
00WZ2P0500WZ2P<0oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`802NX:00<0oooo00WZ2P3o
ool00`09jPX20?ooo`0300WZ2P3oool02NX:00802NX:00@0oooo00WZ2P3oool0oooo0`09jPX00`3o
ool02NX:0?ooo`0300WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00@0oooo00WZ2P09jPX02NX:0P3o
ool200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX30?ooo`802NX:00<0oooo00WZ2P3oool0
4@3oool00`09jPX0oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo01/0oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P80oooo00D02NX:0?ooo`3oool0oooo
00WZ2P030?ooo`802NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P<0oooo00@02NX:0?ooo`09
jPX02NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P80oooo1009jPX30?ooo`0300WZ2P3oool0oooo
00L02NX:0P3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX30?ooo`@02NX:00@0oooo
00WZ2P09jPX0oooo1@09jPX20?ooo`D02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX20?ooo`802NX:
00<0000007moO`1oOgl00`1oOgl200WZ2P0300000009jPX0Ogmo00D0Ogmo00D0000000WZ2P09jPX0
oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00P3oool01009jPX0
oooo00WZ2P09jPX20?ooo`0300WZ2P3oool0oooo00<02NX:0P3oool00`09jPX0oooo00WZ2P0500WZ
2P<0oooo0P09jPX00`3oool02NX:00WZ2P030?ooo`802NX:00<0oooo00WZ2P3oool00`09jPX20?oo
o`0300WZ2P3oool02NX:00802NX:00@0oooo00WZ2P3oool0oooo0`09jPX00`3oool02NX:0?ooo`03
00WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00d0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ
2P3oool02NX:0?ooo`09jPX0oooo00802NX:0`3oool200WZ2P030?ooo`09jPX0oooo0140oooo00<0
2NX:0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0K
0?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:0P3o
ool200WZ2P<0oooo0P09jPX0103oool02NX:0?ooo`09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P<0
oooo1@09jPX00`3oool02NX:00WZ2P0200WZ2P<0oooo00<02NX:0?ooo`3oool00P09jPX00`3oool0
2NX:00WZ2P0200WZ2P80oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:0P3oool400WZ
2P040?ooo`09jPX02NX:0?ooo`D02NX:0P3oool500WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:0P3o
ool200WZ2P030000001oOgl0Ogmo00<0Ogmo0P09jPX00`0000002NX:07moO`0507moO`0500000009
jPX02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0080oooo
00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo0?ooo`0300WZ2P040?ooo`09jPX02NX:0?oo
o`H02NX:0`3oool200WZ2P030?ooo`09jPX02NX:00<0oooo0P09jPX00`3oool02NX:0?ooo`0200WZ
2P<0oooo00<02NX:0?ooo`09jPX00P09jPX0103oool02NX:0?ooo`3oool300WZ2P030?ooo`09jPX0
oooo00<02NX:00@0oooo00WZ2P3oool0oooo0`09jPX02P3oool02NX:00WZ2P3oool02NX:0?ooo`09
jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0oooo0080oooo00@02NX:0?ooo`3oool02NX:4P3o
ool00`09jPX0oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo01/0oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09
jPX20?ooo`802NX:0`3oool200WZ2P80oooo0P09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo
0`09jPX00`3oool02NX:0?ooo`0400WZ2P<0oooo00D02NX:0?ooo`3oool02NX:0?ooo`0500WZ2P80
oooo0P09jPX00`3oool02NX:0?ooo`0500WZ2P80oooo1009jPX0103oool02NX:00WZ2P3oool500WZ
2P80oooo1@09jPX0103oool02NX:00WZ2P3oool300WZ2P80oooo0P09jPX00`000000Ogmo07moO`03
07moO`0400WZ2P1oOgl02NX:00WZ2PH0Ogmo00D0000000WZ2P09jPX0oooo00WZ2P020?ooo`0300WZ
2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00P3oool01009jPX0oooo00WZ2P09jPX20?ooo`03
00WZ2P3oool0oooo00H02NX:00<0oooo00WZ2P09jPX01009jPX30?ooo`802NX:00<0oooo00WZ2P09
jPX00`3oool200WZ2P030?ooo`09jPX0oooo00802NX:0`3oool00`09jPX0oooo00WZ2P0200WZ2P05
0?ooo`09jPX0oooo00WZ2P3oool00P09jPX0203oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:
0P3oool300WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX0
oooo00WZ2P<0oooo00@02NX:0?ooo`3oool02NX:4P3oool00`09jPX0oooo0?ooo`090?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01`0oooo0P09jPX20?ooo`0500WZ2P3o
ool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo0P09jPX30?ooo`802NX:0P3oool200WZ2P<0oooo
00@02NX:0?ooo`09jPX02NX:0`3oool300WZ2P030?ooo`09jPX0oooo00@02NX:0`3oool01@09jPX0
oooo0?ooo`09jPX0oooo00D02NX:0P3oool00`09jPX0oooo00WZ2P0400WZ2P030?ooo`09jPX02NX:
0080oooo1009jPX0103oool02NX:00WZ2P3oool500WZ2P80oooo1@09jPX0103oool02NX:00WZ2P3o
ool300WZ2P80oooo0P09jPX00`000000Ogmo07moO`0307moO`0400WZ2P1oOgl02NX:00WZ2PH0Ogmo
00D0000000WZ2P000000oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3o
ool00P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00D0oooo00WZ
2P09jPX02NX:0?ooo`0600WZ2P<0oooo0P09jPX00`3oool02NX:00WZ2P030?ooo`802NX:00<0oooo
00WZ2P3oool00P09jPX30?ooo`0300WZ2P3oool02NX:00802NX:00D0oooo00WZ2P3oool02NX:0?oo
o`0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00`09jPX20?ooo`<02NX:00P0oooo00WZ2P09jPX0
oooo00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool200WZ2P030?ooo`09
jPX0oooo0180oooo00<02NX:0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0L0?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09
jPX30?ooo`0300WZ2P3oool0oooo0080oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX20?ooo`04
00WZ2P3oool0oooo00WZ2P<0oooo00<02NX:0?ooo`09jPX00P09jPX01@3oool02NX:00WZ2P3oool0
2NX:00<0oooo00D02NX:0?ooo`3oool02NX:0?ooo`0500WZ2P80oooo00<02NX:0?ooo`09jPX01009
jPX00`3oool02NX:00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`09jPX0
1009jPX30?ooo`<02NX:00@0oooo00WZ2P3oool02NX:0P3oool200WZ2P80oooo0P09jPX00`000000
Ogmo07moO`0307moO`0400WZ2P1oOgl02NX:00WZ2PH0Ogmo00D0000000WZ2P000000oooo00WZ2P02
0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00P3oool01009jPX0oooo00WZ2P09
jPX20?ooo`0300WZ2P3oool0oooo00802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0600WZ2P<0oooo
0P09jPX00`3oool02NX:00WZ2P030?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX30?ooo`0300WZ
2P3oool02NX:00802NX:00@0oooo00WZ2P3oool02NX:0P3oool01P09jPX0oooo00WZ2P3oool02NX:
0?ooo`<02NX:0P3oool300WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool200WZ2P030?ooo`09
jPX02NX:00<0oooo0P09jPX00`3oool02NX:0?ooo`0B0?ooo`0300WZ2P3oool0oooo00T0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0703oool200WZ2P<0oooo0P09jPX0
0`3oool02NX:0?ooo`020?ooo`802NX:0`3oool200WZ2P<0oooo00H02NX:0?ooo`3oool02NX:0?oo
o`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P030?oo
o`09jPX0oooo00<02NX:0P3oool200WZ2P030?ooo`09jPX0oooo00H02NX:00<0oooo00WZ2P3oool0
1@09jPX00`3oool02NX:00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo1`09jPX30?ooo`<0
2NX:00@0oooo00WZ2P3oool02NX:0P3oool200WZ2P80oooo0P09jPX00`000000Ogmo07moO`0307mo
O`0400WZ2P1oOgl02NX:00WZ2PH0Ogmo00D0000000WZ2P09jPX0oooo00WZ2P020?ooo`0300WZ2P3o
ool0oooo0080oooo00<02NX:0?ooo`3oool00P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ
2P3oool0oooo00WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P0400WZ2P<0oooo0P09jPX00`3oool0
2NX:00WZ2P030?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX30?ooo`0900WZ2P3oool02NX:0?oo
o`09jPX0oooo00WZ2P3oool02NX:0080oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ2P03
0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`802NX:00<0oooo00WZ
2P09jPX00`3oool200WZ2P030?ooo`09jPX0oooo0140oooo00<02NX:0?ooo`3oool02P3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0L0?ooo`0300WZ2P3oool02NX:0080
oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0`3oool200WZ2P<0oooo0P09jPX0103oool0
2NX:0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P0400WZ
2P040?ooo`09jPX02NX:00WZ2P<0oooo00@02NX:0?ooo`09jPX0oooo1P09jPX00`3oool02NX:0?oo
o`0500WZ2P030?ooo`09jPX02NX:00<0oooo0`09jPX20?ooo`L02NX:0`3oool300WZ2P040?ooo`09
jPX0oooo00WZ2P80oooo0P09jPX20?ooo`802NX:00<0000007moO`1oOgl00`1oOgl01009jPX0Ogmo
00WZ2P09jPX607moO`0500000009jPX02NX:0?ooo`09jPX00`3oool01@09jPX0oooo0?ooo`3oool0
2NX:00@0oooo00@02NX:0?ooo`09jPX02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`<02NX:
00<0oooo00WZ2P09jPX01009jPX30?ooo`0300WZ2P3oool0oooo00802NX:0`3oool300WZ2P80oooo
0P09jPX30?ooo`<02NX:00H0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`<02NX:00<0oooo00WZ
2P3oool00`09jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool2
00WZ2P030?ooo`09jPX02NX:00<0oooo0P09jPX00`3oool02NX:0?ooo`0A0?ooo`0300WZ2P3oool0
oooo00X0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0703oool00`09
jPX0oooo00WZ2P020?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P<0oooo0P09jPX30?oo
o`802NX:00@0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00D02NX:
0?ooo`09jPX02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:00WZ2P<0oooo00<02NX:0?ooo`09jPX0
0P3oool500WZ2P030?ooo`09jPX0oooo00D02NX:00@0oooo00WZ2P09jPX02NX:0P3oool300WZ2P80
oooo1`09jPX30?ooo`<02NX:00@0oooo00WZ2P3oool02NX:0P3oool200WZ2P80oooo0P09jPX00`00
0000Ogmo07moO`0307moO`0400WZ2P1oOgl02NX:00WZ2PH0Ogmo00D0000000WZ2P09jPX0oooo00WZ
2P030?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0103oool01009jPX0oooo00WZ2P09jPX20?ooo`04
00WZ2P3oool02NX:00WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P0400WZ2P<0oooo00<02NX:0?oo
o`3oool00P09jPX30?ooo`<02NX:0P3oool200WZ2P<0oooo0`09jPX00`3oool02NX:00WZ2P020?oo
o`0300WZ2P3oool02NX:00<02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0200WZ
2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX02NX:00<0oooo0P09jPX0
0`3oool02NX:0?ooo`0A0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0703oool00`09jPX0oooo00WZ2P020?ooo`0500WZ2P3oool02NX:
0?ooo`09jPX00`3oool01009jPX0oooo0?ooo`3oool200WZ2P<0oooo0P09jPX0103oool02NX:0?oo
o`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo0080
2NX:00@0oooo00WZ2P09jPX02NX:0`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:
00802NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P80oooo0P09jPX20?ooo`@02NX:00<0oooo00WZ
2P09jPX01@09jPX30?ooo`<02NX:00@0oooo00WZ2P3oool02NX:0P3oool200WZ2P80oooo0P09jPX0
0`000000Ogmo07moO`0307moO`0400WZ2P1oOgl02NX:00WZ2PH0Ogmo00D0000000WZ2P09jPX0oooo
00WZ2P030?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0103oool01@09jPX0oooo00WZ2P09jPX0oooo
00802NX:00<0oooo00WZ2P09jPX00P3oool300WZ2P030?ooo`09jPX02NX:00@02NX:0P3oool200WZ
2P80oooo0P09jPX30?ooo`<02NX:0P3oool300WZ2P80oooo0`09jPX20?ooo`0500WZ2P3oool0oooo
00WZ2P3oool01009jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00802NX:00H0oooo
00WZ2P3oool02NX:0?ooo`09jPX20?ooo`<02NX:00<0oooo00WZ2P3oool00P3oool200WZ2P030?oo
o`09jPX0oooo0140oooo00<02NX:0?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0L0?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo
00WZ2P030?ooo`802NX:0P3oool200WZ2P<0oooo0P09jPX0103oool02NX:0?ooo`09jPX30?ooo`04
00WZ2P3oool02NX:00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P040?ooo`09jPX0
2NX:00WZ2P<0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P0200WZ2P80oooo00@0
2NX:0?ooo`09jPX0oooo0`09jPX00`3oool02NX:00WZ2P020?ooo`@02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0400WZ2P80oooo0`09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:0P3oool200WZ
2P030000001oOgl0Ogmo00<0Ogmo00@02NX:07moO`0000002NX:1P1oOgl01@0000002NX:00WZ2P3o
ool02NX:00<0oooo00H02NX:0?ooo`000000000000WZ2P0000040?ooo`<02NX:00@0oooo00WZ2P09
jPX0oooo0P09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX01009jPX20?ooo`802NX:0P3oool200WZ
2P<0oooo0`09jPX20?ooo`<02NX:0P3oool300WZ2P80oooo00D02NX:0?ooo`3oool02NX:0?ooo`04
00WZ2P030?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P3oool02NX:0P3oool01@09jPX0oooo00WZ
2P3oool02NX:0080oooo0`09jPX00`3oool02NX:0?ooo`020?ooo`802NX:00<0oooo00WZ2P3oool0
4@3oool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo01d0oooo0P09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo
0P09jPX30?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool01009jPX0oooo00WZ2P09jPX20?oo
o`0300WZ2P3oool02NX:00<02NX:00<0oooo00WZ2P3oool00P09jPX30?ooo`802NX:00D0oooo00WZ
2P3oool02NX:0?ooo`0300WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0`09jPX00`3oool02NX:00WZ
2P020?ooo`0500WZ2P3oool02NX:00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo
0`09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:0P3oool200WZ2P030000001oOgl0Ogmo00<0
Ogmo00@02NX:07moO`0000002NX:1P1oOgl01@0000002NX:00WZ2P0000002NX:00<0000000H02NX:
0000001oOgl0000000WZ2P1oOgl200000080oooo0`09jPX0103oool02NX:00WZ2P3oool200WZ2P80
oooo0`09jPX0103oool02NX:00WZ2P3oool300WZ2P80oooo0P09jPX20?ooo`802NX:0P3oool01009
jPX0oooo00WZ2P09jPX20?ooo`<02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0500WZ2P3oool0
oooo00WZ2P3oool01009jPX00`3oool02NX:0?ooo`0300WZ2P040?ooo`09jPX0oooo00WZ2P80oooo
00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool400WZ
2Q<0oooo00<02NX:0?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0M0?ooo`802NX:0`3oool200WZ2P030?ooo`09jPX0oooo0080oooo0P09jPX30?ooo`04
00WZ2P3oool0oooo0?ooo`802NX:0P3oool200WZ2P<0oooo00@02NX:0?ooo`09jPX02NX:0`3oool7
00WZ2P030?ooo`09jPX02NX:00<0oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:0P3o
ool01009jPX0oooo00WZ2P3oool300WZ2P030?ooo`09jPX02NX:0080oooo00@02NX:0?ooo`09jPX0
2NX:0P3oool200WZ2P030?ooo`09jPX02NX:00802NX:0P3oool300WZ2P80oooo00H02NX:0?ooo`09
jPX02NX:00000009jPX2000000802NX:00<0000007moO`1oOgl00P1oOgl00`0000002NX:07moO`02
000000H0Ogmo00D0000000WZ2P09jPX0000000WZ2P0207moO`0400000009jPX0Ogmo07moO`800000
0P1oOgl30?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`<02NX:00@0oooo00WZ2P09jPX0
oooo0`09jPX20?ooo`802NX:0P3oool200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool300WZ
2P030?ooo`09jPX0oooo00<02NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool600WZ2P080?ooo`09
jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo0P09
jPX0103oool02NX:0?ooo`09jPX20?ooo`@02NX:4`3oool00`09jPX0oooo0?ooo`0:0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01d0oooo0P09jPX30?ooo`802NX:00<0
oooo00WZ2P3oool00P3oool200WZ2P<0oooo00@02NX:0?ooo`3oool0oooo0P09jPX20?ooo`802NX:
0`3oool01009jPX0oooo00WZ2P09jPX30?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX00`3o
ool02NX:00WZ2P030?ooo`802NX:00<0oooo00WZ2P3oool01@09jPX20?ooo`0400WZ2P3oool02NX:
0?ooo`<02NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00802NX:0P3oool200WZ2P030?oo
o`09jPX02NX:00802NX:0P3oool300WZ2P80000000@02NX:00000009jPX02NX:0P0000001@1oOgl0
000000WZ2P09jPX0000000@0Ogmo00D0000000WZ2P1oOgl0000000WZ2P0607moO`0500000009jPX0
000007moO`09jPX00`1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:0080Ogmo0`3oool200WZ2P80oooo
00<02NX:0?ooo`09jPX00P09jPX20?ooo`<02NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P80oooo
0P09jPX20?ooo`802NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0600WZ2P3oool02NX:0?oo
o`09jPX0oooo0`09jPX0103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool02NX:00<02NX:00T0
oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P020?oo
o`802NX:00<0oooo00WZ2P09jPX00`3oool400WZ2Q<0oooo00<02NX:0?ooo`3oool02P3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0M0?ooo`0300WZ2P3oool02NX:0080
oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0`3oool200WZ2P<0oooo00H02NX:0?ooo`3o
ool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00D02NX:0?ooo`09jPX02NX:
0?ooo`0200WZ2P030?ooo`09jPX02NX:00<0oooo0P09jPX00`3oool02NX:0?ooo`0500WZ2P80oooo
00<02NX:0?ooo`09jPX01009jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX20?oo
o`L02NX:0P00000300WZ2P0307moO`0000002NX:0080000000@02NX:00000009jPX0Ogmo0P000000
0`09jPX0000007moO`0407moO`0400WZ2P1oOgl0000000WZ2PH0Ogmo00D0000000WZ2P09jPX0Ogmo
00WZ2P0307moO`0500WZ2P1oOgl0Ogmo07moO`09jPX00P1oOgl30?ooo`802NX:0P3oool00`09jPX0
oooo00WZ2P0200WZ2P80oooo0`09jPX20?ooo`0300WZ2P3oool02NX:00802NX:0P3oool200WZ2P80
oooo0P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3o
ool300WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00`09jPX00`3oool02NX:
0?ooo`0200WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P80oooo0P09jPX00`3oool0
2NX:00WZ2P030?ooo`@02NX:4`3oool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo01d0oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P80oooo
00<02NX:0?ooo`3oool00P09jPX30?ooo`802NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80
oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX0103o
ool02NX:00WZ2P09jPX20?ooo`802NX:00@0oooo00WZ2P3oool0oooo1009jPX20?ooo`0300WZ2P3o
ool0oooo00@02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:0P3oool700WZ2P03
07moO`00000000000080000000<0Ogmo00000009jPX00P0000000`09jPX0Ogmo00WZ2P0207moO`03
00000009jPX0000000D0Ogmo00@02NX:07moO`0000002NX:1P1oOgl01@09jPX0Ogmo00WZ2P1oOgl0
2NX:00<0Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0207moO`030000003oool0oooo00802NX:0P3o
ool00`09jPX0oooo00WZ2P0200WZ2P80oooo0`09jPX20?ooo`0300WZ2P3oool02NX:00802NX:0P3o
ool200WZ2P80oooo00H02NX:0?ooo`3oool0oooo00WZ2P3oool200WZ2P080?ooo`09jPX02NX:0?oo
o`09jPX0oooo00WZ2P3oool300WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX0
0`09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P80
oooo0P09jPX00`3oool02NX:00WZ2P030?ooo`@02NX:4`3oool00`09jPX0oooo0?ooo`0:0?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01d0oooo00<02NX:0?ooo`09jPX0
0P3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo00@02NX:0?ooo`3oool0oooo0P09jPX30?oo
o`802NX:00@0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00<02NX:
0?ooo`09jPX01009jPX20?ooo`802NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`D02NX:00@0
oooo00WZ2P3oool0oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00802NX:
0P3oool300WZ2P090?ooo`09jPX02NX:0?ooo`09jPX0Ogmo00WZ2P1oOgl02NX:0080Ogmo1009jPX0
101oOgl02NX:07moO`1oOgl200WZ2P030000001oOgl0Ogmo00<0Ogmo00@02NX:07moO`0000002NX:
1P1oOgl01@09jPX0000000WZ2P0000002NX:0080Ogmo00H0000000WZ2P1oOgl0Ogmo00000009jPX2
07moO`030000003oool0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P80oooo0`09jPX0
103oool02NX:00WZ2P3oool200WZ2P<0oooo0P09jPX20?ooo`802NX:0P3oool01@09jPX0oooo00WZ
2P09jPX0oooo00802NX:00`0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?oo
o`09jPX20?ooo`H02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3o
ool00P09jPX20?ooo`<02NX:00<0oooo00WZ2P3oool00P3oool400WZ2Q<0oooo00<02NX:0?ooo`3o
ool02P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0N0?ooo`802NX:
0P3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX20?ooo`802NX:0`3oool200WZ2P04
0?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`0300WZ2P3oool02NX:
00@02NX:0P3oool200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo00WZ2P02
00WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?oo
o`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX02@3oool02NX:07moO`09jPX0Ogmo00WZ
2P1oOgl02NX:07moO`0300WZ2P0407moO`09jPX0Ogmo07moO`<02NX:101oOgl01@0000002NX:07mo
O`0000002NX:00D0Ogmo00@0000000WZ2P0000002NX:0P00000207moO`0400000009jPX0Ogmo07mo
O`8000000P1oOgl30?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P<0oooo0P09jPX0103o
ool02NX:00WZ2P3oool200WZ2P<0oooo0P09jPX20?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P09
jPX0oooo00802NX:00`0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09
jPX20?ooo`H02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0300WZ2P3oool02NX:00802NX:00@0
oooo00WZ2P3oool0oooo0`09jPX00`3oool02NX:0?ooo`020?ooo`@02NX:4`3oool00`09jPX0oooo
0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01h0oooo0P09
jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo0P09jPX30?ooo`802NX:
00@0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00<02NX:0?ooo`09
jPX00P09jPX0103oool02NX:0?ooo`3oool200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool5
00WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?oo
o`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX0101oOgl02NX:07moO`09jPX700000003
00WZ2P000000000000<02NX:101oOgl01@0000002NX:07moO`0000002NX:00D0Ogmo00H0000000WZ
2P1oOgl02NX:07moO`09jPX307moO`0500WZ2P1oOgl0Ogmo07moO`09jPX00P1oOgl30?ooo`802NX:
0P3oool00`09jPX0oooo00WZ2P0200WZ2P<0oooo0P09jPX0103oool02NX:00WZ2P3oool200WZ2P<0
oooo0P09jPX20?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:00<0oooo00WZ
2P3oool00`09jPX02@3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`0500WZ2P030?oo
o`09jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P090?ooo`09jPX0oooo0?ooo`09
jPX0oooo00WZ2P3oool02NX:0080oooo1009jPXD0?ooo`0300WZ2P3oool0oooo00X0oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool07P3oool200WZ2P<0oooo0P09jPX00`3o
ool02NX:0?ooo`020?ooo`802NX:0P3oool200WZ2P<0oooo0P09jPX0103oool02NX:0?ooo`09jPX3
0?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`09jPX00P09jPX0103oool02NX:0?oo
o`3oool200WZ2P<0oooo0`09jPX20?ooo`D02NX:00P0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:
0?ooo`H02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00802NX:00L0
Ogmo00WZ2P0000002NX:00000009jPX0000000802NX:0P0000000`09jPX000000000000200000003
00WZ2P1oOgl0Ogmo00<0Ogmo00@02NX:07moO`0000002NX:1P1oOgl01@09jPX0Ogmo00WZ2P1oOgl0
2NX:00@0Ogmo00<02NX:07moO`09jPX0101oOgl20?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P02
00WZ2P<0oooo00<02NX:0?ooo`3oool00P09jPX00`3oool02NX:00WZ2P030?ooo`802NX:0P3oool2
00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00<02NX:00T0
oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool01@09jPX00`3oool02NX:0?ooo`0200WZ
2P040?ooo`09jPX02NX:0?ooo`<02NX:00T0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`09
jPX00P3oool400WZ2Q@0oooo00<02NX:0?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`0N0?ooo`802NX:0`3oool200WZ2P030?ooo`09jPX0oooo0080oooo
0P09jPX30?ooo`0400WZ2P3oool0oooo0?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool01009
jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:00@02NX:0P3oool300WZ2P80oooo0`09jPX2
0?ooo`D02NX:00@0oooo00WZ2P3oool0oooo2P09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:
00<0oooo00WZ2P09jPX00P09jPX01`1oOgl00000000000000000Ogmo00WZ2P1oOgl00`09jPX01`1o
Ogl02NX:07moO`1oOgl02NX:00000009jPX01@1oOgl00`09jPX0Ogmo0000000200WZ2P@0Ogmo00H0
2NX:0000001oOgl02NX:07moO`09jPX407moO`0500WZ2P1oOgl02NX:0000001oOgl00`0000000`3o
ool02NX:00WZ2P020?ooo`0300WZ2P3oool02NX:00802NX:0`3oool00`09jPX0oooo0?ooo`0200WZ
2P030?ooo`09jPX02NX:00<0oooo0P09jPX20?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P09jPX0
oooo00@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P050?ooo`09jPX0oooo00WZ2P3oool0
1@09jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:0`3oool01009jPX0
oooo00WZ2P09jPX30?ooo`@02NX:503oool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo01h0oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P80
oooo00<02NX:0?ooo`3oool00P09jPX30?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3oool200WZ
2P<0oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo00WZ2P0500WZ2P040?ooo`09jPX0
2NX:00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool500WZ2P040?ooo`09jPX0oooo0?ooo`H02NX:
00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX01`1o
Ogl02NX:07moO`09jPX0Ogmo00WZ2P1oOgl00`09jPX0101oOgl02NX:00WZ2P1oOgl300WZ2PD0Ogmo
00<02NX:07moO`0000000P09jPX307moO`@0000000T02NX:00000009jPX0Ogmo00000009jPX00000
00WZ2P1oOgl00P09jPX00`1oOgl0000000WZ2P020?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P02
00WZ2P<0oooo00<02NX:0?ooo`3oool00P09jPX00`3oool02NX:00WZ2P030?ooo`802NX:0P3oool2
00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0400WZ2P050?ooo`09jPX02NX:00WZ2P3oool0
0`09jPX02@3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P040?ooo`09jPX0
2NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX02NX:0`3oool01009jPX0oooo00WZ2P09jPX30?ooo`@0
2NX:503oool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo01h0oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P80oooo00<02NX:0?ooo`3oool0
0P09jPX30?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`0200WZ2P<0oooo00@02NX:0?ooo`09jPX0
2NX:0`3oool700WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool700WZ
2P80oooo1009jPX00`3oool02NX:0?ooo`0300WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:0P3oool2
00WZ2P030?ooo`09jPX0Ogmo00802NX:00<0Ogmo00WZ2P1oOgl00`09jPX0101oOgl02NX:00WZ2P1o
Ogl300WZ2PD0000000H02NX:000000000000000000WZ2P00000200WZ2P0300000009jPX0000000@0
000000P0Ogmo00000009jPX0000000WZ2P1oOgl0000000WZ2P80oooo00<02NX:0?ooo`3oool00P09
jPX20?ooo`0300WZ2P3oool02NX:00802NX:0P3oool200WZ2P80oooo0P09jPX00`3oool02NX:00WZ
2P030?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00D0
2NX:00@0oooo00WZ2P09jPX0oooo0`09jPX02@3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:
0?ooo`0300WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00@0oooo00WZ2P09jPX02NX:0`3oool01009
jPX0oooo00WZ2P09jPX30?ooo`@02NX:503oool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo01h0oooo00<02NX:0?ooo`09jPX00P3oool01@09
jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPX30?ooo`802NX:0`3oool01P09jPX0oooo0?ooo`09
jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0`3oool02009jPX0oooo00WZ2P3oool02NX:
0?ooo`09jPX0oooo0`09jPX20?ooo`0700WZ2P3oool02NX:00WZ2P3oool02NX:0?ooo`0500WZ2P80
oooo1009jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00<02NX:00@0oooo00WZ2P3o
ool0oooo0P09jPX00`3oool02NX:07moO`0200WZ2P<000000`09jPX20000000300WZ2P0000002NX:
00802NX:00@0Ogmo00000009jPX0Ogmo0P0000001@1oOgl0000000000009jPX0000000802NX:00L0
Ogmo00WZ2P1oOgl0oooo00WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX0oooo0P09jPX20?oo
o`0300WZ2P3oool0oooo00802NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo0P09jPX20?oo
o`802NX:00<0oooo00WZ2P09jPX00`3oool01009jPX0oooo0?ooo`3oool200WZ2P80oooo00D02NX:
0?ooo`09jPX02NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:0P3oool01P09jPX0oooo
00WZ2P3oool02NX:0?ooo`<02NX:00@0oooo00WZ2P3oool0oooo0`09jPX0103oool02NX:00WZ2P09
jPX30?ooo`802NX:00<0oooo00WZ2P3oool00P3oool01009jPX0oooo00WZ2P09jPXD0?ooo`0300WZ
2P3oool0oooo00X0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool07`3o
ool200WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`0400WZ2P3oool0oooo0?ooo`80
2NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`3oool02NX:0`3oool0
2009jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0`09jPX20?ooo`0700WZ2P3oool02NX:00WZ
2P3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo00@02NX:00L0oooo00WZ2P09jPX02NX:0?oo
o`09jPX0oooo00D02NX:00@0oooo00WZ2P3oool0oooo0P09jPX00`0000002NX:0000000200WZ2P03
00000009jPX0000000<02NX:0P0000002`09jPX000000000000000002NX:0000001oOgl02NX:07mo
O`3oool02NX:0080oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09
jPX00P3oool01009jPX0oooo00WZ2P3oool200WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX20?oo
o`0300WZ2P3oool0oooo00802NX:0P3oool200WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P020?oo
o`802NX:0`3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX0
103oool02NX:00WZ2P3oool400WZ2P80oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ2P0;
0?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P040?oo
o`09jPX0oooo0?ooo`802NX:00<0oooo00WZ2P09jPX0503oool00`09jPX0oooo0?ooo`0:0?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01l0oooo0P09jPX20?ooo`0500WZ
2P3oool02NX:0?ooo`09jPX00`3oool200WZ2P80oooo0P09jPX30?ooo`802NX:00@0oooo00WZ2P3o
ool02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00<02NX:0?ooo`09jPX01009jPX0203o
ool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo0080
2NX:00<0oooo00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00<0
2NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0200000002NX:0000000000002NX:0?ooo`09jPX0oooo
0`09jPX0103oool02NX:00WZ2P3oool300WZ2P030000003oool02NX:0080oooo00<02NX:0?ooo`3o
ool00P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool01009
jPX0oooo00WZ2P3oool200WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`0300WZ2P3oool0
oooo00802NX:0P3oool200WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`802NX:0`3oool2
00WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00<0oooo00WZ2P3oool00`09jPX0103oool02NX:00WZ
2P3oool400WZ2P80oooo0P09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX20?ooo`07
00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`<02NX:00@0oooo00WZ2P3oool0oooo0P09
jPX00`3oool02NX:00WZ2P0D0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool01@3o
ool000L0oooo00<000000?ooo`3oool07`3oool200WZ2P<0oooo0P09jPX00`3oool02NX:0?ooo`02
0?ooo`802NX:0P3oool200WZ2P<0oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3o
ool0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P0500WZ2P060?ooo`09jPX02NX:00WZ2P3oool0
2NX:0P3oool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:00D0oooo00WZ2P3oool02NX:0?oo
o`0500WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:
0?ooo`0200WZ2P030?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX20?ooo`04
00WZ2P3oool0oooo00WZ2P80oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo00<02NX:
0?ooo`09jPX00P3oool01009jPX0oooo00WZ2P3oool200WZ2P80oooo00<02NX:0?ooo`3oool00P09
jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool200WZ2P80oooo0P09jPX00`3oool02NX:00WZ
2P020?ooo`802NX:0`3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00<0oooo00WZ2P3oool0
0`09jPX0103oool02NX:00WZ2P3oool400WZ2P80oooo0P09jPX20?ooo`0500WZ2P3oool02NX:00WZ
2P3oool00P09jPX20?ooo`0700WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`<02NX:00@0
oooo00WZ2P3oool0oooo0P09jPX00`3oool02NX:0?ooo`0D0?ooo`0300WZ2P3oool0oooo00X0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool07`3oool200WZ2P<0oooo0P09
jPX00`3oool02NX:0?ooo`020?ooo`802NX:0P3oool200WZ2P<0oooo0P09jPX0103oool02NX:0?oo
o`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00<0
2NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo
1009jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00P02NX:00@0oooo00WZ2P09jPX0
oooo1009jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo0`09
jPX20?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX01@09jPX0103oool02NX:
0?ooo`09jPX20?ooo`L02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo
00802NX:0P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool200WZ2P<0oooo0P09jPX0
103oool02NX:0?ooo`3oool400WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0P3oool400WZ2P04
0?ooo`09jPX0oooo00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P090?ooo`09jPX0
oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0080oooo1009jPX30?ooo`802NX:00<0oooo00WZ2P3o
ool04`3oool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo01l0oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P030?ooo`09jPX0oooo0080oooo
0P09jPX30?ooo`0400WZ2P3oool0oooo0?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool01009
jPX0oooo00WZ2P09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00`09jPX01P3oool02NX:00WZ
2P09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool01`09jPX00`3oool02NX:0?ooo`0300WZ2P03
0?ooo`09jPX0oooo00H02NX:00<0oooo00WZ2P3oool00P09jPX01@3oool02NX:00WZ2P09jPX0oooo
00<02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0P09jPX01P3o
ool02NX:0?ooo`3oool02NX:0?ooo`H02NX:00@0oooo00WZ2P3oool02NX:0P3oool700WZ2P040?oo
o`09jPX02NX:0?ooo`802NX:0P3oool01009jPX0oooo0?ooo`09jPX30?ooo`<02NX:00@0oooo00WZ
2P09jPX0oooo0P09jPX20?ooo`802NX:0`3oool200WZ2P040?ooo`09jPX0oooo0?ooo`@02NX:00H0
oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`@02NX:00@0oooo00WZ2P3oool02NX:0P3oool01@09
jPX0oooo00WZ2P09jPX0oooo00802NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool200WZ2P<0oooo
1009jPX30?ooo`802NX:00<0oooo00WZ2P3oool04`3oool00`09jPX0oooo0?ooo`0;0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`09jPX00P3o
ool200WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX30?ooo`0400WZ2P3oool0oooo0?ooo`802NX:
0P3oool200WZ2P<0oooo00@02NX:0?ooo`09jPX02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo
00<02NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00L02NX:00<0
oooo00WZ2P3oool00`09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool0
2NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0500WZ
2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P060?ooo`09jPX0oooo0?ooo`09jPX0
oooo1P09jPX0103oool02NX:0?ooo`09jPX20?ooo`L02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX2
0?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo0`09jPX00`3oool02NX:0?ooo`0300WZ2P80oooo0P09
jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool400WZ2P030?ooo`09jPX02NX:00<02NX:
0P3oool02009jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0P3oool01@09jPX0oooo00WZ2P09
jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P030?ooo`@02NX:0`3o
ool01009jPX0oooo0?ooo`09jPXD0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool07`3oool00`09jPX0oooo00WZ2P020?ooo`0500WZ2P3o
ool02NX:0?ooo`09jPX00P3oool200WZ2P<0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo00802NX:
0`3oool01009jPX0oooo00WZ2P09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool02@09jPX20?oo
o`0300WZ2P3oool0oooo00L02NX:0P3oool400WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ
2P3oool00P09jPX0103oool02NX:00WZ2P3oool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01`09
jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX01P3oool02NX:0?ooo`3oool02NX:
0?ooo`H02NX:00@0oooo00WZ2P3oool02NX:0P3oool700WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:
00<0oooo00WZ2P3oool00P09jPX30?ooo`<02NX:00<0oooo00WZ2P3oool01009jPX00`3oool02NX:
00WZ2P020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool400WZ2P030?ooo`09jPX02NX:00<0
2NX:0P3oool02@09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`0400WZ2P80oooo0P09
jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00<0oooo1009jPX30?ooo`0400WZ2P3o
ool0oooo00WZ2Q@0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0P0?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:00<0oooo
00@02NX:0?ooo`3oool0oooo0P09jPX30?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:0P3oool0
1009jPX0oooo00WZ2P09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool02009jPX00`3oool02NX:
0?ooo`0200WZ2P030?ooo`09jPX0oooo00D02NX:0P3oool400WZ2P030?ooo`09jPX0oooo00<02NX:
00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0400WZ2P050?ooo`09jPX02NX:00WZ2P3o
ool01`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX01P3oool02NX:0?ooo`3o
ool02NX:0?ooo`H02NX:00@0oooo00WZ2P3oool02NX:0P3oool700WZ2P040?ooo`09jPX02NX:0?oo
o`<02NX:00<0oooo00WZ2P3oool00P09jPX30?ooo`<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`02
00WZ2P030?ooo`09jPX02NX:0080oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool500WZ2P030?oo
o`09jPX02NX:00<02NX:0P3oool02@09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`04
00WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00<0oooo0P09jPX0
103oool02NX:0?ooo`3oool200WZ2P030?ooo`09jPX02NX:01@0oooo00<02NX:0?ooo`3oool02`3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0P0?ooo`802NX:0P3oool0
1@09jPX0oooo00WZ2P3oool02NX:00<0oooo0P09jPX20?ooo`802NX:0`3oool200WZ2P040?ooo`09
jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0`3oool300WZ2P80oooo1`09jPX00`3oool0
2NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00D02NX:0P3oool300WZ2P030?ooo`09jPX02NX:0080
oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00@02NX:00D0oooo00WZ2P09
jPX02NX:0?ooo`0700WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P060?ooo`09
jPX0oooo0?ooo`09jPX0oooo1P09jPX0103oool02NX:0?ooo`09jPX20?ooo`L02NX:00@0oooo00WZ
2P09jPX0oooo0`09jPX00`3oool02NX:0?ooo`0200WZ2P<0oooo0`09jPX00`3oool02NX:0?ooo`04
00WZ2P030?ooo`09jPX02NX:0080oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool500WZ2P030?oo
o`09jPX02NX:00<02NX:0P3oool02@09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`04
00WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`0500WZ2P<0oooo0P09jPX0103oool02NX:0?ooo`3o
ool200WZ2P030?ooo`09jPX02NX:01@0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0P0?ooo`802NX:0`3oool200WZ2P030?ooo`09jPX0
oooo0080oooo0P09jPX20?ooo`802NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00@0
2NX:0?ooo`3oool02NX:0`3oool00`09jPX0oooo00WZ2P020?ooo`L02NX:00<0oooo00WZ2P3oool0
0P09jPX00`3oool02NX:0?ooo`0500WZ2P80oooo0`09jPX01@3oool02NX:00WZ2P09jPX0oooo0080
2NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0400WZ2P050?ooo`09jPX02NX:00WZ
2P3oool01`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX01P3oool02NX:0?oo
o`3oool02NX:0?ooo`H02NX:00@0oooo00WZ2P3oool02NX:0P3oool700WZ2P040?ooo`09jPX02NX:
0?ooo`@02NX:0P3oool200WZ2P<0oooo0`09jPX00`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX0
2NX:0080oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool500WZ2P040?ooo`09jPX02NX:0?ooo`80
2NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:0?ooo`@02NX:0P3oool200WZ
2P030?ooo`09jPX0oooo00D02NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPX0
0`3oool02NX:00WZ2P0D0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0803oool200WZ2P<0oooo0P09jPX00`3oool02NX:0?ooo`020?oo
o`802NX:0P3oool200WZ2P<0oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool0
oooo00802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`H02NX:00@0oooo00WZ2P09jPX0oooo0P09
jPX00`3oool02NX:0?ooo`0500WZ2P80oooo0`09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:
00<0oooo00WZ2P09jPX03@09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00L0oooo00WZ2P09
jPX02NX:0?ooo`09jPX0oooo00802NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool600WZ2P040?oo
o`09jPX0oooo00WZ2P80oooo1`09jPX0103oool02NX:00WZ2P3oool400WZ2P80oooo0`09jPX20?oo
o`@02NX:0P3oool400WZ2P030?ooo`09jPX02NX:0080oooo00P02NX:0?ooo`09jPX0oooo00WZ2P3o
ool02NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`0300WZ2P3oool02NX:0080
oooo00@02NX:0?ooo`09jPX0oooo1009jPX20?ooo`802NX:00<0oooo00WZ2P3oool01@09jPX20?oo
o`0400WZ2P3oool02NX:00WZ2P<0oooo0P09jPX00`3oool02NX:00WZ2P0D0?ooo`0300WZ2P3oool0
oooo00/0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0803oool00`09
jPX0oooo00WZ2P020?ooo`802NX:00<0oooo00WZ2P3oool00P3oool200WZ2P80oooo0P09jPX30?oo
o`802NX:00@0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00D02NX:
0?ooo`09jPX02NX:0?ooo`0500WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:
0?ooo`0500WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0`09jPX00`3oool02NX:00WZ2P0400WZ2P03
0?ooo`09jPX02NX:00H02NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`<02NX:0P3o
ool200WZ2P030?ooo`09jPX0oooo00802NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool600WZ2P04
0?ooo`09jPX0oooo00WZ2P80oooo1`09jPX0103oool02NX:00WZ2P3oool400WZ2P80oooo0`09jPX2
0?ooo`@02NX:0P3oool400WZ2P030?ooo`09jPX02NX:0080oooo00P02NX:0?ooo`09jPX0oooo00WZ
2P3oool02NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`0300WZ2P3oool02NX:
0080oooo0P09jPX20?ooo`@02NX:0P3oool300WZ2P80oooo1@09jPX20?ooo`0400WZ2P3oool02NX:
00WZ2P<0oooo0P09jPX00`3oool02NX:00WZ2P0D0?ooo`0300WZ2P3oool0oooo00/0oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0803oool00`09jPX0oooo00WZ2P020?oo
o`802NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P<0oooo00@02NX:0?ooo`3oool0oooo0P09jPX0
103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool01009jPX0oooo00WZ
2P09jPX20?ooo`@02NX:00@0oooo00WZ2P09jPX02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00<0
2NX:0P3oool00`09jPX0oooo00WZ2P0400WZ2P030?ooo`09jPX02NX:00<02NX:00D0oooo00WZ2P09
jPX02NX:0?ooo`0500WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ2P80oooo
0P09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P03
0?ooo`09jPX0oooo00802NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool500WZ2P040?ooo`09jPX0
2NX:0?ooo`@02NX:0P3oool300WZ2P80oooo1009jPX20?ooo`@02NX:00<0oooo00WZ2P09jPX00P3o
ool00`09jPX0oooo0?ooo`0200WZ2P030?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P09jPX0oooo
0P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo0P09jPX20?ooo`@02NX:0P3oool300WZ2P80oooo
1009jPX30?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00<02NX:0?ooo`3oool00P09jPXD0?ooo`03
00WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
8@3oool200WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`802NX:0`3oool01009jPX0
oooo0?ooo`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX2
0?ooo`0400WZ2P3oool02NX:00WZ2P80oooo1009jPX0103oool02NX:00WZ2P09jPX20?ooo`<02NX:
00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`D0
2NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00@0oooo
00WZ2P09jPX02NX:0P3oool200WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`0300WZ2P3o
ool0oooo00@02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:00<02NX:
00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P80oooo0`09jPX20?ooo`@02NX:0P3oool400WZ2P03
0?ooo`09jPX0oooo0080oooo00@02NX:0?ooo`3oool02NX:0P3oool01009jPX0oooo00WZ2P09jPX2
0?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool300WZ2P040?ooo`09jPX0oooo00WZ2P80oooo1009
jPX20?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo
00<02NX:0?ooo`3oool00P09jPXD0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool08@3oool200WZ2P80oooo00D02NX:0?ooo`09jPX0oooo
00WZ2P020?ooo`802NX:0`3oool200WZ2P<0oooo00<02NX:0?ooo`3oool00P09jPX30?ooo`0400WZ
2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool400WZ2P040?ooo`09jPX02NX:
00WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo
00WZ2P09jPX00P3oool400WZ2P050?ooo`09jPX02NX:00WZ2P3oool01@09jPX0103oool02NX:00WZ
2P3oool300WZ2P040?ooo`09jPX02NX:00WZ2P80oooo0P09jPX20?ooo`802NX:00<0oooo00WZ2P09
jPX00P3oool00`09jPX0oooo0?ooo`0400WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool01009
jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`D02NX:0P3oool300WZ2P80oooo00@0
2NX:0?ooo`09jPX02NX:0P3oool400WZ2P030?ooo`09jPX0oooo0080oooo00@02NX:0?ooo`3oool0
2NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`802NX:00<0oooo00WZ2P3oool00P3oool300WZ
2P040?ooo`09jPX0oooo00WZ2P80oooo0P09jPX0103oool02NX:0?ooo`3oool300WZ2P030?ooo`09
jPX0oooo00<02NX:0`3oool400WZ2P80oooo0P09jPX0103oool02NX:0?ooo`09jPXD0?ooo`0300WZ
2P3oool0oooo00/0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool08@3o
ool200WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`0400WZ2P3oool0oooo0?ooo`80
2NX:0`3oool00`09jPX0oooo0?ooo`0200WZ2P<0oooo00@02NX:0?ooo`09jPX02NX:0P3oool01009
jPX0oooo00WZ2P09jPX20?ooo`@02NX:00@0oooo00WZ2P3oool02NX:0P3oool300WZ2P030?ooo`09
jPX0oooo00@02NX:00<0oooo00WZ2P3oool00P09jPX01@3oool02NX:0?ooo`09jPX0oooo00@02NX:
00@0oooo00WZ2P09jPX0oooo1P09jPX0103oool02NX:00WZ2P3oool300WZ2P040?ooo`09jPX02NX:
00WZ2P80oooo0P09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo0?ooo`04
00WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool01009jPX0oooo00WZ2P3oool200WZ2P040?oo
o`09jPX0oooo0?ooo`D02NX:0P3oool300WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool600WZ
2P<0oooo00@02NX:0?ooo`3oool02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`802NX:00H0
oooo00WZ2P3oool0oooo00WZ2P3oool200WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`03
00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool00`09jPX30?ooo`@02NX:0P3oool2
00WZ2P040?ooo`09jPX0oooo00WZ2Q@0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0Q0?ooo`802NX:0`3oool200WZ2P030?ooo`09jPX0
oooo0080oooo0P09jPX20?ooo`802NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00@0
2NX:0?ooo`09jPX02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`D02NX:00<0oooo00WZ2P09
jPX00P3oool300WZ2P030?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P3oool00P09jPX01`3oool0
2NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX0
2NX:00802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P80oooo0P09jPX20?ooo`802NX:00<0
oooo00WZ2P09jPX00P3oool00`09jPX0oooo0?ooo`0400WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0
0P3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`03
00WZ2P3oool0oooo00<02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`H02NX:0`3oool01009
jPX0oooo0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo1009jPX20?ooo`0;00WZ2P3o
ool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P02
00WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P80oooo
0P09jPX0103oool02NX:0?ooo`09jPXD0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool08@3oool00`09jPX0oooo00WZ2P020?ooo`802NX:
00<0oooo00WZ2P3oool00P3oool200WZ2P80oooo0P09jPX30?ooo`802NX:00@0oooo00WZ2P3oool0
2NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo1@09jPX0
0`3oool02NX:00WZ2P020?ooo`0300WZ2P3oool02NX:00802NX:00<0oooo00WZ2P3oool00P09jPX0
0`3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX00`3oool02NX:00WZ
2P0500WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01@09jPX20?ooo`802NX:0P3o
ool200WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?ooo`3oool01009jPX01@3oool02NX:00WZ
2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080
2NX:0P3oool00`09jPX0oooo0?ooo`0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool200WZ
2P040?ooo`09jPX02NX:00WZ2P<0oooo00@02NX:0?ooo`3oool02NX:0P3oool01009jPX0oooo00WZ
2P09jPX20?ooo`@02NX:0P3oool02`09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09
jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2P80
oooo00@02NX:0?ooo`09jPX02NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ2Q@0oooo00<02NX:
0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0Q0?oo
o`0300WZ2P3oool02NX:0080oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`802NX:0P3oool200WZ
2P<0oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo0`09
jPX20?ooo`D02NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09
jPX0oooo00802NX:00<0oooo00WZ2P3oool01P09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0`09
jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P09jPX0
0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?ooo`3oool01009jPX01@3oool02NX:
00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P09jPX20?ooo`0300WZ2P3oool0oooo0080
2NX:0P3oool00`09jPX0oooo0?ooo`0300WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?ooo`3o
ool00P09jPX0103oool02NX:00WZ2P09jPX30?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00@02NX:
0?ooo`09jPX02NX:0P3oool400WZ2P80oooo00<02NX:0?ooo`09jPX00`09jPX01@3oool02NX:0?oo
o`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ
2P80oooo00@02NX:0?ooo`09jPX02NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ2Q@0oooo00<0
2NX:0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0Q
0?ooo`0300WZ2P3oool02NX:0080oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool2
00WZ2P<0oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo
00<02NX:0?ooo`09jPX00`3oool400WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0300WZ
2P030?ooo`09jPX0oooo00@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0
2NX:00802NX:0P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX02009
jPX00`3oool02NX:00WZ2P020?ooo`802NX:0P3oool01009jPX0oooo0?ooo`09jPX20?ooo`@02NX:
00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`D02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80
oooo00<02NX:0?ooo`3oool00`09jPX00`3oool02NX:00WZ2P020?ooo`0300WZ2P3oool0oooo0080
2NX:00@0oooo00WZ2P09jPX02NX:0P3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo00@02NX:
0?ooo`09jPX02NX:0P3oool400WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0P09jPX01@3oool02NX:
0?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P09jPX02NX:0P3oool00`09jPX0oooo00WZ2P0200WZ
2P80oooo00@02NX:0?ooo`09jPX02NX:0`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2Q@0oooo
00<02NX:0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0R0?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPX30?ooo`0400WZ
2P3oool0oooo0?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ
2P80oooo00<02NX:0?ooo`09jPX00`3oool400WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?oo
o`0200WZ2P030?ooo`09jPX02NX:00D02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00D0
2NX:0P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo1`09jPX0
0`3oool02NX:00WZ2P020?ooo`802NX:0P3oool01009jPX0oooo0?ooo`09jPX20?ooo`@02NX:00D0
oooo00WZ2P09jPX0oooo00WZ2P020?ooo`D02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo
00<02NX:0?ooo`3oool00`09jPX00`3oool02NX:00WZ2P020?ooo`0300WZ2P3oool0oooo00802NX:
00@0oooo00WZ2P09jPX02NX:0P3oool01`09jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX00P3oool2
00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool01009jPX0oooo00WZ2P3oool300WZ2P80oooo
00<02NX:0?ooo`3oool00P09jPX0103oool02NX:00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:0080
2NX:0P3oool01009jPX0oooo00WZ2P09jPX30?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:503o
ool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo0280oooo0P09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P<0oooo00@0
2NX:0?ooo`3oool0oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo0080
2NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`@02NX:0P3oool200WZ2P030?ooo`09jPX0oooo
00802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo
00D02NX:0P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo1`09
jPX00`3oool02NX:00WZ2P030?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool0
1@09jPX0103oool02NX:0?ooo`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0
oooo0?ooo`0200WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX0103oool02NX:00WZ2P09jPX20?oo
o`0300WZ2P3oool0oooo00802NX:00@0oooo00WZ2P09jPX02NX:0P3oool01`09jPX0oooo0?ooo`3o
ool02NX:0?ooo`09jPX00P3oool200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool01009jPX0
oooo00WZ2P3oool300WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX01P3oool02NX:00WZ2P09jPX0
oooo00WZ2P80oooo0`09jPX20?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX01@3oool02NX:
0?ooo`3oool02NX:01@0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`0R0?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:00<0
oooo00@02NX:0?ooo`3oool0oooo0P09jPX20?ooo`802NX:0P3oool200WZ2P80oooo00<02NX:0?oo
o`3oool00P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo1009jPX20?ooo`802NX:00H0oooo
00WZ2P3oool0oooo00WZ2P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00D0oooo00WZ2P3o
ool02NX:0?ooo`0300WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0`09jPX00`3oool02NX:0?ooo`04
00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00`3oool01009jPX0oooo0?oo
o`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00`0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:
0?ooo`09jPX0oooo00WZ2P3oool200WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`0300WZ
2P3oool0oooo00802NX:00@0oooo00WZ2P09jPX02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P04
0?ooo`09jPX02NX:00WZ2P80oooo00L02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:0080oooo0P09
jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00L02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:
0080oooo00<02NX:0?ooo`3oool01P09jPX0103oool02NX:0?ooo`3oool300WZ2P80oooo0P09jPX0
103oool02NX:0?ooo`3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX0503oool00`09jPX0oooo
0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0280oooo0P09
jPX30?ooo`802NX:00<0oooo00WZ2P3oool00P3oool01009jPX0oooo0?ooo`3oool200WZ2P<0oooo
00<02NX:0?ooo`3oool00P09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09
jPX02NX:0P3oool400WZ2P80oooo0P09jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`<02NX:00@0
oooo00WZ2P09jPX0oooo1009jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:0P3oool01009jPX0
oooo00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00@02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0
0`3oool02NX:00WZ2P030?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00P09
jPX0303oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`<02NX:00@0
oooo00WZ2P09jPX0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00@0oooo00WZ2P09jPX0
2NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00L02NX:0?oo
o`3oool0oooo00WZ2P3oool02NX:0080oooo0P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo
00L02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00`09jPX01@3o
ool02NX:00WZ2P3oool02NX:0080oooo0`09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo
0P09jPX01@3oool02NX:0?ooo`3oool02NX:01@0oooo00<02NX:0?ooo`3oool02`3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool02NX:0080oooo
0P09jPX00`3oool02NX:0?ooo`020?ooo`802NX:0P3oool200WZ2P<0oooo00<02NX:0?ooo`3oool0
0P09jPX30?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool400WZ
2P80oooo0P09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:00<0oooo00WZ2P09jPX01009jPX0
1P3oool02NX:00WZ2P3oool02NX:0?ooo`<02NX:0P3oool300WZ2P80oooo0P09jPX00`3oool02NX:
00WZ2P0400WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX00`3oool01009jPX0oooo
0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00`0oooo00WZ2P09jPX0oooo00WZ2P3oool0
2NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool00`09
jPX0oooo0?ooo`0200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00H02NX:0?ooo`09jPX0oooo00WZ
2P3oool300WZ2P80oooo00L02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:0080oooo0P09jPX20?oo
o`<02NX:0`3oool01`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX00P3oool00`09jPX0oooo00WZ
2P0300WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1009jPX00`3oool02NX:0?ooo`0300WZ2P80
oooo0P09jPX01@3oool02NX:0?ooo`3oool02NX:01@0oooo00<02NX:0?ooo`3oool02`3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool02NX:0080
oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`802NX:0P3oool200WZ2P<0oooo0P09jPX0103oool0
2NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3o
ool00`09jPX0oooo00WZ2P0200WZ2P0;0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo
00WZ2P3oool02009jPX00`3oool02NX:00WZ2P0200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo0`09
jPX20?ooo`802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0700WZ2P80oooo00@0
2NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P0<0?ooo`09jPX02NX:0?ooo`09
jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0`09jPX0103oool02NX:00WZ2P3oool200WZ2P80
oooo00@02NX:0?ooo`3oool02NX:0P3oool300WZ2P80oooo00<02NX:0?ooo`09jPX00P09jPX0103o
ool02NX:00WZ2P09jPX20?ooo`0700WZ2P3oool0oooo0?ooo`09jPX0oooo00WZ2P020?ooo`802NX:
0P3oool300WZ2P80oooo00X02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0P3o
ool400WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1009jPX00`3oool02NX:0?ooo`0300WZ2P80
oooo0P09jPX01@3oool02NX:0?ooo`3oool02NX:01<0oooo00<02NX:0?ooo`3oool0303oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0R0?ooo`0300WZ2P3oool02NX:0080
oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool200WZ2P<0oooo0P09jPX0103oool0
2NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3o
ool00`09jPX0oooo00WZ2P0200WZ2P80oooo0P09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3o
ool02009jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:0P3oool300WZ2P80oooo0P09jPX00`3o
ool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00L02NX:0P3oool01009jPX0oooo0?ooo`09jPX2
0?ooo`0300WZ2P3oool0oooo00802NX:00`0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09
jPX0oooo00WZ2P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool01009jPX0oooo0?oo
o`09jPX20?ooo`<02NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P040?ooo`09jPX02NX:00WZ2P80
oooo00<02NX:0?ooo`3oool00P09jPX00`3oool02NX:0?ooo`0300WZ2P80oooo0`09jPX20?ooo`0:
00WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX00`3oool02NX:
0?ooo`0200WZ2P030?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`0400WZ
2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0<0?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02<0oooo0P09jPX20?ooo`0500WZ
2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P<0oooo00@02NX:0?ooo`3oool0oooo0P09jPX0103o
ool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:
0P3oool00`09jPX0oooo00WZ2P0200WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`0300WZ2P030?oo
o`09jPX02NX:00@02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0300WZ2P040?oo
o`09jPX02NX:00WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00L0
2NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00`0oooo00WZ
2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ2P040?ooo`09jPX02NX:
0?ooo`802NX:0P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00<0oooo00WZ2P09jPX01009
jPX0103oool02NX:00WZ2P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo00WZ2P3oool0
0`09jPX20?ooo`<02NX:0P3oool02P09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09
jPX20?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P050?ooo`09
jPX0oooo00WZ2P3oool00`09jPX20?ooo`0300WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`3oool0
4@3oool00`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo02<0oooo0P09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P<0oooo
00@02NX:0?ooo`3oool0oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool0oooo
00WZ2P<0oooo0`09jPX20?ooo`0300WZ2P3oool02NX:00802NX:0P3oool200WZ2P030?ooo`09jPX0
oooo00<02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0
2NX:00<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P020?ooo`D02NX:00<0oooo
00WZ2P09jPX01`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00@0oooo00WZ2P3oool0oooo0P09
jPX0103oool02NX:00WZ2P3oool200WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0`09jPX0103oool0
2NX:00WZ2P3oool200WZ2P80oooo1009jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX01009jPX00`3o
ool02NX:00WZ2P030?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo00WZ2P3oool00`09jPX20?oo
o`<02NX:0P3oool02P09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`80
2NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX0oooo00WZ
2P3oool00`09jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`3oool04@3oool0
0`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
02<0oooo0P09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P<0oooo0P09jPX2
0?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo0`09
jPX20?ooo`0300WZ2P3oool02NX:00802NX:0P3oool200WZ2P030?ooo`09jPX0oooo00<02NX:00@0
oooo00WZ2P09jPX0oooo0`09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00<0
2NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P020?ooo`D02NX:00D0oooo00WZ2P09
jPX02NX:0?ooo`0500WZ2P80oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`D02NX:00@0
oooo00WZ2P09jPX02NX:0P3oool01009jPX0oooo00WZ2P3oool300WZ2P040?ooo`09jPX02NX:0?oo
o`802NX:0P3oool400WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:
00<0oooo00<02NX:0?ooo`3oool00P09jPX00`3oool02NX:0?ooo`0300WZ2P80oooo0`09jPX20?oo
o`0:00WZ2P3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX00`3oool0
2NX:0?ooo`0300WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?oo
o`802NX:00<0oooo00WZ2P3oool00P3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo
00`0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool08`3oool200WZ2P<0
oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3oool200WZ
2P040?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`0300WZ2P3oool0
2NX:00<0oooo00<02NX:0?ooo`09jPX00P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo0P09jPX0
0`3oool02NX:0?ooo`0400WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1P09jPX00`3oool02NX:
0?ooo`0200WZ2P030?ooo`09jPX02NX:0080oooo1@09jPX01@3oool02NX:0?ooo`09jPX0oooo00D0
2NX:0P3oool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1@09jPX0103oool02NX:00WZ2P09
jPX20?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`@0
2NX:0P3oool300WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX00`3oool00`09jPX0
oooo0?ooo`0200WZ2P030?ooo`09jPX0oooo00<02NX:0P3oool300WZ2P80oooo00D02NX:0?ooo`09
jPX02NX:0?ooo`0200WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX00`3oool02NX:0?ooo`0300WZ
2P80oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo
00WZ2P3oool00P3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo00`0oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool08`3oool00`09jPX0oooo00WZ2P020?oo
o`802NX:00<0oooo00WZ2P3oool00P3oool200WZ2P80oooo0P09jPX30?ooo`0300WZ2P3oool0oooo
00802NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00<02NX:0?ooo`09jPX00`3oool00`09
jPX0oooo00WZ2P0200WZ2P80oooo0`09jPX20?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX00`3o
ool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00<02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3o
ool200WZ2P030?ooo`09jPX02NX:0080oooo1@09jPX01@3oool02NX:0?ooo`09jPX0oooo00D02NX:
0P3oool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo2@09jPX20?ooo`0400WZ2P3oool02NX:
0?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`@02NX:0P3oool300WZ2P030?ooo`09
jPX0oooo00@02NX:00<0oooo00WZ2P09jPX00`3oool00`09jPX0oooo0?ooo`0200WZ2P030?ooo`09
jPX0oooo00<02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool0
0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`802NX:
00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo0080
oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo02<0oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P030?oo
o`09jPX0oooo0080oooo0P09jPX20?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`0200WZ2P<0oooo
00@02NX:0?ooo`09jPX02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:
00802NX:0P3oool300WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`0400WZ2P0:0?ooo`09jPX02NX:
0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX01@3oool0
2NX:00WZ2P09jPX0oooo00D02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX0
oooo00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool900WZ2P80oooo00@02NX:0?ooo`09jPX0
oooo0`09jPX00`3oool02NX:0?ooo`0300WZ2P80oooo1009jPX30?ooo`802NX:00<0oooo00WZ2P3o
ool01009jPX00`3oool02NX:00WZ2P020?ooo`0400WZ2P3oool0oooo0?ooo`<02NX:0P3oool300WZ
2P030?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P0400WZ2P80oooo00@02NX:0?oo
o`09jPX0oooo1`09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00H0oooo00WZ2P09jPX0oooo
00WZ2P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:4`3oool00`09jPX0oooo0?ooo`0<0?oo
o`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02@0oooo0P09jPX20?ooo`80
2NX:00<0oooo00WZ2P3oool00P3oool200WZ2P80oooo0P09jPX30?ooo`802NX:00@0oooo00WZ2P3o
ool02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<0
2NX:0?ooo`09jPX00P09jPX20?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX0oooo00@02NX:00X0
oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo1009jPX0103oool02NX:00WZ2P3o
ool300WZ2P030?ooo`09jPX02NX:00<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0400WZ2P030?oo
o`09jPX0oooo00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool900WZ2P80oooo00@02NX:0?oo
o`09jPX0oooo1@09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00`09jPX30?ooo`802NX:
00<0oooo00WZ2P3oool01009jPX00`3oool02NX:00WZ2P020?ooo`0700WZ2P3oool0oooo0?ooo`09
jPX0oooo00WZ2P020?ooo`<02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0300WZ2P3oool02NX:
00@02NX:0P3oool01009jPX0oooo00WZ2P3oool700WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09
jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2Q<0
oooo00<02NX:0?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`0T0?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPX20?ooo`80
2NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool0
1009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:00<02NX:00@0oooo00WZ2P09jPX02NX:
0P3oool400WZ2P030?ooo`09jPX02NX:00802NX:00X0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:
0?ooo`09jPX0oooo0`09jPX0103oool02NX:00WZ2P3oool400WZ2P80oooo1009jPX01@3oool02NX:
0?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P3oool00P09jPX01P3oool02NX:00WZ2P3oool02NX:
0?ooo`T02NX:0P3oool01009jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:
00<0oooo00WZ2P3oool00`09jPX30?ooo`0500WZ2P3oool0oooo00WZ2P3oool01009jPX00`3oool0
2NX:00WZ2P020?ooo`0700WZ2P3oool0oooo0?ooo`09jPX0oooo00WZ2P020?ooo`<02NX:00<0oooo
00WZ2P3oool00P09jPX20?ooo`0300WZ2P3oool02NX:00@02NX:00H0oooo00WZ2P3oool0oooo00WZ
2P3oool700WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX02@3oool02NX:00WZ2P3oool02NX:
0?ooo`09jPX0oooo00WZ2P030?ooo`802NX:4`3oool00`09jPX0oooo0?ooo`0<0?ooo`030000003o
ool0oooo00D0oooo00070?ooo`030000003oool0oooo02@0oooo0P09jPX20?ooo`0500WZ2P3oool0
2NX:0?ooo`09jPX00P3oool200WZ2P<0oooo00@02NX:0?ooo`3oool0oooo0P09jPX0103oool02NX:
0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool0
0`09jPX0oooo00WZ2P0300WZ2P040?ooo`09jPX02NX:00WZ2P80oooo1009jPX20?ooo`H02NX:0P3o
ool200WZ2P030?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P09jPX0oooo1009jPX20?ooo`@02NX:
00D0oooo00WZ2P3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3o
ool00P09jPX00`3oool02NX:00WZ2P0500WZ2P080?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3o
ool200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX30?ooo`0500WZ
2P3oool0oooo00WZ2P3oool01009jPX00`3oool02NX:00WZ2P020?ooo`0700WZ2P3oool0oooo0?oo
o`09jPX0oooo00WZ2P020?ooo`<02NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`3o
ool500WZ2P060?ooo`09jPX0oooo0?ooo`09jPX0oooo1`09jPX01@3oool02NX:00WZ2P09jPX0oooo
00802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:0?ooo`020?ooo`802NX:4`3oool0
0`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
02@0oooo0P09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P<0oooo00@02NX:
0?ooo`3oool0oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80
oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo0?ooo`0300WZ2P040?ooo`09jPX02NX:
00WZ2P80oooo1009jPX20?ooo`H02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00<02NX:00<0
oooo00WZ2P09jPX01@09jPX20?ooo`@02NX:00<0oooo00WZ2P3oool01P09jPX00`3oool02NX:0?oo
o`0200WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX01@09jPX0203oool02NX:0?oo
o`3oool02NX:0?ooo`09jPX0oooo0P09jPX0103oool02NX:00WZ2P3oool500WZ2P040?ooo`09jPX0
2NX:00WZ2P<0oooo00D02NX:0?ooo`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:0080oooo
00L02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:0080oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3o
ool200WZ2P040?ooo`09jPX0oooo0?ooo`D02NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool700WZ
2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0
oooo0080oooo0P09jPXC0?ooo`0300WZ2P3oool0oooo00`0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0903oool200WZ2P<0oooo0P09jPX00`3oool02NX:0?ooo`020?oo
o`0400WZ2P3oool0oooo0?ooo`802NX:0P3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00@0
2NX:0?ooo`09jPX02NX:0`3oool300WZ2P80oooo00<02NX:0?ooo`3oool00`09jPX00`3oool02NX:
00WZ2P0200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P80oooo
00<02NX:0?ooo`09jPX01@09jPX00`3oool02NX:00WZ2P0500WZ2P80oooo1009jPX00`3oool02NX:
0?ooo`0600WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool300WZ
2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0P3oool01009jPX0oooo00WZ2P3oool200WZ2P040?oo
o`09jPX02NX:0?ooo`D02NX:0P3oool200WZ2P80oooo0P09jPX20?ooo`0300WZ2P3oool02NX:0080
2NX:00@0oooo00WZ2P09jPX02NX:0P3oool01`09jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX00P3o
ool01009jPX0oooo00WZ2P3oool400WZ2P040?ooo`09jPX0oooo0?ooo`D02NX:00H0oooo00WZ2P3o
ool0oooo00WZ2P3oool600WZ2P80oooo0`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool0
0`09jPX00`3oool02NX:0?ooo`020?ooo`802NX:4`3oool00`09jPX0oooo0?ooo`0<0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02@0oooo00<02NX:0?ooo`09jPX00P3o
ool200WZ2P030?ooo`09jPX0oooo0080oooo00@02NX:0?ooo`3oool0oooo0P09jPX20?ooo`802NX:
00@0oooo00WZ2P3oool02NX:0P3oool01009jPX0oooo0?ooo`09jPX30?ooo`<02NX:0P3oool00`09
jPX0oooo0?ooo`0300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool00P09jPX20?oo
o`0300WZ2P3oool02NX:00<02NX:0P3oool00`09jPX0oooo00WZ2P0400WZ2P030?ooo`09jPX02NX:
00L02NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`H02NX:00D0oooo00WZ2P3oool0
2NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0300WZ
2P80oooo00@02NX:0?ooo`09jPX0oooo0P09jPX0103oool02NX:00WZ2P3oool500WZ2P80oooo0P09
jPX20?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo
00P02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P3oool01009jPX0
103oool02NX:0?ooo`09jPX20?ooo`<02NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool600WZ2P80
oooo0`09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`02
0?ooo`802NX:4`3oool00`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00070?oo
o`030000003oool0oooo02@0oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P030?ooo`09jPX0oooo
0080oooo0P09jPX20?ooo`802NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:
0?ooo`3oool00P09jPX20?ooo`<02NX:0P3oool00`09jPX0oooo0?ooo`0600WZ2P0;0?ooo`09jPX0
oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool01009jPX20?ooo`0300WZ2P3oool02NX:
00L02NX:00<0oooo00WZ2P09jPX01009jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo
1P09jPX20?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX0103oool02NX:00WZ2P3oool600WZ
2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool500WZ2P80oooo0P09
jPX20?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo
00@02NX:0?ooo`3oool02NX:0P3oool01`09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool01009jPX0
103oool02NX:0?ooo`09jPX20?ooo`802NX:0P3oool01@09jPX0oooo0?ooo`09jPX0oooo00H02NX:
00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX00`3oool02NX:
0?ooo`020?ooo`802NX:4`3oool00`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo02D0oooo0P09jPX20?ooo`802NX:00<0oooo00WZ2P3oool00P3o
ool200WZ2P80oooo0P09jPX30?ooo`0300WZ2P3oool0oooo00802NX:0P3oool00`09jPX0oooo0?oo
o`0200WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0500WZ2P0:0?ooo`09
jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`H02NX:0P3oool:00WZ2P030?ooo`09jPX0
oooo00@02NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`H02NX:0P3oool200WZ2P04
0?ooo`09jPX02NX:0?ooo`<02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool400WZ2P050?ooo`09
jPX0oooo00WZ2P3oool01@09jPX00`3oool02NX:00WZ2P0300WZ2P80oooo0P09jPX20?ooo`802NX:
0P3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P3oool0
oooo00WZ2P020?ooo`0700WZ2P3oool02NX:00WZ2P3oool02NX:0?ooo`0400WZ2P040?ooo`09jPX0
oooo00WZ2P80oooo0P09jPX20?ooo`0700WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`0400WZ2P03
0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`802NX:0P3oool01009jPX0
oooo0?ooo`3oool200WZ2Q<0oooo00<02NX:0?ooo`3oool0303oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0U0?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:
0080oooo0P09jPX20?ooo`802NX:0`3oool200WZ2P030?ooo`09jPX02NX:00<0oooo00@02NX:0?oo
o`09jPX02NX:0P3oool00`09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool02NX:00@02NX:00X0oooo
00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo1P09jPX20?ooo`802NX:00<0oooo00WZ
2P09jPX01@09jPX00`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ
2P3oool01P09jPX20?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX01P3oool02NX:00WZ2P3o
ool02NX:0?ooo`@02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0500WZ2P030?ooo`09jPX02NX:00<0
2NX:0P3oool200WZ2P80oooo0P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo1009jPX01@3o
ool02NX:0?ooo`3oool02NX:0080oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00@02NX:
00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0
oooo00WZ2P0300WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`80
2NX:00<0oooo00WZ2P3oool00`3oool200WZ2Q<0oooo00<02NX:0?ooo`3oool0303oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0U0?ooo`802NX:0P3oool01@09jPX0oooo
00WZ2P3oool02NX:0080oooo0P09jPX20?ooo`802NX:0`3oool200WZ2P040?ooo`09jPX0oooo00WZ
2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3o
ool02NX:00@02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00@0
2NX:0P3oool200WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool0
2NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ
2P040?ooo`09jPX02NX:0?ooo`<02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool400WZ2P050?oo
o`09jPX0oooo00WZ2P3oool01@09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo0P09jPX20?oo
o`802NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`@02NX:00D0oooo00WZ2P3oool0oooo00WZ
2P020?ooo`0500WZ2P3oool02NX:00WZ2P3oool01P09jPX01@3oool02NX:0?ooo`09jPX0oooo00<0
2NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:00<02NX:00P0oooo00WZ2P09
jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX0oooo00<0oooo0P09
jPXC0?ooo`0300WZ2P3oool0oooo00`0oooo00<000000?ooo`3oool01@3oool000L0oooo00<00000
0?ooo`3oool09@3oool200WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`802NX:0`3o
ool01009jPX0oooo0?ooo`3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09
jPX02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:00<02NX:00L0oooo
00WZ2P09jPX02NX:0?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX20?ooo`80
2NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo00@0
2NX:00<0oooo00WZ2P3oool00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ
2P09jPX00P3oool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1009jPX01@3oool02NX:0?oo
o`09jPX0oooo00D02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`802NX:0P3oool300WZ2P03
0?ooo`09jPX0oooo00802NX:0P3oool400WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00P3oool01@09
jPX0oooo00WZ2P09jPX0oooo00802NX:00T0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P3o
ool00`09jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo00<02NX:0?ooo`09jPX00`09jPX01P3o
ool02NX:00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX00`3oool02NX:
0?ooo`030?ooo`802NX:4`3oool00`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo02D0oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P040?ooo`09
jPX0oooo0?ooo`802NX:0`3oool01009jPX0oooo0?ooo`3oool200WZ2P040?ooo`09jPX0oooo00WZ
2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3o
ool02NX:00P02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`0300WZ2P3oool02NX:00802NX:0P3o
ool200WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P3oool01009jPX00`3oool02NX:0?oo
o`0600WZ2P050?ooo`09jPX0oooo00WZ2P3oool00`09jPX0103oool02NX:00WZ2P3oool200WZ2P80
oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`@02NX:00D0oooo00WZ2P3oool02NX:0?oo
o`0500WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool200WZ2P80oooo0`09jPX00`3oool02NX:
0?ooo`0200WZ2P80oooo1009jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo00D02NX:0?ooo`09
jPX02NX:0?ooo`0200WZ2P090?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00<02NX:
00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:0?ooo`802NX:00H0oooo00WZ
2P09jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00<0oooo00WZ2P3oool0
0`3oool200WZ2Q<0oooo00<02NX:0?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0U0?ooo`0300WZ2P3oool02NX:0080oooo0P09jPX00`3oool02NX:0?oo
o`020?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80
oooo00@02NX:0?ooo`09jPX02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3oool0
2NX:00D02NX:00@0oooo00WZ2P09jPX0oooo1009jPX20?ooo`<02NX:00@0oooo00WZ2P3oool0oooo
0P09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX0
1P09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0
oooo0?ooo`0200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1009jPX01@3oool02NX:0?ooo`09
jPX0oooo00<02NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool200WZ2P80oooo0P09jPX20?ooo`@0
2NX:0P3oool200WZ2P80oooo1009jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`802NX:00@0oooo
00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo00<02NX:0?ooo`09jPX00P09
jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo00@02NX:0?ooo`09jPX0oooo0P09jPX0103oool0
2NX:00WZ2P3oool400WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00<0oooo00WZ2P3oool00`3oool2
00WZ2Q<0oooo00<02NX:0?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0U0?ooo`0300WZ2P3oool02NX:0080oooo0P09jPX00`3oool02NX:0?ooo`020?oo
o`802NX:0P3oool200WZ2P80oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool0
2NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo00WZ2P0500WZ2P040?oo
o`09jPX02NX:0?ooo`@02NX:0P3oool300WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo2009jPX0
0`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00H02NX:00D0oooo00WZ2P3oool02NX:0?oo
o`0300WZ2P80oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`0300WZ2P040?oo
o`09jPX02NX:0?ooo`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:
0?ooo`802NX:0P3oool200WZ2P80oooo1009jPX20?ooo`802NX:0P3oool500WZ2P<0oooo00D02NX:
0?ooo`09jPX02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:0P3oool00`09jPX0oooo
00WZ2P0200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00P3oool01009jPX0oooo00WZ2P3oool200WZ
2P040?ooo`09jPX02NX:0?ooo`D02NX:0`3oool200WZ2P030?ooo`09jPX0oooo00<0oooo0P09jPXB
0?ooo`0300WZ2P3oool0oooo00d0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool09P3oool200WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`802NX:0P3oool200WZ
2P<0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo0`09
jPX20?ooo`0500WZ2P3oool0oooo00WZ2P3oool00`09jPX0103oool02NX:00WZ2P3oool200WZ2P04
0?ooo`09jPX0oooo0?ooo`<02NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`H02NX:
00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0600WZ2P050?ooo`09jPX0oooo00WZ2P3o
ool00`09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00`09jPX0103o
ool02NX:00WZ2P3oool200WZ2P050?ooo`09jPX0oooo00WZ2P3oool01@09jPX00`3oool02NX:00WZ
2P020?ooo`0300WZ2P3oool0oooo00802NX:0P3oool400WZ2P80oooo0P09jPX20?ooo`802NX:00<0
oooo00WZ2P09jPX00`3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0
oooo1009jPX20?ooo`0300WZ2P3oool02NX:00802NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?oo
o`0400WZ2P3oool02NX:0?ooo`<02NX:00<0oooo00WZ2P3oool01@09jPX30?ooo`0300WZ2P3oool0
2NX:00D0oooo0P09jPXB0?ooo`0300WZ2P3oool0oooo00d0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool09P3oool200WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P02
0?ooo`802NX:0P3oool200WZ2P<0oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`0300WZ2P3oool0
oooo00802NX:0P3oool300WZ2P80oooo00D02NX:0?ooo`3oool02NX:0?ooo`0300WZ2P060?ooo`09
jPX02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`H02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ
2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`L02NX:00@0oooo00WZ2P3oool02NX:
0P3oool200WZ2P80oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`0300WZ2P06
0?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:0?ooo`0500WZ2P030?ooo`09jPX0
2NX:0080oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`@02NX:0P3oool200WZ2P80oooo0P09jPX0
0`3oool02NX:00WZ2P030?ooo`0600WZ2P3oool02NX:00WZ2P3oool02NX:0P3oool500WZ2P040?oo
o`09jPX0oooo00WZ2P80oooo0`09jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`802NX:00<0oooo
00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0500WZ2P<0oooo00<02NX:0?ooo`09jPX01@3oool2
00WZ2Q80oooo00<02NX:0?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0V0?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPX2
0?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX2
0?ooo`<02NX:0P3oool01@09jPX0oooo0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09
jPX00`3oool02NX:00WZ2P020?ooo`H02NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00H0
2NX:00<0oooo00WZ2P09jPX00P3oool700WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09
jPX00P3oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00<02NX:00<0oooo00WZ
2P09jPX00P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo
0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:0P3oool400WZ2P80oooo0P09jPX20?ooo`802NX:
00<0oooo00WZ2P09jPX00`3oool01P09jPX0oooo00WZ2P09jPX0oooo00WZ2P80oooo1@09jPX0103o
ool02NX:0?ooo`09jPX20?ooo`<02NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool200WZ2P030?oo
o`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool01@09jPX20?ooo`802NX:00<0oooo00WZ2P3oool0
103oool200WZ2Q80oooo00<02NX:0?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0V0?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo
0P09jPX20?ooo`802NX:0`3oool200WZ2P030?ooo`09jPX02NX:00<0oooo00@02NX:0?ooo`09jPX0
2NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00D02NX:0P3oool300WZ2P03
0?ooo`09jPX02NX:0080oooo00<02NX:0?ooo`09jPX00`09jPX01`3oool02NX:0?ooo`09jPX0oooo
00WZ2P3oool01P09jPX01@3oool02NX:00WZ2P09jPX0oooo00L02NX:00<0oooo00WZ2P3oool00P09
jPX00`3oool02NX:00WZ2P020?ooo`0400WZ2P3oool0oooo00WZ2P80oooo0P09jPX01@3oool02NX:
00WZ2P09jPX0oooo00@02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX0
2NX:0?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P80oooo1009jPX20?ooo`802NX:0P3o
ool200WZ2P030?ooo`09jPX02NX:00<0oooo00<02NX:0?ooo`09jPX00`09jPX20?ooo`D02NX:00@0
oooo00WZ2P3oool02NX:0P3oool300WZ2P040?ooo`09jPX0oooo00WZ2P80oooo0P09jPX00`3oool0
2NX:0?ooo`0400WZ2P80oooo0`09jPX0103oool02NX:0?ooo`3oool200WZ2P030?ooo`09jPX0oooo
00@0oooo0P09jPXB0?ooo`0300WZ2P3oool0oooo00d0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool09P3oool00`09jPX0oooo00WZ2P020?ooo`802NX:00@0oooo00WZ2P3o
ool0oooo0P09jPX30?ooo`0400WZ2P3oool0oooo0?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3o
ool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool0
1@09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo00WZ2P0300WZ2P040?oo
o`09jPX0oooo0?ooo`802NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:00WZ2P09jPX0oooo
00D02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:0080oooo00@02NX:
0?ooo`3oool02NX:0P3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX01P3oool02NX:
00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:0?ooo`03
00WZ2P80oooo1009jPX20?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX30?ooo`0300WZ2P3o
ool02NX:00<02NX:0P3oool400WZ2P0:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:
0?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX00`3oool02NX:0?ooo`0400WZ2P80oooo0`09
jPX0103oool02NX:0?ooo`3oool200WZ2P030?ooo`09jPX0oooo00@0oooo0P09jPXB0?ooo`0300WZ
2P3oool0oooo00d0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool09P3o
ool00`09jPX0oooo00WZ2P020?ooo`802NX:00<0oooo00WZ2P3oool00P3oool01@09jPX0oooo0?oo
o`3oool02NX:00<0oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ
2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:0P3o
ool300WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0400WZ2P040?ooo`09jPX0oooo0?oo
o`T02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:
0?ooo`0200WZ2P030?ooo`09jPX02NX:0080oooo00@02NX:0?ooo`3oool02NX:0P3oool200WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool01009jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00@0
oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:0?ooo`0300WZ2P80oooo1009jPX20?ooo`<02NX:
00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00@02NX:0P3oool400WZ2P0;
0?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX00P3oool00`09jPX0oooo
0?ooo`0400WZ2P030?ooo`09jPX02NX:00802NX:0P3oool300WZ2P040?ooo`09jPX0oooo0?ooo`80
2NX:00<0oooo00WZ2P3oool0103oool200WZ2Q80oooo00<02NX:0?ooo`3oool03@3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0W0?ooo`802NX:0P3oool200WZ2P030?oo
o`09jPX0oooo0080oooo00@02NX:0?ooo`3oool0oooo0P09jPX20?ooo`802NX:00@0oooo00WZ2P3o
ool02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00D0
2NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P0;0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX0
oooo00WZ2P3oool01009jPX20?ooo`0300WZ2P3oool02NX:00@02NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0200WZ2P03
0?ooo`09jPX02NX:0080oooo0P09jPX0103oool02NX:00WZ2P3oool200WZ2P050?ooo`09jPX02NX:
00WZ2P3oool01009jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0
oooo0`09jPX00`3oool02NX:0?ooo`0300WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool300WZ
2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:0P3o
ool400WZ2P0;0?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX00P3oool0
0`09jPX0oooo0?ooo`0500WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:
0`3oool200WZ2P030?ooo`09jPX0oooo00@0oooo0P09jPXB0?ooo`0300WZ2P3oool0oooo00d0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool09`3oool200WZ2P80oooo0P09
jPX00`3oool02NX:0?ooo`020?ooo`802NX:0P3oool200WZ2P80oooo0P09jPX0103oool02NX:0?oo
o`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool01@09
jPX0oooo00WZ2P09jPX0oooo00<02NX:00/0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3o
ool02NX:0?ooo`0400WZ2P80oooo00<02NX:0?ooo`09jPX01009jPX0103oool02NX:0?ooo`09jPX2
0?ooo`802NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX0
2NX:00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80
oooo0`09jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool600WZ2P030?ooo`09jPX0
oooo00<02NX:0P3oool01009jPX0oooo0?ooo`09jPX20?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo
0P09jPX20?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX20?ooo`@02NX:00/0oooo00WZ2P09
jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00D02NX:
00@0oooo00WZ2P09jPX02NX:0P3oool01009jPX0oooo00WZ2P09jPX30?ooo`<02NX:1P3oool200WZ
2Q80oooo00<02NX:0?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0W0?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPX20?oo
o`802NX:0P3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3o
ool01009jPX0oooo00WZ2P09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00`09jPX02`3oool0
2NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00D02NX:00<0oooo00WZ2P3oool0
1@09jPX0103oool02NX:0?ooo`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool0
2NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0300WZ
2P040?ooo`09jPX02NX:00WZ2P80oooo1P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3o
ool02NX:00<02NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P80oooo
0`09jPX0103oool02NX:00WZ2P3oool200WZ2P80oooo00D02NX:0?ooo`3oool02NX:0?ooo`0200WZ
2P80oooo1009jPX02`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0080
oooo00<02NX:0?ooo`3oool01@09jPX0103oool02NX:00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:
00WZ2P<0oooo0`09jPX60?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`0=0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo02L0oooo0P09jPX20?ooo`0500WZ2P3oool02NX:
0?ooo`09jPX00P3oool200WZ2P80oooo0P09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3o
ool01009jPX0oooo0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09
jPX02NX:0P3oool200WZ2P0:0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P80
oooo1009jPX00`3oool02NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:00WZ2P80oooo0P09jPX00`3o
ool02NX:00WZ2P0500WZ2P030?ooo`09jPX0oooo00H02NX:00@0oooo00WZ2P09jPX0oooo1@09jPX0
103oool02NX:00WZ2P09jPX20?ooo`H02NX:00@0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo
00WZ2P0300WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo
0?ooo`0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool01@09jPX0oooo0?ooo`09jPX0oooo
00802NX:0P3oool300WZ2P80oooo0P09jPX0203oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:
0P3oool00`09jPX0oooo0?ooo`0500WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00@02NX:0?ooo`09
jPX02NX:0P3oool400WZ2PH0oooo0P09jPXB0?ooo`0300WZ2P3oool0oooo00d0oooo00<000000?oo
o`3oool01@3oool000L0oooo00<000000?ooo`3oool09`3oool200WZ2P80oooo00D02NX:0?ooo`09
jPX0oooo00WZ2P020?ooo`802NX:0P3oool200WZ2P<0oooo00<02NX:0?ooo`3oool00P09jPX20?oo
o`0400WZ2P3oool0oooo00WZ2P<0oooo0`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo0P09
jPX00`3oool02NX:00WZ2P0300WZ2P040?ooo`09jPX02NX:00WZ2P80oooo1009jPX0103oool02NX:
0?ooo`3oool400WZ2P040?ooo`09jPX02NX:00WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P0400WZ
2P050?ooo`09jPX0oooo00WZ2P3oool01009jPX0103oool02NX:00WZ2P3oool500WZ2P040?ooo`09
jPX02NX:00WZ2P80oooo1009jPX00`3oool02NX:0?ooo`0300WZ2P80oooo00<02NX:0?ooo`09jPX0
1@09jPX0103oool02NX:00WZ2P3oool300WZ2P80oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09jPX0
oooo00802NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`802NX:0P3oool3
00WZ2P80oooo0P09jPX0203oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool01009jPX0
oooo00WZ2P3oool400WZ2P030?ooo`09jPX02NX:00<0oooo00@02NX:0?ooo`09jPX02NX:0P3oool4
00WZ2PH0oooo0P09jPXB0?ooo`0300WZ2P3oool0oooo00d0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool09`3oool00`09jPX0oooo00WZ2P020?ooo`802NX:00@0oooo00WZ
2P3oool0oooo0P09jPX20?ooo`802NX:0`3oool200WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:
0?ooo`3oool00P09jPX20?ooo`<02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`P02NX:00@0
oooo00WZ2P09jPX02NX:0P3oool400WZ2P060?ooo`09jPX0oooo0?ooo`09jPX0oooo0P09jPX0103o
ool02NX:00WZ2P09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:0?ooo`04
00WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`0700WZ2P3o
ool02NX:00WZ2P3oool02NX:0?ooo`0300WZ2P80oooo1`09jPX01@3oool02NX:00WZ2P09jPX0oooo
00<02NX:0P3oool01`09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ
2P020?ooo`0300WZ2P3oool02NX:0080oooo0P09jPX20?ooo`<02NX:0P3oool300WZ2P80oooo0`09
jPX0103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool02NX:00<02NX:00<0oooo00WZ2P09jPX0
0`3oool400WZ2P80oooo1009jPX60?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`0=0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02L0oooo00<02NX:0?ooo`09jPX00P3o
ool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0`3oool01009jPX0oooo0?ooo`3oool200WZ2P04
0?ooo`09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool300WZ2P80oooo00@02NX:
0?ooo`3oool02NX:0P3oool500WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P3oool0
1009jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`802NX:0P3oool200WZ2P80oooo0`09jPX00`3o
ool02NX:00WZ2P0600WZ2P030?ooo`09jPX0oooo00@02NX:00@0oooo00WZ2P09jPX0oooo1009jPX0
0`3oool02NX:00WZ2P0200WZ2P80oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00<02NX:
0P3oool700WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX20?ooo`0700WZ2P3oool02NX:00WZ
2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool0
1009jPX0oooo0?ooo`3oool300WZ2P80oooo0`09jPX20?ooo`<02NX:00@0oooo00WZ2P3oool02NX:
0P3oool00`09jPX0oooo00WZ2P0300WZ2P030?ooo`09jPX02NX:00<0oooo1009jPX20?ooo`@02NX:
1P3oool200WZ2Q80oooo00<02NX:0?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0X0?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX0oooo0080oooo00D0
2NX:0?ooo`3oool0oooo00WZ2P030?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool01009jPX0
oooo00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`3oool02NX:0P3oool4
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX01@3oool02NX:0?ooo`09jPX0oooo00@02NX:
0P3oool500WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX20?ooo`802NX:00<0oooo00WZ2P09
jPX00P09jPX00`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo00D02NX:00<0oooo00WZ2P09
jPX00P09jPX20?ooo`0700WZ2P3oool02NX:00WZ2P3oool02NX:0?ooo`0300WZ2P80oooo1`09jPX0
1@3oool02NX:00WZ2P09jPX0oooo00<02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00@02NX:
00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo0?ooo`<0
2NX:0P3oool300WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool02NX:0P3oool01009
jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:0080oooo1009jPX30?ooo`0400WZ2P3oool0
2NX:00WZ2PH0oooo0P09jPXB0?ooo`0300WZ2P3oool0oooo00d0oooo00<000000?ooo`3oool01@3o
ool000L0oooo00<000000?ooo`3oool0:03oool200WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`02
0?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo
00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080
2NX:0P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX00`3o
ool02NX:00WZ2P020?ooo`D02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P80oooo0P09jPX0
0`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00H02NX:00@0oooo00WZ2P09jPX0oooo0P09
jPX00`3oool02NX:00WZ2P0200WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P030?oo
o`09jPX02NX:0080oooo1@09jPX00`3oool02NX:0?ooo`0300WZ2P040?ooo`09jPX02NX:00WZ2P80
oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?oo
o`09jPX00P3oool01009jPX0oooo0?ooo`3oool300WZ2P80oooo0`09jPX00`3oool02NX:0?ooo`04
00WZ2P090?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPX20?ooo`@0
2NX:0`3oool00`09jPX0oooo00WZ2P070?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`0=0?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02P0oooo0P09jPX20?ooo`0500WZ
2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P80oooo0P09jPX20?ooo`802NX:00@0oooo00WZ2P3o
ool02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@0
2NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P040?ooo`09jPX02NX:0?ooo`80
2NX:00<0oooo00WZ2P09jPX01009jPX30?ooo`@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ
2P80oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00H02NX:00@0oooo00WZ
2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?oo
o`0200WZ2P030?ooo`09jPX02NX:0080oooo1@09jPX00`3oool02NX:0?ooo`0300WZ2P040?ooo`09
jPX02NX:00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:0080
oooo00@02NX:0?ooo`09jPX0oooo0P09jPX30?ooo`<02NX:0P3oool300WZ2P050?ooo`09jPX0oooo
00WZ2P3oool00P09jPX02@3oool02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`80
2NX:0P3oool400WZ2P80oooo1009jPX70?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`0=0?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02P0oooo0P09jPX20?ooo`0500WZ
2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P80oooo0P09jPX20?ooo`802NX:00@0oooo00WZ2P3o
ool02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@0
2NX:0?ooo`09jPX02NX:0P3oool600WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09
jPX01009jPX30?ooo`@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P80oooo0P09jPX00`3o
ool02NX:00WZ2P0200WZ2P040?ooo`09jPX0oooo0?ooo`D02NX:00@0oooo00WZ2P09jPX0oooo0P09
jPX00`3oool02NX:00WZ2P0200WZ2P80oooo1009jPX0103oool02NX:00WZ2P3oool200WZ2P80oooo
1@09jPX00`3oool02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0103oool0
2NX:00WZ2P3oool400WZ2P030?ooo`09jPX02NX:0080oooo00@02NX:0?ooo`09jPX0oooo0P09jPX3
0?ooo`<02NX:0P3oool300WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX02P3oool02NX:0?oo
o`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ2P80oooo1009jPX20?ooo`@02NX:1`3oool2
00WZ2Q80oooo00<02NX:0?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0X0?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPX2
0?ooo`802NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX02NX:
0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo1009jPX00`3o
ool02NX:00WZ2P0200WZ2P040?ooo`09jPX02NX:0?ooo`H02NX:0`3oool400WZ2P050?ooo`09jPX0
2NX:00WZ2P3oool01009jPX0103oool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80
oooo1@09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:0P3oool300WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool00P09jPX20?ooo`D02NX:00<0oooo00WZ2P3oool00`09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo1009jPX00`3oool02NX:00WZ
2P020?ooo`0400WZ2P3oool02NX:0?ooo`802NX:0`3oool300WZ2P80oooo0`09jPX01@3oool02NX:
0?ooo`09jPX0oooo00802NX:00X0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo
1009jPX00`3oool02NX:00WZ2P0200WZ2P80oooo1009jPX70?ooo`802NX:4P3oool00`09jPX0oooo
0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02P0oooo00<0
2NX:0?ooo`09jPX00P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool200WZ2P<0oooo
00<02NX:0?ooo`3oool00P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09
jPX02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`@02NX:00<0oooo00WZ2P09jPX00P09jPX0
103oool02NX:00WZ2P3oool600WZ2P<0oooo1009jPX00`3oool02NX:00WZ2P0600WZ2P040?ooo`09
jPX02NX:0?ooo`@02NX:00@0oooo00WZ2P3oool0oooo1@09jPX00`3oool02NX:00WZ2P0300WZ2P05
0?ooo`09jPX02NX:0?ooo`09jPX00P3oool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX2
0?ooo`802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool300WZ2P070?ooo`09jPX02NX:00WZ2P3o
ool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P02
0?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool300WZ2P050?oo
o`09jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:
0?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`3oool400WZ2PL0oooo0P09
jPXB0?ooo`0300WZ2P3oool0oooo00d0oooo00<000000?ooo`3oool01@3oool000L0oooo00<00000
0?ooo`3oool0:03oool00`09jPX0oooo00WZ2P020?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09
jPX30?ooo`0400WZ2P3oool0oooo0?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool01009jPX0oooo
0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool4
00WZ2P030?ooo`09jPX02NX:00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?oo
o`09jPX0oooo0080oooo0`09jPX00`3oool02NX:00WZ2P0700WZ2P040?ooo`09jPX02NX:0?ooo`@0
2NX:00@0oooo00WZ2P3oool0oooo1@09jPX00`3oool02NX:00WZ2P0300WZ2P80oooo00<02NX:0?oo
o`09jPX00P3oool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX20?ooo`802NX:00H0oooo
00WZ2P09jPX0oooo00WZ2P3oool300WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0300WZ
2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0
2NX:00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0400WZ2P050?ooo`09jPX0oooo00WZ2P3o
ool00P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`802NX:00<0oooo
00WZ2P3oool00P09jPX0103oool02NX:0?ooo`3oool400WZ2PL0oooo0P09jPXB0?ooo`0300WZ2P3o
ool0oooo00d0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0:@3oool2
00WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00`3o
ool200WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`<02NX:0P3o
ool01009jPX0oooo00WZ2P09jPX30?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:00L0oooo00WZ2P3o
ool02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P3oool01009jPX0oooo00WZ2P3o
ool900WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00@0oooo00WZ2P3oool0oooo1@09jPX20?ooo`@0
2NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`L02NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0
oooo00WZ2P0200WZ2P030?ooo`09jPX0oooo00<02NX:0P3oool200WZ2P030?ooo`09jPX0oooo00<0
2NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo00@02NX:0?oo
o`09jPX02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX00P3o
ool300WZ2P80oooo00L02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09
jPX0oooo0`09jPX20?ooo`0300WZ2P3oool02NX:00P0oooo0P09jPXB0?ooo`0300WZ2P3oool0oooo
00d0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0:@3oool200WZ2P80
oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00`3oool200WZ
2P040?ooo`09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool300WZ2P80oooo00@0
2NX:0?ooo`09jPX02NX:0`3oool300WZ2P080?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX2
0?ooo`<02NX:00<0oooo00WZ2P3oool00P3oool300WZ2P030?ooo`09jPX02NX:00L02NX:00@0oooo
00WZ2P09jPX0oooo1009jPX0103oool02NX:0?ooo`3oool200WZ2P030?ooo`09jPX02NX:0080oooo
1009jPX20?ooo`0300WZ2P3oool02NX:0080oooo1`09jPX00`3oool02NX:00WZ2P020?ooo`0300WZ
2P3oool02NX:00802NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`802NX:00<0oooo00WZ2P3oool0
0`09jPX20?ooo`<02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ
2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P80oooo0P09jPX20?ooo`<02NX:0P3oool0
1`09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool300WZ2P80
oooo00<02NX:0?ooo`09jPX0203oool200WZ2Q40oooo00<02NX:0?ooo`3oool03P3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0Y0?ooo`802NX:0P3oool01009jPX0oooo
00WZ2P09jPX30?ooo`802NX:0P3oool200WZ2P80oooo0P09jPX0103oool02NX:0?ooo`09jPX20?oo
o`0400WZ2P3oool02NX:00WZ2P80oooo0`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo0`09
jPX0203oool02NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0P3oool500WZ2P<0oooo3@09jPX0103o
ool02NX:00WZ2P3oool400WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00<0oooo00WZ2P09jPX00P3o
ool200WZ2P070?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P020?ooo`L02NX:00<0oooo00WZ2P09
jPX00P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo0P09jPX0
0`3oool02NX:0?ooo`0300WZ2P80oooo0P09jPX0203oool02NX:00WZ2P09jPX0oooo00WZ2P3oool0
2NX:0P3oool200WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P80oooo0P09jPX20?oo
o`<02NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00D0oooo
00WZ2P09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00L0oooo0P09jPXA0?ooo`0300WZ2P3o
ool0oooo00h0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0:@3oool2
00WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`802NX:0P3oool200WZ2P80oooo0P09
jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`09
jPX00P3oool01009jPX0oooo0?ooo`09jPX30?ooo`<02NX:0P3oool200WZ2P040?ooo`09jPX0oooo
00WZ2P80oooo1P09jPX20?ooo``02NX:00<0oooo00WZ2P09jPX01P09jPX0103oool02NX:0?ooo`3o
ool200WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX01`3oool02NX:0?ooo`3oool02NX:0?ooo`09
jPX00P3oool500WZ2P030?ooo`09jPX0oooo00802NX:0P3oool01009jPX0oooo00WZ2P09jPX20?oo
o`0400WZ2P3oool0oooo00WZ2P<0oooo0P09jPX00`3oool02NX:0?ooo`0300WZ2P80oooo0P09jPX0
203oool02NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0P3oool200WZ2P80oooo1009jPX02@3oool0
2NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`0400WZ2P80oooo00<02NX:0?ooo`09jPX01009
jPX00`3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:
0?ooo`070?ooo`802NX:4@3oool00`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo02T0oooo0P09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0
0P3oool200WZ2P80oooo0P09jPX20?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool01009jPX0
oooo00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`3oool02NX:0`3oool3
00WZ2P80oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`H02NX:0P3oool400WZ2P050?ooo`09
jPX0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:
0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX01`3oool02NX:0?ooo`3oool02NX:0?oo
o`09jPX00P3oool500WZ2P030?ooo`09jPX0oooo00802NX:0P3oool01009jPX0oooo00WZ2P09jPX2
0?ooo`802NX:00<0oooo00WZ2P3oool00P3oool200WZ2P030?ooo`09jPX0oooo00<02NX:0P3oool2
00WZ2P080?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX20?ooo`802NX:0P3oool400WZ2P09
0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00@02NX:0P3oool00`09jPX0oooo00WZ
2P0400WZ2P030?ooo`09jPX0oooo00802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P030?oo
o`09jPX0oooo00L0oooo0P09jPXA0?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool0:@3oool00`09jPX0oooo00WZ2P020?ooo`802NX:00@0
oooo00WZ2P3oool0oooo0P09jPX20?ooo`802NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:0080
oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo
00WZ2P<0oooo1009jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool400WZ2P040?oo
o`09jPX0oooo0?ooo`@02NX:00<0oooo00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0400WZ2P03
0?ooo`09jPX02NX:00802NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00@02NX:0?ooo`3o
ool02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:00@02NX:00<0oooo00WZ
2P09jPX00P3oool01009jPX0oooo00WZ2P09jPX20?ooo`802NX:00<0oooo00WZ2P3oool00P3oool0
1@09jPX0oooo0?ooo`09jPX0oooo00<02NX:0P3oool00`09jPX0oooo0?ooo`0300WZ2P040?ooo`09
jPX0oooo00WZ2P80oooo0P09jPX20?ooo`@02NX:00T0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo
00WZ2P3oool01009jPX20?ooo`0300WZ2P3oool02NX:00@02NX:00@0oooo00WZ2P3oool0oooo1@09
jPX01@3oool02NX:00WZ2P3oool02NX:00P0oooo0P09jPXA0?ooo`0300WZ2P3oool0oooo00h0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0:@3oool00`09jPX0oooo00WZ
2P020?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`802NX:0`3oool01@09jPX0oooo
00WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX02NX:0P3oool01009jPX0oooo00WZ2P09jPX2
0?ooo`0400WZ2P3oool02NX:00WZ2P80oooo1009jPX00`3oool02NX:00WZ2P0200WZ2P040?ooo`09
jPX02NX:0?ooo`@02NX:00@0oooo00WZ2P3oool0oooo1009jPX00`3oool02NX:0?ooo`0400WZ2P03
0?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`802NX:00<0oooo00WZ2P09
jPX00P3oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?oo
o`09jPX01009jPX00`3oool02NX:00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo1009jPX3
0?ooo`0500WZ2P3oool0oooo00WZ2P3oool00`09jPX20?ooo`0300WZ2P3oool0oooo00D02NX:00<0
oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0400WZ2P090?ooo`09jPX02NX:00WZ2P3oool0
2NX:0?ooo`09jPX0oooo00@02NX:0P3oool00`09jPX0oooo00WZ2P0600WZ2P80oooo1@09jPX01@3o
ool02NX:00WZ2P3oool02NX:00P0oooo0P09jPXA0?ooo`0300WZ2P3oool0oooo00h0oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0:P3oool200WZ2P80oooo0P09jPX0103o
ool02NX:0?ooo`3oool200WZ2P<0oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`802NX:0P3o
ool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09
jPX02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00@02NX:0P3oool00`09jPX0oooo00WZ2P05
00WZ2P80oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX0
1009jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P80
oooo00<02NX:0?ooo`3oool00`09jPX20?ooo`0300WZ2P3oool02NX:00@02NX:00<0oooo00WZ2P09
jPX00P3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:0`3oool01@09jPX0
oooo0?ooo`09jPX0oooo00802NX:0`3oool01@09jPX0oooo0?ooo`09jPX0oooo00<02NX:00<0oooo
00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0400WZ2P090?ooo`09jPX02NX:00WZ2P3oool02NX:
0?ooo`09jPX0oooo00@02NX:00@0oooo00WZ2P3oool0oooo1`09jPX20?ooo`<02NX:00D0oooo00WZ
2P3oool02NX:0?ooo`0200WZ2PL0oooo00<02NX:0?ooo`09jPX04@3oool00`09jPX0oooo0?ooo`0>
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02X0oooo0P09jPX20?oo
o`802NX:00<0oooo00WZ2P3oool00P3oool01@09jPX0oooo0?ooo`3oool02NX:00<0oooo0P09jPX0
0`3oool02NX:00WZ2P020?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:
0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool01009jPX20?oo
o`0300WZ2P3oool02NX:00802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00@02NX:00<0
oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00802NX:0P3o
ool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P3oool0oooo0`09jPX20?ooo`03
00WZ2P3oool02NX:00L02NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX02NX:0080
2NX:0`3oool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:0P3oool300WZ2P030?ooo`09jPX0oooo
00<02NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0400WZ2P090?ooo`09jPX02NX:
00WZ2P3oool02NX:0?ooo`09jPX0oooo00@02NX:00@0oooo00WZ2P3oool0oooo1`09jPX00`3oool0
2NX:00WZ2P0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX70?ooo`0300WZ2P3oool02NX:
0140oooo00<02NX:0?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0Z0?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX0oooo0080oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P030?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool01009jPX0oooo0?ooo`09jPX2
0?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo
00WZ2P0600WZ2P80oooo00@02NX:0?ooo`09jPX0oooo1@09jPX00`3oool02NX:0?ooo`0400WZ2P03
0?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0200WZ2P80
oooo0`09jPX0103oool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:0P3oool0
1009jPX0oooo00WZ2P3oool600WZ2P80oooo00<02NX:0?ooo`09jPX00P09jPX00`3oool02NX:00WZ
2P0200WZ2P80oooo0P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo0`09jPX00`3oool02NX:
0?ooo`0300WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo1009jPX0103oool0
2NX:00WZ2P3oool200WZ2P80oooo0`09jPX20?ooo`0300WZ2P3oool0oooo00L02NX:00<0oooo00WZ
2P09jPX00`09jPX0103oool02NX:00WZ2P3oool200WZ2PL0oooo00<02NX:0?ooo`09jPX04@3oool0
0`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
02X0oooo0P09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P80oooo0P09jPX2
0?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`<02NX:
0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:00H02NX:0P3oool01009jPX0
oooo00WZ2P3oool500WZ2P030?ooo`09jPX0oooo00/02NX:00<0oooo00WZ2P09jPX00P09jPX00`3o
ool02NX:00WZ2P0200WZ2P80oooo0`09jPX0103oool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX0
2NX:0?ooo`<02NX:0P3oool01009jPX0oooo00WZ2P3oool600WZ2P80oooo00<02NX:0?ooo`09jPX0
0P09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80
oooo0`09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09
jPX0oooo1009jPX0103oool02NX:00WZ2P3oool200WZ2P80oooo0`09jPX20?ooo`0500WZ2P3oool0
2NX:0?ooo`09jPX00P3oool300WZ2P030?ooo`09jPX02NX:00<02NX:00@0oooo00WZ2P09jPX0oooo
0P09jPX70?ooo`0300WZ2P3oool02NX:0140oooo00<02NX:0?ooo`3oool03P3oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0Z0?ooo`0900WZ2P3oool02NX:0?ooo`09jPX0
oooo00WZ2P3oool02NX:0080oooo0P09jPX20?ooo`802NX:0P3oool200WZ2P040?ooo`09jPX0oooo
00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool300WZ2P80oooo00@02NX:0?ooo`09jPX02NX:
0`3oool00`09jPX0oooo00WZ2P0500WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P0300WZ2P030?oo
o`09jPX0oooo00X02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00@02NX:0P3oool300WZ
2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX20?ooo`0400WZ2P3o
ool02NX:0?ooo`H02NX:00@0oooo00WZ2P3oool0oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P80
oooo0`09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX01@3oool02NX:0?ooo`3oool02NX:
0080oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo
00WZ2P09jPX0oooo0P09jPX20?ooo`<02NX:0P3oool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`@0
2NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:00WZ2P3oool200WZ2PL0oooo00<02NX:0?oo
o`09jPX04@3oool00`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo02X0oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P040?ooo`09jPX0oooo0?oo
o`802NX:0P3oool200WZ2P80oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool0
2NX:00WZ2P80oooo0`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00<02NX:0?ooo`09jPX0
0P09jPX00`3oool02NX:00WZ2P020?ooo`<02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:
0?ooo`0:00WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0400WZ2P80oooo0`09jPX0103o
ool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:0P3oool01009jPX0oooo00WZ
2P3oool600WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`<0
2NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`<02NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?oo
o`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P090?ooo`09jPX0
2NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00802NX:0P3oool01P09jPX0oooo00WZ2P3oool02NX:
0?ooo`@02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0103oool02NX:00WZ2P3oool200WZ2PL0oooo
00<02NX:0?ooo`09jPX04@3oool00`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo02/0oooo0P09jPX20?ooo`802NX:00@0oooo00WZ2P3oool0oooo
0P09jPX20?ooo`802NX:0`3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09
jPX02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00<02NX:
0?ooo`09jPX00P09jPX00`3oool02NX:00WZ2P020?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo0`09
jPX01@3oool02NX:00WZ2P09jPX0oooo00L02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo
00@02NX:0P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0`09
jPX20?ooo`0300WZ2P3oool02NX:00L02NX:00@0oooo00WZ2P3oool0oooo0`09jPX00`3oool02NX:
00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:0P3oool200WZ2P80oooo0`09jPX01@3oool02NX:
0?ooo`3oool02NX:0080oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:
00802NX:00T0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX20?ooo`0600WZ
2P3oool02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:
0?ooo`802NX:1`3oool00`09jPX0oooo00WZ2P0A0?ooo`0300WZ2P3oool0oooo00h0oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0:`3oool200WZ2P80oooo0P09jPX0103o
ool02NX:0?ooo`3oool200WZ2P80oooo0P09jPX30?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3o
ool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`3oool0
2NX:0`3oool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:0P3oool300WZ2P030?ooo`09jPX0
2NX:00@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0700WZ2P070?ooo`09jPX02NX:00WZ2P3oool0
2NX:0?ooo`0400WZ2P80oooo2@09jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool0
0`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P3oool0oooo1009
jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`802NX:0P3oool300WZ2P050?ooo`09
jPX0oooo0?ooo`09jPX00P3oool01@09jPX0oooo00WZ2P09jPX0oooo00L02NX:00T0oooo00WZ2P09
jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0
oooo0P09jPX00`3oool02NX:0?ooo`0500WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:1`3oool0
0`09jPX0oooo00WZ2P0A0?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0:`3oool200WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`020?oo
o`0500WZ2P3oool0oooo0?ooo`09jPX00`3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo00@0
2NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo00WZ2P<0
oooo00<02NX:0?ooo`09jPX00P09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ
2P09jPX00P09jPX00`3oool02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX0
1@3oool02NX:00WZ2P09jPX0oooo00H02NX:0P3oool800WZ2P080?ooo`09jPX02NX:00WZ2P3oool0
2NX:0?ooo`09jPX20?ooo`0300WZ2P3oool02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX0103o
ool02NX:0?ooo`3oool400WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0P09jPX2
0?ooo`<02NX:00L0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:0080oooo0P09jPX00`3oool02NX:
00WZ2P0200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ
2P080?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`@0
2NX:00H0oooo00WZ2P3oool02NX:0?ooo`09jPX70?ooo`0300WZ2P3oool02NX:0140oooo00<02NX:
0?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0[0?oo
o`802NX:0P3oool200WZ2P030?ooo`09jPX0oooo0080oooo00D02NX:0?ooo`3oool0oooo00WZ2P03
0?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0600WZ2P3o
ool02NX:00WZ2P3oool02NX:0P3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`D02NX:00L0oooo
00WZ2P3oool02NX:0?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P3oool00`09jPX01@3oool02NX:
00WZ2P09jPX0oooo00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:
0080oooo0P09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00<02NX:00H0oooo00WZ
2P3oool0oooo00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P3oool0oooo
1009jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`802NX:0P3oool300WZ2P070?oo
o`09jPX0oooo0?ooo`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00@02NX:00@0oooo00WZ
2P09jPX0oooo0`09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00P0oooo00WZ2P3oool0oooo
00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo1P09jPX0103oool02NX:0?ooo`09
jPX70?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo02/0oooo0P09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3o
ool200WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`0400WZ
2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool01009jPX0oooo00WZ2P09jPX2
0?ooo`0300WZ2P3oool02NX:00H02NX:00<0oooo00WZ2P3oool02009jPX01@3oool02NX:00WZ2P09
jPX0oooo00L02NX:0P3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX01P3oool02NX:
00WZ2P3oool02NX:0?ooo`<02NX:00<0oooo00WZ2P09jPX00`09jPX01P3oool02NX:0?ooo`3oool0
2NX:0?ooo`<02NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`3oool400WZ2P80oooo
0`09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0P09jPX20?ooo`<02NX:00L0oooo00WZ2P3oool0
oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool01009jPX0103oool02NX:00WZ2P3oool3
00WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX0203oool02NX:0?ooo`3oool02NX:0?ooo`09
jPX0oooo0P09jPX0103oool02NX:00WZ2P3oool600WZ2P040?ooo`09jPX0oooo00WZ2PL0oooo0P09
jPXB0?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3oool01@3oool000L0oooo00<00000
0?ooo`3oool0:`3oool02@09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`80
2NX:0P3oool200WZ2P80oooo0P09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo00D02NX:
0?ooo`3oool02NX:0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo
00WZ2P0600WZ2P030?ooo`09jPX0oooo01@02NX:0P3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3o
ool00`09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo0P09
jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`D02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?oo
o`@02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00802NX:0P3oool200WZ2P80oooo0`09jPX0203o
ool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`@02NX:00@0oooo00WZ2P09jPX0
oooo0`09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`02
00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01009jPX0103oool02NX:0?oo
o`09jPX70?ooo`802NX:4P3oool00`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo02/0oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P040?ooo`09
jPX0oooo0?ooo`802NX:0P3oool200WZ2P80oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`07
00WZ2P3oool02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3o
ool01@09jPX0oooo00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P3oool01009jPX00`3oool02NX:
00WZ2P0600WZ2P030?ooo`09jPX02NX:00@02NX:0P3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3o
ool00`09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo0P09
jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`D02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?oo
o`@02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00802NX:0P3oool200WZ2P80oooo0`09jPX0203o
ool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`@02NX:00@0oooo00WZ2P3oool0
oooo1009jPX20?ooo`0400WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P3oool00`09jPX00`3o
ool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00@02NX:00@0oooo00WZ2P3oool02NX:1`3oool2
00WZ2Q80oooo00<02NX:0?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0/0?ooo`802NX:0P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool2
00WZ2P80oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo
0`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`3oool01P09jPX00`3oool0
2NX:0?ooo`0400WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo1`09jPX0
0`3oool02NX:00WZ2P0400WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:0?oo
o`0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool500WZ
2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool400WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P02
00WZ2P80oooo0`09jPX00`3oool02NX:0?ooo`0200WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:
0?ooo`0200WZ2P80oooo00T02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool00`09jPX2
0?ooo`0300WZ2P3oool02NX:00<02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`03
00WZ2P030?ooo`09jPX02NX:00@02NX:0P3oool00`09jPX0oooo0?ooo`050?ooo`802NX:4P3oool0
0`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
02`0oooo0P09jPX20?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`802NX:0P3oool2
00WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool300WZ2P80oooo
00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo0?ooo`0700WZ2P030?ooo`09jPX0oooo00<0
2NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0103oool02NX:00WZ2P3oool300WZ2P050?ooo`09jPX0
2NX:00WZ2P3oool01P09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P09jPX0
0`09jPX0103oool02NX:00WZ2P3oool200WZ2P060?ooo`09jPX0oooo0?ooo`09jPX0oooo1@09jPX0
1@3oool02NX:00WZ2P3oool02NX:0080oooo1009jPX20?ooo`<02NX:00D0oooo00WZ2P09jPX0oooo
00WZ2P020?ooo`<02NX:00<0oooo00WZ2P3oool00P09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ
2P3oool00P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX0oooo0`09jPX0
103oool02NX:0?ooo`3oool400WZ2P030?ooo`09jPX0oooo00D02NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0400WZ2P050?ooo`09jPX0oooo0?ooo`09jPX01`3oool200WZ2Q80oooo00<02NX:0?ooo`3o
ool03P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0/0?ooo`802NX:
0P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool200WZ2P<0oooo00D02NX:0?ooo`09
jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo0`09jPX20?ooo`0400WZ2P3oool0
2NX:00WZ2P80oooo00<02NX:0?ooo`3oool00`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3o
ool00`09jPX00`3oool02NX:00WZ2P0300WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3o
ool300WZ2P030?ooo`09jPX02NX:00@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P80oooo
1009jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX01@3oool02NX:0?ooo`09jPX0oooo
00<02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`@02NX:0P3oool300WZ2P050?ooo`09jPX0
2NX:0?ooo`09jPX00P3oool300WZ2P030?ooo`09jPX0oooo00802NX:00L0oooo00WZ2P3oool02NX:
0?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:0?oo
o`<02NX:00@0oooo00WZ2P3oool0oooo1009jPX00`3oool02NX:0?ooo`0500WZ2P030?ooo`09jPX0
2NX:00802NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00D0oooo
0P09jPXA0?ooo`0300WZ2P3oool0oooo00l0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
00000?ooo`3oool0;03oool200WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX00`3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09
jPX02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P<0oooo00<02NX:
0?ooo`09jPX00P09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00`09jPX00`3oool02NX:
00WZ2P0300WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`<02NX:
00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P020?ooo`@02NX:0P3oool01@09jPX0oooo
00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00P3oool600WZ2P040?ooo`09jPX0oooo0?oo
o`@02NX:0P3oool300WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P02
00WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0`09jPX00`3oool02NX:00WZ2P020?ooo`0300WZ
2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX0oooo0`09jPX0103oool02NX:0?ooo`3oool300WZ
2P80oooo00<02NX:0?ooo`09jPX01009jPX00`3oool02NX:00WZ2P0200WZ2P060?ooo`09jPX02NX:
00WZ2P3oool02NX:0P3oool00`09jPX0oooo0?ooo`050?ooo`802NX:4@3oool00`09jPX0oooo0?oo
o`0?0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02`0oooo0P09jPX2
0?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool01@09jPX0oooo0?ooo`3oool02NX:00<0oooo
0P09jPX00`3oool02NX:00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`09
jPX00P3oool01009jPX0oooo00WZ2P09jPX30?ooo`0300WZ2P3oool02NX:00H02NX:00<0oooo00WZ
2P3oool00`09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00@02NX:00@0oooo00WZ
2P09jPX02NX:0P3oool300WZ2P030?ooo`09jPX0oooo00H02NX:0P3oool400WZ2P80oooo00D02NX:
0?ooo`09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:0080oooo1@09jPX20?ooo`0300WZ2P3o
ool0oooo00@02NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00D02NX:0?ooo`09jPX02NX:
0?ooo`0300WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0
oooo00WZ2P020?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:00@0oooo00WZ2P3oool0oooo0`09jPX2
0?ooo`0300WZ2P3oool02NX:00@02NX:00<0oooo00WZ2P09jPX00P09jPX01P3oool02NX:00WZ2P09
jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool01@3oool200WZ2Q40oooo00<02NX:0?ooo`3oool0
3`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0/0?ooo`0900WZ2P3o
ool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPX20?ooo`802NX:0P3oool200WZ
2P030?ooo`09jPX02NX:0080oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo00WZ2P02
0?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00@02NX:0?ooo`09jPX0oooo1@09jPX01P3oool02NX:
0?ooo`09jPX0oooo00WZ2P80oooo1009jPX00`3oool02NX:00WZ2P0400WZ2P060?ooo`09jPX02NX:
0?ooo`09jPX0oooo0`09jPX00`3oool02NX:0?ooo`0600WZ2P80oooo1009jPX20?ooo`0500WZ2P3o
ool02NX:00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P020?ooo`D02NX:0P3oool00`09jPX0oooo
0?ooo`0400WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`0500WZ2P3oool02NX:00WZ2P3o
ool00`09jPX0103oool02NX:00WZ2P3oool500WZ2P030?ooo`09jPX02NX:0080oooo0`09jPX20?oo
o`0400WZ2P3oool02NX:0?ooo`<02NX:00@0oooo00WZ2P3oool0oooo0`09jPX20?ooo`0300WZ2P3o
ool02NX:00@02NX:00<0oooo00WZ2P09jPX00P09jPX01P3oool02NX:00WZ2P09jPX0oooo00WZ2P80
oooo00<02NX:0?ooo`3oool01@3oool200WZ2Q40oooo00<02NX:0?ooo`3oool03`3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0/0?ooo`0300WZ2P3oool02NX:0080oooo
0P09jPX0103oool02NX:0?ooo`3oool200WZ2P80oooo0P09jPX20?ooo`802NX:00<0oooo00WZ2P09
jPX00P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0600WZ2P3oool02NX:00WZ2P3oool02NX:0P3o
ool02009jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX0oooo1`09jPX0103oool02NX:00WZ2P09jPX2
0?ooo`802NX:00<0oooo00WZ2P3oool01P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`<02NX:
00<0oooo00WZ2P3oool01P09jPX20?ooo`@02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo0080
2NX:00<0oooo00WZ2P09jPX00P3oool600WZ2P040?ooo`09jPX0oooo0?ooo`@02NX:0P3oool200WZ
2P030?ooo`09jPX02NX:0080oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P040?ooo`09jPX0
2NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`<02NX:0P3oool300WZ2P090?oo
o`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00802NX:00D0oooo00WZ2P3oool02NX:0?oo
o`0400WZ2P030?ooo`09jPX02NX:00802NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`03
00WZ2P3oool0oooo00D0oooo0P09jPXA0?ooo`0300WZ2P3oool0oooo00l0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0;@3oool200WZ2P80oooo0P09jPX0103oool02NX:
0?ooo`3oool200WZ2P80oooo0P09jPX20?ooo`802NX:00H0oooo00WZ2P3oool02NX:0?ooo`09jPX2
0?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX01@3oool02NX:0?ooo`3oool02NX:00<0oooo
00@02NX:0?ooo`09jPX0oooo1`09jPX0103oool02NX:00WZ2P09jPX20?ooo`802NX:00<0oooo00WZ
2P3oool02`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool01P09jPX20?ooo`@02NX:0P3o
ool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo
00WZ2P0300WZ2P040?ooo`09jPX0oooo0?ooo`D02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?oo
o`0500WZ2P3oool02NX:00WZ2P3oool00`09jPX20?ooo`0600WZ2P3oool02NX:00WZ2P3oool02NX:
0P3oool01009jPX0oooo0?ooo`3oool300WZ2P80oooo0`09jPX02@3oool02NX:00WZ2P09jPX0oooo
00WZ2P3oool02NX:0?ooo`0200WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P06
0?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`0300WZ2P3oool0
oooo00D0oooo0P09jPXA0?ooo`0300WZ2P3oool0oooo00l0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0;@3oool200WZ2P80oooo0P09jPX0103oool02NX:0?ooo`3oool2
00WZ2P80oooo0P09jPX20?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo00WZ
2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`09jPX00`3oool01P09jPX0oooo
00WZ2P3oool02NX:0?ooo`D02NX:00@0oooo00WZ2P09jPX02NX:0P3oool@00WZ2P050?ooo`09jPX0
2NX:00WZ2P3oool02009jPX20?ooo`802NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool200WZ2P04
0?ooo`09jPX02NX:0?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P040?ooo`09jPX0oooo
0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`0500WZ2P3o
ool02NX:00WZ2P3oool00`09jPX20?ooo`0600WZ2P3oool02NX:00WZ2P3oool02NX:0P3oool01009
jPX0oooo0?ooo`3oool300WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P020?ooo`0400WZ2P3oool0
2NX:0?ooo`802NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00802NX:00H0oooo00WZ2P09
jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?ooo`3oool01@3oool2
00WZ2Q40oooo00<02NX:0?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0]0?ooo`802NX:0P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool2
00WZ2P80oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0700WZ2P3oool02NX:00WZ2P3oool0
2NX:0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool01009jPX0oooo00WZ2P3oool3
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX00`3oool02NX:0?ooo`0500WZ2P030?ooo`09
jPX02NX:00H02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00802NX:
0`3oool00`09jPX0oooo00WZ2P020?ooo`@02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`03
00WZ2P3oool02NX:00<02NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`D02NX:00<0oooo00WZ
2P09jPX00P3oool01@09jPX0oooo00WZ2P09jPX0oooo00<02NX:0P3oool01P09jPX0oooo00WZ2P09
jPX0oooo00WZ2P80oooo00@02NX:0?ooo`3oool0oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P03
0?ooo`09jPX02NX:0080oooo00@02NX:0?ooo`09jPX0oooo0P09jPX01@3oool02NX:0?ooo`09jPX0
oooo00802NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`802NX:00<0oooo00WZ2P3oool00P3oool0
0`09jPX0oooo0?ooo`050?ooo`802NX:4@3oool00`09jPX0oooo0?ooo`0?0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo02d0oooo0P09jPX20?ooo`802NX:00<0oooo00WZ
2P3oool00P3oool00`09jPX0oooo0?ooo`0200WZ2P<0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P02
0?ooo`0400WZ2P3oool02NX:00WZ2P80oooo0`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo
00<02NX:0?ooo`09jPX00P3oool200WZ2P050?ooo`09jPX0oooo00WZ2P3oool01009jPX00`3oool0
2NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00H02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ
2P030?ooo`09jPX02NX:00802NX:0`3oool01@09jPX0oooo00WZ2P09jPX0oooo00@02NX:00<0oooo
00WZ2P3oool00`09jPX20?ooo`H02NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`D02NX:00<0
oooo00WZ2P09jPX00P3oool01@09jPX0oooo00WZ2P09jPX0oooo00<02NX:0P3oool01`09jPX0oooo
00WZ2P09jPX0oooo00WZ2P3oool00P09jPX30?ooo`<02NX:00@0oooo00WZ2P09jPX02NX:0P3oool2
00WZ2P060?ooo`09jPX0oooo0?ooo`09jPX0oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo0080
2NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`802NX:00<0oooo00WZ2P3oool00P3oool00`09jPX0
oooo0?ooo`050?ooo`802NX:4@3oool00`09jPX0oooo0?ooo`0?0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo02d0oooo0P09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09
jPX00P3oool01@09jPX0oooo0?ooo`3oool02NX:00<0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P02
0?ooo`0400WZ2P3oool02NX:00WZ2P80oooo0`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo
00<02NX:0?ooo`09jPX00P3oool200WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ
2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0200WZ
2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX20?ooo`802NX:00@0oooo00WZ2P09jPX0oooo1009
jPX00`3oool02NX:0?ooo`0300WZ2P80oooo1P09jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo
1@09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`<02NX:0P3oool200WZ2P80oooo00L02NX:0?oo
o`09jPX02NX:0?ooo`09jPX0oooo00802NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00<02NX:
00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`0900WZ2P3oool02NX:00WZ2P3oool02NX:0?oo
o`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`802NX:00<0oooo00WZ2P3oool0
0P3oool00`09jPX0oooo0?ooo`050?ooo`802NX:4@3oool00`09jPX0oooo0?ooo`0?0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02d0oooo00<02NX:0?ooo`09jPX00P3o
ool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool02@09jPX0oooo0?ooo`3oool02NX:0?oo
o`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo0`09jPX20?ooo`0400WZ2P3o
ool02NX:00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P070?ooo`09jPX02NX:00WZ2P3o
ool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P05
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0P09
jPX0103oool02NX:00WZ2P3oool400WZ2P030?ooo`09jPX0oooo00<02NX:0P3oool600WZ2P050?oo
o`09jPX0oooo0?ooo`09jPX00P3oool500WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0`09jPX2
0?ooo`802NX:0P3oool400WZ2P030?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P02
0?ooo`<02NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`0900WZ2P3oool02NX:00WZ2P3o
ool02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`802NX:00<0oooo
00WZ2P3oool00P3oool00`09jPX0oooo0?ooo`050?ooo`802NX:4@3oool00`09jPX0oooo0?ooo`0?
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02h0oooo0P09jPX20?oo
o`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX0
2NX:0080oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3o
ool02NX:00WZ2P80oooo00D02NX:0?ooo`3oool02NX:0?ooo`0600WZ2P80oooo0`09jPX00`3oool0
2NX:00WZ2P0500WZ2P050?ooo`09jPX02NX:00WZ2P3oool01`09jPX00`3oool02NX:00WZ2P0200WZ
2P030?ooo`09jPX02NX:00802NX:0P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00<0oooo
00WZ2P3oool00`09jPX20?ooo`H02NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`@02NX:00L0
oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00<02NX:0P3oool200WZ2P80oooo1009jPX00`3oool0
2NX:0?ooo`0200WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool300WZ2P060?ooo`09jPX02NX:00WZ
2P3oool02NX:0P3oool02@09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P03
0?ooo`09jPX02NX:00<02NX:0P3oool200WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?ooo`3o
ool01@3oool200WZ2Q40oooo00<02NX:0?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`0^0?ooo`802NX:0P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`80
2NX:0P3oool200WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ
2P80oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0500WZ2P3oool0
oooo00WZ2P3oool01P09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX01@09jPX01@3oool02NX:00WZ
2P09jPX0oooo00L02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo
1@09jPX00`3oool02NX:00WZ2P0400WZ2P040?ooo`09jPX02NX:00WZ2P80oooo1P09jPX01@3oool0
2NX:0?ooo`3oool02NX:0080oooo1009jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00`09
jPX20?ooo`802NX:00T0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX20?oo
o`0300WZ2P3oool02NX:0080oooo0`09jPX01P3oool02NX:00WZ2P09jPX0oooo00WZ2P80oooo00<0
2NX:0?ooo`09jPX00P09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00<02NX:0P3o
ool300WZ2P@0oooo00<02NX:0?ooo`3oool01@3oool200WZ2Q40oooo00<02NX:0?ooo`3oool03`3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0^0?ooo`802NX:0P3oool2
00WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool200WZ2P80oooo0P09jPX00`3oool02NX:00WZ
2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo
00WZ2P09jPX30?ooo`0400WZ2P3oool02NX:0?ooo`L02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09
jPX0oooo00D02NX:00<0oooo00WZ2P09jPX02@09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09
jPX02NX:00802NX:0P3oool500WZ2P030?ooo`09jPX02NX:00@02NX:00@0oooo00WZ2P09jPX02NX:
0P3oool500WZ2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool400WZ2P070?ooo`09jPX02NX:00WZ
2P3oool02NX:0?ooo`0300WZ2P80oooo00<02NX:0?ooo`3oool00`09jPX01@3oool02NX:0?ooo`09
jPX0oooo00802NX:0P3oool300WZ2P80oooo0`09jPX0203oool02NX:00WZ2P09jPX0oooo00WZ2P3o
ool02NX:0P3oool300WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00`09jPX20?oo
o`<02NX:103oool00`09jPX0oooo0?ooo`050?ooo`802NX:4@3oool00`09jPX0oooo0?ooo`0?0?oo
o`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02h0oooo0P09jPX20?ooo`80
2NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`802NX:0P3oool200WZ2P060?ooo`09jPX0oooo
00WZ2P3oool02NX:0P3oool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool0
0P09jPX30?ooo`0400WZ2P3oool02NX:0?ooo`@02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3o
ool02NX:0?ooo`0500WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ2P09jPX00`09jPX00`3o
ool02NX:0?ooo`0400WZ2P80oooo1@09jPX00`3oool02NX:0?ooo`0400WZ2P040?ooo`09jPX02NX:
00WZ2P80oooo0P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:0080oooo1009
jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00`09jPX20?ooo`0300WZ2P3oool0oooo00<0
2NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX20?ooo`<02NX:00P0oooo00WZ
2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P80oooo0`09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo
1009jPX30?ooo`<02NX:103oool00`09jPX0oooo0?ooo`050?ooo`802NX:4@3oool00`09jPX0oooo
0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02h0oooo0P09
jPX20?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`802NX:0P3oool200WZ2P040?oo
o`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool01P09jPX0oooo00WZ2P09jPX0oooo
00WZ2P80oooo00P02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:0?ooo`@02NX:00@0oooo00WZ2P09
jPX0oooo0`09jPX00`3oool02NX:0?ooo`0500WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ
2P09jPX00`09jPX00`3oool02NX:0?ooo`0400WZ2P80oooo1`09jPX00`3oool02NX:00WZ2P0200WZ
2P040?ooo`09jPX02NX:00WZ2P80oooo0P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09
jPX02NX:0080oooo1009jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00`09jPX20?ooo`03
00WZ2P3oool0oooo00D02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`<02NX:0P3oool300WZ2P08
0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX20?ooo`<02NX:00<0oooo00WZ2P3oool00P09
jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo1009jPX40?ooo`0300WZ2P3oool0oooo00D0oooo
0P09jPXA0?ooo`0300WZ2P3oool0oooo00l0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
00000?ooo`3oool0;P3oool200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0`3oool01@09jPX0oooo
0?ooo`3oool02NX:00<0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0700WZ2P3oool02NX:
00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo00<02NX:0?ooo`09jPX00`3oool01009jPX0oooo00WZ
2P3oool400WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00<0oooo00WZ2P3oool01@09jPX00`3oool0
2NX:00WZ2P0<00WZ2P030?ooo`09jPX0oooo00@02NX:0P3oool700WZ2P030?ooo`09jPX02NX:0080
2NX:0P3oool200WZ2P80oooo0P09jPX0103oool02NX:00WZ2P3oool200WZ2P060?ooo`09jPX02NX:
0?ooo`09jPX0oooo0`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00`09jPX20?ooo`03
00WZ2P3oool0oooo00D02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`<02NX:0P3oool300WZ2P08
0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX20?ooo`<02NX:00<0oooo00WZ2P3oool00P09
jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo1009jPX40?ooo`0300WZ2P3oool0oooo00D0oooo
0P09jPXA0?ooo`0300WZ2P3oool0oooo00l0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
00000?ooo`3oool0;P3oool00`09jPX0oooo00WZ2P020?ooo`802NX:00D0oooo00WZ2P3oool0oooo
00WZ2P030?ooo`0900WZ2P3oool0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0080oooo00L02NX:
0?ooo`09jPX02NX:0?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P030?ooo`0400WZ
2P3oool02NX:0?ooo`@02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX20?ooo`H02NX:00<0oooo00WZ
2P09jPX00P09jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX0oooo00@02NX:0P3oool700WZ
2P030?ooo`09jPX02NX:00802NX:0P3oool200WZ2P80oooo1@09jPX0103oool02NX:00WZ2P3oool2
00WZ2P030?ooo`09jPX0oooo00<02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:
0P3oool200WZ2P80oooo00<02NX:0?ooo`09jPX00P09jPX0103oool02NX:0?ooo`09jPX30?ooo`<0
2NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool400WZ2P80oooo00<02NX:0?ooo`3oool00`09jPX0
0`3oool02NX:0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool400WZ2P@0oooo00<0
2NX:0?ooo`3oool01@3oool200WZ2Q40oooo00<02NX:0?ooo`3oool03`3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0_0?ooo`802NX:0P3oool200WZ2P040?ooo`09jPX0
oooo0?ooo`802NX:0P3oool02@09jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P020?oo
o`0400WZ2P3oool02NX:00WZ2P80oooo0`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00H0
2NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00@02NX:0P3oool00`09jPX0
oooo00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool0
2NX:00WZ2P0400WZ2P030?ooo`09jPX0oooo00H02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`80
2NX:0P3oool800WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0`09jPX01`3oool02NX:00WZ2P09
jPX0oooo00WZ2P3oool00P09jPX20?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P0600WZ2P<0oooo
0`09jPX00`3oool02NX:0?ooo`0300WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00<02NX:0?ooo`09
jPX00`09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool400WZ
2P@0oooo00<02NX:0?ooo`3oool01@3oool200WZ2Q40oooo00<02NX:0?ooo`3oool03`3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0_0?ooo`802NX:0P3oool200WZ2P04
0?ooo`09jPX0oooo0?ooo`802NX:0P3oool200WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P020?oo
o`0400WZ2P3oool02NX:00WZ2P80oooo0`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00H0
2NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ2P80oooo1P09jPX00`3oool02NX:0?ooo`0400WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool02P09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX0oooo
00H02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`802NX:0P3oool800WZ2P060?ooo`09jPX02NX:
0?ooo`09jPX0oooo0`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX20?ooo`80
2NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P030?ooo`09jPX02NX:00<0oooo0`09jPX00`3oool0
2NX:0?ooo`0300WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00<02NX:0?ooo`09jPX00`09jPX00`3o
ool02NX:0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool01009jPX0oooo00WZ2P09
jPX40?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPXA0?ooo`0300WZ2P3oool0oooo00l0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0;`3oool200WZ2P80oooo0P09jPX0
103oool02NX:0?ooo`3oool200WZ2P80oooo0P09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P3o
ool01009jPX0oooo00WZ2P09jPX20?ooo`<02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`06
00WZ2P3oool02NX:0?ooo`09jPX0oooo0`09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0
oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00D02NX:00@0
oooo00WZ2P09jPX0oooo1P09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX01@3o
ool02NX:00WZ2P3oool02NX:0080oooo0P09jPX20?ooo`P02NX:00H0oooo00WZ2P09jPX0oooo00WZ
2P3oool300WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX00`3o
ool02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:0080oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09
jPX0oooo00<02NX:00@0oooo00WZ2P09jPX02NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P060?oo
o`09jPX0oooo00WZ2P3oool02NX:0P3oool400WZ2P80oooo00@02NX:0?ooo`09jPX02NX:103oool0
0`09jPX0oooo0?ooo`050?ooo`802NX:4@3oool00`09jPX0oooo0?ooo`0?0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo02l0oooo0P09jPX20?ooo`802NX:00@0oooo00WZ
2P3oool0oooo0P09jPX20?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00@02NX:
0?ooo`09jPX02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo
00<02NX:0?ooo`09jPX00P3oool400WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool0
2NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`02
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3o
ool00P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`<02NX:0P3oool700WZ2P80oooo0P09jPX0
0`3oool02NX:0?ooo`0300WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX0
0`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:0080oooo00L02NX:0?ooo`09jPX02NX:0?oo
o`09jPX0oooo00<02NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`<02NX:00H0oooo00WZ
2P3oool02NX:0?ooo`09jPX20?ooo`@02NX:0P3oool01009jPX0oooo00WZ2P09jPX40?ooo`0300WZ
2P3oool0oooo00D0oooo0P09jPXA0?ooo`0300WZ2P3oool0oooo00l0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool0;`3oool200WZ2P80oooo0P09jPX0103oool02NX:0?oo
o`3oool200WZ2P80oooo0P09jPX20?ooo`802NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo
00802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:
0?ooo`09jPX00P3oool400WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:0?oo
o`0500WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0600WZ2P03
0?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P060?ooo`09jPX02NX:
0?ooo`09jPX0oooo0`09jPX20?ooo`P02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool300WZ2P80
oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX00`3oool02NX:0?ooo`0400WZ2P03
0?ooo`09jPX02NX:0080oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00<02NX:00H0oooo
00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:
00WZ2P0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:103oool00`09jPX0oooo0?ooo`050?ooo`80
2NX:403oool00`09jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo02l0oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ2P<0oooo00<02NX:0?oo
o`3oool00P09jPX20?ooo`802NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00802NX:0P3o
ool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00D02NX:0?ooo`3oool0
2NX:0?ooo`0400WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`3oool4
00WZ2P030?ooo`09jPX02NX:00@02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00@02NX:
00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00T0oooo00WZ2P09
jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX00P3oool800WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0
oooo0`09jPX20?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`<02NX:00<0oooo00WZ2P3o
ool01009jPX00`3oool02NX:00WZ2P020?ooo`0700WZ2P3oool02NX:00WZ2P3oool02NX:0?ooo`03
00WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0P3oool01P09jPX0oooo00WZ2P3oool02NX:0?oo
o`<02NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:00WZ2P3oool200WZ2P@0oooo00<02NX:
0?ooo`3oool01@3oool200WZ2Q00oooo00<02NX:0?ooo`3oool0403oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`0_0?ooo`0300WZ2P3oool02NX:0080oooo0P09jPX01@3o
ool02NX:0?ooo`3oool02NX:00<0oooo00T02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:0?ooo`09
jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09
jPX02NX:0P3oool01@09jPX0oooo0?ooo`09jPX0oooo00@02NX:00D0oooo00WZ2P09jPX02NX:0?oo
o`0400WZ2P80oooo1009jPX00`3oool02NX:00WZ2P0400WZ2P070?ooo`09jPX02NX:00WZ2P3oool0
2NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ
2P090?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0080oooo2009jPX01P3oool02NX:
00WZ2P3oool02NX:0?ooo`802NX:0`3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:0P3oool3
00WZ2P030?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX00P3oool300WZ2P040?ooo`09jPX0
2NX:0?ooo`<02NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`0600WZ2P3oool02NX:0?oo
o`09jPX0oooo0`09jPX00`3oool02NX:00WZ2P0300WZ2P070?ooo`09jPX02NX:0?ooo`09jPX0oooo
00WZ2P030?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPX@0?ooo`0300WZ2P3oool0oooo0100oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0<03oool200WZ2P80oooo0P09
jPX01@3oool02NX:0?ooo`3oool02NX:00<0oooo00T02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:
0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`0700WZ2P3oool02NX:00WZ2P3oool02NX:
0?ooo`0200WZ2P<0oooo00@02NX:0?ooo`09jPX0oooo2009jPX00`3oool02NX:00WZ2P0200WZ2P80
oooo1P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09
jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00@02NX:00T0oooo00WZ2P09
jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P030?ooo`09jPX02NX:00<02NX:00D0
oooo00WZ2P09jPX0oooo00WZ2P020?ooo`802NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo0080
2NX:0P3oool300WZ2P030?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX00P3oool300WZ2P04
0?ooo`09jPX02NX:0?ooo`@02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`0600WZ2P3oool0
2NX:0?ooo`09jPX0oooo0`09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:
00<0oooo00WZ2P3oool00P3oool00`09jPX0oooo0?ooo`050?ooo`802NX:403oool00`09jPX0oooo
0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0300oooo0P09
jPX20?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`0900WZ2P3oool0oooo0?ooo`09
jPX0oooo00WZ2P3oool02NX:0080oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00802NX:
00D0oooo00WZ2P3oool0oooo00WZ2P030?ooo`0400WZ2P3oool02NX:0?ooo`d02NX:0P3oool600WZ
2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:0?ooo`0300WZ
2P80oooo00<02NX:0?ooo`09jPX00`09jPX02@3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo
00WZ2P020?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:
0080oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo0P09jPX20?ooo`@02NX:0P3oool4
00WZ2P030?ooo`09jPX02NX:0080oooo0`09jPX0103oool02NX:00WZ2P3oool400WZ2P070?ooo`09
jPX02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:00<0oooo00WZ
2P09jPX00`09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?oo
o`3oool01@3oool200WZ2Q00oooo00<02NX:0?ooo`3oool0403oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0`0?ooo`802NX:0P3oool200WZ2P040?ooo`09jPX0oooo0?oo
o`802NX:0P3oool200WZ2P80oooo0`09jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`802NX:00<0
oooo00WZ2P3oool00P09jPX20?ooo`0300WZ2P3oool02NX:00<0oooo00H02NX:0?ooo`09jPX0oooo
00WZ2P3oool;00WZ2P80oooo1P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo1`09jPX0103oool0
2NX:0?ooo`3oool200WZ2P80oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00802NX:00H0
oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX01@3o
ool02NX:00WZ2P3oool02NX:0080oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo0P09
jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo1009jPX00`3oool02NX:00WZ2P020?ooo`<02NX:
00@0oooo00WZ2P09jPX0oooo1009jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool0
1009jPX0oooo00WZ2P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P3oool0
0P09jPX00`3oool02NX:0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`09jPX0
403oool00`09jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo0300oooo0P09jPX20?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`802NX:
0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00@02NX:0?ooo`09jPX02NX:0P3oool300WZ2P80
oooo00<02NX:0?ooo`09jPX00`3oool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`@02NX:00<0oooo
00WZ2P09jPX01009jPX20?ooo`H02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P05
00WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool01`09jPX0oooo00WZ2P09jPX0oooo00WZ2P3o
ool01P09jPX0103oool02NX:0?ooo`3oool200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00D0oooo
00WZ2P09jPX0oooo00WZ2P020?ooo`802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`802NX:
0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool300WZ
2P090?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool0
2NX:0P3oool200WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool0
2NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo00WZ2P0@0?ooo`0300WZ2P3oool0oooo0100oooo00<000000?ooo`3oool01@3oool000L0oooo
00<000000?ooo`3oool0<03oool200WZ2P80oooo0P09jPX0103oool02NX:0?ooo`3oool200WZ2P80
oooo0P09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool01009jPX0oooo00WZ2P09jPX20?oo
o`<02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo
0`09jPX00`3oool02NX:00WZ2P0300WZ2P040?ooo`09jPX0oooo0?ooo`H02NX:00<0oooo00WZ2P09
jPX00`09jPX00`3oool02NX:00WZ2P0500WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00<0oooo00WZ
2P3oool00P09jPX00`3oool02NX:00WZ2P0600WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?oo
o`0200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P3oool00`09jPX01@3oool02NX:
00WZ2P3oool02NX:0080oooo0`09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo0P09jPX0103oool0
2NX:0?ooo`09jPX30?ooo`<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P080?ooo`09jPX0
2NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09
jPX01@09jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo00WZ2P0@0?ooo`0300WZ2P3oool0oooo0100oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0<03oool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:0P3oool2
00WZ2P80oooo0P09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool01009jPX0oooo00WZ2P09
jPX20?ooo`<02NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09
jPX0oooo2@09jPX00`3oool02NX:0?ooo`020?ooo`D02NX:00<0oooo00WZ2P09jPX00`09jPX0103o
ool02NX:00WZ2P3oool400WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00<0oooo00WZ2P3oool00P09
jPX00`3oool02NX:00WZ2P0600WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P03
0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool00`09jPX01@3oool02NX:00WZ2P3oool02NX:
0080oooo0`09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo1009jPX00`3oool02NX:0?ooo`020?oo
o`<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00<0
2NX:0?ooo`09jPX00P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00@02NX:
00D0oooo00WZ2P09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`09
jPX0403oool00`09jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo0340oooo0P09jPX20?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`80
2NX:0P3oool200WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo00<02NX:
0?ooo`09jPX00P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0
oooo2@09jPX00`3oool02NX:0?ooo`020?ooo`D02NX:00<0oooo00WZ2P09jPX00`09jPX0103oool0
2NX:00WZ2P3oool700WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0;00WZ2P070?ooo`09
jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3o
ool00`09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0`09jPX01@3oool02NX:0?ooo`3oool02NX:
0080oooo1009jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`802NX:00D0oooo00WZ2P3oool02NX:
0?ooo`0300WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00<02NX:0?ooo`09jPX00P09jPX0103oool0
2NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00@02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P03
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`09jPX0403oool00`09jPX0oooo0?ooo`0@
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0340oooo0P09jPX20?oo
o`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo00802NX:00L0oooo
00WZ2P3oool02NX:0?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ
2P3oool02NX:00WZ2P80oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool900WZ2P030?ooo`09jPX0
oooo0080oooo1@09jPX00`3oool02NX:00WZ2P0300WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo
1@09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool02`09jPX01`3oool02NX:00WZ2P09jPX0
oooo00WZ2P3oool01009jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00`09jPX00`3oool0
2NX:00WZ2P0200WZ2P80oooo1@09jPX20?ooo`0300WZ2P3oool0oooo00H02NX:0P3oool00`09jPX0
oooo00WZ2P020?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX02NX:0P3oool0
0`09jPX0oooo00WZ2P0200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01@09
jPX0103oool02NX:0?ooo`09jPX30?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`09jPX0
403oool00`09jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo0340oooo0P09jPX20?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`0900WZ
2P3oool0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool0
0`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00H02NX:0?ooo`09jPX0oooo
00WZ2P3oool500WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0`3oool500WZ2P030?ooo`09jPX0
2NX:00<02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00<02NX:00T0oooo00WZ2P09jPX02NX:0?oo
o`09jPX0oooo00WZ2P3oool02@09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool01009jPX0
1`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo
1@09jPX20?ooo`0300WZ2P3oool0oooo00H02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ
2P3oool02NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX02NX:0P3oool00`09jPX0oooo00WZ2P0200WZ
2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:0?ooo`09
jPX20?ooo`0400WZ2P3oool0oooo00WZ2PH0oooo00<02NX:0?ooo`09jPX0403oool00`09jPX0oooo
0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0340oooo0P09
jPX20?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`0900WZ2P3oool0oooo0?ooo`09
jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P02
0?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool600WZ2P050?ooo`09
jPX02NX:00WZ2P3oool00P09jPX20?ooo`D02NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:
0?ooo`0300WZ2P030?ooo`09jPX0oooo00<02NX:00T0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo
00WZ2P3oool02@09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool01009jPX00`3oool02NX:
00WZ2P020?ooo`0300WZ2P3oool02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`0300WZ
2P3oool02NX:00802NX:0P3oool00`09jPX0oooo0?ooo`0700WZ2P040?ooo`09jPX0oooo00WZ2P80
oooo00@02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`<02NX:0P3oool00`09jPX0oooo00WZ2P0200WZ
2P040?ooo`09jPX02NX:0?ooo`P02NX:00@0oooo00WZ2P3oool02NX:0P3oool01009jPX0oooo0?oo
o`09jPX60?ooo`0300WZ2P3oool02NX:0100oooo00<02NX:0?ooo`3oool0403oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0a0?ooo`802NX:0P3oool200WZ2P040?ooo`09
jPX0oooo0?ooo`802NX:0P3oool200WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`07
00WZ2P3oool02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool0
0`09jPX0oooo00WZ2P020?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P80oooo00<0
2NX:0?ooo`3oool00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool0
0`09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P3oool0
1@09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P3oool01`09jPX20?ooo`03
00WZ2P3oool02NX:00X02NX:00@0oooo00WZ2P09jPX02NX:0P3oool00`09jPX0oooo0?ooo`0700WZ
2P040?ooo`09jPX02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:00WZ
2P0200WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo1009jPX0203oool0
2NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0P3oool01009jPX0oooo0?ooo`09jPX60?ooo`0300WZ
2P3oool02NX:0100oooo00<02NX:0?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0a0?ooo`802NX:0P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:
0P3oool200WZ2P80oooo0`09jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`802NX:00<0oooo00WZ
2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo00D02NX:0?ooo`3oool02NX:0?ooo`02
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX20?ooo`0300WZ2P3oool0oooo00<02NX:00D0
oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:00<02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0500WZ2P030?ooo`09jPX0oooo00D02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ
2P030?ooo`09jPX0oooo00L02NX:0P3oool00`09jPX0oooo00WZ2P0:00WZ2P040?ooo`09jPX02NX:
00WZ2P80oooo00<02NX:0?ooo`3oool01`09jPX0103oool02NX:00WZ2P09jPX20?ooo`0400WZ2P3o
ool02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX0103oool02NX:0?ooo`3oool400WZ2P03
0?ooo`09jPX0oooo00@02NX:00P0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P80oooo00@0
2NX:0?ooo`3oool02NX:1P3oool00`09jPX0oooo00WZ2P0@0?ooo`0300WZ2P3oool0oooo0100oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0<@3oool01P09jPX0oooo00WZ
2P3oool02NX:0?ooo`802NX:0P3oool200WZ2P80oooo0P09jPX20?ooo`802NX:00<0oooo00WZ2P09
jPX00P3oool01`09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool00P09jPX01@3oool02NX:0?ooo`3o
ool02NX:00<0oooo00@02NX:0?ooo`09jPX0oooo0P09jPX0203oool02NX:00WZ2P09jPX0oooo00WZ
2P3oool02NX:0P3oool00`09jPX0oooo0?ooo`0700WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo
00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX0oooo00D02NX:00D0oooo
00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00L02NX:0P3oool00`09jPX0oooo00WZ
2P0:00WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00<02NX:0?ooo`3oool01`09jPX0103oool02NX:
00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:00<02NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool0
2NX:0?ooo`09jPX0oooo00@02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00<02NX:00@0oooo
00WZ2P3oool02NX:0P3oool01009jPX0oooo0?ooo`09jPX60?ooo`0300WZ2P3oool02NX:0100oooo
00<02NX:0?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0b0?ooo`802NX:0P3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00P3oool200WZ2P80oooo
0P09jPX00`3oool02NX:00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo0`09jPX20?ooo`03
00WZ2P3oool02NX:00<0oooo00@02NX:0?ooo`09jPX0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0
oooo00<02NX:0P3oool00`09jPX0oooo0?ooo`0700WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo
00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX0oooo00D02NX:00D0oooo
00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00L02NX:0P3oool00`09jPX0oooo00WZ
2P0:00WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00<02NX:0?ooo`3oool01`09jPX01@3oool02NX:
00WZ2P09jPX0oooo00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P050?ooo`09jPX0oooo
00WZ2P3oool01009jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool01009jPX20?ooo`0400WZ2P3o
ool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo00WZ2P0@0?ooo`0300WZ
2P3oool0oooo0100oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0<P3o
ool200WZ2P80oooo0P09jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo0P09jPX20?ooo`802NX:
00<0oooo00WZ2P09jPX00P3oool01009jPX0oooo00WZ2P09jPX20?ooo`<02NX:0P3oool00`09jPX0
oooo00WZ2P030?ooo`0400WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01@09jPX20?oo
o`802NX:00<0oooo00WZ2P3oool01@09jPX01@3oool02NX:00WZ2P09jPX0oooo00T02NX:00<0oooo
00WZ2P09jPX01009jPX00`3oool02NX:0?ooo`0500WZ2P0;0?ooo`09jPX0oooo00WZ2P3oool02NX:
0?ooo`09jPX0oooo00WZ2P3oool01@09jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`/02NX:00@0
oooo00WZ2P09jPX02NX:0P3oool00`09jPX0oooo0?ooo`0700WZ2P050?ooo`09jPX02NX:00WZ2P3o
ool00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:0P3oool01009jPX0oooo00WZ2P3oool4
00WZ2P80oooo00<02NX:0?ooo`09jPX01P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo00WZ2P0@0?ooo`0300WZ2P3oool0oooo0100oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0<P3oool200WZ2P80oooo0P09jPX0
1@3oool02NX:0?ooo`3oool02NX:00<0oooo00<02NX:0?ooo`3oool00P09jPX01`3oool02NX:0?oo
o`09jPX0oooo00WZ2P3oool00P09jPX20?ooo`<02NX:0P3oool00`09jPX0oooo00WZ2P030?ooo`04
00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01P09jPX01P3oool02NX:00WZ2P3oool0
2NX:0?ooo`D02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0900WZ2P030?ooo`09jPX02NX:00@02NX:
00@0oooo00WZ2P3oool0oooo1009jPX02`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?oo
o`09jPX0oooo00L02NX:00@0oooo00WZ2P3oool0oooo1@09jPX20?ooo`@02NX:0P3oool200WZ2P03
0?ooo`09jPX02NX:0080oooo1@09jPX00`3oool02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ
2P3oool00`09jPX0103oool02NX:00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`@02NX:0P3o
ool00`09jPX0oooo00WZ2P0400WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00P3oool01009jPX0oooo
0?ooo`09jPX60?ooo`0300WZ2P3oool02NX:0100oooo00<02NX:0?ooo`3oool0403oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0b0?ooo`802NX:0P3oool200WZ2P040?oo
o`09jPX0oooo0?ooo`802NX:0P3oool03009jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ
2P3oool02NX:0?ooo`802NX:0P3oool300WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool01P09
jPX0oooo00WZ2P3oool02NX:0?ooo`T02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P04
0?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0200WZ
2P030?ooo`09jPX02NX:00@02NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool200WZ2P0;0?ooo`09
jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P02
00WZ2P040?ooo`09jPX0oooo0?ooo`D02NX:0P3oool400WZ2P80oooo0P09jPX01P3oool02NX:00WZ
2P3oool02NX:0?ooo`@02NX:00<0oooo00WZ2P3oool00`09jPX02@3oool02NX:00WZ2P09jPX0oooo
00WZ2P3oool02NX:0?ooo`0300WZ2P80oooo00@02NX:0?ooo`09jPX0oooo1009jPX20?ooo`802NX:
00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:0?ooo`3oool02NX:00<0oooo00<02NX:0?ooo`09
jPX01P3oool00`09jPX0oooo00WZ2P0@0?ooo`0300WZ2P3oool0oooo0100oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0<P3oool200WZ2P80oooo0P09jPX0103oool02NX:
0?ooo`3oool200WZ2P80oooo00T02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:0?ooo`09jPX00P3o
ool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX02NX:
0P3oool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX0
1P3oool02NX:00WZ2P3oool02NX:0?ooo`D02NX:00@0oooo00WZ2P09jPX0oooo1@09jPX00`3oool0
2NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00@02NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool2
00WZ2P0=0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`05
00WZ2P040?ooo`09jPX0oooo0?ooo`D02NX:0P3oool400WZ2P80oooo00D02NX:0?ooo`3oool02NX:
0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`<02NX:
00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P80oooo00@02NX:0?ooo`09jPX0oooo1009jPX20?oo
o`802NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:0?ooo`3oool02NX:00<0oooo00<02NX:
0?ooo`09jPX01P3oool00`09jPX0oooo00WZ2P0@0?ooo`0300WZ2P3oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0<P3oool200WZ2P80oooo0P09jPX0103o
ool02NX:0?ooo`3oool200WZ2P80oooo0P09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3o
ool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX02NX:
0P3oool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX0
1P3oool02NX:00WZ2P3oool02NX:0?ooo`D02NX:0P3oool700WZ2P030?ooo`09jPX02NX:00802NX:
00<0oooo00WZ2P09jPX01009jPX01P3oool02NX:0?ooo`3oool02NX:0?ooo`802NX:00d0oooo00WZ
2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00D02NX:00@0oooo00WZ
2P3oool0oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`@02NX:0P3oool01@09jPX0oooo0?ooo`09
jPX0oooo00802NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo
0`09jPX02P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`0600WZ2P3o
ool02NX:00WZ2P3oool02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00<02NX:0P3oool01`09jPX0
oooo0?ooo`3oool02NX:0?ooo`09jPX01P3oool00`09jPX0oooo00WZ2P0?0?ooo`0300WZ2P3oool0
oooo0140oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0<P3oool01P09
jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:0P3oool200WZ2P80oooo0P09jPX20?ooo`<02NX:00L0
oooo00WZ2P3oool0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0
oooo00WZ2P09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:00WZ
2P0400WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`T02NX:00@0
oooo00WZ2P09jPX0oooo1P09jPX0103oool02NX:0?ooo`3oool400WZ2P030?ooo`09jPX02NX:00<0
2NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00802NX:00D0oooo00WZ2P09jPX0oooo00WZ
2P020?ooo`802NX:00@0oooo00WZ2P09jPX0oooo1@09jPX20?ooo`0500WZ2P3oool0oooo00WZ2P3o
ool00P09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool01009
jPX0oooo00WZ2P3oool400WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool400WZ2P030?ooo`09jPX0
oooo00@02NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`0700WZ2P3oool0oooo0?ooo`09jPX0oooo
00WZ2P060?ooo`0300WZ2P3oool02NX:00l0oooo00<02NX:0?ooo`3oool04@3oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0c0?ooo`802NX:0P3oool300WZ2P80oooo0P09
jPX20?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00L02NX:0?ooo`09jPX02NX:
0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0600WZ2P3oool02NX:0?oo
o`09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo
00WZ2P09jPX01009jPX01@3oool02NX:00WZ2P09jPX0oooo00D02NX:00@0oooo00WZ2P09jPX0oooo
1P09jPX0103oool02NX:0?ooo`3oool400WZ2P030?ooo`09jPX02NX:00<02NX:00L0oooo00WZ2P3o
ool02NX:0?ooo`09jPX0oooo00802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`802NX:00@0
oooo00WZ2P09jPX0oooo1@09jPX20?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX00`3oool0
2NX:00WZ2P0200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool01009jPX0oooo00WZ2P3oool4
00WZ2P80oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool400WZ2P80oooo1009jPX00`3oool02NX:
00WZ2P0200WZ2P<0oooo00L02NX:0?ooo`3oool0oooo00WZ2P3oool02NX:00H0oooo00<02NX:0?oo
o`09jPX03`3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo03<0oooo0P09jPX20?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?oo
o`802NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09
jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0
oooo0P09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09
jPX01009jPX01@3oool02NX:00WZ2P09jPX0oooo00D02NX:00<0oooo00WZ2P09jPX01`09jPX0103o
ool02NX:0?ooo`3oool400WZ2P030?ooo`09jPX02NX:00<02NX:00L0oooo00WZ2P3oool02NX:0?oo
o`09jPX0oooo00802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080
2NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX0
0`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:0P3oool01009jPX0oooo00WZ2P3o
ool400WZ2P80oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool400WZ2P80oooo00D02NX:0?ooo`09
jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo0080oooo00L02NX:0?ooo`3oool0oooo00WZ2P3o
ool02NX:00H0oooo00<02NX:0?ooo`09jPX03`3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003o
ool0oooo00D0oooo00070?ooo`030000003oool0oooo03<0oooo0P09jPX20?ooo`802NX:00D0oooo
00WZ2P3oool0oooo00WZ2P020?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00L0
2NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`03
00WZ2P3oool02NX:0080oooo0`09jPX20?ooo`L02NX:00@0oooo00WZ2P09jPX0oooo1P09jPX0103o
ool02NX:00WZ2P3oool=00WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool400WZ2P030?ooo`09
jPX02NX:00<02NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:00WZ2P3oool200WZ2P050?oo
o`09jPX0oooo0?ooo`09jPX00P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ
2P09jPX00P3oool01@09jPX0oooo00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX00P09jPX2
0?ooo`@02NX:00@0oooo00WZ2P09jPX02NX:0P3oool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`@0
2NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P3oool01009
jPX0oooo0?ooo`3oool200WZ2PL0oooo00<02NX:0?ooo`09jPX03`3oool00`09jPX0oooo0?ooo`0A
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03<0oooo0P09jPX20?oo
o`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00L0oooo
00WZ2P3oool02NX:0?ooo`09jPX0oooo00802NX:0P3oool300WZ2P050?ooo`09jPX0oooo0?ooo`09
jPX00P3oool01@09jPX0oooo0?ooo`09jPX0oooo00<02NX:0P3oool700WZ2P040?ooo`09jPX02NX:
0?ooo`H02NX:00@0oooo00WZ2P09jPX0oooo3@09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo1009
jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00<02NX:00@0oooo00WZ2P09jPX0oooo
1009jPX20?ooo`0300WZ2P3oool0oooo00802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool0
2NX:00WZ2P020?ooo`0500WZ2P3oool02NX:00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0200WZ
2P030?ooo`09jPX0oooo00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P070?ooo`09jPX0
oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P03
0?ooo`09jPX0oooo0080oooo00@02NX:0?ooo`3oool0oooo0P09jPX70?ooo`0300WZ2P3oool02NX:
00l0oooo00<02NX:0?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0c0?ooo`802NX:0P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool03009
jPX0oooo0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:0P3oool300WZ
2P80oooo00<02NX:0?ooo`09jPX00`3oool01009jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0
oooo00L02NX:00<0oooo00WZ2P09jPX01`09jPX0103oool02NX:00WZ2P3oool400WZ2P030?ooo`09
jPX02NX:00H02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`@02NX:00<0oooo00WZ2P3oool00`09
jPX00`3oool02NX:00WZ2P0300WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:0P3oool00`09jPX0oooo
0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool01@09jPX0
oooo00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0300WZ
2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool0
0P09jPX20?ooo`@02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo0080
oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo00WZ2P0?0?ooo`0300WZ2P3oool0oooo0140
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0<`3oool01009jPX0oooo
00WZ2P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool03009jPX0oooo0?ooo`3oool0
2NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:0P3oool300WZ2P80oooo00<02NX:0?oo
o`09jPX00`3oool01009jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00L02NX:00<0oooo
00WZ2P09jPX02P09jPX01@3oool02NX:00WZ2P09jPX0oooo00T02NX:00<0oooo00WZ2P09jPX00P09
jPX20?ooo`H02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0500WZ2P030?ooo`09jPX02NX:00D02NX:
0P3oool00`09jPX0oooo0?ooo`0200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool300WZ2P030?oo
o`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?oo
o`09jPX0oooo00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P070?ooo`09jPX0oooo00WZ
2P3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX20?ooo`802NX:00<0oooo00WZ2P3oool00P3oool0
0`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`09jPX03`3oool0
0`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
03@0oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo0P09jPX20?ooo`802NX:0P3oool02009
jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`<02NX:0P3oool00`09jPX0oooo
00WZ2P030?ooo`0400WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P3oool01`09jPX00`3oool0
2NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool0
2NX:00WZ2P0200WZ2P80oooo1P09jPX01@3oool02NX:00WZ2P09jPX0oooo00D02NX:0P3oool600WZ
2P80oooo00<02NX:0?ooo`3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX00`3o
ool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:0P3oool300WZ2P030?ooo`09jPX0oooo
00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P80oooo00<02NX:0?ooo`09jPX00`09jPX2
0?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?ooo`3oool00P3oool0
0`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool02NX:00l0oooo00<02NX:0?ooo`3oool04@3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0d0?ooo`802NX:0P3oool300WZ
2P80oooo0P09jPX20?ooo`802NX:0P3oool300WZ2P070?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ
2P020?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX02NX:0P3oool01009jPX0oooo
00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0=00WZ
2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P02
00WZ2P80oooo1P09jPX01@3oool02NX:0?ooo`09jPX0oooo00D02NX:0P3oool600WZ2P030?ooo`09
jPX02NX:0080oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX00`3oool02NX:0?oo
o`0200WZ2P030?ooo`09jPX02NX:00802NX:0P3oool300WZ2P030?ooo`09jPX0oooo00<02NX:00D0
oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`0400WZ
2P3oool02NX:00WZ2P80oooo1009jPX30?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3o
ool01@3oool00`09jPX0oooo00WZ2P0?0?ooo`0300WZ2P3oool0oooo0140oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0=03oool200WZ2P80oooo0P09jPX01@3oool02NX:
0?ooo`3oool02NX:0080oooo0P09jPX20?ooo`<02NX:00L0oooo00WZ2P3oool0oooo00WZ2P3oool0
2NX:0080oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3o
ool02NX:0?ooo`802NX:00<0oooo00WZ2P3oool05@09jPX0103oool02NX:00WZ2P3oool200WZ2P03
0?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`0300WZ2P3oool02NX:0080
2NX:0P3oool01009jPX0oooo00WZ2P3oool500WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ
2P09jPX00P3oool200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool400WZ2P<0oooo00<02NX:0?oo
o`09jPX00`09jPX20?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P040?ooo`09jPX0oooo
0?ooo`<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:
0P3oool400WZ2P<0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ
2P3oool02NX:00l0oooo00<02NX:0?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0d0?ooo`802NX:0P3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX0
0P3oool200WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`0800WZ2P3oool02NX:00WZ2P3o
ool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`09jPX0oooo
0P09jPX00`3oool02NX:0?ooo`0900WZ2P050?ooo`09jPX02NX:00WZ2P3oool01`09jPX0103oool0
2NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00@02NX:0P3oool300WZ2P80oooo00<02NX:0?oo
o`09jPX00P09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo0`09jPX00`3oool02NX:00WZ
2P0500WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo1009
jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX0103oool02NX:00WZ2P09jPX20?ooo`0300WZ
2P3oool02NX:00<02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX01@3oool02NX:0?ooo`09jPX0oooo
00802NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`@02NX:0`3oool00`09jPX0oooo0?ooo`02
0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`09jPX03`3oool00`09jPX0oooo0?ooo`0A
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03@0oooo0P09jPX20?oo
o`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo
00WZ2P09jPX00P3oool01`09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:
0?ooo`0200WZ2P80oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:
00L02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09
jPX00`3oool02NX:00WZ2P0700WZ2P80oooo0`09jPX20?ooo`0300WZ2P3oool02NX:00802NX:0P3o
ool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`<02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool0
2NX:00WZ2P020?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`@02NX:0P3oool300WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool00`09jPX20?ooo`0300WZ2P3oool02NX:00<02NX:00@0oooo00WZ
2P09jPX0oooo0`09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:0P3oool01009jPX0oooo00WZ
2P09jPX20?ooo`@02NX:0`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00D0oooo
00<02NX:0?ooo`09jPX03`3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo03@0oooo0P09jPX20?ooo`802NX:00@0oooo00WZ2P3oool0oooo
0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo00WZ2P09jPX00P3oool01`09jPX0oooo
00WZ2P09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo00H02NX:0?oo
o`09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00H02NX:0P3oool300WZ2P050?ooo`09
jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:00<02NX:
00@0oooo00WZ2P09jPX02NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P050?ooo`09jPX0oooo00WZ
2P3oool01@09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:0080oooo1009jPX00`3o
ool02NX:00WZ2P020?ooo`@02NX:0P3oool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX2
0?ooo`0700WZ2P3oool02NX:00WZ2P3oool02NX:0?ooo`0300WZ2P080?ooo`09jPX02NX:0?ooo`09
jPX0oooo00WZ2P3oool200WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`0500WZ2P<0oooo00<02NX:
0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool02NX:00l0oooo00<02NX:
0?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0d0?oo
o`0400WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`0<00WZ2P3o
ool0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:0?oo
o`0200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`80
2NX:00<0oooo00WZ2P3oool01P09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool0
2NX:00WZ2P0<00WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00<02NX:0?ooo`09jPX00`09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00D02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:0?ooo`02
00WZ2P80oooo1009jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX20?ooo`<02NX:
00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P80oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo
00<02NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:0P3oool400WZ2P030?oo
o`09jPX02NX:00<02NX:0`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00D0oooo
00<02NX:0?ooo`09jPX03`3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo03D0oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo0P09
jPX20?ooo`802NX:0P3oool02009jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX20?oo
o`<02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo0P09
jPX20?ooo`L02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX02009
jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P050?oo
o`09jPX02NX:00WZ2P3oool01@09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX0oooo0080
2NX:0P3oool400WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX0
1@3oool02NX:00WZ2P09jPX0oooo00<02NX:00T0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ
2P3oool00`09jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`@02NX:
00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX30?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX60?oo
o`0300WZ2P3oool02NX:00l0oooo00<02NX:0?ooo`3oool04@3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0e0?ooo`802NX:0P3oool300WZ2P80oooo0P09jPX20?ooo`80
2NX:0P3oool02009jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`<02NX:0P3o
ool00`09jPX0oooo00WZ2P020?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`L0
2NX:0P3oool300WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX02009jPX01@3oool0
2NX:00WZ2P09jPX0oooo00<02NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P050?ooo`09jPX02NX:
00WZ2P3oool01@09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00802NX:0P3oool4
00WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX01@3oool02NX:
00WZ2P09jPX0oooo00<02NX:00T0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00`09
jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ
2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0`3oool00`09jPX0oooo0?ooo`020?ooo`802NX:1P3o
ool00`09jPX0oooo00WZ2P0?0?ooo`0300WZ2P3oool0oooo0140oooo00<000000?ooo`3oool01@3o
ool000L0oooo00<000000?ooo`3oool0=@3oool200WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`02
00WZ2P80oooo0P09jPX20?ooo`0800WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ2P80
oooo0`09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool300WZ2P80
oooo1`09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0400WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool00`09jPX0103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool0
2NX:00<02NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0
oooo00802NX:0P3oool400WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0P3oool00`09jPX0oooo
0?ooo`0300WZ2P030?ooo`09jPX02NX:00D02NX:00T0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo
00WZ2P3oool00`09jPX0103oool02NX:00WZ2P3oool200WZ2P070?ooo`09jPX02NX:00WZ2P3oool0
2NX:0?ooo`0300WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0`3oool00`09jPX0oooo0?ooo`02
0?ooo`802NX:1P3oool00`09jPX0oooo00WZ2P0?0?ooo`0300WZ2P3oool0oooo0140oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0=@3oool200WZ2P80oooo0P09jPX01@3o
ool02NX:0?ooo`3oool02NX:0080oooo0P09jPX20?ooo`<02NX:00L0oooo00WZ2P3oool0oooo00WZ
2P3oool02NX:0080oooo0`09jPX20?ooo`0300WZ2P3oool02NX:00<0oooo00@02NX:0?ooo`09jPX0
oooo0`09jPX20?ooo`L02NX:0P3oool300WZ2P80oooo1@09jPX00`3oool02NX:00WZ2P0800WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool01009jPX00`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:
00L02NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool200WZ2P80oooo1009jPX0
1P3oool02NX:00WZ2P09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00`09jPX00`3oool02NX:
00WZ2P0500WZ2P090?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00<02NX:00L0oooo
00WZ2P09jPX02NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool00`09jPX01P3oool02NX:
00WZ2P09jPX0oooo00WZ2P<0oooo00<02NX:0?ooo`3oool00P3oool200WZ2PH0oooo00<02NX:0?oo
o`09jPX03`3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo03D0oooo0P09jPX20?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?oo
o`802NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool00`09
jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:00<0oooo00@02NX:0?ooo`09jPX0oooo0`09jPX2
0?ooo`0300WZ2P3oool02NX:00802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX20?ooo`802NX:00<0
oooo00WZ2P09jPX00P3oool200WZ2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P09jPX00`09
jPX00`3oool02NX:0?ooo`0700WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:
0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`D0
2NX:0P3oool00`09jPX0oooo0?ooo`0300WZ2P030?ooo`09jPX02NX:00D02NX:00D0oooo00WZ2P3o
ool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09
jPX0oooo00D02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo0080oooo
00<02NX:0?ooo`3oool00P3oool200WZ2PH0oooo00<02NX:0?ooo`09jPX03`3oool00`09jPX0oooo
0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03D0oooo0P09
jPX20?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo00802NX:
00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo
00<02NX:0?ooo`09jPX00`3oool01009jPX0oooo00WZ2P3oool300WZ2P80oooo00<02NX:0?ooo`09
jPX00P09jPX0103oool02NX:00WZ2P3oool300WZ2P80oooo1@09jPX20?ooo``02NX:00<0oooo00WZ
2P09jPX00`09jPX00`3oool02NX:0?ooo`0700WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0
0`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool00`09jPX0oooo00WZ
2P020?ooo`D02NX:0P3oool00`09jPX0oooo0?ooo`0300WZ2P030?ooo`09jPX02NX:00D02NX:00D0
oooo00WZ2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:00L0oooo00WZ2P09jPX0
2NX:0?ooo`09jPX0oooo00H02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:0?ooo`020?oo
o`0300WZ2P3oool0oooo0080oooo0P09jPX60?ooo`0300WZ2P3oool02NX:00l0oooo00<02NX:0?oo
o`3oool04@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0e0?ooo`04
00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX20?ooo`0300WZ2P3oool0
oooo00802NX:00<0oooo00WZ2P09jPX00P3oool02009jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool0
2NX:0P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`802NX:00D0oooo
00WZ2P3oool02NX:0?ooo`0300WZ2P070?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`D0
2NX:0P3oool<00WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P3oool02`09jPX01P3oool0
2NX:00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX20?ooo`0300WZ2P3o
ool02NX:0080oooo1@09jPX20?ooo`0700WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`0700WZ2P05
0?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P070?ooo`09jPX02NX:
00WZ2P3oool02NX:0?ooo`0700WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P3oool00P3o
ool00`09jPX0oooo0?ooo`020?ooo`802NX:1P3oool00`09jPX0oooo00WZ2P0?0?ooo`0300WZ2P3o
ool0oooo0140oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0=P3oool2
00WZ2P030?ooo`09jPX0oooo00802NX:0P3oool200WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX0
0`3oool02NX:00WZ2P020?ooo`0700WZ2P3oool02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P030?oo
o`09jPX0oooo00802NX:0P3oool01009jPX0oooo00WZ2P3oool200WZ2P050?ooo`09jPX0oooo00WZ
2P3oool01P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ
2P09jPX02P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX0oooo00/02NX:00H0oooo00WZ
2P09jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00D0oooo00WZ2P09jPX0
oooo00WZ2P020?ooo`D02NX:0P3oool01`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool01009jPX0
203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX0103oool02NX:0?ooo`09jPX20?oo
o`<02NX:00<0oooo00WZ2P3oool01`09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX0oooo
0080oooo00<02NX:0?ooo`3oool00P3oool200WZ2PH0oooo00<02NX:0?ooo`09jPX03P3oool00`09
jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03H0
oooo0P09jPX20?ooo`<02NX:0P3oool200WZ2P80oooo0P09jPX20?ooo`0800WZ2P3oool02NX:0?oo
o`09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09
jPX20?ooo`0400WZ2P3oool02NX:0?ooo`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0500WZ2P04
0?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0:00WZ
2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P3oool02`09jPX01P3oool02NX:00WZ2P3oool0
2NX:0?ooo`802NX:00<0oooo00WZ2P3oool00`09jPX0103oool02NX:00WZ2P3oool200WZ2P030?oo
o`09jPX02NX:00<02NX:0P3oool01`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool01009jPX01P3o
ool02NX:00WZ2P3oool02NX:0?ooo`802NX:00H0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`<0
2NX:00<0oooo00WZ2P3oool01009jPX0103oool02NX:00WZ2P3oool500WZ2P030?ooo`09jPX0oooo
0080oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo00WZ2P050?ooo`0300WZ2P3oool02NX:
00h0oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0f0?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool200WZ2P80
oooo00P02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P3oool00P09
jPX00`3oool02NX:0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0P09jPX01@3oool02NX:
0?ooo`09jPX0oooo00P02NX:00@0oooo00WZ2P09jPX0oooo1P09jPX20?ooo`@02NX:00<0oooo00WZ
2P09jPX01009jPX0103oool02NX:00WZ2P3oool400WZ2P030?ooo`09jPX02NX:00T02NX:00H0oooo
00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P09jPX0
oooo0P09jPX00`3oool02NX:00WZ2P0300WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1`09jPX0
103oool02NX:00WZ2P3oool200WZ2P080?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX20?oo
o`<02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX0103oool02NX:00WZ2P3oool200WZ2P050?ooo`09
jPX02NX:0?ooo`09jPX00`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool02NX:00D0oooo
00<02NX:0?ooo`09jPX03P3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo03H0oooo0P09jPX20?ooo`802NX:00D0oooo00WZ2P3oool0oooo
00WZ2P020?ooo`802NX:0P3oool02009jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX2
0?ooo`<02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo
0P09jPX00`3oool02NX:0?ooo`0700WZ2P050?ooo`09jPX02NX:00WZ2P3oool01P09jPX20?ooo`/0
2NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P09
jPX0oooo0P09jPX00`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX0103o
ool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P3oool01009
jPX00`3oool02NX:00WZ2P0400WZ2P0;0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo
00WZ2P3oool01@09jPX0103oool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:
00D0oooo00WZ2P09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`09
jPX01@3oool00`09jPX0oooo00WZ2P0>0?ooo`0300WZ2P3oool0oooo0180oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0=P3oool200WZ2P80oooo0P09jPX01@3oool02NX:
0?ooo`3oool02NX:0080oooo0P09jPX20?ooo`<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ
2P80oooo0`09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3o
ool200WZ2P030?ooo`09jPX0oooo00L02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0600WZ2P80oooo
00<02NX:0?ooo`09jPX02009jPX20?ooo`0300WZ2P3oool02NX:00<02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0400WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P3oool01009jPX00`3o
ool02NX:00WZ2P020?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:00WZ2P3oool2
00WZ2P030?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX01009jPX02`3oool02NX:0?ooo`09
jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00D02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0
103oool02NX:00WZ2P3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool00`09jPX0oooo
0?ooo`020?ooo`0300WZ2P3oool02NX:00@0oooo00@02NX:0?ooo`3oool02NX:3P3oool00`09jPX0
oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03H0oooo
0P09jPX20?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`802NX:0P3oool300WZ2P04
0?ooo`09jPX0oooo0?ooo`<02NX:0P3oool300WZ2P80oooo0`09jPX20?ooo`0600WZ2P3oool02NX:
0?ooo`09jPX0oooo0P09jPX00`3oool02NX:0?ooo`0700WZ2P050?ooo`09jPX02NX:00WZ2P3oool0
1@09jPX01@3oool02NX:0?ooo`09jPX0oooo00X02NX:00<0oooo00WZ2P3oool01009jPX00`3oool0
2NX:00WZ2P0600WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P3oool01`09jPX20?oo
o`802NX:00<0oooo00WZ2P09jPX00P09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09
jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00@02NX:0140oooo00WZ2P3oool02NX:
0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P07
0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3o
ool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool02NX:00@0oooo00@02NX:0?ooo`3oool02NX:
3P3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo03L0oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo0P09jPX20?ooo`0300WZ
2P3oool0oooo00802NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`<02NX:
0P3oool00`09jPX0oooo00WZ2P020?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX00`3o
ool02NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX01@09jPX00`3o
ool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P3oool01009jPX00`3o
ool02NX:00WZ2P0500WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`07
00WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:
0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:
0?ooo`09jPX0oooo00802NX:0P3oool02009jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09
jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo
00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo00WZ2P040?ooo`0400WZ2P3oool0oooo00WZ2Ph0
oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`0g0?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`802NX:0P3oool00`09jPX0oooo
0?ooo`0200WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo
00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ
2P050?ooo`09jPX0oooo00WZ2P3oool02@09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX0
2NX:00@02NX:00<0oooo00WZ2P09jPX00`09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00<0
oooo00WZ2P09jPX01@09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool0
1`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P020?ooo`0500WZ
2P3oool02NX:00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX0oooo00@0
2NX:0P3oool02009jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`<02NX:0P3o
ool500WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo00WZ
2P040?ooo`0400WZ2P3oool0oooo00WZ2Ph0oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0g0?ooo`802NX:0P3oool300WZ2P80oooo0P09
jPX20?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo00WZ2P09jPX00P3oool02009jPX0oooo00WZ
2P09jPX0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo00WZ2P030?ooo`0500WZ2P3oool02NX:
00WZ2P3oool00P09jPX20?ooo`0300WZ2P3oool02NX:00T02NX:00<0oooo00WZ2P09jPX01@09jPX0
1@3oool02NX:00WZ2P09jPX0oooo00P02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P030?oo
o`09jPX02NX:00D02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00L0
2NX:0P3oool200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P3oool01@09jPX0
oooo00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:0?ooo`0400WZ
2P80oooo00P02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:0P3oool300WZ2P80oooo
1@09jPX00`3oool02NX:0?ooo`020?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`09jPX0
103oool01009jPX0oooo0?ooo`09jPX>0?ooo`0300WZ2P3oool0oooo0180oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0=`3oool200WZ2P80oooo0P09jPX00`3oool02NX:
0?ooo`0200WZ2P80oooo0P09jPX20?ooo`0800WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool2
00WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00`3oool01009jPX0oooo00WZ
2P3oool300WZ2P80oooo00<02NX:0?ooo`09jPX02`09jPX00`3oool02NX:00WZ2P0300WZ2P050?oo
o`09jPX02NX:00WZ2P3oool01009jPX01@3oool02NX:00WZ2P09jPX0oooo00H02NX:00<0oooo00WZ
2P09jPX01@09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool01`09jPX2
0?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P020?ooo`0500WZ2P3oool0
2NX:00WZ2P3oool01009jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool0
1009jPX02P3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09
jPX02NX:00802NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX0oooo0080oooo00<0
2NX:0?ooo`3oool00P3oool01009jPX0oooo0?ooo`09jPX30?ooo`0300WZ2P3oool02NX:00l0oooo
00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0g0?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool200WZ2P80oooo00P0
2NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool0
1009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:0P3oool00`09jPX0oooo
00WZ2P0;00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01`09jPX01@3oool02NX:
00WZ2P09jPX0oooo00H02NX:00<0oooo00WZ2P09jPX01@09jPX01@3oool02NX:00WZ2P09jPX0oooo
00802NX:00<0oooo00WZ2P3oool01`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX00`3o
ool02NX:00WZ2P020?ooo`0800WZ2P3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX20?ooo`<02NX:
00@0oooo00WZ2P09jPX0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00D0oooo00WZ
2P3oool02NX:0?ooo`0300WZ2P80oooo1009jPX20?ooo`0300WZ2P3oool02NX:00802NX:00<0oooo
00WZ2P3oool00P3oool00`09jPX0oooo0?ooo`020?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00<0
2NX:0?ooo`09jPX03`3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo03L0oooo0P09jPX20?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ
2P020?ooo`802NX:0P3oool02009jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX00`3o
ool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool01009jPX0oooo00WZ2P3oool3
00WZ2P80oooo00<02NX:0?ooo`09jPX01@09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX0
2NX:00802NX:00<0oooo00WZ2P09jPX02P09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX0
2NX:00D02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00L02NX:0P3o
ool200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P3oool02009jPX0oooo00WZ
2P09jPX0oooo00WZ2P3oool02NX:0P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00D0oooo
00WZ2P09jPX02NX:0?ooo`0300WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`@02NX:0P3o
ool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?ooo`3oool00P3o
ool01009jPX0oooo0?ooo`09jPX30?ooo`0300WZ2P3oool02NX:00l0oooo00<02NX:0?ooo`3oool0
4P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0g0?ooo`802NX:0P3o
ool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00P3oool200WZ2P80oooo0`09jPX01@3oool02NX:
0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P80
oooo00@02NX:0?ooo`09jPX0oooo0`09jPX20?ooo`0300WZ2P3oool02NX:00@02NX:00<0oooo00WZ
2P09jPX01009jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00X02NX:00<0oooo00WZ
2P09jPX01@09jPX00`3oool02NX:00WZ2P0500WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX0
0`3oool02NX:0?ooo`0700WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0
2NX:0080oooo00P02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P80oooo0`09jPX01`3oool0
2NX:00WZ2P09jPX0oooo00WZ2P3oool00`09jPX0103oool02NX:00WZ2P09jPX20?ooo`802NX:00<0
oooo00WZ2P09jPX00P3oool400WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00<0oooo00WZ2P3oool0
0P3oool00`09jPX0oooo0?ooo`020?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00<02NX:0?ooo`09
jPX03`3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo03P0oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3o
ool00P09jPX20?ooo`<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX00`3o
ool02NX:0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0P09jPX01@3oool02NX:0?ooo`09
jPX0oooo00D02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0:00WZ2P030?ooo`09
jPX02NX:00802NX:00T0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool01`09jPX01`3o
ool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09
jPX02NX:0080oooo00<02NX:0?ooo`3oool01009jPX00`3oool02NX:00WZ2P020?ooo`0800WZ2P3o
ool02NX:00WZ2P3oool02NX:0?ooo`09jPX20?ooo`<02NX:00L0oooo00WZ2P3oool02NX:0?ooo`09
jPX0oooo00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:0080oooo
0`09jPX20?ooo`802NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX30?ooo`0300WZ2P3oool0oooo
0080oooo00@02NX:0?ooo`3oool02NX:0`3oool00`09jPX0oooo00WZ2P0?0?ooo`0300WZ2P3oool0
oooo0180oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0>03oool200WZ
2P030?ooo`09jPX0oooo00802NX:0P3oool200WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX00`3o
ool02NX:00WZ2P020?ooo`<02NX:0P3oool300WZ2P030?ooo`09jPX0oooo00802NX:0P3oool01009
jPX0oooo00WZ2P3oool200WZ2P050?ooo`09jPX0oooo00WZ2P3oool01@09jPX00`3oool02NX:00WZ
2P0400WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX02@09jPX02@3oool02NX:00WZ
2P09jPX0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX0
0`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P3oool0
1009jPX0oooo00WZ2P3oool300WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P04
0?ooo`09jPX02NX:00WZ2P80oooo0`09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00`09
jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P3oool300WZ2P80oooo
0`09jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`3oool00P3oool01009jPX0
oooo0?ooo`09jPX30?ooo`0300WZ2P3oool02NX:00l0oooo00<02NX:0?ooo`3oool04P3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0h0?ooo`802NX:0P3oool300WZ2P80
oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0
oooo00WZ2P020?ooo`<02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0400WZ2P3oool02NX:0?oo
o`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00802NX:00L0oooo
00WZ2P3oool02NX:0?ooo`09jPX0oooo00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0=00WZ2P03
0?ooo`09jPX02NX:00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo
00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P020?ooo`0300WZ2P3oool02NX:
0080oooo0P09jPX02`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0080
2NX:0P3oool300WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX0
1@3oool02NX:00WZ2P09jPX0oooo00802NX:0P3oool300WZ2P80oooo0`09jPX01@3oool02NX:00WZ
2P3oool02NX:00<0oooo00<02NX:0?ooo`3oool00P3oool01009jPX0oooo0?ooo`09jPX30?ooo`03
00WZ2P3oool02NX:00l0oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`0h0?ooo`802NX:0P3oool300WZ2P80oooo0P09jPX20?ooo`0300WZ
2P3oool0oooo00802NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo00WZ2P020?ooo`<02NX:
0P3oool300WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo
00<02NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:00D0oooo
00WZ2P09jPX02NX:0?ooo`0:00WZ2P030?ooo`09jPX02NX:00H02NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0300WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:
00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo
0`09jPX00`3oool02NX:00WZ2P020?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P04
0?ooo`09jPX0oooo0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0
oooo00802NX:0P3oool300WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool00`09jPX0oooo0?oo
o`020?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00<02NX:0?ooo`09jPX03`3oool00`09jPX0oooo
0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03P0oooo0P09
jPX20?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`802NX:0P3oool01009jPX0oooo00WZ
2P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo
00WZ2P020?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:0?ooo`0600WZ
2P090?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00<02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0400WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0800WZ2P030?ooo`09jPX0
2NX:00D02NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0
2NX:0080oooo00<02NX:0?ooo`09jPX00P3oool200WZ2P030?ooo`09jPX02NX:00802NX:0P3oool3
00WZ2P030?ooo`09jPX02NX:0080oooo0`09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00D0
oooo00WZ2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P3oool0
2NX:0?ooo`0200WZ2P80oooo0`09jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo00<02NX:0?oo
o`3oool00P3oool01009jPX0oooo0?ooo`09jPX30?ooo`0300WZ2P3oool02NX:00l0oooo00<02NX:
0?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0h0?oo
o`802NX:0P3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00P3oool200WZ2P80oooo00P02NX:
0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool00`09
jPX0oooo00WZ2P020?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:0?oo
o`0600WZ2P090?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00L02NX:00<0oooo00WZ
2P09jPX00P09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool02009jPX00`3oool02NX:00WZ
2P0500WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ
2P020?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool01009jPX20?ooo`<02NX:00<0
oooo00WZ2P09jPX00P3oool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX01@3oool02NX:
0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`0400WZ2P3oool02NX:00WZ
2P80oooo0`09jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`3oool00P3oool0
1@09jPX0oooo0?ooo`3oool02NX:0080oooo00<02NX:0?ooo`09jPX03`3oool00`09jPX0oooo0?oo
o`0B0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03P0oooo00@02NX:
0?ooo`09jPX0oooo0P09jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo0P09jPX20?ooo`0800WZ
2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00<0
2NX:0?ooo`09jPX00P3oool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P3o
ool01P09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX03P09jPX00`3o
ool02NX:0?ooo`0800WZ2P030?ooo`09jPX02NX:00L02NX:00@0oooo00WZ2P09jPX0oooo1009jPX0
0`3oool02NX:00WZ2P0300WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00P3oool400WZ2P80oooo0`09
jPX00`3oool02NX:00WZ2P020?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P050?oo
o`09jPX02NX:00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool200WZ2P80oooo00D02NX:0?oo
o`09jPX02NX:0?ooo`0400WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool00`09jPX0oooo0?oo
o`020?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P0?0?ooo`0300WZ
2P3oool0oooo0180oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0>@3o
ool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo
00P02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3o
ool00`09jPX0oooo00WZ2P030?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX01@3oool02NX:0?oo
o`09jPX0oooo00@02NX:00@0oooo00WZ2P09jPX02NX:0P3oool200WZ2P030?ooo`09jPX02NX:00L0
2NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:0?ooo`0800WZ2P80oooo1009jPX01@3oool0
2NX:00WZ2P09jPX0oooo00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool500WZ2P050?ooo`09
jPX0oooo0?ooo`09jPX00P3oool400WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P020?ooo`<02NX:
00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0300WZ2P040?ooo`09jPX02NX:0?ooo`80
2NX:00<0oooo00WZ2P09jPX00P3oool400WZ2P040?ooo`09jPX02NX:00WZ2P80oooo0P09jPX00`3o
ool02NX:0?ooo`020?ooo`0300WZ2P3oool0oooo0080oooo00D02NX:0?ooo`3oool0oooo00WZ2P02
0?ooo`0300WZ2P3oool02NX:00l0oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`0i0?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX20?oo
o`802NX:00<0oooo00WZ2P09jPX00P3oool300WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX0
0`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool01@09jPX0oooo00WZ2P09
jPX0oooo00802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0900WZ2P040?ooo`09jPX02NX:0?oooa80
2NX:00<0oooo00WZ2P09jPX01P09jPX20?ooo`@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ
2P040?ooo`09jPX02NX:0?ooo`L02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P02
00WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P020?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX0
0`3oool02NX:0?ooo`0300WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo
0`09jPX20?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?ooo`3oool0
0P3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo00<02NX:0?ooo`09jPX03P3oool00`09jPX0
oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03T0oooo
0P09jPX20?ooo`<02NX:0P3oool200WZ2P80oooo00<02NX:0?ooo`3oool00`09jPX01@3oool02NX:
0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P80
oooo00@02NX:0?ooo`09jPX0oooo0`09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool01`09
jPX0103oool02NX:00WZ2P3ooolB00WZ2P80oooo00<02NX:0?ooo`09jPX01009jPX20?ooo`@02NX:
00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo0?ooo`L02NX:00<0oooo00WZ
2P3oool00`09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0`09jPX00`3oool02NX:0?ooo`0200WZ
2P040?ooo`09jPX02NX:0?ooo`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P050?ooo`09
jPX02NX:00WZ2P3oool01009jPX20?ooo`<02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`802NX:
0P3oool01009jPX0oooo0?ooo`09jPX40?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00P3oool00`09
jPX0oooo00WZ2P0>0?ooo`0300WZ2P3oool0oooo01<0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0>@3oool200WZ2P80oooo0`09jPX20?ooo`802NX:0P3oool00`09jPX0
oooo0?ooo`0200WZ2P030?ooo`09jPX02NX:0080oooo0`09jPX20?ooo`<02NX:00<0oooo00WZ2P3o
ool00P09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX0oooo
00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool03`09
jPX00`3oool02NX:0?ooo`0500WZ2P80oooo1009jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:
00@0oooo00WZ2P3oool0oooo1`09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:0080
2NX:0P3oool300WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX01@3o
ool02NX:0?ooo`09jPX0oooo00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P030?ooo`09
jPX0oooo00802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`802NX:0P3oool01009jPX0oooo0?oo
o`09jPX40?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P0>0?ooo`03
00WZ2P3oool0oooo01<0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
>@3oool200WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo00<02NX:0?ooo`3oool0
0P09jPX00`3oool02NX:00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo0`09jPX00`3oool02NX:
0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0`09jPX20?ooo`@02NX:00D0oooo00WZ2P09
jPX02NX:0?ooo`0300WZ2P040?ooo`09jPX02NX:0?oooa<02NX:00<0oooo00WZ2P3oool01@09jPX2
0?ooo`@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00P02NX:00<0
oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo0`09jPX00`3oool02NX:0?oo
o`0600WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool300WZ2P03
0?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0300WZ2P3oool02NX:0080
oooo0P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P02
0?ooo`0300WZ2P3oool02NX:00h0oooo00<02NX:0?ooo`3oool04`3oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`0i0?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX0oooo
00802NX:0P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P02
0?ooo`<02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:0P3o
ool<00WZ2P040?ooo`09jPX02NX:0?ooo``02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX01@3oool0
2NX:0?ooo`09jPX0oooo00<02NX:0P3oool400WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0
0`3oool02NX:0?ooo`0800WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool00P09jPX2
0?ooo`<02NX:00<0oooo00WZ2P3oool01P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0
oooo00802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool0
0P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo0P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P@0
oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:00h0oooo00<02NX:0?oo
o`3oool04`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0i0?ooo`04
00WZ2P3oool02NX:0?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`802NX:0P3oool0
1009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo0`09jPX00`3oool02NX:0?oo
o`0200WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0`09jPX20?ooo`D02NX:00<0oooo00WZ2P09jPX0
1009jPX0103oool02NX:00WZ2P3oool900WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00T0oooo00WZ
2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool00`09jPX20?ooo`@02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00P02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool0
2NX:0?ooo`0200WZ2P80oooo00<02NX:0?ooo`09jPX00P09jPX00`3oool02NX:00WZ2P0400WZ2P03
0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool02NX:0P3oool300WZ2P040?ooo`09jPX02NX:
00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo0080oooo00@0
2NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0080oooo
00D02NX:0?ooo`09jPX0oooo00WZ2P0>0?ooo`0300WZ2P3oool0oooo01<0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0>P3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09
jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00P02NX:0?ooo`09jPX0oooo00WZ2P3oool0
2NX:0?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool300WZ2P80oooo00@02NX:0?ooo`09jPX0
oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX01009jPX0103o
ool02NX:00WZ2P3oool900WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0300WZ2P040?ooo`09jPX02NX:00WZ2P80oooo1009jPX01@3oool02NX:00WZ2P09jPX0oooo
00802NX:00<0oooo00WZ2P3oool02009jPX00`3oool02NX:0?ooo`0500WZ2P030?ooo`09jPX02NX:
0080oooo1@09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ
2P3oool02NX:0P3oool700WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`0400WZ2P<0oooo00@02NX:
0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0080oooo00D0
2NX:0?ooo`09jPX0oooo00WZ2P0>0?ooo`0300WZ2P3oool0oooo01<0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool0>P3oool200WZ2P030?ooo`09jPX0oooo00802NX:0P3o
ool00`09jPX0oooo0?ooo`0200WZ2P80oooo00P02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?oo
o`802NX:00@0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0
2NX:0?ooo`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00@02NX:
00@0oooo00WZ2P09jPX0oooo2@09jPX0103oool02NX:00WZ2P3oool500WZ2P030?ooo`09jPX02NX:
00802NX:00@0oooo00WZ2P09jPX02NX:0P3oool400WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:
0?ooo`0200WZ2P030?ooo`09jPX0oooo00<02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool500WZ
2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09
jPX0oooo00802NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00H02NX:0P3oool400WZ2P03
0?ooo`09jPX02NX:00802NX:0`3oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo
0080oooo00<02NX:0?ooo`3oool00P3oool01@09jPX0oooo00WZ2P3oool02NX:00h0oooo00<02NX:
0?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0j0?oo
o`802NX:0P3oool300WZ2P80oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00<02NX:00D0oooo00WZ
2P3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00P3o
ool01009jPX0oooo00WZ2P3oool200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00`09jPX00`3oool0
2NX:0?ooo`0400WZ2P040?ooo`09jPX02NX:0?ooo`H02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0
0`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00H02NX:0P3oool400WZ2P070?ooo`09jPX0
2NX:00WZ2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00<02NX:00H0oooo00WZ2P09jPX0
oooo00WZ2P3oool500WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1009jPX00`3oool02NX:00WZ
2P0400WZ2P0>0?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ
2P3oool400WZ2P80oooo1009jPX00`3oool02NX:0?ooo`0200WZ2P<0oooo00@02NX:0?ooo`3oool0
2NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0080oooo00D02NX:0?ooo`09
jPX0oooo00WZ2P0>0?ooo`0300WZ2P3oool0oooo01<0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0>P3oool200WZ2P80oooo0`09jPX20?ooo`802NX:0P3oool00`09jPX0
oooo0?ooo`0300WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`09jPX2
0?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX0oooo0P09jPX01@3oool02NX:0?oo
o`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool02P09jPX00`3oool02NX:00WZ2P0700WZ2P070?oo
o`09jPX02NX:00WZ2P3oool02NX:0?ooo`0800WZ2P80oooo2009jPX00`3oool02NX:0?ooo`0200WZ
2P030?ooo`09jPX0oooo00802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00D02NX:00H0
oooo00WZ2P09jPX0oooo00WZ2P3oool400WZ2P030?ooo`09jPX02NX:00@02NX:00h0oooo00WZ2P09
jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`@02NX:0P3oool400WZ
2P030?ooo`09jPX0oooo00802NX:0`3oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool0
oooo0080oooo00<02NX:0?ooo`3oool00P3oool01@09jPX0oooo00WZ2P3oool02NX:00h0oooo00<0
2NX:0?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0j
0?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo0?ooo`03
00WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09
jPX0oooo00WZ2P80oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0oooo
00<02NX:00<0oooo00WZ2P09jPX02P09jPX00`3oool02NX:00WZ2P0;00WZ2P030?ooo`09jPX0oooo
00P02NX:00<0oooo00WZ2P3oool01`09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo
00802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00D02NX:00H0oooo00WZ2P09jPX0oooo
00WZ2P3oool400WZ2P050?ooo`09jPX02NX:00WZ2P3oool01@09jPX02`3oool02NX:0?ooo`09jPX0
oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P3oool01@09jPX00`3oool0
2NX:00WZ2P030?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX03P3oool00`09jPX0oooo0?ooo`0C
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03X0oooo0P09jPX20?oo
o`802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo00WZ
2P09jPX00P3oool300WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool02NX:0`3oool2
00WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0:
00WZ2P030?ooo`09jPX02NX:00P02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool800WZ2P030?oo
o`09jPX0oooo00L02NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P050?oo
o`09jPX02NX:0?ooo`09jPX00P3oool500WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1009jPX0
1@3oool02NX:00WZ2P09jPX0oooo00D02NX:00d0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ
2P3oool02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ
2P3oool200WZ2P<0oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`03
00WZ2P3oool0oooo0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P0>0?ooo`0300WZ2P3oool0oooo
01<0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0>`3oool200WZ2P05
0?ooo`09jPX02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2P040?ooo`09jPX02NX:
0?ooo`802NX:0P3oool300WZ2P80oooo0`09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo00D02NX:
0?ooo`09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P09jPX0oooo
2@09jPX00`3oool02NX:00WZ2P0800WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX0
1P09jPX00`3oool02NX:0?ooo`0400WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX00`3o
ool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool500WZ2P060?ooo`09jPX0
2NX:0?ooo`09jPX0oooo0`09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:
00WZ2P020?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo0`09jPX20?ooo`0500WZ2P3oool02NX:
00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P030?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<0
2NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0
3P3oool00`09jPX0oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo03/0oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool0
0P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool300WZ2P03
0?ooo`09jPX0oooo00802NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:00<0oooo00WZ
2P3oool00`09jPX0103oool02NX:00WZ2P3oool500WZ2P030?ooo`09jPX0oooo00`02NX:00<0oooo
00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX0oooo00@02NX:00<0oooo
00WZ2P09jPX00P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00D0oooo00WZ2P09jPX0
oooo00WZ2P020?ooo`0300WZ2P3oool02NX:00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool3
00WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:0080oooo00H02NX:
0?ooo`09jPX0oooo00WZ2P3oool300WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P03
0?ooo`09jPX0oooo0080oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`020?oo
o`0300WZ2P3oool0oooo00<0oooo0P09jPX00`3oool02NX:0?ooo`0=0?ooo`0300WZ2P3oool0oooo
01<0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0>`3oool200WZ2P03
0?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00T02NX:0?ooo`09
jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX00P3oool300WZ2P030?ooo`09jPX0oooo00802NX:0P3o
ool01009jPX0oooo00WZ2P3oool500WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX01`3oool0
2NX:00WZ2P09jPX0oooo00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX0
oooo00<02NX:00<0oooo00WZ2P3oool01@09jPX00`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX0
2NX:00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09
jPX00P3oool00`09jPX0oooo00WZ2P0200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0`09jPX2
0?ooo`<02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0
oooo00802NX:00<0oooo00WZ2P09jPX00P3oool300WZ2P80oooo0`09jPX00`3oool02NX:0?ooo`02
0?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?oo
o`030?ooo`802NX:00<0oooo00WZ2P3oool03@3oool00`09jPX0oooo0?ooo`0C0?ooo`030000003o
ool0oooo00D0oooo00070?ooo`030000003oool0oooo03/0oooo0P09jPX20?ooo`<02NX:0P3oool2
00WZ2P030?ooo`09jPX02NX:0080oooo00T02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09
jPX00P3oool300WZ2P030?ooo`09jPX0oooo00802NX:0P3oool01009jPX0oooo00WZ2P3oool500WZ
2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0600WZ2P030?ooo`09jPX02NX:00802NX:00<0
oooo00WZ2P09jPX00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00D02NX:00D0oooo00WZ2P3oool0
2NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00T02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool2
00WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`09jPX20?ooo`@02NX:
00@0oooo00WZ2P3oool02NX:0P3oool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3o
ool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00P3oool300WZ
2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<0
2NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`802NX:00<0oooo00WZ2P3oool03@3o
ool00`09jPX0oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo03/0oooo0P09jPX20?ooo`<02NX:0P3oool200WZ2P80oooo00<02NX:0?ooo`3oool00`09jPX0
1@3oool02NX:0?ooo`09jPX0oooo00802NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0080
2NX:0P3oool01009jPX0oooo00WZ2P3oool500WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?oo
o`0600WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ
2P0700WZ2P050?ooo`09jPX0oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0900WZ2P060?oo
o`09jPX02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo00@02NX:0?oo
o`3oool02NX:0P3oool400WZ2P040?ooo`09jPX0oooo00WZ2P80oooo0`09jPX01@3oool02NX:00WZ
2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool00`09jPX01@3oool02NX:00WZ2P09jPX0oooo0080
2NX:0P3oool300WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`0400WZ2P3oool0oooo
00WZ2P80oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`802NX:00<0oooo
00WZ2P3oool03@3oool00`09jPX0oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00070?oo
o`030000003oool0oooo03/0oooo0P09jPX20?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX20?oo
o`0300WZ2P3oool0oooo00<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX0
oooo00WZ2P80oooo0`09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`@02NX:00P0oooo00WZ2P09jPX0
oooo00WZ2P3oool02NX:0?ooo`H02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P03
00WZ2P030?ooo`09jPX02NX:00L02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09
jPX0oooo00T02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:0080
2NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo0?ooo`0400WZ2P040?ooo`09jPX02NX:00WZ
2P80oooo0`09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool00`09jPX0
1@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0500WZ2P3o
ool02NX:0?ooo`09jPX00`3oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo0080
oooo00<02NX:0?ooo`3oool00`3oool200WZ2P030?ooo`09jPX0oooo00d0oooo00<02NX:0?ooo`3o
ool04`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0k0?ooo`802NX:
0P3oool200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo0?ooo`0300WZ2P050?oo
o`09jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool02NX:
0080oooo00@02NX:0?ooo`09jPX0oooo1009jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0
oooo00H02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0:00WZ2P080?ooo`09jPX0
2NX:0?ooo`09jPX0oooo00WZ2P3oool500WZ2P030?ooo`09jPX02NX:00L02NX:00H0oooo00WZ2P09
jPX0oooo00WZ2P3oool700WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?ooo`3oool01@09jPX0
0`3oool02NX:00WZ2P020?ooo`<02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:0?ooo`03
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P070?ooo`09
jPX02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?oo
o`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`802NX:00<0oooo00WZ2P3oool03@3oool00`09
jPX0oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03`0
oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`02
00WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`03
00WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX0oooo1009jPX00`3oool02NX:0?ooo`0200WZ
2P030?ooo`09jPX0oooo00P02NX:00<0oooo00WZ2P09jPX00P3oool;00WZ2P030?ooo`09jPX02NX:
00X02NX:00<0oooo00WZ2P3oool01`09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`L02NX:00<0
oooo00WZ2P09jPX00P3oool00`09jPX0oooo0?ooo`0500WZ2P030?ooo`09jPX02NX:0080oooo0`09
jPX00`3oool02NX:00WZ2P0400WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P06
0?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`09jPX40?ooo`0300WZ2P3oool0oooo00<0
oooo0P09jPX00`3oool02NX:0?ooo`0=0?ooo`0300WZ2P3oool0oooo01<0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0?03oool200WZ2P050?ooo`09jPX02NX:0?ooo`09
jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool300WZ
2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool02NX:0P3oool01009jPX0oooo00WZ2P3o
ool200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`3oool300WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool00P09jPX20?ooo`/02NX:00<0oooo00WZ2P3oool02P09jPX00`3o
ool02NX:0?ooo`0700WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1`09jPX00`3oool02NX:00WZ
2P020?ooo`802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:0P3oool200WZ2P80
oooo0P09jPX02`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00H02NX:
00<0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P09jPX20?ooo`0500WZ2P3oool0oooo0?oo
o`09jPX00P3oool01009jPX0oooo0?ooo`09jPX40?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPX0
0`3oool02NX:0?ooo`0=0?ooo`0300WZ2P3oool0oooo01<0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0?03oool200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool00`09
jPX0oooo0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool300WZ2P030?ooo`09jPX0
oooo00802NX:00@0oooo00WZ2P3oool02NX:0P3oool01009jPX0oooo00WZ2P3oool200WZ2P050?oo
o`09jPX0oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0700WZ2P030?ooo`09jPX02NX:0080
oooo2009jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P3o
ool01`09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`L02NX:00@0oooo00WZ2P09jPX0oooo0`09
jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX20?ooo`802NX:0P3oool700WZ2P80
oooo00@02NX:0?ooo`09jPX0oooo1P09jPX0103oool02NX:00WZ2P09jPX20?ooo`<02NX:0P3oool0
1@09jPX0oooo0?ooo`3oool02NX:0080oooo00@02NX:0?ooo`3oool02NX:103oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool02NX:00h0oooo00<02NX:0?ooo`3oool04`3oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0l0?ooo`802NX:0P3oool300WZ2P80oooo00<0
2NX:0?ooo`3oool00P09jPX20?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`09jPX0
0P3oool300WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0P09jPX01@3o
ool02NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool01`09jPX00`3oool02NX:00WZ2P02
0?ooo`X02NX:00@0oooo00WZ2P09jPX0oooo2P09jPX00`3oool02NX:0?ooo`0700WZ2P060?ooo`09
jPX02NX:0?ooo`09jPX0oooo1`09jPX0103oool02NX:00WZ2P3oool400WZ2P060?ooo`09jPX02NX:
0?ooo`09jPX0oooo0P09jPX20?ooo`802NX:0P3oool700WZ2P060?ooo`09jPX0oooo0?ooo`09jPX0
oooo1P09jPX0103oool02NX:00WZ2P09jPX20?ooo`<02NX:0P3oool01@09jPX0oooo0?ooo`3oool0
2NX:0080oooo00@02NX:0?ooo`3oool02NX:103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3o
ool02NX:00d0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0l0?ooo`802NX:0P3oool300WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P02
0?ooo`0900WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0080oooo0`09jPX00`3oool0
2NX:0?ooo`0200WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00<0
2NX:00<0oooo00WZ2P3oool01`09jPX00`3oool02NX:00WZ2P020?ooo`@02NX:00<0oooo00WZ2P09
jPX00`09jPX00`3oool02NX:00WZ2P0;00WZ2P030?ooo`09jPX0oooo00L02NX:00<0oooo00WZ2P09
jPX00P09jPX00`3oool02NX:00WZ2P0500WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:0P3oool01009
jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09jPX0
103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool02NX:00D02NX:00@0oooo00WZ2P09jPX02NX:
0P3oool300WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo00WZ
2P@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo00WZ2P0=0?ooo`0300WZ2P3oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0?03oool200WZ2P80
oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo00`02NX:0?ooo`3oool02NX:0?ooo`09jPX0
oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`<02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`80
2NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00L0
2NX:00<0oooo00WZ2P09jPX00P3oool400WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09
jPX02`09jPX00`3oool02NX:0?ooo`0700WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09
jPX01@09jPX0103oool02NX:00WZ2P3oool400WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0P09jPX0
0`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P3oool00P09jPX0
0`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:0080oooo0`09jPX20?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`09jPX40?ooo`0300WZ2P3oool0oooo00@0oooo
00<02NX:0?ooo`09jPX03@3oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo03`0oooo00@02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:
0?ooo`0200WZ2P80oooo00<02NX:0?ooo`3oool00`09jPX01@3oool02NX:0?ooo`09jPX0oooo0080
2NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:0P3oool01@09jPX0oooo00WZ2P09
jPX0oooo00802NX:00<0oooo00WZ2P3oool00`09jPX0103oool02NX:0?ooo`3oool300WZ2P040?oo
o`09jPX02NX:0?ooo`802NX:0P3oool400WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09
jPX00`09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX0oooo00L02NX:00<0oooo00WZ2P09
jPX00P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09
jPX00P09jPX20?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo1P09jPX00`3oool02NX:00WZ2P04
00WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX01009jPX0103oool02NX:00WZ2P3o
ool400WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo00WZ2P@0
oooo00<02NX:0?ooo`3oool00`3oool200WZ2P030?ooo`09jPX0oooo00`0oooo00<02NX:0?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0m0?ooo`802NX:
00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P80oooo00<02NX:0?ooo`3oool00`09jPX01@3o
ool02NX:0?ooo`09jPX0oooo00802NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00802NX:
0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool00`09jPX0103oool0
2NX:0?ooo`3oool600WZ2P030?ooo`09jPX02NX:0080oooo1P09jPX0103oool02NX:00WZ2P09jPX2
0?ooo`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0500WZ2P030?ooo`09jPX0oooo00L02NX:00<0
oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00802NX:00<0
oooo00WZ2P09jPX00P09jPX20?ooo`<02NX:00<0oooo00WZ2P3oool01P09jPX00`3oool02NX:00WZ
2P0400WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX01009jPX0103oool02NX:00WZ
2P3oool300WZ2P<0oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo00WZ
2P@0oooo00<02NX:0?ooo`3oool00`3oool200WZ2P030?ooo`09jPX0oooo00`0oooo00<02NX:0?oo
o`3oool0503oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0m0?ooo`80
2NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo00WZ2P80oooo0`09jPX0
1@3oool02NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool02NX:0P3oool300WZ2P80oooo
00@02NX:0?ooo`09jPX0oooo0`09jPX00`3oool02NX:0?ooo`0300WZ2P040?ooo`09jPX0oooo0?oo
o`H02NX:00@0oooo00WZ2P09jPX0oooo1`09jPX00`3oool02NX:00WZ2P0200WZ2P080?ooo`09jPX0
2NX:0?ooo`09jPX0oooo00WZ2P3oool500WZ2P030?ooo`09jPX0oooo00D02NX:00<0oooo00WZ2P3o
ool00`09jPX20?ooo`0300WZ2P3oool02NX:00@02NX:00@0oooo00WZ2P09jPX0oooo1009jPX20?oo
o`<02NX:00<0oooo00WZ2P3oool01P09jPX0103oool02NX:00WZ2P3oool300WZ2P030?ooo`09jPX0
oooo00<02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX0103oool02NX:00WZ2P3oool300WZ2P<0oooo
00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo00<02NX:0?oo
o`3oool00`3oool200WZ2P030?ooo`09jPX0oooo00`0oooo00<02NX:0?ooo`3oool0503oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0m0?ooo`802NX:00<0oooo00WZ2P3o
ool00P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3o
ool02NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo0`09jPX20?ooo`0400WZ2P3oool0
2NX:0?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX0103oool02NX:0?ooo`3oool600WZ2P040?oo
o`09jPX02NX:0?ooo`T02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX01`3oool02NX:0?ooo`09jPX0
oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0500WZ2P060?ooo`09jPX0oooo00WZ2P3oool0
2NX:0P3oool00`09jPX0oooo00WZ2P0400WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:0P3oool300WZ
2P030?ooo`09jPX0oooo00H02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:0?ooo`03
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX20?ooo`<02NX:0`3oool01@09jPX0oooo0?oo
o`3oool02NX:0080oooo00@02NX:0?ooo`3oool02NX:103oool00`09jPX0oooo0?ooo`030?ooo`80
2NX:00<0oooo00WZ2P3oool0303oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo03d0oooo0P09jPX20?ooo`<02NX:0P3oool00`09jPX0oooo
0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool300WZ2P040?ooo`09jPX0oooo00WZ
2P80oooo0`09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX0
103oool02NX:0?ooo`3ooolC00WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX02`3oool0
2NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00D02NX:00H0oooo00WZ2P09jPX0
2NX:0?ooo`09jPX20?ooo`0300WZ2P3oool02NX:00@02NX:00@0oooo00WZ2P09jPX0oooo1009jPX2
0?ooo`D02NX:00<0oooo00WZ2P09jPX01009jPX0103oool02NX:00WZ2P3oool300WZ2P030?ooo`09
jPX0oooo00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P80oooo00<02NX:0?ooo`09jPX0
0`3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo00@02NX:0?ooo`3oool02NX:103oool00`09
jPX0oooo0?ooo`030?ooo`802NX:00<0oooo00WZ2P3oool0303oool00`09jPX0oooo0?ooo`0D0?oo
o`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03d0oooo0P09jPX20?ooo`<0
2NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool300WZ
2P040?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo00WZ2P3o
ool300WZ2P030?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P3oool0oooo4`09jPX01P3oool02NX:
00WZ2P3oool02NX:0?ooo`802NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00<02NX:00<0
oooo00WZ2P09jPX00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool0
0P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo00@02NX:0?ooo`09jPX02NX:0P3oool500WZ
2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo00WZ2P0300WZ
2P040?ooo`09jPX02NX:0?ooo`@02NX:0P3oool00`09jPX0oooo00WZ2P030?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2P<0oooo00<02NX:0?ooo`3oool00`3o
ool01009jPX0oooo00WZ2P09jPX=0?ooo`0300WZ2P3oool0oooo01@0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool0?@3oool200WZ2P80oooo0`09jPX20?ooo`802NX:00<0
oooo00WZ2P09jPX00P3oool01009jPX0oooo00WZ2P09jPX20?ooo`<02NX:00<0oooo00WZ2P3oool0
0P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:0P3oool200WZ
2P040?ooo`09jPX0oooo00WZ2P80oooo5P09jPX00`3oool02NX:0?ooo`0800WZ2P050?ooo`09jPX0
2NX:00WZ2P3oool02@09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00D0oooo00WZ2P09
jPX0oooo00WZ2P020?ooo`0400WZ2P3oool02NX:00WZ2P80oooo0P09jPX0103oool02NX:00WZ2P3o
ool300WZ2P030?ooo`09jPX02NX:00<02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`@02NX:
00@0oooo00WZ2P09jPX0oooo1009jPX20?ooo`0300WZ2P3oool02NX:00<0oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00802NX:0`3oool00`09jPX0oooo0?ooo`030?oo
o`0400WZ2P3oool02NX:00WZ2Pd0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`0n0?ooo`802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3o
ool200WZ2P80oooo00`02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09
jPX20?ooo`<02NX:00@0oooo00WZ2P3oool02NX:0P3oool01009jPX0oooo00WZ2P3oool300WZ2P80
oooo0P09jPX0103oool02NX:0?ooo`09jPX20?oooaH02NX:00<0oooo00WZ2P09jPX02009jPX01@3o
ool02NX:00WZ2P09jPX0oooo00T02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P050?oo
o`09jPX02NX:0?ooo`09jPX00P3oool01009jPX0oooo00WZ2P09jPX20?ooo`802NX:00@0oooo00WZ
2P09jPX0oooo0`09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00L0oooo00WZ2P3oool02NX:
0?ooo`09jPX0oooo00<02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P050?ooo`09jPX0
2NX:0?ooo`09jPX00`3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo00<02NX:0?ooo`3oool0
0P09jPX30?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`09jPX02NX:3@3oool00`09jPX0
oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03h0oooo
0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`0300WZ
2P060?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool300WZ2P040?ooo`09jPX0oooo00WZ2P80oooo
00@02NX:0?ooo`09jPX0oooo0`09jPX20?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3ooolA00WZ
2P030?ooo`09jPX02NX:00d02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0900WZ2P030?ooo`09jPX0
2NX:00802NX:0P3oool01P09jPX0oooo00WZ2P09jPX0oooo00WZ2P80oooo00T02NX:0?ooo`09jPX0
2NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX02@3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool0
2NX:0?ooo`0200WZ2P0;0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool0
0P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:0`3oool01@09jPX0oooo
0?ooo`3oool02NX:0080oooo00<02NX:0?ooo`3oool00P09jPX30?ooo`0300WZ2P3oool0oooo00<0
oooo00@02NX:0?ooo`09jPX02NX:3@3oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo03h0oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:
0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`0300WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:
0P3oool300WZ2P030?ooo`09jPX0oooo00802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P05
0?ooo`09jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`3oool900WZ2P030?ooo`09jPX0
2NX:00D02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0500WZ2P050?ooo`09jPX0
2NX:00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:0P3o
ool01009jPX0oooo00WZ2P3oool200WZ2P80oooo00T02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo
00WZ2P3oool00P09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:00h0oooo00WZ2P09jPX0oooo
00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX0
0P09jPX00`3oool02NX:00WZ2P0200WZ2P<0oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`03
00WZ2P3oool0oooo00802NX:0`3oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool02NX:00WZ
2Pd0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0n0?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`0300WZ2P3oool0oooo0080
2NX:00T0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX01`3oool02NX:00WZ
2P09jPX0oooo00WZ2P3oool00P09jPX20?ooo`802NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool0
2NX:0?ooo`802NX:00P0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`d02NX:00<0oooo00WZ
2P09jPX01@09jPX00`3oool02NX:00WZ2P0900WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ
2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo00<02NX:0?ooo`09jPX00`09jPX20?oo
o`0900WZ2P3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00802NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0300WZ2P0<0?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0
oooo0`09jPX20?ooo`<02NX:0P3oool400WZ2P<0oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?oo
o`0300WZ2P3oool0oooo00802NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`0400WZ2P3oool02NX:
00WZ2Pd0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0n0?ooo`802NX:0P3oool300WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX0103o
ool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00802NX:00L0oooo00WZ2P3oool02NX:0?oo
o`09jPX0oooo00802NX:0P3oool200WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool2
00WZ2P080?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool=00WZ2P030?ooo`09jPX02NX:00D0
2NX:00<0oooo00WZ2P09jPX02@09jPX00`3oool02NX:00WZ2P0400WZ2P040?ooo`09jPX02NX:0?oo
o`@02NX:0P3oool600WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00H0oooo00WZ2P3oool02NX:0?oo
o`09jPX20?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P090?ooo`09jPX0oooo00WZ
2P3oool02NX:0?ooo`09jPX0oooo00<02NX:0P3oool300WZ2P80oooo00<02NX:0?ooo`09jPX00P09
jPX20?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo
00<02NX:0?ooo`3oool0103oool01009jPX0oooo00WZ2P09jPX=0?ooo`0300WZ2P3oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0?P3oool200WZ2P80oooo
0`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool0
2NX:0?ooo`0200WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo0P09jPX0
0`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00@02NX:0P3oool01009jPX0oooo00WZ2P3o
ool=00WZ2P030?ooo`09jPX0oooo00D02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0700WZ2P030?oo
o`09jPX02NX:00@02NX:00@0oooo00WZ2P09jPX0oooo1009jPX00`3oool02NX:00WZ2P0500WZ2P04
0?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`<02NX:00<0oooo00WZ
2P09jPX01009jPX02@3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P80oooo
0`09jPX20?ooo`0300WZ2P3oool02NX:00802NX:0P3oool01@09jPX0oooo0?ooo`3oool02NX:0080
oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`0300WZ2P3oool0oooo00@0oooo00@02NX:0?ooo`09
jPX02NX:3@3oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo03h0oooo0P09jPX20?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080
oooo00@02NX:0?ooo`09jPX02NX:0P3oool300WZ2P040?ooo`09jPX0oooo00WZ2P80oooo0`09jPX2
0?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0400WZ2P80oooo00@0
2NX:0?ooo`09jPX0oooo3@09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00802NX:
00<0oooo00WZ2P3oool01`09jPX00`3oool02NX:00WZ2P0400WZ2P060?ooo`09jPX02NX:0?ooo`09
jPX0oooo0P09jPX00`3oool02NX:00WZ2P0500WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo
00WZ2P3oool00`09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX01009jPX01`3oool02NX:0?ooo`09
jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P020?ooo`<02NX:0P3oool00`09jPX0oooo
00WZ2P0200WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0080
2NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`0400WZ2P3oool0oooo00WZ2Pd0oooo00<02NX:0?oo
o`3oool0503oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0o0?ooo`80
2NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00@02NX:
0?ooo`09jPX02NX:0P3oool300WZ2P040?ooo`09jPX0oooo00WZ2P80oooo0`09jPX20?ooo`0500WZ
2P3oool02NX:00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0300WZ2P070?ooo`09jPX0oooo00WZ
2P3oool02NX:0?ooo`0600WZ2P030?ooo`09jPX02NX:00/02NX:00P0oooo00WZ2P09jPX0oooo00WZ
2P3oool02NX:0?ooo`H02NX:00<0oooo00WZ2P3oool00`09jPX01P3oool02NX:00WZ2P3oool02NX:
0?ooo`802NX:00<0oooo00WZ2P09jPX01@09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09
jPX0oooo00<02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P3oool00P09
jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ
2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00802NX:0P3oool0
0`09jPX0oooo0?ooo`040?ooo`0400WZ2P3oool0oooo00WZ2Pd0oooo00<02NX:0?ooo`3oool0503o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0o0?ooo`802NX:00H0oooo
00WZ2P09jPX0oooo00WZ2P3oool200WZ2P80oooo00T02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo
00WZ2P3oool00`09jPX0103oool02NX:0?ooo`09jPX20?ooo`<02NX:0P3oool00`09jPX0oooo00WZ
2P0400WZ2P030?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P3oool0oooo2@09jPX01@3oool02NX:
00WZ2P09jPX0oooo00T02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0600WZ2P03
0?ooo`09jPX0oooo00<02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0
2NX:00D02NX:00@0oooo00WZ2P09jPX0oooo1009jPX0103oool02NX:00WZ2P09jPX20?ooo`<02NX:
00@0oooo00WZ2P09jPX0oooo1P09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX00`3o
ool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX20?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00<02NX:0?ooo`3oool0103o
ool01009jPX0oooo0?ooo`09jPX=0?ooo`0300WZ2P3oool0oooo01@0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool0?`3oool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0
oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00<02NX:00T0oooo00WZ2P3oool02NX:0?ooo`09jPX0
oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`<0
2NX:00<0oooo00WZ2P3oool00`09jPX0103oool02NX:0?ooo`3oool900WZ2P050?ooo`09jPX02NX:
00WZ2P3oool02@09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00H02NX:00<0oooo
00WZ2P09jPX01P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00D02NX:00@0oooo
00WZ2P09jPX0oooo1009jPX0103oool02NX:00WZ2P09jPX20?ooo`<02NX:00@0oooo00WZ2P09jPX0
oooo1P09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`02
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX20?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0
0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo00<02NX:0?ooo`3oool0103oool01009jPX0oooo
0?ooo`09jPX=0?ooo`0300WZ2P3oool0oooo01@0oooo00<000000?ooo`3oool01@3oool000L0oooo
00<000000?ooo`3oool0?`3oool200WZ2P80oooo0`09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P80
oooo0`09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0`09jPX0103oool02NX:0?ooo`09
jPX20?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX0103oool02NX:
0?ooo`3oool900WZ2P050?ooo`09jPX02NX:00WZ2P3oool02@09jPX00`3oool02NX:00WZ2P0400WZ
2P030?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:0?ooo`0200WZ
2P030?ooo`09jPX02NX:00D02NX:00@0oooo00WZ2P09jPX0oooo1009jPX0103oool02NX:00WZ2P09
jPX20?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX02NX:00@02NX:00L0oooo00WZ2P3oool02NX:
0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX01@3oool02NX:0?ooo`09jPX0oooo
00802NX:0P3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo00<02NX:0?ooo`3oool00P09jPX2
0?ooo`0300WZ2P3oool0oooo00@0oooo00@02NX:0?ooo`3oool02NX:3@3oool00`09jPX0oooo0?oo
o`0D0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03l0oooo0P09jPX2
0?ooo`<02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P0:0?ooo`09jPX02NX:00WZ2P3oool02NX:
0?ooo`09jPX0oooo00WZ2P80oooo0`09jPX0103oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool0
2NX:0?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX0103oool02NX:0?ooo`3oool900WZ2P040?oo
o`09jPX02NX:0?ooo`D02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo``02NX:00<0oooo00WZ2P09
jPX01P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00D02NX:00@0oooo00WZ2P09
jPX0oooo1@09jPX00`3oool02NX:00WZ2P020?ooo`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`06
00WZ2P050?ooo`09jPX0oooo00WZ2P3oool01009jPX0103oool02NX:00WZ2P09jPX20?ooo`0300WZ
2P3oool02NX:0080oooo00@02NX:0?ooo`3oool02NX:0`3oool01009jPX0oooo0?ooo`09jPX20?oo
o`802NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`0400WZ2P3oool0oooo00WZ2P`0oooo00<02NX:
0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0o0?oo
o`802NX:0P3oool300WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX02@3oool02NX:00WZ2P09jPX0
oooo00WZ2P3oool02NX:0?ooo`0200WZ2P080?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX2
0?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX0103oool02NX:0?oo
o`3oool300WZ2P030?ooo`09jPX02NX:00<02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo0080
2NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0:00WZ2P030?ooo`09jPX02NX:
00H02NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P040?ooo`09jPX02NX:
0?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P020?ooo`802NX:00D0oooo
00WZ2P3oool02NX:0?ooo`0600WZ2P050?ooo`09jPX0oooo00WZ2P3oool01009jPX0103oool02NX:
00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00@02NX:0?ooo`3oool02NX:0`3oool01009
jPX0oooo0?ooo`09jPX20?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`0400WZ2P3oool0
oooo00WZ2P`0oooo00<02NX:0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0o0?ooo`802NX:0P3oool300WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX0
103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00802NX:00P0oooo00WZ2P09jPX02NX:
0?ooo`09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0`09jPX00`3oool02NX:0?ooo`03
00WZ2P040?ooo`09jPX0oooo0?ooo`T02NX:0P3oool00`09jPX0oooo00WZ2P0400WZ2P040?ooo`09
jPX02NX:0?ooo`802NX:00<0oooo00WZ2P3oool02P09jPX00`3oool02NX:00WZ2P0800WZ2P040?oo
o`09jPX02NX:0?ooo`@02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`D02NX:00<0oooo00WZ
2P09jPX00P3oool200WZ2P030?ooo`09jPX0oooo00P02NX:00D0oooo00WZ2P3oool02NX:0?ooo`08
00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`09jPX30?ooo`0600WZ2P3o
ool0oooo0?ooo`09jPX0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00@0oooo00@02NX:0?ooo`3o
ool02NX:303oool00`09jPX0oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo0400oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00<0oooo
00WZ2P09jPX00P3oool01`09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool00P09jPX01`3oool02NX:
00WZ2P09jPX0oooo00WZ2P3oool00P09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:0P3oool4
00WZ2P040?ooo`09jPX0oooo0?ooo`T02NX:0P3oool00`09jPX0oooo00WZ2P0400WZ2P040?ooo`09
jPX02NX:0?ooo`802NX:00<0oooo00WZ2P3oool02P09jPX00`3oool02NX:00WZ2P0800WZ2P040?oo
o`09jPX02NX:0?ooo`@02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`0600WZ2P3oool02NX:
0?ooo`09jPX0oooo0P09jPX00`3oool02NX:0?ooo`0300WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:
00<0oooo00WZ2P3oool01`09jPX0103oool02NX:00WZ2P3oool300WZ2P<0oooo00@02NX:0?ooo`3o
ool02NX:0`3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`802NX:0P3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00802NX:2`3oool00`09jPX0oooo0?ooo`0E0?ooo`030000003o
ool0oooo00D0oooo00070?ooo`030000003oool0oooo0400oooo0P09jPX01P3oool02NX:00WZ2P3o
ool02NX:0?ooo`802NX:0P3oool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:0P3oool300WZ2P07
0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09
jPX20?ooo`@02NX:00@0oooo00WZ2P3oool0oooo2@09jPX20?ooo`0300WZ2P3oool02NX:00@02NX:
00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:0?ooo`0:00WZ2P030?ooo`09jPX02NX:00<0
2NX:00<0oooo00WZ2P09jPX00P09jPX0103oool02NX:00WZ2P3oool400WZ2P050?ooo`09jPX02NX:
0?ooo`09jPX00P3oool01`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX00P3oool500WZ2P040?oo
o`09jPX02NX:0?ooo`D02NX:00<0oooo00WZ2P3oool01`09jPX0103oool02NX:00WZ2P3oool300WZ
2P<0oooo00@02NX:0?ooo`3oool02NX:0`3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`802NX:
0P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00802NX:2`3oool00`09jPX0oooo
0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0400oooo0P09
jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:0P3oool01@09jPX0oooo0?ooo`09jPX0oooo
00802NX:0P3oool300WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo0P09
jPX0103oool02NX:00WZ2P09jPX20?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool:00WZ2P03
0?ooo`09jPX0oooo00D02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:0?ooo`0@00WZ2P03
0?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P09jPX0oooo1009jPX01@3oool02NX:00WZ2P3oool0
2NX:0080oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00<02NX:
00@0oooo00WZ2P09jPX0oooo1@09jPX00`3oool02NX:0?ooo`0700WZ2P040?ooo`09jPX02NX:0?oo
o`<02NX:0`3oool01009jPX0oooo0?ooo`09jPX30?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo
0P09jPX20?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00P09jPX;0?ooo`0300WZ
2P3oool0oooo01D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0@03o
ool200WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`0900WZ2P3oool0oooo00WZ2P3o
ool02NX:0?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P3oool02NX:0P3oool300WZ2P80oooo0P09
jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P3oool02NX:0P3oool:00WZ
2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX00`09jPX01`3oool02NX:00WZ2P09jPX0
oooo00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00802NX:00H0
oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool01P09
jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:00WZ
2P3oool600WZ2P030?ooo`09jPX0oooo00H02NX:00L0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:
00<0oooo00@02NX:0?ooo`3oool02NX:0`3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`802NX:
0P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00802NX:2`3oool00`09jPX0oooo
0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0400oooo0P09
jPX20?ooo`<02NX:0P3oool01009jPX0oooo0?ooo`09jPX20?ooo`<02NX:00X0oooo00WZ2P3oool0
2NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool300WZ2P80oooo00<02NX:0?ooo`09jPX00P09
jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool0oooo0`09jPX00`3oool0
2NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00l02NX:00<0oooo00WZ2P3oool01009jPX00`3oool0
2NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool5
00WZ2P040?ooo`09jPX0oooo00WZ2P80oooo0`09jPX0103oool02NX:00WZ2P3oool600WZ2P030?oo
o`09jPX0oooo00H02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0300WZ2P040?oo
o`09jPX0oooo00WZ2P<0oooo00@02NX:0?ooo`3oool02NX:0`3oool01P09jPX0oooo0?ooo`3oool0
2NX:0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00802NX:2`3o
ool00`09jPX0oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo0400oooo0P09jPX20?ooo`<02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P0=0?ooo`09jPX0
2NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX0
2NX:00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00802NX:
00@0oooo00WZ2P3oool0oooo0`09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:0080
2NX:00<0oooo00WZ2P09jPX03009jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00T0
2NX:0P3oool200WZ2P030?ooo`09jPX0oooo00L02NX:00@0oooo00WZ2P3oool0oooo0`09jPX0103o
ool02NX:00WZ2P3oool600WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:00<0oooo00WZ2P3oool00`09
jPX00`3oool02NX:00WZ2P0300WZ2P040?ooo`09jPX0oooo00WZ2P<0oooo00@02NX:0?ooo`3oool0
2NX:0`3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00802NX:2`3oool00`09jPX0oooo0?ooo`0E0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo0440oooo00<02NX:0?ooo`3oool00`09jPX20?oo
o`0300WZ2P3oool0oooo00802NX:00X0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool0
2NX:0P3oool300WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`02
00WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool0oooo0`09jPX00`3oool02NX:00WZ
2P0400WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX03009jPX00`3oool02NX:0?oo
o`0200WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`802NX:00<0
oooo00WZ2P3oool01009jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo1P09jPX0103oool02NX:
00WZ2P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:00<0oooo00WZ2P3oool00`09jPX00`3o
ool02NX:00WZ2P0300WZ2P040?ooo`09jPX0oooo00WZ2P<0oooo00@02NX:0?ooo`3oool02NX:0`3o
ool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00802NX:2`3oool00`09jPX0oooo0?ooo`0E0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo0440oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?oo
o`802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo
0`09jPX0103oool02NX:0?ooo`09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX00`3o
ool02NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00<0oooo00WZ2P09jPX00`09jPX0
0`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00h02NX:00@0oooo00WZ2P09jPX0oooo1@09
jPX00`3oool02NX:00WZ2P0400WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1`09jPX0103oool0
2NX:0?ooo`3oool600WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ2P030?oo
o`09jPX02NX:00<02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0600WZ2P@0oooo
00@02NX:0?ooo`3oool02NX:0`3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`802NX:0P3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00802NX:2`3oool00`09jPX0oooo0?ooo`0E
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0440oooo0P09jPX01P3o
ool02NX:00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool01`09jPX0oooo00WZ
2P09jPX0oooo00WZ2P3oool00P09jPX0203oool02NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0P3o
ool01009jPX0oooo00WZ2P3oool300WZ2P030?ooo`09jPX0oooo00@02NX:0P3oool300WZ2P030?oo
o`09jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0oooo4009jPX0103oool02NX:00WZ2P3oool500WZ
2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0500WZ
2P040?ooo`09jPX0oooo0?ooo`H02NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`80
2NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:
00H02NX:103oool01009jPX0oooo0?ooo`09jPX30?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo
0P09jPX20?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00P09jPX;0?ooo`0300WZ
2P3oool0oooo01D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0@@3o
ool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`0500WZ2P3oool0oooo00WZ
2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P080?ooo`09jPX02NX:00WZ2P3oool02NX:0?oo
o`09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`<02NX:00<0oooo00WZ2P3oool01009jPX20?ooo`<0
2NX:00<0oooo00WZ2P09jPX02@09jPX00`3oool02NX:00WZ2P0500WZ2P040?ooo`09jPX02NX:0?oo
o`h02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:
00D02NX:00@0oooo00WZ2P3oool0oooo1P09jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0
oooo0P09jPX00`3oool02NX:00WZ2P0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ
2P09jPX01P09jPX40?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00@02NX:0?ooo`3oool0oooo0P09
jPX01@3oool02NX:0?ooo`3oool02NX:00H0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX:0?oo
o`0300WZ2P3oool0oooo01D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool0@@3oool200WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0P09jPX20?ooo`0500WZ2P3oool0oooo
00WZ2P3oool00P09jPX20?ooo`<02NX:00P0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P80
oooo00@02NX:0?ooo`09jPX0oooo0`09jPX00`3oool02NX:0?ooo`0400WZ2P80oooo00@02NX:0?oo
o`09jPX0oooo2`09jPX00`3oool02NX:00WZ2P0500WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo
3009jPX00`3oool02NX:00WZ2P0600WZ2P040?ooo`09jPX02NX:0?ooo`L02NX:00@0oooo00WZ2P3o
ool0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00P09jPX0
0`3oool02NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01009
jPX00`3oool02NX:0?ooo`030?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo0P09jPX20?ooo`802NX:
00D0oooo00WZ2P3oool0oooo00WZ2P060?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:2P3oool0
0`09jPX0oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
0440oooo0P09jPX20?ooo`<02NX:0P3oool01009jPX0oooo0?ooo`09jPX20?ooo`0400WZ2P3oool0
2NX:00WZ2P80oooo0`09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX01@3oool0
2NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool00`09jPX01`3oool02NX:0?ooo`09jPX0
oooo00WZ2P3oool02`09jPX00`3oool02NX:00WZ2P0500WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0
oooo3009jPX00`3oool02NX:00WZ2P0600WZ2P040?ooo`09jPX02NX:0?ooo`L02NX:00@0oooo00WZ
2P3oool0oooo0P09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo
00WZ2P09jPX0oooo1@09jPX00`3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool0
0P09jPX00`3oool02NX:0?ooo`030?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo0P09jPX20?ooo`80
2NX:00D0oooo00WZ2P3oool0oooo00WZ2P060?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:2P3o
ool00`09jPX0oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo0440oooo0P09jPX20?ooo`<02NX:0P3oool01009jPX0oooo0?ooo`09jPX20?ooo`<02NX:00<0
oooo00WZ2P3oool00`09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX01@3oool0
2NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool00`09jPX01`3oool02NX:0?ooo`09jPX0
oooo00WZ2P3oool02`09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX0oooo00802NX:00<0
oooo00WZ2P3oool03009jPX00`3oool02NX:00WZ2P0600WZ2P040?ooo`09jPX02NX:0?ooo`L02NX:
00@0oooo00WZ2P3oool0oooo0P09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:0080
2NX:00@0oooo00WZ2P09jPX0oooo1@09jPX0103oool02NX:00WZ2P09jPX20?ooo`<02NX:00D0oooo
00WZ2P09jPX0oooo00WZ2P040?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo0P09jPX20?ooo`802NX:
00D0oooo00WZ2P3oool0oooo00WZ2P060?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:2P3oool0
0`09jPX0oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
0480oooo0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00L0oooo
00WZ2P09jPX02NX:0?ooo`09jPX0oooo00<02NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo
00<02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:0?ooo`0300WZ2P070?ooo`09jPX0
oooo00WZ2P3oool02NX:0?ooo`0;00WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX0
0P09jPX00`3oool02NX:0?ooo`0<00WZ2P030?ooo`09jPX02NX:00H02NX:00H0oooo00WZ2P09jPX0
oooo00WZ2P3oool500WZ2P050?ooo`09jPX0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P02
00WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0300WZ2P030?oo
o`09jPX02NX:00802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2PD0oooo00@02NX:0?ooo`3o
ool02NX:0`3oool200WZ2P80oooo0P09jPX01@3oool02NX:0?ooo`3oool02NX:00H0oooo00H02NX:
0?ooo`3oool02NX:0?ooo`09jPX:0?ooo`0300WZ2P3oool0oooo01D0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool0@P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo
00<02NX:0?ooo`3oool00P09jPX03P3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09
jPX0oooo00WZ2P3oool02NX:0P3oool400WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00<0oooo00WZ
2P3oool00`09jPX0103oool02NX:0?ooo`3oool200WZ2P030?ooo`09jPX02NX:00T02NX:00<0oooo
00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00`02NX:00D0oooo
00WZ2P09jPX02NX:0?ooo`0400WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1009jPX20?ooo`04
00WZ2P3oool02NX:0?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX01P3oool02NX:00WZ2P3oool0
2NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09
jPX02NX:00WZ2P3oool00`09jPX50?ooo`802NX:00<0oooo00WZ2P3oool00P3oool200WZ2P80oooo
0P09jPX01@3oool02NX:0?ooo`3oool02NX:00H0oooo00H02NX:0?ooo`3oool02NX:0?ooo`09jPX:
0?ooo`0300WZ2P3oool0oooo01D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool0@P3oool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX0103oool02NX:00WZ
2P3oool300WZ2P090?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00802NX:00<0oooo
00WZ2P09jPX00P09jPX0103oool02NX:00WZ2P3oool300WZ2P80oooo1009jPX0103oool02NX:0?oo
o`3oool200WZ2P030?ooo`09jPX02NX:00T02NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:
00WZ2P3oool500WZ2P030?ooo`09jPX0oooo00P02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ
2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09
jPX0oooo0`09jPX20?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo1009jPX00`3oool02NX:00WZ2P04
00WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX50?ooo`802NX:00<0
oooo00WZ2P3oool00P3oool200WZ2P80oooo0P09jPX01@3oool02NX:0?ooo`3oool02NX:00H0oooo
00H02NX:0?ooo`3oool02NX:0?ooo`09jPX:0?ooo`0300WZ2P3oool0oooo01D0oooo00<000000?oo
o`3oool01@3oool000L0oooo00<000000?ooo`3oool0@P3oool200WZ2P060?ooo`09jPX02NX:0?oo
o`09jPX0oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`0800WZ2P3oool02NX:00WZ2P3oool02NX:
0?ooo`09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX0103oool02NX:00WZ2P3oool300WZ
2P80oooo1009jPX0103oool02NX:0?ooo`3oool200WZ2P030?ooo`09jPX02NX:00T02NX:00<0oooo
00WZ2P09jPX00`09jPX0103oool02NX:00WZ2P3oool700WZ2P030?ooo`09jPX02NX:00H02NX:00D0
oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P070?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P020?oo
o`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P80oooo0`09jPX0103oool02NX:00WZ2P3o
ool400WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX00P09jPX0103oool02NX:00WZ
2P3oool300WZ2PD0oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`802NX:0P3oool200WZ2P050?oo
o`09jPX0oooo0?ooo`09jPX01P3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2PX0oooo00<02NX:
0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`120?oo
o`802NX:0P3oool01009jPX0oooo00WZ2P3oool200WZ2P80oooo00D02NX:0?ooo`3oool02NX:0?oo
o`0200WZ2P030?ooo`09jPX0oooo00802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo0080
2NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0400WZ2P040?ooo`09jPX0oooo0?oo
o`802NX:00<0oooo00WZ2P09jPX02@09jPX00`3oool02NX:00WZ2P0300WZ2P040?ooo`09jPX02NX:
0?ooo`L02NX:00<0oooo00WZ2P09jPX01`09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:
00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00<02NX:
0?ooo`09jPX00P09jPX20?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo
00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0200WZ2P070?ooo`09jPX02NX:0?ooo`09jPX0oooo
00WZ2P050?ooo`802NX:00<0oooo00WZ2P3oool00P3oool200WZ2P80oooo0P09jPX01@3oool02NX:
0?ooo`3oool02NX:00H0oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`070?oo
o`0300WZ2P3oool0oooo01D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool0@P3oool200WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P020?ooo`0500WZ2P3oool0oooo00WZ
2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?oo
o`0200WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0103oool02NX:
0?ooo`09jPX20?oooa@02NX:00<0oooo00WZ2P09jPX04P09jPX01P3oool02NX:00WZ2P3oool02NX:
0?ooo`802NX:00@0oooo00WZ2P09jPX02NX:0P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo
00<02NX:0?ooo`09jPX00P09jPX20?ooo`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0400WZ2P03
0?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX01009jPX20?ooo`0300WZ2P3oool02NX:00D0
oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`802NX:0P3oool200WZ2P050?ooo`09jPX0oooo0?oo
o`09jPX01P3oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:
0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`120?oo
o`802NX:0P3oool300WZ2P80oooo00@02NX:0?ooo`3oool02NX:0P3oool01009jPX0oooo00WZ2P09
jPX20?ooo`<02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3o
ool00P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P3oool0oooo5009
jPX00`3oool02NX:00WZ2P0B00WZ2P80oooo0`09jPX0103oool02NX:00WZ2P3oool300WZ2P80oooo
0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:00802NX:0P3oool200WZ2P03
0?ooo`09jPX0oooo00802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0600WZ2P030?ooo`09jPX02NX:
00@02NX:0P3oool300WZ2PD0oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`802NX:0P3oool200WZ
2P050?ooo`09jPX0oooo0?ooo`09jPX01P3oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3o
ool0oooo00H0oooo00<02NX:0?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`130?ooo`802NX:00@0oooo00WZ2P09jPX02NX:0P3oool01009jPX0oooo0?oo
o`09jPX20?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ
2P3oool00P09jPX00`3oool02NX:0?ooo`0200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09
jPX0103oool02NX:0?ooo`3ooolK00WZ2P030?ooo`09jPX02NX:00T02NX:00<0oooo00WZ2P3oool0
1009jPX0103oool02NX:00WZ2P3oool300WZ2P80oooo1P09jPX20?ooo`0300WZ2P3oool02NX:0080
2NX:0P3oool200WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool0
2NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00802NX:0P3oool200WZ2PH0oooo0P09jPX00`3oool0
2NX:0?ooo`020?ooo`802NX:0P3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX01P3oool01009
jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool05P3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`130?ooo`802NX:00@0oooo00WZ
2P09jPX02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:
0?ooo`0300WZ2P080?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`0400WZ2P3oool0
2NX:0?ooo`<02NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`3oool300WZ2P030?oo
o`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P0200WZ2P030?oo
o`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX02`09jPX00`3oool02NX:00WZ2P0500WZ2P050?oo
o`09jPX02NX:00WZ2P3oool01`09jPX20?ooo`0300WZ2P3oool02NX:00802NX:0P3oool200WZ2P03
0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:0?ooo`0300WZ2P03
0?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P09jPX02NX:1P3oool200WZ2P030?ooo`09jPX0oooo
0080oooo0P09jPX20?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P050?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01H0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0@`3oool200WZ2P070?ooo`09jPX0
2NX:0?ooo`09jPX0oooo00WZ2P020?ooo`802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo
00<02NX:00P0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09jPX0
oooo0`09jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00<0oooo00WZ
2P09jPX02`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ
2P09jPX02`09jPX00`3oool02NX:00WZ2P0500WZ2P050?ooo`09jPX02NX:00WZ2P3oool01`09jPX2
0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09
jPX02NX:00@02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09
jPX02NX:00WZ2PH0oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`802NX:0P3oool200WZ2P050?oo
o`09jPX0oooo0?ooo`09jPX01@3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo00<02NX:0?oo
o`3oool01P3oool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo04<0oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00@0oooo
00WZ2P09jPX0oooo0`09jPX03@3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0
oooo00WZ2P3oool00P09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool0
0P09jPX0103oool02NX:0?ooo`3oool300WZ2P040?ooo`09jPX02NX:0?ooo`L02NX:00@0oooo00WZ
2P09jPX0oooo1009jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00L02NX:00D0oooo
00WZ2P09jPX02NX:0?ooo`0700WZ2P050?ooo`09jPX0oooo00WZ2P3oool01`09jPX20?ooo`802NX:
00@0oooo00WZ2P09jPX0oooo0`09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`T02NX:00H0oooo
00WZ2P09jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX02NX:00WZ2PH0oooo0P09jPX00`3oool0
2NX:0?ooo`020?ooo`802NX:0P3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX01@3oool01009
jPX0oooo0?ooo`09jPX30?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool05P3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`130?ooo`802NX:0P3oool01009
jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00X0oooo00WZ2P3oool02NX:
0?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool300WZ2P050?ooo`09jPX0oooo00WZ2P3oool00`09
jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo0?ooo`H02NX:00<0oooo00WZ2P09jPX0
1@09jPX0103oool02NX:00WZ2P3oool400WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09
jPX01009jPX0103oool02NX:00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00D02NX:00D0oooo00WZ
2P3oool02NX:0?ooo`0700WZ2P80oooo0P09jPX0103oool02NX:00WZ2P3oool300WZ2P040?ooo`09
jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01P09jPX01P3oool02NX:00WZ2P3oool02NX:0?oo
o`@02NX:00<0oooo00WZ2P3oool01@3oool200WZ2P030?ooo`09jPX0oooo0080oooo0P09jPX20?oo
o`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P050?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00<0
2NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo04<0oooo0P09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX00P3oool0
1@09jPX0oooo0?ooo`09jPX0oooo00802NX:00P0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ
2P80oooo0`09jPX20?ooo`802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00@02NX:0P3o
ool600WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P03
0?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01009jPX0103oool02NX:00WZ2P3oool300WZ
2P030?ooo`09jPX02NX:00D02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0700WZ2P80oooo0P09jPX0
103oool02NX:00WZ2P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0400WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1009jPX00`3oool02NX:0?ooo`05
0?ooo`802NX:00<0oooo00WZ2P3oool00P3oool200WZ2P80oooo0P09jPX01@3oool02NX:0?ooo`3o
ool02NX:00D0oooo00@02NX:0?ooo`3oool02NX:103oool00`09jPX0oooo0?ooo`050?ooo`0300WZ
2P3oool0oooo01H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0A03o
ool00`09jPX0oooo0?ooo`0300WZ2P030?ooo`09jPX02NX:0080oooo00D02NX:0?ooo`3oool02NX:
0?ooo`0200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo0`09jPX0103oool02NX:00WZ2P09jPX20?oo
o`802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00@02NX:0P3oool600WZ2P040?ooo`09
jPX02NX:0?ooo`L02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`0300WZ2P3oool02NX:00L02NX:
00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:00WZ2P0500WZ2P050?ooo`09jPX0oooo00WZ
2P3oool01`09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00D0oooo00WZ2P09jPX02NX:0?oo
o`0200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX0103oool02NX:
00WZ2P3oool600WZ2P030?ooo`09jPX0oooo00D0oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`80
2NX:0P3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX01@3oool01009jPX0oooo0?ooo`09jPX4
0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool05P3oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`140?ooo`802NX:00@0oooo00WZ2P09jPX02NX:0P3oool0
1009jPX0oooo0?ooo`09jPX20?ooo`0700WZ2P3oool02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool00`09jPX20?ooo`802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09
jPX0oooo00@02NX:0P3oool600WZ2P040?ooo`09jPX02NX:0?ooo`L02NX:00<0oooo00WZ2P09jPX0
0P09jPX20?ooo`0300WZ2P3oool02NX:00<02NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:
00WZ2P09jPX0oooo00@02NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`L02NX:00D0
oooo00WZ2P3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0103oool0
2NX:00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P3oool0oooo2009jPX6
0?ooo`802NX:00<0oooo00WZ2P3oool00P3oool200WZ2P80oooo0P09jPX01@3oool02NX:0?ooo`3o
ool02NX:00D0oooo00@02NX:0?ooo`3oool02NX:103oool00`09jPX0oooo0?ooo`050?ooo`0300WZ
2P3oool0oooo01H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0A03o
ool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00@02NX:0?ooo`3oool02NX:0P3oool01009jPX0
oooo00WZ2P09jPX20?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P80oooo0P09jPX0
1`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool01009jPX20?ooo`H02NX:00@0oooo00WZ2P09jPX0
oooo1`09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo00<02NX:0?ooo`09jPX00`09jPX00`3oool0
2NX:00WZ2P0400WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX0203oool02NX:00WZ2P3oool0
2NX:0?ooo`09jPX0oooo1009jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0P09jPX0
0`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX02009jPX2
0?ooo`P02NX:1P3oool200WZ2P030?ooo`09jPX0oooo0080oooo0P09jPX20?ooo`802NX:00D0oooo
00WZ2P3oool0oooo00WZ2P050?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo00<02NX:0?ooo`3oool0
1@3oool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo04@0oooo0P09jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P07
0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09
jPX20?ooo`0300WZ2P3oool02NX:00<02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:0?oo
o`0600WZ2P040?ooo`09jPX02NX:0?ooo`L02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`H0
2NX:00<0oooo00WZ2P09jPX02009jPX00`3oool02NX:00WZ2P0200WZ2P080?ooo`09jPX02NX:0?oo
o`09jPX0oooo00WZ2P3oool400WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ
2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX0103oool02NX:00WZ2P3oool7
00WZ2P80oooo2009jPX60?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P80oooo0P09jPX0
1@3oool02NX:0?ooo`3oool02NX:00D0oooo00@02NX:0?ooo`3oool02NX:103oool00`09jPX0oooo
0?ooo`050?ooo`0300WZ2P3oool0oooo01H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
00000?ooo`3oool0A03oool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX0103oool0
2NX:00WZ2P3oool300WZ2P030?ooo`09jPX0oooo00<02NX:00P0oooo00WZ2P09jPX02NX:0?ooo`09
jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00`09jPX20?ooo`@02NX:00D0oooo00WZ2P3oool0
2NX:0?ooo`0400WZ2P040?ooo`09jPX02NX:0?ooo`L02NX:00<0oooo00WZ2P09jPX00`09jPX00`3o
ool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P09jPX00P09jPX00`3o
ool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX00`3o
ool02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0
0`3oool02NX:0?ooo`0700WZ2P030?ooo`09jPX02NX:00L02NX:1`3oool01009jPX0oooo0?ooo`09
jPX20?ooo`802NX:0P3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX01@3oool01009jPX0oooo
0?ooo`09jPX40?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool05P3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`140?ooo`802NX:0P3oool01009jPX0oooo
00WZ2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX0203o
ool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P030?oo
o`09jPX0oooo00@02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:0080
oooo0P09jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX02NX:00l02NX:00<0oooo00WZ2P09
jPX00P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3o
ool00P09jPX00`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P09
jPX0oooo0P09jPX00`3oool02NX:0?ooo`0700WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ
2P09jPX01`3oool01009jPX0oooo0?ooo`09jPX20?ooo`802NX:0P3oool200WZ2P050?ooo`09jPX0
oooo0?ooo`09jPX01@3oool01009jPX0oooo0?ooo`09jPX40?ooo`0300WZ2P3oool0oooo00D0oooo
00<02NX:0?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`140?ooo`802NX:0P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:0180oooo00WZ2P09jPX0
2NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX2
0?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09
jPX0oooo00WZ2P3oool01009jPX00`3oool02NX:00WZ2P020?ooo``02NX:00<0oooo00WZ2P09jPX0
1@09jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool0
0P09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool0
2NX:00WZ2P0700WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01`09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P09jPX01`3oool01009jPX0oooo0?ooo`09
jPX20?ooo`802NX:0P3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX01@3oool01009jPX0oooo
0?ooo`09jPX40?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool05P3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`150?ooo`0300WZ2P3oool0oooo00<02NX:
00<0oooo00WZ2P09jPX00P3oool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:00`0oooo00WZ2P3o
ool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`0500WZ2P3oool02NX:00WZ
2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00@0oooo
00WZ2P09jPX0oooo0`09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00@02NX:00<0
oooo00WZ2P09jPX01@09jPX0103oool02NX:00WZ2P3oool=00WZ2P040?ooo`09jPX02NX:0?ooo`<0
2NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P09
jPX00P09jPX00`3oool02NX:00WZ2P0700WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3o
ool02NX:0?ooo`060?ooo`0400WZ2P3oool0oooo00WZ2P80oooo0P09jPX20?ooo`802NX:00D0oooo
00WZ2P3oool0oooo00WZ2P050?ooo`0400WZ2P3oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo04D0oooo0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P80
oooo00l02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ
2P3oool00P09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:00L0oooo00WZ2P09jPX0oooo00WZ
2P3oool02NX:0080oooo0P09jPX0103oool02NX:00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00<0
2NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0700WZ2P030?ooo`09jPX02NX:0140
2NX:00@0oooo00WZ2P09jPX02NX:0P3oool00`09jPX0oooo00WZ2P0400WZ2P030?ooo`09jPX02NX:
00L02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0700WZ2P050?ooo`09jPX02NX:
00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`060?ooo`0400WZ2P3oool0oooo00WZ2P80oooo0P09
jPX20?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P050?ooo`0400WZ2P3oool0oooo00WZ2PD0
oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo04D0oooo0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`04
00WZ2P3oool0oooo00WZ2P80oooo00d02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool0
2NX:0?ooo`09jPX0oooo00@02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0
oooo00802NX:00@0oooo00WZ2P3oool0oooo0P09jPX0103oool02NX:00WZ2P3oool300WZ2P030?oo
o`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0500WZ2P030?oo
o`09jPX02NX:00T02NX:00<0oooo00WZ2P09jPX01@09jPX01@3oool02NX:00WZ2P09jPX0oooo00P0
2NX:00<0oooo00WZ2P09jPX01009jPX0103oool02NX:00WZ2P3oool400WZ2P030?ooo`09jPX02NX:
00H02NX:0P3oool300WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:1`3oool01009jPX0oooo0?oo
o`09jPX20?ooo`802NX:0P3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX01@3oool01009jPX0
oooo0?ooo`09jPX50?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool05P3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`150?ooo`802NX:00L0oooo00WZ2P09
jPX0oooo00WZ2P3oool02NX:0080oooo00D02NX:0?ooo`3oool02NX:0?ooo`0200WZ2P030?ooo`09
jPX0oooo00802NX:00<0oooo00WZ2P09jPX01@09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:
00<0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`3oool200WZ2P040?ooo`09jPX02NX:0?oo
o`<02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:
00<02NX:00<0oooo00WZ2P09jPX01@09jPX01@3oool02NX:00WZ2P09jPX0oooo00P02NX:00@0oooo
00WZ2P09jPX0oooo2009jPX00`3oool02NX:0?ooo`0400WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:
00@0oooo00WZ2P09jPX0oooo1@09jPX20?ooo`<02NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX7
0?ooo`0400WZ2P3oool0oooo00WZ2P80oooo0P09jPX20?ooo`802NX:00D0oooo00WZ2P3oool0oooo
00WZ2P050?ooo`0400WZ2P3oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04D0oooo
0P09jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P030?ooo`09jPX02NX:
00802NX:0P3oool300WZ2P030?ooo`09jPX02NX:00D02NX:0P3oool200WZ2P070?ooo`09jPX02NX:
00WZ2P3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00@0oooo00WZ2P09jPX0
oooo0`09jPX00`3oool02NX:00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX00`3o
ool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00H02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`08
00WZ2P040?ooo`09jPX02NX:0?ooo`P02NX:00<0oooo00WZ2P3oool01009jPX0103oool02NX:00WZ
2P3oool500WZ2P030?ooo`09jPX0oooo00D02NX:00<0oooo00WZ2P3oool00P09jPX01P3oool02NX:
00WZ2P09jPX0oooo00WZ2PL0oooo00@02NX:0?ooo`3oool02NX:0P3oool200WZ2P80oooo0P09jPX0
1@3oool02NX:0?ooo`3oool02NX:00D0oooo00@02NX:0?ooo`3oool02NX:1@3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo01H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
00000?ooo`3oool0A@3oool200WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0P09jPX0103oool02NX:
00WZ2P3oool300WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX01@09jPX20?ooo`80
2NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool0oooo0P09
jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00@02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01P09jPX01@3oool0
2NX:00WZ2P09jPX0oooo00P02NX:00@0oooo00WZ2P09jPX0oooo2009jPX00`3oool02NX:0?ooo`03
00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`05
00WZ2P030?ooo`09jPX0oooo00802NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX70?ooo`0400WZ
2P3oool0oooo00WZ2P80oooo0P09jPX20?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P050?oo
o`0400WZ2P3oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0F
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04D0oooo0P09jPX20?oo
o`<02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool0
0`09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:0P3oool200WZ2P070?ooo`09jPX02NX:00WZ
2P3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo0?ooo`D02NX:00@0oooo00WZ2P09jPX0oooo
0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool0
2NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00H02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0
oooo00H02NX:00@0oooo00WZ2P09jPX0oooo1P09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:
00<0oooo00WZ2P09jPX00P09jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo1@09jPX0
0`3oool02NX:0?ooo`0200WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:1`3oool200WZ2P040?oo
o`09jPX0oooo0?ooo`802NX:0P3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX01@3oool01009
jPX0oooo0?ooo`09jPX50?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool05P3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`160?ooo`0300WZ2P3oool0oooo
00<02NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX0oooo
00<02NX:00P0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX01`3oool02NX:
00WZ2P09jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`3oool500WZ2P040?ooo`09jPX0
2NX:0?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00802NX:
00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0600WZ2P070?ooo`09jPX02NX:00WZ2P3o
ool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P04
00WZ2P050?ooo`09jPX0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09
jPX02NX:00802NX:00<0oooo00WZ2P3oool01@09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09
jPX02NX:0080oooo00<02NX:0?ooo`3oool01@3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:
0P3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX01@3oool01009jPX0oooo0?ooo`09jPX50?oo
o`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`160?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ
2P80oooo00<02NX:0?ooo`3oool00P09jPX00`3oool02NX:0?ooo`0300WZ2P080?ooo`09jPX0oooo
00WZ2P3oool02NX:0?ooo`09jPX20?ooo`802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo
00@02NX:0P3oool400WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P05
00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`06
00WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3o
ool00P09jPX00`3oool02NX:00WZ2P0200WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`03
00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`05
00WZ2P030?ooo`09jPX02NX:00D02NX:0P3oool00`09jPX0oooo0?ooo`050?ooo`802NX:00@0oooo
00WZ2P3oool0oooo0P09jPX20?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P050?ooo`0400WZ
2P3oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0G0?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04H0oooo0P09jPX0103oool02NX:
00WZ2P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P80oooo01002NX:0?ooo`09jPX02NX:0?ooo`09
jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo00WZ
2P0300WZ2P030?ooo`09jPX0oooo00@02NX:0P3oool400WZ2P050?ooo`09jPX02NX:00WZ2P3oool0
0P09jPX00`3oool02NX:00WZ2P0500WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P030?oo
o`09jPX0oooo00P02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ
2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00<02NX:0P3oool200WZ
2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0500WZ
2P030?ooo`09jPX02NX:00D02NX:0P3oool00`09jPX0oooo0?ooo`050?ooo`802NX:00@0oooo00WZ
2P3oool0oooo0P09jPX20?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P050?ooo`0400WZ2P3o
ool0oooo00WZ2PH0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04H0oooo0P09jPX01`3oool02NX:00WZ
2P3oool02NX:0?ooo`09jPX00P3oool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:00`0oooo00WZ
2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool02NX:
00<02NX:00<0oooo00WZ2P3oool01009jPX20?ooo`@02NX:00@0oooo00WZ2P09jPX02NX:0P3oool0
0`09jPX0oooo00WZ2P0400WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00<0oooo00WZ2P09jPX03`09
jPX00`3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:
0?ooo`0200WZ2P030?ooo`09jPX02NX:00<02NX:0P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`80
2NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0700WZ2P030?ooo`09jPX02NX:00D02NX:0P3oool00`09
jPX0oooo0?ooo`050?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX30?ooo`0300WZ2P3oool0
2NX:0080oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09jPX60?ooo`0300WZ2P3o
ool0oooo0080oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`160?ooo`802NX:00L0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0080oooo
00D02NX:0?ooo`3oool02NX:0?ooo`0200WZ2P0<0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09
jPX0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P80oooo1@09jPX20?ooo`@0
2NX:00@0oooo00WZ2P09jPX02NX:0P3oool700WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00<0oooo
00WZ2P09jPX03`09jPX00`3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09
jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00<02NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo1@09jPX00`3o
ool02NX:00WZ2P0200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX01`3oool200WZ2P040?ooo`09jPX0
oooo0?ooo`802NX:0`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00<0oooo00@0
2NX:0?ooo`3oool02NX:1P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01L0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0AP3oool200WZ2P80oooo00@0
2NX:0?ooo`09jPX0oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00/0oooo00WZ
2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00<0
2NX:00<0oooo00WZ2P3oool01@09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`L0
2NX:00@0oooo00WZ2P3oool0oooo0`09jPX00`3oool02NX:00WZ2P0A00WZ2P040?ooo`09jPX02NX:
0?ooo`<02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00<02NX:
00D0oooo00WZ2P09jPX02NX:0?ooo`0500WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3o
ool01@09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX01`3oool200WZ
2P040?ooo`09jPX0oooo0?ooo`802NX:0`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0
oooo00<0oooo00@02NX:0?ooo`3oool02NX:1P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3o
ool0oooo01L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0A`3oool0
0`09jPX0oooo0?ooo`0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00P09
jPX20?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00802NX:
00@0oooo00WZ2P09jPX0oooo1@09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`@0
2NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?oooaL02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX0
0`3oool02NX:00WZ2P0200WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0500WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool500WZ2P030?ooo`09jPX0
2NX:00802NX:00@0oooo00WZ2P3oool0oooo0P09jPX60?ooo`802NX:00@0oooo00WZ2P3oool0oooo
0P09jPX30?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo
0?ooo`09jPX60?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool05`3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`170?ooo`802NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09
jPX02NX:00802NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo1`09
jPX0103oool02NX:0?ooo`3ooolG00WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX0
0P09jPX0103oool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00L0oooo00WZ
2P09jPX02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool02@09jPX00`3oool02NX:00WZ
2P0200WZ2P80oooo0P09jPX60?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX30?ooo`0300WZ
2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09jPX60?ooo`03
00WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`170?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P80
oooo00<02NX:0?ooo`09jPX00P09jPX00`3oool02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ
2P3oool00`09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09jPX0
0`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00802NX:0P3oool700WZ2P040?ooo`09jPX0
oooo0?oooaL02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0200WZ2P040?ooo`09
jPX02NX:0?ooo`802NX:00@0oooo00WZ2P3oool0oooo1009jPX0103oool02NX:00WZ2P3oool200WZ
2P050?ooo`09jPX0oooo00WZ2P3oool02@09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0P09jPX6
0?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX30?ooo`0300WZ2P3oool02NX:0080oooo00<0
2NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09jPX60?ooo`0300WZ2P3oool0oooo0080oooo
00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`170?ooo`802NX:00@0oooo00WZ2P09jPX02NX:0P3oool01009jPX0oooo0?ooo`09jPX20?ooo`80
2NX:00<0oooo00WZ2P3oool00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:0P3oool200WZ
2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0
2NX:00802NX:0P3oool700WZ2P040?ooo`09jPX02NX:0?ooo`X02NX:00<0oooo00WZ2P09jPX02P09
jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo
0P09jPX0103oool02NX:0?ooo`3oool400WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00D0oooo00WZ
2P3oool02NX:0?ooo`0900WZ2P030?ooo`09jPX02NX:00802NX:0P3oool200WZ2PH0oooo0P09jPX0
103oool02NX:0?ooo`3oool200WZ2P<0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?oo
o`030?ooo`0400WZ2P3oool0oooo00WZ2PH0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04L0oooo0P09
jPX0103oool02NX:00WZ2P09jPX20?ooo`0400WZ2P3oool0oooo00WZ2P80oooo0P09jPX00`3oool0
2NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX20?ooo`802NX:00D0oooo00WZ
2P09jPX02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:00<02NX:00@0oooo00WZ2P09jPX0oooo0P09
jPX00`3oool02NX:00WZ2P0800WZ2P030?ooo`09jPX02NX:00P02NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0800WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:
00WZ2P3oool400WZ2P80oooo1009jPX0103oool02NX:00WZ2P3oool200WZ2P050?ooo`09jPX0oooo
00WZ2P3oool02@09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00H0oooo0P09jPX0
103oool02NX:0?ooo`3oool200WZ2P<0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?oo
o`030?ooo`0400WZ2P3oool0oooo00WZ2PL0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0I0?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04L0oooo0P09jPX01`3oool02NX:
00WZ2P3oool02NX:0?ooo`09jPX00P3oool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:00`0oooo
00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`802NX:00L0oooo
00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo
00802NX:00@0oooo00WZ2P09jPX0oooo2P09jPX00`3oool02NX:00WZ2P0800WZ2P030?ooo`09jPX0
2NX:00X02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX0
2NX:0?ooo`@02NX:0P3oool400WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0900WZ2P030?ooo`09jPX0oooo00<02NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`80
2NX:00@0oooo00WZ2P3oool0oooo0P09jPX30?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?oo
o`3oool00`3oool01009jPX0oooo0?ooo`09jPX70?ooo`0500WZ2P3oool0oooo0?ooo`09jPX06@3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`170?ooo`802NX:0P3oool0
1@09jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPX00`3oool02NX:0?ooo`0200WZ2P0<0?ooo`09
jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool200WZ2P070?ooo`09
jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`02
00WZ2P040?ooo`09jPX02NX:0?ooo`X02NX:00<0oooo00WZ2P09jPX05@09jPX00`3oool02NX:00WZ
2P0600WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX02NX:0P3oool400WZ2P07
0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0:00WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo
0`09jPX20?ooo`0300WZ2P3oool0oooo00@0oooo0P09jPX0103oool02NX:0?ooo`3oool200WZ2P<0
oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0oooo00WZ
2PL0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0I0?ooo`030000003oool0oooo00D0oooo00070?oo
o`030000003oool0oooo04P0oooo00<02NX:0?ooo`3oool00`09jPX0103oool02NX:00WZ2P3oool2
00WZ2P030?ooo`09jPX0oooo00802NX:00`0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3o
ool02NX:0?ooo`09jPX20?ooo`802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:
00@0oooo00WZ2P09jPX0oooo0P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:
00802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:0?ooo`0E00WZ2P030?ooo`09jPX02NX:
00H02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX0103oool02NX:00WZ2P09jPX20?ooo`D02NX:00H0
oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00D02NX:00@0oooo00WZ2P09
jPX0oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`0300WZ2P3oool0oooo00@0oooo0P09jPX0103o
ool02NX:0?ooo`3oool200WZ2P<0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`03
0?ooo`0400WZ2P3oool0oooo00WZ2PL0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0I0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04P0oooo0P09jPX01@3oool02NX:00WZ
2P09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo1009jPX0303oool02NX:0?ooo`09jPX0oooo
00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00`09jPX00`3oool0
2NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0
0`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P09jPX0oooo1P09
jPX0103oool02NX:00WZ2P3oool;00WZ2P030?ooo`09jPX0oooo00H02NX:00@0oooo00WZ2P09jPX0
oooo0`09jPX0103oool02NX:00WZ2P09jPX20?ooo`D02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3o
ool200WZ2P030?ooo`09jPX0oooo00L02NX:0P3oool200WZ2P030?ooo`09jPX02NX:0080oooo00<0
2NX:0?ooo`3oool0103oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0`3oool00`09jPX0oooo
00WZ2P020?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3oool02NX:1`3oool01@09jPX0
oooo0?ooo`3oool02NX:01T0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool0B03oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool3
00WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00H0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`03
00WZ2P3oool02NX:00<02NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool200WZ
2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P02
00WZ2P040?ooo`09jPX02NX:0?ooo`H02NX:00@0oooo00WZ2P09jPX0oooo3@09jPX00`3oool02NX:
00WZ2P0400WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ2P030?ooo`09jPX0
2NX:00@02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:0?ooo`0900WZ2P050?ooo`09
jPX02NX:00WZ2P3oool00P09jPX20?ooo`0300WZ2P3oool0oooo00@0oooo0P09jPX0103oool02NX:
0?ooo`3oool200WZ2P<0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`030?ooo`04
00WZ2P3oool0oooo00WZ2PL0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0I0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo04P0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0
oooo00802NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX0oooo00P02NX:00H0oooo
00WZ2P3oool0oooo00WZ2P3oool400WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0
oooo0P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ
2P09jPX00P09jPX0103oool02NX:00WZ2P3oool900WZ2P030?ooo`09jPX02NX:00/02NX:00<0oooo
00WZ2P09jPX01009jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0`09jPX00`3oool0
2NX:00WZ2P0400WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P3oool02@09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00802NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`802NX:00@0oooo
00WZ2P3oool0oooo0P09jPX30?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00`3o
ool01009jPX0oooo0?ooo`09jPX70?ooo`0500WZ2P3oool0oooo0?ooo`09jPX06@3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`180?ooo`802NX:00@0oooo00WZ2P09jPX0
2NX:0P3oool01@09jPX0oooo0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool00`09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P3oool01009jPX00`3oool02NX:0?ooo`02
00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:
00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P09jPX0oooo2@09jPX00`3oool0
2NX:00WZ2P0;00WZ2P030?ooo`09jPX02NX:00@02NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool0
2NX:0?ooo`<02NX:00<0oooo00WZ2P09jPX01@09jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09
jPX0oooo2@09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:0P3oool00`09jPX0oooo0?ooo`04
0?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX30?ooo`0300WZ2P3oool02NX:0080oooo00<0
2NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09jPX70?ooo`0500WZ2P3oool0oooo0?ooo`09
jPX06@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`180?ooo`802NX:
00L0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P09jPX00`3o
ool02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`04
00WZ2P030?ooo`09jPX0oooo00@02NX:0P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0
oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P040?ooo`09jPX02NX:0?ooo`T02NX:
00<0oooo00WZ2P09jPX02`09jPX00`3oool02NX:00WZ2P0400WZ2P080?ooo`09jPX02NX:0?ooo`09
jPX0oooo00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00D02NX:00P0oooo00WZ2P09jPX0oooo00WZ
2P3oool02NX:0?ooo`T02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P80oooo00<02NX:0?oo
o`3oool0103oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0`3oool00`09jPX0oooo00WZ2P02
0?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3oool02NX:203oool01009jPX0oooo0?oo
o`09jPXI0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04P0oooo0P09
jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool01@09jPX0oooo0?ooo`09jPX0oooo0080
2NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?oo
o`0300WZ2P030?ooo`09jPX0oooo00D02NX:0P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:
00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo00<02NX:0?ooo`09jPX0
2009jPX00`3oool02NX:00WZ2P0;00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0103oool0
2NX:00WZ2P09jPX20?ooo`802NX:00@0oooo00WZ2P09jPX0oooo1`09jPX0203oool02NX:00WZ2P3o
ool02NX:0?ooo`09jPX0oooo2@09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:0P3oool00`09
jPX0oooo0?ooo`040?ooo`802NX:00@0oooo00WZ2P3oool0oooo0P09jPX30?ooo`0300WZ2P3oool0
2NX:0080oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09jPX80?ooo`0400WZ2P3o
ool0oooo00WZ2QT0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0B@3o
ool00`09jPX0oooo0?ooo`0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P3oool0
0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00T0oooo00WZ2P09jPX02NX:0?ooo`09jPX0
oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0300WZ2P80oooo1@09jPX0103oool02NX:00WZ
2P3oool400WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P3oool02@09jPX0103oool02NX:
00WZ2P3oool:00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0103oool02NX:00WZ2P09jPX2
0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P080?ooo`09
jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool900WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX2
0?ooo`0300WZ2P3oool0oooo00@0oooo0P09jPX0103oool02NX:0?ooo`3oool200WZ2P<0oooo00<0
2NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0oooo00WZ2PP0oooo
00@02NX:0?ooo`3oool02NX:6@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`190?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P060?ooo`09jPX02NX:0?oo
o`09jPX0oooo0P09jPX02@3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P80
oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00D02NX:0P3oool500WZ2P040?ooo`09jPX02NX:
0?ooo`@02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:0?ooo`0<00WZ2P050?ooo`09jPX0
oooo00WZ2P3oool00`09jPX0103oool02NX:00WZ2P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`<0
2NX:0P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01@09jPX01P3o
ool02NX:00WZ2P3oool02NX:0?ooo`L02NX:0P3oool300WZ2P80oooo00@02NX:0?ooo`3oool02NX:
1P3oool200WZ2P070?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:
0080oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09jPX80?ooo`0400WZ2P3oool0
oooo00WZ2QT0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0B@3oool2
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool400WZ2P0<0?oo
o`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool200WZ2P050?oo
o`09jPX02NX:00WZ2P3oool01@09jPX20?ooo`D02NX:00@0oooo00WZ2P09jPX0oooo1009jPX00`3o
ool02NX:00WZ2P0300WZ2P030?ooo`09jPX0oooo00H02NX:00<0oooo00WZ2P09jPX00`09jPX00`3o
ool02NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00L0oooo00WZ2P09jPX0oooo00WZ
2P3oool02NX:0080oooo0P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00D0
2NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool700WZ2P030?ooo`09jPX02NX:00802NX:0P3oool0
1009jPX0oooo0?ooo`09jPX60?ooo`802NX:00L0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:0080
oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0oooo00WZ
2PP0oooo00<02NX:0?ooo`09jPX06P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`190?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:
0?ooo`@02NX:00`0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX2
0?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0500WZ2P80oooo1@09jPX0103oool02NX:00WZ
2P3oool:00WZ2P030?ooo`09jPX0oooo00H02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:
0?ooo`0800WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0103oool02NX:0?ooo`09jPX20?oo
o`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX0
oooo00802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0200WZ2P80oooo00@02NX:
0?ooo`3oool02NX:1`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:0080oooo00<0
2NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0
203oool00`09jPX0oooo00WZ2P0J0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo04T0oooo0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`0500WZ2P3oool0oooo00WZ2P3o
ool00`09jPX03@3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09
jPX00P3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool01@09jPX20?ooo`D02NX:00@0oooo00WZ
2P09jPX0oooo2P09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX00`09
jPX00`3oool02NX:00WZ2P0800WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0103oool02NX:
0?ooo`09jPX20?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0600WZ
2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0200WZ
2P80oooo00@02NX:0?ooo`3oool02NX:1`3oool300WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool0
1@09jPX0oooo00WZ2P3oool02NX:00D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P080?ooo`0300WZ
2P3oool02NX:01X0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0B@3o
ool200WZ2P070?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:0080
2NX:00<0oooo00WZ2P3oool01009jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX0
1@3oool02NX:00WZ2P09jPX0oooo00H02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ
2P020?ooo`d02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09
jPX02NX:00P02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P050?ooo`09jPX0oooo00WZ2P3o
ool01009jPX0103oool02NX:00WZ2P3oool800WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ
2P09jPX01009jPX00`3oool02NX:0?ooo`0200WZ2P80oooo00@02NX:0?ooo`3oool02NX:1`3oool3
00WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo00WZ2P3oool02NX:00D0oooo00D0
2NX:0?ooo`3oool0oooo00WZ2P080?ooo`0300WZ2P3oool02NX:01X0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool0B@3oool200WZ2P80oooo00D02NX:0?ooo`09jPX0oooo
00WZ2P020?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:
00WZ2P0200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0
oooo00@02NX:00<0oooo00WZ2P09jPX00P09jPX0103oool02NX:00WZ2P09jPX20?ooo`H02NX:00<0
oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00h02NX:00<0
oooo00WZ2P09jPX01P09jPX01@3oool02NX:0?ooo`09jPX0oooo00L02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool0
2NX:0?ooo`0200WZ2P80oooo00@02NX:0?ooo`3oool02NX:1`3oool300WZ2P80oooo00<02NX:0?oo
o`09jPX00P3oool01@09jPX0oooo00WZ2P3oool02NX:00D0oooo00D02NX:0?ooo`3oool0oooo00WZ
2P080?ooo`0300WZ2P3oool02NX:01X0oooo00<000000?ooo`3oool01@3oool000L0oooo00<00000
0?ooo`3oool0BP3oool00`09jPX0oooo0?ooo`0300WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00P3o
ool200WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09jPX01P3oool02NX:0?oo
o`3oool02NX:0?ooo`@02NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0400WZ2P04
0?ooo`09jPX02NX:00WZ2P80oooo0`09jPX0103oool02NX:00WZ2P3oool600WZ2P030?ooo`09jPX0
2NX:00802NX:00<0oooo00WZ2P09jPX03P09jPX00`3oool02NX:00WZ2P0600WZ2P050?ooo`09jPX0
oooo00WZ2P3oool01`09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P3oool0
2@09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo00@02NX:0?ooo`3oool02NX:1`3oool300WZ
2P80oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo00WZ2P3oool02NX:00D0oooo00D02NX:
0?ooo`3oool0oooo00WZ2P090?ooo`802NX:6P3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`1:0?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P060?ooo`09
jPX02NX:0?ooo`09jPX0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00L0oooo00WZ
2P09jPX02NX:0?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?oo
o`0300WZ2P030?ooo`09jPX02NX:00802NX:0P3oool300WZ2P040?ooo`09jPX02NX:0?ooo`H02NX:
00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0>00WZ2P030?ooo`09jPX0oooo00H02NX:
00D0oooo00WZ2P3oool02NX:0?ooo`0700WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX00`3o
ool02NX:0?ooo`0900WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool01009jPX0oooo0?ooo`09
jPX70?ooo`<02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0
1@3oool01@09jPX0oooo0?ooo`3oool02NX:00T0oooo0P09jPXJ0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo04X0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo0080
2NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09
jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool01009jPX00`3oool02NX:0?ooo`0200WZ2P03
0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`<02NX:00@0oooo00WZ2P09
jPX0oooo1009jPX00`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:01002NX:00<0oooo00WZ
2P09jPX01009jPX01@3oool02NX:0?ooo`09jPX0oooo00P02NX:00<0oooo00WZ2P09jPX01@09jPX0
0`3oool02NX:00WZ2P0800WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0P3oool01009jPX0oooo
0?ooo`09jPX70?ooo`<02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0500WZ2P3oool02NX:0?oo
o`09jPX01@3oool01@09jPX0oooo0?ooo`3oool02NX:00T0oooo0P09jPXJ0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo04X0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0
oooo00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P050?ooo`09jPX0oooo00WZ2P3o
ool00`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool01009jPX00`3oool02NX:0?ooo`02
00WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`802NX:00L0oooo
00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool01009jPX0103oool02NX:
00WZ2P3oool:00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01009jPX01@3oool0
2NX:00WZ2P09jPX0oooo00P02NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P0;00WZ
2P050?ooo`09jPX0oooo0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`050?ooo`<02NX:0P3oool0
0`09jPX0oooo00WZ2P020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX01@3oool01@09jPX0oooo0?oo
o`3oool02NX:00T0oooo0P09jPXJ0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo04X0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0
oooo1009jPX02@3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09
jPX0oooo00@02NX:00<0oooo00WZ2P3oool00P09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3o
ool01009jPX20?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo
00@02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:0?ooo`0500WZ2P030?ooo`09jPX02NX:
00T02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:
0?ooo`0300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX02`09jPX01@3oool02NX:
0?ooo`3oool02NX:0080oooo00<02NX:0?ooo`3oool01@3oool300WZ2P80oooo00<02NX:0?ooo`09
jPX00P3oool01@09jPX0oooo00WZ2P3oool02NX:00D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P09
0?ooo`802NX:6P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1:0?oo
o`802NX:00L0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00`09
jPX02@3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo
00@02NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`3oool200WZ2P030?ooo`09jPX0
2NX:00802NX:0P3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX00`3oool02NX:0?oo
o`0400WZ2P030?ooo`09jPX02NX:00<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P030?oo
o`09jPX02NX:00H02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00<0
2NX:00<0oooo00WZ2P09jPX00`09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`/02NX:00@0oooo
00WZ2P3oool02NX:0P3oool01009jPX0oooo0?ooo`09jPX70?ooo`<02NX:0P3oool00`09jPX0oooo
00WZ2P020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX01@3oool01@09jPX0oooo0?ooo`3oool02NX:
00T0oooo0P09jPXJ0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04/0
oooo00P02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00P09
jPX02P3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ2P80oooo0`09jPX0
1@3oool02NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool0oooo0P09jPX00`3oool02NX:
00WZ2P0200WZ2P80oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P3o
ool02P09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool01P09jPX01@3o
ool02NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool00`09jPX0103oool02NX:00WZ2P3o
ool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1009jPX00`3oool02NX:00WZ2P0500WZ2P<0
oooo00<02NX:0?ooo`09jPX00P3oool200WZ2PH0oooo0`09jPX20?ooo`0300WZ2P3oool02NX:0080
oooo00D02NX:0?ooo`09jPX0oooo00WZ2P050?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02@3oool2
00WZ2QX0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0B`3oool200WZ
2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P030?ooo`09
jPX0oooo00802NX:00P0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00<02NX:00@0oooo00WZ2P3oool0oooo0P09jPX00`3oool02NX:00WZ
2P0200WZ2P80oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX0
3009jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00H02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00<02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3o
ool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool01@09jPX30?oo
o`0300WZ2P3oool02NX:0080oooo0P09jPX60?ooo`<02NX:0P3oool00`09jPX0oooo00WZ2P020?oo
o`0500WZ2P3oool02NX:0?ooo`09jPX01@3oool01@09jPX0oooo0?ooo`3oool02NX:00T0oooo0P09
jPXJ0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04/0oooo0P09jPX0
1P3oool02NX:00WZ2P09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX00`3oool02NX:
0?ooo`0400WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool200WZ2P050?ooo`09jPX02NX:
00WZ2P3oool01@09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`0300WZ2P3oool0
2NX:00<02NX:00<0oooo00WZ2P09jPX04@09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX0
oooo00<02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3o
ool00`09jPX0103oool02NX:00WZ2P3oool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX0
0`3oool02NX:0?ooo`0500WZ2P<0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2PH0oooo0`09
jPX20?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09jPX0oooo00WZ2P050?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX02P3oool00`09jPX0oooo0?ooo`0H0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo04/0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo0080
2NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09
jPX0103oool02NX:0?ooo`09jPX20?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0500WZ2P80
oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo00<02NX:0?ooo`09jPX00`09jPX00`3oool0
2NX:00WZ2P0A00WZ2P030?ooo`09jPX02NX:00T02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX01P3o
ool02NX:00WZ2P09jPX0oooo00WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P0400WZ2P050?ooo`09
jPX02NX:00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0500WZ2P<0oooo00D02NX:0?ooo`09jPX0
2NX:0?ooo`0200WZ2PH0oooo0`09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00D02NX:0?ooo`09
jPX0oooo00WZ2P050?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02P3oool00`09jPX0oooo0?ooo`0H
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04/0oooo0P09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P050?oo
o`09jPX02NX:00WZ2P3oool01009jPX0103oool02NX:0?ooo`3oool200WZ2P050?ooo`09jPX02NX:
00WZ2P3oool01@09jPX20?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:0?oo
o`0T00WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:0P3oool400WZ2P050?ooo`09jPX02NX:00WZ2P3o
ool01P09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool01`09jPX30?oo
o`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX60?ooo`<02NX:0P3oool00`09jPX0oooo00WZ2P02
0?ooo`0500WZ2P3oool02NX:0?ooo`09jPX01@3oool01@09jPX0oooo0?ooo`3oool02NX:00X0oooo
00<02NX:0?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`1;0?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P060?ooo`09jPX02NX:0?ooo`09
jPX0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P3oool2
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool01@09jPX20?ooo`802NX:00@0oooo00WZ2P09jPX0oooo
0P09jPX00`3oool02NX:0?ooo`0T00WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:0P3oool400WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool01P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`<02NX:00<0
oooo00WZ2P09jPX01@09jPX30?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX60?ooo`<02NX:
0P3oool00`09jPX0oooo00WZ2P020?ooo`0500WZ2P3oool02NX:0?ooo`09jPX01@3oool01@09jPX0
oooo0?ooo`3oool02NX:00X0oooo00<02NX:0?ooo`3oool0603oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`1;0?ooo`802NX:00L0oooo00WZ2P09jPX0oooo00WZ2P3oool0
2NX:0080oooo00<02NX:0?ooo`09jPX00`09jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:00<0
oooo00WZ2P09jPX00P3oool00`09jPX0oooo00WZ2P0300WZ2P030?ooo`09jPX02NX:00<02NX:0P3o
ool200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P3oool02`09jPX00`3oool02NX:
00WZ2P0500WZ2P030?ooo`09jPX02NX:00h02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:
00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:
00WZ2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`L02NX:0`3oool01@09jPX0oooo00WZ2P09jPX0
oooo00802NX:1P3oool300WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo00WZ2P3o
ool02NX:00D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0:0?ooo`0300WZ2P3oool0oooo01P0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0C03oool02009jPX0oooo0?oo
o`09jPX0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P050?ooo`09jPX0oooo
00WZ2P3oool00`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool01009jPX00`3oool02NX:
00WZ2P0300WZ2P80oooo0P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00L0
2NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0700WZ2P030?ooo`09jPX02NX:00h02NX:00<0oooo00WZ
2P09jPX01009jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ
2P09jPX00`09jPX0103oool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`H02NX:103o
ool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:1P3oool300WZ2P80oooo00<02NX:0?ooo`09jPX0
0P3oool01@09jPX0oooo00WZ2P3oool02NX:00D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0:0?oo
o`0300WZ2P3oool0oooo01P0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool0C03oool200WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0P3oool00`09jPX0oooo00WZ2P05
00WZ2P070?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00@02NX:
00<0oooo00WZ2P09jPX00`09jPX20?ooo`D02NX:00@0oooo00WZ2P09jPX0oooo2@09jPX01@3oool0
2NX:00WZ2P09jPX0oooo00L02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0800WZ
2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX02009jPX00`3oool02NX:00WZ2P0400WZ
2P030?ooo`09jPX0oooo00802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0500WZ2P@0oooo00D02NX:
0?ooo`09jPX02NX:0?ooo`0200WZ2PH0oooo0`09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00D0
2NX:0?ooo`09jPX0oooo00WZ2P050?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02P3oool00`09jPX0
oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04`0oooo
0P09jPX01P3oool02NX:00WZ2P09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`3oool01@09jPX01`3o
ool02NX:0?ooo`09jPX0oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0400WZ2P030?ooo`09
jPX02NX:00<02NX:0P3oool500WZ2P040?ooo`09jPX02NX:0?ooo`H02NX:00@0oooo00WZ2P09jPX0
oooo0`09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09
jPX02009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00T02NX:00<0oooo00WZ2P09
jPX00`09jPX00`3oool02NX:0?ooo`0600WZ2P030?ooo`09jPX02NX:00<02NX:103oool01@09jPX0
oooo00WZ2P09jPX0oooo00802NX:1P3oool300WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool01@09
jPX0oooo00WZ2P3oool02NX:00D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0:0?ooo`0300WZ2P3o
ool0oooo01P0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0C03oool2
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0103oool02NX:0?ooo`3oool200WZ2P030?oo
o`09jPX0oooo00802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00@0
2NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:0?oo
o`H02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX0
2NX:00X02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0600WZ2P030?ooo`09jPX02NX:00802NX:00<0
oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX0oooo00H02NX:00<0
oooo00WZ2P09jPX00`09jPX40?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`3oool0
103oool300WZ2P80oooo00<02NX:0?ooo`09jPX00P3oool01@09jPX0oooo00WZ2P3oool02NX:00D0
oooo00D02NX:0?ooo`3oool0oooo00WZ2P090?ooo`0300WZ2P3oool02NX:01T0oooo00<000000?oo
o`3oool01@3oool000L0oooo00<000000?ooo`3oool0C03oool200WZ2P050?ooo`09jPX02NX:00WZ
2P3oool00P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00@02NX:00<0oooo
00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo
00WZ2P3oool01@09jPX0103oool02NX:00WZ2P3oool600WZ2P040?ooo`09jPX02NX:0?ooo`/02NX:
00<0oooo00WZ2P09jPX02P09jPX01@3oool02NX:00WZ2P09jPX0oooo00H02NX:00H0oooo00WZ2P09
jPX0oooo00WZ2P3oool600WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX03@09jPX3
0?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`3oool0103oool300WZ2P80oooo0`09
jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX01@3oool01@09jPX0oooo0?ooo`3oool02NX:00T0
oooo00<02NX:0?ooo`09jPX06@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`1<0?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?oo
o`@02NX:00<0oooo00WZ2P09jPX00P09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo1@09
jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00D02NX:00@0oooo00WZ2P09jPX0oooo
1P09jPX0103oool02NX:00WZ2P3oool;00WZ2P030?ooo`09jPX02NX:00X02NX:00D0oooo00WZ2P3o
ool02NX:0?ooo`0600WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01@09jPX00`3o
ool02NX:00WZ2P0200WZ2P040?ooo`09jPX02NX:0?ooo``02NX:0`3oool01009jPX0oooo00WZ2P09
jPX20?ooo`0300WZ2P3oool0oooo00@0oooo0`09jPX20?ooo`<02NX:0P3oool01@09jPX0oooo00WZ
2P3oool02NX:00D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P090?ooo`0300WZ2P3oool02NX:01T0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0C03oool200WZ2P050?oo
o`09jPX02NX:00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool400WZ2P050?ooo`09jPX02NX:
00WZ2P3oool00P09jPX0103oool02NX:0?ooo`09jPX20?ooo`D02NX:00<0oooo00WZ2P3oool00P09
jPX00`3oool02NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:0?ooo`H02NX:00@0oooo00WZ2P09jPX0
oooo2`09jPX00`3oool02NX:00WZ2P0:00WZ2P050?ooo`09jPX0oooo00WZ2P3oool01P09jPX00`3o
ool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX00P09jPX0103o
ool02NX:00WZ2P3oool900WZ2P030?ooo`09jPX02NX:00<0oooo00@02NX:0?ooo`09jPX02NX:0P3o
ool00`09jPX0oooo0?ooo`040?ooo`<02NX:0P3oool300WZ2P80oooo0P09jPX00`3oool02NX:00WZ
2P050?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02@3oool00`09jPX0oooo00WZ2P0I0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04d0oooo00P02NX:0?ooo`3oool02NX:
0?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX00`09jPX01@3oool02NX:00WZ2P09jPX0
oooo00@02NX:00@0oooo00WZ2P3oool0oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`80
2NX:00<0oooo00WZ2P3oool01@09jPX0103oool02NX:00WZ2P3oool500WZ2P050?ooo`09jPX02NX:
00WZ2P3oool02`09jPX00`3oool02NX:00WZ2P0:00WZ2P030?ooo`09jPX0oooo00P02NX:00<0oooo
00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo
00WZ2P09jPX02@09jPX30?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool0103o
ool300WZ2P80oooo0`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX01@3oool01@09jPX0oooo0?oo
o`3oool02NX:00T0oooo00<02NX:0?ooo`09jPX06@3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`1=0?ooo`802NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`03
00WZ2P3oool02NX:00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P040?ooo`09jPX0oooo
0?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`D02NX:
00@0oooo00WZ2P09jPX0oooo1@09jPX01@3oool02NX:00WZ2P09jPX0oooo00/02NX:00<0oooo00WZ
2P09jPX00`09jPX01@3oool02NX:00WZ2P09jPX0oooo01802NX:00<0oooo00WZ2P09jPX01@09jPX0
0`3oool02NX:00WZ2P0600WZ2P050?ooo`09jPX0oooo00WZ2P3oool01`09jPX30?ooo`0400WZ2P3o
ool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool0103oool300WZ2P80oooo0`09jPX20?ooo`802NX:
00<0oooo00WZ2P09jPX01@3oool01@09jPX0oooo0?ooo`3oool02NX:00T0oooo00<02NX:0?ooo`09
jPX06@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1=0?ooo`802NX:
00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool02NX:00<02NX:00D0oooo00WZ
2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX00`3oool02NX:00WZ2P05
00WZ2P030?ooo`09jPX0oooo00D02NX:00@0oooo00WZ2P09jPX0oooo1@09jPX01@3oool02NX:00WZ
2P09jPX0oooo00`02NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:0?ooo`09jPX0oooo0180
2NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P0500WZ2P050?ooo`09jPX0oooo00WZ
2P3oool01`09jPX30?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo00WZ2P020?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX02NX:00D0oooo00D02NX:
0?ooo`3oool0oooo00WZ2P090?ooo`0300WZ2P3oool02NX:01T0oooo00<000000?ooo`3oool01@3o
ool000L0oooo00<000000?ooo`3oool0C@3oool200WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:
0P3oool00`09jPX0oooo00WZ2P0200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0`09jPX00`3o
ool02NX:00WZ2P020?ooo`802NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:0?ooo`0500WZ
2P040?ooo`09jPX02NX:0?ooo`@02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0:
00WZ2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0800WZ2P030?ooo`09
jPX02NX:00L02NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09
jPX02NX:00802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0500WZ2P<0oooo00@02NX:0?ooo`3oool0
2NX:0P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool02NX:0080oooo0`09jPX20?ooo`80
2NX:00<0oooo00WZ2P09jPX01@3oool01@09jPX0oooo0?ooo`3oool02NX:00T0oooo00<02NX:0?oo
o`09jPX06@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1=0?ooo`80
2NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00X0oooo
00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo0`09jPX0103oool02NX:00WZ2P3oool9
00WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo
00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0600WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009
jPX01@3oool02NX:0?ooo`09jPX0oooo00D02NX:00@0oooo00WZ2P09jPX0oooo2@09jPX00`3oool0
2NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool0
2NX:00WZ2P09jPX0oooo00D02NX:0`3oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`09jPX00P3oool300WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P05
0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02@3oool00`09jPX0oooo00WZ2P0I0?ooo`030000003o
ool0oooo00D0oooo00070?ooo`030000003oool0oooo04d0oooo0P09jPX01@3oool02NX:00WZ2P09
jPX0oooo00802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:0?ooo`0200WZ2P050?ooo`09
jPX0oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0:00WZ2P80oooo0P09jPX00`3oool02NX:
00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:
00WZ2P0400WZ2P030?ooo`09jPX02NX:00802NX:00T0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo
00WZ2P3oool01@09jPX0103oool02NX:00WZ2P3oool500WZ2P050?ooo`09jPX02NX:00WZ2P3oool0
0P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09
jPX00P09jPX01@3oool02NX:00WZ2P09jPX0oooo00D02NX:0`3oool01009jPX0oooo0?ooo`09jPX2
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`09jPX00P3oool300WZ2P80oooo0P09jPX0
0`3oool02NX:00WZ2P050?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02@3oool01009jPX0oooo0?oo
o`09jPXH0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04h0oooo00<0
2NX:0?ooo`09jPX00P09jPX0103oool02NX:00WZ2P3oool400WZ2P040?ooo`09jPX02NX:0?ooo`80
2NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00@02NX:00<0oooo00WZ
2P09jPX00`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0200WZ
2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0200WZ
2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0700WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:
00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo``02NX:00D0oooo00WZ
2P09jPX02NX:0?ooo`0500WZ2P@0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool02NX:0080oooo0`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX01@3oool0
1@09jPX0oooo0?ooo`3oool02NX:00T0oooo00@02NX:0?ooo`3oool02NX:603oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1>0?ooo`0900WZ2P3oool0oooo00WZ2P3oool0
2NX:0?ooo`09jPX0oooo00@02NX:00@0oooo00WZ2P09jPX0oooo1009jPX00`3oool02NX:0?ooo`03
00WZ2P030?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`802NX:00<0oooo
00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo
00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool02@09
jPX0103oool02NX:00WZ2P3oool500WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0103oool0
2NX:00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00H02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`05
00WZ2P@0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
2NX:0080oooo0`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX01@3oool01@09jPX0oooo0?ooo`3o
ool02NX:00T0oooo00@02NX:0?ooo`3oool02NX:603oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`1>0?ooo`802NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`<0
2NX:00@0oooo00WZ2P09jPX0oooo1009jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo
00@02NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX00`3o
ool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX01009jPX00`3o
ool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00/02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX0
0`3oool02NX:00WZ2P0300WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo
0P09jPX00`3oool02NX:00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01@09jPX40?ooo`03
00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo00WZ2P020?ooo`<0
2NX:0P3oool200WZ2P030?ooo`09jPX02NX:00D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P090?oo
o`0400WZ2P3oool0oooo00WZ2QP0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool0CP3oool200WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0P3oool600WZ2P050?ooo`09
jPX02NX:00WZ2P3oool00P09jPX01`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool01009jPX00`3o
ool02NX:00WZ2P0300WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:
00802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:
00802NX:00<0oooo00WZ2P09jPX04P09jPX0103oool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX0
2NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P030?oo
o`09jPX0oooo00P02NX:103oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00@0oooo
00<02NX:0?ooo`09jPX00P3oool300WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P050?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX02@3oool01009jPX0oooo0?ooo`09jPXH0?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo04h0oooo0P09jPX01P3oool02NX:00WZ2P09jPX0oooo
00WZ2P80oooo1P09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:00@0oooo00WZ2P3oool0oooo
1@09jPX00`3oool02NX:00WZ2P0300WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P030?oo
o`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0600WZ2P030?oo
o`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX04P09jPX0103oool02NX:00WZ2P3oool200WZ2P04
0?ooo`09jPX02NX:0?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo1`09jPX01@3oool02NX:0?ooo`09
jPX0oooo00H02NX:103oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00D0oooo0P09
jPX20?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX02NX:00D0oooo00D02NX:0?ooo`3oool0oooo
00WZ2P090?ooo`0400WZ2P3oool0oooo00WZ2QP0oooo00<000000?ooo`3oool01@3oool000L0oooo
00<000000?ooo`3oool0CP3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool0
2NX:00WZ2P0400WZ2P050?ooo`09jPX0oooo00WZ2P3oool01009jPX0103oool02NX:0?ooo`3oool5
00WZ2P030?ooo`09jPX0oooo00<02NX:0P3oool200WZ2P030?ooo`09jPX02NX:00802NX:0P3oool3
00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool01P09jPX00`3oool02NX:00WZ2P02
00WZ2P030?ooo`09jPX02NX:01802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ
2P0400WZ2P030?ooo`09jPX02NX:00P02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0600WZ2P@0oooo
00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`050?ooo`802NX:0P3oool300WZ2P80oooo
0P09jPX00`3oool02NX:00WZ2P050?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02@3oool01009jPX0
oooo0?ooo`09jPXH0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04h0
oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0
1P3oool02NX:00WZ2P3oool02NX:0?ooo`@02NX:00@0oooo00WZ2P3oool0oooo1@09jPX00`3oool0
2NX:0?ooo`0300WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0`09jPX00`3oool0
2NX:00WZ2P0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool04`09jPX00`3oool02NX:00WZ2P0;00WZ
2P040?ooo`09jPX02NX:0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0900WZ2P090?ooo`09
jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00<02NX:0`3oool00`09jPX0oooo00WZ2P020?oo
o`0300WZ2P3oool0oooo00D0oooo0P09jPX20?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX02NX:
00D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P090?ooo`0400WZ2P3oool0oooo00WZ2QP0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0C`3oool00`09jPX0oooo00WZ2P02
00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:
0?ooo`0300WZ2P030?ooo`09jPX02NX:0080oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?oo
o`802NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0`09jPX00`3o
ool02NX:00WZ2P0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool03`09jPX01@3oool02NX:00WZ2P09
jPX0oooo00d02NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:00WZ2P09jPX0oooo00T02NX:
00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P040?ooo`09jPX02NX:00WZ2P<0oooo00<02NX:0?oo
o`09jPX00P3oool200WZ2PH0oooo0P09jPX20?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX02NX:
00D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P090?ooo`0500WZ2P3oool0oooo0?ooo`09jPX05`3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1?0?ooo`0500WZ2P3oool0
oooo00WZ2P3oool00`09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00802NX:
00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P80oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:
0?ooo`802NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0`09jPX0
0`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool02`09jPX00`3oool02NX:00WZ
2P0500WZ2P030?ooo`09jPX02NX:00d02NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:00WZ
2P09jPX0oooo00T02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P040?ooo`09jPX02NX:00WZ
2P<0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2PH0oooo0P09jPX20?ooo`<02NX:0P3oool2
00WZ2P030?ooo`09jPX02NX:00D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P090?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX05`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`1?0?ooo`802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3o
ool00P09jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0`09jPX0103oool02NX:00WZ
2P3oool400WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1`09jPX20?ooo`<02NX:00<0oooo00WZ
2P09jPX00P09jPX01@3oool02NX:00WZ2P09jPX0oooo00/02NX:00<0oooo00WZ2P09jPX01@09jPX0
0`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX00`09jPX0
1@3oool02NX:00WZ2P09jPX0oooo00@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0700WZ2P040?oo
o`09jPX02NX:00WZ2P<0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2PH0oooo0P09jPX20?oo
o`<02NX:0P3oool200WZ2P030?ooo`09jPX02NX:00D0oooo00D02NX:0?ooo`3oool0oooo00WZ2P09
0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX05`3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`1?0?ooo`802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:
00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00<02NX:
00@0oooo00WZ2P09jPX0oooo0`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool01`09jPX2
0?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:00WZ2P09jPX0oooo00/02NX:00<0
oooo00WZ2P09jPX01@09jPX02@3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`0700WZ
2P040?ooo`09jPX02NX:0?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0500WZ2P050?ooo`09
jPX02NX:00WZ2P3oool01P09jPX0103oool02NX:00WZ2P09jPX30?ooo`0500WZ2P3oool02NX:00WZ
2P3oool00P09jPX60?ooo`802NX:0P3oool300WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P050?oo
o`0400WZ2P3oool0oooo00WZ2PX0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0G0?ooo`030000003o
ool0oooo00D0oooo00070?ooo`030000003oool0oooo04l0oooo0P09jPX01`3oool02NX:00WZ2P09
jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:
00<0oooo00WZ2P3oool00`09jPX0103oool02NX:00WZ2P3oool300WZ2P070?ooo`09jPX02NX:00WZ
2P3oool02NX:0?ooo`0700WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX0
2NX:00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00T02NX:00D0
oooo00WZ2P3oool02NX:0?ooo`0700WZ2P040?ooo`09jPX02NX:0?ooo`H02NX:00<0oooo00WZ2P09
jPX00`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool01009jPX0103oool02NX:00WZ2P09
jPX30?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX60?ooo`802NX:0P3oool300WZ2P80oooo
0P09jPX00`3oool02NX:00WZ2P050?ooo`0400WZ2P3oool0oooo00WZ2PX0oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P0G0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04l0
oooo0P09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P02
00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`04
00WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:0?ooo`<0
2NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ
2P09jPX01009jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ
2P3oool01`09jPX0103oool02NX:00WZ2P3oool600WZ2P030?ooo`09jPX02NX:00<02NX:00L0oooo
00WZ2P09jPX02NX:0?ooo`09jPX0oooo00P02NX:0`3oool01@09jPX0oooo00WZ2P09jPX0oooo0080
2NX:1P3oool200WZ2P80oooo0`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX0103oool01@09jPX0
oooo0?ooo`3oool02NX:00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0E0?oo
o`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04l0oooo0P09jPX01@3oool0
2NX:00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:00WZ2P09jPX0
oooo00802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00@02NX:00L0oooo00WZ2P09jPX0
2NX:0?ooo`09jPX0oooo00D02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:00WZ2P02
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09
jPX02NX:00802NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P0600WZ2P80oooo0P09
jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00T02NX:00<0oooo00WZ2P3oool01P09
jPX30?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX60?ooo`802NX:0P3oool300WZ2P80oooo
0P09jPX00`3oool02NX:00WZ2P040?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02@3oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01D0oooo00<000000?ooo`3oool01@3oool000L0oooo
00<000000?ooo`3oool0D03oool00`09jPX0oooo0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:
0P3oool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1009jPX01@3oool02NX:0?ooo`09jPX0
oooo00@02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00D02NX:00@0oooo00WZ2P09jPX0
oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool01009jPX00`3o
ool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01P09jPX00`3o
ool02NX:00WZ2P0600WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:
00P02NX:00@0oooo00WZ2P09jPX0oooo1@09jPX30?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09
jPX60?ooo`802NX:0P3oool300WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P040?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01D0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0D03oool200WZ2P030?ooo`09
jPX0oooo00H02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:0?ooo`0400WZ2P050?oo
o`09jPX0oooo00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00<0
2NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX0oooo
00WZ2P3oool02`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo
00WZ2P09jPX01P09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P08
00WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:0`3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:
1P3oool200WZ2P80oooo0`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX0103oool01@09jPX0oooo
0?ooo`3oool02NX:00T0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0500oooo0P09jPX01@3oool02NX:
00WZ2P09jPX0oooo00@02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:0?ooo`0400WZ
2P040?ooo`09jPX0oooo0?ooo`D02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P03
00WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:0?oo
o`09jPX0oooo00/02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0600WZ2P030?oo
o`09jPX02NX:00L02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0600WZ2P030?ooo`09jPX02NX:00P0
2NX:00<0oooo00WZ2P09jPX00P3oool400WZ2P<0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ
2PH0oooo0P09jPX20?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX02NX:00@0oooo00D02NX:0?oo
o`3oool0oooo00WZ2P090?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0503oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1@0?ooo`802NX:00L0oooo00WZ
2P09jPX02NX:0?ooo`09jPX0oooo00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P03
0?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P3oool0oooo1@09jPX00`3oool02NX:00WZ2P0300WZ
2P030?ooo`09jPX02NX:00<02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:00WZ2P02
00WZ2P050?ooo`09jPX0oooo00WZ2P3oool04009jPX00`3oool02NX:00WZ2P0@00WZ2P050?ooo`09
jPX02NX:00WZ2P3oool01P09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00<02NX:
0P3oool400WZ2P<0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2PH0oooo0P09jPX20?ooo`<0
2NX:0P3oool200WZ2P030?ooo`09jPX02NX:00@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P090?oo
o`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`1@0?ooo`802NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX2
0?ooo`0400WZ2P3oool02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:
00WZ2P020?ooo`D02NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`@02NX:00@0oooo00WZ2P09jPX0
oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool04009jPX00`3o
ool02NX:00WZ2P0D00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool01`09jPX00`3o
ool02NX:0?ooo`0300WZ2P80oooo1009jPX30?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX6
0?ooo`802NX:0P3oool300WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P040?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01@0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0D03oool200WZ2P060?ooo`09jPX0
2NX:00WZ2P3oool02NX:0P3oool00`09jPX0oooo00WZ2P0300WZ2P080?ooo`09jPX02NX:0?ooo`09
jPX0oooo00WZ2P3oool200WZ2P80oooo1@09jPX00`3oool02NX:00WZ2P0300WZ2P80oooo1009jPX0
103oool02NX:00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool00P09
jPX00`3oool02NX:00WZ2P0J00WZ2P030?ooo`09jPX02NX:00`02NX:00@0oooo00WZ2P09jPX0oooo
1009jPX01@3oool02NX:0?ooo`09jPX0oooo00<02NX:0P3oool01009jPX0oooo00WZ2P09jPX30?oo
o`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX60?ooo`802NX:0P3oool200WZ2P030?ooo`09jPX0
oooo00802NX:00<0oooo00WZ2P09jPX0103oool01@09jPX0oooo0?ooo`3oool02NX:00T0oooo00<0
2NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo0540oooo00<02NX:0?ooo`09jPX00P09jPX01P3oool02NX:0?ooo`3o
ool02NX:0?ooo`@02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo
0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`<02NX:0P3oool400WZ2P040?ooo`09jPX02NX:
0?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0
2NX:00T02NX:00<0oooo00WZ2P09jPX03P09jPX00`3oool02NX:00WZ2P0?00WZ2P030?ooo`09jPX0
2NX:00802NX:00P0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`09
jPX02NX:103oool01009jPX0oooo00WZ2P3oool200WZ2PH0oooo0`09jPX01P3oool02NX:00WZ2P3o
ool02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX0103oool01@09jPX0oooo0?ooo`3oool02NX:00T0
oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo0540oooo00<02NX:0?ooo`3oool00P09jPX01P3oool02NX:
00WZ2P3oool02NX:0?ooo`@02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0300WZ
2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P3oool00`09jPX20?ooo`802NX:00<0oooo
00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool300WZ2P050?ooo`09jPX0oooo00WZ2P3oool0
0P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX0
3P09jPX00`3oool02NX:00WZ2P0900WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX0
0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P<0
oooo00@02NX:0?ooo`09jPX0oooo0P09jPX60?ooo`<02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3o
ool200WZ2P030?ooo`09jPX02NX:00@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P090?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`1A0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0103oool02NX:
00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool00`09jPX0103oool0
2NX:00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00<02NX:0P3oool200WZ2P030?ooo`09jPX0oooo
00802NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00<0oooo
00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0D00WZ2P030?ooo`09jPX02NX:00d02NX:00<0oooo
00WZ2P3oool01009jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:0P3oool00`09jPX0oooo00WZ
2P0200WZ2P<0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`040?ooo`<02NX:00H0
oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00@0oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P090?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0503oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1A0?ooo`802NX:00<0oooo00WZ2P09
jPX00`09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ
2P09jPX0oooo0`09jPX0103oool02NX:00WZ2P3oool400WZ2P040?ooo`09jPX02NX:00WZ2P80oooo
0P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00@02NX:00D0oooo00WZ2P3oool0
2NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX03@09jPX00`3oool0
2NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool0
2NX:0?ooo`0400WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX20?ooo`0300WZ2P3oool02NX:
00802NX:0`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00@0oooo0`09jPX01P3o
ool02NX:00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX0103oool01@09jPX0oooo0?oo
o`3oool02NX:00T0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0C0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0540oooo0P09jPX00`3oool02NX:00WZ
2P0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ
2P050?ooo`09jPX02NX:00WZ2P3oool01`09jPX0103oool02NX:00WZ2P09jPX20?ooo`802NX:00<0
oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0400WZ2P050?ooo`09jPX0oooo00WZ2P3oool0
5009jPX01@3oool02NX:00WZ2P09jPX0oooo00H02NX:00<0oooo00WZ2P09jPX00P09jPX0103oool0
2NX:00WZ2P3oool700WZ2P030?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX01@09jPX20?oo
o`0300WZ2P3oool02NX:00802NX:0`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo
00@0oooo0`09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX0103o
ool01@09jPX0oooo0?ooo`3oool02NX:00T0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0540oooo0P09
jPX01P3oool02NX:00WZ2P09jPX0oooo00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ
2P030?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P3oool01P09jPX01`3oool02NX:00WZ2P09jPX0
oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00@02NX:00D0
oooo00WZ2P3oool02NX:0?ooo`0500WZ2P030?ooo`09jPX02NX:00P02NX:00T0oooo00WZ2P09jPX0
2NX:0?ooo`09jPX0oooo00WZ2P3oool02`09jPX0103oool02NX:00WZ2P3oool400WZ2P040?ooo`09
jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0200WZ2P80oooo
00<02NX:0?ooo`09jPX00P09jPX30?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool0
103oool300WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:00WZ2P040?oo
o`0500WZ2P3oool0oooo0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo01<0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0D@3oool200WZ
2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0P3oool01009jPX0oooo00WZ2P3oool200WZ2P040?oo
o`09jPX02NX:0?ooo`@02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0400WZ2P070?ooo`09jPX02NX:
00WZ2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01009
jPX01@3oool02NX:0?ooo`09jPX0oooo00D02NX:00<0oooo00WZ2P09jPX02009jPX02@3oool02NX:
00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`0700WZ2P030?ooo`09jPX02NX:00T02NX:00@0oooo
00WZ2P09jPX0oooo2@09jPX00`3oool02NX:0?ooo`0200WZ2P80oooo00D02NX:0?ooo`09jPX0oooo
00WZ2P030?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool0103oool300WZ2P060?oo
o`09jPX02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:00WZ2P040?ooo`0500WZ2P3oool0oooo
0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01<0oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0DP3oool00`09jPX0oooo00WZ2P0200WZ
2P080?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`@0
2NX:00D0oooo00WZ2P3oool02NX:0?ooo`0400WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?oo
o`0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:0?oo
o`09jPX0oooo00D02NX:00<0oooo00WZ2P09jPX02009jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ
2P3oool02@09jPX00`3oool02NX:00WZ2P0:00WZ2P040?ooo`09jPX02NX:0?ooo`P02NX:00D0oooo
00WZ2P09jPX0oooo00WZ2P020?ooo`D02NX:0`3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3o
ool0oooo00@0oooo0`09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P09
jPX0103oool01@09jPX0oooo0?ooo`3oool02NX:00T0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0580
oooo00<02NX:0?ooo`3oool00P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`@02NX:00@0oooo
00WZ2P09jPX0oooo0`09jPX0103oool02NX:00WZ2P3oool600WZ2P070?ooo`09jPX02NX:00WZ2P3o
ool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01009jPX01@3o
ool02NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo2P09jPX01`3oool02NX:0?oo
o`09jPX0oooo00WZ2P3oool01`09jPX00`3oool02NX:00WZ2P0800WZ2P050?ooo`09jPX02NX:00WZ
2P3oool00P09jPX00`3oool02NX:00WZ2P0600WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool4
00WZ2P<0oooo00<02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`040?ooo`<02NX:00H0oooo
00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00@0oooo00D02NX:0?ooo`3oool0
oooo00WZ2P090?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool04`3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1B0?ooo`802NX:00@0oooo00WZ2P09jPX0
oooo0P09jPX00`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3o
ool00P09jPX00`3oool02NX:00WZ2P0400WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`02
00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:0?ooo`09
jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo2P09jPX01@3oool02NX:0?ooo`09jPX0oooo00T0
2NX:00<0oooo00WZ2P09jPX02009jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ
2P09jPX01P09jPX00`3oool02NX:00WZ2P020?ooo`0300WZ2P3oool0oooo00@02NX:0`3oool00`09
jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo00@0oooo0`09jPX01P3oool02NX:00WZ2P3oool0
2NX:0?ooo`802NX:00<0oooo00WZ2P09jPX0103oool01@09jPX0oooo0?ooo`3oool02NX:00T0oooo
00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo0580oooo0P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09
jPX02NX:00@02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09
jPX02NX:00@02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00L02NX:00<0oooo00WZ2P09
jPX01009jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo2P09jPX0
0`3oool02NX:00WZ2P0900WZ2P030?ooo`09jPX0oooo00/02NX:00@0oooo00WZ2P09jPX0oooo0P09
jPX00`3oool02NX:00WZ2P0900WZ2P80oooo00<02NX:0?ooo`3oool01009jPX30?ooo`0300WZ2P3o
ool02NX:0080oooo00<02NX:0?ooo`3oool0103oool300WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0
oooo0P09jPX00`3oool02NX:00WZ2P040?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02@3oool00`09
jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01<0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0DP3oool200WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`02
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09
jPX02NX:00@02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00L02NX:00<0oooo00WZ2P09
jPX01009jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo2P09jPX0
0`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX02@09jPX0
0`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01009jPX2
0?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX30?ooo`0300WZ2P3oool02NX:0080oooo00<0
2NX:0?ooo`3oool0103oool300WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX00`3oool0
2NX:00WZ2P040?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`040?oo
o`0300WZ2P3oool0oooo01<0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool0DP3oool200WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX0
2NX:0?ooo`D02NX:00<0oooo00WZ2P3oool02@09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09
jPX02NX:00D02NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:
00@0oooo00WZ2P09jPX0oooo2`09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00@0
2NX:00<0oooo00WZ2P09jPX02@09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00T0
2NX:0P3oool01@09jPX0oooo0?ooo`09jPX0oooo00802NX:0`3oool01P09jPX0oooo00WZ2P09jPX0
oooo00WZ2PH0oooo0`09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P09
jPX0103oool01@09jPX0oooo0?ooo`3oool02NX:00T0oooo00<02NX:0?ooo`3oool01@3oool00`09
jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0580
oooo0P09jPX01P3oool02NX:00WZ2P09jPX0oooo00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?oo
o`0200WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX01009jPX0103oool02NX:00WZ
2P3oool500WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:
0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo2`09jPX00`3oool02NX:00WZ2P0300WZ
2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX02@09jPX00`3oool02NX:00WZ2P0400WZ
2P030?ooo`09jPX02NX:00H02NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`0400WZ2P3oool0
2NX:00WZ2P<0oooo00H02NX:0?ooo`09jPX02NX:0?ooo`09jPX60?ooo`<02NX:00H0oooo00WZ2P09
jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00@0oooo00D02NX:0?ooo`3oool0oooo00WZ
2P080?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`1C0?ooo`0300WZ2P3oool02NX:00802NX:00H0oooo
00WZ2P3oool0oooo00WZ2P3oool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo1@09jPX00`3oool02NX:00WZ
2P0500WZ2P030?ooo`09jPX02NX:00@02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P040?oo
o`09jPX02NX:0?ooo`P02NX:00@0oooo00WZ2P09jPX0oooo1@09jPX00`3oool02NX:00WZ2P0400WZ
2P030?ooo`09jPX02NX:00X02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:00WZ2P06
00WZ2P<0oooo00D02NX:0?ooo`3oool02NX:0?ooo`0200WZ2P<0oooo00D02NX:0?ooo`09jPX02NX:
0?ooo`0200WZ2PD0oooo0`09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ
2P09jPX0103oool01@09jPX0oooo0?ooo`3oool02NX:00P0oooo00<02NX:0?ooo`3oool01P3oool0
0`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
05<0oooo00<02NX:0?ooo`09jPX00P09jPX0203oool02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo
0P09jPX0103oool02NX:00WZ2P3oool600WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ
2P09jPX00`09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00@02NX:00D0oooo00WZ
2P3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`/02NX:00<0oooo00WZ2P09jPX02P09
jPX00`3oool02NX:00WZ2P0:00WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX01P09
jPX30?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX30?ooo`0500WZ2P3oool02NX:00WZ2P3o
ool00P09jPX50?ooo`<02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0
2NX:00@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P080?ooo`0300WZ2P3oool0oooo00H0oooo00<0
2NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1C
0?ooo`D02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool400WZ2P040?ooo`09jPX02NX:0?ooo`H0
2NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:
00D02NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00@0oooo
00WZ2P09jPX0oooo2`09jPX00`3oool02NX:00WZ2P0:00WZ2P030?ooo`09jPX02NX:01X02NX:0`3o
ool01@09jPX0oooo0?ooo`09jPX0oooo00<02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo0080
2NX:1@3oool300WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX00`3oool02NX:00WZ2P04
0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0203oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3o
ool0oooo0180oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0D`3oool8
00WZ2P030?ooo`09jPX0oooo00@02NX:00@0oooo00WZ2P09jPX0oooo1009jPX01@3oool02NX:0?oo
o`09jPX0oooo00D02NX:00@0oooo00WZ2P09jPX02NX:0P3oool600WZ2P030?ooo`09jPX02NX:00@0
2NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`/02NX:00<0oooo
00WZ2P09jPX09`09jPX30?ooo`0500WZ2P3oool0oooo00WZ2P3oool00`09jPX20?ooo`0500WZ2P3o
ool02NX:00WZ2P3oool00P09jPX60?ooo`802NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:
0?ooo`<02NX:103oool01@09jPX0oooo0?ooo`3oool02NX:00P0oooo00<02NX:0?ooo`3oool01P3o
ool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo05<0oooo2009jPX00`3oool02NX:00WZ2P0400WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00D0
oooo00WZ2P3oool02NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:00WZ2P80oooo1P09jPX00`3oool0
2NX:00WZ2P0400WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0J00WZ
2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ2P09jPX04009jPX30?ooo`0300WZ2P3oool0oooo
00<02NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00H0oooo0P09
jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0`09jPX40?ooo`0500WZ2P3oool0oooo
0?ooo`09jPX0203oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0180oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0D`3oool600WZ2P030?ooo`09jPX0oooo
00802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo
00WZ2P3oool01@09jPX0103oool02NX:00WZ2P09jPX20?ooo`@02NX:00@0oooo00WZ2P09jPX0oooo
1@09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool0
2NX:00WZ2P0D00WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ2P09jPX04009jPX40?ooo`03
00WZ2P3oool02NX:00802NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0
2NX:00H0oooo0P09jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0`09jPX40?ooo`05
00WZ2P3oool0oooo0?ooo`09jPX0203oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo
0180oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0E03oool500WZ2P03
0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo1@09jPX00`3oool02NX:0?ooo`0200WZ
2P80oooo1@09jPX00`3oool02NX:00WZ2P0200WZ2P80oooo1009jPX0103oool02NX:00WZ2P3oool5
00WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09
jPX02NX:01@02NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P0;00WZ2P040?ooo`09
jPX0oooo00WZ2P@0oooo00<02NX:0?ooo`09jPX00P09jPX01P3oool02NX:0?ooo`3oool02NX:0?oo
o`802NX:00<0oooo00WZ2P09jPX01P3oool200WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ
2P3oool300WZ2P@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P080?ooo`0300WZ2P3oool0oooo00L0
oooo00<02NX:0?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`1D0?ooo`D02NX:00H0oooo00WZ2P3oool0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:
00<02NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`D02NX:00<0oooo00WZ2P09jPX00P09jPX20?oo
o`@02NX:00@0oooo00WZ2P09jPX0oooo1@09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00<0
oooo00WZ2P09jPX00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00H02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool01P09jPX00`3oool0
2NX:00WZ2P0700WZ2P030?ooo`09jPX02NX:00D02NX:103oool00`09jPX0oooo00WZ2P0200WZ2P03
0?ooo`09jPX0oooo0080oooo0`09jPX00`3oool02NX:00WZ2P060?ooo`802NX:00P0oooo00WZ2P09
jPX0oooo00WZ2P3oool02NX:0?ooo`<02NX:103oool01@09jPX0oooo0?ooo`3oool02NX:00P0oooo
00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo05@0oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo
00D02NX:0?ooo`09jPX02NX:0?ooo`0500WZ2P030?ooo`09jPX0oooo00802NX:0P3oool500WZ2P03
0?ooo`09jPX02NX:00802NX:0P3oool400WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:00D0oooo00WZ
2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX02009jPX0
1@3oool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?oo
o`0600WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P3oool01`09jPX40?ooo`0300WZ2P3o
ool02NX:00802NX:00<0oooo00WZ2P3oool00P3oool300WZ2P030?ooo`09jPX02NX:00H0oooo0P09
jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo0`09jPX40?ooo`0500WZ2P3oool0oooo
0?ooo`09jPX0203oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0140oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0E03oool200WZ2P040?ooo`09jPX02NX:
0?ooo`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00802NX:00<0
oooo00WZ2P09jPX00P3oool500WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0400WZ2P04
0?ooo`09jPX02NX:0?ooo`D02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX0
2NX:0?ooo`802NX:00<0oooo00WZ2P09jPX02009jPX02@3oool02NX:00WZ2P09jPX0oooo00WZ2P3o
ool02NX:0?ooo`0E00WZ2P030?ooo`09jPX0oooo00L02NX:103oool00`09jPX0oooo00WZ2P0400WZ
2P<0oooo0`09jPX00`3oool02NX:00WZ2P060?ooo`802NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3o
ool02NX:0?ooo`<02NX:103oool01@09jPX0oooo0?ooo`3oool02NX:00P0oooo00<02NX:0?ooo`3o
ool01`3oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo05@0oooo0P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX0oooo00@02NX:
00@0oooo00WZ2P09jPX0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00D02NX:00L0oooo00WZ
2P09jPX02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ
2P0300WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool=00WZ2P07
0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0D00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo
00WZ2P09jPX01@09jPX40?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX30?ooo`<02NX:00<0
oooo00WZ2P09jPX01P3oool200WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ
2P@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P080?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:
0?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1D0?oo
o`802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:0?ooo`0400WZ2P040?ooo`09jPX02NX:
0?ooo`H02NX:00<0oooo00WZ2P09jPX00`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool0
0P09jPX00`3oool02NX:0?ooo`0200WZ2P0;0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX0
oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool=00WZ2P070?ooo`09jPX0oooo00WZ2P3o
ool02NX:0?ooo`0A00WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00<0oooo00WZ2P09jPX01@09jPX4
0?ooo`0500WZ2P3oool0oooo00WZ2P3oool00P09jPX30?ooo`<02NX:00<0oooo00WZ2P09jPX01P3o
ool00`09jPX0oooo00WZ2P0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX50?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX0203oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0140
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0E03oool200WZ2P070?oo
o`09jPX02NX:00WZ2P3oool02NX:0?ooo`0600WZ2P040?ooo`09jPX02NX:0?ooo`H02NX:00<0oooo
00WZ2P09jPX00`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:
0?ooo`0200WZ2P0;0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09
jPX0103oool02NX:00WZ2P3oool=00WZ2P030?ooo`09jPX0oooo01P02NX:00<0oooo00WZ2P09jPX0
0P09jPX00`3oool02NX:00WZ2P0500WZ2P@0oooo00D02NX:0?ooo`3oool02NX:0?ooo`0200WZ2P<0
oooo0`09jPX00`3oool02NX:00WZ2P060?ooo`0300WZ2P3oool02NX:00802NX:00D0oooo00WZ2P3o
ool02NX:0?ooo`0200WZ2PD0oooo00D02NX:0?ooo`3oool0oooo00WZ2P080?ooo`0300WZ2P3oool0
oooo00L0oooo00<02NX:0?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`1D0?ooo`802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:00D0
oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00@02NX:00@0oooo00WZ2P09jPX0
oooo0P09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P02
00WZ2P0;0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool00P09jPX0103o
ool02NX:00WZ2P3oool=00WZ2P030?ooo`09jPX02NX:01P02NX:00<0oooo00WZ2P09jPX00`09jPX0
0`3oool02NX:00WZ2P0400WZ2P@0oooo00D02NX:0?ooo`3oool02NX:0?ooo`0200WZ2P<0oooo00@0
2NX:0?ooo`09jPX0oooo0P09jPX60?ooo`0300WZ2P3oool02NX:00802NX:00D0oooo00WZ2P3oool0
2NX:0?ooo`0200WZ2PD0oooo00D02NX:0?ooo`3oool0oooo00WZ2P080?ooo`0300WZ2P3oool0oooo
00L0oooo00<02NX:0?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`1D0?ooo`802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:00D0oooo
00WZ2P09jPX02NX:0?ooo`0700WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo
1@09jPX0103oool02NX:00WZ2P3oool400WZ2P0;0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`09
jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool400WZ2P030?ooo`09jPX02NX:00l0
2NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:0080
2NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0400WZ2P@0oooo00D02NX:0?ooo`3o
ool02NX:0?ooo`0200WZ2P<0oooo00@02NX:0?ooo`09jPX0oooo0P09jPX60?ooo`0300WZ2P3oool0
2NX:00802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2PD0oooo00D02NX:0?ooo`3oool0oooo
00WZ2P080?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0403oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1D0?ooo`<02NX:00D0oooo00WZ2P09jPX0oooo
00WZ2P020?ooo`0500WZ2P3oool02NX:00WZ2P3oool01@09jPX0203oool02NX:00WZ2P3oool02NX:
0?ooo`09jPX0oooo0`09jPX00`3oool02NX:00WZ2P0300WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:
00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09
jPX0oooo1009jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00l02NX:00<0oooo00WZ
2P09jPX02009jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ
2P3oool00P3oool00`09jPX0oooo0?ooo`0400WZ2P<0oooo00@02NX:0?ooo`09jPX0oooo0P09jPX6
0?ooo`0300WZ2P3oool02NX:00802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2PD0oooo00D0
2NX:0?ooo`3oool0oooo00WZ2P080?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0
403oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1D0?ooo`<02NX:00D0
oooo00WZ2P09jPX0oooo00WZ2P020?ooo`0500WZ2P3oool02NX:00WZ2P3oool01@09jPX00`3oool0
2NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00`09jPX0103oool0
2NX:00WZ2P3oool400WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`02
00WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?oo
o`0400WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P09jPX02009jPX00`3oool02NX:00WZ
2P0300WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P3oool00`3oool00`09jPX0oooo00WZ
2P0400WZ2P80oooo00@02NX:0?ooo`09jPX0oooo0P09jPX60?ooo`0300WZ2P3oool02NX:00802NX:
00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2PD0oooo00D02NX:0?ooo`3oool0oooo00WZ2P080?oo
o`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0403oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`1D0?ooo`<02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool0
2NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool0
2NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX01@09jPX01@3oool0
2NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool4
00WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P08
00WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P05
00WZ2P030?ooo`09jPX0oooo00<0oooo00<02NX:0?ooo`09jPX01009jPX20?ooo`0400WZ2P3oool0
2NX:0?ooo`802NX:1P3oool500WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX50?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX0203oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0100
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0D`3oool01@09jPX0oooo
00WZ2P09jPX0oooo00D02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P060?ooo`09jPX02NX:
0?ooo`09jPX0oooo0P09jPX20?ooo`H02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0700WZ2P050?oo
o`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?oo
o`@02NX:00<0oooo00WZ2P09jPX05009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:
00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:
00@0oooo00<02NX:0?ooo`09jPX00P09jPX0203oool02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo
0P09jPX60?ooo`D02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2PD0oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P080?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0403oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1C0?ooo`0500WZ2P3oool02NX:00WZ
2P3oool01@09jPX00`3oool02NX:0?ooo`0400WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo
00WZ2P09jPX00P3oool600WZ2P050?ooo`09jPX02NX:00WZ2P3oool01`09jPX01@3oool02NX:00WZ
2P09jPX0oooo00<02NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool400WZ2P03
0?ooo`09jPX02NX:01@02NX:00<0oooo00WZ2P09jPX02@09jPX00`3oool02NX:00WZ2P0200WZ2P03
0?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX0103oool00`09jPX0oooo00WZ2P0200WZ2P08
0?ooo`09jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool200WZ2PH0oooo1@09jPX01@3oool02NX:0?oo
o`09jPX0oooo00802NX:1@3oool01@09jPX0oooo0?ooo`3oool02NX:00P0oooo00<02NX:0?ooo`3o
ool0203oool00`09jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo05<0oooo00D02NX:0?ooo`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00H0
2NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`H02NX:00D0oooo00WZ
2P09jPX02NX:0?ooo`0700WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:0?oo
o`0200WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00@0oooo00WZ2P09jPX0oooo4`09jPX00`3oool0
2NX:00WZ2P0600WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:00<0oooo00WZ2P3oool00`09jPX00`3o
ool02NX:00WZ2P040?ooo`0300WZ2P3oool02NX:00802NX:00L0oooo00WZ2P3oool0oooo00WZ2P3o
ool02NX:0080oooo00<02NX:0?ooo`3oool0103oool500WZ2P050?ooo`09jPX0oooo00WZ2P3oool0
0P09jPX40?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo
0?ooo`080?ooo`0300WZ2P3oool0oooo0100oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
00000?ooo`3oool0D`3oool01@09jPX0oooo0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool0
1P09jPX0103oool02NX:00WZ2P3oool600WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09
jPX00P09jPX00`3oool02NX:00WZ2P0500WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3o
ool02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00<0oooo00WZ2P09jPX03`09jPX0
0`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0oooo1@09
jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00@0oooo00<02NX:0?ooo`09jPX00P09
jPX01`3oool02NX:0?ooo`3oool02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`040?ooo`D0
2NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P@0oooo00<02NX:0?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0403oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1C0?ooo`0300WZ2P3oool0oooo0080
2NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09
jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX00P09
jPX00`3oool02NX:00WZ2P0500WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:
0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool0
2NX:00WZ2P0>00WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0oooo1`09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00802NX:103oool00`09jPX0oooo00WZ2P0200WZ2P060?ooo`09jPX0
oooo0?ooo`09jPX0oooo0P09jPX00`3oool02NX:0?ooo`050?ooo`D02NX:00D0oooo00WZ2P3oool0
2NX:0?ooo`0200WZ2P@0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`050?ooo`03
00WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`1C0?ooo`0300WZ2P3oool0oooo00802NX:00D0oooo00WZ2P09jPX0
oooo00WZ2P020?ooo`0300WZ2P3oool02NX:00802NX:00@0oooo00WZ2P09jPX0oooo1P09jPX00`3o
ool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:0P3oool600WZ2P050?ooo`09jPX02NX:
00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00<0
oooo00WZ2P09jPX07P09jPX00`3oool02NX:0?ooo`0700WZ2P050?ooo`09jPX02NX:00WZ2P3oool0
0P09jPX40?ooo`0300WZ2P3oool02NX:00@02NX:0P3oool01P09jPX0oooo00WZ2P09jPX0oooo00WZ
2PH0oooo1@09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:103oool00`09jPX0oooo0?ooo`02
0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0?
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo05<0oooo00<02NX:0?oo
o`3oool00P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo
00WZ2P09jPX02009jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:0P3oool6
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09
jPX02NX:0?ooo`@02NX:00<0oooo00WZ2P09jPX02@09jPX01@3oool02NX:00WZ2P09jPX0oooo0100
2NX:00<0oooo00WZ2P09jPX02`09jPX00`3oool02NX:00WZ2P040?ooo`0300WZ2P3oool02NX:00@0
2NX:0P3oool01P09jPX0oooo00WZ2P09jPX0oooo00WZ2PH0oooo1@09jPX01@3oool02NX:0?ooo`09
jPX0oooo00802NX:103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00D0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo05<0oooo00<02NX:0?ooo`3oool00P09jPX00`3oool02NX:00WZ2P03
00WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:0?ooo`05
00WZ2P030?ooo`09jPX02NX:00802NX:0P3oool600WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09
jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00<0oooo00WZ2P09jPX0
2@09jPX01@3oool02NX:00WZ2P09jPX0oooo01002NX:00<0oooo00WZ2P09jPX02P09jPX01@3oool0
2NX:00WZ2P3oool02NX:00<0oooo00<02NX:0?ooo`09jPX01009jPX20?ooo`0600WZ2P3oool02NX:
00WZ2P3oool02NX:1P3oool500WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX40?ooo`0300WZ
2P3oool0oooo0080oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00l0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0D`3o
ool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`D02NX:00<0oooo00WZ2P3oool00P09jPX00`3oool0
2NX:00WZ2P0300WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo0P09jPX0103oool02NX:00WZ2P3o
ool400WZ2P80oooo1P09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P3oool0
0P09jPX0103oool02NX:00WZ2P3oool@00WZ2P050?ooo`09jPX02NX:00WZ2P3oool05P09jPX00`3o
ool02NX:00WZ2P0400WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0103oool01009jPX0oooo00WZ2P3o
ool200WZ2P80oooo00H02NX:0?ooo`09jPX02NX:0?ooo`09jPX60?ooo`D02NX:00D0oooo00WZ2P3o
ool02NX:0?ooo`0200WZ2P@0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`050?oo
o`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool03`3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`1B0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`09
jPX00P09jPX01@3oool02NX:0?ooo`09jPX0oooo00D02NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3o
ool200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo
00H02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo
00WZ2P09jPX0oooo4009jPX00`3oool02NX:0?ooo`0K00WZ2P050?ooo`09jPX02NX:00WZ2P3oool0
0P09jPX00`3oool02NX:0?ooo`030?ooo`0300WZ2P3oool02NX:00<02NX:0`3oool300WZ2P030?oo
o`09jPX02NX:00D0oooo1@09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:103oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0
oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0580oooo
00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX0oooo00H02NX:
00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool00`09jPX01`3o
ool02NX:00WZ2P09jPX0oooo00WZ2P3oool01P09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:
00<0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool700WZ2P030?ooo`09jPX02NX:0080
2NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX03@09jPX0
0`3oool02NX:00WZ2P0500WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:0?oo
o`030?ooo`0300WZ2P3oool02NX:00@02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00D0oooo1@09
jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ
2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0?0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0580oooo00<02NX:0?ooo`3oool00P3o
ool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0oooo1P09jPX00`3oool02NX:00WZ2P0300WZ2P06
0?ooo`09jPX02NX:0?ooo`09jPX0oooo0`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool0
1P09jPX01@3oool02NX:00WZ2P09jPX0oooo00D02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3o
ool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01`09jPX00`3o
ool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00<02NX:00@0oooo00WZ2P09jPX0oooo1`09jPX0
0`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00@0oooo00<02NX:0?ooo`09jPX01009jPX2
0?ooo`<02NX:00<0oooo00WZ2P09jPX01@3oool500WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09
jPX40?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00l0oooo00<000000?ooo`3oool01@3oool000L0oooo00<00000
0?ooo`3oool0DP3oool00`09jPX0oooo0?ooo`020?ooo`802NX:00D0oooo00WZ2P09jPX0oooo00WZ
2P020?ooo`0300WZ2P3oool02NX:00802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ
2P020?ooo`@02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00H02NX:00D0oooo00WZ2P09
jPX02NX:0?ooo`0500WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01@09jPX0
0`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ2P09jPX01@09jPX0
0`3oool02NX:00WZ2P0600WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:00WZ
2P0300WZ2P030?ooo`09jPX02NX:00@0oooo00<02NX:0?ooo`09jPX01009jPX20?ooo`<02NX:00<0
oooo00WZ2P09jPX01@3oool500WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX40?ooo`0300WZ
2P3oool0oooo0080oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00l0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0DP3o
ool00`09jPX0oooo0?ooo`020?ooo`802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`0300WZ
2P3oool02NX:00802NX:00<0oooo00WZ2P09jPX01P09jPX20?ooo`@02NX:00<0oooo00WZ2P09jPX0
0`09jPX00`3oool02NX:00WZ2P0400WZ2P050?ooo`09jPX02NX:00WZ2P3oool01@09jPX0103oool0
2NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00X02NX:00<0oooo00WZ2P3oool01P09jPX00`3o
ool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ2P09jPX02`09jPX00`3o
ool02NX:00WZ2P040?ooo`0300WZ2P3oool02NX:00@02NX:0P3oool300WZ2P030?ooo`09jPX02NX:
00D0oooo1@09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:103oool00`09jPX0oooo0?ooo`02
0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0>
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0580oooo00<02NX:0?oo
o`3oool00P3oool200WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P3oool00P09jPX00`3o
ool02NX:00WZ2P0800WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P09jPX01009jPX00`3o
ool02NX:00WZ2P0700WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX02P09jPX0
0`3oool02NX:00WZ2P0900WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01009jPX0
1@3oool02NX:00WZ2P09jPX0oooo00/02NX:00<0oooo00WZ2P09jPX0103oool00`09jPX0oooo00WZ
2P0400WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P050?ooo`D02NX:00D0oooo00WZ2P3oool02NX:
0?ooo`0200WZ2P@0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`1B0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`09jPX01009
jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P09jPX01009
jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool02`09jPX0103oool02NX:
00WZ2P3oool200WZ2P030?ooo`09jPX02NX:01`02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool0
2NX:00WZ2P0900WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX40?ooo`0300WZ2P3oool02NX:
00802NX:00@0oooo00WZ2P3oool0oooo0`09jPX00`3oool02NX:00WZ2P050?ooo`D02NX:00D0oooo
00WZ2P3oool02NX:0?ooo`0200WZ2P@0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?oo
o`050?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool03P3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`1B0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:
0?ooo`09jPX01009jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo
00WZ2P09jPX01009jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool02`09
jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:02802NX:00<0oooo00WZ2P09jPX0
2@09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX0oooo0080oooo00<02NX:0?ooo`09
jPX00P09jPX0103oool02NX:0?ooo`3oool300WZ2P030?ooo`09jPX02NX:00D0oooo1@09jPX01@3o
ool02NX:0?ooo`09jPX0oooo00802NX:103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0
oooo00D0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0>0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo0540oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo00WZ2P0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool02009jPX00`3oool02NX:00WZ2P02
00WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX00P09jPX01P3oool02NX:00WZ2P3o
ool02NX:0?ooo`/02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0Y00WZ2P03
0?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:0?ooo`020?oo
o`0300WZ2P3oool02NX:00@02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00D0oooo1@09jPX00`3o
ool02NX:00WZ2P020?ooo`802NX:103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo
00D0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo0540oooo00<02NX:0?ooo`3oool0103oool200WZ2P06
0?ooo`09jPX02NX:0?ooo`09jPX0oooo2P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`D02NX:
00<0oooo00WZ2P09jPX00P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`/02NX:00@0oooo00WZ
2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0=00WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo
00WZ2P09jPX03P09jPX00`3oool02NX:00WZ2P0200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0
oooo00WZ2P3oool00`3oool600WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P060?ooo`0400WZ2P3o
ool02NX:00WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX40?ooo`0300WZ2P3oool0oooo0080oooo
00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00h0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0D@3oool00`09jPX0oooo0?oo
o`040?ooo`802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool600WZ2P070?ooo`09jPX02NX:00WZ
2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX00P09jPX0
1P3oool02NX:00WZ2P3oool02NX:0?ooo`/02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool0
2NX:00WZ2P0=00WZ2P030?ooo`09jPX02NX:01h02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3o
ool02NX:0?ooo`030?ooo`H02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00H0oooo00@02NX:0?oo
o`09jPX02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P@0oooo00<02NX:0?ooo`3oool00P3oool0
0`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool03P3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1A0?ooo`0300WZ2P3oool0oooo
00@0oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX00P09jPX0
1`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0300WZ2P030?oo
o`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0600WZ2P040?oo
o`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX02P09jPX0103oool02NX:00WZ2P3oool900WZ
2P030?ooo`09jPX02NX:00d02NX:00<0oooo00WZ2P09jPX01009jPX0103oool02NX:00WZ2P3oool2
00WZ2P030?ooo`09jPX0oooo00<0oooo0P09jPX0103oool02NX:00WZ2P09jPX20?ooo`<02NX:00<0
oooo00WZ2P09jPX01P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:
103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo0540oooo00<02NX:0?ooo`3oool0103oool200WZ2P030?ooo`09jPX02NX:00802NX:0P3o
ool00`09jPX0oooo00WZ2P0200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0
oooo0P09jPX0103oool02NX:00WZ2P3oool400WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ
2P09jPX01P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:01L02NX:00<0oooo
00WZ2P09jPX02@09jPX01@3oool02NX:00WZ2P09jPX0oooo00H02NX:00@0oooo00WZ2P09jPX0oooo
0P09jPX00`3oool02NX:0?ooo`030?ooo`802NX:00@0oooo00WZ2P09jPX02NX:0P3oool01009jPX0
oooo00WZ2P3oool200WZ2PH0oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo0?ooo`02
00WZ2P@0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0
oooo00`0oooo00<02NX:0?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`1A0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`09jPX01009jPX00`3o
ool02NX:0?ooo`0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00H0oooo00WZ2P09jPX0oooo00WZ
2P3oool300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:
00WZ2P0600WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX04@09jPX00`3oool0
2NX:00WZ2P0A00WZ2P030?ooo`09jPX0oooo00D02NX:0`3oool300WZ2P030?ooo`09jPX02NX:00@0
oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX60?oo
o`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX40?ooo`0300WZ2P3oool0
oooo0080oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0
oooo00d0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0D@3oool00`09
jPX0oooo0?ooo`050?ooo`0300WZ2P3oool02NX:00@02NX:00<0oooo00WZ2P3oool00P09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool300WZ2P030?oo
o`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0600WZ2P040?oo
o`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX09`09jPX0103oool02NX:00WZ2P3oool200WZ
2P<0oooo0`09jPX00`3oool02NX:00WZ2P040?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX01@3o
ool02NX:0?ooo`09jPX0oooo00802NX:1P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3o
ool0oooo00802NX:103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00D0oooo00<0
2NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo0540oooo00<02NX:0?ooo`3oool01@3oool500WZ2P050?ooo`09jPX0
oooo00WZ2P3oool00P09jPX01@3oool02NX:00WZ2P09jPX0oooo00D02NX:0P3oool400WZ2P030?oo
o`09jPX02NX:00802NX:0P3oool600WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0
oooo0P09jPX00`3oool02NX:00WZ2P0300WZ2P040?ooo`09jPX02NX:0?ooob<02NX:00<0oooo00WZ
2P09jPX00`3oool300WZ2P030?ooo`09jPX02NX:00@0oooo00<02NX:0?ooo`09jPX01009jPX01@3o
ool02NX:0?ooo`09jPX0oooo00802NX:1P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3o
ool0oooo00802NX:103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo0540oooo00<02NX:0?ooo`3oool01@3oool200WZ2P080?ooo`09jPX0
2NX:0?ooo`09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00L02NX:0P3oool400WZ2P03
0?ooo`09jPX02NX:00802NX:0P3oool600WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P09
jPX0oooo0P09jPX00`3oool02NX:00WZ2P0300WZ2P040?ooo`09jPX02NX:0?ooob<02NX:00<0oooo
00WZ2P09jPX00`3oool300WZ2P030?ooo`09jPX02NX:00@0oooo00<02NX:0?ooo`09jPX01009jPX0
1@3oool02NX:0?ooo`09jPX0oooo00802NX:1P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ
2P3oool0oooo00802NX:103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo
00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo0500oooo00<02NX:0?ooo`3oool01P3oool200WZ2P060?ooo`09
jPX02NX:0?ooo`09jPX0oooo3`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:0080
2NX:0P3oool600WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3o
ool02NX:00WZ2P0300WZ2P040?ooo`09jPX02NX:0?oooaH02NX:00<0oooo00WZ2P09jPX02P09jPX0
0`3oool02NX:00WZ2P030?ooo`802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P030?ooo`0300WZ2P3o
ool02NX:00@02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2PH0oooo00@02NX:0?ooo`09jPX0
2NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P@0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool03@3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1@0?ooo`0300WZ2P3oool0oooo00H0oooo
0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`X02NX:00<0oooo00WZ2P09jPX00P09jPX00`3o
ool02NX:00WZ2P0200WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0600WZ2P030?ooo`09
jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0300WZ2P040?oo
o`09jPX02NX:0?ooo`H02NX:00<0oooo00WZ2P09jPX03@09jPX00`3oool02NX:00WZ2P0600WZ2P03
0?ooo`09jPX02NX:00@02NX:0`3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool00`09
jPX0oooo00WZ2P0400WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX60?ooo`0400WZ2P3oool0
2NX:00WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX40?ooo`0300WZ2P3oool0oooo0080oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00d0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0D03oool00`09jPX0oooo0?ooo`06
0?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`0300WZ2P3oool02NX:00802NX:00D0oooo
00WZ2P09jPX02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ2P3oool01P09
jPX00`3oool02NX:00WZ2P0600WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX0
0`09jPX01@3oool02NX:00WZ2P09jPX0oooo00X02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool0
2NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ2P09jPX01009jPX30?ooo`80
2NX:00D0oooo00WZ2P09jPX0oooo00WZ2P040?ooo`H02NX:00<0oooo00WZ2P3oool01009jPX60?oo
o`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX40?ooo`0300WZ2P3oool0
oooo0080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0
oooo00d0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0D03oool00`09
jPX0oooo0?ooo`070?ooo`0300WZ2P3oool02NX:00@02NX:00<0oooo00WZ2P3oool00`09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:0?ooo`06
00WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ
2P0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool02P09jPX00`3oool02NX:00WZ2P0A00WZ2P030?oo
o`09jPX02NX:00@02NX:0`3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0103oool600WZ2P80
oooo1@09jPX60?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P04
0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0>
0?ooo`0300WZ2P3oool0oooo00`0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool0D03oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool02NX:00@02NX:00<0oooo00WZ
2P3oool00`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX00`3oool02NX:00WZ
2P0800WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX01P09jPX0103oool02NX:00WZ
2P3oool200WZ2P030?ooo`09jPX0oooo00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0:00WZ2P03
0?ooo`09jPX02NX:00X02NX:00<0oooo00WZ2P09jPX03009jPX20?ooo`802NX:00D0oooo00WZ2P09
jPX0oooo00WZ2P040?ooo`H02NX:0P3oool500WZ2PH0oooo00@02NX:0?ooo`09jPX02NX:0P3oool0
1@09jPX0oooo0?ooo`3oool02NX:00@0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0303oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`1@0?ooo`0300WZ2P3oool0oooo00L0oooo1`09jPX0
0`3oool02NX:0?ooo`0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo
1P09jPX01@3oool02NX:00WZ2P09jPX0oooo00H02NX:00<0oooo00WZ2P09jPX01P09jPX0103oool0
2NX:00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00<02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09
jPX0oooo00P02NX:00<0oooo00WZ2P09jPX06@09jPX20?ooo`802NX:00D0oooo00WZ2P09jPX0oooo
00WZ2P040?ooo`802NX:00@0oooo00WZ2P09jPX02NX:0P3oool500WZ2PH0oooo00@02NX:0?ooo`09
jPX02NX:0P3oool01@09jPX0oooo0?ooo`3oool02NX:00@0oooo00<02NX:0?ooo`3oool00P3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0303oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1@0?ooo`0300WZ2P3oool0oooo
00L0oooo0P09jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo1P09jPX0103oool02NX:
00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool0
2NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX01@3o
ool02NX:0?ooo`09jPX0oooo00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool800WZ2P030?oo
o`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX04P09jPX30?ooo`@02NX:00<0oooo00WZ2P3oool0
0`3oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo1@09jPX60?ooo`0400WZ2P3oool02NX:00WZ
2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:
0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo00`0oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0D03oool00`09jPX0oooo0?ooo`070?oo
o`802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool800WZ2P040?ooo`09jPX02NX:0?ooo`802NX:
00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00@02NX:
00<0oooo00WZ2P09jPX01P09jPX0103oool02NX:00WZ2P3oool200WZ2P050?ooo`09jPX0oooo00WZ
2P3oool00P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`l02NX:00<0oooo00WZ2P09jPX04P09
jPX30?ooo`<02NX:00<0oooo00WZ2P09jPX0103oool200WZ2P040?ooo`09jPX02NX:00WZ2P80oooo
1@09jPX60?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?oo
o`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0>0?oo
o`0300WZ2P3oool0oooo00`0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool0D03oool00`09jPX0oooo0?ooo`070?ooo`802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool>
00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ
2P0400WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX01@3oool02NX:
0?ooo`09jPX0oooo00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool600WZ2P030?ooo`09jPX0
2NX:00<02NX:00<0oooo00WZ2P09jPX04`09jPX00`3oool02NX:0?ooo`020?ooo`<02NX:00<0oooo
00WZ2P09jPX0103oool200WZ2P030?ooo`09jPX02NX:00802NX:00H0oooo00WZ2P09jPX02NX:0?oo
o`09jPX60?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?oo
o`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0>0?oo
o`0300WZ2P3oool0oooo00`0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool0C`3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool02NX:00<02NX:00<0oooo00WZ2P09
jPX03009jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09
jPX01009jPX00`3oool02NX:00WZ2P0600WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00D0oooo00WZ
2P3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01009jPX0
0`3oool02NX:00WZ2P0B00WZ2P030?ooo`09jPX02NX:00<02NX:0P3oool01009jPX0oooo0?ooo`3o
ool200WZ2P040?ooo`09jPX02NX:00WZ2P@0oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P060?oo
o`09jPX02NX:00WZ2P3oool02NX:1P3oool01009jPX0oooo00WZ2P09jPX20?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX0103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo04l0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo00WZ2P03
00WZ2P80oooo3@09jPX20?ooo`@02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P04
00WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX01@3oool02NX:0?oo
o`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0400WZ2P030?oo
o`09jPX02NX:01802NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`0400WZ2P3oool0oooo0?ooo`80
2NX:00D0oooo00WZ2P09jPX0oooo00WZ2P030?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00802NX:1@3oool01009jPX0oooo00WZ2P09jPX20?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX0103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo
00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo04l0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo00WZ
2P0400WZ2P030?ooo`09jPX0oooo00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P030?oo
o`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0400WZ2P030?oo
o`09jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo
00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0O00WZ2P80oooo00@02NX:0?oo
o`3oool0oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo0P09jPX00`3oool02NX:00WZ
2P0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX50?ooo`0400WZ2P3oool02NX:00WZ2P80
oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?oo
o`3oool0103oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo00`0oooo00<000000?oo
o`3oool01@3oool000L0oooo00<000000?ooo`3oool0C`3oool00`09jPX0oooo0?ooo`090?ooo`L0
2NX:00<0oooo00WZ2P3oool00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ
2P09jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ
2P09jPX01P09jPX0103oool02NX:00WZ2P3oool200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09
jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:02002NX:00<0oooo00WZ2P3oool00P3o
ool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0103oool00`09jPX0oooo00WZ2P0300WZ2P050?oo
o`09jPX02NX:00WZ2P3oool00P09jPX50?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00D02NX:0?oo
o`3oool0oooo00WZ2P040?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0C`3oool00`09jPX0oooo0?ooo`090?ooo`802NX:00P0oooo00WZ
2P09jPX0oooo00WZ2P3oool02NX:0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P03
0?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX0103oool02NX:00WZ2P3oool300WZ
2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX01@3oool02NX:0?ooo`09
jPX0oooo00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09
jPX02NX:01P02NX:00<0oooo00WZ2P09jPX00P3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0
103oool00`09jPX0oooo00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX50?ooo`04
00WZ2P3oool02NX:00WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX01`3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0C`3oool00`09jPX0oooo0?ooo`09
0?ooo`802NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P09
jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09
jPX00P09jPX0103oool02NX:00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ
2P09jPX0oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00H0oooo00WZ2P09jPX0oooo
00WZ2P3oool400WZ2P040?ooo`09jPX02NX:0?ooo`d02NX:00<0oooo00WZ2P09jPX02P09jPX00`3o
ool02NX:00WZ2P020?ooo`802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P040?ooo`H02NX:00D0oooo
00WZ2P09jPX02NX:0?ooo`0200WZ2PD0oooo00@02NX:0?ooo`09jPX02NX:0P3oool01@09jPX0oooo
0?ooo`3oool02NX:00@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P070?ooo`0300WZ2P3oool0oooo
00l0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`1?0?ooo`0300WZ2P3oool0oooo00T0oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:
0?ooo`@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:
00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0400WZ2P050?ooo`09jPX02NX:00WZ2P3o
ool01009jPX0103oool02NX:00WZ2P3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool01@09jPX0
0`3oool02NX:0?ooo`0700WZ2P030?ooo`09jPX02NX:00/02NX:00<0oooo00WZ2P09jPX02P09jPX0
0`3oool02NX:00WZ2P020?ooo`802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P040?ooo`H02NX:00D0
oooo00WZ2P09jPX02NX:0?ooo`0200WZ2PD0oooo00@02NX:0?ooo`09jPX02NX:0P3oool01@09jPX0
oooo0?ooo`3oool02NX:00@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P070?ooo`0300WZ2P3oool0
oooo00l0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`1?0?ooo`0300WZ2P3oool0oooo00X0oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09
jPX0oooo00@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`T0
2NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:00@0oooo00WZ
2P09jPX0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00D02NX:00<0oooo00WZ2P09jPX01`09
jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P09jPX02@09
jPX00`3oool02NX:00WZ2P030?ooo`@02NX:00<0oooo00WZ2P3oool00`3oool200WZ2P050?ooo`09
jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P050?ooo`0400WZ2P3oool02NX:00WZ2P80
oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01`3oool0
0`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0C`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool02NX:
00<02NX:00<0oooo00WZ2P09jPX01P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX0
2NX:00L02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX00P09jPX0
103oool02NX:00WZ2P3oool600WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX00P09
jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P09jPX02@09
jPX20?ooo`0400WZ2P3oool0oooo0?ooo`@02NX:00<0oooo00WZ2P3oool00`3oool200WZ2P050?oo
o`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P050?ooo`0400WZ2P3oool02NX:00WZ
2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX30?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01`3o
ool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool01@3o
ool000L0oooo00<000000?ooo`3oool0CP3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
2NX:00@02NX:00<0oooo00WZ2P09jPX02`09jPX00`3oool02NX:00WZ2P0700WZ2P80oooo0`09jPX0
0`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo1P09
jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00h02NX:00<0oooo00WZ2P09jPX01@09
jPX00`3oool02NX:00WZ2P0700WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00`3oool200WZ2P040?oo
o`09jPX02NX:00WZ2P@0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ
2P09jPX01@3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3o
ool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool03`3o
ool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo04h0oooo00<02NX:0?ooo`3oool02`3oool700WZ2P030?ooo`09jPX0oooo00/02NX:00<0oooo
00WZ2P09jPX01P09jPX00`3oool02NX:0?ooo`0900WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo
00WZ2P09jPX0oooo1P09jPX00`3oool02NX:00WZ2P0A00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:
00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0700WZ2P050?ooo`09jPX0oooo0?ooo`09
jPX00`3oool200WZ2P040?ooo`09jPX02NX:00WZ2P@0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0
oooo00<02NX:00<0oooo00WZ2P09jPX01@3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3o
ool0oooo0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00D0oooo
00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo04h0oooo00<02NX:0?ooo`3oool02`3oool200WZ2P030?ooo`09
jPX02NX:00802NX:00<0oooo00WZ2P3oool02`09jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09
jPX0oooo00T02NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool600WZ2P030?oo
o`09jPX02NX:01402NX:00<0oooo00WZ2P09jPX02009jPX00`3oool02NX:00WZ2P0700WZ2P050?oo
o`09jPX0oooo0?ooo`09jPX00`3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool200WZ
2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX01@3oool01009jPX0oooo00WZ2P09jPX2
0?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3o
ool0oooo00@0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0:0?ooo`030000003o
ool0oooo00D0oooo00070?ooo`030000003oool0oooo04h0oooo00<02NX:0?ooo`3oool02`3oool2
00WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ2P050?ooo`09jPX02NX:00WZ
2P3oool00`09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo
00WZ2P09jPX01`09jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`H02NX:00<0
oooo00WZ2P09jPX04@09jPX00`3oool02NX:00WZ2P0B00WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0
0`3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool200WZ2P030?ooo`09jPX02NX:00<0
2NX:00<0oooo00WZ2P3oool00P09jPX50?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?oo
o`3oool0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0CP3oool00`09jPX0oooo0?ooo`0;0?ooo`802NX:00P0oooo00WZ
2P09jPX0oooo00WZ2P3oool02NX:0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P80
oooo1009jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P3o
ool00P09jPX0103oool02NX:00WZ2P3oool?00WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ
2P09jPX05@09jPX00`3oool02NX:00WZ2P020?ooo`802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P03
0?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:0?ooo`0200WZ2PD0oooo00@02NX:
0?ooo`09jPX02NX:0P3oool01009jPX0oooo0?ooo`3oool200WZ2P80oooo00<02NX:0?ooo`3oool0
0P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool0
2P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1>0?ooo`0300WZ2P3o
ool0oooo00`0oooo00L02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P09
jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09
jPX00P09jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09
jPX0oooo4009jPX00`3oool02NX:00WZ2P0K00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX2
0?ooo`802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P040?ooo`0300WZ2P3oool02NX:00<02NX:00@0
oooo00WZ2P09jPX0oooo0P09jPX50?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00@02NX:0?ooo`3o
ool0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0CP3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool02NX:00<0
2NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:0080
2NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00L0
2NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool@00WZ2P030?ooo`09jPX02NX:
01l02NX:00<0oooo00WZ2P09jPX00P3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0103oool0
0`09jPX0oooo00WZ2P0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:1@3oool01009jPX0oooo00WZ
2P09jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0:0?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04h0oooo00<02NX:0?ooo`3oool0
303oool00`09jPX0oooo00WZ2P0400WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool0
2NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool0
2NX:00WZ2P0700WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo2P09jPX00`3o
ool02NX:00WZ2P0300WZ2P030?ooo`09jPX0oooo01l02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ
2P050?ooo`09jPX02NX:0?ooo`09jPX0103oool00`09jPX0oooo00WZ2P0300WZ2P040?ooo`09jPX0
2NX:0?ooo`802NX:1@3oool01009jPX0oooo00WZ2P09jPX20?ooo`0400WZ2P3oool0oooo0?ooo`80
2NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool04@3oool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo04h0oooo00<02NX:0?ooo`3oool0303oool700WZ2P030?ooo`09jPX02NX:00D02NX:
00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:0080
2NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?oo
o`/02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0A00WZ2P030?ooo`09jPX02NX:
00/02NX:0P3oool01@09jPX0oooo0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P3oool00`3oool0
0`09jPX0oooo00WZ2P0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:1@3oool400WZ2P80oooo00@0
2NX:0?ooo`3oool0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool0C@3oool00`09jPX0oooo0?ooo`0=0?ooo`802NX:00<0
oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0800WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:
00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0700WZ2P050?ooo`09jPX02NX:00WZ2P3o
ool03`09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo01402NX:00<0oooo00WZ2P09
jPX02@09jPX01@3oool02NX:0?ooo`3oool02NX:00<0oooo1009jPX00`3oool02NX:0?ooo`030?oo
o`0300WZ2P3oool02NX:00<02NX:00<0oooo00WZ2P09jPX00`09jPX50?ooo`@02NX:0P3oool01009
jPX0oooo0?ooo`3oool200WZ2P80oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool02P3oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`1=0?ooo`0300WZ2P3oool0oooo00d0oooo0P09jPX0203o
ool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo2`09jPX00`3oool02NX:00WZ2P0200WZ2P030?oo
o`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01009jPX0103oool02NX:00WZ2P3oool300WZ2P03
0?ooo`09jPX02NX:00d02NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:0?ooo`0600WZ2P03
0?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX03P09jPX01@3oool02NX:0?ooo`3oool02NX:
00<0oooo0P09jPX0103oool02NX:0?ooo`09jPX40?ooo`0300WZ2P3oool02NX:00<02NX:00<0oooo
00WZ2P09jPX00`09jPX50?ooo`@02NX:0P3oool01009jPX0oooo0?ooo`3oool200WZ2P80oooo00<0
2NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0180oooo00<0
2NX:0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1=
0?ooo`0300WZ2P3oool0oooo00h0oooo00T02NX:0?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3o
ool02`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09
jPX01009jPX0103oool02NX:00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00d02NX:00<0oooo00WZ
2P3oool01009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ
2P09jPX03P09jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo0P09jPX01@3oool02NX:00WZ2P3o
ool02NX:00<0oooo00<02NX:0?ooo`09jPX00`09jPX00`3oool02NX:00WZ2P0300WZ2PD0oooo1009
jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`090?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04d0oooo00<02NX:0?ooo`3oool03P3o
ool02@09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:
00D02NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P0400WZ2P040?ooo`09jPX02NX:
0?ooo`<02NX:00<0oooo00WZ2P09jPX03@09jPX00`3oool02NX:0?ooo`0;00WZ2P030?ooo`09jPX0
2NX:00<02NX:00<0oooo00WZ2P09jPX03009jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0
oooo0080oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo1P09jPX00`3oool02NX:00WZ
2P0300WZ2PD0oooo1009jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3oool00`09jPX0oooo
0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo
0?ooo`090?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04d0oooo00<0
2NX:0?ooo`3oool03P3oool00`09jPX0oooo00WZ2P0300WZ2P030?ooo`09jPX02NX:00<02NX:00<0
oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX02NX:00@02NX:00@0
oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:00WZ2P0=00WZ2P030?ooo`09jPX0oooo00/02NX:
00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P0>00WZ2P030?ooo`09jPX02NX:0080oooo
0P09jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo1P09jPX00`3oool02NX:00WZ2P0300WZ2PD0
oooo1009jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`020?oo
o`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`090?oo
o`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04d0oooo00<02NX:0?ooo`3o
ool03P3oool600WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool0
2NX:00WZ2P09jPX0oooo00T02NX:00<0oooo00WZ2P09jPX01009jPX0103oool02NX:00WZ2P3oool3
00WZ2P030?ooo`09jPX02NX:00d02NX:00<0oooo00WZ2P3oool02`09jPX00`3oool02NX:00WZ2P07
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool02`09jPX00`3oool02NX:00WZ2P020?ooo`802NX:00D0
oooo00WZ2P09jPX0oooo00WZ2P030?ooo`802NX:00@0oooo00WZ2P09jPX0oooo1P09jPX50?ooo`@0
2NX:0P3oool01009jPX0oooo0?ooo`3oool200WZ2P80oooo00<02NX:0?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool02@3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1=0?ooo`0300WZ2P3oool0oooo00h0
oooo1P09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:00WZ2P09jPX0oooo
00T02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:
00d02NX:00<0oooo00WZ2P3oool05@09jPX01@3oool02NX:00WZ2P09jPX0oooo00/02NX:00<0oooo
00WZ2P09jPX00P3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0103oool01@09jPX0oooo00WZ
2P09jPX0oooo00H02NX:1@3oool400WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX20?ooo`03
00WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0B0?ooo`03
00WZ2P3oool0oooo00T0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
C@3oool00`09jPX0oooo0?ooo`0>0?ooo`802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:
00WZ2P0600WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:
00WZ2P0400WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX03@09jPX00`3oool02NX:
0?ooo`0200WZ2P030?ooo`09jPX02NX:01002NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0;00WZ2P80
oooo00<02NX:0?ooo`3oool00P09jPX01@3oool02NX:00WZ2P3oool02NX:00@0oooo00<02NX:0?oo
o`09jPX02009jPX50?ooo`@02NX:0P3oool01009jPX0oooo0?ooo`3oool200WZ2P80oooo00<02NX:
0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:
0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1=0?oo
o`0300WZ2P3oool0oooo00h0oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo
00D02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:
00@02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0=00WZ2P030?ooo`09jPX02NX:
00D02NX:00<0oooo00WZ2P09jPX03@09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:
00P02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0103oool0
0`09jPX0oooo00WZ2P0800WZ2PD0oooo1009jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3o
ool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool04P3o
ool00`09jPX0oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo04`0oooo00<02NX:0?ooo`3oool0403oool02@09jPX0oooo00WZ2P09jPX0oooo00WZ2P3oool0
2NX:0?ooo`0500WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool0
2NX:00WZ2P09jPX0oooo00H02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0900WZ
2P050?ooo`09jPX02NX:00WZ2P3oool01`09jPX00`3oool02NX:0?ooo`0=00WZ2P030?ooo`09jPX0
2NX:00/02NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:00802NX:00<0
oooo00WZ2P3oool00`3oool00`09jPX0oooo00WZ2P0800WZ2PD0oooo1009jPX20?ooo`0400WZ2P3o
ool0oooo0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo
00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo04`0oooo00<02NX:0?ooo`3oool0403oool02@09jPX0oooo00WZ
2P09jPX0oooo00WZ2P3oool02NX:0?ooo`0800WZ2P040?ooo`09jPX02NX:0?ooo`@02NX:00<0oooo
00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo
00WZ2P09jPX02@09jPX01@3oool02NX:00WZ2P09jPX0oooo00L02NX:00<0oooo00WZ2P3oool05`09
jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX0103o
ool02NX:0?ooo`09jPX40?ooo`0300WZ2P3oool02NX:00L02NX:00<0oooo00WZ2P3oool00`3oool4
00WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo0080oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00P0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0C03oool00`09jPX0oooo0?ooo`0@
0?ooo`0300WZ2P3oool02NX:00<02NX:00<0oooo00WZ2P3oool02009jPX0103oool02NX:00WZ2P3o
ool400WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ
2P0400WZ2P030?ooo`09jPX02NX:00T02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0700WZ2P030?oo
o`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX06009jPX00`3oool02NX:0?ooo`020?ooo`802NX:
00@0oooo00WZ2P3oool02NX:103oool00`09jPX0oooo00WZ2P0700WZ2P030?ooo`09jPX0oooo00<0
oooo1009jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3oool00`09jPX0oooo0?ooo`020?oo
o`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`080?oo
o`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04`0oooo00<02NX:0?ooo`3o
ool0403oool600WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool0
2NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool0
2NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX01009jPX0103oool0
2NX:00WZ2P3oool800WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX05P09jPX00`3o
ool02NX:0?ooo`020?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P030?ooo`0300WZ2P3oool0
2NX:00L02NX:00<0oooo00WZ2P3oool00`3oool400WZ2P80oooo00@02NX:0?ooo`3oool0oooo0P09
jPX20?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?oo
o`0C0?ooo`0300WZ2P3oool0oooo00P0oooo00<000000?ooo`3oool01@3oool000L0oooo00<00000
0?ooo`3oool0C03oool00`09jPX0oooo0?ooo`0@0?ooo`H02NX:00<0oooo00WZ2P09jPX00P09jPX0
0`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX0
0`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX00`09jPX0
0`3oool02NX:00WZ2P0400WZ2P040?ooo`09jPX02NX:0?ooo`P02NX:00<0oooo00WZ2P09jPX02P09
jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P09jPX00P3o
ool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool00`09jPX0oooo00WZ2P0600WZ2P030?oo
o`09jPX02NX:00@0oooo1009jPX20?ooo`0400WZ2P3oool0oooo0?ooo`802NX:0P3oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0
oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04`0oooo
00<02NX:0?ooo`3oool0403oool200WZ2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0800WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool0
2NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool0
2NX:00WZ2P0400WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3o
ool02NX:00WZ2P0B00WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P09jPX00P3oool200WZ
2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool00`09jPX0oooo00WZ2P0600WZ2P030?ooo`09jPX0
2NX:00@0oooo1@09jPX0103oool02NX:0?ooo`3oool300WZ2P80oooo00<02NX:0?ooo`3oool00P3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0203o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1<0?ooo`0300WZ2P3oool0
oooo0100oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009
jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:
00WZ2P0300WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:
00WZ2P0400WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P3oool00P09jPX00`3oool02NX:
00WZ2P0;00WZ2P030?ooo`09jPX02NX:00l02NX:00<0oooo00WZ2P09jPX00P3oool200WZ2P050?oo
o`09jPX02NX:0?ooo`09jPX00`3oool00`09jPX0oooo00WZ2P0600WZ2P030?ooo`09jPX02NX:00@0
oooo1@09jPX0103oool02NX:0?ooo`3oool300WZ2P80oooo00<02NX:0?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool0203oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1<0?ooo`0300WZ2P3oool0oooo0140
oooo1009jPX00`3oool02NX:0?ooo`0800WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX00`3o
ool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX01009jPX00`3o
ool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00/02NX:00<0oooo00WZ2P3oool00P09jPX00`3o
ool02NX:00WZ2P0;00WZ2P030?ooo`09jPX02NX:00T02NX:00<0oooo00WZ2P3oool00`09jPX20?oo
o`0300WZ2P3oool0oooo00802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P030?ooo`H02NX:00@0oooo
00WZ2P09jPX0oooo0P09jPX40?ooo`D02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX20?ooo`0300WZ
2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ
2P3oool0oooo00P0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0B`3o
ool00`09jPX0oooo0?ooo`0B0?ooo`@02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0600WZ2P050?oo
o`09jPX02NX:00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00X0
2NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0;00WZ2P030?ooo`09jPX0oooo0080
2NX:00<0oooo00WZ2P09jPX02`09jPX00`3oool02NX:00WZ2P0;00WZ2P040?ooo`09jPX02NX:00WZ
2P80oooo00<02NX:0?ooo`3oool00P09jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo1@09jPX0
1@3oool02NX:00WZ2P09jPX0oooo00802NX:103oool500WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:
0P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
503oool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo04/0oooo00<02NX:0?ooo`3oool04P3oool400WZ2P050?ooo`09jPX0oooo00WZ2P3oool0
1@09jPX00`3oool02NX:00WZ2P0<00WZ2P030?ooo`09jPX02NX:00X02NX:00<0oooo00WZ2P09jPX0
0`09jPX00`3oool02NX:00WZ2P0;00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX0
6`09jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:
00<0oooo1@09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:103oool500WZ2P040?ooo`09jPX0
2NX:0?ooo`<02NX:0P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00<0
2NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo04/0oooo00<02NX:0?ooo`3oool04P3oool600WZ2P030?ooo`09jPX0
oooo00/02NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P0:00WZ2P030?ooo`09jPX0
2NX:00<02NX:00<0oooo00WZ2P09jPX02`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0
2NX:01h02NX:00/0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P040?oo
o`@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P@0oooo1@09jPX0103oool02NX:00WZ2P3o
ool300WZ2P80oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3o
ool0oooo01D0oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`1;0?ooo`0300WZ2P3oool0oooo0180oooo1P09jPX00`3oool02NX:00WZ2P08
00WZ2P040?ooo`09jPX02NX:0?ooo`P02NX:00<0oooo00WZ2P09jPX02P09jPX00`3oool02NX:00WZ
2P0300WZ2P030?ooo`09jPX02NX:00/02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ
2P0>00WZ2P030?ooo`09jPX02NX:00d02NX:00/0oooo00WZ2P3oool0oooo00WZ2P3oool02NX:0?oo
o`09jPX0oooo00WZ2P040?ooo`@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P@0oooo1@09
jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04/0oooo00<02NX:0?ooo`3oool0
4P3oool200WZ2P050?ooo`09jPX02NX:00WZ2P3oool01@09jPX00`3oool02NX:00WZ2P0200WZ2P04
0?ooo`09jPX02NX:0?ooo`P02NX:00<0oooo00WZ2P09jPX02P09jPX00`3oool02NX:00WZ2P0300WZ
2P050?ooo`09jPX02NX:00WZ2P3oool02@09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0
2NX:00P02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0=00WZ2P030?ooo`09jPX0
oooo0080oooo0P09jPX0103oool02NX:0?ooo`09jPX40?ooo`@02NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0200WZ2P@0oooo1@09jPX01`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool00`09
jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool05@3oool00`09
jPX0oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04/0
oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ
2P3oool02009jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:00X02NX:00<0oooo00WZ
2P09jPX00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00H02NX:00@0oooo00WZ2P09jPX0oooo3@09
jPX00`3oool02NX:00WZ2P0:00WZ2P030?ooo`09jPX02NX:00@02NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0200WZ2P80oooo0P09jPX01@3oool02NX:0?ooo`3oool02NX:00<0oooo00<02NX:0?ooo`09
jPX01@09jPX00`3oool02NX:00WZ2P040?ooo`D02NX:00L0oooo00WZ2P09jPX0oooo00WZ2P3oool0
2NX:0080oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo01D0oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`1;0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`09jPX00`09jPX01@3o
ool02NX:00WZ2P09jPX0oooo00P02NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:00WZ2P09
jPX0oooo00`02NX:00<0oooo00WZ2P09jPX00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:
00<0oooo00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool500WZ2P030?ooo`09jPX02NX:00H0
2NX:00<0oooo00WZ2P09jPX01P09jPX20?ooo`<02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool0
2NX:00WZ2P020?ooo`802NX:00D0oooo00WZ2P3oool0oooo00WZ2P030?ooo`0300WZ2P3oool02NX:
00D02NX:00<0oooo00WZ2P09jPX0103oool500WZ2P070?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ
2P020?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`0E0?ooo`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<00000
0?ooo`3oool0B`3oool00`09jPX0oooo0?ooo`0B0?ooo`802NX:00H0oooo00WZ2P09jPX0oooo00WZ
2P3oool<00WZ2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0<00WZ2P03
0?ooo`09jPX02NX:00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo
00802NX:00@0oooo00WZ2P09jPX0oooo3P09jPX00`3oool02NX:00WZ2P0600WZ2P80oooo0P09jPX0
103oool02NX:00WZ2P3oool300WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX01@3oool02NX:00WZ
2P3oool02NX:00<0oooo00<02NX:0?ooo`09jPX02009jPX40?ooo`D02NX:00L0oooo00WZ2P09jPX0
oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?oo
o`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`1;0?ooo`0300WZ2P3oool0oooo0180oooo0P09jPX0203oool0
2NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo1P09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:
00D0oooo00WZ2P09jPX02NX:0?ooo`0<00WZ2P030?ooo`09jPX02NX:00<02NX:00D0oooo00WZ2P09
jPX02NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo00H02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0C
00WZ2P030?ooo`09jPX02NX:00L02NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P050?ooo`09jPX0
2NX:0?ooo`09jPX00`3oool00`09jPX0oooo00WZ2P0800WZ2P@0oooo1@09jPX01`3oool02NX:00WZ
2P3oool02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0
oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo04X0oooo00<02NX:0?ooo`3oool04`3oool700WZ2P030?oo
o`09jPX0oooo00H02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P050?ooo`09jPX02NX:00WZ
2P3oool03009jPX00`3oool02NX:00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX0
0`3oool02NX:0?ooo`0600WZ2P050?ooo`09jPX02NX:00WZ2P3oool04`09jPX00`3oool02NX:00WZ
2P0700WZ2P80oooo00<02NX:0?ooo`3oool00P09jPX01@3oool02NX:00WZ2P3oool02NX:00<0oooo
2`09jPX40?ooo`D02NX:00L0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?oo
o`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1:0?ooo`03
00WZ2P3oool0oooo01<0oooo0`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool01P09jPX0
1@3oool02NX:00WZ2P09jPX0oooo00@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0<00WZ2P030?oo
o`09jPX02NX:00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo00H0
2NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0C00WZ2P030?ooo`09jPX02NX:00L02NX:0P3oool00`09
jPX0oooo0?ooo`0200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool;00WZ2P@0oooo1@09jPX0
1`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04X0oooo00<02NX:0?ooo`3oool04`3o
ool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01`09jPX00`3oool02NX:00WZ2P0200WZ2P030?oo
o`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX03P09jPX00`3oool02NX:00WZ2P0300WZ2P050?oo
o`09jPX02NX:00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0600WZ2P050?ooo`09jPX02NX:00WZ
2P3oool03009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00P02NX:00@0oooo00WZ
2P3oool0oooo0P09jPX20?ooo`0300WZ2P3oool02NX:00<0oooo2`09jPX40?ooo`D02NX:00L0oooo
00WZ2P09jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1:0?ooo`0300WZ2P3oool0oooo01<0oooo00@0
2NX:0?ooo`09jPX0oooo4009jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:
00<0oooo00WZ2P09jPX02@09jPX00`3oool02NX:00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ2P3o
ool01009jPX00`3oool02NX:00WZ2P0600WZ2P050?ooo`09jPX02NX:00WZ2P3oool04`09jPX00`3o
ool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00<02NX:00/0oooo00WZ2P3oool0oooo00WZ2P3o
ool02NX:0?ooo`09jPX0oooo00WZ2P030?ooo`D02NX:00<0oooo00WZ2P09jPX00`09jPX40?ooo`D0
2NX:00L0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P3oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1:0?ooo`0300WZ2P3oool0oooo
01<0oooo00@02NX:0?ooo`09jPX0oooo1009jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0
2NX:00T02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0900WZ2P030?ooo`09jPX0
2NX:00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0400WZ2P030?ooo`09jPX02NX:00H02NX:00D0
oooo00WZ2P09jPX02NX:0?ooo`0C00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX01P3oool0
2NX:00WZ2P09jPX0oooo00WZ2P80oooo00L02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:00<0oooo
1@09jPX00`3oool02NX:00WZ2P0300WZ2P@0oooo1@09jPX01`3oool02NX:00WZ2P3oool02NX:0?oo
o`09jPX00P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?oo
o`3oool05P3oool00`09jPX0oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo04X0oooo00<02NX:0?ooo`3oool04`3oool01009jPX0oooo00WZ2P3oool200WZ
2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:00WZ2P3oool3
00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX02@09jPX00`3oool02NX:00WZ2P03
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0300WZ2P040?ooo`09
jPX02NX:0?ooo`<02NX:00<0oooo00WZ2P09jPX04P09jPX0103oool02NX:00WZ2P3oool200WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool00P09jPX20?ooo`802NX:00@0oooo00WZ2P3oool02NX:0`3oool5
00WZ2P030?ooo`09jPX02NX:00<02NX:103oool500WZ2P070?ooo`09jPX02NX:0?ooo`09jPX0oooo
00WZ2P020?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`0F0?ooo`0300WZ2P3oool0oooo00H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
00000?ooo`3oool0BP3oool00`09jPX0oooo0?ooo`0C0?ooo`0400WZ2P3oool02NX:0?ooo`802NX:
00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:00H02NX:
00<0oooo00WZ2P09jPX02@09jPX00`3oool02NX:00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ2P3o
ool01009jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00P09jPX01@3oool02NX:00WZ2P09
jPX0oooo01@02NX:00@0oooo00WZ2P09jPX0oooo1P09jPX00`3oool02NX:00WZ2P020?ooo`802NX:
00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`D02NX:00<0oooo00WZ2P09jPX00`09jPX40?ooo`03
00WZ2P3oool02NX:00802NX:00L0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:
0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1:0?oo
o`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool01P09jPX00`3oool02NX:0?ooo`0:00WZ
2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ2P09jPX02@09jPX00`3oool02NX:00WZ2P0300WZ
2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:00D0
oooo00WZ2P09jPX02NX:0?ooo`0D00WZ2P030?ooo`09jPX02NX:00L02NX:0P3oool00`09jPX0oooo
0?ooo`0200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00P3oool300WZ2P030?ooo`09jPX0oooo00D0
2NX:103oool00`09jPX0oooo00WZ2P0200WZ2P090?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3o
ool02NX:00D0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0BP3oool0
0`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00802NX:00L0oooo00WZ2P09jPX02NX:0?oo
o`09jPX0oooo00X02NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P0300WZ2P030?oo
o`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0600WZ2P050?oo
o`09jPX02NX:00WZ2P3oool01009jPX01@3oool02NX:00WZ2P09jPX0oooo01@02NX:00<0oooo00WZ
2P09jPX01`09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00D0oooo00WZ2P3oool0oooo00WZ2P02
0?ooo`<02NX:00<0oooo00WZ2P3oool01@09jPX40?ooo`0300WZ2P3oool02NX:00802NX:00T0oooo
00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX01@3oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`190?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0
0P09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool01P09jPX01@3oool02NX:00WZ2P09jPX0
oooo00P02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX0
2NX:00<02NX:00<0oooo00WZ2P09jPX01P09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:00<0
oooo00WZ2P09jPX03@09jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:00@02NX:00<0
oooo00WZ2P09jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0
0`3oool200WZ2P030?ooo`09jPX0oooo00D02NX:103oool00`09jPX0oooo00WZ2P0200WZ2P090?oo
o`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:00D0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0B@3oool00`09jPX0oooo0?ooo`0C0?ooo`0600WZ2P3oool0oooo
0?ooo`09jPX0oooo0`09jPX00`3oool02NX:00WZ2P0600WZ2P050?ooo`09jPX02NX:00WZ2P3oool0
2009jPX00`3oool02NX:00WZ2P0300WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09
jPX00`09jPX00`3oool02NX:00WZ2P0600WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX0103o
ool02NX:00WZ2P3ooolJ00WZ2P030?ooo`09jPX0oooo00802NX:0P3oool00`09jPX0oooo0?ooo`02
00WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00`3oool200WZ2P030?ooo`09jPX0oooo00D02NX:103o
ool00`09jPX0oooo00WZ2P0200WZ2P090?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:
00D0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0B@3oool00`09jPX0
oooo0?ooo`0C0?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo1009jPX00`3oool02NX:00WZ2P05
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool02009jPX00`3oool02NX:00WZ2P0300WZ2P040?ooo`09
jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0600WZ2P050?oo
o`09jPX02NX:00WZ2P3oool01`09jPX00`3oool02NX:00WZ2P0E00WZ2P030?ooo`09jPX0oooo0080
2NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`802NX:00D0oooo00WZ2P09jPX0oooo00WZ
2P030?ooo`802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:0?ooo`020?ooo`0300WZ2P3o
ool02NX:00802NX:00T0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX01@3oool00`09
jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`190?ooo`0300WZ2P3oool0oooo01<0
oooo00H02NX:0?ooo`3oool0oooo00WZ2P3oool400WZ2P030?ooo`09jPX02NX:00T02NX:00<0oooo
00WZ2P09jPX00P09jPX01@3oool02NX:00WZ2P09jPX0oooo00D02NX:00@0oooo00WZ2P09jPX0oooo
0P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00X02NX:00@0oooo00WZ2P09jPX0
oooo1009jPX00`3oool02NX:00WZ2P0?00WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P09
jPX0oooo0P09jPX01P3oool02NX:00WZ2P09jPX0oooo00WZ2P80oooo0P09jPX20?ooo`0300WZ2P3o
ool02NX:00<0oooo0P09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX0oooo0080oooo00<0
2NX:0?ooo`09jPX00P09jPX02@3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P050?oo
o`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04T0oooo00<02NX:0?ooo`3o
ool04`3oool01009jPX0oooo0?ooo`3oool400WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo00WZ
2P09jPX01@09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool01@09jPX0
103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX02P09
jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:
00WZ2P0:00WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P09jPX0oooo1P09jPX02`3oool0
2NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:00<0oooo2@09jPX00`3oool02NX:
0?ooo`020?ooo`0500WZ2P3oool02NX:00WZ2P3oool00`09jPX01P3oool02NX:0?ooo`09jPX0oooo
00WZ2PD0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0B@3oool00`09
jPX0oooo0?ooo`0C0?ooo`0400WZ2P3oool0oooo0?ooo`H02NX:00D0oooo00WZ2P09jPX02NX:0?oo
o`0700WZ2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0500WZ2P040?oo
o`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0:00WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:
00l02NX:00@0oooo00WZ2P09jPX0oooo1P09jPX02`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0
oooo00WZ2P3oool02NX:00<0oooo2@09jPX00`3oool02NX:0?ooo`020?ooo`0500WZ2P3oool02NX:
00WZ2P3oool00`09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool0
0P3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool0B@3oool00`09jPX0oooo0?ooo`0C0?ooo`0400WZ2P3o
ool0oooo0?ooo`802NX:00T0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool03009jPX0
1@3oool02NX:00WZ2P09jPX0oooo00D02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:
00WZ2P0300WZ2P030?ooo`09jPX02NX:00X02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P03
0?ooo`09jPX02NX:01@02NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P020?ooo`80
2NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`D02NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09
jPX30?ooo`0500WZ2P3oool02NX:00WZ2P3oool00`09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ
2PD0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0B@3oool00`09jPX0
oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`09jPX00P09jPX00`3oool0
2NX:0?ooo`0>00WZ2P050?ooo`09jPX02NX:00WZ2P3oool01@09jPX0103oool02NX:00WZ2P3oool8
00WZ2P030?ooo`09jPX02NX:00h02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0K00WZ2P030?ooo`09
jPX0oooo00802NX:0P3oool00`09jPX0oooo0?ooo`0200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX0
0P3oool500WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0`3oool01@09jPX0oooo00WZ2P09jPX0
oooo00<02NX:00H0oooo00WZ2P3oool02NX:0?ooo`09jPX50?ooo`0300WZ2P3oool0oooo0080oooo
00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo04T0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?oo
o`030?ooo`0300WZ2P3oool02NX:00802NX:00<0oooo00WZ2P09jPX02P09jPX01@3oool02NX:00WZ
2P09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:00WZ2P3oool800WZ2P03
0?ooo`09jPX02NX:00h02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0H00WZ2P060?ooo`09jPX02NX:
0?ooo`09jPX0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00802NX:00D0oooo00WZ2P3oool0oooo
00WZ2P020?ooo`D02NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX30?ooo`0500WZ2P3oool02NX:
00WZ2P3oool00`09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool0
0P3oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool0B03oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3o
ool0oooo00<0oooo00<02NX:0?ooo`09jPX03`09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:
00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:00WZ2P3oool800WZ2P030?ooo`09jPX02NX:00L0
2NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:00WZ2P09jPX0oooo01002NX:00<0oooo00WZ
2P3oool01@09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:0080oooo00<02NX:0?oo
o`3oool00P09jPX01@3oool02NX:0?ooo`3oool02NX:0080oooo0`09jPX00`3oool02NX:0?ooo`03
00WZ2P030?ooo`09jPX0oooo0080oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P060?ooo`09
jPX0oooo00WZ2P3oool02NX:1@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01T0
oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`180?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
00WZ2P0300WZ2P030?ooo`09jPX02NX:00D02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool02009jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:
00L02NX:00<0oooo00WZ2P09jPX01009jPX01@3oool02NX:00WZ2P09jPX0oooo01002NX:00<0oooo
00WZ2P09jPX01009jPX0103oool02NX:00WZ2P3oool200WZ2P060?ooo`09jPX02NX:00WZ2P3oool0
2NX:0P3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09jPX00P3oool300WZ2P030?ooo`09jPX0oooo
00802NX:00<0oooo00WZ2P09jPX00`3oool01@09jPX0oooo00WZ2P09jPX0oooo00<02NX:00H0oooo
00WZ2P3oool02NX:0?ooo`09jPX50?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0
6@3oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo04P0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`030?ooo`@02NX:00<0
oooo00WZ2P3oool01`09jPX01@3oool02NX:00WZ2P09jPX0oooo01002NX:00<0oooo00WZ2P09jPX0
1P09jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX0
4P09jPX00`3oool02NX:00WZ2P0400WZ2P040?ooo`09jPX02NX:0?ooo`H02NX:00@0oooo00WZ2P3o
ool0oooo0P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo0`09jPX00`3oool02NX:0?ooo`02
00WZ2P030?ooo`09jPX02NX:00<0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P060?ooo`09
jPX0oooo00WZ2P3oool02NX:1@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01T0
oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`180?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool00`3oool600WZ2P030?oo
o`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0>00WZ2P030?oo
o`09jPX02NX:00H02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0300WZ2P040?oo
o`09jPX02NX:0?oooa@02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0800WZ2P04
0?ooo`09jPX0oooo0?ooo`802NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0600WZ2P3oool02NX:
0?ooo`09jPX0oooo0P09jPX00`3oool02NX:00WZ2P030?ooo`0500WZ2P3oool02NX:00WZ2P3oool0
0`09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo00@0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0B03oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00<0
oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX01@09jPX00`3o
ool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX01P09jPX00`3o
ool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P09jPX0oooo1009jPX0
0`3oool02NX:00WZ2P0:00WZ2P030?ooo`09jPX02NX:00h02NX:00@0oooo00WZ2P3oool0oooo0P09
jPX20?ooo`0300WZ2P3oool02NX:0080oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool500WZ2P<0
oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:1@3o
ool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01T0oooo00<02NX:0?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`180?ooo`0300WZ2P3oool0
oooo01<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo00WZ2P0200WZ2P050?ooo`09jPX0
2NX:00WZ2P3oool01`09jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:00D02NX:00<0
oooo00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P0500WZ2P050?ooo`09jPX02NX:00WZ2P3oool0
1009jPX0103oool02NX:00WZ2P3oool400WZ2P030?ooo`09jPX02NX:00X02NX:00<0oooo00WZ2P09
jPX02@09jPX00`3oool02NX:00WZ2P0200WZ2P0;0?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3o
ool02NX:0?ooo`09jPX00P3oool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`D02NX:0`3oool01@09
jPX0oooo00WZ2P09jPX0oooo00<02NX:00H0oooo00WZ2P3oool02NX:0?ooo`09jPX50?ooo`0300WZ
2P3oool0oooo0080oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04P0oooo00<02NX:0?ooo`3oool04P3o
ool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool02NX:00802NX:00<0oooo00WZ2P3oool02@09
jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX01P09
jPX00`3oool02NX:00WZ2P0500WZ2P050?ooo`09jPX02NX:00WZ2P3oool01`09jPX00`3oool02NX:
00WZ2P0200WZ2P030?ooo`09jPX02NX:00T02NX:00<0oooo00WZ2P3oool02@09jPX0103oool02NX:
00WZ2P3oool200WZ2P80oooo00T02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX00P3o
ool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`D02NX:0`3oool01@09jPX0oooo00WZ2P09jPX0oooo
00<02NX:00H0oooo00WZ2P3oool02NX:0?ooo`09jPX50?ooo`0300WZ2P3oool0oooo0080oooo00<0
2NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo04P0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`05
0?ooo`0300WZ2P3oool02NX:00802NX:00<0oooo00WZ2P09jPX02@09jPX00`3oool02NX:00WZ2P06
00WZ2P030?ooo`09jPX02NX:00h02NX:00<0oooo00WZ2P09jPX01@09jPX01@3oool02NX:00WZ2P09
jPX0oooo00L02NX:00<0oooo00WZ2P09jPX02P09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3o
ool01`09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:0080oooo00L02NX:0?ooo`09
jPX0oooo00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool00P09jPX00`3oool02NX:0?ooo`05
00WZ2P<0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P060?ooo`09jPX0oooo00WZ2P3oool0
2NX:1@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`180?ooo`0300WZ
2P3oool0oooo0180oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo00WZ2P0>00WZ2P030?oo
o`09jPX02NX:00H02NX:00<0oooo00WZ2P09jPX03P09jPX00`3oool02NX:00WZ2P0500WZ2P050?oo
o`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00X0
2NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX0oooo0080
2NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0oooo0?ooo`0200WZ2P050?ooo`09jPX0oooo0?oo
o`09jPX00P3oool200WZ2P030?ooo`09jPX02NX:00D02NX:0`3oool01@09jPX0oooo00WZ2P09jPX0
oooo00<02NX:00H0oooo00WZ2P3oool02NX:0?ooo`09jPX50?ooo`0300WZ2P3oool0oooo0080oooo
00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo04L0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?oo
o`050?ooo`H02NX:00<0oooo00WZ2P09jPX03@09jPX01@3oool02NX:00WZ2P09jPX0oooo01002NX:
00<0oooo00WZ2P09jPX01@09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00D0oooo00WZ2P09
jPX02NX:0?ooo`0B00WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX01`09jPX20?oo
o`0300WZ2P3oool0oooo00802NX:00D0oooo00WZ2P3oool0oooo00WZ2P020?ooo`802NX:00<0oooo
00WZ2P09jPX01@09jPX30?ooo`0500WZ2P3oool02NX:00WZ2P3oool00`09jPX01P3oool02NX:0?oo
o`09jPX0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0J0?ooo`03
00WZ2P3oool0oooo00<0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
A`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00D0oooo1009jPX00`3oool02NX:
0?ooo`0;00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0>00WZ2P03
0?ooo`09jPX02NX:00D02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:
00WZ2P3oool04P09jPX00`3oool02NX:00WZ2P0>00WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00D0
oooo00WZ2P3oool0oooo00WZ2P020?ooo`802NX:00<0oooo00WZ2P09jPX01@09jPX30?ooo`0500WZ
2P3oool02NX:00WZ2P3oool00`09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2PD0oooo00<02NX:
0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0A`3oool00`09jPX0oooo0?ooo`0C0?oo
o`0300WZ2P3oool0oooo00D0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00L02NX:00D0oooo
00WZ2P09jPX02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool04009jPX00`3oool02NX:
00WZ2P0500WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX01@3oool02NX:00WZ2P09jPX0oooo
01802NX:0P3oool:00WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P3oool0oooo0P09jPX0
1@3oool02NX:0?ooo`3oool02NX:0080oooo0`09jPX00`3oool02NX:00WZ2P0400WZ2P<0oooo00D0
2NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:1@3oool00`09
jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`170?ooo`0300WZ2P3oool0oooo01<0
oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX02NX:00D0
2NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool04009jPX0
0`3oool02NX:00WZ2P0500WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX01@3oool02NX:00WZ
2P09jPX0oooo00L02NX:00<0oooo00WZ2P09jPX00`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ
2P3oool02P09jPX00`3oool02NX:00WZ2P0200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00D0oooo
00WZ2P09jPX0oooo00WZ2P020?ooo`<02NX:00<0oooo00WZ2P3oool01009jPX30?ooo`0500WZ2P3o
ool02NX:00WZ2P3oool00`09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2PD0oooo00<02NX:0?oo
o`3oool00P3oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?oo
o`3oool01@3oool000L0oooo00<000000?ooo`3oool0A`3oool00`09jPX0oooo0?ooo`0C0?ooo`03
00WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`09jPX00P09jPX01@3oool02NX:00WZ2P09jPX0oooo
00L02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00h02NX:00<0oooo
00WZ2P09jPX01@09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX02@09
jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX01009
jPX0103oool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:0P3oool00`09jPX0
oooo00WZ2P020?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo1009jPX30?ooo`0500WZ2P3oool0
2NX:00WZ2P3oool00`09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2PD0oooo00<02NX:0?ooo`3o
ool00P3oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0A`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ
2P3oool0oooo00H0oooo00<02NX:0?ooo`09jPX00P09jPX01@3oool02NX:0?ooo`09jPX0oooo00L0
2NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00h02NX:00<0oooo00WZ
2P09jPX01@09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX01@09jPX0
1@3oool02NX:00WZ2P09jPX0oooo00P02NX:00@0oooo00WZ2P09jPX0oooo1@09jPX01@3oool02NX:
0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P020?oo
o`0300WZ2P3oool02NX:0080oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool400WZ2P<0oooo00D0
2NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:1@3oool01@09
jPX0oooo0?ooo`3oool02NX:01d0oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`170?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?oo
o`3oool01`3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX02NX:00T02NX:00D0oooo00WZ
2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00h02NX:00<0oooo00WZ2P09jPX01@09jPX0
0`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX02P09jPX0
103oool02NX:00WZ2P3oool500WZ2P030?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX00P3o
ool01009jPX0oooo00WZ2P09jPX20?ooo`0300WZ2P3oool02NX:0080oooo00H02NX:0?ooo`09jPX0
oooo00WZ2P3oool400WZ2P<0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P060?ooo`09jPX0
oooo00WZ2P3oool02NX:1@3oool01@09jPX0oooo0?ooo`3oool02NX:01h0oooo00<02NX:0?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`170?ooo`0300WZ
2P3oool0oooo0180oooo00<02NX:0?ooo`3oool01`3ooolA00WZ2P030?ooo`09jPX02NX:00D02NX:
00<0oooo00WZ2P09jPX03P09jPX00`3oool02NX:00WZ2P0=00WZ2P040?ooo`09jPX02NX:0?oooa@0
2NX:00<0oooo00WZ2P09jPX03@09jPX20?ooo`0900WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3o
ool02NX:0080oooo00H02NX:0?ooo`09jPX0oooo00WZ2P3oool400WZ2P<0oooo00D02NX:0?ooo`09
jPX02NX:0?ooo`0300WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:1@3oool01@09jPX0oooo0?oo
o`3oool02NX:01h0oooo00<02NX:0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`160?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool01`3o
ool400WZ2P030?ooo`09jPX0oooo00X02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ
2P0>00WZ2P030?ooo`09jPX02NX:00d02NX:00@0oooo00WZ2P09jPX0oooo5@09jPX00`3oool02NX:
00WZ2P0<00WZ2P80oooo00L02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0080oooo00P02NX:0?oo
o`09jPX0oooo00WZ2P3oool02NX:0?ooo`@02NX:103oool300WZ2P0:0?ooo`09jPX02NX:00WZ2P3o
ool02NX:0?ooo`09jPX0oooo00WZ2PD0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0N0?ooo`0300WZ
2P3oool0oooo0080oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0AP3o
ool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`09jPX00P09
jPX00`3oool02NX:00WZ2P0800WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX03P09
jPX00`3oool02NX:00WZ2P0=00WZ2P040?ooo`09jPX02NX:0?oooa<02NX:00<0oooo00WZ2P3oool0
2P09jPX00`3oool02NX:00WZ2P0200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00`0oooo00WZ2P3o
ool0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool400WZ2P@0oooo0`09jPX02P3oool0
2NX:00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX50?ooo`0500WZ2P3oool0oooo0?ooo`09
jPX07P3oool00`09jPX0oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo04H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P3oool02NX:00802NX:00<0oooo00WZ2P09jPX02009jPX00`3oool02NX:00WZ2P0500WZ2P030?oo
o`09jPX02NX:00h02NX:00@0oooo00WZ2P09jPX0oooo3`09jPX00`3oool02NX:00WZ2P0=00WZ2P04
0?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX01@3oool02NX:00WZ2P09
jPX0oooo00D02NX:00@0oooo00WZ2P3oool0oooo0P09jPX0303oool02NX:0?ooo`3oool02NX:0?oo
o`09jPX0oooo00WZ2P3oool02NX:0?ooo`@02NX:103oool300WZ2P070?ooo`09jPX02NX:00WZ2P3o
ool02NX:0?ooo`0300WZ2PD0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0N0?ooo`0300WZ2P3oool0
oooo0080oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0AP3oool00`09
jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`09jPX00P09jPX00`3o
ool02NX:00WZ2P0Q00WZ2P040?ooo`09jPX02NX:0?ooo`l02NX:00<0oooo00WZ2P09jPX03@09jPX2
0?ooo`0500WZ2P3oool02NX:00WZ2P3oool01@09jPX01@3oool02NX:00WZ2P09jPX0oooo00D02NX:
00@0oooo00WZ2P3oool0oooo0P09jPX0303oool02NX:0?ooo`3oool02NX:0?ooo`09jPX0oooo00WZ
2P3oool02NX:0?ooo`<02NX:00<0oooo00WZ2P3oool00P3oool300WZ2P80oooo0P09jPX00`3oool0
2NX:0?ooo`0300WZ2PD0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0N0?ooo`0300WZ2P3oool0oooo
0080oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0AP3oool00`09jPX0
oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`09jPX00P09jPX01@3oool0
2NX:00WZ2P09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX07009jPX00`3oool02NX:00WZ2P0=00WZ
2P030?ooo`09jPX02NX:00h02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0300WZ
2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo0P09
jPX02P3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool500WZ2P030?ooo`09jPX0
oooo0080oooo0`09jPX20?ooo`802NX:00<0oooo00WZ2P3oool00`09jPX50?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX07P3oool00`09jPX0oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo04H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`08
0?ooo`D02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool0
6P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P09jPX0
1@09jPX01@3oool02NX:00WZ2P09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool0
2NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P020?oo
o`802NX:00X0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo1@09jPX00`3oool0
2NX:0?ooo`020?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX0oooo00<02NX:103oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`160?ooo`0300WZ2P3oool0oooo01<0oooo
00<02NX:0?ooo`3oool0203ooolA00WZ2P030?ooo`09jPX02NX:01P02NX:00<0oooo00WZ2P09jPX0
1@09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ
2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool0
3P09jPX0103oool02NX:00WZ2P3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool800WZ
2P030?ooo`09jPX0oooo0080oooo0`09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00`09jPX4
0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo04H0oooo00<02NX:0?oo
o`3oool04P3oool00`09jPX0oooo0?ooo`090?oooa402NX:00D0oooo00WZ2P09jPX02NX:0?ooo`03
00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX02`09jPX00`3oool02NX:00WZ2P05
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool01`09jPX00`3oool02NX:00WZ2P0:00WZ2P070?ooo`09
jPX02NX:00WZ2P3oool02NX:0?ooo`0:00WZ2P040?ooo`09jPX02NX:00WZ2P80oooo00@02NX:0?oo
o`09jPX02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX0
0`3oool02NX:0?ooo`020?ooo`<02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00<02NX:103o
ool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01d0oooo00D02NX:0?ooo`3oool0oooo
000000070?ooo`001`3oool00`000000oooo0?ooo`160?ooo`0300WZ2P3oool0oooo0180oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX02NX:00P02NX:00D0
oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX0
2`09jPX00`3oool02NX:00WZ2P0500WZ2P050?ooo`09jPX02NX:00WZ2P3oool05009jPX20?ooo`05
00WZ2P3oool02NX:00WZ2P3oool01@09jPX00`3oool02NX:00WZ2P0200WZ2P040?ooo`09jPX02NX:
00WZ2P80oooo00@02NX:0?ooo`09jPX02NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`<02NX:00<0
oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`020?ooo`<02NX:0P3oool01@09jPX0oooo00WZ
2P09jPX0oooo00<02NX:103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01d0oooo
00D02NX:0?ooo`3oool0oooo000000070?ooo`001`3oool00`000000oooo0?ooo`150?ooo`0300WZ
2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo00WZ2P0200WZ2P030?oo
o`09jPX02NX:00P02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:0080
2NX:00<0oooo00WZ2P09jPX02`09jPX00`3oool02NX:00WZ2P0500WZ2P050?ooo`09jPX02NX:00WZ
2P3oool05009jPX20?ooo`@02NX:00<0oooo00WZ2P09jPX00`09jPX01@3oool02NX:00WZ2P09jPX0
oooo00@02NX:0P3oool02@09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`<0
2NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`020?ooo`<02NX:0P3oool01@09jPX0
oooo00WZ2P09jPX0oooo00<02NX:103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo
01d0oooo00D02NX:0?ooo`3oool0oooo000000070?ooo`001`3oool00`000000oooo0?ooo`150?oo
o`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo00WZ2P0200WZ
2P030?ooo`09jPX02NX:00P02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX0
2NX:00802NX:00<0oooo00WZ2P09jPX02`09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:00D0
oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:01002NX:00<0oooo00WZ2P09jPX0
0P09jPX00`3oool02NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01@09jPX0203oool0
2NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0P3oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09
jPX02NX:00802NX:00<0oooo00WZ2P3oool00P3oool300WZ2P80oooo00D02NX:0?ooo`09jPX02NX:
0?ooo`0300WZ2P@0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0M0?ooo`0500WZ
2P3oool0oooo0?ooo`0000001`3oool000L0oooo00<000000?ooo`3oool0A@3oool00`09jPX0oooo
0?ooo`0C0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`09jPX00P09jPX00`3oool02NX:
00WZ2P0800WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0@00WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo
00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0800WZ2P030?ooo`09jPX02NX:00802NX:0P3oool>
00WZ2P080?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`0600WZ2P3oool02NX:0?oo
o`09jPX0oooo1009jPX00`3oool02NX:0?ooo`020?ooo`<02NX:0P3oool01@09jPX0oooo00WZ2P09
jPX0oooo00<02NX:103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01d0oooo00D0
2NX:0?ooo`3oool0oooo000000070?ooo`001`3oool00`000000oooo0?ooo`150?ooo`0300WZ2P3o
ool0oooo01<0oooo00<02NX:0?ooo`3oool02P3oool500WZ2P030?ooo`09jPX02NX:00P02NX:00D0
oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:01002NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX00`3oool02NX:00WZ2P0500WZ
2P050?ooo`09jPX02NX:00WZ2P3oool01P09jPX20?ooo`802NX:00<0oooo00WZ2P3oool01P09jPX0
0`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3oool200WZ2P0:0?ooo`09
jPX0oooo0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`@02NX:00<0oooo00WZ2P3oool00P3oool3
00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0300WZ2P@0oooo00<02NX:0?ooo`3oool00P3o
ool00`09jPX0oooo0?ooo`0M0?ooo`0500WZ2P3oool0oooo0?ooo`0000001`3oool000L0oooo00<0
00000?ooo`3oool0A@3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00X0oooo1@09
jPX01@3oool02NX:0?ooo`09jPX0oooo00H02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:
00WZ2P0D00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX0103oool02NX:00WZ2P3oool700WZ
2P050?ooo`09jPX02NX:00WZ2P3oool01P09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool01@09
jPX00`3oool02NX:00WZ2P0600WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00X0oooo00WZ2P3oool0
oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo1009jPX00`3oool02NX:0?ooo`020?ooo`<02NX:0P3o
ool01@09jPX0oooo00WZ2P09jPX0oooo00<02NX:103oool00`09jPX0oooo0?ooo`020?ooo`0300WZ
2P3oool0oooo01d0oooo00D02NX:0?ooo`3oool0oooo000000070?ooo`001`3oool00`000000oooo
0?ooo`150?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool02P3oool900WZ2P050?oo
o`09jPX02NX:00WZ2P3oool02P09jPX00`3oool02NX:00WZ2P0D00WZ2P030?ooo`09jPX02NX:00D0
2NX:00@0oooo00WZ2P09jPX0oooo1`09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:
0080oooo1009jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:00H0oooo00WZ
2P09jPX02NX:0?ooo`09jPX20?ooo`802NX:00X0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?oo
o`09jPX0oooo1009jPX00`3oool02NX:0?ooo`020?ooo`<02NX:0P3oool01@09jPX0oooo00WZ2P09
jPX0oooo00802NX:1@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01d0oooo00D0
2NX:0?ooo`3oool0oooo000000070?ooo`001`3oool00`000000oooo0?ooo`150?ooo`0300WZ2P3o
ool0oooo0180oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09
jPX02NX:00@02NX:00<0oooo00WZ2P09jPX02009jPX00`3oool02NX:00WZ2P0D00WZ2P030?ooo`09
jPX02NX:00P02NX:00<0oooo00WZ2P09jPX03009jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX00P09
jPX00`3oool02NX:00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX20?ooo`0500WZ
2P3oool02NX:00WZ2P3oool00P09jPX02@3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?oo
o`0200WZ2P030?ooo`09jPX0oooo0080oooo0`09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool0
0P09jPX50?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool07P3oool01009jPX0oooo
0?ooo`0000070?ooo`001`3oool00`000000oooo0?ooo`150?ooo`0300WZ2P3oool0oooo0180oooo
00<02NX:0?ooo`3oool0303oool00`09jPX0oooo00WZ2P0200WZ2P030?ooo`09jPX02NX:00l02NX:
00<0oooo00WZ2P09jPX05009jPX00`3oool02NX:00WZ2P0800WZ2P050?ooo`09jPX02NX:00WZ2P3o
ool02P09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0300WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool01009jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX0
1@3oool02NX:0?ooo`09jPX0oooo00P02NX:0`3oool300WZ2P80oooo00D02NX:0?ooo`09jPX02NX:
0?ooo`0200WZ2PD0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0N0?ooo`0400WZ
2P3oool0oooo000000L0oooo00070?ooo`030000003oool0oooo04D0oooo00<02NX:0?ooo`3oool0
4P3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool02NX:00802NX:00<0oooo00WZ2P09jPX0
2009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:01@02NX:00<0oooo00WZ2P09jPX0
2009jPX01@3oool02NX:00WZ2P09jPX0oooo00X02NX:0P3oool300WZ2P80oooo0P09jPX00`3oool0
2NX:0?ooo`0=00WZ2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P050?ooo`09jPX0oooo
00WZ2P3oool02009jPX30?ooo`<02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:1@3o
ool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01h0oooo00@02NX:0?ooo`3oool00000
1`3oool000L0oooo00<000000?ooo`3oool0A03oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3o
ool0oooo00`0oooo00<02NX:0?ooo`09jPX00P09jPX00`3oool02NX:00WZ2P0800WZ2P030?ooo`09
jPX02NX:00@02NX:00<0oooo00WZ2P09jPX05009jPX00`3oool02NX:00WZ2P0800WZ2P030?ooo`09
jPX02NX:00`02NX:0P3oool300WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`0>00WZ2P030?ooo`09
jPX0oooo00802NX:0P3oool01P09jPX0oooo00WZ2P3oool02NX:0?ooo`P02NX:0`3oool300WZ2P80
oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2PD0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0Q
0?ooo`0400WZ2P3oool0oooo000000L0oooo00070?ooo`030000003oool0oooo04@0oooo00<02NX:
0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0<0?ooo`D02NX:00<0oooo00WZ2P09jPX02009jPX0
0`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:01@02NX:00<0oooo00WZ2P09jPX01009jPX0
0`3oool02NX:00WZ2P0@00WZ2P<0oooo0P09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool03009
jPX02P3oool02NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`802NX:00<0oooo
00WZ2P09jPX01P09jPX30?ooo`<02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:1@3o
ool01@09jPX0oooo0?ooo`3oool02NX:0240oooo00@02NX:0?ooo`3oool000001`3oool000L0oooo
00<000000?ooo`3oool0A03oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00`0oooo
1@09jPX00`3oool02NX:00WZ2P0800WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX0
5009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00P02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0300WZ2P<0oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00`0
2NX:00P0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX00`3oool02NX:00WZ
2P0600WZ2P<0oooo0`09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX50?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX08@3oool01009jPX0oooo0?ooo`0000070?ooo`001`3oool00`000000
oooo0?ooo`140?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool03@3oool?00WZ2P05
0?ooo`09jPX02NX:00WZ2P3oool06@09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:
00P02NX:00<0oooo00WZ2P09jPX01@09jPX30?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3o
ool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:00`0oooo00WZ2P09jPX02NX:0?ooo`09
jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX20?ooo`802NX:00<0oooo00WZ2P09jPX01P09jPX30?oo
o`<02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:1@3oool01@09jPX0oooo0?ooo`3o
ool02NX:0240oooo00@02NX:0?ooo`3oool000001`3oool000L0oooo00<000000?ooo`3oool0A03o
ool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`09jPX01@09
jPX00`3oool02NX:00WZ2P0400WZ2P050?ooo`09jPX02NX:00WZ2P3oool08009jPX0103oool02NX:
00WZ2P3oool700WZ2P030?ooo`09jPX02NX:00@02NX:103oool300WZ2P80oooo0`09jPX00`3oool0
2NX:00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool01009jPX0103oool02NX:0?ooo`3oool2
00WZ2P060?ooo`09jPX0oooo0?ooo`09jPX0oooo0`09jPX00`3oool02NX:00WZ2P0300WZ2P<0oooo
0`09jPX20?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX50?ooo`0500WZ2P3oool0oooo0?oo
o`09jPX08@3oool01009jPX0oooo0?ooo`0000070?ooo`001`3oool00`000000oooo0?ooo`140?oo
o`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo00WZ2P0200WZ
2P030?ooo`09jPX02NX:00L02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0:00WZ2P050?ooo`09jPX0
2NX:00WZ2P3oool03@09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P09jPX0
3009jPX40?ooo`<02NX:0P3oool200WZ2P030?ooo`09jPX0oooo00d02NX:00@0oooo00WZ2P3oool0
oooo0P09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`<02NX:00<0oooo00WZ2P09jPX00`09jPX3
0?ooo`<02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:1@3oool01@09jPX0oooo0?oo
o`3oool02NX:0280oooo00<02NX:0?ooo`0000001`3oool000L0oooo00<000000?ooo`3oool0A03o
ool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`09jPX00P09
jPX00`3oool02NX:00WZ2P0400WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00<0oooo00WZ2P09jPX0
2009jPX01@3oool02NX:00WZ2P09jPX0oooo00d02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ
2P030?ooo`09jPX02NX:00d02NX:103oool200WZ2P80oooo0P09jPX00`3oool02NX:0?ooo`0=00WZ
2P80oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo00<02NX:00<0oooo
00WZ2P09jPX00`09jPX30?ooo`<02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:1@3o
ool01@09jPX0oooo0?ooo`3oool02NX:0280oooo00<02NX:0?ooo`0000001`3oool000L0oooo00<0
00000?ooo`3oool0A03oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00h0oooo00<0
2NX:0?ooo`09jPX00P09jPX00`3oool02NX:00WZ2P0400WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:
00<0oooo00WZ2P09jPX02009jPX01@3oool02NX:00WZ2P09jPX0oooo00d02NX:00D0oooo00WZ2P09
jPX02NX:0?ooo`0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool02`09jPX40?ooo`802NX:0P3oool4
00WZ2P030?ooo`09jPX02NX:00/02NX:0P3oool01@09jPX0oooo00WZ2P09jPX0oooo00802NX:00<0
oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0300WZ2P<0oooo0`09jPX20?ooo`0500WZ2P3o
ool02NX:00WZ2P3oool00P09jPX50?ooo`0500WZ2P3oool0oooo0?ooo`09jPX08P3oool00`09jPX0
oooo000000070?ooo`001`3oool00`000000oooo0?ooo`140?ooo`0300WZ2P3oool0oooo0180oooo
00<02NX:0?ooo`3oool03P3oool500WZ2P030?ooo`09jPX02NX:00/02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0600WZ2P050?ooo`09jPX02NX:00WZ2P3oool03@09jPX01@3oool02NX:00WZ2P09jPX0
oooo00802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0;00WZ2P@0oooo0`09jPX00`3oool02NX:00WZ
2P0200WZ2P030?ooo`09jPX02NX:00`02NX:00<0oooo00WZ2P3oool00P09jPX01P3oool02NX:00WZ
2P3oool02NX:0?ooo`<02NX:00<0oooo00WZ2P09jPX00`09jPX30?ooo`<02NX:0P3oool01@09jPX0
oooo00WZ2P09jPX0oooo00802NX:1@3oool01@09jPX0oooo0?ooo`3oool02NX:0280oooo00<02NX:
0?ooo`0000001`3oool000L0oooo00<000000?ooo`3oool0@`3oool00`09jPX0oooo0?ooo`0C0?oo
o`0300WZ2P3oool0oooo00h0oooo1@09jPX00`3oool02NX:00WZ2P0;00WZ2P050?ooo`09jPX02NX:
00WZ2P3oool01P09jPX01@3oool02NX:00WZ2P09jPX0oooo00d02NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0200WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P09jPX00P09jPX40?ooo`<02NX:
00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0<00WZ2P030?ooo`09jPX0oooo00802NX:
00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00@02NX:0`3oool300WZ
2P80oooo0`09jPX20?ooo`802NX:1@3oool01@09jPX0oooo0?ooo`3oool02NX:0280oooo00<02NX:
0?ooo`0000001`3oool000L0oooo00<000000?ooo`3oool0@`3oool00`09jPX0oooo0?ooo`0C0?oo
o`0300WZ2P3oool0oooo00l0oooo1009jPX00`3oool02NX:00WZ2P0?00WZ2P030?ooo`09jPX02NX:
00@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0=00WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo
00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX0oooo00<0oooo0`09jPX2
0?ooo`H02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09
jPX0oooo00802NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`L02NX:0`3oool300WZ
2P80oooo0`09jPX20?ooo`802NX:1@3oool01@09jPX0oooo0?ooo`3oool02NX:0280oooo00<02NX:
0?ooo`0000001`3oool000L0oooo00<000000?ooo`3oool0@`3oool00`09jPX0oooo0?ooo`0C0?oo
o`0300WZ2P3oool0oooo00l0oooo00<02NX:0?ooo`09jPX03009jPX00`3oool02NX:00WZ2P0400WZ
2P030?ooo`09jPX02NX:00@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0=00WZ2P030?ooo`09jPX0
2NX:00@02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0400WZ2P80oooo00<02NX:
0?ooo`3oool00P3oool200WZ2P80oooo0P09jPX01@3oool02NX:0?ooo`09jPX0oooo00/02NX:00P0
oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P0500WZ
2P<0oooo0`09jPX20?ooo`<02NX:0P3oool200WZ2PD0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0R
0?ooo`0300WZ2P3oool0000000L0oooo00070?ooo`030000003oool0oooo04<0oooo00<02NX:0?oo
o`3oool04`3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool02NX:00D02NX:00<0oooo00WZ
2P09jPX01009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00@02NX:00D0oooo00WZ
2P09jPX02NX:0?ooo`0=00WZ2P030?ooo`09jPX02NX:00/02NX:00<0oooo00WZ2P09jPX01009jPX2
0?ooo`0300WZ2P3oool0oooo0080oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0
2NX:00/02NX:00P0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX00`3oool0
2NX:00WZ2P0400WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:0P3oool300WZ2P80oooo0P09jPX50?oo
o`0500WZ2P3oool0oooo0?ooo`09jPX08P3oool00`09jPX0oooo000000070?ooo`001`3oool00`00
0000oooo0?ooo`130?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool03`3oool00`09
jPX0oooo00WZ2P0200WZ2P040?ooo`09jPX02NX:0?ooo`H02NX:00<0oooo00WZ2P09jPX01009jPX0
0`3oool02NX:00WZ2P0400WZ2P050?ooo`09jPX02NX:00WZ2P3oool08P09jPX20?ooo`0300WZ2P3o
ool0oooo0080oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00/02NX:00P0
oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00WZ2P80oooo0P09jPX00`3oool02NX:00WZ2P0400WZ
2P040?ooo`09jPX0oooo0?ooo`<02NX:0P3oool300WZ2P<0oooo00<02NX:0?ooo`3oool00`3oool0
1@09jPX0oooo0?ooo`3oool02NX:0280oooo00<02NX:0?ooo`0000001`3oool000L0oooo00<00000
0?ooo`3oool0@`3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:
0?ooo`09jPX00P09jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo
00WZ2P09jPX01009jPX01@3oool02NX:00WZ2P09jPX0oooo02802NX:0P3oool00`09jPX0oooo0?oo
o`020?ooo`<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0<00WZ2P030?ooo`09
jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0400WZ2P040?oo
o`09jPX0oooo0?ooo`<02NX:0P3oool300WZ2P<0oooo00<02NX:0?ooo`3oool00`3oool01@09jPX0
oooo0?ooo`3oool02NX:02<0oooo00<02NX:0000003oool01P3oool000L0oooo00<000000?ooo`3o
ool0@`3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo0100oooo1@09jPX00`3oool0
2NX:00WZ2P0700WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX01009jPX01@3oool0
2NX:00WZ2P09jPX0oooo01002NX:00<0oooo00WZ2P09jPX03`09jPX20?ooo`0300WZ2P3oool0oooo
00<0oooo0P09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX03009jPX00`3oool02NX:0?ooo`0200WZ
2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01009jPX0103oool02NX:0?ooo`3o
ool300WZ2P80oooo0`09jPX30?ooo`0300WZ2P3oool0oooo00<0oooo00D02NX:0?ooo`3oool0oooo
00WZ2P0S0?ooo`0300WZ2P000000oooo00H0oooo00070?ooo`030000003oool0oooo04<0oooo00<0
2NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0@0?ooo`D02NX:00<0oooo00WZ2P09jPX01009
jPX0103oool02NX:00WZ2P3oool600WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P09jPX0
3P09jPX0103oool02NX:00WZ2P3oool:00WZ2P040?ooo`09jPX02NX:00WZ2P<0oooo00<02NX:0?oo
o`3oool00P3oool200WZ2P80oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00/02NX:00<0oooo
00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00@02NX:00@0
oooo00WZ2P3oool0oooo0`09jPX20?ooo`<02NX:0`3oool00`09jPX0oooo0?ooo`030?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX08`3oool00`09jPX000000?ooo`060?ooo`001`3oool00`000000oooo
0?ooo`130?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool04@3oool400WZ2P030?oo
o`09jPX02NX:00@02NX:00@0oooo00WZ2P09jPX0oooo1P09jPX00`3oool02NX:00WZ2P0800WZ2P03
0?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P09jPX01009jPX0103oool02NX:00WZ2P3oool300WZ
2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX0103oool00`09jPX0oooo0?ooo`020?oo
o`<02NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`/02NX:00<0oooo00WZ2P3oool0
0P09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00@02NX:00@0oooo00WZ2P3o
ool0oooo0`09jPX20?ooo`<02NX:0`3oool00`09jPX0oooo0?ooo`030?ooo`0500WZ2P3oool0oooo
0?ooo`09jPX08`3oool00`09jPX000000?ooo`060?ooo`001`3oool00`000000oooo0?ooo`120?oo
o`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool04@3oool01@09jPX0oooo00WZ2P09jPX0
oooo00T02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00P02NX:00<0
oooo00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P0400WZ2P040?ooo`09jPX02NX:0?ooo`H02NX:
00<0oooo00WZ2P09jPX01009jPX40?ooo`0300WZ2P3oool0oooo0080oooo0`09jPX00`3oool02NX:
00WZ2P0200WZ2P030?ooo`09jPX0oooo00/02NX:00<0oooo00WZ2P3oool00P09jPX0103oool02NX:
00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00@02NX:00@0oooo00WZ2P3oool0oooo0`09jPX20?oo
o`<02NX:0`3oool00`09jPX0oooo0?ooo`030?ooo`0500WZ2P3oool0oooo0?ooo`09jPX08`3oool0
0`09jPX000000?ooo`060?ooo`001`3oool00`000000oooo0?ooo`120?ooo`0300WZ2P3oool0oooo
01<0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo00WZ2P0?00WZ2P040?ooo`09jPX02NX:
0?ooo`X02NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P0400WZ2P040?ooo`09jPX0
2NX:0?ooo`H02NX:00<0oooo00WZ2P09jPX01009jPX40?ooo`0300WZ2P3oool0oooo0080oooo0`09
jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00/02NX:00<0oooo00WZ2P3oool00P09
jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00@02NX:00@0oooo00WZ2P3oool0
oooo1009jPX0103oool02NX:00WZ2P09jPX30?ooo`0300WZ2P3oool0oooo00<0oooo00D02NX:0?oo
o`3oool0oooo00WZ2P0S0?ooo`0300WZ2P000000oooo00H0oooo00070?ooo`030000003oool0oooo
0480oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool02NX:
00l02NX:00@0oooo00WZ2P09jPX0oooo2P09jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX0
2NX:00@02NX:00@0oooo00WZ2P09jPX0oooo1P09jPX00`3oool02NX:00WZ2P0400WZ2P@0oooo00<0
2NX:0?ooo`3oool00`3oool200WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P0;00WZ2P030?ooo`09
jPX0oooo00802NX:00H0oooo00WZ2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:0080
2NX:00@0oooo00WZ2P3oool0oooo1009jPX0103oool02NX:00WZ2P09jPX30?ooo`0300WZ2P3oool0
oooo00<0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0S0?ooo`0300WZ2P000000oooo00H0oooo0007
0?ooo`030000003oool0oooo0480oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0A
0?ooo`D02NX:00@0oooo00WZ2P09jPX0oooo2@09jPX00`3oool02NX:00WZ2P0;00WZ2P030?ooo`09
jPX02NX:00L02NX:00<0oooo00WZ2P09jPX01009jPX0103oool02NX:00WZ2P3oool=00WZ2PD0oooo
00<02NX:0?ooo`3oool00P3oool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool03`09jPX00`3oool0
2NX:0?ooo`0300WZ2P80oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P040?ooo`09jPX0oooo0?oo
o`@02NX:00@0oooo00WZ2P09jPX02NX:0`3oool00`09jPX0oooo0?ooo`030?ooo`0500WZ2P3oool0
oooo0?ooo`09jPX08`3oool00`09jPX000000?ooo`060?ooo`001`3oool00`000000oooo0?ooo`12
0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool04@3oool500WZ2P040?ooo`09jPX0
2NX:0?ooo`T02NX:00<0oooo00WZ2P09jPX02`09jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09
jPX02NX:00@02NX:00@0oooo00WZ2P09jPX0oooo3@09jPX50?ooo`0300WZ2P3oool0oooo0080oooo
0`09jPX0103oool02NX:00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00X02NX:00H0oooo00WZ2P3o
ool02NX:0?ooo`09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX01009jPX20?ooo`@02NX:00@0oooo
00WZ2P09jPX02NX:0`3oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0oooo00WZ2RD0oooo
00<02NX:0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0@P3oool00`09jPX0oooo0?oo
o`0B0?ooo`0300WZ2P3oool0oooo0180oooo1@09jPX00`3oool02NX:00WZ2P0700WZ2P040?ooo`09
jPX02NX:0?ooo`d02NX:00<0oooo00WZ2P09jPX01`09jPX0103oool02NX:00WZ2P3ooolD00WZ2PD0
oooo00<02NX:0?ooo`3oool00P3oool300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3o
ool02`09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?oo
o`0600WZ2P80oooo1009jPX0103oool02NX:00WZ2P09jPX30?ooo`0300WZ2P3oool0oooo00<0oooo
00@02NX:0?ooo`3oool02NX:9@3oool00`09jPX0oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`120?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool04`3oool400WZ2P030?oo
o`09jPX02NX:00L02NX:00<0oooo00WZ2P09jPX03P09jPX00`3oool02NX:00WZ2P0700WZ2P040?oo
o`09jPX02NX:0?oooa002NX:00<0oooo00WZ2P09jPX01P3oool00`09jPX0oooo0?ooo`020?ooo`<0
2NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?ooo`0;00WZ2P060?ooo`09jPX02NX:0?oo
o`09jPX0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0oooo00H02NX:0P3oool400WZ2P040?ooo`09
jPX02NX:00WZ2P<0oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09jPXU0?ooo`03
00WZ2P3oool0oooo00D0oooo00070?ooo`030000003oool0oooo0480oooo00<02NX:0?ooo`3oool0
4P3oool00`09jPX0oooo0?ooo`0C0?ooo`0500WZ2P3oool02NX:00WZ2P3oool02@09jPX00`3oool0
2NX:00WZ2P0>00WZ2P030?ooo`09jPX02NX:00L02NX:00@0oooo00WZ2P09jPX0oooo4`09jPX60?oo
o`0300WZ2P3oool0oooo00<0oooo0P09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX01@09jPX00`3o
ool02NX:00WZ2P0300WZ2P030?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX0
0`3oool02NX:00WZ2P0400WZ2P80oooo1009jPX0103oool02NX:00WZ2P09jPX30?ooo`0300WZ2P3o
ool0oooo00<0oooo00@02NX:0?ooo`3oool02NX:903oool2000000L0oooo00070?ooo`030000003o
ool0oooo0480oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3o
ool02NX:00/02NX:00<0oooo00WZ2P09jPX03P09jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09
jPX02NX:00@02NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P0700WZ2PL0oooo00<0
2NX:0?ooo`3oool00P3oool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool03@09jPX00`3oool02NX:
0?ooo`0200WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:00<0oooo00WZ2P09jPX01009jPX20?ooo`@0
2NX:00@0oooo00WZ2P09jPX02NX:0`3oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0oooo
00WZ2R@0oooo0P0000070?ooo`001`3oool00`000000oooo0?ooo`110?ooo`0300WZ2P3oool0oooo
01<0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo00WZ2P0800WZ2P040?ooo`09jPX02NX:
0?oooa002NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX0
2NX:00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P030?ooo`09jPX02NX:00@02NX:1`3o
ool00`09jPX0oooo0?ooo`020?ooo`<02NX:00<0oooo00WZ2P09jPX04@09jPX0103oool02NX:00WZ
2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`L02NX:0P3oool400WZ2P040?ooo`09jPX02NX:00WZ
2P<0oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo0?ooo`09jPXU0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo0440oooo00<02NX:0?ooo`3oool04`3oool00`09
jPX0oooo0?ooo`0C0?ooo`h02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0700WZ
2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0300WZ
2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX01009jPX70?ooo`0300WZ2P3oool0oooo
0080oooo0`09jPX0103oool02NX:00WZ2P3oool300WZ2P030?ooo`09jPX02NX:00X02NX:00@0oooo
00WZ2P09jPX0oooo0P09jPX0103oool02NX:00WZ2P3oool700WZ2P80oooo1009jPX0103oool02NX:
00WZ2P09jPX30?ooo`802NX:103oool01009jPX0oooo0?ooo`09jPXU0?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo0440oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0
oooo0?ooo`0C0?ooo`D02NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P0400WZ2P03
0?ooo`09jPX02NX:00L02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0400WZ
2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P04
00WZ2PL0oooo00<02NX:0?ooo`3oool00P3oool300WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo
00WZ2P3oool03009jPX0103oool02NX:00WZ2P3oool200WZ2P060?ooo`09jPX02NX:0?ooo`09jPX0
oooo1@09jPX20?ooo`@02NX:00@0oooo00WZ2P09jPX02NX:0`3oool200WZ2P@0oooo00@02NX:0?oo
o`3oool02NX:9@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`110?oo
o`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0503oool400WZ2P040?ooo`09jPX02NX:
0?ooo`D02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0700WZ2P040?ooo`09jPX0
2NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01`09jPX0103oool02NX:00WZ2P3oool<00WZ2PP0oooo
00<02NX:0?ooo`3oool00`3oool300WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0<00WZ
2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool01009jPX0oooo00WZ2P3oool500WZ2P80oooo1009
jPX0103oool02NX:00WZ2P09jPX30?ooo`802NX:103oool01009jPX0oooo0?ooo`09jPXU0?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0440oooo00<02NX:0?ooo`3oool0
4`3oool00`09jPX0oooo0?ooo`0D0?ooo`@02NX:00<0oooo00WZ2P09jPX03@09jPX00`3oool02NX:
00WZ2P0700WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01`09jPX0103oool0
2NX:00WZ2P3oool900WZ2P030?ooo`09jPX02NX:00T0oooo00<02NX:0?ooo`3oool00P3oool300WZ
2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0500WZ2P030?ooo`09jPX02NX:00@02NX:00<0
oooo00WZ2P3oool00`09jPX20?ooo`0400WZ2P3oool02NX:0?ooo`D02NX:0P3oool400WZ2P040?oo
o`09jPX02NX:00WZ2P<0oooo0P09jPX40?ooo`0400WZ2P3oool0oooo00WZ2RD0oooo00<000000?oo
o`3oool01@3oool000L0oooo00<000000?ooo`3oool0@@3oool00`09jPX0oooo0?ooo`0B0?ooo`03
00WZ2P3oool0oooo01D0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0?00WZ2P030?ooo`09jPX02NX:
00L02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0700WZ2P040?ooo`09jPX0
2NX:0?ooo``02NX:2@3oool00`09jPX0oooo0?ooo`020?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0700WZ2P030?ooo`09jPX02NX:00<02NX:00@0oooo00WZ2P09jPX0oooo0`09jPX20?ooo`04
00WZ2P3oool02NX:0?ooo`D02NX:0P3oool400WZ2P040?ooo`09jPX02NX:00WZ2P<0oooo0P09jPX4
0?ooo`0400WZ2P3oool0oooo00WZ2RD0oooo00<000000?ooo`3oool01@3oool000L0oooo00<00000
0?ooo`3oool0@@3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo01D0oooo00D02NX:
0?ooo`09jPX02NX:0?ooo`0<00WZ2P040?ooo`09jPX02NX:0?ooo`T02NX:00@0oooo00WZ2P09jPX0
oooo0P09jPX00`3oool02NX:00WZ2P0700WZ2P040?ooo`09jPX02NX:0?ooo``02NX:2@3oool00`09
jPX0oooo0?ooo`020?ooo`<02NX:00@0oooo00WZ2P09jPX0oooo3P09jPX01P3oool02NX:00WZ2P3o
ool02NX:0?ooo`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0500WZ2P80oooo1009jPX0103oool0
2NX:00WZ2P09jPX30?ooo`802NX:103oool01009jPX0oooo0?ooo`09jPXU0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo0440oooo00<02NX:0?ooo`3oool04P3oool00`09
jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool02NX:00h02NX:00@0oooo00WZ2P09jPX0oooo2@09jPX0
103oool02NX:00WZ2P3oool<00WZ2P030?ooo`09jPX02NX:00d02NX:2@3oool00`09jPX0oooo0?oo
o`020?ooo`<02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0;00WZ2P030?ooo`09
jPX0oooo00802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0500WZ2P80oooo1009jPX0103oool02NX:
0?ooo`09jPX30?ooo`802NX:103oool01009jPX0oooo0?ooo`09jPXU0?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo0400oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0
oooo0?ooo`0E0?ooo`h02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0700WZ
2P040?ooo`09jPX02NX:0?ooo``02NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P04
00WZ2PT0oooo00<02NX:0?ooo`3oool00`3oool300WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:
0?ooo`0<00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00D0oooo00WZ2P3oool02NX:0?ooo`0500WZ
2P80oooo1009jPX0103oool02NX:0?ooo`09jPX30?ooo`802NX:103oool01009jPX0oooo0?ooo`09
jPXU0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0400oooo00<02NX:
0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0E0?ooo`D02NX:00<0oooo00WZ2P09jPX01P09jPX0
103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00L02NX:00@0oooo00WZ2P09jPX0oooo
4P09jPX0103oool02NX:00WZ2P3oool600WZ2PX0oooo00<02NX:0?ooo`3oool00P3oool300WZ2P07
0?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0<00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00D0
oooo00WZ2P09jPX02NX:0?ooo`0500WZ2P80oooo1009jPX0103oool02NX:0?ooo`09jPX30?ooo`80
2NX:103oool01009jPX0oooo0?ooo`09jPXU0?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo0400oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0F0?ooo`@0
2NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX02NX:
0?ooo`T02NX:00@0oooo00WZ2P09jPX0oooo5@09jPX00`3oool02NX:00WZ2P0300WZ2P/0oooo00<0
2NX:0?ooo`3oool00P3oool300WZ2P070?ooo`09jPX02NX:00WZ2P3oool02NX:0?ooo`0500WZ2P03
0?ooo`09jPX02NX:00@02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX01@3oool02NX:00WZ2P09jPX0
oooo00D02NX:0P3oool400WZ2P040?ooo`09jPX0oooo00WZ2P<0oooo0P09jPX40?ooo`0400WZ2P3o
ool0oooo00WZ2RD0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0@03o
ool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01H0oooo1009jPX00`3oool02NX:00WZ
2P0600WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX01`09jPX0103oool02NX:00WZ
2P3ooolH00WZ2P030?ooo`09jPX02NX:00/0oooo00<02NX:0?ooo`3oool00P3oool300WZ2P030?oo
o`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0400WZ2P040?oo
o`09jPX02NX:0?ooo`802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0500WZ2P80oooo1009jPX0103o
ool02NX:0?ooo`09jPX20?ooo`<02NX:103oool01009jPX0oooo0?ooo`09jPXU0?ooo`030000003o
ool0oooo00D0oooo00070?ooo`030000003oool0oooo0400oooo00<02NX:0?ooo`3oool04`3oool0
0`09jPX0oooo0?ooo`0F0?ooo`0500WZ2P3oool02NX:00WZ2P3oool00P09jPX00`3oool02NX:00WZ
2P0300WZ2P030?ooo`09jPX02NX:00d02NX:00@0oooo00WZ2P09jPX0oooo3P09jPX00`3oool02NX:
00WZ2P0:00WZ2P/0oooo00<02NX:0?ooo`3oool00P3ooolF00WZ2P040?ooo`09jPX02NX:0?ooo`80
2NX:00@0oooo00WZ2P09jPX02NX:0P3oool500WZ2P030?ooo`09jPX02NX:00<02NX:0P3oool200WZ
2P040?ooo`09jPX02NX:00WZ2P@0oooo00@02NX:0?ooo`3oool02NX:9@3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`100?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:
0?ooo`3oool05`3oool01@09jPX0oooo00WZ2P09jPX0oooo00P02NX:00<0oooo00WZ2P09jPX03@09
jPX0103oool02NX:00WZ2P3oool>00WZ2P030?ooo`09jPX02NX:00X02NX:2`3oool00`09jPX0oooo
0?ooo`030?ooo`<02NX:00<0oooo00WZ2P09jPX03@09jPX00`3oool02NX:00WZ2P0200WZ2P030?oo
o`09jPX02NX:0080oooo0P09jPX20?ooo`D02NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`802NX:
00@0oooo00WZ2P09jPX02NX:103oool01009jPX0oooo0?ooo`09jPXU0?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo0400oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0
oooo0?ooo`0G0?ooo`0300WZ2P3oool02NX:00X02NX:00<0oooo00WZ2P09jPX03@09jPX0103oool0
2NX:00WZ2P3oool500WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:00<0oooo00WZ2P09jPX02P09jPX<
0?ooo`0300WZ2P3oool0oooo0080oooo0`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool0
2@09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:0P3oool200WZ2P80oooo1@09jPX00`3oool0
2NX:00WZ2P0300WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09jPX40?ooo`0400WZ2P3oool0oooo
00WZ2RD0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0@03oool00`09
jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo01L0oooo7@09jPX0103oool02NX:00WZ2P3oool5
00WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:00<0oooo00WZ2P09jPX02P09jPX<0?ooo`0300WZ2P3o
ool0oooo0080oooo0`09jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool02@09jPX01@3oool0
2NX:00WZ2P09jPX0oooo00802NX:00<0oooo00WZ2P3oool00P09jPX20?ooo`D02NX:00<0oooo00WZ
2P09jPX00`09jPX20?ooo`802NX:00@0oooo00WZ2P09jPX02NX:103oool01009jPX0oooo0?ooo`09
jPXU0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0400oooo00<02NX:
0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0G0?oooad02NX:00@0oooo00WZ2P09jPX0oooo1@09
jPX0103oool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:00<0oooo00WZ2P09
jPX01009jPX<0?ooo`0300WZ2P3oool0oooo0080oooo0`09jPX01`3oool02NX:00WZ2P09jPX0oooo
00WZ2P3oool01@09jPX00`3oool02NX:00WZ2P0500WZ2P0:0?ooo`09jPX02NX:0?ooo`09jPX0oooo
00WZ2P3oool02NX:0?ooo`D02NX:00<0oooo00WZ2P09jPX00`09jPX20?ooo`802NX:00@0oooo00WZ
2P09jPX02NX:103oool00`09jPX0oooo00WZ2P0V0?ooo`030000003oool0oooo00D0oooo00070?oo
o`030000003oool0oooo03l0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0H0?oo
o`@02NX:00<0oooo00WZ2P09jPX05@09jPX0103oool02NX:00WZ2P3oool500WZ2P040?ooo`09jPX0
2NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0oooo1@09jPX00`3oool02NX:00WZ2P0300WZ2Pd0oooo
00<02NX:0?ooo`3oool00`3ooolF00WZ2P030?ooo`09jPX0oooo00802NX:00D0oooo00WZ2P3oool0
2NX:0?ooo`0500WZ2P030?ooo`09jPX02NX:00<02NX:0P3oool200WZ2P040?ooo`09jPX02NX:00WZ
2P@0oooo00<02NX:0?ooo`09jPX09P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0o0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0603oool400WZ2P03
0?ooo`09jPX02NX:01D02NX:00@0oooo00WZ2P09jPX0oooo1@09jPX0103oool02NX:00WZ2P3oool2
00WZ2P030?ooo`09jPX02NX:00<02NX:00@0oooo00WZ2P09jPX0oooo1@09jPX=0?ooo`0300WZ2P3o
ool0oooo00<0oooo5P09jPX00`3oool02NX:0?ooo`0200WZ2P050?ooo`09jPX0oooo00WZ2P3oool0
1@09jPX00`3oool02NX:00WZ2P0300WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09jPX40?ooo`03
00WZ2P3oool02NX:02H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
?`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01P0oooo00D02NX:0?ooo`09jPX0
2NX:0?ooo`0G00WZ2P040?ooo`09jPX02NX:0?ooo`D02NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0
0`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX03P3oool0
0`09jPX0oooo0?ooo`020?ooo`<02NX:00<0oooo00WZ2P09jPX03`09jPX0103oool02NX:00WZ2P3o
ool200WZ2P050?ooo`09jPX0oooo00WZ2P3oool00`09jPX00`3oool02NX:0?ooo`0500WZ2P80oooo
0P09jPX0103oool02NX:00WZ2P09jPX40?ooo`0300WZ2P3oool02NX:02H0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0?`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ
2P3oool0oooo01P0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0200WZ2P040?ooo`09jPX02NX:0?oo
o`802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0600WZ2P040?ooo`09jPX02NX:
0?ooo`D02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0<00WZ2Ph0oooo00<02NX:
0?ooo`3oool00P3oool300WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX01`09jPX0
0`3oool02NX:0?ooo`0200WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ2P03
0?ooo`09jPX0oooo00D02NX:0P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P@0oooo00<02NX:0?oo
o`09jPX09P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0o0?ooo`03
00WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0603oool400WZ2P030?ooo`09jPX02NX:00H0
2NX:00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0600WZ2P040?ooo`09jPX02NX:
0?ooo`D02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0<00WZ2Ph0oooo00<02NX:
0?ooo`3oool00P3oool200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P3oool02@09jPX0
0`3oool02NX:0?ooo`0200WZ2P080?ooo`09jPX02NX:0?ooo`09jPX0oooo00WZ2P3oool300WZ2P03
0?ooo`09jPX0oooo00D02NX:0P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P@0oooo00<02NX:0?oo
o`09jPX09P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0o0?ooo`03
00WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool06@3oool=00WZ2P040?ooo`09jPX02NX:0?oo
o`802NX:00<0oooo00WZ2P09jPX01P09jPX0103oool02NX:00WZ2P3ooolJ00WZ2Ph0oooo00<02NX:
0?ooo`3oool00`3oool800WZ2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P09jPX00P09jPX0
1`3oool02NX:00WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2P030?ooo`09jPX0oooo00D02NX:
0P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P@0oooo00<02NX:0?ooo`09jPX09P3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0o0?ooo`0300WZ2P3oool0oooo0180oooo
00<02NX:0?ooo`3oool06P3oool<00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09
jPX01P09jPX0103oool02NX:00WZ2P3ooolI00WZ2Pl0oooo00<02NX:0?ooo`3oool00`3ooolB00WZ
2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P09jPX0oooo0`09jPX20?ooo`802NX:00<0oooo
00WZ2P3oool01@09jPX20?ooo`802NX:00@0oooo00WZ2P09jPX02NX:103oool00`09jPX0oooo00WZ
2P0V0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03l0oooo00<02NX:
0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0J0?ooo``02NX:00@0oooo00WZ2P09jPX0oooo0P09
jPX00`3oool02NX:00WZ2P0600WZ2P040?ooo`09jPX02NX:0?ooo`d02NX:00<0oooo00WZ2P09jPX0
2@09jPX@0?ooo`0300WZ2P3oool0oooo0080oooo0`09jPX00`3oool02NX:00WZ2P0@00WZ2P040?oo
o`09jPX02NX:0?ooo`@02NX:0P3oool200WZ2P030?ooo`09jPX0oooo00D02NX:0P3oool200WZ2P04
0?ooo`09jPX02NX:00WZ2P@0oooo00<02NX:0?ooo`09jPX09P3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0o0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3o
ool06P3oool400WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool0
2NX:00WZ2P0600WZ2P040?ooo`09jPX02NX:0?ooo`d02NX:00<0oooo00WZ2P09jPX00`09jPX00`3o
ool02NX:00WZ2P0300WZ2Q00oooo00<02NX:0?ooo`3oool00P3oool300WZ2P030?ooo`09jPX02NX:
00@02NX:00<0oooo00WZ2P09jPX02@09jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:0P3o
ool200WZ2P030?ooo`09jPX0oooo00D02NX:0P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P@0oooo
00<02NX:0?ooo`09jPX09P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0n0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool06P3oool01@09jPX0oooo00WZ
2P09jPX0oooo00d02NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:00WZ2P3oool200WZ2P03
0?ooo`09jPX02NX:00/02NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:00WZ2P3oool200WZ
2Q00oooo00<02NX:0?ooo`3oool00P3oool200WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ
2P09jPX01`09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX0oooo00802NX:0P3oool4
00WZ2P060?ooo`09jPX02NX:00WZ2P3oool02NX:0P3oool200WZ2P040?ooo`09jPX02NX:00WZ2P@0
oooo00<02NX:0?ooo`09jPX09P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`0n0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool06P3oool01@09jPX0oooo
00WZ2P09jPX0oooo00d02NX:00<0oooo00WZ2P09jPX00`09jPX0103oool02NX:00WZ2P3oool200WZ
2P030?ooo`09jPX02NX:00/02NX:00<0oooo00WZ2P09jPX02@09jPX@0?ooo`0300WZ2P3oool0oooo
00<0oooo1P09jPX00`3oool02NX:0?ooo`0900WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo
00WZ2P3oool00P09jPX20?ooo`@02NX:00H0oooo00WZ2P09jPX02NX:0?ooo`09jPX20?ooo`802NX:
00@0oooo00WZ2P09jPX02NX:103oool00`09jPX0oooo00WZ2P0V0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo03h0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo
0?ooo`0J0?ooo`@02NX:00<0oooo00WZ2P09jPX02`09jPX00`3oool02NX:00WZ2P0300WZ2P040?oo
o`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX02`09jPX0103oool02NX:00WZ2P3oool800WZ
2Q00oooo00<02NX:0?ooo`3oool00`3oool800WZ2P030?ooo`09jPX02NX:00L02NX:00H0oooo00WZ
2P09jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX02NX:0080oooo1009jPX01P3oool02NX:00WZ
2P09jPX0oooo00WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09jPX40?ooo`0300WZ2P3oool02NX:
02H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0?P3oool00`09jPX0
oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01X0oooo1`09jPX00`3oool02NX:00WZ2P0>00WZ2P04
0?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX02009jPX00`3oool02NX:00WZ2P0<00WZ
2Q40oooo00<02NX:0?ooo`3oool00P3oool300WZ2P030?ooo`09jPX02NX:00`02NX:00<0oooo00WZ
2P3oool00P09jPX0103oool02NX:00WZ2P3oool200WZ2P80oooo1009jPX01P3oool02NX:00WZ2P09
jPX0oooo00WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09jPX40?ooo`0300WZ2P3oool02NX:02H0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0?P3oool00`09jPX0oooo
0?ooo`0C0?ooo`0300WZ2P3oool0oooo01/0oooo2@09jPX00`3oool02NX:00WZ2P0;00WZ2P040?oo
o`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX02009jPX00`3oool02NX:00WZ2P0;00WZ2Q80
oooo00<02NX:0?ooo`3oool00P3oool300WZ2P030?ooo`09jPX02NX:00`02NX:00<0oooo00WZ2P3o
ool00P09jPX0103oool02NX:00WZ2P3oool200WZ2P80oooo1009jPX01P3oool02NX:00WZ2P09jPX0
oooo00WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09jPX40?ooo`0300WZ2P3oool02NX:02H0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0?P3oool00`09jPX0oooo0?oo
o`0B0?ooo`0300WZ2P3oool0oooo01`0oooo5`09jPX0103oool02NX:00WZ2P3oool200WZ2P030?oo
o`09jPX02NX:00D02NX:00@0oooo00WZ2P09jPX0oooo3@09jPXB0?ooo`0300WZ2P3oool0oooo0080
oooo0P09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09
jPX00P09jPX0103oool02NX:00WZ2P3oool200WZ2P80oooo2009jPX0103oool02NX:0?ooo`3oool2
00WZ2P040?ooo`09jPX02NX:00WZ2P@0oooo00<02NX:0?ooo`09jPX09P3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0n0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:
0?ooo`3oool0703oool00`09jPX0oooo00WZ2P0900WZ2P030?ooo`09jPX02NX:00P02NX:00@0oooo
00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0500WZ2P040?ooo`09jPX02NX:0?ooo`d02NX:
4P3oool00`09jPX0oooo0?ooo`030?ooo`P02NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:
00WZ2P0200WZ2P040?ooo`09jPX02NX:0?ooo`802NX:0P3oool800WZ2P040?ooo`09jPX0oooo0?oo
o`802NX:00@0oooo00WZ2P09jPX02NX:103oool00`09jPX0oooo00WZ2P0V0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo03h0oooo00<02NX:0?ooo`3oool04P3oool00`09
jPX0oooo0?ooo`0L0?ooo`0500WZ2P3oool02NX:00WZ2P3oool01`09jPX00`3oool02NX:00WZ2P08
00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00<0oooo00WZ2P09jPX01@09jPX0103oool02NX:00WZ
2P3oool700WZ2P040?ooo`09jPX02NX:0?ooo`802NX:4`3oool00`09jPX0oooo0?ooo`020?ooo`P0
2NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX02NX:00WZ
2P3oool00P09jPX01@3oool02NX:00WZ2P09jPX0oooo00P02NX:00@0oooo00WZ2P3oool0oooo0P09
jPX0103oool02NX:00WZ2P09jPX40?ooo`0300WZ2P3oool02NX:02H0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool0?P3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3o
ool0oooo01`0oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0700WZ2P030?ooo`09jPX02NX:00/02NX:
00<0oooo00WZ2P09jPX02009jPX0103oool02NX:00WZ2P3oool700WZ2P030?ooo`09jPX02NX:00<0
2NX:4`3oool00`09jPX0oooo0?ooo`020?ooo`<02NX:00<0oooo00WZ2P09jPX03009jPX01`3oool0
2NX:00WZ2P09jPX0oooo00WZ2P3oool01009jPX00`3oool02NX:00WZ2P0600WZ2P040?ooo`09jPX0
oooo0?ooo`802NX:00@0oooo00WZ2P09jPX02NX:103oool00`09jPX0oooo00WZ2P0V0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03d0oooo00<02NX:0?ooo`3oool04`3o
ool00`09jPX0oooo0?ooo`0L0?ooo`@02NX:00<0oooo00WZ2P09jPX01@09jPX0103oool02NX:00WZ
2P3oool:00WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:
00WZ2P0900WZ2Q<0oooo00<02NX:0?ooo`3oool00P3oool200WZ2P030?ooo`09jPX02NX:00d02NX:
00@0oooo00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00H0
2NX:00@0oooo00WZ2P3oool0oooo0P09jPX0103oool02NX:00WZ2P09jPX40?ooo`0300WZ2P3oool0
2NX:02H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0?@3oool00`09
jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01`0oooo1009jPX00`3oool02NX:00WZ2P0500WZ
2P040?ooo`09jPX02NX:0?ooo`X02NX:00<0oooo00WZ2P09jPX02009jPX00`3oool02NX:00WZ2P02
00WZ2P030?ooo`09jPX02NX:00T02NX:4`3oool00`09jPX0oooo0?ooo`020?ooo`802NX:00<0oooo
00WZ2P09jPX03@09jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00802NX:00<0
oooo00WZ2P09jPX01P09jPX0103oool02NX:0?ooo`3oool200WZ2P040?ooo`09jPX02NX:00WZ2P@0
oooo00<02NX:0?ooo`09jPX09P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`0m0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool07@3oool;00WZ2P040?oo
o`09jPX02NX:0?ooo`X02NX:00<0oooo00WZ2P09jPX03@09jPX0103oool02NX:00WZ2P3oool700WZ
2Q@0oooo00<02NX:0?ooo`3oool00`3oool900WZ2P030?ooo`09jPX02NX:00D02NX:00@0oooo00WZ
2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo
00WZ2P3oool0oooo0P09jPX0103oool02NX:00WZ2P09jPX40?ooo`0300WZ2P3oool02NX:02H0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0?@3oool00`09jPX0oooo0?oo
o`0C0?ooo`0300WZ2P3oool0oooo01d0oooo1P09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09
jPX02NX:00P02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09
jPX02NX:00P02NX:5@3oool00`09jPX0oooo0?ooo`020?ooo`T02NX:00<0oooo00WZ2P09jPX01@09
jPX0103oool02NX:00WZ2P3oool200WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX0
1P09jPX0103oool02NX:0?ooo`3oool200WZ2P040?ooo`09jPX02NX:00WZ2P@0oooo0P09jPXW0?oo
o`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03d0oooo00<02NX:0?ooo`3o
ool04P3oool00`09jPX0oooo0?ooo`0N0?ooo`0300WZ2P3oool02NX:00h02NX:00<0oooo00WZ2P09
jPX01@09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09
jPX02009jPXE0?ooo`0300WZ2P3oool0oooo0080oooo0`09jPX00`3oool02NX:00WZ2P0200WZ2P03
0?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:00WZ2P0300WZ2P03
0?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P3oool0oooo0P09jPX0103oool02NX:00WZ2P09jPX4
0?ooo`802NX:9`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0m0?oo
o`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool07P3oool00`09jPX0oooo00WZ2P0600WZ
2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0500WZ
2P030?ooo`09jPX02NX:01002NX:5@3oool00`09jPX0oooo0?ooo`020?ooo`802NX:00<0oooo00WZ
2P09jPX02009jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:00<02NX:00<0oooo00WZ
2P09jPX01P09jPX0103oool02NX:0?ooo`3oool200WZ2P040?ooo`09jPX02NX:00WZ2P@0oooo0P09
jPXW0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03d0oooo00<02NX:
0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0N0?ooo`0500WZ2P3oool02NX:00WZ2P3oool03009
jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00802NX:00@0oooo00WZ2P09jPX0oooo
3`09jPX00`3oool02NX:00WZ2P0E0?ooo`0300WZ2P3oool0oooo0080oooo4P09jPX01@3oool02NX:
00WZ2P09jPX0oooo00802NX:00@0oooo00WZ2P09jPX0oooo2009jPX0103oool02NX:0?ooo`3oool2
00WZ2P040?ooo`09jPX02NX:00WZ2P<0oooo00<02NX:0?ooo`09jPX09`3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0m0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:
0?ooo`3oool07P3oool400WZ2P030?ooo`09jPX02NX:00X02NX:00<0oooo00WZ2P09jPX01@09jPX0
0`3oool02NX:00WZ2P0200WZ2P040?ooo`09jPX02NX:0?ooo``02NX:00<0oooo00WZ2P09jPX00`09
jPXE0?ooo`0300WZ2P3oool0oooo00<0oooo4@09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:
00@0oooo00WZ2P09jPX0oooo2009jPX0103oool02NX:0?ooo`3oool200WZ2P040?ooo`09jPX02NX:
00WZ2P<0oooo00<02NX:0?ooo`09jPX09`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0m0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool07`3oool300WZ
2P030?ooo`09jPX02NX:00X02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0200WZ
2P040?ooo`09jPX02NX:0?ooo`@02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P02
00WZ2QL0oooo00<02NX:0?ooo`3oool00P3oool900WZ2P030?ooo`09jPX02NX:00D02NX:00L0oooo
00WZ2P09jPX02NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX01P09jPX0103oool02NX:
0?ooo`3oool200WZ2P040?ooo`09jPX02NX:00WZ2P<0oooo00<02NX:0?ooo`09jPX09`3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0l0?ooo`0300WZ2P3oool0oooo01<0
oooo00<02NX:0?ooo`3oool07`3oool300WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09
jPX00P09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09
jPX01@09jPX00`3oool02NX:00WZ2P0:00WZ2QL0oooo00<02NX:0?ooo`3oool00P3oool200WZ2P03
0?ooo`09jPX02NX:00@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P070?ooo`09jPX02NX:
00WZ2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:00H02NX:00@0oooo00WZ2P3oool0oooo
0P09jPX0103oool02NX:00WZ2P09jPX30?ooo`0300WZ2P3oool02NX:02L0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0?03oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ
2P3oool0oooo01l0oooo2`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00D02NX:
00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:00X02NX:
5`3oool00`09jPX0oooo0?ooo`020?ooo`802NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:
00WZ2P0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0103oool02NX:00WZ2P3oool300WZ
2P80oooo1`09jPX0103oool02NX:0?ooo`3oool200WZ2P050?ooo`09jPX02NX:0?ooo`09jPX00P3o
ool00`09jPX0oooo00WZ2P0W0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo03`0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0O0?ooo`0300WZ2P3oool0
2NX:00<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0
2NX:00D02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX0
2NX:00X02NX:5`3oool00`09jPX0oooo0?ooo`030?ooo``02NX:00<0oooo00WZ2P09jPX01009jPX0
103oool02NX:00WZ2P3oool300WZ2P80oooo1`09jPX0103oool02NX:0?ooo`3oool200WZ2P050?oo
o`09jPX02NX:0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P0W0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo03`0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo
0?ooo`0O0?ooo`0300WZ2P3oool02NX:00P02NX:00<0oooo00WZ2P09jPX02P09jPX00`3oool02NX:
00WZ2P0:00WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX01@09jPXG0?ooo`0300WZ
2P3oool0oooo00<0oooo3009jPX00`3oool02NX:00WZ2P0400WZ2P040?ooo`09jPX02NX:0?ooo`<0
2NX:0P3oool700WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P02
0?ooo`0300WZ2P3oool02NX:02L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool0?03oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo0200oooo00D02NX:0?oo
o`09jPX02NX:0?ooo`0600WZ2P030?ooo`09jPX02NX:00X02NX:00<0oooo00WZ2P09jPX03009jPX0
0`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX02NX:01P0oooo00<02NX:0?ooo`3oool00P3ooolC
00WZ2P040?ooo`09jPX02NX:0?ooo`<02NX:0P3oool700WZ2P040?ooo`09jPX0oooo0?ooo`802NX:
00D0oooo00WZ2P09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool02NX:02L0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0?03oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ
2P3oool0oooo0200oooo1009jPX00`3oool02NX:00WZ2P0A00WZ2P030?ooo`09jPX02NX:00L02NX:
00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0800WZ2QP0oooo00<02NX:0?ooo`3oool0
0P3oool200WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX01`09jPX0103oool02NX:
00WZ2P3oool300WZ2P80oooo1`09jPX0103oool02NX:0?ooo`3oool200WZ2P050?ooo`09jPX02NX:
0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P0W0?ooo`030000003oool0oooo00D0oooo00070?oo
o`030000003oool0oooo03`0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0Q0?oo
o`<02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:
00L02NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:
00802NX:00<0oooo00WZ2P09jPX00P09jPXI0?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX00`3o
ool02NX:00WZ2P0400WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX01@3oool02NX:00WZ2P09
jPX0oooo00D02NX:00<0oooo00WZ2P09jPX01@09jPX0103oool02NX:0?ooo`3oool200WZ2P050?oo
o`09jPX02NX:0?ooo`09jPX00P3oool00`09jPX0oooo00WZ2P0W0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo03`0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo
0?ooo`0Q0?ooo`<02NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P0700WZ2P030?oo
o`09jPX02NX:00L02NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P0200WZ2QT0oooo
00<02NX:0?ooo`3oool00`3oool<00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool0
2NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00D02NX:00@0oooo00WZ2P3oool0oooo0P09jPX01@3o
ool02NX:00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX09`3oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`0k0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?oo
o`3oool08@3oool=00WZ2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P09jPX01`09jPX00`3o
ool02NX:00WZ2P0<00WZ2QT0oooo00<02NX:0?ooo`3oool00`3oool<00WZ2P030?ooo`09jPX02NX:
00D02NX:00L0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00L02NX:00@0oooo00WZ2P3oool0oooo
0P09jPX01@3oool02NX:00WZ2P3oool02NX:0080oooo00<02NX:0?ooo`09jPX09`3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0k0?ooo`0300WZ2P3oool0oooo01<0oooo
00<02NX:0?ooo`3oool08@3oool00`09jPX0oooo00WZ2P0:00WZ2P030?ooo`09jPX02NX:00L02NX:
00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P0<00WZ2QX0oooo00<02NX:0?ooo`3oool0
0P3oool200WZ2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P09jPX01@09jPX01`3oool02NX:
0?ooo`09jPX0oooo00WZ2P3oool01`09jPX0103oool02NX:0?ooo`3oool300WZ2P040?ooo`09jPX0
oooo00WZ2P80oooo00<02NX:0?ooo`09jPX09`3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0k0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool08@3oool0
0`09jPX0oooo00WZ2P0D00WZ2P030?ooo`09jPX02NX:01H02NX:6P3oool00`09jPX0oooo0?ooo`02
0?ooo`802NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P0500WZ2P070?ooo`09jPX0
oooo00WZ2P3oool02NX:0?ooo`0700WZ2P040?ooo`09jPX0oooo0?ooo`<02NX:00@0oooo00WZ2P3o
ool02NX:0P3oool00`09jPX0oooo00WZ2P0W0?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo03/0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0Q0?ooo`H0
2NX:00<0oooo00WZ2P09jPX03P09jPX00`3oool02NX:00WZ2P0C00WZ2P030?ooo`09jPX02NX:01X0
oooo00<02NX:0?ooo`3oool00P3oool200WZ2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P09
jPX01009jPX0203oool02NX:00WZ2P3oool02NX:0?ooo`09jPX0oooo1`09jPX0103oool02NX:0?oo
o`3oool300WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX09`3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0k0?ooo`0300WZ2P3oool0oooo0180oooo
00<02NX:0?ooo`3oool08P3oool400WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX0
2@09jPX00`3oool02NX:00WZ2P0>00WZ2P030?ooo`09jPX02NX:00D02NX:6P3oool00`09jPX0oooo
0?ooo`030?ooo`P02NX:00<0oooo00WZ2P09jPX01`09jPX0203oool02NX:00WZ2P3oool02NX:0?oo
o`09jPX0oooo1`09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00@0oooo00WZ2P3oool02NX:
0P3oool00`09jPX0oooo00WZ2P0W0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo03/0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0S0?ooo`<02NX:00<0
oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0900WZ2P030?ooo`09jPX02NX:00T02NX:00<0
oooo00WZ2P09jPX02@09jPXK0?ooo`0300WZ2P3oool0oooo00<0oooo2009jPX01@3oool02NX:00WZ
2P09jPX0oooo00D02NX:00P0oooo00WZ2P09jPX0oooo00WZ2P3oool02NX:0?ooo`L02NX:00D0oooo
00WZ2P3oool02NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo00<02NX:0?ooo`09jPX0
9`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0k0?ooo`0300WZ2P3o
ool0oooo0180oooo00<02NX:0?ooo`3oool08`3oool300WZ2P030?ooo`09jPX02NX:00@02NX:00<0
oooo00WZ2P09jPX02@09jPX00`3oool02NX:00WZ2P0900WZ2P030?ooo`09jPX02NX:00@02NX:00<0
oooo00WZ2P09jPX00P09jPXL0?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX00`3oool02NX:00WZ
2P0700WZ2P030?ooo`09jPX02NX:00H02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0700WZ2P050?oo
o`09jPX0oooo00WZ2P3oool00P09jPX0103oool02NX:0?ooo`09jPX20?ooo`0300WZ2P3oool02NX:
02L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0>`3oool00`09jPX0
oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo02<0oooo0`09jPX00`3oool02NX:00WZ2P0400WZ2P03
0?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0900WZ2P03
0?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX00P09jPXL0?ooo`0300WZ2P3oool0oooo0080
oooo0P09jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX02NX:00H02NX:00D0oooo00WZ2P09
jPX02NX:0?ooo`0700WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPX0103oool02NX:0?ooo`09
jPX20?ooo`802NX::03oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0k
0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool08`3oool00`09jPX0oooo00WZ2P05
00WZ2P030?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P09
00WZ2P030?ooo`09jPX0oooo00T02NX:703oool00`09jPX0oooo0?ooo`020?ooo`802NX:00<0oooo
00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P0600WZ2P050?ooo`09jPX02NX:00WZ2P3oool01`09
jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00@0oooo00WZ2P3oool02NX:0P3oool200WZ2RP0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0>P3oool00`09jPX0oooo
0?ooo`0C0?ooo`0300WZ2P3oool0oooo02<0oooo00<02NX:0?ooo`09jPX03009jPX00`3oool02NX:
00WZ2P0400WZ2P030?ooo`09jPX02NX:00/02NX:00<0oooo00WZ2P09jPX01`09jPXL0?ooo`0300WZ
2P3oool0oooo0080oooo3009jPX00`3oool02NX:00WZ2P0500WZ2P030?ooo`09jPX0oooo00802NX:
00<0oooo00WZ2P09jPX01@09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:00@0oooo00WZ2P3o
ool02NX:0P3oool200WZ2RP0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool0>P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo02<0oooo3`09jPX00`3oool0
2NX:00WZ2P0;00WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX01`09jPXL0?ooo`03
00WZ2P3oool0oooo00<0oooo0P09jPX00`3oool02NX:00WZ2P0>00WZ2P030?ooo`09jPX0oooo00X0
2NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0200WZ2P040?ooo`09jPX0oooo00WZ2P80oooo0P09jPXX
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03X0oooo00<02NX:0?oo
o`3oool04`3oool00`09jPX0oooo0?ooo`0T0?ooo`h02NX:00<0oooo00WZ2P09jPX02`09jPX00`3o
ool02NX:00WZ2P0=00WZ2Qh0oooo00<02NX:0?ooo`3oool00P3oool200WZ2P030?ooo`09jPX02NX:
00<02NX:00<0oooo00WZ2P09jPX02009jPX00`3oool02NX:0?ooo`0:00WZ2P040?ooo`09jPX02NX:
00WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`802NX::03oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0j0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:
0?ooo`3oool0903oool300WZ2P030?ooo`09jPX02NX:00P02NX:00<0oooo00WZ2P09jPX02`09jPX0
0`3oool02NX:00WZ2P0=00WZ2Qh0oooo00<02NX:0?ooo`3oool00P3oool200WZ2P030?ooo`09jPX0
2NX:00h02NX:00<0oooo00WZ2P3oool02P09jPX0103oool02NX:00WZ2P09jPX20?ooo`0500WZ2P3o
ool02NX:0?ooo`09jPX00P3oool200WZ2RP0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
00000?ooo`3oool0>P3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo02D0oooo0`09
jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:00d02NX:00<0oooo00WZ2P09jPX01P09
jPX00`3oool02NX:00WZ2P0400WZ2Qh0oooo00<02NX:0?ooo`3oool00P3oool200WZ2P030?ooo`09
jPX02NX:00X02NX:00<0oooo00WZ2P09jPX00`09jPX00`3oool02NX:00WZ2P0800WZ2P040?ooo`09
jPX02NX:00WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`802NX::03oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0j0?ooo`0300WZ2P3oool0oooo0180oooo
00<02NX:0?ooo`3oool09@3oool300WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ2P09jPX0
3@09jPX00`3oool02NX:00WZ2P0=00WZ2Qh0oooo00<02NX:0?ooo`3oool00P3oool<00WZ2P040?oo
o`09jPX02NX:0?ooo`D02NX:00<0oooo00WZ2P3oool02009jPX0103oool02NX:00WZ2P09jPX20?oo
o`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2RP0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0>P3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo
02D0oooo00<02NX:0?ooo`09jPX02@09jPX00`3oool02NX:00WZ2P0?00WZ2P030?ooo`09jPX02NX:
00H02NX:00<0oooo00WZ2P09jPX00P09jPXN0?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPX00`3o
ool02NX:00WZ2P0?00WZ2P030?ooo`09jPX0oooo00P02NX:00@0oooo00WZ2P09jPX02NX:0P3oool0
1@09jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPXX0?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo03X0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0U
0?ooo`0300WZ2P3oool02NX:00L02NX:00<0oooo00WZ2P09jPX04@09jPX00`3oool02NX:00WZ2P0;
00WZ2Ql0oooo00<02NX:0?ooo`3oool00P3oool200WZ2P030?ooo`09jPX02NX:00l02NX:00<0oooo
00WZ2P3oool02009jPX0103oool02NX:00WZ2P09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0
0P3oool200WZ2RP0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0>P3o
ool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo02D0oooo2P09jPX00`3oool02NX:00WZ
2P0A00WZ2P030?ooo`09jPX02NX:00/02NX:7`3oool00`09jPX0oooo0?ooo`020?ooo`802NX:00<0
oooo00WZ2P09jPX03`09jPX00`3oool02NX:0?ooo`0800WZ2P040?ooo`09jPX02NX:00WZ2P80oooo
00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`802NX::03oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0
9P3oool700WZ2P030?ooo`09jPX0oooo01D02NX:00<0oooo00WZ2P3oool01P09jPX00`3oool02NX:
0?ooo`0O0?ooo`0300WZ2P3oool0oooo0080oooo5009jPX00`3oool02NX:0?ooo`0800WZ2P040?oo
o`09jPX02NX:00WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P020?ooo`802NX::03oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo01<0
oooo00<02NX:0?ooo`3oool09P3oool900WZ2P030?ooo`09jPX02NX:01<02NX:00<0oooo00WZ2P3o
ool02009jPXP0?ooo`0300WZ2P3oool0oooo0080oooo0`09jPX00`3oool02NX:00WZ2P0700WZ2P03
0?ooo`09jPX0oooo00@02NX:00<0oooo00WZ2P09jPX02009jPX0103oool02NX:00WZ2P09jPX20?oo
o`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2RP0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo
02H0oooo0`09jPX00`3oool02NX:0?ooo`0I00WZ2P030?ooo`09jPX0oooo00P02NX:803oool00`09
jPX0oooo0?ooo`030?ooo`802NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:0?ooo`0300WZ
2P030?ooo`09jPX02NX:00T02NX:00@0oooo00WZ2P09jPX02NX:0P3oool01@09jPX0oooo00WZ2P3o
ool02NX:0080oooo0P09jPXX0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo03T0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0V0?ooo`<02NX:00<0oooo
00WZ2P09jPX06@09jPX00`3oool02NX:0?ooo`0800WZ2R40oooo00<02NX:0?ooo`3oool00P3oool2
00WZ2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P05
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09jPX0
0P3oool200WZ2RP0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0>@3o
ool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo02L0oooo00@02NX:0?ooo`09jPX0oooo
3P09jPX00`3oool02NX:00WZ2P0E00WZ2R40oooo00<02NX:0?ooo`3oool00P3oool200WZ2P050?oo
o`09jPX02NX:00WZ2P3oool01@09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX0oooo00D0
2NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P80oooo00D02NX:0?ooo`09jPX0oooo00WZ2P02
0?ooo`802NX::03oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0i0?oo
o`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool09`3oool00`09jPX0oooo00WZ2P0?00WZ
2P030?ooo`09jPX02NX:00h02NX:00<0oooo00WZ2P3oool01009jPXQ0?ooo`0300WZ2P3oool0oooo
0080oooo5009jPX00`3oool02NX:00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX2
0?ooo`0500WZ2P3oool02NX:0?ooo`09jPX00P3oool200WZ2RP0oooo00<000000?ooo`3oool01@3o
ool000L0oooo00<000000?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0
oooo02L0oooo4P09jPX00`3oool02NX:00WZ2P0E00WZ2R40oooo00<02NX:0?ooo`3oool00P3oool3
00WZ2P030?ooo`09jPX02NX:00h02NX:00<0oooo00WZ2P09jPX00`09jPX01@3oool02NX:00WZ2P09
jPX0oooo00<02NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPXX0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03T0oooo00<02NX:0?ooo`3oool04P3o
ool00`09jPX0oooo0?ooo`0X0?oooa402NX:00<0oooo00WZ2P09jPX04P09jPX00`3oool02NX:0?oo
o`0Q0?ooo`0300WZ2P3oool0oooo0080oooo0`09jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09
jPX02NX:00@02NX:00<0oooo00WZ2P09jPX00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:
0P3oool01@09jPX0oooo00WZ2P3oool02NX:0080oooo0P09jPXX0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo03T0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo
0?ooo`0X0?ooo`d02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0F00WZ2R<0oooo00<02NX:0?ooo`3o
ool00P3oool200WZ2P030?ooo`09jPX02NX:00L02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ
2P030?ooo`09jPX02NX:00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P80oooo00D02NX:
0?ooo`09jPX0oooo00WZ2P020?ooo`802NX::03oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0h0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0:03oool=
00WZ2P030?ooo`09jPX02NX:01P02NX:8`3oool00`09jPX0oooo0?ooo`020?ooo`802NX:00<0oooo
00WZ2P09jPX01`09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P09jPX00`09
jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:0P3oool01@09jPX0oooo00WZ2P3oool02NX:0080
oooo0P09jPXX0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03P0oooo
00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0X0?ooo`<02NX:00/0oooo00WZ2P09jPX0
2NX:0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`0J00WZ2R<0oooo00<02NX:0?ooo`3oool00P3o
ool600WZ2P030?ooo`09jPX02NX:00<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2P030?oo
o`09jPX02NX:00<02NX:00<0oooo00WZ2P09jPX01@09jPX20?ooo`0500WZ2P3oool02NX:0?ooo`09
jPX00P3oool200WZ2RP0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
>03oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo02P0oooo00H02NX:0?ooo`09jPX0
oooo00WZ2P3oool300WZ2P050?ooo`09jPX0oooo00WZ2P3oool06P09jPXS0?ooo`0300WZ2P3oool0
oooo0080oooo0`09jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX02NX:00@02NX:00@0oooo
00WZ2P09jPX0oooo0P09jPX00`3oool02NX:00WZ2P0500WZ2P80oooo0`09jPX01@3oool02NX:0?oo
o`3oool02NX:02T0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0>03o
ool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo02T0oooo00@02NX:0?ooo`09jPX0oooo
1@09jPX01@3oool02NX:00WZ2P09jPX0oooo01402NX:00<0oooo00WZ2P09jPX01P09jPXT0?ooo`04
00WZ2P3oool0oooo0?ooo`<02NX:00<0oooo00WZ2P09jPX03@09jPX0103oool02NX:00WZ2P3oool2
00WZ2P030?ooo`09jPX02NX:00D02NX:0P3oool300WZ2P050?ooo`09jPX0oooo0?ooo`09jPX0:@3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0h0?ooo`0300WZ2P3oool0
oooo0180oooo00<02NX:0?ooo`3oool0:P3ooolF00WZ2P030?ooo`09jPX02NX:00D02NX:00D0oooo
00WZ2P09jPX02NX:0?ooo`0400WZ2R@0oooo00<02NX:0?ooo`3oool00P3oool200WZ2P030?ooo`09
jPX02NX:00`02NX:00<0oooo00WZ2P09jPX03009jPX20?ooo`<02NX:00D0oooo00WZ2P3oool0oooo
00WZ2P0Y0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03P0oooo00<0
2NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0Z0?oooaH02NX:00d0oooo00WZ2P09jPX02NX:
0?ooo`09jPX0oooo00WZ2P3oool02NX:0?ooo`09jPX0oooo00<02NX:9@3oool00`09jPX0oooo0?oo
o`020?ooo`802NX:00<0oooo00WZ2P09jPX01`09jPX00`3oool02NX:00WZ2P0A00WZ2P80oooo0`09
jPX01@3oool02NX:0?ooo`3oool02NX:02T0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
00000?ooo`3oool0>03oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo02X0oooo5P09
jPX01`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool02@09jPXU0?ooo`0300WZ2P3oool0oooo0080
oooo3009jPX01@3oool02NX:00WZ2P09jPX0oooo00l02NX:0P3oool300WZ2P050?ooo`09jPX0oooo
0?ooo`09jPX0:@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0h0?oo
o`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0:P3ooolF00WZ2P070?ooo`09jPX0oooo
00WZ2P3oool02NX:0?ooo`0900WZ2RD0oooo00<02NX:0?ooo`3oool00P3oool300WZ2P040?ooo`09
jPX02NX:0?ooo`D02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0?00WZ2P80oooo0`09jPX01@3oool0
2NX:0?ooo`3oool02NX:02T0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool0>03oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo02X0oooo0`09jPX00`3oool0
2NX:00WZ2P0B00WZ2P030?ooo`09jPX02NX:00/02NX:9P3oool01009jPX0oooo0?ooo`3oool300WZ
2P030?ooo`09jPX02NX:00X02NX:00<0oooo00WZ2P09jPX03@09jPX20?ooo`<02NX:00D0oooo00WZ
2P3oool0oooo00WZ2P0Y0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
03L0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0Z0?ooo`0400WZ2P3oool02NX:
0?oooa@02NX:00<0oooo00WZ2P09jPX02`09jPXV0?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX0
0`3oool02NX:00WZ2P0:00WZ2P030?ooo`09jPX02NX:00d02NX:0P3oool300WZ2P050?ooo`09jPX0
oooo0?ooo`09jPX0:@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0g
0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0:P3oool300WZ2P030?ooo`09jPX0
2NX:01802NX:00<0oooo00WZ2P09jPX02`09jPXV0?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX0
0`3oool02NX:00WZ2P0:00WZ2P050?ooo`09jPX02NX:00WZ2P3oool02`09jPX20?ooo`802NX:00H0
oooo00WZ2P3oool02NX:0?ooo`09jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo03L0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0[0?ooo`H02NX:
00<0oooo00WZ2P09jPX06`09jPXW0?ooo`0300WZ2P3oool0oooo0080oooo3`09jPX0103oool02NX:
00WZ2P3oool<00WZ2P80oooo0P09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2RT0oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0=`3oool00`09jPX0oooo0?ooo`0B0?oo
o`0300WZ2P3oool0oooo02`0oooo9009jPXW0?ooo`0300WZ2P3oool0oooo0080oooo0`09jPX00`3o
ool02NX:00WZ2P0<00WZ2P030?ooo`09jPX02NX:00X02NX:0P3oool200WZ2P060?ooo`09jPX0oooo
00WZ2P3oool02NX::@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0g
0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0;03oool800WZ2P030?ooo`09jPX0
2NX:01D02NX:00@0oooo00WZ2P09jPX02NX::03oool01009jPX0oooo0?ooo`3oool300WZ2P040?oo
o`09jPX02NX:0?ooo`/02NX:00<0oooo00WZ2P09jPX01P09jPX0103oool02NX:0?ooo`09jPX20?oo
o`802NX:00H0oooo00WZ2P3oool02NX:0?ooo`09jPXY0?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo03L0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0/
0?ooo`P02NX:00<0oooo00WZ2P09jPX06@09jPXX0?ooo`0400WZ2P3oool0oooo0?ooo`<02NX:00<0
oooo00WZ2P09jPX03009jPX00`3oool02NX:00WZ2P0300WZ2P030?ooo`09jPX02NX:00802NX:00@0
oooo00WZ2P3oool0oooo0P09jPX01P3oool02NX:0?ooo`09jPX0oooo00WZ2RT0oooo00<000000?oo
o`3oool01@3oool000L0oooo00<000000?ooo`3oool0=`3oool00`09jPX0oooo0?ooo`0B0?ooo`03
00WZ2P3oool0oooo02`0oooo2009jPX00`3oool02NX:0?ooo`0A00WZ2P030?ooo`09jPX02NX:00D0
2NX::03oool00`09jPX0oooo0?ooo`020?ooo`802NX:00<0oooo00WZ2P09jPX04P09jPX00`3oool0
2NX:00WZ2P0200WZ2P040?ooo`09jPX0oooo0?ooo`802NX:00H0oooo00WZ2P3oool02NX:0?ooo`09
jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03L0oooo00<02NX:
0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0/0?ooo`0400WZ2P3oool02NX:0?ooo`H02NX:00<0
oooo00WZ2P09jPX03`09jPX00`3oool02NX:00WZ2P0500WZ2RP0oooo00<02NX:0?ooo`3oool00P3o
ool?00WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:0?oo
o`0300WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX::@3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`0g0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0
;03oool300WZ2P030?ooo`09jPX02NX:01h02NX::03oool00`09jPX0oooo0?ooo`020?ooo`l02NX:
00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00<02NX:
00H0oooo00WZ2P3oool02NX:0?ooo`09jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo03H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0]0?ooo`80
2NX:00<0oooo00WZ2P09jPX07@09jPXZ0?ooo`0400WZ2P3oool0oooo0?ooo`<02NX:00<0oooo00WZ
2P09jPX04@09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX0oooo00<02NX:00H0oooo00WZ
2P3oool02NX:0?ooo`09jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo03H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0]0?ooo`@02NX:00<0oooo
00WZ2P09jPX01009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo
00WZ2P09jPX01P09jPXZ0?ooo`0400WZ2P3oool0oooo0?ooo`<02NX:00<0oooo00WZ2P09jPX05P09
jPX00`3oool02NX:0?ooo`0300WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX::@3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0f0?ooo`0300WZ2P3oool0oooo01<0oooo
00<02NX:0?ooo`3oool0;@3oool;00WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P09jPX0
1009jPX00`3oool02NX:00WZ2P0400WZ2P030?ooo`09jPX0oooo02T0oooo00<02NX:0?ooo`3oool0
0P3oool700WZ2P030?ooo`09jPX02NX:01402NX:00<0oooo00WZ2P3oool00`09jPX01P3oool02NX:
0?ooo`09jPX0oooo00WZ2RT0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool0=P3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo02h0oooo2`09jPX00`3oool0
2NX:00WZ2P0400WZ2P030?ooo`09jPX02NX:00T02NX:00@0oooo00WZ2P09jPX02NX::P3oool00`09
jPX0oooo0?ooo`020?oooa802NX:00<0oooo00WZ2P09jPX01P09jPX00`3oool02NX:0?ooo`0300WZ
2P060?ooo`09jPX0oooo00WZ2P3oool02NX::@3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0f0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0;P3ooolB
00WZ2P030?ooo`09jPX02NX:00d02NX::P3oool00`09jPX0oooo0?ooo`020?oooa802NX:00<0oooo
00WZ2P09jPX01P09jPX00`3oool02NX:0?ooo`0300WZ2P060?ooo`09jPX0oooo00WZ2P3oool02NX:
:@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0f0?ooo`0300WZ2P3o
ool0oooo0180oooo00<02NX:0?ooo`3oool0;P3oool00`09jPX0oooo00WZ2P0?00WZ2P030?ooo`09
jPX02NX:00802NX:00<0oooo00WZ2P09jPX02009jPX[0?ooo`0400WZ2P3oool0oooo0?ooo`<02NX:
00<0oooo00WZ2P09jPX03009jPX00`3oool02NX:00WZ2P0600WZ2P030?ooo`09jPX0oooo00<02NX:
00<0oooo00WZ2P3oool00`09jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo03H0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0^0?ooo`<02NX:00<0
oooo00WZ2P09jPX03009jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00802NX:00<0
oooo00WZ2P09jPX00`09jPX[0?ooo`0400WZ2P3oool0oooo0?ooo`<02NX:00<0oooo00WZ2P09jPX0
0P09jPX00`3oool02NX:00WZ2P0700WZ2P030?ooo`09jPX02NX:00H02NX:00<0oooo00WZ2P3oool0
0`09jPX00`3oool02NX:0?ooo`0300WZ2RT0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
00000?ooo`3oool0=P3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo02l0oooo0P09
jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P09jPX03009
jPX/0?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo1P09jPX00`3oool02NX:00WZ2P0700WZ2P03
0?ooo`09jPX02NX:00P02NX:00L0oooo00WZ2P09jPX02NX:0?ooo`09jPX0oooo00<02NX::@3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0e0?ooo`0300WZ2P3oool0oooo
01<0oooo00<02NX:0?ooo`3oool0;`3oool700WZ2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ
2P09jPX01@09jPX00`3oool02NX:00WZ2P0400WZ2R`0oooo00<02NX:0?ooo`3oool00P3oool700WZ
2P030?ooo`09jPX02NX:00L02NX:00<0oooo00WZ2P09jPX02009jPX01`3oool02NX:00WZ2P09jPX0
oooo00WZ2P3oool00`09jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo03D0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0_0?oooa402NX:00<0oooo
00WZ2P09jPX01@09jPX00`3oool02NX:00WZ2P0400WZ2R`0oooo00<02NX:0?ooo`3oool00P3oool7
00WZ2P030?ooo`09jPX02NX:01802NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0103oool02NX:00WZ
2P09jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03D0oooo00<0
2NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0_0?oooa402NX:00<0oooo00WZ2P09jPX03009
jPX]0?ooo`0400WZ2P3oool0oooo0?ooo`<02NX:00<0oooo00WZ2P09jPX01009jPX00`3oool02NX:
00WZ2P0?00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX02NX::@3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0e0?ooo`0300WZ2P3oool0oooo0180
oooo00<02NX:0?ooo`3oool0<03ooolA00WZ2P030?ooo`09jPX02NX:00P02NX:00@0oooo00WZ2P09
jPX02NX:;@3oool01009jPX0oooo0?ooo`3oool300WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo
00WZ2P09jPX03`09jPX0103oool02NX:00WZ2P3oool200WZ2P040?ooo`09jPX02NX:00WZ2RT0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0=@3oool00`09jPX0oooo0?oo
o`0B0?ooo`0300WZ2P3oool0oooo0300oooo00<02NX:0?ooo`09jPX01P09jPX00`3oool02NX:00WZ
2P0D00WZ2Rd0oooo00H02NX:0?ooo`3oool0oooo00WZ2P3oool600WZ2P030?ooo`09jPX0oooo0140
2NX:00@0oooo00WZ2P09jPX0oooo0P09jPX0103oool02NX:00WZ2P09jPXY0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo03D0oooo00<02NX:0?ooo`3oool04P3oool00`09
jPX0oooo0?ooo`0a0?oooa<02NX:00<0oooo00WZ2P09jPX02009jPX^0?ooo`0300WZ2P3oool0oooo
0080oooo1`09jPX00`3oool02NX:0?ooo`0A00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo
00WZ2P09jPX02NX::@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0e
0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0<@3oool200WZ2P030?ooo`09jPX0
2NX:00h02NX:00<0oooo00WZ2P09jPX02009jPX^0?ooo`0300WZ2P3oool0oooo0080oooo1`09jPX0
0`3oool02NX:00WZ2P0A00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX02NX:
:@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0e0?ooo`0300WZ2P3o
ool0oooo0180oooo00<02NX:0?ooo`3oool0<@3oool200WZ2P030?ooo`09jPX02NX:01402NX:00<0
oooo00WZ2P09jPX01@09jPX_0?ooo`0400WZ2P3oool0oooo0?ooo`<02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0C00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX02NX::@3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0e0?ooo`0300WZ2P3oool0oooo
0180oooo00<02NX:0?ooo`3oool0<@3ooolN00WZ2Rl0oooo00@02NX:0?ooo`3oool0oooo1`09jPX0
103oool02NX:00WZ2P3oool@00WZ2P040?ooo`09jPX02NX:0?ooo`802NX:00@0oooo00WZ2P09jPX0
2NX::@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0d0?ooo`0300WZ
2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0<@3ooolN00WZ2Rl0oooo00H02NX:0?ooo`3oool0
oooo00WZ2P3oool800WZ2P030?ooo`09jPX02NX:00h02NX:00<0oooo00WZ2P3oool00`09jPX0103o
ool02NX:00WZ2P09jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
03@0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0a0?oooah02NX:;`3oool00`09
jPX0oooo0?ooo`020?ooo`T02NX:00<0oooo00WZ2P09jPX03P09jPX00`3oool02NX:0?ooo`0300WZ
2P040?ooo`09jPX02NX:00WZ2RT0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool0=03oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo0340oooo1`09jPX00`3o
ool02NX:00WZ2P0D00WZ2Rl0oooo00<02NX:0?ooo`3oool00P3oool900WZ2P030?ooo`09jPX02NX:
00h02NX:00<0oooo00WZ2P3oool00`09jPX0103oool02NX:00WZ2P09jPXY0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo03@0oooo00<02NX:0?ooo`3oool04P3oool00`09
jPX0oooo0?ooo`0c0?ooo`H02NX:00@0oooo00WZ2P09jPX0oooo3009jPX00`3oool02NX:00WZ2P03
00WZ2S40oooo00@02NX:0?ooo`3oool0oooo1`09jPX00`3oool02NX:00WZ2P0@00WZ2P030?ooo`09
jPX0oooo00<02NX:00@0oooo00WZ2P09jPX02NX::@3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0d0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0<`3o
ool900WZ2P030?ooo`09jPX02NX:01002NX:<@3oool01009jPX0oooo0?ooo`3oool700WZ2P040?oo
o`09jPX02NX:0?ooo`l02NX:00<0oooo00WZ2P3oool00`09jPX0103oool02NX:00WZ2P09jPXY0?oo
o`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03@0oooo00<02NX:0?ooo`3o
ool04P3oool00`09jPX0oooo0?ooo`0c0?ooo`802NX:00<0oooo00WZ2P09jPX05`09jPXa0?ooo`06
00WZ2P3oool0oooo0?ooo`09jPX0oooo1@09jPX0103oool02NX:00WZ2P3oool?00WZ2P030?ooo`09
jPX0oooo00<02NX:00@0oooo00WZ2P09jPX02NX::@3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0d0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0<`3o
oolC00WZ2P030?ooo`09jPX02NX:00H02NX:<@3oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`P0
2NX:00<0oooo00WZ2P09jPX03@09jPX00`3oool02NX:0?ooo`0300WZ2P040?ooo`09jPX02NX:00WZ
2RT0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0=03oool00`09jPX0
oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo03<0oooo6P09jPX00`3oool02NX:0?ooo`0`0?ooo`03
00WZ2P3oool0oooo0080oooo6@09jPX00`3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:02X0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0=03oool00`09jPX0oooo
0?ooo`0B0?ooo`0300WZ2P3oool0oooo03<0oooo3009jPX00`3oool02NX:00WZ2P0800WZ2P030?oo
o`09jPX02NX:00802NX:<P3oool01009jPX0oooo0?ooo`3ooolE00WZ2P070?ooo`09jPX02NX:00WZ
2P3oool02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:02X0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0<`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo
03<0oooo3009jPX00`3oool02NX:00WZ2P0=00WZ2S80oooo00@02NX:0?ooo`3oool0oooo5@09jPX0
1`3oool02NX:00WZ2P09jPX0oooo00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0Z0?ooo`030000
003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03<0oooo00<02NX:0?ooo`3oool04`3o
ool00`09jPX0oooo0?ooo`0d0?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0B00WZ2S<0oooo
00H02NX:0?ooo`3oool0oooo00WZ2P3oool500WZ2P030?ooo`09jPX02NX:00/02NX:00L0oooo00WZ
2P09jPX02NX:0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ2P09jPX0:P3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0c0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:
0?ooo`3oool0=@3oool?00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool02NX:00WZ
2P0c0?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo4`09jPX01`3oool02NX:00WZ2P09jPX0oooo
00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P0Z0?ooo`030000003oool0oooo00D0oooo00070?oo
o`030000003oool0oooo03<0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0e0?oo
o`802NX:00<0oooo00WZ2P09jPX05@09jPXc0?ooo`0300WZ2P3oool0oooo0080oooo5009jPX00`3o
ool02NX:00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00P09jPXZ0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo03<0oooo00<02NX:0?ooo`3oool04P3oool00`09
jPX0oooo0?ooo`0e0?ooo`802NX:00<0oooo00WZ2P09jPX05@09jPXd0?ooo`0400WZ2P3oool0oooo
0?oooa@02NX:00<0oooo00WZ2P09jPX00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX::P3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0c0?ooo`0300WZ2P3oool0
oooo0180oooo00<02NX:0?ooo`3oool0=@3oool600WZ2P030?ooo`09jPX02NX:01402NX:=03oool0
1009jPX0oooo0?ooo`3ooolD00WZ2P030?ooo`09jPX02NX:00<02NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0200WZ2RX0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0<`3o
ool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo03D0oooo6P09jPXd0?ooo`0600WZ2P3o
ool0oooo0?ooo`09jPX0oooo4P09jPX00`3oool02NX:00WZ2P0300WZ2P050?ooo`09jPX02NX:00WZ
2P3oool00P09jPXZ0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo03<0
oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0f0?oooaP02NX:=@3oool01P09jPX0
oooo0?ooo`3oool02NX:0?oooa802NX:00<0oooo00WZ2P09jPX00`09jPX01@3oool02NX:00WZ2P09
jPX0oooo00802NX::P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0c
0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0=P3ooolH00WZ2SD0oooo00H02NX:
0?ooo`3oool0oooo00WZ2P3ooolB00WZ2P030?ooo`09jPX02NX:00<02NX:00D0oooo00WZ2P3oool0
2NX:0?ooo`0200WZ2RX0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
<P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo03H0oooo6009jPXf0?ooo`0400WZ
2P3oool0oooo0?oooa<02NX:00<0oooo00WZ2P09jPX00`09jPX01@3oool02NX:0?ooo`09jPX0oooo
00802NX::P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0b0?ooo`03
00WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0=P3ooolE00WZ2P030?ooo`09jPX02NX:03H0
oooo00H02NX:0?ooo`3oool0oooo00WZ2P3oool<00WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo
00WZ2P09jPX00`09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX::P3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0b0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:
0?ooo`3oool0=`3oool200WZ2P030?ooo`09jPX02NX:00X02NX:00<0oooo00WZ2P09jPX01P09jPXf
0?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo3009jPX00`3oool02NX:00WZ2P0200WZ2P030?oo
o`09jPX02NX:00<02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2RX0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0<P3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ
2P3oool0oooo03L0oooo0P09jPX00`3oool02NX:00WZ2P0C00WZ2SH0oooo00H02NX:0?ooo`3oool0
oooo00WZ2P3oool700WZ2P030?ooo`09jPX02NX:00802NX:00<0oooo00WZ2P09jPX00P09jPX00`3o
ool02NX:00WZ2P0300WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPXZ0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo0380oooo00<02NX:0?ooo`3oool04P3oool00`09
jPX0oooo0?ooo`0g0?ooo`P02NX:00<0oooo00WZ2P09jPX03@09jPXg0?ooo`0500WZ2P3oool0oooo
00WZ2P3oool04@09jPX00`3oool02NX:00WZ2P0300WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09
jPXZ0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0380oooo00<02NX:
0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0h0?ooo`l02NX:00<0oooo00WZ2P09jPX01009jPXh
0?ooo`0400WZ2P3oool0oooo0?oooa802NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`0400WZ2P3o
ool02NX:0?ooo`802NX::P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0b0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0>03ooolF00WZ2SP0oooo00H0
2NX:0?ooo`3oool0oooo00WZ2P3oool@00WZ2P030?ooo`09jPX02NX:00802NX:0P3oool01009jPX0
oooo00WZ2P3oool200WZ2RX0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool0<P3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo03P0oooo5P09jPXh0?ooo`06
00WZ2P3oool0oooo0?ooo`09jPX0oooo4009jPX00`3oool02NX:00WZ2P0200WZ2P80oooo00@02NX:
0?ooo`09jPX0oooo0P09jPXZ0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo0380oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0h0?oooaH02NX:>03oool0
1P09jPX0oooo0?ooo`3oool02NX:0?oooaH02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2RX0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0<@3oool00`09jPX0oooo
0?ooo`0C0?ooo`0300WZ2P3oool0oooo03P0oooo5P09jPXi0?ooo`0500WZ2P3oool0oooo00WZ2P3o
ool05P09jPX01@3oool02NX:0?ooo`09jPX0oooo00802NX::P3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0a0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3o
ool0>03oool200WZ2P030?ooo`09jPX02NX:01402NX:>@3oool01009jPX0oooo0?ooo`3ooolG00WZ
2P050?ooo`09jPX0oooo00WZ2P3oool00P09jPXZ0?ooo`030000003oool0oooo00D0oooo00070?oo
o`030000003oool0oooo0340oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0i0?oo
oaH02NX:>@3oool01009jPX0oooo0?ooo`3ooolG00WZ2P050?ooo`09jPX0oooo00WZ2P3oool00P09
jPXZ0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0340oooo00<02NX:
0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0j0?oooa@02NX:>P3oool01P09jPX0oooo0?ooo`3o
ool02NX:0?oooaD02NX:00D0oooo00WZ2P3oool02NX:0?ooo`0200WZ2RX0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0<@3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ
2P3oool0oooo03X0oooo5009jPXj0?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo4P09jPX01P3o
ool02NX:00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P3oool0:@3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0a0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:
0?ooo`3oool0>P3oool200WZ2Q00oooo0P09jPXk0?ooo`0500WZ2P3oool0oooo00WZ2P3oool04P09
jPX01P3oool02NX:00WZ2P3oool02NX:0?ooo`802NX:00<0oooo00WZ2P3oool0:@3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0a0?ooo`0300WZ2P3oool0oooo0180oooo
00<02NX:0?ooo`3oool0R@3oool01@09jPX0oooo0?ooo`09jPX0oooo01802NX:00H0oooo00WZ2P09
jPX0oooo00WZ2P3oool200WZ2P030?ooo`09jPX0oooo02T0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0<@3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo
08T0oooo00@02NX:0?ooo`3oool0oooo5P09jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0
oooo02T0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0<03oool00`09
jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo08T0oooo00H02NX:0?ooo`3oool0oooo00WZ2P3o
oolD00WZ2P030?ooo`09jPX0oooo00802NX:00<0oooo00WZ2P3oool0:@3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0`0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:
0?ooo`3oool0R@3oool01P09jPX0oooo0?ooo`3oool02NX:0?oooa@02NX:00<0oooo00WZ2P3oool0
0P09jPX00`3oool02NX:0?ooo`0Y0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo0300oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2;0?ooo`0500WZ2P3o
ool0oooo00WZ2P3oool05009jPX00`3oool02NX:0?ooo`0200WZ2P030?ooo`09jPX0oooo02T0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0<03oool00`09jPX0oooo0?oo
o`0B0?ooo`0300WZ2P3oool0oooo08/0oooo00D02NX:0?ooo`3oool02NX:0?ooo`0F00WZ2P050?oo
o`09jPX02NX:0?ooo`09jPX0:P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`0`0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0R`3oool01009jPX0oooo
0?ooo`3ooolG00WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0:P3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0`0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3o
ool0R`3oool01P09jPX0oooo0?ooo`3oool02NX:0?oooaD02NX:00D0oooo00WZ2P09jPX0oooo00WZ
2P0Z0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0300oooo00<02NX:
0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2;0?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo
5@09jPX01@3oool02NX:00WZ2P3oool02NX:02X0oooo00<000000?ooo`3oool01@3oool000L0oooo
00<000000?ooo`3oool0<03oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo08`0oooo
00D02NX:0?ooo`3oool02NX:0?ooo`0E00WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0:P3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0`0?ooo`0300WZ2P3oool0oooo0180
oooo00<02NX:0?ooo`3oool0S03oool01@09jPX0oooo0?ooo`09jPX0oooo01D02NX:00D0oooo00WZ
2P09jPX0oooo00WZ2P0Z0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
02l0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`2<0?ooo`0400WZ2P3oool0oooo
0?oooaH02NX:00D0oooo00WZ2P09jPX0oooo00WZ2P0Z0?ooo`030000003oool0oooo00D0oooo0007
0?ooo`030000003oool0oooo02l0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`2<
0?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo5009jPX01@3oool02NX:00WZ2P3oool02NX:02X0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0;`3oool00`09jPX0oooo
0?ooo`0B0?ooo`0300WZ2P3oool0oooo08d0oooo00H02NX:0?ooo`3oool0oooo00WZ2P3oool?00WZ
2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P0Z0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo02l0oooo00<02NX:0?ooo`3oool04P3oool00`09
jPX0oooo0?ooo`2>0?ooo`0500WZ2P3oool0oooo00WZ2P3oool03`09jPX00`3oool02NX:00WZ2P02
00WZ2P050?ooo`09jPX02NX:0?ooo`09jPX0:P3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0_0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0SP3oool0
1@09jPX0oooo0?ooo`09jPX0oooo00l02NX:00<0oooo00WZ2P09jPX00P09jPX01@3oool02NX:00WZ
2P3oool02NX:02X0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0;`3o
ool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo08h0oooo00D02NX:0?ooo`3oool02NX:
0?ooo`0?00WZ2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P09jPX0oooo00WZ2P0Z0?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02l0oooo00<02NX:0?ooo`3oool0
4P3oool00`09jPX0oooo0?ooo`2>0?ooo`0400WZ2P3oool0oooo0?oooa002NX:00<0oooo00WZ2P09
jPX00P09jPX01@3oool02NX:00WZ2P3oool02NX:02X0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0;`3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo08h0
oooo00H02NX:0?ooo`3oool0oooo00WZ2P3oool>00WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo
00WZ2P3oool0:@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0_0?oo
o`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0S`3oool01@09jPX0oooo0?ooo`09jPX0
oooo00h02NX:00<0oooo00WZ2P09jPX01@09jPX00`3oool02NX:0?ooo`0Y0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo02h0oooo00<02NX:0?ooo`3oool04`3oool00`09
jPX0oooo0?ooo`2?0?ooo`0500WZ2P3oool0oooo00WZ2P3oool03P09jPX00`3oool02NX:00WZ2P05
00WZ2P030?ooo`09jPX0oooo02T0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool0;P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo08l0oooo00D02NX:0?oo
o`3oool02NX:0?ooo`0>00WZ2P030?ooo`09jPX02NX:00D02NX:00<0oooo00WZ2P3oool0:@3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0^0?ooo`0300WZ2P3oool0oooo
0180oooo00<02NX:0?ooo`3oool0T03oool01009jPX0oooo0?ooo`3ooolG00WZ2P030?ooo`09jPX0
oooo02T0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0;P3oool00`09
jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo0900oooo00@02NX:0?ooo`3oool0oooo5`09jPX0
0`3oool02NX:0?ooo`0Y0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
02h0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2A0?ooo`0300WZ2P3oool0oooo
01L02NX:00<0oooo00WZ2P3oool0:@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0^0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0T@3oool01@09jPX0
oooo0?ooo`09jPX0oooo01D02NX:00<0oooo00WZ2P3oool0:@3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0^0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3o
ool0T@3oool01@09jPX0oooo0?ooo`09jPX0oooo01D02NX:00<0oooo00WZ2P3oool0:@3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0^0?ooo`0300WZ2P3oool0oooo0180
oooo00<02NX:0?ooo`3oool0T@3oool01@09jPX0oooo0?ooo`09jPX0oooo01D02NX:00<0oooo00WZ
2P3oool0:@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0^0?ooo`03
00WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0T@3oool01009jPX0oooo0?ooo`3ooolF00WZ
2P030?ooo`09jPX0oooo02T0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool0;@3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo0980oooo00<02NX:0?ooo`3o
ool04@09jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:02T0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0;@3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ
2P3oool0oooo09<0oooo00<02NX:0?ooo`3oool04@09jPX00`3oool02NX:00WZ2P0200WZ2P030?oo
o`09jPX02NX:02T0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0;@3o
ool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo09<0oooo00<02NX:0?ooo`3oool04@09
jPX00`3oool02NX:00WZ2P0200WZ2P030?ooo`09jPX02NX:02T0oooo00<000000?ooo`3oool01@3o
ool000L0oooo00<000000?ooo`3oool0;@3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0
oooo09<0oooo00D02NX:0?ooo`3oool02NX:0?ooo`0?00WZ2P030?ooo`09jPX02NX:00802NX:00<0
oooo00WZ2P09jPX0:@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0]
0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0T`3oool01009jPX0oooo0?ooo`3o
ool@00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPXY0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo02d0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?oo
o`2D0?ooo`0300WZ2P3oool0oooo01002NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2RT0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0;@3oool00`09jPX0oooo0?oo
o`0B0?ooo`0300WZ2P3oool0oooo09@0oooo00<02NX:0?ooo`3oool04009jPX01@3oool02NX:00WZ
2P09jPX0oooo00<02NX::@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0]0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0U03oool00`09jPX0oooo0?oo
o`0@00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPXY0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo02d0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?oo
o`2D0?ooo`0300WZ2P3oool0oooo01002NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2RT0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0;03oool00`09jPX0oooo0?oo
o`0C0?ooo`0300WZ2P3oool0oooo09@0oooo00@02NX:0?ooo`3oool0oooo4`09jPX0103oool02NX:
00WZ2P09jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02`0oooo
00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2F0?ooo`0300WZ2P3oool0oooo01002NX:
00@0oooo00WZ2P09jPX0oooo0`09jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo02`0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2F0?ooo`0300WZ
2P3oool0oooo01002NX:00@0oooo00WZ2P09jPX0oooo0`09jPXY0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo02`0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo
0?ooo`2F0?ooo`0300WZ2P3oool0oooo01002NX:00@0oooo00WZ2P09jPX0oooo0`09jPXY0?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02`0oooo00<02NX:0?ooo`3oool0
4P3oool00`09jPX0oooo0?ooo`2F0?ooo`0300WZ2P3oool0oooo00802NX:00<0oooo00WZ2P09jPX0
2`09jPX0103oool02NX:00WZ2P3oool300WZ2RT0oooo00<000000?ooo`3oool01@3oool000L0oooo
00<000000?ooo`3oool0;03oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo09L0oooo
00<02NX:0?ooo`09jPX03`09jPX0103oool02NX:00WZ2P3oool300WZ2RT0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0;03oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ
2P3oool0oooo09L0oooo00<02NX:0?ooo`3oool03`09jPX00`3oool02NX:00WZ2P0400WZ2RT0oooo
00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0;03oool00`09jPX0oooo0?oo
o`0B0?ooo`0300WZ2P3oool0oooo09L0oooo00<02NX:0?ooo`3oool03`09jPX00`3oool02NX:00WZ
2P0400WZ2RT0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0;03oool0
0`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo09L0oooo00<02NX:0?ooo`3oool03`09jPX0
0`3oool02NX:00WZ2P0400WZ2RT0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool0:`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo09L0oooo00<02NX:0?oo
o`3oool03`09jPX00`3oool02NX:00WZ2P0400WZ2RT0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0:`3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo09T0
oooo00D02NX:0?ooo`09jPX02NX:0?ooo`0<00WZ2P030?ooo`09jPX02NX:00@02NX::@3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0[0?ooo`0300WZ2P3oool0oooo0180
oooo00<02NX:0?ooo`3oool0V@3oool01@09jPX0oooo0?ooo`09jPX0oooo00`02NX:00<0oooo00WZ
2P09jPX01009jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02/0
oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2I0?ooo`0500WZ2P3oool0oooo00WZ
2P3oool03009jPX00`3oool02NX:00WZ2P0400WZ2RT0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0:`3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo09T0
oooo00<02NX:0?ooo`3oool05@09jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo02/0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2I0?ooo`0300WZ
2P3oool0oooo01D02NX::@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0[0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0VP3oool00`09jPX0oooo00WZ
2P0D00WZ2RT0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0:`3oool0
0`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo09X0oooo00<02NX:0?ooo`09jPX05009jPXY
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02X0oooo00<02NX:0?oo
o`3oool04`3oool00`09jPX0oooo0?ooo`2J0?ooo`0500WZ2P3oool0oooo00WZ2P3oool04009jPX0
0`3oool02NX:0?ooo`0X0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
02X0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2K0?ooo`0500WZ2P3oool0oooo
00WZ2P3oool04009jPX00`3oool02NX:0?ooo`0X0?ooo`030000003oool0oooo00D0oooo00070?oo
o`030000003oool0oooo02X0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2K0?oo
o`0500WZ2P3oool0oooo00WZ2P3oool04009jPX00`3oool02NX:0?ooo`0X0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo02X0oooo00<02NX:0?ooo`3oool04P3oool00`09
jPX0oooo0?ooo`2L0?ooo`0300WZ2P3oool02NX:01<02NX::@3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0Z0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3o
ool0W03oool00`09jPX0oooo00WZ2P0>00WZ2P030?ooo`09jPX02NX:00802NX::@3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0Z0?ooo`0300WZ2P3oool0oooo0180oooo
00<02NX:0?ooo`3oool0W03oool00`09jPX0oooo0?ooo`0>00WZ2P030?ooo`09jPX02NX:00802NX:
:@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0Z0?ooo`0300WZ2P3o
ool0oooo0180oooo00<02NX:0?ooo`3oool0W03oool00`09jPX0oooo0?ooo`0>00WZ2P030?ooo`09
jPX02NX:00802NX::@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0Z
0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0W03oool00`09jPX0oooo0?ooo`0>
00WZ2P030?ooo`09jPX02NX:00802NX::@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0Z0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0W@3oool01009
jPX0oooo00WZ2P3ooolA00WZ2RT0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool0:@3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo09d0oooo00@02NX:0?oo
o`09jPX0oooo4@09jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
02T0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2N0?ooo`0300WZ2P3oool02NX:
00T02NX:00<0oooo00WZ2P09jPX01P09jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo02T0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2N0?ooo`03
00WZ2P3oool02NX:01802NX::@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`0Y0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0WP3oool00`09jPX0oooo
0?ooo`0B00WZ2RT0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0:@3o
ool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo09l0oooo00<02NX:0?ooo`09jPX04@09
jPXY0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02T0oooo00<02NX:
0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2O0?ooo`0300WZ2P3oool02NX:01402NX::@3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0Y0?ooo`0300WZ2P3oool0oooo
0180oooo00<02NX:0?ooo`3oool0W`3oool00`09jPX0oooo00WZ2P0A00WZ2RT0oooo00<000000?oo
o`3oool01@3oool000L0oooo00<000000?ooo`3oool0:@3oool00`09jPX0oooo0?ooo`0B0?ooo`03
00WZ2P3oool0oooo09l0oooo00<02NX:0?ooo`09jPX04@09jPXY0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030000003oool0oooo02T0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo
0?ooo`2O0?ooo`0300WZ2P3oool02NX:01402NX::@3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0X@3o
oolB00WZ2P030?ooo`09jPX0oooo02L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<00000
0?ooo`3oool0:03oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo0:40oooo4P09jPX0
0`3oool02NX:0?ooo`0W0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
02P0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2Q0?ooo`0300WZ2P3oool02NX:
00l02NX:00<0oooo00WZ2P3oool09`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0X@3oool00`09jPX0
oooo00WZ2P0?00WZ2P030?ooo`09jPX0oooo02L0oooo00<000000?ooo`3oool01@3oool000L0oooo
00<000000?ooo`3oool0:03oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo0:40oooo
00<02NX:0?ooo`09jPX03`09jPX00`3oool02NX:0?ooo`0W0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo02P0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?oo
o`2R0?oooa402NX:00<0oooo00WZ2P3oool09`3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0XP3oool:
00WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P3oool09`3oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?oo
o`3oool0XP3oool:00WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P3oool09`3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo0180
oooo00<02NX:0?ooo`3oool0XP3oool:00WZ2P030?ooo`09jPX02NX:00@02NX:00<0oooo00WZ2P3o
ool09`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0W0?ooo`0300WZ
2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0X`3oool:00WZ2P030?ooo`09jPX02NX:00@02NX:
00<0oooo00WZ2P3oool09`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0W0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0Y03oool900WZ2P030?ooo`09
jPX02NX:00H02NX::03oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0W
0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0Y03ooolB00WZ2RP0oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool09`3oool00`09jPX0oooo0?ooo`0B0?oo
o`0300WZ2P3oool0oooo0:@0oooo4P09jPXX0?ooo`030000003oool0oooo00D0oooo00070?ooo`03
0000003oool0oooo02L0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2T0?oooa80
2NX::03oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0W0?ooo`0300WZ
2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0Y03ooolB00WZ2RP0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool09`3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3o
ool0oooo0:D0oooo4@09jPXX0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo02L0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2U0?oooa402NX::03oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo
0180oooo00<02NX:0?ooo`3oool0Y@3ooolA00WZ2RP0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool09P3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo0:H0
oooo4@09jPXX0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo02H0oooo
00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`2V0?ooo`X02NX:00D0oooo00WZ2P09jPX0
2NX:0?ooo`0200WZ2RP0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
9P3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo0:H0oooo2P09jPX01@3oool02NX:
00WZ2P09jPX0oooo00<02NX:9`3oool00`000000oooo0?ooo`050?ooo`001`3ooooo000002800000
1`3oool002l0oooo0P00000C0?ooo`800000Z03ooolC000002h0oooo003o0?oooc00oooo003o0?oo
oc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oo
oc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oo
oc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oo
oc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oo
oc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oo
oc00oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oooc00oooo0000\
\>"],
  ImageRangeCache->{{{0, 302.5}, {1262.69, 0}} -> {-157.708, -182.88, \
1.04203, 1.04203}},
  CellTags->"Laser Radar Example"],

Cell[BoxData[
    \({105.14999999999418`\ Second, Null}\)], "Output",
  CellTags->"Laser Radar Example"]
}, Open  ]],

Cell[TextData[{
  "We can now construct a composite tree from ",
  StyleBox["TreeDisk", "Input"],
  " objects. As shown previously, we will include the subtracted ",
  StyleBox["ClonePosition", "Input"],
  " information in the ",
  StyleBox["DetectorPosition", "Input"],
  " of each ",
  StyleBox["TreeDisk", "Input"],
  " in order to maintain a constant focal point for all of the clones trees."
}], "Text",
  CellTags->"Laser Radar Example"],

Cell["\<\
focusedtreecomposite = 
\tMove[Resonate[{
\t\tMove[Move[TreeDisk[500, 100, {.6,.85}, .1, .02, 
\t\t\tDetectorPosition->Hold[{0,0,50000}-ClonePosition]],0,Random[Real,{-5,5}]\
],
\t\t\t-250,10*Random[],TwistAngle->90],
\t\tMove[Move[TreeDisk[400, 75, {.6,.85}, .1, .02,
\t\t\tDetectorPosition->Hold[{0,0,50000}-ClonePosition]],0,Random[Real,{-5,5}]\
],
\t\t\t-750,10*Random[],TwistAngle->90],
\t\tMove[Move[TreeDisk[300, 60, {.6,.85}, .1, .02,
\t\t\tDetectorPosition->Hold[{0,0,50000}-ClonePosition]],0,Random[Real,{-5,5}]\
],
\t\t\t-1250,10*Random[],TwistAngle->90],
\t\tMove[Move[TreeDisk[200, 50, {.6,.85}, .1, .02,
\t\t\tDetectorPosition->Hold[{0,0,50000}-ClonePosition]],0,Random[Real,{-5,5}]\
],
\t\t\t-1750,10*Random[],TwistAngle->90],
\t\tMove[Move[TreeDisk[100, 40, {.6,.85}, .1, .02,
\t\t\tDetectorPosition->Hold[{0,0,50000}-ClonePosition]],0,Random[Real,{-5,5}]\
],
\t\t\t-200,10*Random[],TwistAngle->90],
\t\tMove[Move[TreeDisk[70, 30, {.6,.85}, .1, .02,
\t\t\tDetectorPosition->Hold[{0,0,50000}-ClonePosition]],0,Random[Real,{-5,5}]\
],
\t\t\t-2150,10*Random[],TwistAngle->90],
\t\tMove[TreeTrunk[20, 2500, .02, \
DetectorPosition->Hold[{0,0,50000}-ClonePosition]],-2140]
\t}], {0,0,0}, {0,0,-1}];\
\>", "Input",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{

Cell["\<\
treepositions = 
\tApply[Join,Table[
\t\t{x+Random[Real,{-100,100}],y+Random[Real,{-100,100}]}, 
\t\t{x,-1000,1000,1000}, 
\t\t{y,-1000,1000,1000}]]\
\>", "Input",
  CellTags->"Laser Radar Example"],

Cell[BoxData[
    \({{\(-978.9676136525502`\), \(-906.9753839807324`\)}, \
{\(-1054.2825741331146`\), 38.514739744238`}, {\(-1002.7829491460932`\), 
        976.5799030893971`}, {\(-69.20708039892692`\), \(-1054.0705485298524`\
\)}, {69.6074118867449`, \(-11.64788086893978`\)}, {2.1390585053421347`, 
        913.8798431674156`}, {1053.5453212310458`, \(-909.574567133182`\)}, \
{1090.4695073361718`, \(-21.293185115264592`\)}, {908.9178813135933`, 
        1085.5112708097643`}}\)], "Output",
  CellTags->"Laser Radar Example"]
}, Open  ]],

Cell[TextData[{
  "You can also use ",
  StyleBox["ShowSystem", "Input"],
  " to render the cloned system without running the ray trace."
}], "Text",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[focusedtreecomposite, \
CreateClones->treepositions,ShowClones->True];\
\>", "Input",
  CellTags->"Laser Radar Example"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99793 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0189436 1.08924 5.55112e-17 1.08924 [
[ 0 0 0 0 ]
[ 1 .99793 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .99793 L
0 .99793 L
closepath
clip
newpath
.4454 .63347 m .44597 .62595 L .46883 .62557 L .675 .456 .58 r
F
.42249 .63067 m .44597 .62595 L .4454 .63347 L .73 .504 .584 r
F
.42249 .63067 m .42311 .62316 L .44597 .62595 L F
.44592 .61009 m .44597 .62572 L .46871 .62534 L .643 .738 .918 r
F
.43059 .60821 m .44597 .62572 L .44592 .61009 L F
.43059 .60821 m .42322 .62294 L .44597 .62572 L F
.40099 .62487 m .42311 .62316 L .42249 .63067 L .782 .55 .586 r
F
.40099 .62487 m .40166 .61735 L .42311 .62316 L F
0 g
.5 Mabswid
[ ] 0 setdash
.42311 .62316 m
.44597 .62595 L
s
.4683 .63309 m .46883 .62557 L .49025 .62202 L .612 .401 .572 r
F
.4454 .63347 m .46883 .62557 L .4683 .63309 L .675 .456 .58 r
F
0 g
.44597 .62595 m
.46883 .62557 L
s
.41624 .60429 m .42322 .62294 L .43059 .60821 L .643 .738 .918 r
F
.41624 .60429 m .40187 .61715 L .42322 .62294 L F
.46123 .60982 m .46871 .62534 L .49003 .6218 L F
.44592 .61009 m .46871 .62534 L .46123 .60982 L F
.44483 .64101 m .4454 .63347 L .4683 .63309 L .675 .456 .58 r
F
.42187 .63822 m .4454 .63347 L .44483 .64101 L .73 .504 .584 r
F
.42187 .63822 m .42249 .63067 L .4454 .63347 L F
.44534 .61781 m .4454 .63347 L .4683 .63309 L .642 .739 .919 r
F
.42991 .61592 m .4454 .63347 L .44534 .61781 L F
.42991 .61592 m .42249 .63067 L .4454 .63347 L F
.40032 .63243 m .42249 .63067 L .42187 .63822 L .782 .55 .586 r
F
.40032 .63243 m .40099 .62487 L .42249 .63067 L F
.41545 .61199 m .42249 .63067 L .42991 .61592 L .642 .739 .919 r
F
.41545 .61199 m .40099 .62487 L .42249 .63067 L F
0 g
.42249 .63067 m
.4454 .63347 L
s
.4683 .63309 m .49025 .62202 L .48977 .62956 L .612 .401 .572 r
F
.46778 .64064 m .4683 .63309 L .48977 .62956 L F
.44483 .64101 m .4683 .63309 L .46778 .64064 L .675 .456 .58 r
F
.46076 .61755 m .4683 .63309 L .48977 .62956 L .642 .739 .919 r
F
.44534 .61781 m .4683 .63309 L .46076 .61755 L F
0 g
.4454 .63347 m
.4683 .63309 L
s
.38225 .6164 m .40166 .61735 L .40099 .62487 L .837 .601 .583 r
F
.38225 .6164 m .38297 .60885 L .40166 .61735 L F
0 g
.40166 .61735 m
.40762 .61896 L
s
.44476 .62541 m .44483 .64101 L .46778 .64064 L .641 .739 .92 r
F
.42929 .62351 m .44483 .64101 L .44476 .62541 L F
.42929 .62351 m .42187 .63822 L .44483 .64101 L F
.48977 .62956 m .49025 .62202 L .50889 .6155 L .527 .33 .557 r
F
0 g
.47691 .62423 m
.49025 .62202 L
s
.4038 .59857 m .40187 .61715 L .41624 .60429 L .643 .738 .918 r
F
.4038 .59857 m .38327 .6087 L .40187 .61715 L F
.47556 .60741 m .49003 .6218 L .50858 .61531 L F
.46123 .60982 m .49003 .6218 L .47556 .60741 L F
.41481 .61959 m .42187 .63822 L .42929 .62351 L .641 .739 .92 r
F
.41481 .61959 m .40032 .63243 L .42187 .63822 L F
0 g
.42187 .63822 m
.44483 .64101 L
s
.46778 .64064 m .48977 .62956 L .48929 .63713 L .612 .401 .572 r
F
.46022 .62515 m .46778 .64064 L .48929 .63713 L .641 .739 .92 r
F
.44476 .62541 m .46778 .64064 L .46022 .62515 L F
0 g
.44483 .64101 m
.46778 .64064 L
s
.38154 .62398 m .40099 .62487 L .40032 .63243 L .837 .601 .583 r
F
.38154 .62398 m .38225 .6164 L .40099 .62487 L F
.40292 .60625 m .40099 .62487 L .41545 .61199 L .642 .739 .919 r
F
.40292 .60625 m .38225 .6164 L .40099 .62487 L F
0 g
.40099 .62487 m
.40701 .6265 L
s
.48977 .62956 m .50889 .6155 L .50845 .62306 L .527 .33 .557 r
F
.48929 .63713 m .48977 .62956 L .50845 .62306 L F
.47519 .61514 m .48977 .62956 L .50845 .62306 L .642 .739 .919 r
F
.46076 .61755 m .48977 .62956 L .47519 .61514 L F
0 g
.4763 .63177 m
.48977 .62956 L
s
.44686 .50629 m .44686 .56635 L .44534 .56652 L .651 .424 .562 r
F
.44686 .50629 m .44835 .50612 L .44686 .56635 L F
.44537 .50607 m .44686 .50629 L .44534 .56652 L .747 .505 .564 r
F
0 g
.44686 .50629 m
.44686 .50629 L
s
.44835 .50612 m .44783 .56599 L .44686 .56635 L .539 .332 .549 r
F
.44835 .50612 m .4493 .50575 L .44783 .56599 L F
0 g
.44686 .50629 m
.44835 .50612 L
s
.44537 .50607 m .44534 .56652 L .44382 .56631 L .747 .505 .564 r
F
.44442 .50567 m .44537 .50607 L .44382 .56631 L .83 .576 .556 r
F
0 g
.44537 .50607 m
.44686 .50629 L
s
.4493 .50575 m .44849 .56551 L .44783 .56599 L .387 .212 .518 r
F
.4493 .50575 m .44995 .50527 L .44849 .56551 L F
0 g
.44835 .50612 m
.4493 .50575 L
s
.44442 .50567 m .44382 .56631 L .44286 .56591 L .83 .576 .556 r
F
.44378 .50516 m .44442 .50567 L .44286 .56591 L .908 .647 .532 r
F
0 g
.44442 .50567 m
.44537 .50607 L
s
.44995 .50527 m .44888 .56495 L .44849 .56551 L .095 0 .426 r
F
.44995 .50527 m .45033 .50469 L .44888 .56495 L F
0 g
.4493 .50575 m
.44995 .50527 L
s
.44378 .50516 m .44286 .56591 L .4422 .56542 L .908 .647 .532 r
F
.44339 .50457 m .44378 .50516 L .4422 .56542 L .984 .727 .46 r
F
0 g
.44378 .50516 m
.44442 .50567 L
s
.45033 .50469 m .44896 .56427 L .44888 .56495 L 0 0 .082 r
F
.45033 .50469 m .45041 .504 L .44896 .56427 L F
0 g
.44995 .50527 m
.45033 .50469 L
s
.44339 .50457 m .4422 .56542 L .4418 .56483 L .984 .727 .46 r
F
.44331 .50388 m .44339 .50457 L .4418 .56483 L .868 .695 .169 r
F
0 g
.44339 .50457 m
.44378 .50516 L
s
.40224 .61387 m .40032 .63243 L .41481 .61959 L .641 .739 .92 r
F
.40224 .61387 m .38154 .62398 L .40032 .63243 L F
0 g
.40032 .63243 m
.42187 .63822 L
s
.45041 .504 m .44849 .56339 L .44896 .56427 L .993 .743 .421 r
F
.45041 .504 m .44995 .50311 L .44849 .56339 L F
.48929 .63713 m .50845 .62306 L .50801 .63065 L .527 .33 .557 r
F
.47467 .62275 m .48929 .63713 L .50801 .63065 L .641 .739 .92 r
F
.46022 .62515 m .48929 .63713 L .47467 .62275 L F
0 g
.46778 .64064 m
.48929 .63713 L
s
.44331 .50388 m .4418 .56483 L .44172 .56415 L .868 .695 .169 r
F
.44377 .50301 m .44331 .50388 L .44172 .56415 L 0 0 .377 r
F
.44995 .50311 m .44744 .5627 L .44849 .56339 L .889 .63 .539 r
F
.44995 .50311 m .44892 .50241 L .44744 .5627 L F
0 g
.44995 .50311 m
.45041 .504 L
s
.44995 .50311 m
.44995 .50311 L
s
.4448 .50234 m .44377 .50301 L .44219 .56329 L .428 .243 .527 r
F
.44377 .50301 m .44172 .56415 L .44219 .56329 L 0 0 .377 r
F
0 g
.44331 .50388 m
.44377 .50301 L
s
.44377 .50301 m
.44377 .50301 L
s
.36752 .60576 m .38297 .60885 L .38225 .6164 L .899 .662 .571 r
F
.36752 .60576 m .36827 .59818 L .38297 .60885 L F
0 g
.38297 .60885 m
.39058 .61231 L
s
.39409 .5914 m .38327 .6087 L .4038 .59857 L .643 .738 .918 r
F
.39409 .5914 m .36865 .59808 L .38327 .6087 L F
.50845 .62306 m .50889 .6155 L .52352 .60637 L .397 .224 .526 r
F
0 g
.49586 .62006 m
.50889 .6155 L
s
.44892 .50241 m .44639 .56239 L .44744 .5627 L .799 .548 .56 r
F
.44892 .50241 m .44789 .50209 L .44639 .56239 L F
0 g
.44892 .50241 m
.44995 .50311 L
s
.4448 .50234 m .44219 .56329 L .44324 .56264 L .428 .243 .527 r
F
.44583 .50205 m .4448 .50234 L .44324 .56264 L .585 .37 .555 r
F
0 g
.44377 .50301 m
.4448 .50234 L
s
.48797 .603 m .50858 .61531 L .52314 .60623 L .643 .738 .918 r
F
.47556 .60741 m .50858 .61531 L .48797 .603 L F
.44789 .50209 m .44534 .56228 L .44639 .56239 L .733 .492 .564 r
F
.44789 .50209 m .44686 .50198 L .44534 .56228 L F
0 g
.44789 .50209 m
.44892 .50241 L
s
.44583 .50205 m .44324 .56264 L .44429 .56235 L .585 .37 .555 r
F
.44686 .50198 m .44583 .50205 L .44429 .56235 L .667 .437 .562 r
F
0 g
.4448 .50234 m
.44583 .50205 L
s
.44686 .50198 m .44429 .56235 L .44534 .56228 L .667 .437 .562 r
F
0 g
.44686 .50198 m
.44789 .50209 L
s
.44583 .50205 m
.44686 .50198 L
s
.44586 .59413 m .44592 .61009 L .46123 .60982 L .643 .738 .918 r
F
.43812 .59317 m .44592 .61009 L .44586 .59413 L F
.43812 .59317 m .43059 .60821 L .44592 .61009 L F
.36677 .61336 m .38225 .6164 L .38154 .62398 L .899 .662 .571 r
F
.36677 .61336 m .36752 .60576 L .38225 .6164 L F
.39313 .59907 m .38225 .6164 L .40292 .60625 L .642 .739 .919 r
F
.39313 .59907 m .36752 .60576 L .38225 .6164 L F
0 g
.38225 .6164 m
.38994 .61988 L
s
.43088 .59118 m .43059 .60821 L .43812 .59317 L .643 .738 .918 r
F
.43088 .59118 m .41624 .60429 L .43059 .60821 L F
.4536 .59399 m .46123 .60982 L .47556 .60741 L F
.44586 .59413 m .46123 .60982 L .4536 .59399 L F
.50845 .62306 m .52352 .60637 L .52311 .61396 L .397 .224 .526 r
F
.50801 .63065 m .50845 .62306 L .52311 .61396 L F
.48769 .61072 m .50845 .62306 L .52311 .61396 L .642 .739 .919 r
F
.47519 .61514 m .50845 .62306 L .48769 .61072 L F
0 g
.49529 .62764 m
.50845 .62306 L
s
.44527 .60182 m .44534 .61781 L .46076 .61755 L .642 .739 .919 r
F
.43748 .60086 m .44534 .61781 L .44527 .60182 L F
.43748 .60086 m .42991 .61592 L .44534 .61781 L F
.43019 .59886 m .42991 .61592 L .43748 .60086 L F
.43019 .59886 m .41545 .61199 L .42991 .61592 L F
.45307 .60168 m .46076 .61755 L .47519 .61514 L F
.44527 .60182 m .46076 .61755 L .45307 .60168 L F
.42464 .58827 m .41624 .60429 L .43088 .59118 L .643 .738 .918 r
F
.42464 .58827 m .4038 .59857 L .41624 .60429 L F
.39243 .6067 m .38154 .62398 L .40224 .61387 L .641 .739 .92 r
F
.39243 .6067 m .36677 .61336 L .38154 .62398 L F
0 g
.38154 .62398 m
.40032 .63243 L
s
.46082 .59276 m .47556 .60741 L .48797 .603 L .643 .738 .918 r
F
.4536 .59399 m .47556 .60741 L .46082 .59276 L F
.50801 .63065 m .52311 .61396 L .5227 .62159 L .397 .224 .526 r
F
.4872 .61835 m .50801 .63065 L .5227 .62159 L .641 .739 .92 r
F
.47467 .62275 m .50801 .63065 L .4872 .61835 L F
0 g
.48929 .63713 m
.50801 .63065 L
s
.44469 .60946 m .44476 .62541 L .46022 .62515 L .641 .739 .92 r
F
.43687 .6085 m .44476 .62541 L .44469 .60946 L F
.43687 .6085 m .42929 .62351 L .44476 .62541 L F
.4239 .59594 m .41545 .61199 L .43019 .59886 L .642 .739 .919 r
F
.4239 .59594 m .40292 .60625 L .41545 .61199 L F
.42957 .6065 m .42929 .62351 L .43687 .6085 L .641 .739 .92 r
F
.42957 .6065 m .41481 .61959 L .42929 .62351 L F
.4525 .60932 m .46022 .62515 L .47467 .62275 L F
.44469 .60946 m .46022 .62515 L .4525 .60932 L F
.46034 .60045 m .47519 .61514 L .48769 .61072 L .642 .739 .919 r
F
.45307 .60168 m .47519 .61514 L .46034 .60045 L F
.35782 .59359 m .36827 .59818 L .36752 .60576 L .969 .738 .534 r
F
.35782 .59359 m .3586 .58598 L .36827 .59818 L F
0 g
.36827 .59818 m
.37574 .60361 L
s
.38779 .58325 m .36865 .59808 L .39409 .5914 L .643 .738 .918 r
F
.38779 .58325 m .35903 .58594 L .36865 .59808 L F
.52311 .61396 m .52352 .60637 L .53312 .59518 L .153 .029 .446 r
F
0 g
.51286 .61302 m
.52352 .60637 L
s
.49764 .59686 m .52314 .60623 L .53268 .5951 L .643 .738 .918 r
F
.48797 .603 m .52314 .60623 L .49764 .59686 L F
.4198 .58465 m .4038 .59857 L .42464 .58827 L F
.4198 .58465 m .39409 .5914 L .4038 .59857 L F
.46704 .59051 m .48797 .603 L .49764 .59686 L F
.46082 .59276 m .48797 .603 L .46704 .59051 L F
.42326 .6036 m .41481 .61959 L .42957 .6065 L .641 .739 .92 r
F
.42326 .6036 m .40224 .61387 L .41481 .61959 L F
.45979 .60809 m .47467 .62275 L .4872 .61835 L F
.4525 .60932 m .47467 .62275 L .45979 .60809 L F
.35704 .60123 m .36752 .60576 L .36677 .61336 L .969 .738 .534 r
F
.35704 .60123 m .35782 .59359 L .36752 .60576 L F
.38678 .5909 m .36752 .60576 L .39313 .59907 L .642 .739 .919 r
F
.38678 .5909 m .35782 .59359 L .36752 .60576 L F
0 g
.36752 .60576 m
.37507 .61121 L
s
.52311 .61396 m .53312 .59518 L .53272 .60281 L .153 .029 .446 r
F
.5227 .62159 m .52311 .61396 L .53272 .60281 L F
.49742 .60457 m .52311 .61396 L .53272 .60281 L .642 .739 .919 r
F
.48769 .61072 m .52311 .61396 L .49742 .60457 L F
0 g
.51234 .62064 m
.52311 .61396 L
s
.41903 .59231 m .40292 .60625 L .4239 .59594 L .642 .739 .919 r
F
.41903 .59231 m .39313 .59907 L .40292 .60625 L F
.46661 .5982 m .48769 .61072 L .49742 .60457 L F
.46034 .60045 m .48769 .61072 L .46661 .5982 L F
.38607 .59856 m .36677 .61336 L .39243 .6067 L .641 .739 .92 r
F
.38607 .59856 m .35704 .60123 L .36677 .61336 L F
0 g
.36677 .61336 m
.38154 .62398 L
s
.5227 .62159 m .53272 .60281 L .53232 .61047 L .153 .029 .446 r
F
.49695 .61222 m .5227 .62159 L .53232 .61047 L .641 .739 .92 r
F
.4872 .61835 m .5227 .62159 L .49695 .61222 L F
0 g
.50801 .63065 m
.5227 .62159 L
s
.41838 .59997 m .40224 .61387 L .42326 .6036 L .641 .739 .92 r
F
.41838 .59997 m .39243 .6067 L .40224 .61387 L F
.46607 .60585 m .4872 .61835 L .49695 .61222 L F
.45979 .60809 m .4872 .61835 L .46607 .60585 L F
.41671 .58054 m .39409 .5914 L .4198 .58465 L .643 .738 .918 r
F
.41671 .58054 m .38779 .58325 L .39409 .5914 L F
.44534 .56652 m .44686 .56635 L .44652 .58008 L .651 .424 .562 r
F
.44717 .58066 m .44586 .59413 L .44659 .59412 L .643 .738 .918 r
F
.44807 .58253 m .44659 .59412 L .4536 .59399 L F
.44717 .58066 m .44659 .59412 L .44807 .58253 L F
.44783 .56599 m .44764 .57968 L .44749 .57977 L .387 .212 .518 r
F
.44534 .56652 m .44652 .58008 L .44534 .58016 L .651 .424 .562 r
F
.44849 .56551 m .44888 .56495 L .44854 .57884 L .095 0 .426 r
F
.44835 .58036 m .4536 .59399 L .45722 .59337 L .643 .738 .918 r
F
.44835 .58036 m .45722 .59337 L .45177 .58376 L F
.44827 .58096 m .4536 .59399 L .44835 .58036 L F
.44776 .57987 m .4536 .59399 L .4478 .57982 L F
.44749 .57977 m .4536 .59399 L .4477 .57971 L F
.44684 .57998 m .44692 .58014 L .44749 .57977 L F
.44692 .58014 m .4536 .59399 L .44749 .57977 L F
.44783 .56599 m .44849 .56551 L .44815 .57936 L .387 .212 .518 r
F
.4478 .57982 m .44827 .58096 L .44835 .58036 L .643 .738 .918 r
F
.4477 .57971 m .44776 .57987 L .4478 .57982 L F
.44686 .56635 m .44674 .58001 L .44652 .58008 L .539 .332 .549 r
F
.44692 .58014 m .44685 .58109 L .44717 .58066 L .643 .738 .918 r
F
.44685 .58109 m .44586 .59413 L .44717 .58066 L F
.44688 .58006 m .44687 .58017 L .44692 .58014 L F
.44687 .58017 m .44586 .59413 L .44692 .58014 L F
.44686 .56635 m .44783 .56599 L .44749 .57977 L .539 .332 .549 r
F
.44684 .57998 m .44652 .58008 L .44688 .58006 L .643 .738 .918 r
F
.44581 .58013 m .44586 .59413 L .44688 .58006 L F
.44686 .56635 m .44749 .57977 L .44674 .58001 L .539 .332 .549 r
F
.44783 .56599 m .44815 .57936 L .44764 .57968 L .387 .212 .518 r
F
.44849 .56551 m .44824 .57924 L .44815 .57936 L .095 0 .426 r
F
.44974 .58018 m .46082 .59276 L .46704 .59051 L .643 .738 .918 r
F
.4458 .57782 m .45177 .58376 L .44974 .58018 L F
.45177 .58376 m .46082 .59276 L .44974 .58018 L F
.44888 .56495 m .44896 .56427 L .44862 .5782 L 0 0 .082 r
F
.44888 .56495 m .44862 .5782 L .44856 .57869 L F
.44849 .56551 m .44854 .57884 L .44824 .57924 L .095 0 .426 r
F
.44888 .56495 m .44856 .57869 L .44854 .57884 L 0 0 .082 r
F
.44896 .56427 m .44849 .56339 L .44815 .57737 L .993 .743 .421 r
F
.44797 .58628 m .44953 .58957 L .45388 .58856 L .668 .747 .91 r
F
.44382 .56631 m .44534 .56652 L .445 .58018 L .747 .505 .564 r
F
.4422 .56542 m .44286 .56591 L .4425 .57952 L .908 .647 .532 r
F
.44172 .56415 m .4418 .56483 L .44144 .57847 L .868 .695 .169 r
F
.44272 .5881 m .43812 .59317 L .44348 .59384 L .643 .738 .918 r
F
.44487 .58333 m .44254 .58673 L .44582 .58468 L F
.44254 .58673 m .43812 .59317 L .44272 .5881 L F
.44254 .58673 m .44272 .5881 L .44582 .58468 L F
.44536 .58162 m .44456 .58289 L .44581 .58196 L F
.44456 .58289 m .43812 .59317 L .44487 .58333 L F
.44456 .58289 m .44487 .58333 L .44581 .58196 L F
.44553 .58078 m .44513 .58145 L .44581 .5809 L F
.44513 .58145 m .43812 .59317 L .44536 .58162 L F
.44513 .58145 m .44536 .58162 L .44581 .5809 L F
.4457 .5803 m .44544 .58075 L .44581 .58032 L F
.44544 .58075 m .43812 .59317 L .44553 .58078 L F
.44544 .58075 m .44553 .58078 L .44581 .58032 L F
.44461 .58021 m .43812 .59317 L .4457 .5803 L F
.445 .58018 m .4457 .5803 L .44581 .58013 L F
.44461 .58021 m .4457 .5803 L .445 .58018 L F
.44582 .58468 m .44272 .5881 L .44586 .59413 L F
.44272 .5881 m .44348 .59384 L .44586 .59413 L F
.44382 .56631 m .44381 .57998 L .44347 .57992 L .747 .505 .564 r
F
.44286 .56591 m .44382 .56631 L .44347 .57992 L .83 .576 .556 r
F
.44286 .56591 m .44347 .57992 L .44272 .57961 L F
.44382 .56631 m .445 .58018 L .44381 .57998 L .747 .505 .564 r
F
.44534 .56652 m .44534 .58016 L .445 .58018 L .651 .424 .562 r
F
.4458 .57782 m .4363 .58633 L .43812 .59317 L .643 .738 .918 r
F
.4363 .58633 m .43088 .59118 L .43306 .59178 L F
.4363 .58633 m .43306 .59178 L .43812 .59317 L F
.4418 .56483 m .44153 .57859 L .44144 .57847 L .984 .727 .46 r
F
.44172 .56415 m .44138 .57797 L .44136 .57783 L .868 .695 .169 r
F
.44172 .56415 m .44144 .57847 L .44138 .57797 L F
.4418 .56483 m .4422 .56542 L .44184 .57903 L .984 .727 .46 r
F
.4418 .56483 m .44184 .57903 L .44153 .57859 L F
.44219 .56329 m .44172 .56415 L .44136 .57783 L 0 0 .377 r
F
.44286 .56591 m .44272 .57961 L .4425 .57952 L .83 .576 .556 r
F
.4422 .56542 m .4425 .57952 L .44199 .57913 L .908 .647 .532 r
F
.4363 .58633 m .42464 .58827 L .43088 .59118 L .643 .738 .918 r
F
.4458 .57782 m .43951 .58093 L .4363 .58633 L F
.43951 .58093 m .42464 .58827 L .4363 .58633 L F
.44484 .59296 m .44485 .58996 L .44955 .58962 L .673 .446 .569 r
F
.44014 .5926 m .44485 .58996 L .44484 .59296 L .729 .493 .569 r
F
.44484 .59296 m .44955 .58962 L .44954 .59262 L .673 .446 .569 r
F
.44548 .5955 m .44484 .59296 L .44954 .59262 L F
.44525 .59556 m .43748 .60086 L .44527 .60182 L .642 .739 .919 r
F
.44525 .5955 m .44518 .59556 L .44525 .59556 L F
.44518 .59556 m .43748 .60086 L .44525 .59556 L F
.4411 .59505 m .44484 .59296 L .44483 .59551 L .729 .493 .569 r
F
.44483 .59551 m .44484 .59296 L .44548 .5955 L .673 .446 .569 r
F
.4411 .59505 m .44014 .5926 L .44484 .59296 L .729 .493 .569 r
F
.44485 .58651 m .44485 .58991 L .44953 .58957 L .668 .747 .91 r
F
.44483 .58954 m .44484 .59296 L .44954 .59262 L .667 .747 .91 r
F
.44014 .5926 m .44015 .58961 L .44485 .58996 L .729 .493 .569 r
F
.44172 .58627 m .44485 .58991 L .44485 .58651 L .668 .747 .91 r
F
.44172 .58627 m .44018 .58956 L .44485 .58991 L F
.44169 .5893 m .44484 .59296 L .44483 .58954 L .667 .747 .91 r
F
.44169 .5893 m .44014 .5926 L .44484 .59296 L F
.44523 .59155 m .4422 .59519 L .44525 .5955 L .642 .739 .919 r
F
.4422 .59519 m .44189 .59557 L .44483 .59551 L F
.4422 .59519 m .44483 .59551 L .44525 .5955 L F
.44012 .59493 m .44014 .5926 L .4411 .59505 L .729 .493 .569 r
F
.44327 .58297 m .44172 .58627 L .44485 .58651 L .668 .747 .91 r
F
.44325 .58599 m .44169 .5893 L .44483 .58954 L .667 .747 .91 r
F
.44343 .58901 m .44203 .5918 L .44523 .59155 L .642 .739 .919 r
F
.44203 .5918 m .43748 .60086 L .44244 .5949 L F
.44203 .5918 m .44244 .5949 L .44523 .59155 L F
.4422 .56542 m .44199 .57913 L .44184 .57903 L .908 .647 .532 r
F
.4458 .57782 m .43543 .58055 L .42464 .58827 L .643 .738 .918 r
F
.43543 .58055 m .4198 .58465 L .42324 .58723 L F
.43543 .58055 m .42324 .58723 L .42464 .58827 L F
.44324 .56264 m .44219 .56329 L .44183 .57704 L .428 .243 .527 r
F
.44189 .59557 m .43748 .60086 L .44525 .5955 L .642 .739 .919 r
F
.44012 .59561 m .4411 .59505 L .44483 .59596 L .729 .493 .569 r
F
.4411 .59505 m .44483 .59551 L .44483 .59596 L F
.43543 .58055 m .41671 .58054 L .4198 .58465 L .643 .738 .918 r
F
.4458 .57782 m .43928 .57843 L .43543 .58055 L F
.43928 .57843 m .41671 .58054 L .43543 .58055 L F
.44343 .58901 m .44179 .59002 L .44203 .5918 L .642 .739 .919 r
F
.44316 .58863 m .44174 .58962 L .44343 .58901 L F
.43575 .59157 m .44015 .58961 L .44014 .5926 L .785 .539 .565 r
F
.43691 .59405 m .43575 .59157 L .44014 .5926 L F
.44042 .59501 m .43639 .59391 L .43748 .60086 L .642 .739 .919 r
F
.43573 .59372 m .43575 .59157 L .43691 .59405 L .785 .539 .565 r
F
.43604 .59387 m .43019 .59886 L .43265 .59953 L .642 .739 .919 r
F
.43631 .5934 m .43588 .59379 L .43604 .59387 L F
.43588 .59379 m .43019 .59886 L .43604 .59387 L F
.43639 .59391 m .43265 .59953 L .43748 .60086 L F
.43631 .5934 m .43607 .59382 L .43639 .59391 L F
.43607 .59382 m .43265 .59953 L .43639 .59391 L F
.43572 .59458 m .43691 .59405 L .44012 .59561 L .785 .539 .565 r
F
.43691 .59405 m .44014 .5926 L .44012 .59493 L F
.43691 .59405 m .44012 .59493 L .44012 .59561 L F
.43312 .59251 m .43575 .59157 L .43573 .59372 L .843 .589 .554 r
F
.44181 .58263 m .44172 .58627 L .44327 .58297 L .668 .747 .91 r
F
.44178 .58565 m .44169 .5893 L .44325 .58599 L .667 .747 .91 r
F
.44369 .5821 m .44181 .58263 L .44327 .58297 L .668 .747 .91 r
F
.44385 .58175 m .44344 .58192 L .44369 .5821 L F
.44344 .58192 m .44181 .58263 L .44369 .5821 L F
.44199 .57913 m .4425 .57952 L .44246 .58122 L .908 .647 .532 r
F
.44199 .57913 m .44196 .58086 L .44184 .57903 L F
.44319 .58174 m .44181 .58263 L .44344 .58192 L .668 .747 .91 r
F
.44293 .58153 m .44181 .58263 L .44343 .58159 L F
.43575 .59157 m .43577 .58857 L .44015 .58961 L .785 .539 .565 r
F
.43881 .58558 m .44018 .58956 L .44172 .58627 L .668 .747 .91 r
F
.43881 .58558 m .43581 .58853 L .44018 .58956 L F
.43876 .58861 m .44014 .5926 L .44169 .5893 L .667 .747 .91 r
F
.43876 .58861 m .43575 .59157 L .44014 .5926 L F
.44181 .58263 m .43881 .58558 L .44172 .58627 L .668 .747 .91 r
F
.44178 .58565 m .43876 .58861 L .44169 .5893 L .667 .747 .91 r
F
.44258 .58782 m .43874 .58935 L .43631 .5934 L .642 .739 .919 r
F
.44297 .58747 m .44249 .58768 L .44258 .58782 L F
.44249 .58768 m .43874 .58935 L .44258 .58782 L F
.44056 .58208 m .43881 .58558 L .44181 .58263 L .668 .747 .91 r
F
.44052 .5851 m .43876 .58861 L .44165 .58577 L .667 .747 .91 r
F
.44163 .58558 m .44165 .58577 L .44178 .58565 L F
.44052 .5851 m .44165 .58577 L .44163 .58558 L F
.44219 .56329 m .44136 .57783 L .44172 .57721 L 0 0 .377 r
F
.4294 .57936 m .41559 .57623 L .41671 .58054 L .643 .738 .918 r
F
.4458 .57782 m .43836 .57743 L .4294 .57936 L F
.43836 .57743 m .41559 .57623 L .4294 .57936 L F
.44429 .56235 m .44324 .56264 L .44288 .57646 L .585 .37 .555 r
F
.44327 .58297 m .44485 .58651 L .44484 .58309 L .668 .747 .91 r
F
.44325 .58599 m .44483 .58954 L .44482 .58611 L .667 .747 .91 r
F
.44272 .57961 m .44347 .57992 L .44343 .58159 L .83 .576 .556 r
F
.44484 .58213 m .44327 .58297 L .44484 .58309 L .668 .747 .91 r
F
.44452 .58201 m .44327 .58297 L .44484 .58213 L F
.4439 .58165 m .44327 .58297 L .44484 .58177 L F
.44303 .58143 m .44293 .58153 L .44343 .58159 L F
.44272 .57961 m .44343 .58159 L .4427 .58131 L .83 .576 .556 r
F
.44381 .57998 m .44381 .58164 L .44347 .57992 L .747 .505 .564 r
F
.44381 .58164 m .44348 .5816 L .44347 .57992 L F
.44153 .57859 m .44184 .57903 L .44179 .58074 L .984 .727 .46 r
F
.44258 .58187 m .44157 .58151 L .44181 .58263 L .668 .747 .91 r
F
.44211 .5812 m .44157 .58151 L .44258 .58187 L F
.44157 .58151 m .44056 .58208 L .4417 .58258 L F
.44157 .58151 m .4417 .58258 L .44181 .58263 L F
.44153 .57859 m .44179 .58074 L .44156 .5804 L .984 .727 .46 r
F
.44157 .58151 m .43959 .58137 L .44056 .58208 L .668 .747 .91 r
F
.44147 .58075 m .43959 .58137 L .44157 .58151 L F
.44153 .57859 m .44156 .5804 L .4415 .58032 L .984 .727 .46 r
F
.44196 .58086 m .44182 .58076 L .44184 .57903 L .908 .647 .532 r
F
.44347 .57992 m .44348 .5816 L .44343 .58159 L .747 .505 .564 r
F
.44199 .57913 m .44246 .58122 L .44196 .58086 L .908 .647 .532 r
F
.4425 .57952 m .44249 .58123 L .44246 .58122 L .83 .576 .556 r
F
.44147 .58075 m .43898 .58054 L .43959 .58137 L .668 .747 .91 r
F
.44153 .57859 m .4415 .58032 L .44144 .57847 L .984 .727 .46 r
F
.44136 .57783 m .44132 .57954 L .44132 .57951 L .868 .695 .169 r
F
.44138 .57797 m .44136 .57985 L .44135 .57978 L F
.44138 .57797 m .44144 .57847 L .4414 .58018 L F
.44324 .56264 m .44183 .57704 L .44264 .57659 L .428 .243 .527 r
F
.44219 .56329 m .44172 .57721 L .44183 .57704 L 0 0 .377 r
F
.4458 .57782 m .44099 .57687 L .43836 .57743 L .643 .738 .918 r
F
.44211 .5812 m .44147 .58075 L .44157 .58151 L .668 .747 .91 r
F
.44254 .5849 m .44155 .58499 L .44178 .58565 L .667 .747 .91 r
F
.44155 .58499 m .44052 .5851 L .44163 .58558 L F
.44155 .58499 m .44163 .58558 L .44178 .58565 L F
.44239 .58467 m .44154 .58487 L .44254 .5849 L F
.44154 .58487 m .44052 .5851 L .44155 .58499 L F
.44154 .58487 m .44155 .58499 L .44254 .5849 L F
.4414 .58018 m .4409 .58025 L .44147 .58075 L .668 .747 .91 r
F
.4409 .58025 m .44067 .58068 L .44147 .58075 L F
.4414 .58017 m .43898 .58054 L .4414 .58018 L F
.4414 .58017 m .43877 .57965 L .43898 .58054 L F
.44133 .57965 m .43877 .57965 L .4414 .58017 L F
.44134 .57968 m .4413 .58297 L .44126 .58269 L .868 .695 .169 r
F
.44138 .57797 m .44135 .57978 L .44134 .57968 L F
.44135 .57978 m .4413 .58297 L .44134 .57968 L F
.44133 .57965 m .43897 .57876 L .43877 .57965 L .668 .747 .91 r
F
.44126 .58269 m .44125 .58264 L .44132 .57957 L .868 .695 .169 r
F
.44132 .57959 m .44132 .57957 L .44136 .57783 L F
.44126 .58269 m .44132 .57957 L .44132 .57959 L F
.44126 .57911 m .43958 .57793 L .43897 .57876 L .668 .747 .91 r
F
.44138 .57797 m .44134 .57968 L .44136 .57783 L .868 .695 .169 r
F
.44134 .57968 m .44132 .57959 L .44136 .57783 L F
.44184 .57903 m .44182 .58076 L .44179 .58074 L .908 .647 .532 r
F
.44172 .57721 m .44136 .57783 L .44132 .57951 L 0 0 .377 r
F
.44138 .57797 m .4414 .58018 L .44136 .57985 L .868 .695 .169 r
F
.44172 .57721 m .44132 .57951 L .44167 .57888 L 0 0 .377 r
F
.44143 .58022 m .44141 .5802 L .44144 .57847 L .984 .727 .46 r
F
.4415 .58032 m .44143 .58022 L .44144 .57847 L F
.44152 .57915 m .4412 .57846 L .44126 .57911 L .668 .747 .91 r
F
.44483 .57966 m .4418 .57866 L .44152 .57915 L F
.44207 .58422 m .4415 .58454 L .44239 .58467 L .667 .747 .91 r
F
.4415 .58454 m .44052 .5851 L .44154 .58487 L F
.4415 .58454 m .44154 .58487 L .44239 .58467 L F
.44179 .58074 m .44177 .58376 L .44172 .58372 L .908 .647 .532 r
F
.44182 .58076 m .44178 .58377 L .44179 .58074 L F
.44207 .58422 m .44033 .58413 L .44052 .5851 L .667 .747 .91 r
F
.44226 .58411 m .44199 .58411 L .44207 .58422 L F
.44199 .58411 m .44033 .58413 L .44207 .58422 L F
.44141 .58328 m .44141 .5802 L .44143 .58022 L .984 .727 .46 r
F
.4414 .58378 m .44033 .58413 L .44144 .58412 L .667 .747 .91 r
F
.4415 .58032 m .44144 .58333 L .44143 .58022 L .984 .727 .46 r
F
.44144 .58333 m .44141 .58328 L .44143 .58022 L F
.4414 .58327 m .44141 .5802 L .44141 .58328 L F
.44178 .58377 m .44177 .58376 L .44179 .58074 L .908 .647 .532 r
F
.4414 .58018 m .44136 .58321 L .44132 .58316 L .984 .727 .46 r
F
.44144 .57847 m .44141 .5802 L .4414 .58018 L F
.44141 .5802 m .44136 .58321 L .4414 .58018 L F
.44125 .58264 m .44124 .58256 L .44132 .57954 L .868 .695 .169 r
F
.44132 .57957 m .44132 .57954 L .44136 .57783 L F
.44125 .58264 m .44132 .57954 L .44132 .57957 L F
.44116 .57833 m .44054 .57721 L .43974 .57781 L .668 .747 .91 r
F
.44183 .57704 m .44177 .57869 L .44179 .57867 L 0 0 .377 r
F
.44183 .57704 m .44177 .5787 L .44177 .57869 L F
.42303 .5733 m .41946 .56815 L .41652 .572 L .643 .738 .918 r
F
.44534 .56228 m .44429 .56235 L .44393 .57624 L .667 .437 .562 r
F
.4458 .57782 m .44165 .5763 L .43858 .57639 L .643 .738 .918 r
F
.44483 .57966 m .44241 .57828 L .4419 .57859 L .668 .747 .91 r
F
.44429 .56235 m .44288 .57646 L .4437 .57629 L .585 .37 .555 r
F
.44324 .56264 m .44264 .57659 L .44288 .57646 L .428 .243 .527 r
F
.44165 .5763 m .42423 .56494 L .41946 .56815 L .643 .738 .918 r
F
.4458 .57782 m .44318 .57626 L .44165 .5763 L F
.44318 .57626 m .42423 .56494 L .44165 .5763 L F
.44483 .57966 m .4419 .57859 L .4418 .57866 L .668 .747 .91 r
F
.44303 .58143 m .44211 .5812 L .44258 .58187 L F
.44272 .57961 m .4427 .58131 L .4425 .57952 L .83 .576 .556 r
F
.4427 .58131 m .44256 .58126 L .4425 .57952 L F
.44223 .58113 m .44211 .5812 L .44303 .58143 L .668 .747 .91 r
F
.44267 .58431 m .44247 .58423 L .4425 .57952 L .83 .576 .556 r
F
.44484 .58177 m .44452 .58201 L .44484 .58213 L .668 .747 .91 r
F
.44381 .57998 m .445 .58018 L .44496 .58178 L .747 .505 .564 r
F
.44381 .57998 m .44496 .58178 L .44419 .58169 L F
.44381 .57998 m .44488 .58476 L .44381 .58463 L F
.44483 .57966 m .44303 .58143 L .44343 .58159 L .668 .747 .91 r
F
.4439 .58165 m .44343 .58159 L .44385 .58175 L F
.44483 .57966 m .44343 .58159 L .4439 .58165 L F
.44581 .58196 m .44487 .58333 L .44582 .58468 L .643 .738 .918 r
F
.44484 .58309 m .44485 .58651 L .44797 .58628 L .668 .747 .91 r
F
.44484 .58309 m .44797 .58628 L .4464 .58298 L F
.44419 .58169 m .44496 .58178 L .44488 .58476 L .747 .505 .564 r
F
.44388 .58813 m .44316 .58863 L .44343 .58901 L .642 .739 .919 r
F
.44408 .58772 m .4437 .588 L .44388 .58813 L F
.4437 .588 m .43631 .5934 L .44388 .58813 L F
.44417 .58754 m .44399 .58768 L .44408 .58772 L F
.44399 .58768 m .44363 .58795 L .44408 .58772 L F
.44363 .58795 m .43631 .5934 L .4437 .588 L F
.44363 .58795 m .4437 .588 L .44408 .58772 L F
.44128 .58341 m .44081 .58327 L .44066 .58354 L .667 .747 .91 r
F
.44229 .5811 m .44179 .58074 L .44211 .5812 L .668 .747 .91 r
F
.44196 .58086 m .44246 .58122 L .44238 .5842 L .908 .647 .532 r
F
.44196 .58086 m .44238 .5842 L .44214 .58402 L F
.4427 .58131 m .44343 .58159 L .44335 .58457 L .83 .576 .556 r
F
.44366 .58511 m .44178 .58565 L .44325 .58599 L .667 .747 .91 r
F
.44383 .58475 m .44341 .58494 L .44366 .58511 L F
.44341 .58494 m .44178 .58565 L .44366 .58511 L F
.44196 .58086 m .44191 .58386 L .44182 .58076 L .908 .647 .532 r
F
.44187 .58666 m .44175 .58657 L .44178 .58377 L F
.44185 .58381 m .44178 .58377 L .44182 .58076 L F
.44167 .58369 m .44199 .58411 L .44172 .58372 L .667 .747 .91 r
F
.44187 .58666 m .44178 .58377 L .44185 .58381 L .908 .647 .532 r
F
.44335 .58457 m .44312 .58473 L .44383 .58475 L .667 .747 .91 r
F
.44312 .58473 m .44178 .58565 L .44341 .58494 L F
.44312 .58473 m .44341 .58494 L .44383 .58475 L F
.44301 .58444 m .44293 .58452 L .44335 .58457 L F
.44293 .58452 m .44178 .58565 L .44335 .58457 L F
.44381 .58164 m .44381 .58463 L .44348 .5816 L .747 .505 .564 r
F
.44343 .58159 m .44319 .58174 L .44385 .58175 L .668 .747 .91 r
F
.44319 .58174 m .44344 .58192 L .44385 .58175 L F
.44381 .58463 m .4435 .58459 L .44348 .5816 L .747 .505 .564 r
F
.4427 .58131 m .44335 .58457 L .443 .58443 L .83 .576 .556 r
F
.44482 .58475 m .44325 .58599 L .44482 .58611 L .667 .747 .91 r
F
.44482 .58267 m .44389 .58464 L .44482 .58475 L F
.44389 .58464 m .44325 .58599 L .44482 .58475 L F
.44348 .5816 m .4435 .58459 L .44343 .58159 L .747 .505 .564 r
F
.4435 .58459 m .44352 .58742 L .44348 .58458 L F
.4435 .58459 m .44348 .58458 L .44343 .58159 L F
.44335 .58457 m .44352 .58742 L .44328 .58738 L F
.44343 .58159 m .44348 .58458 L .44335 .58457 L F
.44348 .58458 m .44352 .58742 L .44335 .58457 L F
.44482 .58267 m .44301 .58444 L .44335 .58457 L .667 .747 .91 r
F
.44389 .58464 m .44335 .58457 L .44383 .58475 L F
.44482 .58267 m .44335 .58457 L .44389 .58464 L F
.4431 .58735 m .43631 .5934 L .44399 .58768 L .642 .739 .919 r
F
.44328 .58738 m .44399 .58768 L .44417 .58754 L F
.4431 .58735 m .44399 .58768 L .44328 .58738 L F
.44289 .58456 m .44239 .58467 L .44254 .5849 L .667 .747 .91 r
F
.44267 .58431 m .44264 .58712 L .44247 .58423 L .83 .576 .556 r
F
.44314 .58732 m .44231 .58698 L .44297 .58747 L .642 .739 .919 r
F
.44225 .58693 m .43932 .58837 L .44297 .58747 L F
.43196 .58994 m .43577 .58857 L .43575 .59157 L .843 .589 .554 r
F
.43312 .59251 m .43196 .58994 L .43575 .59157 L F
.43197 .59198 m .43197 .59198 L .43239 .59217 L .642 .739 .919 r
F
.43197 .59198 m .4239 .59594 L .43228 .59222 L F
.43197 .59198 m .43228 .59222 L .43239 .59217 L F
.43195 .59197 m .43196 .58994 L .43312 .59251 L .843 .589 .554 r
F
.4363 .58449 m .43581 .58853 L .43881 .58558 L .668 .747 .91 r
F
.43624 .58752 m .43575 .59157 L .43876 .58861 L .667 .747 .91 r
F
.43196 .58994 m .43199 .58693 L .43577 .58857 L .843 .589 .554 r
F
.4363 .58449 m .43205 .5869 L .43581 .58853 L .668 .747 .91 r
F
.43624 .58752 m .43196 .58994 L .43575 .59157 L .667 .747 .91 r
F
.43874 .58935 m .4239 .59594 L .43631 .5934 L .642 .739 .919 r
F
.43001 .59051 m .43196 .58994 L .43195 .59197 L .911 .649 .53 r
F
.44264 .58712 m .44246 .58704 L .44247 .58423 L .83 .576 .556 r
F
.44191 .58386 m .44185 .58381 L .44182 .58076 L .908 .647 .532 r
F
.44196 .58086 m .44214 .58402 L .44191 .58386 L F
.4427 .58131 m .44267 .58431 L .44256 .58126 L .83 .576 .556 r
F
.44169 .58368 m .44128 .58341 L .44167 .58369 L .667 .747 .91 r
F
.4415 .58032 m .44157 .58352 L .44144 .58333 L .984 .727 .46 r
F
.4414 .58378 m .44066 .58354 L .44134 .5838 L .667 .747 .91 r
F
.44167 .58369 m .44138 .58365 L .4414 .58378 L F
.44138 .58365 m .44066 .58354 L .4414 .58378 L F
.44132 .57954 m .44124 .58256 L .44132 .57951 L .868 .695 .169 r
F
.44128 .58341 m .44066 .58354 L .44167 .58369 L .667 .747 .91 r
F
.44174 .58067 m .4414 .58018 L .44147 .58075 L .668 .747 .91 r
F
.44156 .5804 m .4416 .58356 L .4415 .58032 L .984 .727 .46 r
F
.4416 .58356 m .44164 .58649 L .44157 .58352 L F
.4416 .58356 m .44157 .58352 L .4415 .58032 L F
.44147 .58337 m .44103 .58323 L .44128 .58341 L .667 .747 .91 r
F
.4414 .58327 m .44136 .58321 L .44141 .5802 L .984 .727 .46 r
F
.44167 .58369 m .4414 .58378 L .44199 .58411 L .667 .747 .91 r
F
.4414 .58378 m .44144 .58412 L .44199 .58411 L F
.44174 .58067 m .44147 .58075 L .44211 .5812 L .668 .747 .91 r
F
.44156 .5804 m .44179 .58074 L .44172 .58372 L .984 .727 .46 r
F
.44169 .58368 m .44167 .58369 L .44172 .58372 L .667 .747 .91 r
F
.4416 .58356 m .44172 .58372 L .44164 .58649 L .984 .727 .46 r
F
.44156 .5804 m .44172 .58372 L .4416 .58356 L F
.44267 .58431 m .44328 .58738 L .44264 .58712 L .83 .576 .556 r
F
.4427 .58131 m .443 .58443 L .44267 .58431 L F
.44291 .5844 m .44238 .5842 L .44281 .5845 L .667 .747 .91 r
F
.44293 .58452 m .44281 .5845 L .44289 .58456 L F
.443 .58443 m .44328 .58738 L .44267 .58431 L .83 .576 .556 r
F
.44238 .5842 m .44246 .58704 L .44231 .58698 L F
.44246 .58122 m .44246 .58423 L .44238 .5842 L F
.44238 .5842 m .44207 .58422 L .44289 .58456 L .667 .747 .91 r
F
.44207 .58422 m .44239 .58467 L .44289 .58456 L F
.44246 .58423 m .44246 .58704 L .44238 .5842 L .83 .576 .556 r
F
.44226 .58411 m .44222 .58413 L .44238 .5842 L .667 .747 .91 r
F
.44222 .58413 m .44207 .58422 L .44238 .5842 L F
.44249 .58123 m .44247 .58423 L .44246 .58122 L .83 .576 .556 r
F
.44247 .58423 m .44246 .58704 L .44246 .58423 L F
.44247 .58423 m .44246 .58423 L .44246 .58122 L F
.44483 .57966 m .4423 .57927 L .44221 .57965 L .668 .747 .91 r
F
.4423 .57927 m .44152 .57915 L .44221 .57965 L F
.44221 .57965 m .44152 .57915 L .44133 .57965 L F
.44483 .57966 m .44133 .57965 L .4414 .58017 L F
.44483 .57966 m .44174 .58067 L .44179 .58074 L F
.44483 .57966 m .44179 .58074 L .44229 .5811 L F
.44483 .57966 m .4421 .58007 L .4421 .58007 L F
.4421 .58007 m .4414 .58017 L .4421 .58007 L F
.4421 .58007 m .4414 .58017 L .4414 .58018 L F
.44483 .57966 m .4414 .58018 L .44174 .58067 L F
.44172 .57721 m .44167 .57888 L .44183 .57704 L 0 0 .377 r
F
.44056 .58208 m .4363 .58449 L .43881 .58558 L .668 .747 .91 r
F
.44109 .58275 m .44009 .58266 L .43988 .58278 L .667 .747 .91 r
F
.44135 .57978 m .44132 .58316 L .4413 .58297 L .868 .695 .169 r
F
.44136 .57985 m .44132 .58316 L .44135 .57978 L F
.4414 .58017 m .4414 .58017 L .4414 .58018 L .668 .747 .91 r
F
.44136 .57985 m .4414 .58018 L .44132 .58316 L .868 .695 .169 r
F
.44482 .58267 m .44115 .58266 L .44109 .58275 L .667 .747 .91 r
F
.44115 .58266 m .44009 .58266 L .44109 .58275 L F
.4418 .57866 m .44179 .57867 L .44152 .57915 L .668 .747 .91 r
F
.44167 .57888 m .44157 .5819 L .44177 .5787 L 0 0 .377 r
F
.43959 .58137 m .4363 .58449 L .44056 .58208 L .668 .747 .91 r
F
.44081 .58327 m .43876 .58281 L .4402 .58336 L .667 .747 .91 r
F
.44482 .58267 m .44109 .58275 L .44081 .58327 L F
.44109 .58275 m .43876 .58281 L .44081 .58327 L F
.44124 .58256 m .44124 .58255 L .44132 .57951 L .868 .695 .169 r
F
.44132 .57951 m .44124 .58255 L .44124 .58249 L F
.44152 .57915 m .44132 .57951 L .44133 .57965 L .668 .747 .91 r
F
.44134 .57968 m .44126 .58269 L .44132 .57959 L .868 .695 .169 r
F
.44167 .57888 m .44132 .57951 L .44124 .58249 L 0 0 .377 r
F
.44134 .58319 m .44103 .58323 L .44147 .58337 L .667 .747 .91 r
F
.44167 .57888 m .44124 .58249 L .44141 .58219 L 0 0 .377 r
F
.43959 .58137 m .43437 .58307 L .4363 .58449 L .668 .747 .91 r
F
.44009 .58266 m .43893 .58176 L .43872 .58265 L .667 .747 .91 r
F
.44482 .58267 m .44143 .58215 L .44115 .58266 L F
.44482 .58267 m .44134 .58319 L .44147 .58337 L F
.44482 .58267 m .44147 .58337 L .44169 .58368 L F
.44147 .58337 m .44128 .58341 L .44169 .58368 L F
.44144 .58333 m .44138 .58612 L .44141 .58328 L .984 .727 .46 r
F
.44138 .58612 m .4414 .58327 L .44141 .58328 L F
.44132 .58316 m .44131 .58602 L .44125 .58593 L F
.44136 .58321 m .44131 .58602 L .44132 .58316 L F
.44126 .58269 m .44125 .58593 L .44119 .58551 L .868 .695 .169 r
F
.44138 .58612 m .44136 .58321 L .4414 .58327 L .984 .727 .46 r
F
.44167 .57888 m .44141 .58219 L .44157 .5819 L 0 0 .377 r
F
.44157 .5819 m .44166 .58173 L .44177 .5787 L F
.44177 .57869 m .44167 .58171 L .44179 .57867 L F
.44167 .58171 m .44168 .5817 L .44179 .57867 L F
.44264 .57659 m .44179 .57867 L .44258 .57818 L .428 .243 .527 r
F
.44257 .57809 m .44294 .5778 L .44224 .57786 L .668 .747 .91 r
F
.44483 .57966 m .44309 .57794 L .44257 .57809 L F
.44534 .56228 m .44393 .57624 L .44475 .57621 L .667 .437 .562 r
F
.44429 .56235 m .4437 .57629 L .44393 .57624 L .585 .37 .555 r
F
.4458 .57782 m .4305 .56261 L .42423 .56494 L .643 .738 .918 r
F
.4437 .57629 m .44288 .57646 L .44284 .57801 L .585 .37 .555 r
F
.44309 .57794 m .44294 .5778 L .44257 .57809 L .668 .747 .91 r
F
.44482 .58267 m .44171 .58165 L .44171 .58165 L .667 .747 .91 r
F
.44143 .58215 m .44171 .58165 L .44101 .58208 L F
.44482 .58267 m .44171 .58165 L .44143 .58215 L F
.44167 .58171 m .44156 .58463 L .44158 .5846 L 0 0 .377 r
F
.44177 .57869 m .44166 .58173 L .44167 .58171 L F
.44166 .58173 m .44156 .58463 L .44167 .58171 L F
.44483 .57966 m .44224 .57786 L .4421 .5781 L .668 .747 .91 r
F
.44482 .58267 m .44226 .58411 L .44238 .5842 L .667 .747 .91 r
F
.44482 .58267 m .44238 .5842 L .44291 .5844 L F
.44482 .58267 m .44169 .58368 L .44226 .58411 L F
.44144 .58333 m .44164 .58649 L .44138 .58612 L .984 .727 .46 r
F
.44157 .58352 m .44164 .58649 L .44144 .58333 L F
.44381 .58463 m .4438 .58747 L .4435 .58459 L .747 .505 .564 r
F
.4438 .58747 m .44352 .58742 L .4435 .58459 L F
.44191 .58386 m .44187 .58666 L .44185 .58381 L .908 .647 .532 r
F
.443 .58443 m .44335 .58457 L .44328 .58738 L .83 .576 .556 r
F
.44191 .58386 m .44231 .58698 L .44187 .58666 L .908 .647 .532 r
F
.44172 .58372 m .44199 .58411 L .44226 .58411 L .667 .747 .91 r
F
.44214 .58402 m .44231 .58698 L .44191 .58386 L .908 .647 .532 r
F
.44214 .58402 m .44238 .5842 L .44231 .58698 L F
.44381 .58463 m .44488 .58476 L .44481 .58765 L .747 .505 .564 r
F
.44483 .58954 m .44954 .59262 L .44797 .58932 L .667 .747 .91 r
F
.44485 .58651 m .44588 .58718 L .44519 .58648 L .668 .747 .91 r
F
.44588 .58718 m .44953 .58957 L .44519 .58648 L F
.44519 .58648 m .44953 .58957 L .44797 .58628 L F
.44482 .58611 m .44483 .58954 L .44797 .58932 L .667 .747 .91 r
F
.44522 .58771 m .44343 .58901 L .44523 .59155 L .642 .739 .919 r
F
.44481 .58765 m .44343 .58901 L .44522 .58771 L F
.44417 .58754 m .44409 .58769 L .44481 .58765 L F
.44409 .58769 m .44343 .58901 L .44481 .58765 L F
.44522 .58789 m .44525 .5955 L .44623 .58758 L F
.44525 .5955 m .44527 .60182 L .4457 .5955 L F
.44548 .5955 m .44954 .59262 L .44953 .59543 L .673 .446 .569 r
F
.44525 .5955 m .4457 .5955 L .44623 .58758 L .642 .739 .919 r
F
.4458 .57782 m .46704 .59051 L .46771 .59008 L .643 .738 .918 r
F
.45282 .5804 m .46771 .59008 L .47186 .58739 L F
.4458 .57782 m .46771 .59008 L .45282 .5804 L F
.44999 .59535 m .44638 .6018 L .45307 .60168 L .642 .739 .919 r
F
.4498 .59538 m .44954 .59262 L .45392 .5916 L .607 .393 .565 r
F
.44953 .59543 m .44954 .59262 L .4498 .59538 L F
.44714 .59583 m .44638 .6018 L .44999 .59535 L .642 .739 .919 r
F
.45279 .59487 m .45392 .5916 L .45392 .59461 L .607 .393 .565 r
F
.44999 .59535 m .45307 .60168 L .45408 .5964 L .642 .739 .919 r
F
.45279 .59487 m .45408 .5964 L .45442 .59459 L F
.44999 .59535 m .45408 .5964 L .45279 .59487 L F
.44953 .59562 m .4498 .59538 L .45279 .59487 L .607 .393 .565 r
F
.4498 .59538 m .45392 .5916 L .45279 .59487 L F
.45193 .59385 m .45279 .59487 L .45392 .59461 L .667 .747 .91 r
F
.44797 .58628 m .45388 .58856 L .45088 .5856 L .668 .747 .91 r
F
.4464 .58298 m .44797 .58628 L .45088 .5856 L F
.45177 .58376 m .45722 .59337 L .46082 .59276 L .643 .738 .918 r
F
.44786 .58264 m .45088 .5856 L .45338 .58452 L .668 .747 .91 r
F
.4464 .58298 m .45088 .5856 L .44786 .58264 L F
.44786 .58264 m .45338 .58452 L .44911 .58209 L F
.45088 .5856 m .45388 .58856 L .45764 .58694 L F
.44786 .58566 m .4509 .58864 L .45342 .58755 L .667 .747 .91 r
F
.44647 .58598 m .4509 .58864 L .44786 .58566 L F
.4464 .586 m .44644 .58602 L .44647 .58598 L F
.44644 .58602 m .4509 .58864 L .44647 .58598 L F
.44773 .58131 m .44786 .58264 L .44911 .58209 L .668 .747 .91 r
F
.44581 .58013 m .4457 .5803 L .44581 .58032 L .643 .738 .918 r
F
.4458 .57782 m .44461 .58021 L .44581 .58013 L F
.44764 .57968 m .44815 .57936 L .44812 .58075 L .387 .212 .518 r
F
.44723 .58202 m .44786 .58264 L .44773 .58131 L .668 .747 .91 r
F
.44815 .58553 m .45342 .58755 L .44912 .58511 L .667 .747 .91 r
F
.44786 .58566 m .44812 .58574 L .44815 .58553 L F
.44812 .58574 m .45342 .58755 L .44815 .58553 L F
.4502 .5787 m .47186 .58739 L .47492 .58361 L .643 .738 .918 r
F
.4458 .57782 m .45282 .5804 L .4502 .5787 L F
.45282 .5804 m .47186 .58739 L .4502 .5787 L F
.44849 .56339 m .44744 .5627 L .44709 .57668 L .889 .63 .539 r
F
.44686 .58165 m .4464 .58298 L .44786 .58264 L .668 .747 .91 r
F
.4464 .586 m .44797 .58932 L .4509 .58864 L .667 .747 .91 r
F
.44764 .57968 m .4477 .58105 L .44762 .58111 L .387 .212 .518 r
F
.44843 .58084 m .44911 .58209 L .45007 .58139 L .668 .747 .91 r
F
.44764 .57968 m .44812 .58075 L .4477 .58105 L .387 .212 .518 r
F
.44812 .58074 m .44833 .58165 L .44843 .58084 L .668 .747 .91 r
F
.44824 .57924 m .4483 .58049 L .44826 .58055 L .095 0 .426 r
F
.44851 .58022 m .45007 .58139 L .45068 .58056 L .668 .747 .91 r
F
.44773 .58131 m .44833 .58165 L .44812 .58074 L F
.44826 .58462 m .44815 .58553 L .44912 .58511 L .667 .747 .91 r
F
.44835 .5839 m .44912 .58511 L .44973 .58467 L F
.44805 .58373 m .44833 .58408 L .44835 .5839 L F
.44833 .58408 m .44912 .58511 L .44835 .5839 L F
.44836 .58383 m .44973 .58467 L .44946 .58419 L F
.44805 .58373 m .44835 .5839 L .44836 .58383 L F
.44835 .5839 m .44973 .58467 L .44836 .58383 L F
.44843 .58084 m .45007 .58139 L .44851 .58022 L .668 .747 .91 r
F
.44833 .58165 m .44911 .58209 L .44843 .58084 L F
.44851 .58022 m .44902 .5803 L .44857 .57967 L F
.44902 .5803 m .45068 .58056 L .4487 .57972 L F
.44902 .5803 m .4487 .57972 L .44857 .57967 L F
.44896 .56427 m .44815 .57737 L .44852 .57801 L .993 .743 .421 r
F
.44896 .56427 m .44852 .57801 L .44862 .5782 L F
.45165 .57813 m .47492 .58361 L .47602 .57942 L .643 .738 .918 r
F
.4458 .57782 m .45881 .58041 L .45165 .57813 L F
.45881 .58041 m .47492 .58361 L .45165 .57813 L F
.44853 .58003 m .44852 .58013 L .44854 .57884 L 0 0 .082 r
F
.44846 .58298 m .44845 .58311 L .44851 .58017 L F
.44852 .58013 m .44851 .58017 L .44854 .57884 L F
.44846 .58298 m .44851 .58017 L .44852 .58013 L F
.44865 .57908 m .45089 .57967 L .45068 .57878 L .668 .747 .91 r
F
.44856 .57869 m .44853 .58003 L .44854 .57884 L 0 0 .082 r
F
.44851 .58019 m .44845 .58311 L .44844 .58317 L F
.44854 .57884 m .44851 .58017 L .44851 .58019 L F
.44851 .58017 m .44845 .58311 L .44851 .58019 L F
.44958 .57747 m .47602 .57942 L .47505 .57509 L .643 .738 .918 r
F
.4458 .57782 m .45165 .57813 L .44958 .57747 L F
.45165 .57813 m .47602 .57942 L .44958 .57747 L F
.44744 .5627 m .44639 .56239 L .44604 .57635 L .799 .548 .56 r
F
.44856 .57869 m .44862 .5782 L .44859 .57953 L 0 0 .082 r
F
.44856 .57869 m .44859 .57953 L .44855 .57988 L F
.44847 .57932 m .44858 .57951 L .44862 .5782 L .993 .743 .421 r
F
.44862 .5782 m .44858 .57951 L .44859 .57953 L F
.44856 .57869 m .44849 .58273 L .44846 .58298 L 0 0 .082 r
F
.44824 .57924 m .44826 .58055 L .44821 .58062 L .095 0 .426 r
F
.44856 .57869 m .44855 .57988 L .44854 .57995 L 0 0 .082 r
F
.44824 .57924 m .44854 .57884 L .44851 .58019 L .095 0 .426 r
F
.44824 .57924 m .44851 .58019 L .4483 .58049 L F
.4458 .57782 m .44581 .58013 L .44652 .58008 L .643 .738 .918 r
F
.4458 .57782 m .44652 .58008 L .44684 .57998 L F
.4458 .57782 m .44665 .5796 L .44755 .57956 L F
.44665 .5796 m .44684 .57998 L .44755 .57956 L F
.44755 .57956 m .44684 .57998 L .4477 .57971 L F
.44815 .57936 m .44813 .58074 L .44812 .58075 L .095 0 .426 r
F
.44674 .58001 m .44749 .57977 L .44746 .58123 L .539 .332 .549 r
F
.44674 .58001 m .44746 .58123 L .44695 .58142 L F
.44685 .58146 m .44738 .58421 L .44708 .58432 L F
.44674 .58001 m .44695 .58142 L .44685 .58146 L F
.44695 .58142 m .44738 .58421 L .44685 .58146 L F
.44671 .58151 m .44686 .58165 L .44746 .58123 L .668 .747 .91 r
F
.44482 .58611 m .44797 .58932 L .4464 .586 L .667 .747 .91 r
F
.44681 .58462 m .4464 .586 L .44786 .58566 L F
.44534 .58016 m .44534 .58174 L .445 .58018 L .651 .424 .562 r
F
.44534 .58174 m .44507 .58177 L .445 .58018 L F
.44579 .58168 m .44484 .58309 L .4464 .58298 L .668 .747 .91 r
F
.44507 .58177 m .44501 .58178 L .445 .58018 L .651 .424 .562 r
F
.44484 .5818 m .44484 .58309 L .44579 .58168 L .668 .747 .91 r
F
.44583 .5848 m .44482 .58611 L .4464 .586 L .667 .747 .91 r
F
.44576 .58465 m .44562 .58488 L .44583 .5848 L F
.44562 .58488 m .44482 .58611 L .44583 .5848 L F
.44672 .58454 m .44601 .58518 L .44681 .58462 L F
.44641 .58457 m .44601 .58518 L .44672 .58454 L F
.44576 .58465 m .44583 .5848 L .44641 .58457 L F
.44583 .5848 m .44601 .58518 L .44641 .58457 L F
.44672 .58175 m .4464 .58298 L .44686 .58165 L .668 .747 .91 r
F
.44482 .58477 m .44482 .58611 L .44576 .58465 L .667 .747 .91 r
F
.44601 .58518 m .4464 .586 L .44681 .58462 L F
.44648 .5816 m .4464 .58298 L .44677 .58156 L .668 .747 .91 r
F
.44579 .58168 m .44586 .58183 L .44648 .5816 L F
.44586 .58183 m .4464 .58298 L .44648 .5816 L F
.4467 .58447 m .4465 .58454 L .44652 .58158 L .539 .332 .549 r
F
.44658 .58156 m .44652 .58158 L .44652 .58008 L F
.4467 .58447 m .44652 .58158 L .44658 .58156 L F
.44675 .58843 m .4478 .59067 L .44744 .58849 L .642 .739 .919 r
F
.4478 .59067 m .44999 .59535 L .44795 .58952 L F
.4478 .59067 m .44795 .58952 L .44769 .58879 L F
.44675 .58843 m .44744 .58849 L .44705 .58803 L F
.44634 .58754 m .44675 .58843 L .44699 .58796 L F
.44634 .58754 m .44699 .58796 L .44663 .58752 L F
.44766 .58428 m .44912 .58511 L .44805 .58373 L .667 .747 .91 r
F
.44805 .58373 m .44805 .58373 L .44805 .58373 L F
.44766 .58428 m .44805 .58373 L .44805 .58373 L F
.4477 .58105 m .44783 .58388 L .44762 .58111 L .387 .212 .518 r
F
.44766 .58428 m .44786 .58566 L .44815 .58553 L .667 .747 .91 r
F
.44828 .58689 m .44911 .58812 L .44969 .5877 L F
.44797 .58672 m .44825 .58706 L .44828 .58689 L F
.44825 .58706 m .44911 .58812 L .44828 .58689 L F
.44812 .58074 m .44843 .58084 L .44849 .58022 L .668 .747 .91 r
F
.44824 .57924 m .44816 .58357 L .44815 .57936 L .095 0 .426 r
F
.44805 .58373 m .44946 .58419 L .44841 .58322 L .667 .747 .91 r
F
.44946 .58419 m .45009 .5844 L .44925 .58381 L F
.44946 .58419 m .44925 .58381 L .44841 .58322 L F
.44845 .58021 m .44849 .58022 L .44856 .57976 L .668 .747 .91 r
F
.44845 .58021 m .44856 .57976 L .44857 .57967 L F
.44816 .58357 m .44808 .58368 L .44815 .57936 L .095 0 .426 r
F
.4467 .58447 m .44667 .58743 L .4465 .58454 L .539 .332 .549 r
F
.44667 .58743 m .44667 .58743 L .4465 .58454 L F
.44667 .58743 m .44649 .5875 L .4465 .58454 L F
.44662 .58745 m .44675 .58759 L .44669 .58743 L .667 .747 .91 r
F
.44675 .58759 m .44785 .58867 L .44681 .58755 L F
.44675 .58759 m .44681 .58755 L .44669 .58743 L F
.44747 .58417 m .44717 .58498 L .44766 .58428 L F
.44717 .58498 m .44786 .58566 L .44766 .58428 L F
.44744 .58416 m .44741 .58712 L .44738 .58421 L .387 .212 .518 r
F
.44738 .58714 m .44731 .58719 L .44741 .58715 L .667 .747 .91 r
F
.44731 .58719 m .44785 .58867 L .44741 .58715 L F
.44669 .58743 m .44681 .58755 L .44731 .58719 L F
.44681 .58755 m .44785 .58867 L .44731 .58719 L F
.44764 .57968 m .44762 .58111 L .44749 .57977 L .387 .212 .518 r
F
.44762 .58111 m .4475 .58119 L .44749 .57977 L F
.44754 .58703 m .44741 .58712 L .44744 .58416 L F
.44751 .58119 m .44723 .58202 L .44773 .58131 L .668 .747 .91 r
F
.44752 .58411 m .44744 .58416 L .44749 .57977 L .387 .212 .518 r
F
.44754 .58703 m .44744 .58416 L .44752 .58411 L F
.44581 .5809 m .44536 .58162 L .44581 .58196 L .643 .738 .918 r
F
.44581 .58032 m .44553 .58078 L .44581 .5809 L F
.44534 .58016 m .44652 .58008 L .44641 .58457 L .651 .424 .562 r
F
.44675 .58843 m .44705 .58803 L .44699 .58796 L .642 .739 .919 r
F
.44623 .58758 m .44999 .59535 L .44634 .58754 L F
.44635 .58784 m .44638 .6018 L .44779 .5908 L F
.44653 .58754 m .44639 .58901 L .44763 .58872 L .667 .747 .91 r
F
.44533 .58471 m .44641 .58457 L .44634 .58754 L .651 .424 .562 r
F
.44633 .58754 m .44634 .58754 L .44634 .58756 L F
.44533 .58471 m .44634 .58754 L .44633 .58754 L F
.44759 .58726 m .44911 .58812 L .44797 .58672 L .667 .747 .91 r
F
.44759 .58726 m .44785 .58867 L .44911 .58812 L F
.44954 .59262 m .44955 .58962 L .45393 .58861 L .607 .393 .565 r
F
.45392 .5916 m .45393 .58861 L .4577 .58698 L .521 .324 .554 r
F
.44954 .59262 m .45393 .58861 L .45392 .5916 L .607 .393 .565 r
F
.44797 .58932 m .44954 .59262 L .45392 .5916 L .667 .747 .91 r
F
.45392 .5916 m .4577 .58698 L .4577 .58998 L .521 .324 .554 r
F
.45392 .59461 m .45392 .5916 L .4577 .58998 L F
.4509 .58864 m .45392 .5916 L .4577 .58998 L .667 .747 .91 r
F
.44797 .58932 m .45392 .5916 L .4509 .58864 L F
.45392 .59461 m .4577 .58998 L .4577 .59299 L .521 .324 .554 r
F
.45089 .59164 m .45392 .59461 L .4577 .59299 L .667 .747 .91 r
F
.4577 .59299 m .4577 .58998 L .4606 .58786 L .389 .221 .529 r
F
.4577 .59299 m .4606 .58786 L .46061 .59086 L F
.45341 .59056 m .4577 .59299 L .46061 .59086 L .667 .747 .91 r
F
.45089 .59164 m .4577 .59299 L .45341 .59056 L F
.44785 .58867 m .45089 .59164 L .45341 .59056 L F
.4577 .58998 m .4577 .58698 L .4606 .58486 L .389 .221 .529 r
F
.4577 .58998 m .4606 .58486 L .4606 .58786 L F
.45342 .58755 m .4577 .58998 L .4606 .58786 L .667 .747 .91 r
F
.4509 .58864 m .4577 .58998 L .45342 .58755 L F
.45341 .59056 m .46061 .59086 L .45535 .58914 L F
.44911 .58812 m .45341 .59056 L .45535 .58914 L F
.44785 .58867 m .45079 .58966 L .44911 .58812 L F
.45079 .58966 m .45341 .59056 L .4503 .58879 L F
.45079 .58966 m .4503 .58879 L .44911 .58812 L F
.44621 .58755 m .44623 .58758 L .44634 .58754 L .642 .739 .919 r
F
.44522 .58762 m .44522 .58789 L .44621 .58755 L F
.44533 .58761 m .44634 .58756 L .44533 .58768 L .651 .424 .562 r
F
.44533 .58471 m .44633 .58754 L .44533 .58761 L F
.44633 .58754 m .44634 .58756 L .44533 .58761 L F
.44621 .58755 m .44522 .58789 L .44623 .58758 L .642 .739 .919 r
F
.44762 .58111 m .44758 .58407 L .4475 .58119 L .387 .212 .518 r
F
.44758 .58407 m .44754 .58703 L .44752 .58411 L F
.44758 .58407 m .44752 .58411 L .4475 .58119 L F
.44534 .58016 m .44641 .58457 L .44533 .58471 L .651 .424 .562 r
F
.44749 .57977 m .44744 .58416 L .44738 .58421 L .387 .212 .518 r
F
.44783 .58388 m .44779 .58391 L .44762 .58111 L F
.44671 .58151 m .44648 .5816 L .44677 .58156 L .668 .747 .91 r
F
.44672 .5815 m .4467 .58447 L .44658 .58156 L .539 .332 .549 r
F
.44652 .58008 m .4465 .58454 L .44641 .58457 L F
.445 .58018 m .44503 .58474 L .44488 .58476 L .651 .424 .562 r
F
.44533 .58761 m .44505 .58763 L .44501 .58178 L F
.44533 .58761 m .44501 .58178 L .44507 .58177 L F
.44534 .58174 m .44533 .58471 L .44507 .58177 L F
.44533 .58471 m .4452 .58472 L .44507 .58177 L F
.44762 .58111 m .44779 .58391 L .44758 .58407 L .387 .212 .518 r
F
.44677 .58156 m .44672 .58175 L .44686 .58165 L .668 .747 .91 r
F
.44674 .58001 m .44708 .58432 L .4467 .58447 L .539 .332 .549 r
F
.44686 .58165 m .44723 .58202 L .44751 .58119 L .668 .747 .91 r
F
.44695 .58142 m .44746 .58123 L .44738 .58421 L .539 .332 .549 r
F
.44753 .5812 m .44773 .58131 L .44791 .58105 L .668 .747 .91 r
F
.44753 .5812 m .44791 .58105 L .44812 .58074 L F
.4477 .58105 m .44812 .58075 L .44805 .58373 L .387 .212 .518 r
F
.44766 .58428 m .44815 .58553 L .44826 .58462 L .667 .747 .91 r
F
.44861 .58626 m .45008 .58741 L .45069 .58658 L F
.44783 .58388 m .44805 .58373 L .44797 .58672 L .387 .212 .518 r
F
.44783 .58388 m .44797 .58672 L .44797 .58672 L F
.44741 .58712 m .44736 .58716 L .44738 .58421 L F
.44738 .58421 m .44736 .58716 L .44731 .58719 L F
.44816 .58357 m .44811 .58653 L .44808 .58368 L .095 0 .426 r
F
.44811 .58653 m .44803 .58663 L .44808 .58368 L F
.44783 .58388 m .44797 .58672 L .44779 .58391 L .387 .212 .518 r
F
.44797 .58672 m .44796 .58672 L .44779 .58391 L F
.44813 .58074 m .44808 .58368 L .44812 .58075 L .095 0 .426 r
F
.44808 .58368 m .44803 .58663 L .44808 .58369 L F
.44808 .58368 m .44808 .58369 L .44812 .58075 L F
.44879 .58267 m .44871 .58326 L .44953 .58267 L .667 .747 .91 r
F
.4477 .58105 m .44805 .58373 L .44783 .58388 L .387 .212 .518 r
F
.44803 .58663 m .44802 .58665 L .44807 .5837 L .095 0 .426 r
F
.44808 .58369 m .44807 .5837 L .44812 .58075 L F
.44803 .58663 m .44807 .5837 L .44808 .58369 L F
.44911 .58209 m .45338 .58452 L .45531 .58311 L .668 .747 .91 r
F
.44911 .58209 m .45531 .58311 L .45007 .58139 L F
.44926 .582 m .45091 .58268 L .4507 .58178 L .667 .747 .91 r
F
.44854 .57995 m .44852 .58251 L .44849 .58273 L 0 0 .082 r
F
.44855 .57988 m .44859 .57953 L .44852 .58251 L F
.44859 .57953 m .44849 .58246 L .44852 .58251 L .993 .743 .421 r
F
.44483 .57966 m .44845 .58021 L .44857 .57967 L .668 .747 .91 r
F
.44849 .58022 m .44851 .58022 L .44851 .58019 L F
.44849 .58022 m .44851 .58019 L .44857 .57967 L F
.44483 .57966 m .44857 .57967 L .44859 .57953 L F
.44483 .57966 m .44859 .57953 L .44837 .57913 L F
.44849 .58022 m .44843 .58084 L .44851 .58022 L F
.4483 .58049 m .44851 .58019 L .44844 .58317 L .095 0 .426 r
F
.44847 .57932 m .44838 .58226 L .44858 .57951 L .993 .743 .421 r
F
.44838 .58226 m .44843 .58235 L .44858 .57951 L F
.44797 .58672 m .44802 .58675 L .44797 .58682 L .095 0 .426 r
F
.44812 .58075 m .44807 .5837 L .44805 .58373 L F
.44853 .58003 m .44846 .58298 L .44852 .58013 L 0 0 .082 r
F
.44843 .58235 m .44848 .58243 L .44858 .57951 L .993 .743 .421 r
F
.44674 .58001 m .44672 .5815 L .44652 .58008 L .539 .332 .549 r
F
.44672 .5815 m .44658 .58156 L .44652 .58008 L F
.44483 .57966 m .44751 .58119 L .44812 .58074 L .668 .747 .91 r
F
.44751 .58119 m .44753 .5812 L .44803 .58082 L F
.44483 .57966 m .44671 .58151 L .44751 .58119 L F
.44671 .58151 m .44746 .58123 L .44751 .58119 L F
.44483 .57966 m .44837 .57913 L .44812 .57868 L F
.44483 .57966 m .44812 .57868 L .4481 .57867 L F
.44805 .58373 m .44802 .58665 L .44797 .58672 L .095 0 .426 r
F
.44807 .5837 m .44802 .58665 L .44805 .58373 L F
.44787 .58706 m .44723 .58748 L .44845 .5874 L .642 .739 .919 r
F
.44641 .58457 m .4464 .58752 L .44634 .58754 L .539 .332 .549 r
F
.4465 .58454 m .44649 .5875 L .44641 .58457 L F
.44649 .5875 m .44649 .5875 L .44641 .58457 L F
.44707 .58731 m .44634 .58754 L .44723 .58748 L .642 .739 .919 r
F
.44649 .5875 m .4464 .58753 L .4464 .58752 L .539 .332 .549 r
F
.44649 .5875 m .4464 .58752 L .44641 .58457 L F
.44649 .5875 m .4464 .58752 L .44649 .5875 L F
.44797 .58672 m .4494 .58719 L .44861 .58626 L .667 .747 .91 r
F
.4494 .58719 m .45008 .58741 L .44908 .58663 L F
.4494 .58719 m .44908 .58663 L .44861 .58626 L F
.44826 .58055 m .44831 .58335 L .44821 .58062 L .095 0 .426 r
F
.44831 .58335 m .44829 .58339 L .44821 .58062 L F
.44821 .58062 m .44829 .58339 L .44816 .58357 L F
.44826 .58055 m .44844 .58317 L .44831 .58335 L F
.4483 .58049 m .44844 .58317 L .44826 .58055 L F
.44482 .58267 m .44861 .58267 L .44831 .58214 L .667 .747 .91 r
F
.44855 .57988 m .44852 .58251 L .44854 .57995 L 0 0 .082 r
F
.44858 .57951 m .44848 .58243 L .44859 .57953 L .993 .743 .421 r
F
.44847 .5828 m .44846 .58314 L .44869 .58281 L .667 .747 .91 r
F
.44482 .58267 m .44846 .58314 L .44847 .5828 L F
.44482 .58267 m .44841 .58322 L .44846 .58314 L F
.44482 .58267 m .44869 .58281 L .44861 .58267 L F
.44845 .58311 m .44838 .58606 L .44844 .58317 L 0 0 .082 r
F
.44846 .58298 m .44839 .58593 L .44845 .58311 L F
.44848 .58243 m .44838 .58537 L .44848 .58244 L .993 .743 .421 r
F
.44848 .58243 m .44848 .58244 L .44859 .57953 L F
.44758 .58407 m .44797 .58682 L .44754 .58709 L .387 .212 .518 r
F
.44745 .58416 m .44747 .58417 L .448 .58377 L .667 .747 .91 r
F
.44747 .58417 m .44766 .58428 L .44783 .58403 L F
.44747 .58417 m .44783 .58403 L .44805 .58373 L F
.44779 .58391 m .44797 .58682 L .44758 .58407 L .387 .212 .518 r
F
.4467 .58447 m .44731 .58724 L .44667 .58744 L .539 .332 .549 r
F
.44708 .58432 m .44731 .58724 L .4467 .58447 L F
.44666 .58448 m .44717 .58498 L .44747 .58417 L .667 .747 .91 r
F
.44708 .58432 m .44738 .58421 L .44731 .58724 L .539 .332 .549 r
F
.44634 .58615 m .44797 .58672 L .4481 .58654 L .667 .747 .91 r
F
.44832 .58622 m .44797 .58672 L .44861 .58626 L F
.44811 .58653 m .44836 .5863 L .44811 .58664 L .095 0 .426 r
F
.44816 .58357 m .44835 .58618 L .44811 .58653 L F
.44835 .58618 m .44836 .5863 L .44811 .58653 L F
.45088 .5856 m .45764 .58694 L .45338 .58452 L .668 .747 .91 r
F
.44912 .58511 m .45342 .58755 L .45535 .58613 L .667 .747 .91 r
F
.4487 .58569 m .45069 .58658 L .4509 .58569 L F
.44576 .58649 m .44621 .58755 L .44634 .58754 L .642 .739 .919 r
F
.44533 .58598 m .44731 .58719 L .44738 .58714 L .667 .747 .91 r
F
.44838 .58606 m .44837 .58611 L .44844 .58317 L 0 0 .082 r
F
.44839 .58593 m .44838 .58606 L .44845 .58311 L F
.44837 .58616 m .44837 .58626 L .44836 .5863 L F
.44844 .58317 m .44837 .58611 L .44837 .58616 L F
.44832 .58622 m .45069 .58658 L .4487 .58569 L .667 .747 .91 r
F
.44837 .58611 m .44837 .58626 L .44837 .58616 L 0 0 .082 r
F
.44533 .58471 m .44533 .58761 L .4452 .58472 L .651 .424 .562 r
F
.44508 .58568 m .44832 .58622 L .44837 .58616 L .667 .747 .91 r
F
.44842 .58568 m .44837 .58616 L .4487 .58569 L F
.44831 .58335 m .44836 .5863 L .44829 .58339 L .095 0 .426 r
F
.44829 .58339 m .44836 .5863 L .44816 .58357 L F
.44831 .58335 m .44844 .58317 L .44836 .5863 L F
.44508 .58568 m .44837 .58616 L .44842 .58568 L .667 .747 .91 r
F
.44838 .58537 m .44839 .58539 L .44849 .58246 L .993 .743 .421 r
F
.44848 .58244 m .44849 .58246 L .44859 .57953 L F
.44838 .58537 m .44849 .58246 L .44848 .58244 L F
.44896 .5833 m .45009 .5844 L .4507 .58357 L .667 .747 .91 r
F
.44841 .58322 m .44925 .58381 L .44896 .5833 L F
.44925 .58381 m .45009 .5844 L .44896 .5833 L F
.44828 .5852 m .44838 .58537 L .44848 .58243 L .993 .743 .421 r
F
.44828 .5852 m .44848 .58243 L .44843 .58235 L F
.44849 .58513 m .44963 .58568 L .44869 .5851 L .667 .747 .91 r
F
.44846 .58298 m .44844 .58552 L .44839 .58593 L 0 0 .082 r
F
.44849 .58273 m .44845 .58551 L .44846 .58298 L F
.44843 .58567 m .44963 .58568 L .44849 .58513 L .667 .747 .91 r
F
.44845 .58551 m .44844 .58567 L .44844 .58552 L 0 0 .082 r
F
.44845 .58551 m .44844 .58552 L .44846 .58298 L F
.44849 .58273 m .44852 .58251 L .44845 .5855 L F
.44845 .58551 m .44845 .5855 L .44844 .58567 L F
.44849 .58273 m .44845 .5855 L .44845 .58551 L F
.4487 .58348 m .45009 .58396 L .44912 .58324 L .667 .747 .91 r
F
.44852 .58251 m .44839 .58539 L .44845 .5855 L .993 .743 .421 r
F
.44482 .58267 m .44745 .58416 L .44805 .58373 L .667 .747 .91 r
F
.44482 .58267 m .44805 .58373 L .44841 .58322 L F
.44483 .57966 m .44812 .58074 L .44849 .58022 L .668 .747 .91 r
F
.44812 .57868 m .44795 .5816 L .44805 .58166 L .889 .63 .539 r
F
.44849 .56339 m .44791 .57721 L .44815 .57737 L F
.4458 .57782 m .47505 .57509 L .47208 .57092 L .643 .738 .918 r
F
.44815 .57737 m .44809 .57866 L .44812 .57868 L .889 .63 .539 r
F
.44809 .57866 m .44795 .5816 L .44812 .57868 L F
.44852 .57801 m .44812 .57868 L .44842 .57922 L .993 .743 .421 r
F
.44852 .57801 m .44847 .57932 L .44862 .5782 L F
.44483 .57966 m .4481 .57867 L .44802 .57862 L .668 .747 .91 r
F
.44842 .57922 m .44805 .58166 L .4482 .58194 L .993 .743 .421 r
F
.44847 .57932 m .4482 .58194 L .44838 .58226 L F
.44842 .57922 m .4482 .58194 L .44847 .57932 L F
.45007 .58139 m .45531 .58311 L .45652 .58146 L .668 .747 .91 r
F
.45007 .58139 m .45652 .58146 L .45068 .58056 L F
.448 .58163 m .4507 .58178 L .4501 .58095 L .667 .747 .91 r
F
.44482 .58267 m .44872 .58208 L .448 .58163 L F
.44872 .58208 m .4507 .58178 L .448 .58163 L F
.44849 .56339 m .44709 .57668 L .44791 .57721 L .889 .63 .539 r
F
.4458 .57782 m .47208 .57092 L .46729 .56721 L .643 .738 .918 r
F
.44791 .57721 m .44786 .57852 L .44815 .57737 L .889 .63 .539 r
F
.44751 .58119 m .44803 .58082 L .44812 .58074 L .668 .747 .91 r
F
.44773 .58147 m .44795 .5816 L .44809 .57866 L .889 .63 .539 r
F
.44802 .57862 m .44809 .57866 L .44815 .57737 L F
.44773 .58147 m .44809 .57866 L .44802 .57862 L F
.44786 .57852 m .44802 .57862 L .44815 .57737 L F
.44791 .57721 m .44706 .57802 L .44786 .57852 L F
.44852 .57801 m .44815 .57737 L .44812 .57868 L .993 .743 .421 r
F
.44738 .57822 m .45008 .57795 L .44912 .57723 L .668 .747 .91 r
F
.44483 .57966 m .44802 .57862 L .44738 .57822 L F
.44802 .57862 m .45008 .57795 L .44738 .57822 L F
.44744 .5627 m .44686 .57661 L .44709 .57668 L .799 .548 .56 r
F
.4458 .57782 m .46729 .56721 L .461 .56422 L .643 .738 .918 r
F
.44791 .57721 m .44709 .57668 L .44706 .57802 L .889 .63 .539 r
F
.44483 .57966 m .44738 .57822 L .44706 .57802 L .668 .747 .91 r
F
.44482 .58267 m .448 .58163 L .44735 .58123 L .667 .747 .91 r
F
.44773 .58147 m .44761 .58442 L .44795 .5816 L .889 .63 .539 r
F
.44488 .58476 m .44505 .58763 L .44481 .58765 L .651 .424 .562 r
F
.44503 .58474 m .44505 .58763 L .44488 .58476 L F
.445 .58558 m .44797 .58465 L .44748 .58434 L .667 .747 .91 r
F
.44381 .58463 m .44481 .58765 L .4438 .58747 L .747 .505 .564 r
F
.44504 .58563 m .44231 .58698 L .44314 .58732 L .642 .739 .919 r
F
.44502 .58561 m .44797 .58465 L .445 .58558 L .667 .747 .91 r
F
.44521 .58548 m .445 .58558 L .44504 .58563 L .642 .739 .919 r
F
.445 .58558 m .44231 .58698 L .44504 .58563 L F
.44482 .58267 m .44666 .58448 L .44738 .58421 L .667 .747 .91 r
F
.44482 .58267 m .44738 .58421 L .44745 .58416 L F
.44703 .57801 m .44689 .58098 L .44706 .57802 L .799 .548 .56 r
F
.44689 .58098 m .44691 .58098 L .44706 .57802 L F
.44483 .57966 m .44579 .58168 L .44648 .5816 L .668 .747 .91 r
F
.44483 .57966 m .44648 .5816 L .44671 .58151 L F
.44482 .58267 m .44735 .58123 L .44662 .5809 L .667 .747 .91 r
F
.44786 .57852 m .44699 .581 L .44773 .58147 L .889 .63 .539 r
F
.44735 .58123 m .4475 .58115 L .44699 .581 L .667 .747 .91 r
F
.44735 .58123 m .44699 .581 L .44662 .5809 L F
.44786 .57852 m .44706 .57802 L .44699 .581 L .889 .63 .539 r
F
.44849 .58246 m .44839 .58539 L .44852 .58251 L .993 .743 .421 r
F
.44838 .58226 m .44828 .5852 L .44843 .58235 L F
.44838 .58226 m .44799 .58468 L .44828 .5852 L F
.44502 .58561 m .44867 .58508 L .44797 .58465 L .667 .747 .91 r
F
.44505 .58564 m .44869 .5851 L .44502 .58561 L F
.44912 .58511 m .45535 .58613 L .45009 .5844 L F
.44869 .5851 m .4507 .5848 L .44867 .58508 L F
.44869 .5851 m .44867 .58508 L .44502 .58561 L F
.44795 .5816 m .44781 .58455 L .44805 .58166 L .889 .63 .539 r
F
.44505 .58564 m .44843 .58567 L .44845 .5855 L .667 .747 .91 r
F
.44505 .58564 m .44845 .5855 L .44826 .58516 L F
.44508 .58568 m .4509 .58569 L .44505 .58564 L F
.44512 .58573 m .44832 .58622 L .44508 .58568 L F
.44634 .58615 m .4481 .58654 L .44832 .58622 L F
.44512 .58573 m .44634 .58615 L .44832 .58622 L F
.44802 .58665 m .44802 .58675 L .44797 .58672 L .095 0 .426 r
F
.44797 .58672 m .44797 .58672 L .44832 .58622 L .667 .747 .91 r
F
.44797 .58672 m .44797 .58672 L .44797 .58682 L .387 .212 .518 r
F
.44519 .5858 m .44738 .58714 L .44797 .58672 L .667 .747 .91 r
F
.44797 .58672 m .44825 .58706 L .44797 .58672 L F
.44825 .58706 m .44825 .58706 L .44797 .58672 L F
.44811 .58653 m .44811 .58664 L .44803 .58663 L .095 0 .426 r
F
.44799 .5868 m .44787 .58706 L .44828 .58693 L .642 .739 .919 r
F
.44811 .58664 m .44803 .58674 L .44803 .58663 L .095 0 .426 r
F
.44797 .58672 m .44797 .58682 L .44796 .58672 L .387 .212 .518 r
F
.44817 .58656 m .44828 .58693 L .44832 .58662 L .642 .739 .919 r
F
.44803 .58663 m .44803 .58674 L .44802 .58665 L .095 0 .426 r
F
.44803 .58674 m .44802 .58675 L .44802 .58665 L F
.44521 .58548 m .44799 .5868 L .44817 .58656 L .642 .739 .919 r
F
.44799 .5868 m .44828 .58693 L .44817 .58656 L F
.44825 .58706 m .44911 .58812 L .44825 .58706 L .667 .747 .91 r
F
.4494 .58719 m .44969 .5877 L .45008 .58741 L F
.44797 .58672 m .44969 .5877 L .4494 .58719 L F
.44911 .58812 m .45535 .58914 L .45008 .58741 L F
.44787 .58706 m .46661 .5982 L .44877 .58678 L .642 .739 .919 r
F
.44748 .58742 m .44785 .58867 L .44759 .58726 L .667 .747 .91 r
F
.44723 .58748 m .46034 .60045 L .44845 .5874 L .642 .739 .919 r
F
.44763 .58872 m .45089 .59164 L .44785 .58867 L .667 .747 .91 r
F
.4478 .59067 m .44769 .58879 L .44744 .58849 L .642 .739 .919 r
F
.44662 .58745 m .44763 .58872 L .44785 .58867 L .667 .747 .91 r
F
.44636 .5872 m .44658 .58747 L .44662 .58745 L F
.44658 .58747 m .44763 .58872 L .44662 .58745 L F
.44639 .58901 m .44648 .58906 L .44648 .58898 L F
.44931 .59072 m .45089 .59164 L .44763 .58872 L F
.44931 .59072 m .45022 .5918 L .45089 .59164 L F
.4478 .58892 m .44999 .59535 L .45279 .59487 L .642 .739 .919 r
F
.45022 .5918 m .45392 .59461 L .45089 .59164 L .667 .747 .91 r
F
.44769 .58879 m .44999 .59535 L .4478 .58892 L .642 .739 .919 r
F
.44779 .5908 m .44714 .59583 L .44999 .59535 L F
.44796 .59232 m .45193 .59385 L .45022 .5918 L .667 .747 .91 r
F
.45193 .59385 m .45392 .59461 L .45022 .5918 L F
.44731 .58769 m .44769 .58879 L .44736 .58763 L .642 .739 .919 r
F
.44769 .58879 m .4478 .58892 L .44736 .58763 L F
.44736 .58763 m .4478 .58892 L .4536 .59473 L F
.4478 .58892 m .45279 .59487 L .4536 .59473 L F
.44648 .58906 m .44931 .59072 L .44648 .58898 L .667 .747 .91 r
F
.44648 .58898 m .44931 .59072 L .44763 .58872 L F
.44658 .58747 m .44649 .5875 L .44649 .5875 L .539 .332 .549 r
F
.44521 .58583 m .44417 .58754 L .44522 .58771 L .642 .739 .919 r
F
.4451 .5857 m .44417 .58754 L .44521 .58583 L F
.44658 .58747 m .44649 .5875 L .44667 .58743 L .539 .332 .549 r
F
.44576 .58649 m .44634 .58754 L .44658 .58747 L .642 .739 .919 r
F
.44561 .58631 m .44621 .58755 L .44576 .58649 L F
.44561 .58631 m .44522 .58762 L .44621 .58755 L F
.44521 .58583 m .44522 .58762 L .44561 .58631 L F
.44521 .58548 m .4431 .58735 L .44417 .58754 L F
.4448 .58568 m .44763 .58872 L .44636 .5872 L .667 .747 .91 r
F
.44639 .58901 m .44796 .59232 L .45022 .5918 L F
.44639 .58901 m .45022 .5918 L .44931 .59072 L F
.44635 .58784 m .44527 .60182 L .44638 .6018 L .642 .739 .919 r
F
.4462 .58794 m .44527 .60182 L .44635 .58784 L F
.44483 .59596 m .44548 .5955 L .44953 .59562 L .673 .446 .569 r
F
.44548 .5955 m .44953 .59543 L .44953 .59562 L F
.44723 .58748 m .4536 .59473 L .45236 .59255 L .642 .739 .919 r
F
.44482 .59255 m .44953 .59562 L .44796 .59232 L .667 .747 .91 r
F
.44481 .58912 m .44482 .59255 L .44796 .59232 L F
.44481 .58912 m .44796 .59232 L .44639 .58901 L F
.44803 .58674 m .44791 .59416 L .44802 .58675 L .095 0 .426 r
F
.4462 .59641 m .44469 .60946 L .44617 .60943 L .641 .739 .92 r
F
.4475 .59909 m .44617 .60943 L .4525 .60932 L F
.4462 .59641 m .44617 .60943 L .4475 .59909 L F
.44953 .59562 m .44953 .59543 L .4498 .59538 L .607 .393 .565 r
F
.44796 .59232 m .44953 .59562 L .45279 .59487 L .667 .747 .91 r
F
.44796 .59232 m .45279 .59487 L .45193 .59385 L F
.44838 .58606 m .44838 .5862 L .44837 .58611 L 0 0 .082 r
F
.44838 .5862 m .44837 .58626 L .44837 .58611 L F
.46704 .59051 m .49764 .59686 L .47186 .58739 L .643 .738 .918 r
F
.46061 .59086 m .4606 .58786 L .46245 .58537 L .145 .034 .459 r
F
.45338 .58452 m .45764 .58694 L .46053 .58483 L .668 .747 .91 r
F
.45342 .58755 m .4606 .58786 L .45535 .58613 L .667 .747 .91 r
F
.46061 .59086 m .46245 .58537 L .46245 .58838 L .145 .034 .459 r
F
.45535 .58914 m .46061 .59086 L .46245 .58838 L .667 .747 .91 r
F
.45535 .58914 m .46245 .58838 L .45657 .58748 L F
.45008 .58741 m .45535 .58914 L .45657 .58748 L F
.4606 .58786 m .4606 .58486 L .46244 .58237 L .145 .034 .459 r
F
.4606 .58786 m .46244 .58237 L .46245 .58537 L F
.45535 .58613 m .4606 .58786 L .46245 .58537 L .667 .747 .91 r
F
.45338 .58452 m .46053 .58483 L .45531 .58311 L .668 .747 .91 r
F
.45535 .58613 m .46245 .58537 L .45658 .58447 L .667 .747 .91 r
F
.45009 .5844 m .45535 .58613 L .45658 .58447 L F
.45069 .58658 m .45657 .58748 L .457 .5857 L F
.45008 .58741 m .45657 .58748 L .45069 .58658 L F
.45069 .58658 m .457 .5857 L .4509 .58569 L F
.44873 .58618 m .47146 .59508 L .47454 .59129 L .642 .739 .919 r
F
.44839 .58593 m .44839 .58608 L .44838 .58606 L 0 0 .082 r
F
.44832 .58662 m .44915 .58692 L .44839 .58611 L .642 .739 .919 r
F
.44832 .58662 m .44828 .58693 L .44877 .58678 L F
.44785 .59635 m .4525 .60932 L .45706 .60855 L .641 .739 .92 r
F
.45442 .59459 m .45307 .60168 L .46034 .60045 L .642 .739 .919 r
F
.44785 .59635 m .45706 .60855 L .45295 .60137 L .641 .739 .92 r
F
.4475 .59909 m .4525 .60932 L .44785 .59635 L F
.45012 .59642 m .45979 .60809 L .46607 .60585 L F
.44483 .59596 m .44483 .59551 L .44548 .5955 L .673 .446 .569 r
F
.44482 .59255 m .44483 .59596 L .44953 .59562 L .667 .747 .91 r
F
.44667 .58744 m .4466 .5949 L .44649 .5875 L .539 .332 .549 r
F
.4466 .5949 m .44645 .59495 L .44649 .5875 L F
.44811 .58664 m .44797 .59408 L .44803 .58674 L .095 0 .426 r
F
.44801 .59517 m .45295 .60137 L .45012 .59642 L .641 .739 .92 r
F
.44741 .59482 m .44797 .59548 L .44801 .59517 L F
.44797 .59548 m .45295 .60137 L .44801 .59517 L F
.44693 .59545 m .44785 .59635 L .44741 .59482 L F
.44785 .59635 m .45295 .60137 L .44797 .59548 L F
.44785 .59635 m .44797 .59548 L .44741 .59482 L F
.44837 .58626 m .4482 .59365 L .44836 .5863 L 0 0 .082 r
F
.44839 .58608 m .44838 .5862 L .44838 .58606 L F
.44521 .58548 m .44832 .58662 L .44839 .58611 L .642 .739 .919 r
F
.44811 .58664 m .44836 .5863 L .44818 .5938 L .095 0 .426 r
F
.44804 .59494 m .45012 .59642 L .44979 .59585 L .641 .739 .92 r
F
.44752 .59467 m .44803 .59501 L .44804 .59494 L F
.44803 .59501 m .45012 .59642 L .44804 .59494 L F
.44839 .58611 m .44915 .58692 L .44873 .58618 L .642 .739 .919 r
F
.44839 .58593 m .44844 .58567 L .44839 .58608 L 0 0 .082 r
F
.44844 .58552 m .44844 .58567 L .44839 .58593 L F
.44521 .58548 m .44873 .58618 L .44843 .58565 L .642 .739 .919 r
F
.44839 .58608 m .44844 .58567 L .44826 .59317 L 0 0 .082 r
F
.44839 .58608 m .44826 .59317 L .44822 .59351 L F
.44741 .59482 m .45012 .59642 L .44752 .59467 L .641 .739 .92 r
F
.44869 .5851 m .4509 .58569 L .4507 .5848 L .667 .747 .91 r
F
.44963 .58568 m .4509 .58569 L .44869 .5851 L F
.44521 .58548 m .44843 .58565 L .44818 .5852 L .642 .739 .919 r
F
.4481 .59443 m .44979 .59585 L .44922 .59484 L .641 .739 .92 r
F
.4465 .5875 m .44634 .58756 L .44653 .58754 L .667 .747 .91 r
F
.44649 .5875 m .44645 .59495 L .4464 .58753 L .539 .332 .549 r
F
.44645 .59495 m .44638 .59497 L .4464 .58753 L F
.44623 .58758 m .4462 .58794 L .44635 .58784 L .642 .739 .919 r
F
.4458 .58776 m .44639 .58901 L .44634 .58756 L .667 .747 .91 r
F
.4458 .58776 m .44481 .58912 L .44639 .58901 L F
.44533 .58761 m .44533 .58768 L .44505 .58763 L .651 .424 .562 r
F
.44573 .58763 m .44481 .58814 L .4458 .58776 L .667 .747 .91 r
F
.44481 .58775 m .44481 .58814 L .44573 .58763 L F
.44481 .58814 m .44481 .58912 L .4458 .58776 L F
.44741 .58715 m .44748 .58742 L .44759 .58726 L F
.44744 .58849 m .44769 .58879 L .44731 .58769 L .642 .739 .919 r
F
.44754 .58703 m .44743 .59454 L .44741 .58712 L .387 .212 .518 r
F
.44693 .59545 m .4475 .59909 L .44785 .59635 L .641 .739 .92 r
F
.44657 .59509 m .44672 .59573 L .44693 .59545 L F
.44672 .59573 m .4475 .59909 L .44693 .59545 L F
.44743 .59454 m .44733 .59461 L .44741 .58712 L .387 .212 .518 r
F
.44533 .58768 m .44533 .59509 L .44505 .58772 L .651 .424 .562 r
F
.44533 .59509 m .44509 .59511 L .44505 .58772 L F
.4464 .58753 m .44638 .59497 L .44634 .58756 L .539 .332 .549 r
F
.44643 .59495 m .44615 .59504 L .4465 .59502 L .641 .739 .92 r
F
.44555 .59508 m .44579 .59558 L .4465 .59502 L F
.44579 .59558 m .4475 .59909 L .44652 .59512 L F
.44579 .59558 m .44652 .59512 L .4465 .59502 L F
.44731 .58724 m .44723 .58748 L .44787 .58706 L .642 .739 .919 r
F
.44707 .58731 m .44711 .58736 L .44731 .58724 L F
.44711 .58736 m .44723 .58748 L .44731 .58724 L F
.44741 .58712 m .44741 .58717 L .44736 .58716 L .387 .212 .518 r
F
.44741 .58717 m .44733 .59461 L .44736 .58721 L F
.44741 .58717 m .44736 .58721 L .44736 .58716 L F
.44652 .59512 m .4475 .59909 L .44657 .59509 L .641 .739 .92 r
F
.44638 .59497 m .44633 .59498 L .44634 .58756 L .539 .332 .549 r
F
.44634 .58756 m .44633 .59498 L .44615 .59504 L F
.44634 .58756 m .44633 .59498 L .44634 .58756 L F
.44573 .58763 m .4458 .58776 L .44634 .58756 L .667 .747 .91 r
F
.44533 .58768 m .44634 .58756 L .44615 .59504 L .651 .424 .562 r
F
.44533 .58768 m .44615 .59504 L .44533 .59509 L F
.44722 .59471 m .44678 .59496 L .44741 .59482 L .641 .739 .92 r
F
.4472 .59469 m .44713 .59474 L .44722 .59471 L F
.44713 .59474 m .44678 .59496 L .44722 .59471 L F
.44699 .58796 m .44731 .58769 L .44723 .58748 L .642 .739 .919 r
F
.44705 .58803 m .44731 .58769 L .44699 .58796 L F
.44663 .58752 m .44699 .58796 L .44723 .58748 L F
.44705 .58803 m .44744 .58849 L .44731 .58769 L F
.44667 .58744 m .44731 .58724 L .44713 .59474 L .539 .332 .549 r
F
.4467 .595 m .44693 .59545 L .4473 .59496 L .641 .739 .92 r
F
.4465 .59502 m .44657 .59509 L .4467 .595 L F
.44657 .59509 m .44693 .59545 L .4467 .595 L F
.44736 .58716 m .44729 .59464 L .44731 .58719 L .387 .212 .518 r
F
.4465 .59502 m .4473 .59496 L .44741 .59482 L .641 .739 .92 r
F
.44729 .59464 m .44697 .62813 L .44725 .59466 L .387 .212 .518 r
F
.44729 .59464 m .44725 .59466 L .44731 .58719 L F
.4466 .5949 m .44713 .59474 L .4463 .6286 L .539 .332 .549 r
F
.44667 .58744 m .44713 .59474 L .4466 .5949 L F
.44713 .59474 m .44697 .62813 L .4463 .6286 L .387 .212 .518 r
F
.44723 .58748 m .44731 .58769 L .44736 .58763 L .642 .739 .919 r
F
.44731 .58719 m .44725 .59466 L .44713 .59474 L .387 .212 .518 r
F
.44725 .59466 m .44697 .62813 L .44713 .59474 L F
.44547 .59736 m .44469 .60946 L .4462 .59641 L .641 .739 .92 r
F
.44203 .5918 m .43639 .59391 L .44042 .59501 L .642 .739 .919 r
F
.44167 .59231 m .44483 .59596 L .44482 .59255 L .667 .747 .91 r
F
.44555 .59508 m .44462 .59552 L .44561 .59521 L .641 .739 .92 r
F
.44462 .59514 m .44462 .59552 L .44555 .59508 L F
.44012 .59561 m .44042 .59497 L .4411 .59505 L .729 .493 .569 r
F
.44012 .59561 m .44012 .59493 L .44042 .59497 L F
.44167 .59231 m .44012 .59561 L .44483 .59596 L .667 .747 .91 r
F
.44462 .59552 m .44469 .60946 L .44561 .59521 L .641 .739 .92 r
F
.43932 .58837 m .43874 .58935 L .44297 .58747 L .642 .739 .919 r
F
.44174 .58962 m .44179 .59002 L .44343 .58901 L F
.44203 .5918 m .43631 .5934 L .43639 .59391 L F
.44179 .59002 m .43631 .5934 L .44203 .5918 L F
.44324 .589 m .44167 .59231 L .44482 .59255 L .667 .747 .91 r
F
.44174 .58962 m .43631 .5934 L .44179 .59002 L .642 .739 .919 r
F
.44177 .58866 m .44167 .59231 L .44324 .589 L .667 .747 .91 r
F
.44382 .58776 m .44177 .58866 L .44324 .589 L F
.4438 .58747 m .4438 .58762 L .44352 .58742 L .747 .505 .564 r
F
.44388 .58763 m .44328 .58755 L .44382 .58776 L .667 .747 .91 r
F
.44328 .58755 m .44177 .58866 L .44382 .58776 L F
.443 .58745 m .44293 .58751 L .44328 .58755 L F
.44293 .58751 m .44177 .58866 L .44328 .58755 L F
.44324 .589 m .44482 .59255 L .44481 .58912 L F
.44481 .58775 m .44324 .589 L .44481 .58912 L F
.44481 .58775 m .4449 .59512 L .44462 .59514 L .651 .424 .562 r
F
.44481 .58765 m .44481 .58775 L .44481 .58775 L F
.44481 .58775 m .4449 .59512 L .44481 .58775 L F
.4438 .58747 m .44481 .58765 L .44481 .58775 L .747 .505 .564 r
F
.4438 .58747 m .44481 .58775 L .44382 .58762 L F
.4448 .58568 m .44388 .58763 L .44481 .58775 L .667 .747 .91 r
F
.44388 .58763 m .44324 .589 L .44481 .58775 L F
.44382 .58762 m .44481 .58775 L .44462 .59514 L .747 .505 .564 r
F
.4438 .58762 m .44462 .59514 L .4438 .595 L F
.4438 .58747 m .44382 .58762 L .4438 .58762 L F
.44382 .58762 m .44462 .59514 L .4438 .58762 L F
.44178 .58377 m .44175 .58657 L .44177 .58376 L .908 .647 .532 r
F
.44172 .58372 m .44175 .58657 L .44164 .58649 L F
.44177 .58376 m .44175 .58657 L .44172 .58372 L F
.445 .58558 m .44028 .58676 L .44183 .58714 L .642 .739 .919 r
F
.44781 .58455 m .4479 .5846 L .44805 .58166 L .889 .63 .539 r
F
.44745 .58416 m .44738 .58421 L .44747 .58417 L .667 .747 .91 r
F
.44773 .58147 m .44691 .58399 L .44761 .58442 L .889 .63 .539 r
F
.44745 .58416 m .448 .58377 L .44805 .58373 L .667 .747 .91 r
F
.44761 .58442 m .44781 .58455 L .44795 .5816 L .889 .63 .539 r
F
.44805 .58166 m .4479 .5846 L .44797 .58465 L F
.44499 .58557 m .44733 .58425 L .44496 .58553 L .667 .747 .91 r
F
.4482 .58194 m .44805 .58166 L .44797 .58465 L .993 .743 .421 r
F
.44798 .58467 m .44797 .58465 L .44797 .58484 L F
.4482 .58194 m .44797 .58465 L .44798 .58467 L F
.4482 .58194 m .44797 .58484 L .44838 .58226 L F
.44722 .58331 m .4487 .58348 L .44785 .58269 L .667 .747 .91 r
F
.44773 .58147 m .44699 .581 L .44691 .58399 L .889 .63 .539 r
F
.44675 .58395 m .44678 .58395 L .44692 .58098 L .799 .548 .56 r
F
.44675 .58395 m .44692 .58098 L .44691 .58098 L F
.44689 .58098 m .44675 .58395 L .44691 .58098 L F
.44706 .57802 m .44678 .58395 L .44691 .58399 L F
.44482 .58267 m .44576 .58465 L .44672 .58454 L .667 .747 .91 r
F
.44483 .57966 m .44484 .5818 L .44579 .58168 L .668 .747 .91 r
F
.44482 .58267 m .44662 .5809 L .44593 .58071 L .667 .747 .91 r
F
.44482 .58267 m .44593 .58071 L .44575 .58069 L F
.44496 .58553 m .44748 .58415 L .44661 .58391 L F
.44733 .58425 m .44731 .58424 L .44496 .58553 L F
.44464 .59847 m .43687 .6085 L .44469 .60946 L .641 .739 .92 r
F
.44391 .59744 m .43687 .6085 L .44464 .59847 L F
.4443 .59607 m .44193 .60003 L .44463 .59631 L F
.44193 .60003 m .43687 .6085 L .44199 .60046 L F
.44193 .60003 m .44199 .60046 L .44463 .59631 L F
.44445 .59544 m .44415 .59596 L .44462 .59552 L F
.44497 .58554 m .44028 .58676 L .445 .58558 L .642 .739 .919 r
F
.44028 .58676 m .44022 .58686 L .44183 .58714 L F
.43429 .58609 m .43196 .58994 L .43624 .58752 L .667 .747 .91 r
F
.44052 .5851 m .43624 .58752 L .43876 .58861 L F
.44183 .58714 m .43323 .58909 L .4239 .59594 L .642 .739 .919 r
F
.42904 .5878 m .43199 .58693 L .43196 .58994 L .911 .649 .53 r
F
.43001 .59051 m .42904 .5878 L .43196 .58994 L F
.42903 .58978 m .42904 .5878 L .43001 .59051 L F
.42904 .5878 m .42907 .5848 L .43199 .58693 L F
.43437 .58307 m .43205 .5869 L .4363 .58449 L .668 .747 .91 r
F
.43437 .58307 m .42915 .58477 L .43205 .5869 L F
.43429 .58609 m .42904 .5878 L .43196 .58994 L .667 .747 .91 r
F
.42895 .58972 m .41903 .59231 L .4293 .58998 L .642 .739 .919 r
F
.43323 .58909 m .41903 .59231 L .42253 .59492 L F
.4278 .58814 m .42904 .5878 L .42903 .58978 L .98 .72 .463 r
F
.44483 .57966 m .44223 .58113 L .44303 .58143 L .668 .747 .91 r
F
.4437 .57629 m .44284 .57801 L .44363 .57779 L .585 .37 .555 r
F
.44264 .57659 m .44183 .57704 L .44179 .57867 L .428 .243 .527 r
F
.44264 .57659 m .44258 .57818 L .44288 .57646 L F
.44258 .57818 m .44281 .57803 L .44288 .57646 L F
.44288 .57646 m .44281 .57803 L .44284 .57801 L F
.44294 .5778 m .44325 .57633 L .44179 .57667 L .668 .747 .91 r
F
.44483 .57966 m .44391 .57772 L .44294 .5778 L F
.44391 .57772 m .44325 .57633 L .44294 .5778 L F
.44534 .56228 m .44475 .57621 L .44499 .57621 L .667 .437 .562 r
F
.44639 .56239 m .44534 .56228 L .44499 .57621 L .733 .492 .564 r
F
.44639 .56239 m .44499 .57621 L .4458 .57631 L F
.4458 .57782 m .43784 .56132 L .4305 .56261 L .643 .738 .918 r
F
.44475 .57621 m .44393 .57624 L .44389 .57772 L .667 .437 .562 r
F
.42719 .58531 m .42907 .5848 L .42904 .5878 L .98 .72 .463 r
F
.4278 .58814 m .42719 .58531 L .42904 .5878 L F
.42898 .58971 m .42727 .58743 L .42721 .58746 L .642 .739 .919 r
F
.42786 .59001 m .42721 .58746 L .41903 .59231 L F
.42898 .58971 m .42721 .58746 L .42786 .59001 L F
.42672 .58554 m .42719 .58531 L .42717 .5873 L .935 .725 .246 r
F
.42717 .5873 m .42719 .58531 L .4278 .58814 L .98 .72 .463 r
F
.42781 .58711 m .41591 .5882 L .41686 .58945 L .642 .739 .919 r
F
.42781 .58711 m .41686 .58945 L .41903 .59231 L F
.4413 .58297 m .44125 .58593 L .44126 .58269 L .868 .695 .169 r
F
.44138 .58612 m .44131 .58602 L .44136 .58321 L .984 .727 .46 r
F
.4413 .58297 m .44132 .58316 L .44125 .58593 L .868 .695 .169 r
F
.44493 .5855 m .43875 .58608 L .44497 .58554 L .642 .739 .919 r
F
.43875 .58608 m .4387 .58611 L .44497 .58554 L F
.43306 .58443 m .42904 .5878 L .43429 .58609 L .667 .747 .91 r
F
.43306 .58443 m .42719 .58531 L .42904 .5878 L F
.43955 .58438 m .43624 .58752 L .44052 .5851 L F
.43955 .58438 m .43429 .58609 L .43624 .58752 L F
.42795 .58708 m .42781 .58711 L .43868 .58612 L .642 .739 .919 r
F
.4387 .58611 m .43868 .58612 L .44497 .58554 L F
.42795 .58708 m .43868 .58612 L .4387 .58611 L F
.44177 .5787 m .44166 .58173 L .44177 .57869 L 0 0 .377 r
F
.44166 .58173 m .44156 .58463 L .44166 .58173 L F
.44166 .58173 m .44166 .58173 L .44177 .57869 L F
.4409 .58025 m .43898 .58054 L .44067 .58068 L .668 .747 .91 r
F
.44171 .58164 m .4405 .58021 L .43953 .58093 L .667 .747 .91 r
F
.44258 .57818 m .44171 .58165 L .44209 .58141 L .428 .243 .527 r
F
.44171 .58165 m .44171 .58164 L .44171 .58164 L .667 .747 .91 r
F
.44171 .58164 m .4405 .58021 L .44171 .58164 L F
.44482 .58267 m .44234 .58126 L .44171 .58165 L F
.44258 .57818 m .44209 .58141 L .44245 .58119 L .428 .243 .527 r
F
.44258 .57818 m .44179 .57867 L .44171 .58165 L F
.44179 .57867 m .44168 .5817 L .44171 .58165 L 0 0 .377 r
F
.44234 .58126 m .4405 .58021 L .44171 .58165 L .667 .747 .91 r
F
.44281 .57803 m .44266 .58106 L .44284 .57801 L .428 .243 .527 r
F
.44266 .58106 m .44268 .58105 L .44284 .57801 L F
.44234 .58126 m .44176 .57966 L .4405 .58021 L .667 .747 .91 r
F
.44363 .57779 m .4435 .58079 L .44386 .57773 L .585 .37 .555 r
F
.44482 .58267 m .44304 .58092 L .44234 .58126 L .667 .747 .91 r
F
.4435 .58079 m .44362 .58076 L .44386 .57773 L .585 .37 .555 r
F
.44268 .58105 m .44269 .58104 L .44284 .57801 L .428 .243 .527 r
F
.44284 .57801 m .44269 .58104 L .44276 .58099 L F
.44363 .57779 m .44284 .57801 L .44276 .58099 L .585 .37 .555 r
F
.44483 .57966 m .4439 .58165 L .44484 .58177 L .668 .747 .91 r
F
.44482 .58267 m .44388 .5807 L .44304 .58092 L .667 .747 .91 r
F
.44475 .57621 m .44389 .57772 L .44469 .57766 L .667 .437 .562 r
F
.44475 .57621 m .44469 .57766 L .44499 .57621 L F
.4437 .57629 m .44363 .57779 L .44393 .57624 L .585 .37 .555 r
F
.44363 .57779 m .44386 .57773 L .44393 .57624 L F
.44393 .57624 m .44386 .57773 L .44389 .57772 L F
.44483 .57966 m .44482 .57621 L .44325 .57633 L .668 .747 .91 r
F
.44469 .57766 m .44382 .5807 L .44456 .58064 L .667 .437 .562 r
F
.44388 .5807 m .44388 .58069 L .44382 .5807 L .667 .747 .91 r
F
.44388 .5807 m .44382 .5807 L .44304 .58092 L F
.44469 .57766 m .44389 .57772 L .44382 .5807 L .667 .437 .562 r
F
.44497 .58554 m .43868 .58612 L .43493 .58816 L .642 .739 .919 r
F
.44415 .59596 m .44191 .59983 L .4443 .59607 L .641 .739 .92 r
F
.44191 .59983 m .44193 .60003 L .4443 .59607 L F
.4437 .59498 m .44363 .59511 L .44462 .59514 L F
.44003 .58683 m .42898 .58971 L .44183 .58714 L .642 .739 .919 r
F
.42898 .58971 m .42898 .58972 L .44183 .58714 L F
.42895 .58972 m .4293 .58998 L .44183 .58714 L F
.43874 .59162 m .44012 .59561 L .44167 .59231 L .667 .747 .91 r
F
.44177 .58866 m .43874 .59162 L .44167 .59231 L F
.4405 .58811 m .43874 .59162 L .44177 .58866 L F
.44499 .58557 m .44773 .58422 L .4475 .58415 L F
.445 .58558 m .44773 .58422 L .44499 .58557 L F
.44157 .5819 m .44116 .58529 L .44147 .58478 L 0 0 .377 r
F
.44141 .58219 m .44116 .58529 L .44157 .5819 L F
.44124 .58256 m .44118 .58539 L .44124 .58255 L .868 .695 .169 r
F
.42719 .58531 m .42722 .5823 L .42907 .5848 L .98 .72 .463 r
F
.42653 .58263 m .42722 .5823 L .42719 .58531 L .935 .725 .246 r
F
.43894 .58355 m .43429 .58609 L .43955 .58438 L .667 .747 .91 r
F
.43894 .58355 m .43306 .58443 L .43429 .58609 L F
.42672 .58554 m .42653 .58263 L .42719 .58531 L .935 .725 .246 r
F
.42652 .58475 m .41478 .58387 L .42713 .58716 L .642 .739 .919 r
F
.42651 .58471 m .42653 .58263 L .42672 .58554 L .935 .725 .246 r
F
.43314 .58141 m .42915 .58477 L .43437 .58307 L .668 .747 .91 r
F
.43314 .58141 m .42731 .58229 L .42915 .58477 L F
.43263 .58264 m .42719 .58531 L .43306 .58443 L .667 .747 .91 r
F
.43263 .58264 m .42653 .58263 L .42719 .58531 L F
.44116 .58526 m .42656 .5845 L .44124 .58585 L .642 .739 .919 r
F
.42694 .58287 m .42653 .58263 L .42651 .58471 L 0 0 .196 r
F
.42656 .5845 m .41478 .58387 L .4265 .58475 L .642 .739 .919 r
F
.42656 .5845 m .4265 .58475 L .44124 .58585 L F
.44124 .58585 m .42652 .58475 L .42713 .58716 L F
.41559 .57623 m .38779 .58325 L .41671 .58054 L .643 .738 .918 r
F
.42281 .5843 m .41571 .57964 L .41478 .58387 L .642 .739 .919 r
F
.44157 .5819 m .44147 .58478 L .44166 .58173 L 0 0 .377 r
F
.44147 .58478 m .44156 .58463 L .44166 .58173 L F
.44124 .58249 m .44118 .58539 L .44116 .58529 L .868 .695 .169 r
F
.44124 .58255 m .44118 .58539 L .44124 .58249 L F
.44119 .58551 m .44118 .58539 L .44124 .58256 L F
.44119 .58551 m .44124 .58256 L .44125 .58264 L F
.44126 .58269 m .44119 .58551 L .44125 .58264 L F
.44141 .58219 m .44124 .58249 L .44116 .58529 L 0 0 .377 r
F
.44033 .58413 m .43955 .58438 L .44 .58471 L .667 .747 .91 r
F
.44033 .58413 m .44 .58471 L .44052 .5851 L F
.4449 .58546 m .44015 .58448 L .43738 .58507 L .642 .739 .919 r
F
.44482 .58267 m .44482 .58477 L .44576 .58465 L .667 .747 .91 r
F
.4449 .58547 m .44657 .58389 L .44574 .58369 L F
.44483 .57966 m .44706 .57802 L .44662 .5779 L .668 .747 .91 r
F
.4468 .57795 m .44586 .5837 L .44655 .58389 L .799 .548 .56 r
F
.44657 .58389 m .44671 .58377 L .44586 .5837 L .667 .747 .91 r
F
.44657 .58389 m .44586 .5837 L .44574 .58369 L F
.44655 .58389 m .44675 .58395 L .44703 .57801 L .799 .548 .56 r
F
.447 .578 m .44703 .57801 L .44709 .57668 L F
.44655 .58389 m .44703 .57801 L .447 .578 L F
.44744 .5627 m .44604 .57635 L .44686 .57661 L F
.4458 .57782 m .461 .56422 L .45364 .56215 L .643 .738 .918 r
F
.44686 .57661 m .4468 .57795 L .44709 .57668 L .799 .548 .56 r
F
.4468 .57795 m .447 .578 L .44709 .57668 L F
.44483 .57966 m .44662 .5779 L .44601 .57773 L .668 .747 .91 r
F
.44601 .57773 m .44585 .5807 L .44593 .58071 L .733 .492 .564 r
F
.44598 .57772 m .44584 .5807 L .44601 .57773 L F
.44584 .5807 m .4457 .58368 L .44585 .5807 L F
.44584 .5807 m .44585 .5807 L .44601 .57773 L F
.4458 .57782 m .44574 .56116 L .43784 .56132 L .643 .738 .918 r
F
.44483 .57966 m .44601 .57773 L .44575 .5777 L .668 .747 .91 r
F
.44639 .56239 m .4458 .57631 L .44604 .57635 L .733 .492 .564 r
F
.4458 .57782 m .45364 .56215 L .44574 .56116 L .643 .738 .918 r
F
.4458 .57631 m .44499 .57621 L .44495 .57763 L .733 .492 .564 r
F
.44483 .57966 m .44575 .5777 L .44495 .57763 L .668 .747 .91 r
F
.44469 .57766 m .44492 .57764 L .44499 .57621 L .667 .437 .562 r
F
.44483 .57764 m .44495 .57763 L .44483 .57762 L .668 .747 .91 r
F
.44483 .57966 m .44495 .57763 L .44483 .57764 L F
.44495 .57763 m .44478 .58063 L .44487 .58062 L .667 .437 .562 r
F
.44499 .57621 m .44492 .57764 L .44495 .57763 L F
.44492 .57764 m .44478 .58063 L .44495 .57763 L F
.44551 .57768 m .44495 .57763 L .44487 .58062 L .733 .492 .564 r
F
.4458 .57631 m .44495 .57763 L .44551 .57768 L F
.4458 .57631 m .44487 .58062 L .44562 .58068 L F
.44482 .58267 m .44575 .58069 L .44481 .58061 L .667 .747 .91 r
F
.4458 .57631 m .44574 .5777 L .44604 .57635 L .733 .492 .564 r
F
.44496 .58553 m .44675 .58377 L .4449 .58547 L .667 .747 .91 r
F
.44675 .58377 m .44785 .58269 L .44671 .58377 L F
.44675 .58377 m .44671 .58377 L .4449 .58547 L F
.44574 .5777 m .44549 .58366 L .44598 .57772 L .733 .492 .564 r
F
.44363 .59511 m .44177 .5988 L .44445 .59544 L .641 .739 .92 r
F
.44177 .5988 m .44191 .59983 L .44445 .59544 L F
.44363 .59511 m .44445 .59544 L .44462 .59514 L F
.4425 .58793 m .4405 .58811 L .44177 .58866 L .667 .747 .91 r
F
.44264 .58712 m .44328 .58738 L .44328 .58755 L .83 .576 .556 r
F
.44265 .58731 m .44328 .58755 L .44309 .59488 L F
.44264 .58712 m .44328 .58755 L .44265 .58731 L F
.44187 .58666 m .44231 .58698 L .4423 .58718 L .908 .647 .532 r
F
.44202 .58725 m .4405 .58811 L .4425 .58793 L .667 .747 .91 r
F
.44187 .58666 m .4423 .58718 L .44188 .58688 L .908 .647 .532 r
F
.44202 .58725 m .43953 .58739 L .4405 .58811 L .667 .747 .91 r
F
.44187 .58666 m .44187 .58687 L .44175 .58657 L .908 .647 .532 r
F
.44164 .58671 m .44164 .58671 L .44223 .58713 L .667 .747 .91 r
F
.44164 .58671 m .43953 .58739 L .44202 .58725 L F
.44187 .58687 m .44175 .59421 L .44175 .58678 L .908 .647 .532 r
F
.44187 .58687 m .44175 .58678 L .44175 .58657 L F
.44223 .58713 m .44164 .58671 L .44202 .58725 L .667 .747 .91 r
F
.44175 .59421 m .44165 .59414 L .44174 .58678 L .908 .647 .532 r
F
.44175 .58678 m .44174 .58678 L .44175 .58657 L F
.44175 .59421 m .44174 .58678 L .44175 .58678 L F
.44138 .58612 m .44164 .58649 L .44164 .58671 L .984 .727 .46 r
F
.44028 .58676 m .44003 .58683 L .44022 .58686 L .642 .739 .919 r
F
.44164 .58671 m .43892 .58656 L .43953 .58739 L .667 .747 .91 r
F
.441 .58625 m .43892 .58656 L .44131 .58669 L F
.44128 .58645 m .44131 .58669 L .44164 .58671 L F
.441 .58625 m .44131 .58669 L .44128 .58645 L F
.44119 .58551 m .44125 .58593 L .44124 .58614 L .868 .695 .169 r
F
.44138 .58612 m .44164 .58671 L .44138 .58635 L .984 .727 .46 r
F
.44138 .58634 m .44145 .59399 L .44123 .59369 L F
.44138 .58612 m .44138 .58635 L .44138 .58634 L F
.44138 .58635 m .44145 .59399 L .44138 .58634 L F
.44177 .5988 m .43576 .60145 L .43687 .6085 L .641 .739 .92 r
F
.44306 .59625 m .44157 .59731 L .44177 .5988 L F
.44157 .59731 m .43576 .60145 L .44177 .5988 L F
.44125 .58621 m .4387 .58567 L .43892 .58656 L .667 .747 .91 r
F
.44119 .58551 m .44124 .58614 L .44119 .58572 L .868 .695 .169 r
F
.44131 .58624 m .44131 .58623 L .44131 .58602 L .984 .727 .46 r
F
.44138 .58612 m .44138 .58634 L .44131 .58602 L F
.44138 .58634 m .44131 .58624 L .44131 .58602 L F
.44131 .58602 m .44131 .58623 L .44125 .58593 L F
.44129 .58621 m .44124 .58614 L .44125 .58621 L .667 .747 .91 r
F
.44124 .58614 m .4387 .58567 L .44125 .58621 L F
.44272 .59578 m .43576 .60145 L .44306 .59625 L .641 .739 .92 r
F
.44286 .58758 m .44202 .58725 L .4425 .58793 L .667 .747 .91 r
F
.44255 .58736 m .44202 .58725 L .44286 .58758 L F
.44221 .58714 m .44202 .58725 L .443 .58745 L F
.44246 .58704 m .44241 .5946 L .44231 .58698 L .83 .576 .556 r
F
.44275 .59482 m .44231 .59521 L .44344 .59503 L .641 .739 .92 r
F
.44231 .59521 m .43633 .60051 L .44272 .59578 L F
.43633 .60051 m .42957 .6065 L .43576 .60145 L F
.43633 .60051 m .43576 .60145 L .44272 .59578 L F
.44124 .58614 m .44112 .59353 L .44105 .59343 L .984 .727 .46 r
F
.44125 .58593 m .44124 .58615 L .44124 .58614 L F
.44177 .5988 m .43687 .6085 L .44191 .59983 L .641 .739 .92 r
F
.44191 .59983 m .43687 .6085 L .44193 .60003 L F
.44124 .58615 m .44112 .59353 L .44124 .58614 L .984 .727 .46 r
F
.43633 .60051 m .42326 .6036 L .42957 .6065 L .641 .739 .92 r
F
.44231 .59521 m .43851 .59688 L .43633 .60051 L F
.43851 .59688 m .42326 .6036 L .43633 .60051 L F
.43631 .5934 m .4239 .59594 L .43019 .59886 L .642 .739 .919 r
F
.43572 .59458 m .43573 .59372 L .43691 .59405 L .785 .539 .565 r
F
.43874 .59162 m .43572 .59458 L .44012 .59561 L .667 .747 .91 r
F
.44183 .59453 m .43913 .59584 L .44231 .59521 L .641 .739 .92 r
F
.43913 .59584 m .42326 .6036 L .43851 .59688 L F
.43913 .59584 m .43851 .59688 L .44231 .59521 L F
.44131 .58623 m .44124 .58615 L .44125 .58593 L .984 .727 .46 r
F
.4448 .58568 m .44118 .58567 L .44124 .58614 L .667 .747 .91 r
F
.4448 .58568 m .44124 .58614 L .44129 .58621 L F
.44131 .58623 m .44117 .5936 L .44124 .58615 L .984 .727 .46 r
F
.44183 .59453 m .43962 .59504 L .43913 .59584 L .641 .739 .92 r
F
.4418 .59448 m .43965 .59498 L .44183 .59453 L F
.43965 .59498 m .41838 .59997 L .43962 .59504 L F
.43965 .59498 m .43962 .59504 L .44183 .59453 L F
.44164 .58649 m .44164 .58671 L .44164 .58671 L .908 .647 .532 r
F
.44145 .59399 m .43444 .59581 L .44204 .59442 L .641 .739 .92 r
F
.43444 .59581 m .41838 .59997 L .43314 .59651 L F
.43444 .59581 m .43314 .59651 L .44204 .59442 L F
.44175 .58657 m .44174 .58678 L .44164 .58649 L .908 .647 .532 r
F
.43323 .58909 m .42253 .59492 L .4239 .59594 L .642 .739 .919 r
F
.43194 .59294 m .43312 .59251 L .43572 .59458 L .843 .589 .554 r
F
.43312 .59251 m .43573 .59372 L .43572 .59458 L F
.43621 .59053 m .43572 .59458 L .43874 .59162 L .667 .747 .91 r
F
.43194 .59294 m .43195 .59197 L .43312 .59251 L .843 .589 .554 r
F
.43621 .59053 m .43194 .59294 L .43572 .59458 L .667 .747 .91 r
F
.44145 .59399 m .41526 .59587 L .41838 .59997 L .641 .739 .92 r
F
.44174 .58678 m .44165 .59414 L .44164 .58671 L .908 .647 .532 r
F
.44165 .59414 m .44157 .59408 L .44164 .58671 L F
.44117 .5936 m .44112 .59353 L .44124 .58615 L .984 .727 .46 r
F
.44164 .58671 m .44157 .59408 L .44145 .59399 L .908 .647 .532 r
F
.44164 .58671 m .44157 .59408 L .44164 .58671 L F
.44157 .59408 m .44123 .62852 L .44157 .59408 L F
.44157 .59408 m .44157 .59408 L .44164 .58671 L F
.42902 .59081 m .43001 .59051 L .43194 .59294 L .911 .649 .53 r
F
.43001 .59051 m .43195 .59197 L .43194 .59294 L F
.41591 .5882 m .39313 .59907 L .41903 .59231 L .642 .739 .919 r
F
.43932 .58837 m .43197 .59198 L .43874 .58935 L F
.43197 .59198 m .43239 .59217 L .43874 .58935 L F
.43427 .5891 m .43194 .59294 L .43621 .59053 L .667 .747 .91 r
F
.43427 .5891 m .42902 .59081 L .43194 .59294 L F
.4408 .59352 m .41411 .59156 L .41526 .59587 L .641 .739 .92 r
F
.44112 .59353 m .44112 .59353 L .44124 .58614 L .984 .727 .46 r
F
.44241 .5946 m .44229 .59455 L .44231 .58698 L .83 .576 .556 r
F
.44091 .58567 m .4387 .58567 L .44124 .58614 L .667 .747 .91 r
F
.44105 .58567 m .43891 .58477 L .4387 .58567 L F
.44119 .58551 m .44119 .58571 L .44118 .58539 L .868 .695 .169 r
F
.44119 .58571 m .44117 .58559 L .44118 .58539 L F
.441 .59309 m .44099 .59299 L .44117 .58559 L F
.44117 .58559 m .44117 .58559 L .44118 .58539 L F
.441 .59309 m .44117 .58559 L .44117 .58559 L F
.44493 .5855 m .44116 .58526 L .44124 .58585 L .642 .739 .919 r
F
.44118 .58539 m .44099 .59299 L .44116 .58529 L .868 .695 .169 r
F
.4448 .58568 m .44134 .58515 L .44116 .58548 L .667 .747 .91 r
F
.44118 .58567 m .44116 .58548 L .44105 .58567 L F
.44119 .58551 m .44119 .58572 L .44119 .58571 L .868 .695 .169 r
F
.4448 .58568 m .44116 .58548 L .44118 .58567 L .667 .747 .91 r
F
.44134 .58515 m .43891 .58477 L .44105 .58567 L F
.43836 .57743 m .42303 .5733 L .41559 .57623 L .643 .738 .918 r
F
.41874 .58024 m .41867 .57578 L .41571 .57964 L .642 .739 .919 r
F
.44482 .58267 m .44281 .5845 L .44293 .58452 L .667 .747 .91 r
F
.44389 .57772 m .44375 .58072 L .44382 .5807 L .585 .37 .555 r
F
.44363 .57779 m .44276 .58099 L .44316 .58089 L F
.44338 .58379 m .44348 .58376 L .44386 .57773 L F
.44444 .58492 m .44385 .58366 L .44348 .58376 L .667 .747 .91 r
F
.44348 .58376 m .44358 .58374 L .44358 .58374 L .585 .37 .555 r
F
.44348 .58376 m .44358 .58374 L .44386 .57773 L F
.44316 .58089 m .44276 .58099 L .44269 .58393 L F
.44276 .58099 m .44255 .58401 L .44269 .58393 L .428 .243 .527 r
F
.44304 .58092 m .44276 .58099 L .44234 .58126 L .667 .747 .91 r
F
.44269 .58104 m .44255 .58401 L .44276 .58099 L .428 .243 .527 r
F
.44252 .58402 m .44255 .58401 L .44269 .58104 L F
.44252 .58402 m .44269 .58104 L .44268 .58105 L F
.44266 .58106 m .44252 .58402 L .44268 .58105 L F
.44363 .57779 m .44269 .58393 L .44338 .58379 L .585 .37 .555 r
F
.44348 .58376 m .44321 .58234 L .44243 .58252 L .667 .747 .91 r
F
.44386 .57773 m .44358 .58374 L .44389 .57772 L .585 .37 .555 r
F
.44358 .58374 m .44361 .58374 L .44389 .57772 L F
.44382 .5807 m .44361 .58374 L .44374 .58371 L F
.44375 .58072 m .44361 .58374 L .44382 .5807 L F
.44482 .58267 m .44481 .58043 L .44388 .58069 L .667 .747 .91 r
F
.44456 .58064 m .44443 .58369 L .44478 .58063 L .667 .437 .562 r
F
.44443 .58369 m .44463 .58368 L .44478 .58063 L F
.44456 .58064 m .44382 .5807 L .44374 .58371 L F
.44456 .58064 m .44374 .58371 L .44443 .58369 L F
.4435 .58079 m .44338 .58379 L .44362 .58076 L .585 .37 .555 r
F
.44444 .58492 m .4448 .58361 L .44385 .58368 L .667 .747 .91 r
F
.44169 .58368 m .44172 .58372 L .44226 .58411 L F
.44245 .58119 m .44163 .58451 L .44232 .58413 L .428 .243 .527 r
F
.44209 .58141 m .44163 .58451 L .44245 .58119 L F
.44209 .58141 m .44171 .58165 L .44163 .58451 L F
.44478 .58532 m .44161 .58416 L .44485 .58541 L .642 .739 .919 r
F
.4448 .58535 m .4448 .58361 L .44444 .58492 L .667 .747 .91 r
F
.43988 .58278 m .43872 .58265 L .43876 .58281 L F
.44009 .58266 m .43872 .58265 L .43988 .58278 L F
.4402 .58336 m .43876 .58281 L .43894 .58355 L F
.44081 .58327 m .43894 .58355 L .44033 .58413 L F
.43858 .57639 m .43937 .57546 L .42303 .5733 L .643 .738 .918 r
F
.43937 .57546 m .41946 .56815 L .42303 .5733 L F
.44099 .57687 m .42303 .5733 L .43836 .57743 L F
.42303 .5733 m .41652 .572 L .41642 .57242 L F
.42303 .5733 m .41642 .57242 L .41559 .57623 L F
.43898 .58054 m .43437 .58307 L .43959 .58137 L .668 .747 .91 r
F
.43898 .58054 m .43314 .58141 L .43437 .58307 L F
.43271 .57964 m .42731 .58229 L .43314 .58141 L F
.43271 .57964 m .42665 .57962 L .42731 .58229 L F
.43877 .57965 m .43314 .58141 L .43898 .58054 L F
.43877 .57965 m .43271 .57964 L .43314 .58141 L F
.43872 .58265 m .43306 .58443 L .43894 .58355 L .667 .747 .91 r
F
.43872 .58265 m .43263 .58264 L .43306 .58443 L F
.43897 .57876 m .43271 .57964 L .43877 .57965 L .668 .747 .91 r
F
.43311 .57785 m .42665 .57962 L .43271 .57964 L F
.43897 .57876 m .43311 .57785 L .43271 .57964 L F
.43311 .57785 m .42724 .57695 L .42665 .57962 L F
.42712 .57995 m .42715 .57694 L .42656 .57962 L 0 0 .196 r
F
.43893 .58176 m .43263 .58264 L .43872 .58265 L .667 .747 .91 r
F
.43303 .58085 m .42653 .58263 L .43263 .58264 L F
.43893 .58176 m .43303 .58085 L .43263 .58264 L F
.42653 .58263 m .42656 .57962 L .42722 .5823 L .935 .725 .246 r
F
.43303 .58085 m .42712 .57995 L .42653 .58263 L .667 .747 .91 r
F
.43431 .57619 m .42724 .57695 L .43311 .57785 L .668 .747 .91 r
F
.43953 .58093 m .43303 .58085 L .43893 .58176 L .667 .747 .91 r
F
.43431 .57619 m .42903 .57445 L .42724 .57695 L .668 .747 .91 r
F
.42892 .57744 m .42715 .57694 L .42712 .57995 L .121 .012 .445 r
F
.42892 .57744 m .42895 .57443 L .42715 .57694 L F
.43953 .58093 m .43423 .57918 L .43303 .58085 L .667 .747 .91 r
F
.43423 .57918 m .42712 .57995 L .43303 .58085 L F
.43423 .57918 m .42892 .57744 L .42712 .57995 L F
.42852 .58035 m .42892 .57744 L .42712 .57995 L .121 .012 .445 r
F
.4289 .57986 m .42892 .57744 L .42852 .58035 L F
.42712 .57995 m .42656 .57962 L .42653 .58263 L 0 0 .196 r
F
.42694 .58287 m .42712 .57995 L .42653 .58263 L F
.4271 .58217 m .42712 .57995 L .42694 .58287 L F
.43773 .58275 m .42923 .57964 L .42768 .58142 L .642 .739 .919 r
F
.43958 .57793 m .43311 .57785 L .43897 .57876 L .668 .747 .91 r
F
.43958 .57793 m .43431 .57619 L .43311 .57785 L F
.43616 .57775 m .42892 .57744 L .43423 .57918 L .667 .747 .91 r
F
.43142 .57819 m .42892 .57744 L .4289 .57986 L .379 .21 .523 r
F
.42923 .57964 m .42911 .57959 L .4289 .57986 L .642 .739 .919 r
F
.42923 .57964 m .4289 .57986 L .42768 .58142 L F
.43623 .57476 m .42903 .57445 L .43431 .57619 L .668 .747 .91 r
F
.43616 .57775 m .43181 .57528 L .42892 .57744 L .667 .747 .91 r
F
.43142 .57819 m .43181 .57528 L .42892 .57744 L .379 .21 .523 r
F
.42923 .57964 m .43083 .57738 L .42911 .57959 L .642 .739 .919 r
F
.44061 .5838 m .43174 .57798 L .42923 .57964 L F
.43174 .57798 m .43083 .57738 L .42923 .57964 L F
.43179 .57794 m .43181 .57528 L .43142 .57819 L .379 .21 .523 r
F
.44101 .58208 m .43984 .58103 L .43893 .58176 L .667 .747 .91 r
F
.43984 .58103 m .43943 .58106 L .43893 .58176 L F
.44115 .58266 m .44101 .58208 L .44009 .58266 L F
.44101 .58208 m .43893 .58176 L .44009 .58266 L F
.44103 .58323 m .44081 .58327 L .44128 .58341 L F
.44167 .58171 m .44158 .5846 L .44168 .5817 L 0 0 .377 r
F
.44171 .58165 m .44158 .5846 L .44163 .58451 L F
.44168 .5817 m .44158 .5846 L .44171 .58165 L F
.4405 .58021 m .43423 .57918 L .43953 .58093 L .667 .747 .91 r
F
.4405 .58021 m .43616 .57775 L .43423 .57918 L F
.43181 .57528 m .42895 .57443 L .42892 .57744 L .379 .21 .523 r
F
.4423 .58375 m .43225 .57778 L .44061 .5838 L .642 .739 .919 r
F
.44054 .57721 m .43431 .57619 L .43958 .57793 L .668 .747 .91 r
F
.44165 .5763 m .43937 .57546 L .43858 .57639 L .643 .738 .918 r
F
.44054 .57721 m .43623 .57476 L .43431 .57619 L .668 .747 .91 r
F
.43869 .57665 m .43181 .57528 L .43616 .57775 L .667 .747 .91 r
F
.43545 .5766 m .43181 .57528 L .43179 .57794 L .516 .318 .55 r
F
.43225 .57778 m .42347 .57256 L .43172 .57797 L .642 .739 .919 r
F
.43225 .57778 m .43172 .57797 L .44061 .5838 L F
.43984 .58103 m .43953 .58093 L .43943 .58106 L .667 .747 .91 r
F
.44143 .58215 m .44101 .58208 L .44115 .58266 L F
.44176 .57966 m .43616 .57775 L .4405 .58021 L F
.4418 .57866 m .43974 .57781 L .43989 .57803 L .668 .747 .91 r
F
.44167 .57888 m .44177 .5787 L .44183 .57704 L 0 0 .377 r
F
.4419 .57859 m .43974 .57781 L .4418 .57866 L .668 .747 .91 r
F
.43989 .57803 m .43974 .57781 L .43958 .57793 L F
.44118 .57846 m .43958 .57793 L .44126 .57911 L F
.44126 .57911 m .43897 .57876 L .44133 .57965 L F
.44176 .57966 m .43869 .57665 L .43616 .57775 L .667 .747 .91 r
F
.43623 .57476 m .43191 .5723 L .42903 .57445 L .668 .747 .91 r
F
.43181 .57528 m .43184 .57227 L .42895 .57443 L .379 .21 .523 r
F
.44179 .57667 m .43623 .57476 L .44054 .57721 L .668 .747 .91 r
F
.44179 .57667 m .43874 .57367 L .43623 .57476 L F
.43874 .57367 m .43191 .5723 L .43623 .57476 L F
.43869 .57665 m .43561 .57362 L .43181 .57528 L .667 .747 .91 r
F
.43561 .57362 m .43184 .57227 L .43181 .57528 L .516 .318 .55 r
F
.43545 .5766 m .43561 .57362 L .43181 .57528 L F
.4423 .58375 m .43563 .57654 L .43225 .57778 L .642 .739 .919 r
F
.44325 .57633 m .43874 .57367 L .44179 .57667 L .668 .747 .91 r
F
.44164 .57596 m .43561 .57362 L .43869 .57665 L .667 .747 .91 r
F
.44002 .57561 m .43561 .57362 L .43558 .57655 L .605 .389 .562 r
F
.43563 .57654 m .43562 .57653 L .43558 .57655 L .642 .739 .919 r
F
.43563 .57654 m .43558 .57655 L .43225 .57778 L F
.44002 .57561 m .43558 .57655 L .43719 .57627 L .605 .389 .562 r
F
.43558 .57655 m .43561 .57362 L .43545 .5766 L .516 .318 .55 r
F
.44245 .58119 m .44232 .58413 L .44266 .58106 L .428 .243 .527 r
F
.44232 .58413 m .44252 .58402 L .44266 .58106 L F
.44171 .58165 m .43984 .58103 L .44101 .58208 L .667 .747 .91 r
F
.43874 .57367 m .43567 .57065 L .43191 .5723 L .668 .747 .91 r
F
.43561 .57362 m .43563 .57061 L .43184 .57227 L .516 .318 .55 r
F
.44343 .58372 m .42979 .57023 L .4423 .58375 L .642 .739 .919 r
F
.44258 .57818 m .44245 .58119 L .44281 .57803 L .428 .243 .527 r
F
.44245 .58119 m .44266 .58106 L .44281 .57803 L F
.44298 .58086 m .44176 .57966 L .44234 .58126 L .667 .747 .91 r
F
.44174 .5779 m .44179 .57667 L .44054 .57721 L .668 .747 .91 r
F
.44106 .57751 m .44054 .57721 L .44116 .57833 L F
.44152 .57915 m .44126 .57911 L .44132 .57951 L F
.4412 .57846 m .44118 .57846 L .44118 .57847 L F
.4412 .57846 m .44118 .57847 L .44126 .57911 L F
.44325 .57633 m .44167 .57298 L .43874 .57367 L F
.4419 .57859 m .44223 .57818 L .4414 .57841 L F
.4414 .57841 m .44106 .57751 L .44116 .57833 L F
.44223 .57818 m .44106 .57751 L .4414 .57841 L F
.4418 .57866 m .44179 .57866 L .44179 .57867 L F
.44179 .57866 m .4412 .57846 L .44152 .57915 L F
.44323 .57932 m .43869 .57665 L .44176 .57966 L .667 .747 .91 r
F
.4421 .5781 m .44224 .57786 L .44174 .5779 L .668 .747 .91 r
F
.44294 .5778 m .44179 .57667 L .44174 .5779 L F
.44241 .57828 m .44223 .57818 L .4419 .57859 L F
.44323 .57932 m .44164 .57596 L .43869 .57665 L .667 .747 .91 r
F
.44343 .58372 m .44342 .5837 L .42979 .57023 L .642 .739 .919 r
F
.44342 .5837 m .43182 .56987 L .42979 .57023 L F
.44243 .58252 m .43867 .57967 L .44174 .58268 L .667 .747 .91 r
F
.44321 .58234 m .44137 .58125 L .44243 .58252 L F
.44137 .58125 m .43867 .57967 L .44243 .58252 L F
.44167 .57298 m .43567 .57065 L .43874 .57367 L .668 .747 .91 r
F
.44298 .58086 m .44323 .57932 L .44176 .57966 L .667 .747 .91 r
F
.44321 .58234 m .44162 .57898 L .43981 .5794 L F
.44137 .58125 m .43981 .5794 L .43867 .57967 L F
.44321 .58234 m .43981 .5794 L .44137 .58125 L F
.44428 .58356 m .4448 .5834 L .44427 .58355 L F
.44428 .58356 m .44427 .58355 L .44385 .58366 L F
.44385 .58368 m .44428 .58356 L .44385 .58366 L F
.4448 .58361 m .4448 .5834 L .44385 .58368 L F
.44385 .58366 m .4448 .58222 L .44321 .58234 L F
.44463 .58368 m .44472 .58368 L .44487 .58062 L .667 .437 .562 r
F
.4448 .5834 m .4448 .58222 L .44385 .58366 L .667 .747 .91 r
F
.44385 .58366 m .44321 .58234 L .44348 .58376 L F
.44304 .58092 m .44298 .58086 L .44276 .58099 L F
.44478 .58063 m .44463 .58368 L .44487 .58062 L .667 .437 .562 r
F
.44304 .58092 m .44374 .58039 L .44298 .58086 L .667 .747 .91 r
F
.44388 .58069 m .44374 .58039 L .44304 .58092 L F
.44374 .58039 m .44323 .57932 L .44298 .58086 L F
.4448 .58222 m .44162 .57898 L .44321 .58234 L F
.44469 .57766 m .44456 .58064 L .44492 .57764 L .667 .437 .562 r
F
.44388 .58069 m .44481 .5792 L .44323 .57932 L .667 .747 .91 r
F
.44456 .58064 m .44478 .58063 L .44492 .57764 L .667 .437 .562 r
F
.44481 .58043 m .44481 .5792 L .44388 .58069 L .667 .747 .91 r
F
.44481 .5792 m .44164 .57596 L .44323 .57932 L F
.44482 .57621 m .44167 .57298 L .44325 .57633 L .668 .747 .91 r
F
.44482 .57621 m .44482 .57275 L .44167 .57298 L F
.44481 .5792 m .4448 .57573 L .44164 .57596 L .667 .747 .91 r
F
.4448 .58222 m .44479 .57875 L .44162 .57898 L F
.44167 .57298 m .44008 .56962 L .43567 .57065 L .668 .747 .91 r
F
.44164 .57596 m .44004 .57259 L .43561 .57362 L .667 .747 .91 r
F
.44162 .57898 m .43558 .57665 L .43867 .57967 L F
.44004 .57259 m .43563 .57061 L .43561 .57362 L .605 .389 .562 r
F
.44004 .57259 m .44005 .56957 L .43563 .57061 L F
.44162 .57898 m .44002 .57561 L .43558 .57665 L .667 .747 .91 r
F
.44479 .57875 m .44002 .57561 L .44162 .57898 L F
.4448 .57573 m .44004 .57259 L .44164 .57596 L F
.44482 .57275 m .44008 .56962 L .44167 .57298 L .668 .747 .91 r
F
.44482 .57275 m .44481 .56927 L .44008 .56962 L F
.4448 .57573 m .4448 .57224 L .44004 .57259 L .667 .747 .91 r
F
.44479 .57875 m .44478 .57526 L .44002 .57561 L F
.44002 .57561 m .44004 .57259 L .43561 .57362 L .605 .389 .562 r
F
.44478 .57526 m .44004 .57259 L .44002 .57561 L .672 .443 .566 r
F
.44434 .58369 m .43718 .56893 L .44342 .5837 L .642 .739 .919 r
F
.44343 .58372 m .44342 .5837 L .44343 .58372 L F
.44434 .58369 m .44342 .5837 L .44343 .58372 L F
.44342 .5837 m .43718 .56893 L .43182 .56987 L F
.44487 .58062 m .44473 .58361 L .4448 .58361 L .667 .437 .562 r
F
.44562 .58068 m .44487 .58062 L .4448 .58361 L .733 .492 .564 r
F
.4448 .58535 m .44568 .58368 L .4448 .58361 L .667 .747 .91 r
F
.44482 .58361 m .4448 .58361 L .4448 .58368 L .733 .492 .564 r
F
.44562 .58068 m .4448 .58361 L .44482 .58361 L F
.44562 .58068 m .4448 .58368 L .44549 .58377 L F
.44549 .58366 m .4457 .58368 L .44598 .57772 L F
.44593 .58071 m .4457 .58368 L .44586 .5837 L F
.44585 .5807 m .4457 .58368 L .44593 .58071 L F
.4468 .57795 m .44601 .57773 L .44593 .58071 L .799 .548 .56 r
F
.44633 .58082 m .44593 .58071 L .44586 .5837 L F
.4468 .57795 m .44593 .58071 L .44633 .58082 L F
.44481 .5804 m .44639 .57933 L .44481 .5792 L .667 .747 .91 r
F
.44481 .58061 m .44501 .58045 L .44481 .5804 L F
.44501 .58045 m .44639 .57933 L .44481 .5804 L F
.4448 .58361 m .44638 .58234 L .4448 .58222 L F
.44568 .58368 m .44638 .58234 L .4448 .58361 L F
.4449 .58546 m .44116 .58526 L .44493 .5855 L .642 .739 .919 r
F
.4448 .58568 m .4449 .58547 L .4448 .58535 L .667 .747 .91 r
F
.4449 .58547 m .44638 .58234 L .4448 .58535 L F
.44521 .58548 m .44434 .58369 L .44343 .58372 L .642 .739 .919 r
F
.44347 .58376 m .44343 .58372 L .44343 .58372 L F
.44521 .58548 m .44343 .58372 L .44347 .58376 L F
.44521 .58548 m .44343 .58372 L .4423 .58375 L F
.44134 .5838 m .44066 .58354 L .44033 .58413 L .667 .747 .91 r
F
.44521 .58548 m .4423 .58375 L .44061 .5838 L .642 .739 .919 r
F
.4448 .58568 m .4448 .58535 L .44444 .58492 L .667 .747 .91 r
F
.44485 .58541 m .44161 .58416 L .44015 .58448 L .642 .739 .919 r
F
.44119 .58571 m .441 .59309 L .44117 .58559 L .868 .695 .169 r
F
.44106 .59349 m .43999 .59292 L .4408 .59352 L .641 .739 .92 r
F
.44125 .58621 m .441 .58625 L .44128 .58645 L .667 .747 .91 r
F
.44119 .58571 m .44105 .59343 L .441 .59309 L .868 .695 .169 r
F
.44119 .58572 m .44105 .59343 L .44119 .58571 L F
.44119 .58572 m .44124 .58614 L .44105 .59343 L F
.44129 .58621 m .44125 .58621 L .44164 .5867 L .667 .747 .91 r
F
.44125 .58621 m .44128 .58645 L .44164 .58671 L F
.44138 .58635 m .44164 .58671 L .44145 .59399 L .984 .727 .46 r
F
.44123 .59369 m .44117 .5936 L .44131 .58623 L F
.44123 .59369 m .44131 .58623 L .44131 .58624 L F
.44188 .58688 m .4423 .58718 L .44211 .59448 L .908 .647 .532 r
F
.44138 .58634 m .44123 .59369 L .44131 .58624 L .984 .727 .46 r
F
.44374 .59499 m .44366 .59498 L .44364 .5876 L .747 .505 .564 r
F
.44264 .58712 m .44309 .59488 L .44256 .59466 L .83 .576 .556 r
F
.4438 .58762 m .4438 .595 L .44364 .5876 L .747 .505 .564 r
F
.4438 .595 m .44379 .5988 L .44374 .59499 L F
.4438 .595 m .44374 .59499 L .44364 .5876 L F
.44309 .59488 m .44344 .59503 L .4437 .59498 L .641 .739 .92 r
F
.44231 .59521 m .44272 .59578 L .4437 .59498 L F
.4437 .59498 m .44272 .59578 L .44306 .59625 L F
.44364 .5876 m .44366 .59498 L .44352 .58758 L .747 .505 .564 r
F
.44366 .59498 m .44376 .62912 L .44356 .59496 L F
.44366 .59498 m .44356 .59496 L .44352 .58758 L F
.44174 .58678 m .44164 .58671 L .44164 .58649 L .908 .647 .532 r
F
.4448 .58568 m .44129 .58621 L .44164 .58671 L .667 .747 .91 r
F
.44521 .58548 m .44225 .58693 L .44231 .58698 L .642 .739 .919 r
F
.44231 .58698 m .44229 .59455 L .44211 .59448 L .83 .576 .556 r
F
.44187 .58666 m .44211 .59448 L .44175 .59421 L .908 .647 .532 r
F
.44264 .58731 m .44256 .59466 L .44246 .58724 L .83 .576 .556 r
F
.44256 .59466 m .44241 .5946 L .44246 .58704 L F
.44275 .59482 m .44344 .59503 L .44309 .59488 L .641 .739 .92 r
F
.44328 .58738 m .44376 .62912 L .44222 .62891 L .747 .505 .564 r
F
.44352 .58742 m .44376 .62912 L .44328 .58738 L F
.44461 .59317 m .44183 .59453 L .44194 .59469 L .641 .739 .92 r
F
.44275 .59482 m .44194 .59469 L .44231 .59521 L F
.44461 .59317 m .44194 .59469 L .44275 .59482 L F
.44211 .59448 m .44222 .62891 L .44123 .62852 L .83 .576 .556 r
F
.44229 .59455 m .44222 .62891 L .44211 .59448 L F
.4448 .58568 m .44348 .58611 L .44347 .58643 L .667 .747 .91 r
F
.44348 .58611 m .44164 .58671 L .44347 .58643 L F
.44347 .58643 m .44164 .58671 L .44223 .58713 L F
.44264 .58712 m .44264 .58731 L .44246 .58704 L .83 .576 .556 r
F
.44264 .58731 m .44246 .58724 L .44246 .58704 L F
.4448 .58568 m .44221 .58714 L .443 .58745 L .667 .747 .91 r
F
.44485 .58541 m .44015 .58448 L .4449 .58546 L .642 .739 .919 r
F
.4448 .58568 m .44444 .58492 L .44316 .58385 L .667 .747 .91 r
F
.44299 .5839 m .44316 .58385 L .44174 .58268 L F
.4448 .58568 m .44316 .58385 L .44299 .5839 L F
.44129 .58621 m .44164 .5867 L .44164 .58671 L F
.44099 .59299 m .44098 .59291 L .44116 .58529 L .868 .695 .169 r
F
.44116 .58529 m .44098 .59291 L .44097 .59279 L F
.44147 .58478 m .44116 .58529 L .44116 .58548 L 0 0 .377 r
F
.4448 .58568 m .44163 .58464 L .44134 .58515 L .667 .747 .91 r
F
.44146 .58494 m .44116 .58548 L .44097 .59279 L 0 0 .377 r
F
.44147 .58478 m .44116 .58548 L .44146 .58494 L F
.44033 .58413 m .43894 .58355 L .43955 .58438 L .667 .747 .91 r
F
.44015 .58448 m .44061 .5838 L .4372 .58389 L .642 .739 .919 r
F
.44015 .58448 m .4372 .58389 L .43738 .58507 L F
.44134 .58515 m .43951 .58394 L .43891 .58477 L .667 .747 .91 r
F
.44163 .58464 m .43951 .58394 L .44134 .58515 L F
.44147 .58478 m .44097 .59279 L .44122 .59237 L 0 0 .377 r
F
.4406 .59246 m .4393 .59212 L .43899 .59218 L .641 .739 .92 r
F
.44461 .59317 m .44072 .5924 L .4406 .59246 L F
.44072 .5924 m .4393 .59212 L .4406 .59246 L F
.43774 .59245 m .43483 .59146 L .43704 .59237 L F
.44161 .58416 m .44061 .5838 L .44015 .58448 L .642 .739 .919 r
F
.44061 .5838 m .43773 .58275 L .4372 .58389 L F
.44158 .5846 m .44157 .58474 L .44163 .58451 L 0 0 .377 r
F
.44157 .58474 m .44163 .58464 L .44163 .58451 L F
.44163 .58464 m .44048 .58323 L .43951 .58394 L .667 .747 .91 r
F
.4448 .58568 m .44227 .58424 L .44163 .58464 L F
.44227 .58424 m .44048 .58323 L .44163 .58464 L F
.44255 .58401 m .44255 .58407 L .44269 .58393 L .428 .243 .527 r
F
.44255 .58407 m .44268 .58398 L .44269 .58393 L F
.44227 .58424 m .44174 .58268 L .44048 .58323 L .667 .747 .91 r
F
.44338 .58379 m .44269 .58393 L .44268 .58398 L .585 .37 .555 r
F
.4448 .58568 m .44299 .5839 L .44227 .58424 L .667 .747 .91 r
F
.44461 .59317 m .4406 .59246 L .44017 .5927 L .641 .739 .92 r
F
.43639 .59273 m .41446 .59001 L .4278 .59228 L F
.44232 .58413 m .442 .5917 L .44252 .58402 L .428 .243 .527 r
F
.44461 .59317 m .44017 .5927 L .43978 .59291 L .641 .739 .92 r
F
.44461 .59317 m .44099 .59298 L .44106 .59349 L F
.44461 .59317 m .4408 .59352 L .44145 .59399 L F
.44165 .59414 m .44123 .62852 L .44157 .59408 L .908 .647 .532 r
F
.44062 .62436 m .44055 .62804 L .44061 .62454 L .984 .727 .46 r
F
.4408 .59352 m .41526 .59587 L .44145 .59399 L .641 .739 .92 r
F
.44062 .62436 m .44061 .62454 L .44112 .59353 L .984 .727 .46 r
F
.44117 .5936 m .44062 .62436 L .44112 .59353 L F
.44204 .59442 m .4418 .59448 L .44183 .59453 L .641 .739 .92 r
F
.44461 .59317 m .44145 .59399 L .44204 .59442 L F
.44145 .59399 m .44123 .62852 L .44055 .62804 L .908 .647 .532 r
F
.44157 .59408 m .44123 .62852 L .44145 .59399 L F
.44061 .62454 m .44055 .62804 L .44061 .62455 L .984 .727 .46 r
F
.44061 .62454 m .44061 .62455 L .44112 .59353 L F
.44112 .59353 m .44061 .62454 L .44112 .59353 L F
.44099 .59298 m .43999 .59292 L .44106 .59349 L .641 .739 .92 r
F
.44105 .59343 m .44055 .62804 L .44015 .62747 L .984 .727 .46 r
F
.44112 .59353 m .44055 .62804 L .44105 .59343 L F
.44123 .59369 m .44055 .62804 L .44117 .5936 L F
.44175 .59421 m .44123 .62852 L .44165 .59414 L .908 .647 .532 r
F
.44123 .59369 m .44145 .59399 L .44055 .62804 L .984 .727 .46 r
F
.44175 .59421 m .44211 .59448 L .44123 .62852 L .908 .647 .532 r
F
.42713 .58716 m .41478 .58387 L .41591 .5882 L .642 .739 .919 r
F
.42795 .58708 m .41591 .5882 L .42781 .58711 L F
.4265 .58564 m .42672 .58554 L .42716 .58832 L .935 .725 .246 r
F
.42672 .58554 m .42717 .5873 L .42716 .58832 L F
.42716 .58832 m .42717 .5873 L .4278 .58814 L .98 .72 .463 r
F
.43493 .58816 m .42781 .58711 L .42727 .58743 L .642 .739 .919 r
F
.43493 .58816 m .42727 .58743 L .42898 .58971 L F
.42716 .58832 m .4278 .58814 L .42902 .59081 L .98 .72 .463 r
F
.42898 .58971 m .42895 .58972 L .42898 .58972 L .642 .739 .919 r
F
.4278 .58814 m .42903 .58978 L .42902 .59081 L .98 .72 .463 r
F
.42902 .59081 m .42903 .58978 L .43001 .59051 L .911 .649 .53 r
F
.41478 .58387 m .38678 .5909 L .41591 .5882 L .642 .739 .919 r
F
.43868 .58612 m .42781 .58711 L .43493 .58816 L F
.43304 .58744 m .42902 .59081 L .43427 .5891 L .667 .747 .91 r
F
.43304 .58744 m .42716 .58832 L .42902 .59081 L F
.43875 .58608 m .42795 .58708 L .4387 .58611 L .642 .739 .919 r
F
.4326 .58566 m .42716 .58832 L .43304 .58744 L .667 .747 .91 r
F
.4326 .58566 m .4265 .58564 L .42716 .58832 L F
.4393 .59212 m .41802 .58348 L .41505 .58733 L .641 .739 .92 r
F
.44157 .58474 m .44132 .5922 L .44163 .58464 L 0 0 .377 r
F
.44132 .5922 m .44137 .59212 L .44163 .58451 L F
.44163 .58451 m .44137 .59212 L .44144 .59201 L F
.44156 .58463 m .44129 .59225 L .44158 .5846 L F
.44129 .59225 m .4413 .59223 L .44158 .5846 L F
.44158 .5846 m .4413 .59223 L .44132 .5922 L F
.44147 .58478 m .44122 .59237 L .44156 .58463 L F
.44122 .59237 m .44129 .59225 L .44156 .58463 L F
.44461 .59317 m .44084 .59179 L .4393 .59212 L .641 .739 .92 r
F
.4405 .58811 m .43621 .59053 L .43874 .59162 L .667 .747 .91 r
F
.43953 .58739 m .43621 .59053 L .4405 .58811 L F
.43953 .58739 m .43427 .5891 L .43621 .59053 L F
.44084 .59179 m .41802 .58348 L .4393 .59212 L .641 .739 .92 r
F
.44338 .58379 m .44338 .58379 L .44348 .58376 L .585 .37 .555 r
F
.44444 .58492 m .44243 .58252 L .44174 .58268 L .667 .747 .91 r
F
.4448 .58568 m .443 .58745 L .44328 .58755 L F
.44338 .58379 m .44306 .59132 L .44348 .58376 L .585 .37 .555 r
F
.44241 .5946 m .44222 .62891 L .44229 .59455 L .83 .576 .556 r
F
.44461 .59317 m .44275 .59482 L .4437 .59498 L .641 .739 .92 r
F
.44256 .59466 m .44309 .59488 L .44222 .62891 L .83 .576 .556 r
F
.44256 .59466 m .44222 .62891 L .44241 .5946 L F
.442 .5917 m .44216 .59162 L .44252 .58402 L .428 .243 .527 r
F
.42852 .58035 m .42712 .57995 L .4271 .58217 L .121 .012 .445 r
F
.42728 .58137 m .41867 .57578 L .41874 .58024 L .642 .739 .919 r
F
.4372 .58389 m .43773 .58275 L .41874 .58024 L F
.43738 .58507 m .4372 .58389 L .42281 .5843 L F
.4372 .58389 m .41571 .57964 L .42281 .5843 L F
.42709 .58296 m .42694 .58287 L .4265 .58564 L 0 0 .196 r
F
.42694 .58287 m .42651 .58471 L .4265 .58564 L F
.4265 .58564 m .42651 .58471 L .42672 .58554 L .935 .725 .246 r
F
.43892 .58656 m .43427 .5891 L .43953 .58739 L .667 .747 .91 r
F
.43892 .58656 m .43304 .58744 L .43427 .5891 L F
.4387 .58567 m .43304 .58744 L .43892 .58656 L F
.4387 .58567 m .4326 .58566 L .43304 .58744 L F
.433 .58387 m .4265 .58564 L .4326 .58566 L F
.433 .58387 m .42709 .58296 L .4265 .58564 L F
.43956 .59133 m .42283 .58028 L .41802 .58348 L .641 .739 .92 r
F
.44232 .58413 m .44163 .58451 L .44144 .59201 L .428 .243 .527 r
F
.44232 .58413 m .44144 .59201 L .442 .5917 L F
.44461 .59317 m .4419 .59156 L .44084 .59179 L .641 .739 .92 r
F
.443 .58745 m .44255 .58736 L .44286 .58758 L .667 .747 .91 r
F
.44338 .58379 m .44268 .58398 L .44249 .59144 L .585 .37 .555 r
F
.44338 .58379 m .44249 .59144 L .44306 .59132 L F
.44219 .5916 m .4423 .59154 L .44268 .58398 L .428 .243 .527 r
F
.44219 .5916 m .44268 .58398 L .44268 .58398 L F
.44299 .5839 m .44268 .58398 L .44227 .58424 L .667 .747 .91 r
F
.44255 .58407 m .44219 .5916 L .44268 .58398 L .428 .243 .527 r
F
.44269 .58393 m .4423 .59154 L .44249 .59144 L F
.43179 .5783 m .43142 .57819 L .42889 .58046 L .379 .21 .523 r
F
.43142 .57819 m .4289 .57986 L .42889 .58046 L F
.42889 .58046 m .42852 .58035 L .42709 .58296 L .121 .012 .445 r
F
.42852 .58035 m .4271 .58217 L .42709 .58296 L F
.42768 .58142 m .42781 .57911 L .42728 .58137 L .642 .739 .919 r
F
.42911 .57959 m .42781 .57911 L .42768 .58142 L F
.42781 .57911 m .41867 .57578 L .42728 .58137 L F
.42709 .58296 m .4271 .58217 L .42694 .58287 L 0 0 .196 r
F
.42889 .58046 m .4289 .57986 L .42852 .58035 L .121 .012 .445 r
F
.42911 .57959 m .42347 .57256 L .41867 .57578 L .642 .739 .919 r
F
.43083 .57738 m .42347 .57256 L .42911 .57959 L F
.43891 .58477 m .4326 .58566 L .4387 .58567 L .667 .747 .91 r
F
.43891 .58477 m .433 .58387 L .4326 .58566 L F
.43951 .58394 m .433 .58387 L .43891 .58477 L F
.43951 .58394 m .43421 .5822 L .433 .58387 L F
.43421 .5822 m .42709 .58296 L .433 .58387 L F
.43421 .5822 m .42889 .58046 L .42709 .58296 L F
.43614 .58077 m .42889 .58046 L .43421 .5822 L F
.43614 .58077 m .43179 .5783 L .42889 .58046 L F
.44141 .59127 m .42915 .57795 L .42283 .58028 L .641 .739 .92 r
F
.44252 .58408 m .44216 .59162 L .44255 .58407 L .428 .243 .527 r
F
.44216 .59162 m .44219 .5916 L .44255 .58401 L F
.4438 .58762 m .44352 .58758 L .44352 .58742 L .747 .505 .564 r
F
.4448 .58568 m .44328 .58755 L .44388 .58763 L .667 .747 .91 r
F
.44361 .58374 m .44324 .59128 L .44374 .58371 L .585 .37 .555 r
F
.44461 .59317 m .44279 .59137 L .4419 .59156 L .641 .739 .92 r
F
.44324 .59128 m .44335 .59126 L .44374 .58371 L .585 .37 .555 r
F
.44374 .58371 m .44335 .59126 L .44355 .59121 L F
.44306 .59132 m .44314 .5913 L .44348 .58376 L F
.44348 .58376 m .44314 .5913 L .44358 .58374 L F
.44314 .5913 m .44322 .59128 L .44358 .58374 L F
.44358 .58374 m .44322 .59128 L .44361 .58374 L F
.44322 .59128 m .44324 .59128 L .44361 .58374 L F
.43225 .57778 m .42979 .57023 L .42347 .57256 L .642 .739 .919 r
F
.43562 .57653 m .42979 .57023 L .43225 .57778 L F
.43558 .57665 m .43545 .5766 L .43179 .5783 L .516 .318 .55 r
F
.43545 .5766 m .43179 .57794 L .43179 .5783 L F
.43179 .5783 m .43179 .57794 L .43142 .57819 L .379 .21 .523 r
F
.44048 .58323 m .43421 .5822 L .43951 .58394 L .667 .747 .91 r
F
.44048 .58323 m .43614 .58077 L .43421 .5822 L F
.44174 .58268 m .43614 .58077 L .44048 .58323 L F
.44174 .58268 m .43867 .57967 L .43614 .58077 L F
.43867 .57967 m .43179 .5783 L .43614 .58077 L F
.43867 .57967 m .43558 .57665 L .43179 .5783 L F
.44266 .59124 m .43656 .57666 L .42915 .57795 L .641 .739 .92 r
F
.44461 .59317 m .44366 .59121 L .44266 .59124 L F
.44118 .58567 m .44091 .58567 L .44124 .58614 L .667 .747 .91 r
F
.44379 .5988 m .44376 .62912 L .44366 .59498 L .747 .505 .564 r
F
.44379 .5988 m .44366 .59498 L .44374 .59499 L F
.44461 .59317 m .4437 .59498 L .44462 .59514 L .641 .739 .92 r
F
.44415 .59596 m .4443 .59607 L .44462 .59552 L F
.44463 .59631 m .44391 .59744 L .44464 .59847 L F
.44462 .59552 m .4443 .59607 L .44463 .59631 L F
.44462 .59514 m .44445 .59544 L .44462 .59552 L F
.4438 .595 m .44462 .59514 L .44376 .62912 L .747 .505 .564 r
F
.44473 .58361 m .44472 .58368 L .4448 .58361 L .667 .437 .562 r
F
.44472 .58368 m .4448 .58368 L .4448 .58361 L F
.4448 .58361 m .4448 .58368 L .4448 .58368 L F
.44483 .57762 m .4464 .57633 L .44482 .57621 L .668 .747 .91 r
F
.44574 .5777 m .44598 .57772 L .44604 .57635 L .733 .492 .564 r
F
.44575 .5777 m .4464 .57633 L .44483 .57762 L .668 .747 .91 r
F
.44575 .58069 m .44639 .57933 L .44481 .58061 L .667 .747 .91 r
F
.4464 .57633 m .44482 .57275 L .44482 .57621 L .668 .747 .91 r
F
.4464 .57633 m .44797 .57299 L .44482 .57275 L F
.44639 .57933 m .4448 .57573 L .44481 .5792 L .667 .747 .91 r
F
.44709 .57668 m .44703 .57801 L .44706 .57802 L .799 .548 .56 r
F
.44686 .57661 m .44601 .57773 L .4468 .57795 L F
.44601 .57773 m .44786 .57668 L .44577 .57766 L .668 .747 .91 r
F
.44662 .5779 m .44673 .57779 L .44601 .57773 L F
.44673 .57779 m .44786 .57668 L .44601 .57773 L F
.44604 .57635 m .44598 .57772 L .44601 .57773 L .733 .492 .564 r
F
.44575 .5777 m .44601 .57773 L .44577 .57766 L .668 .747 .91 r
F
.44686 .57661 m .44604 .57635 L .44601 .57773 L .799 .548 .56 r
F
.44577 .57766 m .44786 .57668 L .4464 .57633 L .668 .747 .91 r
F
.44706 .57802 m .44912 .57723 L .44672 .5778 L F
.4468 .57795 m .44655 .58389 L .447 .578 L .799 .548 .56 r
F
.44662 .5779 m .44706 .57802 L .44672 .5778 L .668 .747 .91 r
F
.44672 .5778 m .44912 .57723 L .44786 .57668 L F
.44786 .57668 m .44797 .57299 L .4464 .57633 L F
.44786 .57668 m .4509 .57369 L .44797 .57299 L F
.44639 .57933 m .44797 .57597 L .4448 .57573 L .667 .747 .91 r
F
.44638 .58234 m .44479 .57875 L .4448 .58222 L F
.44691 .58098 m .44692 .58098 L .44706 .57802 L .799 .548 .56 r
F
.44593 .58071 m .44786 .57967 L .44576 .58066 L .667 .747 .91 r
F
.44662 .5809 m .44674 .58078 L .44593 .58071 L F
.44674 .58078 m .44786 .57967 L .44593 .58071 L F
.44575 .58069 m .44593 .58071 L .44576 .58066 L F
.44786 .57852 m .44773 .58147 L .44802 .57862 L .889 .63 .539 r
F
.44842 .57922 m .44812 .57868 L .44805 .58166 L .993 .743 .421 r
F
.44662 .5809 m .44913 .58023 L .44786 .57967 L .667 .747 .91 r
F
.4475 .58115 m .44913 .58023 L .44662 .5809 L F
.44576 .58066 m .44786 .57967 L .44639 .57933 L F
.44738 .57822 m .4475 .57814 L .44706 .57802 L .668 .747 .91 r
F
.4475 .57814 m .44912 .57723 L .44706 .57802 L F
.44912 .57723 m .4509 .57369 L .44786 .57668 L F
.44786 .57967 m .44797 .57597 L .44639 .57933 L .667 .747 .91 r
F
.44802 .57862 m .44872 .57848 L .44856 .57844 L .668 .747 .91 r
F
.4481 .57867 m .44872 .57848 L .44802 .57862 L F
.4481 .57867 m .44812 .57868 L .44811 .57867 L F
.44852 .57801 m .44842 .57922 L .44847 .57932 L .993 .743 .421 r
F
.44811 .57867 m .44865 .57908 L .44872 .57848 L .668 .747 .91 r
F
.44837 .57913 m .44865 .57908 L .44811 .57867 L F
.44856 .57844 m .44872 .57848 L .44873 .57839 L F
.44873 .57839 m .45068 .57878 L .45008 .57795 L F
.44865 .57908 m .45068 .57878 L .44873 .57839 L F
.45008 .57795 m .45341 .5748 L .44912 .57723 L F
.44912 .57723 m .45341 .5748 L .4509 .57369 L F
.44786 .57967 m .45092 .57667 L .44797 .57597 L .667 .747 .91 r
F
.44638 .58234 m .44796 .57899 L .44479 .57875 L F
.44797 .57299 m .44481 .56927 L .44482 .57275 L .668 .747 .91 r
F
.44797 .57299 m .44954 .56964 L .44481 .56927 L F
.44797 .57597 m .4448 .57224 L .4448 .57573 L .667 .747 .91 r
F
.4509 .57369 m .44954 .56964 L .44797 .57299 L .668 .747 .91 r
F
.44797 .57597 m .44956 .57261 L .4448 .57224 L .667 .747 .91 r
F
.44796 .57899 m .44478 .57526 L .44479 .57875 L F
.45092 .57667 m .44956 .57261 L .44797 .57597 L F
.44796 .57899 m .44955 .57563 L .44478 .57526 L F
.44956 .57261 m .44957 .56959 L .44481 .56922 L .73 .491 .566 r
F
.4448 .57224 m .44005 .56957 L .44004 .57259 L .672 .443 .566 r
F
.4448 .57224 m .44481 .56922 L .44005 .56957 L F
.44956 .57261 m .44481 .56922 L .4448 .57224 L .73 .491 .566 r
F
.44955 .57563 m .44956 .57261 L .4448 .57224 L F
.44478 .57526 m .4448 .57224 L .44004 .57259 L .672 .443 .566 r
F
.44955 .57563 m .4448 .57224 L .44478 .57526 L .73 .491 .566 r
F
.44521 .58548 m .44514 .56878 L .43718 .56893 L .642 .739 .919 r
F
.44443 .58369 m .44374 .58371 L .44355 .59121 L .667 .437 .562 r
F
.44461 .59317 m .44461 .59119 L .44366 .59121 L .641 .739 .92 r
F
.44411 .5912 m .44355 .59121 L .44268 .62503 L .667 .437 .562 r
F
.44443 .58369 m .44355 .59121 L .44411 .5912 L F
.44338 .58379 m .44268 .58398 L .44338 .58379 L .585 .37 .555 r
F
.44299 .5839 m .44292 .58383 L .44268 .58398 L .667 .747 .91 r
F
.44268 .58398 m .44268 .58398 L .44269 .58393 L .428 .243 .527 r
F
.44252 .58402 m .44252 .58408 L .44255 .58401 L F
.44252 .58408 m .44255 .58407 L .44255 .58401 L F
.44292 .58383 m .44174 .58268 L .44227 .58424 L .667 .747 .91 r
F
.44366 .59121 m .44454 .57651 L .43656 .57666 L .641 .739 .92 r
F
.4448 .58368 m .44441 .59119 L .4448 .58368 L .667 .437 .562 r
F
.44441 .59119 m .44441 .59119 L .4448 .58368 L F
.4448 .58368 m .44441 .59119 L .44461 .59119 L F
.44472 .58368 m .44435 .59119 L .4448 .58368 L F
.44435 .59119 m .44441 .59119 L .4448 .58368 L F
.44463 .58368 m .44428 .59119 L .44472 .58368 L F
.44428 .59119 m .44435 .59119 L .44472 .58368 L F
.44443 .58369 m .44411 .5912 L .44463 .58368 L F
.44411 .5912 m .44268 .62503 L .44428 .59119 L F
.44411 .5912 m .44428 .59119 L .44463 .58368 L F
.44521 .58548 m .44478 .58532 L .44485 .58541 L .642 .739 .919 r
F
.4448 .58568 m .44496 .58553 L .4449 .58547 L .667 .747 .91 r
F
.44521 .58548 m .4449 .58546 L .44493 .5855 L .642 .739 .919 r
F
.44521 .58548 m .44485 .58541 L .4449 .58546 L F
.44521 .58548 m .44493 .5855 L .44497 .58554 L F
.4448 .58568 m .445 .58558 L .44499 .58557 L .667 .747 .91 r
F
.44521 .58548 m .44497 .58554 L .445 .58558 L .642 .739 .919 r
F
.4448 .58568 m .44499 .58557 L .44496 .58553 L .667 .747 .91 r
F
.44533 .58768 m .44505 .58772 L .44505 .58763 L .651 .424 .562 r
F
.44505 .58763 m .44509 .59511 L .44481 .58765 L F
.44509 .59511 m .44531 .62896 L .4449 .59512 L F
.44509 .59511 m .4449 .59512 L .44481 .58765 L F
.44877 .58678 m .46661 .5982 L .47146 .59508 L .642 .739 .919 r
F
.44845 .5874 m .46034 .60045 L .46661 .5982 L F
.46661 .5982 m .49742 .60457 L .47146 .59508 L F
.45211 .59465 m .47092 .60274 L .47401 .59897 L .641 .739 .92 r
F
.44733 .59461 m .44729 .59464 L .44736 .58716 L .387 .212 .518 r
F
.44797 .58682 m .44786 .59422 L .44779 .59432 L .095 0 .426 r
F
.44811 .58664 m .44818 .5938 L .44797 .59408 L F
.44828 .5852 m .44804 .59279 L .44838 .58537 L .993 .743 .421 r
F
.44779 .59432 m .44921 .59484 L .44921 .59484 L .641 .739 .92 r
F
.44781 .58703 m .44787 .58706 L .44799 .5868 L .642 .739 .919 r
F
.44738 .58714 m .44759 .58726 L .44797 .58672 L .667 .747 .91 r
F
.44754 .58709 m .44797 .58682 L .44779 .59432 L .387 .212 .518 r
F
.44779 .59432 m .44779 .59432 L .44779 .59432 L .641 .739 .92 r
F
.44779 .59432 m .44745 .59464 L .4481 .59443 L F
.44754 .58709 m .44779 .59432 L .44743 .59454 L .387 .212 .518 r
F
.44461 .59317 m .44736 .59459 L .44779 .59432 L .641 .739 .92 r
F
.44736 .59459 m .44745 .59464 L .44779 .59432 L F
.44745 .59464 m .44741 .59482 L .44752 .59467 L F
.44461 .59317 m .44722 .59471 L .44745 .59464 L F
.44745 .59464 m .44979 .59585 L .4481 .59443 L F
.44743 .59454 m .44779 .59432 L .44697 .62813 L .387 .212 .518 r
F
.44461 .59317 m .44779 .59432 L .44779 .59432 L .641 .739 .92 r
F
.44779 .59432 m .44921 .59484 L .44779 .59432 L F
.44802 .58675 m .4479 .59417 L .44797 .58682 L .095 0 .426 r
F
.4479 .59417 m .44786 .59422 L .44797 .58682 L F
.44797 .59408 m .44791 .59416 L .44803 .58674 L F
.44791 .59416 m .4479 .59417 L .44802 .58675 L F
.44461 .59317 m .44921 .59484 L .44872 .59398 L .641 .739 .92 r
F
.4479 .59417 m .44737 .62758 L .44786 .59422 L .095 0 .426 r
F
.44733 .59461 m .44697 .62813 L .44729 .59464 L .387 .212 .518 r
F
.44779 .59432 m .44737 .62758 L .44697 .62813 L .095 0 .426 r
F
.44786 .59422 m .44737 .62758 L .44779 .59432 L F
.44722 .59471 m .44741 .59482 L .44745 .59464 L .641 .739 .92 r
F
.44743 .59454 m .44697 .62813 L .44733 .59461 L .387 .212 .518 r
F
.44797 .59408 m .448 .59404 L .44794 .59599 L .095 0 .426 r
F
.44634 .58756 m .44639 .58901 L .44653 .58754 L .667 .747 .91 r
F
.44521 .58548 m .44781 .58703 L .44799 .5868 L .642 .739 .919 r
F
.44519 .5858 m .44797 .58672 L .44512 .58573 L .667 .747 .91 r
F
.44533 .58598 m .44738 .58714 L .44519 .5858 L F
.44533 .58598 m .44669 .58743 L .44731 .58719 L F
.44521 .58548 m .44576 .58649 L .44707 .58731 L .642 .739 .919 r
F
.44667 .58744 m .44658 .58747 L .44667 .58743 L .539 .332 .549 r
F
.44636 .5872 m .44662 .58745 L .44533 .58598 L .667 .747 .91 r
F
.44662 .58745 m .44669 .58743 L .44533 .58598 L F
.44667 .58743 m .44667 .58744 L .44667 .58743 L .539 .332 .549 r
F
.44576 .58649 m .44658 .58747 L .44707 .58731 L .642 .739 .919 r
F
.44649 .5875 m .44649 .5875 L .44649 .5875 L .539 .332 .549 r
F
.4464 .58752 m .4464 .58753 L .44634 .58754 L F
.4464 .58753 m .44634 .58756 L .44634 .58754 L F
.44634 .58754 m .44634 .58756 L .44634 .58756 L F
.4448 .58568 m .44634 .58756 L .4465 .5875 L .667 .747 .91 r
F
.44521 .58548 m .44707 .58731 L .44787 .58706 L .642 .739 .919 r
F
.44574 .58369 m .44785 .58269 L .44638 .58234 L .667 .747 .91 r
F
.44671 .58377 m .44785 .58269 L .44574 .58369 L F
.44735 .58123 m .44802 .58162 L .4477 .58104 L F
.448 .58163 m .44802 .58162 L .44735 .58123 L F
.4477 .58104 m .44997 .58099 L .44913 .58023 L F
.44802 .58162 m .44997 .58099 L .4477 .58104 L F
.44997 .58099 m .45003 .5809 L .44913 .58023 L F
.44837 .57913 m .44859 .57953 L .44865 .57908 L .668 .747 .91 r
F
.44857 .57967 m .45089 .57967 L .44865 .57908 L F
.44867 .57967 m .45068 .58056 L .45089 .57967 L F
.44857 .57967 m .4487 .57972 L .44867 .57967 L F
.4487 .57972 m .45068 .58056 L .44867 .57967 L F
.45068 .58056 m .45694 .57968 L .45089 .57967 L F
.45089 .57967 m .45694 .57968 L .45654 .5779 L F
.45089 .57967 m .45654 .5779 L .45068 .57878 L F
.45068 .57878 m .45534 .57623 L .45008 .57795 L F
.45068 .57878 m .45654 .5779 L .45534 .57623 L F
.45008 .57795 m .45534 .57623 L .45341 .5748 L F
.4501 .58095 m .45345 .57778 L .44913 .58023 L .667 .747 .91 r
F
.45534 .57623 m .45772 .57236 L .45341 .5748 L .668 .747 .91 r
F
.45534 .57623 m .4606 .57451 L .45772 .57236 L F
.44913 .58023 m .45092 .57667 L .44786 .57967 L .667 .747 .91 r
F
.44913 .58023 m .45345 .57778 L .45092 .57667 L F
.45341 .5748 m .45395 .57069 L .4509 .57369 L .668 .747 .91 r
F
.45341 .5748 m .45772 .57236 L .45395 .57069 L F
.45694 .57968 m .4624 .57702 L .45654 .5779 L F
.45654 .5779 m .4606 .57451 L .45534 .57623 L F
.45654 .5779 m .4624 .57702 L .4606 .57451 L F
.46068 .5775 m .46068 .57449 L .45779 .57232 L .914 .65 .523 r
F
.44997 .58099 m .4501 .58095 L .45003 .5809 L .667 .747 .91 r
F
.44831 .58214 m .44879 .58267 L .44926 .582 L F
.44861 .58267 m .44879 .58267 L .44831 .58214 L F
.44879 .58267 m .45091 .58268 L .44926 .582 L F
.44861 .58267 m .44869 .58281 L .44879 .58267 L F
.45068 .58056 m .45652 .58146 L .45694 .57968 L .668 .747 .91 r
F
.4507 .58178 m .45538 .57922 L .4501 .58095 L .667 .747 .91 r
F
.4501 .58095 m .45538 .57922 L .45345 .57778 L F
.44912 .58324 m .45091 .57969 L .44785 .58269 L F
.44953 .58267 m .4507 .58357 L .45091 .58268 L F
.44871 .58326 m .4507 .58357 L .44953 .58267 L F
.45091 .58268 m .4566 .5809 L .4507 .58178 L F
.4507 .58178 m .4566 .5809 L .45538 .57922 L F
.44912 .58324 m .45344 .5808 L .45091 .57969 L F
.4509 .57369 m .45395 .57069 L .44954 .56964 L .668 .747 .91 r
F
.44785 .58269 m .44796 .57899 L .44638 .58234 L .667 .747 .91 r
F
.44785 .58269 m .45091 .57969 L .44796 .57899 L F
.45345 .57778 m .45399 .57366 L .45092 .57667 L F
.45345 .57778 m .45778 .57533 L .45399 .57366 L F
.46068 .5775 m .45779 .57232 L .45778 .57533 L .914 .65 .523 r
F
.45778 .57533 m .45779 .57232 L .45399 .57065 L .846 .589 .55 r
F
.45092 .57667 m .45399 .57366 L .44956 .57261 L .667 .747 .91 r
F
.45538 .57922 m .45778 .57533 L .45345 .57778 L F
.45344 .5808 m .45398 .57668 L .45091 .57969 L F
.45652 .58146 m .463 .57969 L .45694 .57968 L .668 .747 .91 r
F
.45694 .57968 m .463 .57969 L .4624 .57702 L F
.4566 .5809 m .46068 .5775 L .45538 .57922 L .667 .747 .91 r
F
.45538 .57922 m .46068 .5775 L .45778 .57533 L F
.45344 .5808 m .45778 .57835 L .45398 .57668 L F
.45778 .57533 m .45399 .57065 L .45399 .57366 L .846 .589 .55 r
F
.45778 .57835 m .45778 .57533 L .45399 .57366 L F
.45399 .57366 m .45399 .57065 L .44957 .56959 L .786 .538 .561 r
F
.45091 .57969 m .44955 .57563 L .44796 .57899 L .667 .747 .91 r
F
.45091 .57969 m .45398 .57668 L .44955 .57563 L F
.45399 .57366 m .44957 .56959 L .44956 .57261 L .786 .538 .561 r
F
.45778 .57835 m .45399 .57366 L .45398 .57668 L .846 .589 .55 r
F
.45398 .57668 m .45399 .57366 L .44956 .57261 L .786 .538 .561 r
F
.45398 .57668 m .44956 .57261 L .44955 .57563 L F
.44602 .58387 m .46051 .57184 L .4531 .56977 L .642 .739 .919 r
F
.44521 .58548 m .44675 .5841 L .44602 .58387 L F
.44655 .58389 m .44654 .58404 L .44675 .58395 L .799 .548 .56 r
F
.44654 .58404 m .44674 .5841 L .44675 .58395 L F
.4482 .59365 m .4482 .59369 L .44836 .5863 L 0 0 .082 r
F
.44836 .5863 m .4482 .59369 L .44818 .5938 L F
.44839 .58608 m .44822 .59351 L .44838 .5862 L F
.44822 .59351 m .44821 .59361 L .44838 .5862 L F
.44838 .5862 m .44821 .59361 L .44837 .58626 L F
.44821 .59361 m .4482 .59365 L .44837 .58626 L F
.45236 .59255 m .4536 .59473 L .45442 .59459 L .642 .739 .919 r
F
.44958 .5935 m .46297 .59679 L .45334 .59375 L .641 .739 .92 r
F
.44828 .5852 m .44797 .58484 L .44828 .58538 L .993 .743 .421 r
F
.44521 .58548 m .44849 .58517 L .44788 .58478 L .642 .739 .919 r
F
.44781 .58455 m .4478 .58473 L .4479 .5846 L .889 .63 .539 r
F
.44521 .58548 m .44788 .58478 L .44734 .58443 L .642 .739 .919 r
F
.4478 .58473 m .44746 .59213 L .44789 .58479 L .889 .63 .539 r
F
.4478 .58473 m .44789 .58479 L .4479 .5846 L F
.44761 .58442 m .44691 .58399 L .44691 .58415 L F
.44748 .58434 m .44797 .58465 L .44773 .58422 L .667 .747 .91 r
F
.44765 .58407 m .44858 .58445 L .4487 .58348 L F
.44797 .58465 m .44858 .58445 L .44765 .58407 L F
.44858 .58445 m .45009 .58396 L .4487 .58348 L F
.45531 .58311 m .46236 .58236 L .45652 .58146 L .668 .747 .91 r
F
.46245 .58537 m .46244 .58237 L .46309 .57969 L 0 0 .231 r
F
.45652 .58146 m .46236 .58236 L .463 .57969 L .668 .747 .91 r
F
.46245 .58537 m .46309 .57969 L .46309 .5827 L 0 0 .231 r
F
.45531 .58311 m .46053 .58483 L .46236 .58236 L .668 .747 .91 r
F
.4507 .58357 m .45658 .58447 L .457 .58269 L .667 .747 .91 r
F
.45009 .5844 m .45658 .58447 L .4507 .58357 L F
.46309 .5827 m .46309 .57969 L .46249 .577 L .916 .708 .212 r
F
.4507 .58357 m .457 .58269 L .45091 .58268 L .667 .747 .91 r
F
.46309 .5827 m .46249 .577 L .46249 .58001 L .916 .708 .212 r
F
.46245 .58838 m .46245 .58537 L .46309 .5827 L 0 0 .231 r
F
.45658 .58447 m .46245 .58537 L .46309 .5827 L .667 .747 .91 r
F
.45658 .58447 m .46309 .5827 L .457 .58269 L F
.46245 .58838 m .46309 .5827 L .4631 .58571 L 0 0 .231 r
F
.457 .58269 m .46309 .5827 L .46249 .58001 L .667 .747 .91 r
F
.4631 .58571 m .46309 .5827 L .46249 .58001 L .916 .708 .212 r
F
.457 .58269 m .46249 .58001 L .4566 .5809 L .667 .747 .91 r
F
.45091 .58268 m .457 .58269 L .4566 .5809 L F
.46249 .58001 m .46249 .577 L .46068 .57449 L .982 .719 .449 r
F
.4631 .58571 m .46249 .58001 L .4625 .58303 L .916 .708 .212 r
F
.4566 .5809 m .46249 .58001 L .46068 .5775 L .667 .747 .91 r
F
.4507 .5848 m .45538 .58224 L .45009 .58396 L F
.4507 .5848 m .45659 .58391 L .45538 .58224 L F
.46249 .58001 m .46068 .57449 L .46068 .5775 L .982 .719 .449 r
F
.4625 .58303 m .46249 .58001 L .46068 .5775 L F
.45659 .58391 m .46069 .58052 L .45538 .58224 L .667 .747 .91 r
F
.45659 .58391 m .4625 .58303 L .46069 .58052 L F
.45009 .58396 m .45344 .5808 L .44912 .58324 L F
.45009 .58396 m .45538 .58224 L .45344 .5808 L F
.4625 .58303 m .46068 .5775 L .46069 .58052 L .982 .719 .449 r
F
.45538 .58224 m .45778 .57835 L .45344 .5808 L .667 .747 .91 r
F
.45538 .58224 m .46069 .58052 L .45778 .57835 L F
.46069 .58052 m .46068 .5775 L .45778 .57533 L .914 .65 .523 r
F
.46069 .58052 m .45778 .57533 L .45778 .57835 L F
.44734 .58443 m .47168 .57857 L .46685 .57485 L .642 .739 .919 r
F
.44746 .59213 m .44753 .59218 L .4479 .5846 L .889 .63 .539 r
F
.44797 .58465 m .45011 .58488 L .44858 .58445 L .667 .747 .91 r
F
.44867 .58508 m .45011 .58488 L .44797 .58465 L F
.44946 .58419 m .44973 .58467 L .45009 .5844 L F
.44858 .58445 m .4507 .5848 L .45009 .58396 L F
.45011 .58488 m .4507 .5848 L .44858 .58445 L F
.44461 .59317 m .44872 .59398 L .4484 .59342 L .641 .739 .92 r
F
.44761 .58442 m .44729 .59202 L .44781 .58455 L .889 .63 .539 r
F
.44461 .59317 m .44958 .5935 L .44946 .59342 L .641 .739 .92 r
F
.44461 .59317 m .44678 .59496 L .4472 .59469 L F
.44638 .59497 m .4463 .6286 L .44633 .59498 L .539 .332 .549 r
F
.44561 .59521 m .44547 .59736 L .4462 .59641 L .641 .739 .92 r
F
.44615 .59504 m .4463 .6286 L .44531 .62896 L .539 .332 .549 r
F
.44633 .59498 m .4463 .6286 L .44615 .59504 L F
.44461 .59317 m .4465 .59502 L .44678 .59496 L .641 .739 .92 r
F
.44645 .59495 m .4463 .6286 L .44638 .59497 L .539 .332 .549 r
F
.4465 .59502 m .44652 .59512 L .44657 .59509 L .641 .739 .92 r
F
.4466 .5949 m .4463 .6286 L .44645 .59495 L .539 .332 .549 r
F
.44729 .59202 m .44746 .59213 L .44781 .58455 L .889 .63 .539 r
F
.44797 .58465 m .44759 .59221 L .44779 .59234 L F
.44461 .59317 m .44779 .59234 L .44715 .59193 L .641 .739 .92 r
F
.4479 .5846 m .44753 .59218 L .44797 .58465 L .889 .63 .539 r
F
.44828 .58538 m .44779 .59234 L .44804 .59279 L .993 .743 .421 r
F
.4448 .58568 m .44573 .58763 L .44634 .58756 L .667 .747 .91 r
F
.4448 .58568 m .44636 .5872 L .44533 .58598 L F
.4452 .58361 m .4531 .56977 L .44514 .56878 L .642 .739 .919 r
F
.44549 .58366 m .44549 .58377 L .4457 .58368 L .733 .492 .564 r
F
.44521 .58548 m .44602 .58387 L .44585 .58382 L .642 .739 .919 r
F
.44521 .58548 m .44585 .58382 L .4452 .58373 L F
.44546 .58706 m .44542 .58767 L .44573 .58763 L .667 .747 .91 r
F
.4448 .58568 m .44542 .58767 L .44546 .58706 L F
.4448 .58568 m .44481 .58775 L .44542 .58767 L F
.44521 .58548 m .44561 .58631 L .44576 .58649 L .642 .739 .919 r
F
.44521 .58548 m .44521 .58583 L .44561 .58631 L F
.44661 .58391 m .44764 .58406 L .44722 .58331 L .667 .747 .91 r
F
.44748 .58415 m .44764 .58406 L .44661 .58391 L F
.44764 .58406 m .4487 .58348 L .44722 .58331 L F
.44761 .58442 m .44691 .58415 L .44759 .58459 L .889 .63 .539 r
F
.44521 .58548 m .44752 .58434 L .44675 .5841 L .642 .739 .919 r
F
.44804 .59279 m .44811 .59292 L .44838 .58537 L .993 .743 .421 r
F
.44838 .58556 m .44812 .59293 L .44844 .58567 L F
.44812 .59293 m .44817 .59302 L .44845 .5855 L F
.44837 .58554 m .44811 .59292 L .44838 .58556 L F
.44811 .59292 m .44812 .59293 L .44839 .58539 L F
.44844 .58567 m .44817 .59302 L .44844 .58567 L F
.44817 .59302 m .44817 .59302 L .44844 .58567 L F
.44844 .58567 m .44817 .59302 L .44826 .59317 L F
.44461 .59317 m .44995 .59268 L .44839 .59219 L .641 .739 .92 r
F
.44675 .58395 m .4464 .59156 L .44678 .58395 L .799 .548 .56 r
F
.44462 .59514 m .44531 .62896 L .44376 .62912 L .651 .424 .562 r
F
.4449 .59512 m .44531 .62896 L .44462 .59514 L F
.44533 .59509 m .44615 .59504 L .44531 .62896 L F
.44461 .59317 m .44615 .59504 L .44643 .59495 L .641 .739 .92 r
F
.44533 .59509 m .44531 .62896 L .44509 .59511 L .651 .424 .562 r
F
.4464 .59156 m .44642 .59156 L .44678 .58395 L .799 .548 .56 r
F
.44691 .58399 m .44653 .5916 L .44673 .59166 L F
.44461 .59317 m .44642 .59156 L .44567 .59132 L .641 .739 .92 r
F
.44586 .5837 m .44547 .5913 L .44567 .59132 L .733 .492 .564 r
F
.44555 .59131 m .44567 .59132 L .44556 .59129 L .641 .739 .92 r
F
.44461 .59317 m .44567 .59132 L .44555 .59131 L F
.44461 .59317 m .44462 .59514 L .44555 .59508 L F
.44461 .59317 m .44555 .59508 L .44615 .59504 L F
.44678 .58395 m .44642 .59156 L .44691 .58399 L .799 .548 .56 r
F
.44761 .58442 m .44673 .59166 L .44729 .59202 L .889 .63 .539 r
F
.44461 .59317 m .44732 .59185 L .44642 .59156 L .641 .739 .92 r
F
.47186 .58739 m .49764 .59686 L .50388 .58937 L .643 .738 .918 r
F
.47186 .58739 m .50388 .58937 L .47492 .58361 L F
.45657 .58748 m .46245 .58838 L .4631 .58571 L .667 .747 .91 r
F
.45657 .58748 m .4631 .58571 L .457 .5857 L F
.44843 .58565 m .47454 .59129 L .47564 .58708 L .642 .739 .919 r
F
.44873 .58618 m .47454 .59129 L .44843 .58565 L F
.44915 .58692 m .47146 .59508 L .44873 .58618 L F
.49764 .59686 m .53268 .5951 L .50388 .58937 L .643 .738 .918 r
F
.47146 .59508 m .50371 .59706 L .47454 .59129 L .642 .739 .919 r
F
.45346 .59235 m .47512 .59477 L .47414 .59045 L .641 .739 .92 r
F
.44461 .59317 m .46969 .59449 L .45346 .59235 L F
.46969 .59449 m .47512 .59477 L .45346 .59235 L F
.4457 .58368 m .44534 .59128 L .44586 .5837 L .733 .492 .564 r
F
.44461 .59317 m .44563 .59116 L .44461 .59119 L .641 .739 .92 r
F
.44534 .59128 m .44375 .62496 L .44547 .5913 L .733 .492 .564 r
F
.44534 .59128 m .44547 .5913 L .44586 .5837 L F
.44642 .59156 m .44483 .62506 L .44653 .5916 L .799 .548 .56 r
F
.44642 .59156 m .44653 .5916 L .44691 .58399 L F
.44753 .59218 m .44759 .59221 L .44797 .58465 L .889 .63 .539 r
F
.457 .5857 m .4631 .58571 L .4625 .58303 L .667 .747 .91 r
F
.457 .5857 m .4625 .58303 L .45659 .58391 L F
.4509 .58569 m .457 .5857 L .45659 .58391 L F
.4509 .58569 m .45659 .58391 L .4507 .5848 L F
.44788 .58478 m .47467 .58274 L .47168 .57857 L .642 .739 .919 r
F
.44797 .58465 m .44797 .58465 L .44748 .58434 L .667 .747 .91 r
F
.44788 .58478 m .47168 .57857 L .44734 .58443 L .642 .739 .919 r
F
.44799 .58468 m .44797 .58484 L .44828 .5852 L .993 .743 .421 r
F
.44849 .58517 m .47467 .58274 L .44788 .58478 L .642 .739 .919 r
F
.44759 .58459 m .44691 .58415 L .44673 .59166 L .889 .63 .539 r
F
.44828 .58538 m .44797 .58484 L .44779 .59234 L .993 .743 .421 r
F
.44818 .5852 m .47564 .58708 L .47467 .58274 L .642 .739 .919 r
F
.44839 .58539 m .44838 .58556 L .44845 .5855 L .993 .743 .421 r
F
.44838 .58556 m .44844 .58567 L .44845 .5855 L F
.44838 .58537 m .44837 .58554 L .44839 .58539 L F
.44837 .58554 m .44838 .58556 L .44839 .58539 L F
.44845 .5855 m .44844 .58567 L .44844 .58567 L F
.44826 .58516 m .44845 .5855 L .44849 .58513 L .667 .747 .91 r
F
.44843 .58565 m .47564 .58708 L .44818 .5852 L .642 .739 .919 r
F
.44642 .59156 m .4663 .58257 L .45995 .57958 L .641 .739 .92 r
F
.44732 .59185 m .4663 .58257 L .44642 .59156 L F
.44567 .59132 m .44375 .62496 L .44483 .62506 L .733 .492 .564 r
F
.44547 .5913 m .44375 .62496 L .44567 .59132 L F
.44841 .58322 m .44871 .58326 L .44879 .58267 L .667 .747 .91 r
F
.4487 .58348 m .44874 .58308 L .44785 .58269 L F
.44675 .5841 m .44993 .58264 L .45118 .58015 L .642 .739 .919 r
F
.44993 .58264 m .46685 .57485 L .45118 .58015 L F
.45118 .58015 m .46685 .57485 L .46051 .57184 L F
.44733 .58425 m .4487 .58348 L .44731 .58424 L .667 .747 .91 r
F
.4475 .58415 m .44773 .58422 L .44765 .58407 L F
.4487 .58348 m .44912 .58324 L .44874 .58308 L F
.44752 .58434 m .46685 .57485 L .44675 .5841 L .642 .739 .919 r
F
.44654 .58404 m .44567 .59132 L .44623 .5915 L .799 .548 .56 r
F
.44653 .58403 m .44567 .59132 L .44654 .58404 L F
.44653 .58403 m .44585 .58382 L .44567 .59132 L F
.44655 .58389 m .44653 .58403 L .44654 .58404 L F
.44655 .58389 m .44585 .58382 L .44653 .58403 L F
.44675 .5841 m .46051 .57184 L .44602 .58387 L .642 .739 .919 r
F
.44654 .58404 m .44623 .5915 L .44674 .5841 L .799 .548 .56 r
F
.44667 .58744 m .44649 .5875 L .44658 .58747 L .539 .332 .549 r
F
.44623 .5915 m .4464 .59156 L .44675 .58395 L .799 .548 .56 r
F
.44556 .59129 m .45995 .57958 L .45252 .57751 L .641 .739 .92 r
F
.44642 .59156 m .45995 .57958 L .44556 .59129 L F
.44673 .59166 m .44483 .62506 L .4459 .62537 L .799 .548 .56 r
F
.44653 .5916 m .44483 .62506 L .44673 .59166 L F
.4464 .59156 m .44483 .62506 L .44642 .59156 L F
.44549 .58377 m .44517 .59126 L .44569 .5838 L .733 .492 .564 r
F
.44517 .59126 m .44534 .59128 L .4457 .58368 L F
.4448 .58568 m .44533 .58598 L .44519 .5858 L .667 .747 .91 r
F
.44549 .58377 m .44461 .59119 L .44517 .59126 L .733 .492 .564 r
F
.44563 .59116 m .45252 .57751 L .4447 .59102 L .641 .739 .92 r
F
.44517 .59117 m .4447 .59102 L .44461 .59119 L F
.44563 .59116 m .4447 .59102 L .44517 .59117 L F
.44549 .58377 m .44569 .5838 L .4457 .58368 L .733 .492 .564 r
F
.4452 .58373 m .44585 .58382 L .4452 .58361 L .642 .739 .919 r
F
.44602 .58387 m .4531 .56977 L .4452 .58361 L F
.44655 .58389 m .44586 .5837 L .44585 .58382 L .799 .548 .56 r
F
.44623 .5915 m .44567 .59132 L .44483 .62506 L F
.44839 .59219 m .47414 .59045 L .47114 .58628 L .641 .739 .92 r
F
.44995 .59268 m .47414 .59045 L .44839 .59219 L F
.44753 .59218 m .4459 .62537 L .44759 .59221 L .889 .63 .539 r
F
.4448 .58568 m .44505 .58564 L .44502 .58561 L .667 .747 .91 r
F
.4448 .58568 m .44502 .58561 L .445 .58558 L F
.44521 .58548 m .4451 .5857 L .44521 .58583 L .642 .739 .919 r
F
.4448 .58568 m .44508 .58568 L .44505 .58564 L .667 .747 .91 r
F
.4448 .58568 m .44512 .58573 L .44508 .58568 L F
.4448 .58568 m .44519 .5858 L .44512 .58573 L F
.44549 .58377 m .4448 .58368 L .44461 .59119 L .733 .492 .564 r
F
.4446 .59029 m .45252 .57751 L .44454 .57651 L .641 .739 .92 r
F
.44461 .59119 m .44498 .59054 L .4446 .59029 L F
.44498 .59054 m .45252 .57751 L .4446 .59029 L F
.46434 .58353 m .46726 .58331 L .4663 .58257 L F
.44715 .59193 m .46726 .58331 L .46434 .58353 L F
.44715 .59193 m .47114 .58628 L .46726 .58331 L F
.44779 .59234 m .47114 .58628 L .44715 .59193 L F
.44779 .59234 m .4459 .62537 L .44697 .62605 L .889 .63 .539 r
F
.44759 .59221 m .4459 .62537 L .44779 .59234 L F
.44729 .59202 m .4459 .62537 L .44746 .59213 L F
.44946 .59342 m .47501 .59519 L .46969 .59449 L .641 .739 .92 r
F
.44958 .5935 m .47501 .59519 L .44946 .59342 L F
.44797 .59408 m .44737 .62758 L .44791 .59416 L .095 0 .426 r
F
.44791 .59416 m .44737 .62758 L .4479 .59417 L F
.44804 .59279 m .44779 .59234 L .44697 .62605 L .993 .743 .421 r
F
.4484 .59342 m .45103 .59443 L .44958 .5935 L .641 .739 .92 r
F
.44872 .59398 m .45103 .59443 L .4484 .59342 L F
.45103 .59443 m .46297 .59679 L .44958 .5935 L F
.44729 .59202 m .44673 .59166 L .4459 .62537 L .889 .63 .539 r
F
.44623 .5915 m .44483 .62506 L .4464 .59156 L .799 .548 .56 r
F
.47146 .59508 m .49742 .60457 L .50371 .59706 L .642 .739 .919 r
F
.45334 .59375 m .47401 .59897 L .47501 .59519 L .641 .739 .92 r
F
.46297 .59679 m .47401 .59897 L .45334 .59375 L F
.46969 .59449 m .47501 .59519 L .47512 .59477 L F
.44517 .59126 m .44375 .62496 L .44534 .59128 L .733 .492 .564 r
F
.448 .59404 m .44818 .5938 L .44794 .59599 L .095 0 .426 r
F
.44794 .59599 m .44818 .5938 L .44737 .62758 L F
.44804 .59279 m .44697 .62605 L .44811 .59292 L .993 .743 .421 r
F
.44872 .59398 m .44921 .59484 L .45211 .59465 L .641 .739 .92 r
F
.44921 .59484 m .47092 .60274 L .45211 .59465 L F
.44517 .59126 m .44461 .59119 L .44375 .62496 L .733 .492 .564 r
F
.44461 .59119 m .44454 .57651 L .44366 .59121 L .641 .739 .92 r
F
.44366 .59121 m .43656 .57666 L .44266 .59124 L F
.44441 .59119 m .44268 .62503 L .44441 .59119 L .667 .437 .562 r
F
.44324 .59128 m .44161 .62531 L .44335 .59126 L .585 .37 .555 r
F
.4419 .59156 m .44266 .59124 L .44141 .59127 L .641 .739 .92 r
F
.44279 .59137 m .44266 .59124 L .4419 .59156 L F
.44266 .59124 m .42915 .57795 L .44141 .59127 L F
.44461 .59119 m .44268 .62503 L .44375 .62496 L .667 .437 .562 r
F
.44441 .59119 m .44268 .62503 L .44461 .59119 L F
.44355 .59121 m .44161 .62531 L .44268 .62503 L .585 .37 .555 r
F
.44335 .59126 m .44161 .62531 L .44355 .59121 L F
.44084 .59179 m .44141 .59127 L .43956 .59133 L .641 .739 .92 r
F
.4419 .59156 m .44141 .59127 L .44084 .59179 L F
.44141 .59127 m .42283 .58028 L .43956 .59133 L F
.44435 .59119 m .44268 .62503 L .44441 .59119 L .667 .437 .562 r
F
.44306 .59132 m .44161 .62531 L .44314 .5913 L .585 .37 .555 r
F
.442 .5917 m .44055 .62595 L .44216 .59162 L .428 .243 .527 r
F
.43978 .59291 m .43774 .59245 L .43639 .59273 L .641 .739 .92 r
F
.44017 .5927 m .43774 .59245 L .43978 .59291 L F
.43774 .59245 m .41446 .59001 L .43639 .59273 L F
.44306 .59132 m .44249 .59144 L .44161 .62531 L .585 .37 .555 r
F
.44219 .5916 m .44055 .62595 L .4423 .59154 L .428 .243 .527 r
F
.44017 .5927 m .43899 .59218 L .43774 .59245 L .641 .739 .92 r
F
.4406 .59246 m .43899 .59218 L .44017 .5927 L F
.43899 .59218 m .43483 .59146 L .43774 .59245 L F
.44314 .5913 m .44161 .62531 L .44322 .59128 L .585 .37 .555 r
F
.44249 .59144 m .44055 .62595 L .44161 .62531 L .428 .243 .527 r
F
.4423 .59154 m .44055 .62595 L .44249 .59144 L F
.44322 .59128 m .44161 .62531 L .44324 .59128 L .585 .37 .555 r
F
.43899 .59218 m .43581 .59143 L .43483 .59146 L .641 .739 .92 r
F
.4393 .59212 m .43581 .59143 L .43899 .59218 L F
.43704 .59237 m .43483 .59146 L .42966 .5916 L F
.44428 .59119 m .44268 .62503 L .44435 .59119 L .667 .437 .562 r
F
.41591 .5882 m .38678 .5909 L .39313 .59907 L .642 .739 .919 r
F
.42966 .5916 m .41505 .58733 L .41446 .59001 L .641 .739 .92 r
F
.43581 .59143 m .41505 .58733 L .42966 .5916 L F
.4278 .59228 m .41446 .59001 L .41411 .59156 L F
.43719 .57627 m .43558 .57655 L .43558 .57665 L .605 .389 .562 r
F
.43558 .57665 m .43558 .57655 L .43545 .5766 L .516 .318 .55 r
F
.43999 .59292 m .41411 .59156 L .4408 .59352 L .641 .739 .92 r
F
.44216 .59162 m .44055 .62595 L .44219 .5916 L .428 .243 .527 r
F
.44132 .5922 m .44018 .62661 L .44137 .59212 L 0 0 .377 r
F
.44144 .59201 m .44018 .62661 L .44069 .62034 L F
.44137 .59212 m .44018 .62661 L .44144 .59201 L F
.43913 .59584 m .43303 .59657 L .42326 .6036 L .641 .739 .92 r
F
.43962 .59504 m .43303 .59657 L .43913 .59584 L F
.43303 .59657 m .41838 .59997 L .42192 .6026 L F
.43303 .59657 m .42192 .6026 L .42326 .6036 L F
.442 .5917 m .44144 .59201 L .44055 .62595 L .428 .243 .527 r
F
.441 .59309 m .44015 .62747 L .44099 .59299 L .868 .695 .169 r
F
.441 .59309 m .44105 .59343 L .44015 .62747 L F
.44099 .59299 m .44015 .62747 L .44098 .59291 L F
.44097 .59279 m .44015 .62747 L .44007 .6268 L F
.44098 .59291 m .44015 .62747 L .44097 .59279 L F
.44129 .59225 m .44007 .6268 L .4413 .59223 L 0 0 .377 r
F
.44132 .5922 m .44007 .6268 L .44018 .62661 L F
.4413 .59223 m .44007 .6268 L .44132 .5922 L F
.44122 .59237 m .44097 .59279 L .44007 .6268 L F
.43576 .60145 m .42957 .6065 L .43228 .60724 L .641 .739 .92 r
F
.43576 .60145 m .43228 .60724 L .43687 .6085 L F
.44122 .59237 m .44007 .6268 L .44129 .59225 L 0 0 .377 r
F
.44812 .59293 m .44697 .62605 L .44817 .59302 L .993 .743 .421 r
F
.44922 .59484 m .46742 .60498 L .45486 .5969 L .641 .739 .92 r
F
.44979 .59585 m .46742 .60498 L .44922 .59484 L F
.44822 .59351 m .44826 .59317 L .44745 .62691 L 0 0 .082 r
F
.44811 .59292 m .44697 .62605 L .44812 .59293 L .993 .743 .421 r
F
.44979 .59585 m .46607 .60585 L .46742 .60498 L .641 .739 .92 r
F
.45012 .59642 m .46607 .60585 L .44979 .59585 L F
.45486 .5969 m .46742 .60498 L .47092 .60274 L F
.44746 .59213 m .4459 .62537 L .44753 .59218 L .889 .63 .539 r
F
.4482 .59365 m .44745 .62691 L .4482 .59369 L 0 0 .082 r
F
.44818 .5938 m .44745 .62691 L .44737 .62758 L F
.4482 .59369 m .44745 .62691 L .44818 .5938 L F
.45295 .60137 m .45979 .60809 L .45012 .59642 L .641 .739 .92 r
F
.44817 .59302 m .44697 .62605 L .44817 .59302 L .993 .743 .421 r
F
.44822 .59351 m .44745 .62691 L .44821 .59361 L 0 0 .082 r
F
.44821 .59361 m .44745 .62691 L .4482 .59365 L F
.44826 .59317 m .44697 .62605 L .44745 .62691 L .993 .743 .421 r
F
.44817 .59302 m .44697 .62605 L .44826 .59317 L F
.45295 .60137 m .45706 .60855 L .45979 .60809 L .641 .739 .92 r
F
.44069 .62034 m .44018 .62661 L .44055 .62595 L 0 0 .377 r
F
.49742 .60457 m .53272 .60281 L .50371 .59706 L .642 .739 .919 r
F
.35392 .58067 m .3586 .58598 L .35782 .59359 L .986 .796 .4 r
F
.35392 .58067 m .35471 .57302 L .3586 .58598 L F
0 g
.3586 .58598 m
.36416 .593 L
s
.38537 .57464 m .35903 .58594 L .38779 .58325 L .643 .738 .918 r
F
.38537 .57464 m .35516 .57305 L .35903 .58594 L F
.53272 .60281 m .53312 .59518 L .53691 .58263 L 0 0 .199 r
F
0 g
.52747 .60177 m
.53312 .59518 L
s
.50388 .58937 m .53268 .5951 L .53646 .5826 L .643 .738 .918 r
F
.41526 .59587 m .39243 .6067 L .41838 .59997 L .641 .739 .92 r
F
.41526 .59587 m .38607 .59856 L .39243 .6067 L F
.49695 .61222 m .53232 .61047 L .50325 .60474 L F
.47092 .60274 m .49695 .61222 L .50325 .60474 L F
.46607 .60585 m .49695 .61222 L .47092 .60274 L F
.35312 .58834 m .35782 .59359 L .35704 .60123 L .986 .796 .4 r
F
.35312 .58834 m .35392 .58067 L .35782 .59359 L F
.38435 .58227 m .35782 .59359 L .38678 .5909 L .642 .739 .919 r
F
.38435 .58227 m .35392 .58067 L .35782 .59359 L F
0 g
.35782 .59359 m
.36344 .60064 L
s
.53272 .60281 m .53691 .58263 L .53652 .59029 L 0 0 .199 r
F
.53232 .61047 m .53272 .60281 L .53652 .59029 L F
.50371 .59706 m .53272 .60281 L .53652 .59029 L .642 .739 .919 r
F
0 g
.52702 .60943 m
.53272 .60281 L
s
.41559 .57623 m .38537 .57464 L .38779 .58325 L .643 .738 .918 r
F
.50388 .58937 m .53646 .5826 L .50624 .58101 L F
.47492 .58361 m .50388 .58937 L .50624 .58101 L F
0 g
.44853 .56151 m
.44995 .50311 L
s
.44224 .56123 m
.44377 .50301 L
s
.38362 .58995 m .35704 .60123 L .38607 .59856 L .641 .739 .92 r
F
.38362 .58995 m .35312 .58834 L .35704 .60123 L F
0 g
.35704 .60123 m
.36677 .61336 L
s
.44795 .5854 m
.44795 .5854 L
s
.53232 .61047 m .53652 .59029 L .53613 .59799 L 0 0 .199 r
F
.50325 .60474 m .53232 .61047 L .53613 .59799 L .641 .739 .92 r
F
0 g
.5227 .62159 m
.53232 .61047 L
s
.41478 .58387 m .38435 .58227 L .38678 .5909 L .642 .739 .919 r
F
.50371 .59706 m .53652 .59029 L .50608 .58869 L F
.47454 .59129 m .50371 .59706 L .50608 .58869 L F
.47492 .58361 m .50624 .58101 L .47602 .57942 L .643 .738 .918 r
F
.4426 .69854 m .44242 .69248 L .46128 .69083 L .678 .467 .593 r
F
.42369 .69789 m .44242 .69248 L .4426 .69854 L .731 .51 .591 r
F
.42369 .69789 m .42354 .69181 L .44242 .69248 L F
.44238 .68096 m .44242 .69231 L .46119 .69067 L .654 .782 .942 r
F
.42975 .68051 m .44242 .69231 L .44238 .68096 L F
.42975 .68051 m .42363 .69165 L .44242 .69231 L F
.46149 .69689 m .46128 .69083 L .47893 .68697 L .618 .42 .592 r
F
.4426 .69854 m .46128 .69083 L .46149 .69689 L .678 .467 .593 r
F
0 g
.44242 .69248 m
.46128 .69083 L
s
.455 .67985 m .46119 .69067 L .47875 .68682 L .654 .782 .942 r
F
.44238 .68096 m .46119 .69067 L .455 .67985 L F
.41411 .59156 m .38607 .59856 L .41526 .59587 L .641 .739 .92 r
F
.41411 .59156 m .38362 .58995 L .38607 .59856 L F
.50325 .60474 m .53613 .59799 L .50562 .59638 L F
.47401 .59897 m .50325 .60474 L .50562 .59638 L F
.47092 .60274 m .50325 .60474 L .47401 .59897 L F
.40595 .69496 m .42354 .69181 L .42369 .69789 L .783 .551 .585 r
F
.40595 .69496 m .40582 .68887 L .42354 .69181 L F
0 g
.42354 .69181 m
.44242 .69248 L
s
.41792 .67852 m .42363 .69165 L .42975 .68051 L .654 .782 .942 r
F
.41792 .67852 m .406 .68872 L .42363 .69165 L F
.44278 .70462 m .4426 .69854 L .46149 .69689 L .678 .467 .593 r
F
.42384 .70398 m .4426 .69854 L .44278 .70462 L .731 .51 .591 r
F
.42384 .70398 m .42369 .69789 L .4426 .69854 L F
.44256 .68718 m .4426 .69854 L .46149 .69689 L .654 .783 .943 r
F
.42985 .68673 m .4426 .69854 L .44256 .68718 L F
.42985 .68673 m .42369 .69789 L .4426 .69854 L F
.47454 .59129 m .50608 .58869 L .47564 .58708 L .642 .739 .919 r
F
.46149 .69689 m .47893 .68697 L .47917 .69304 L .618 .42 .592 r
F
.4617 .70298 m .46149 .69689 L .47917 .69304 L F
.44278 .70462 m .46149 .69689 L .4617 .70298 L .678 .467 .593 r
F
.45527 .68606 m .46149 .69689 L .47917 .69304 L .654 .783 .943 r
F
.44256 .68718 m .46149 .69689 L .45527 .68606 L F
0 g
.4426 .69854 m
.46149 .69689 L
s
.38707 .56615 m .35516 .57305 L .38537 .57464 L .643 .738 .918 r
F
.38707 .56615 m .35746 .56026 L .35516 .57305 L F
.35622 .56785 m .35471 .57302 L .35392 .58067 L 0 0 .004 r
F
0 g
.35507 .57424 m
.35705 .58083 L
s
.35622 .56785 m .35701 .56018 L .35471 .57302 L 0 0 .004 r
F
.41652 .572 m .38537 .57464 L .41559 .57623 L .643 .738 .918 r
F
.41652 .572 m .38707 .56615 L .38537 .57464 L F
.47602 .57942 m .50447 .57234 L .47505 .57509 L F
.47602 .57942 m .50624 .58101 L .50447 .57234 L F
.50624 .58101 m .53406 .56957 L .50447 .57234 L F
.50624 .58101 m .53646 .5826 L .53406 .56957 L F
.53652 .59029 m .53691 .58263 L .53451 .56953 L .924 .743 .257 r
F
0 g
.53462 .59019 m
.53605 .58546 L
s
.40607 .70106 m .42369 .69789 L .42384 .70398 L .783 .551 .585 r
F
.40607 .70106 m .40595 .69496 L .42369 .69789 L F
.41794 .68474 m .42369 .69789 L .42985 .68673 L .654 .783 .943 r
F
.41794 .68474 m .40595 .69496 L .42369 .69789 L F
0 g
.42369 .69789 m
.4426 .69854 L
s
.47917 .69304 m .47893 .68697 L .49425 .68112 L .54 .36 .586 r
F
0 g
.46717 .68954 m
.47893 .68697 L
s
.4668 .67725 m .47875 .68682 L .49399 .68101 L .654 .782 .942 r
F
.455 .67985 m .47875 .68682 L .4668 .67725 L F
.44274 .6933 m .44278 .70462 L .4617 .70298 L .653 .784 .944 r
F
.43001 .69285 m .44278 .70462 L .44274 .6933 L F
.43001 .69285 m .42384 .70398 L .44278 .70462 L F
.599 .57872 m .59925 .57108 L .62305 .57062 L .674 .451 .574 r
F
.57547 .57578 m .59925 .57108 L .599 .57872 L .73 .499 .576 r
F
.57547 .57578 m .57578 .56812 L .59925 .57108 L F
.4617 .70298 m .47917 .69304 L .4794 .69913 L .618 .42 .592 r
F
.45547 .69219 m .4617 .70298 L .4794 .69913 L .653 .784 .944 r
F
.44274 .6933 m .4617 .70298 L .45547 .69219 L F
0 g
.44278 .70462 m
.4617 .70298 L
s
.6009 .55406 m .59927 .57083 L .62296 .57037 L .644 .737 .917 r
F
.58516 .55207 m .59927 .57083 L .6009 .55406 L F
.58516 .55207 m .57591 .56789 L .59927 .57083 L F
.47401 .59897 m .50562 .59638 L .47512 .59477 L .641 .739 .92 r
F
.38605 .57376 m .35392 .58067 L .38435 .58227 L .642 .739 .919 r
F
.38605 .57376 m .35622 .56785 L .35392 .58067 L F
.35543 .57557 m .35392 .58067 L .35312 .58834 L 0 0 .004 r
F
0 g
.35429 .58189 m
.35629 .58851 L
s
.35543 .57557 m .35622 .56785 L .35392 .58067 L 0 0 .004 r
F
.39051 .68992 m .40582 .68887 L .40595 .69496 L .839 .598 .574 r
F
.39051 .68992 m .39041 .68382 L .40582 .68887 L F
0 g
.40582 .68887 m
.4119 .68988 L
s
.41809 .69087 m .42384 .70398 L .43001 .69285 L .653 .784 .944 r
F
.41809 .69087 m .40607 .70106 L .42384 .70398 L F
0 g
.42384 .70398 m
.44278 .70462 L
s
.47917 .69304 m .49425 .68112 L .49451 .68721 L .54 .36 .586 r
F
.4794 .69913 m .47917 .69304 L .49451 .68721 L F
.46714 .68346 m .47917 .69304 L .49451 .68721 L .654 .783 .943 r
F
.45527 .68606 m .47917 .69304 L .46714 .68346 L F
0 g
.46731 .69562 m
.47917 .69304 L
s
.41571 .57964 m .38435 .58227 L .41478 .58387 L .642 .739 .919 r
F
.41571 .57964 m .38605 .57376 L .38435 .58227 L F
.40767 .67511 m .406 .68872 L .41792 .67852 L .654 .782 .942 r
F
.40767 .67511 m .39067 .68369 L .406 .68872 L F
.47564 .58708 m .50431 .57999 L .47467 .58274 L .642 .739 .919 r
F
.47564 .58708 m .50608 .58869 L .50431 .57999 L F
.50608 .58869 m .53411 .57723 L .50431 .57999 L F
.50608 .58869 m .53652 .59029 L .53411 .57723 L F
.55373 .5696 m .57578 .56812 L .57547 .57578 L .787 .547 .574 r
F
.55373 .5696 m .55409 .56194 L .57578 .56812 L F
0 g
.57578 .56812 m
.59925 .57108 L
s
.53652 .59029 m .53451 .56953 L .53411 .57723 L .924 .743 .257 r
F
.53613 .59799 m .53652 .59029 L .53411 .57723 L F
0 g
.53421 .59789 m
.53566 .59314 L
s
.62285 .57827 m .62305 .57062 L .64572 .56676 L .61 .398 .569 r
F
.599 .57872 m .62305 .57062 L .62285 .57827 L .674 .451 .574 r
F
0 g
.59925 .57108 m
.62305 .57062 L
s
.57065 .54789 m .57591 .56789 L .58516 .55207 L .644 .737 .917 r
F
.57065 .54789 m .55433 .56173 L .57591 .56789 L F
.61686 .55374 m .62296 .57037 L .64552 .56653 L F
.6009 .55406 m .62296 .57037 L .61686 .55374 L F
.41946 .56815 m .38707 .56615 L .41652 .572 L .643 .738 .918 r
F
.47505 .57509 m .49865 .56395 L .47208 .57092 L F
.47505 .57509 m .50447 .57234 L .49865 .56395 L F
.59874 .58641 m .599 .57872 L .62285 .57827 L .674 .451 .574 r
F
.57516 .58346 m .599 .57872 L .59874 .58641 L .73 .499 .576 r
F
.57516 .58346 m .57547 .57578 L .599 .57872 L F
.60063 .56193 m .599 .57872 L .62285 .57827 L .643 .738 .918 r
F
.58478 .55993 m .599 .57872 L .60063 .56193 L F
.58478 .55993 m .57547 .57578 L .599 .57872 L F
.39061 .69605 m .40595 .69496 L .40607 .70106 L .839 .598 .574 r
F
.39061 .69605 m .39051 .68992 L .40595 .69496 L F
.40763 .68133 m .40595 .69496 L .41794 .68474 L .654 .783 .943 r
F
.40763 .68133 m .39051 .68992 L .40595 .69496 L F
0 g
.40595 .69496 m
.41207 .69597 L
s
.4794 .69913 m .49451 .68721 L .49477 .69332 L .54 .36 .586 r
F
.46736 .68959 m .4794 .69913 L .49477 .69332 L .653 .784 .944 r
F
.45547 .69219 m .4794 .69913 L .46736 .68959 L F
0 g
.4617 .70298 m
.4794 .69913 L
s
.38532 .58147 m .35312 .58834 L .38362 .58995 L .641 .739 .92 r
F
.38532 .58147 m .35543 .57557 L .35312 .58834 L F
0 g
.35312 .58834 m
.35704 .60123 L
s
.41505 .58733 m .38362 .58995 L .41411 .59156 L .641 .739 .92 r
F
.41505 .58733 m .38532 .58147 L .38362 .58995 L F
.47512 .59477 m .50384 .58771 L .47414 .59045 L F
.47512 .59477 m .50562 .59638 L .50384 .58771 L F
.50562 .59638 m .53371 .58497 L .50384 .58771 L F
.50562 .59638 m .53613 .59799 L .53371 .58497 L F
.55338 .57729 m .57547 .57578 L .57516 .58346 L .787 .547 .574 r
F
.55338 .57729 m .55373 .5696 L .57547 .57578 L F
.57017 .55573 m .57547 .57578 L .58478 .55993 L .643 .738 .918 r
F
.57017 .55573 m .55373 .5696 L .57547 .57578 L F
0 g
.57547 .57578 m
.599 .57872 L
s
.49451 .68721 m .49425 .68112 L .50622 .67365 L .423 .271 .569 r
F
0 g
.48258 .68558 m
.49425 .68112 L
s
.53613 .59799 m .53411 .57723 L .53371 .58497 L .924 .743 .257 r
F
0 g
.53232 .61047 m
.53613 .59799 L
s
.62285 .57827 m .64572 .56676 L .64557 .57444 L .61 .398 .569 r
F
.62265 .58596 m .62285 .57827 L .64557 .57444 L F
.59874 .58641 m .62285 .57827 L .62265 .58596 L .674 .451 .574 r
F
.6167 .56161 m .62285 .57827 L .64557 .57444 L .643 .738 .918 r
F
.60063 .56193 m .62285 .57827 L .6167 .56161 L F
0 g
.599 .57872 m
.62285 .57827 L
s
.477 .67333 m .49399 .68101 L .50591 .67357 L .654 .782 .942 r
F
.4668 .67725 m .49399 .68101 L .477 .67333 L F
.41867 .57578 m .38605 .57376 L .41571 .57964 L .642 .739 .919 r
F
.47467 .58274 m .49844 .57158 L .47168 .57857 L F
.47467 .58274 m .50431 .57999 L .49844 .57158 L F
.40776 .68748 m .40607 .70106 L .41809 .69087 L .653 .784 .944 r
F
.40776 .68748 m .39061 .69605 L .40607 .70106 L F
0 g
.40607 .70106 m
.42384 .70398 L
s
.41946 .56815 m .39283 .55837 L .38707 .56615 L .643 .738 .918 r
F
.42423 .56494 m .39283 .55837 L .41946 .56815 L F
.47208 .57092 m .48911 .55643 L .46729 .56721 L F
.47208 .57092 m .49865 .56395 L .48911 .55643 L F
.53515 .56055 m .55409 .56194 L .55373 .5696 L .847 .602 .567 r
F
.53515 .56055 m .53555 .55286 L .55409 .56194 L F
0 g
.55409 .56194 m
.56061 .5638 L
s
.39283 .55837 m .35746 .56026 L .38707 .56615 L .643 .738 .918 r
F
.60037 .56966 m .59874 .58641 L .62265 .58596 L .642 .738 .919 r
F
.58449 .56766 m .59874 .58641 L .60037 .56966 L F
.58449 .56766 m .57516 .58346 L .59874 .58641 L F
.64557 .57444 m .64572 .56676 L .66582 .55972 L .529 .332 .558 r
F
0 g
.63312 .5689 m
.64572 .56676 L
s
.55832 .54177 m .55433 .56173 L .57065 .54789 L .644 .737 .917 r
F
.55832 .54177 m .53589 .5527 L .55433 .56173 L F
.50447 .57234 m .52552 .55689 L .49865 .56395 L .643 .738 .918 r
F
.50447 .57234 m .53406 .56957 L .52552 .55689 L F
.63203 .55112 m .64552 .56653 L .66552 .55953 L .644 .737 .917 r
F
.61686 .55374 m .64552 .56653 L .63203 .55112 L F
.49451 .68721 m .50622 .67365 L .5065 .67976 L .423 .271 .569 r
F
.49477 .69332 m .49451 .68721 L .5065 .67976 L F
.4774 .67952 m .49451 .68721 L .5065 .67976 L .654 .783 .943 r
F
.46714 .68346 m .49451 .68721 L .4774 .67952 L F
0 g
.48274 .69168 m
.49451 .68721 L
s
.37842 .68308 m .39041 .68382 L .39051 .68992 L .905 .653 .548 r
F
.37842 .68308 m .37833 .67695 L .39041 .68382 L F
0 g
.39041 .68382 m
.39783 .68625 L
s
.56984 .56347 m .57516 .58346 L .58449 .56766 L .642 .738 .919 r
F
.56984 .56347 m .55338 .57729 L .57516 .58346 L F
0 g
.57516 .58346 m
.59874 .58641 L
s
.3997 .6705 m .39067 .68369 L .40767 .67511 L .654 .782 .942 r
F
.3997 .6705 m .37865 .67685 L .39067 .68369 L F
.62265 .58596 m .64557 .57444 L .64541 .58214 L .61 .398 .569 r
F
.61648 .56934 m .62265 .58596 L .64541 .58214 L .642 .738 .919 r
F
.60037 .56966 m .62265 .58596 L .61648 .56934 L F
0 g
.59874 .58641 m
.62265 .58596 L
s
.44481 .67144 m .44348 .68086 L .455 .67985 L .654 .782 .942 r
F
.44513 .66916 m .455 .67985 L .44871 .66885 L F
.44235 .66941 m .44481 .67144 L .44513 .66916 L F
.44481 .67144 m .455 .67985 L .44513 .66916 L F
.44737 .62758 m .44745 .62691 L .4467 .65794 L 0 0 .082 r
F
.44235 .66941 m .44238 .68096 L .44348 .68086 L .654 .782 .942 r
F
.44235 .66941 m .44348 .68086 L .44481 .67144 L F
.44253 .6756 m .44256 .68718 L .45527 .68606 L .654 .783 .943 r
F
.44253 .6756 m .45527 .68606 L .44894 .67504 L F
.44271 .68176 m .44274 .6933 L .45547 .69219 L .653 .784 .944 r
F
.44271 .68176 m .45547 .69219 L .44913 .6812 L F
.44222 .62891 m .44376 .62912 L .44299 .65999 L .747 .505 .564 r
F
.44439 .66129 m .44235 .66941 L .44871 .66885 L .654 .782 .942 r
F
.44392 .66047 m .44361 .66226 L .44439 .66129 L F
.44361 .66226 m .44235 .66941 L .44439 .66129 L F
.44531 .62896 m .44503 .65962 L .44455 .65979 L .539 .332 .549 r
F
.44222 .62891 m .44299 .65999 L .44217 .65993 L .747 .505 .564 r
F
.44376 .62912 m .44373 .65989 L .44299 .65999 L .651 .424 .562 r
F
.4463 .6286 m .44697 .62813 L .44622 .65902 L .387 .212 .518 r
F
.44536 .66009 m .44871 .66885 L .45339 .66781 L .654 .782 .942 r
F
.44536 .66009 m .45339 .66781 L .45148 .66499 L F
.4452 .66029 m .44871 .66885 L .44536 .66009 L F
.44496 .65981 m .44871 .66885 L .44499 .65979 L F
.44455 .65979 m .44871 .66885 L .44493 .65974 L F
.4436 .65991 m .4437 .66008 L .44455 .65979 L F
.4437 .66008 m .44871 .66885 L .44455 .65979 L F
.44531 .62896 m .4463 .6286 L .44554 .65944 L .539 .332 .549 r
F
.44499 .65979 m .4452 .66029 L .44536 .66009 L .654 .782 .942 r
F
.44531 .62896 m .44554 .65944 L .44503 .65962 L .539 .332 .549 r
F
.44376 .62912 m .44531 .62896 L .44455 .65979 L .651 .424 .562 r
F
.44376 .62912 m .44455 .65979 L .44373 .65989 L F
.4463 .6286 m .44587 .65924 L .44554 .65944 L .387 .212 .518 r
F
.44835 .66037 m .45465 .66753 L .45977 .66554 L .654 .782 .942 r
F
.44231 .65764 m .45148 .66499 L .44835 .66037 L F
.45148 .66499 m .45465 .66753 L .44835 .66037 L F
.44697 .62813 m .44737 .62758 L .44662 .65852 L .095 0 .426 r
F
.44697 .62813 m .44662 .65852 L .44641 .65878 L F
.4463 .6286 m .44622 .65902 L .44587 .65924 L .387 .212 .518 r
F
.44697 .62813 m .44641 .65878 L .44622 .65902 L .095 0 .426 r
F
.44737 .62758 m .4467 .65794 L .44666 .65824 L 0 0 .082 r
F
.44737 .62758 m .44666 .65824 L .44662 .65852 L F
.44745 .62691 m .44697 .62605 L .44621 .65722 L .993 .743 .421 r
F
.44231 .65764 m .45977 .66554 L .46112 .66467 L .654 .782 .942 r
F
.45181 .66002 m .46112 .66467 L .46372 .66301 L F
.44231 .65764 m .46112 .66467 L .45181 .66002 L F
.44503 .65962 m .44554 .65944 L .4454 .66534 L .539 .332 .549 r
F
.44435 .66705 m .44253 .6756 L .44894 .67504 L .654 .783 .943 r
F
.4437 .66593 m .44343 .66819 L .44435 .66705 L F
.44343 .66819 m .44253 .6756 L .44435 .66705 L F
.44828 .65826 m .46372 .66301 L .46623 .6601 L .654 .782 .942 r
F
.44231 .65764 m .45181 .66002 L .44828 .65826 L F
.45181 .66002 m .46372 .66301 L .44828 .65826 L F
.44697 .62605 m .4459 .62537 L .44513 .65668 L .889 .63 .539 r
F
.44587 .65924 m .44622 .65902 L .44608 .66491 L .387 .212 .518 r
F
.44745 .62691 m .44621 .65722 L .44647 .6576 L .993 .743 .421 r
F
.44745 .62691 m .44647 .6576 L .4467 .65794 L F
.44892 .65747 m .46623 .6601 L .46712 .65701 L .654 .782 .942 r
F
.44231 .65764 m .45685 .65914 L .44892 .65747 L F
.45685 .65914 m .46623 .6601 L .44892 .65747 L F
.44464 .66581 m .4449 .66637 L .44504 .66619 L .654 .783 .943 r
F
.44449 .66567 m .4439 .66628 L .44464 .66581 L F
.44362 .66066 m .44235 .66941 L .44392 .66047 L .654 .782 .942 r
F
.44373 .65989 m .44455 .65979 L .4444 .66568 L .651 .424 .562 r
F
.4437 .66008 m .44362 .66066 L .44392 .66047 L .654 .782 .942 r
F
.44373 .65989 m .4444 .66568 L .44373 .66577 L .651 .424 .562 r
F
.44368 .66009 m .44235 .66941 L .4437 .66008 L .654 .782 .942 r
F
.4439 .66628 m .44435 .66705 L .44464 .66581 L .654 .783 .943 r
F
.44576 .66951 m .44894 .67504 L .4459 .66852 L F
.44871 .66885 m .455 .67985 L .4668 .67725 L .654 .782 .942 r
F
.44609 .66716 m .44894 .67504 L .45351 .67403 L .654 .783 .943 r
F
.44594 .66823 m .44894 .67504 L .44609 .66716 L F
.4449 .66637 m .4459 .66852 L .44504 .66619 L F
.4459 .66852 m .44894 .67504 L .44594 .66823 L F
.4459 .66852 m .44594 .66823 L .44504 .66619 L F
.44666 .65824 m .44652 .66409 L .44662 .65852 L 0 0 .082 r
F
.44455 .65979 m .44458 .66562 L .4444 .66568 L .539 .332 .549 r
F
.44871 .66885 m .4668 .67725 L .45465 .66753 L .654 .782 .942 r
F
.44484 .66569 m .45351 .67403 L .45136 .67089 L .654 .783 .943 r
F
.44493 .65974 m .44496 .65981 L .44499 .65979 L .654 .782 .942 r
F
.44503 .65962 m .44497 .66549 L .44455 .65979 L .539 .332 .549 r
F
.4447 .66558 m .44464 .66581 L .44484 .66569 L .654 .783 .943 r
F
.44447 .66566 m .44464 .66581 L .4447 .66558 L F
.44464 .66581 m .45351 .67403 L .44484 .66569 L F
.44435 .66705 m .44576 .66951 L .4449 .66637 L F
.44576 .66951 m .4459 .66852 L .4449 .66637 L F
.44435 .66705 m .4449 .66637 L .44464 .66581 L F
.44497 .66549 m .44458 .66562 L .44455 .65979 L .539 .332 .549 r
F
.44554 .65944 m .44552 .66526 L .4454 .66534 L .387 .212 .518 r
F
.44503 .65962 m .4454 .66534 L .44497 .66549 L .539 .332 .549 r
F
.45465 .66753 m .4668 .67725 L .477 .67333 L .654 .782 .942 r
F
.44834 .66645 m .45492 .67372 L .46007 .67172 L .654 .783 .943 r
F
.44587 .65924 m .44579 .66509 L .44554 .65944 L .387 .212 .518 r
F
.44559 .66522 m .45136 .67089 L .44834 .66645 L .654 .783 .943 r
F
.44484 .66569 m .45136 .67089 L .44559 .66522 L F
.44504 .66619 m .44594 .66823 L .44609 .66716 L F
.44579 .66509 m .44552 .66526 L .44554 .65944 L .387 .212 .518 r
F
.44631 .66463 m .44615 .66483 L .44622 .65902 L .095 0 .426 r
F
.44622 .65902 m .44615 .66483 L .44608 .66491 L F
.44587 .65924 m .44608 .66491 L .44579 .66509 L .387 .212 .518 r
F
.44639 .65989 m .44662 .65852 L .44648 .66442 L .095 0 .426 r
F
.44643 .65876 m .44662 .65852 L .44639 .65989 L F
.44647 .6576 m .44628 .66343 L .4467 .65794 L .993 .743 .421 r
F
.44359 .66004 m .44235 .66941 L .44368 .66005 L .654 .782 .942 r
F
.44232 .66008 m .44235 .66941 L .4436 .65991 L F
.44123 .62852 m .44222 .62891 L .44142 .65987 L .83 .576 .556 r
F
.44015 .62747 m .44055 .62804 L .43974 .65918 L .984 .727 .46 r
F
.44232 .6622 m .44023 .66449 L .44235 .66941 L .654 .782 .942 r
F
.44023 .66449 m .43597 .66917 L .44099 .66936 L F
.44023 .66449 m .44099 .66936 L .44235 .66941 L F
.44007 .6268 m .44015 .62747 L .43933 .6587 L .868 .695 .169 r
F
.44171 .66148 m .4401 .66364 L .44232 .6622 L .654 .782 .942 r
F
.4401 .66364 m .43597 .66917 L .44023 .66449 L F
.4401 .66364 m .44023 .66449 L .44232 .6622 L F
.44205 .66051 m .44152 .66126 L .44232 .66066 L F
.44152 .66126 m .43597 .66917 L .44171 .66148 L F
.44152 .66126 m .44171 .66148 L .44232 .66066 L F
.4422 .6601 m .44196 .66046 L .44232 .66013 L F
.44196 .66046 m .43597 .66917 L .44205 .66051 L F
.44196 .66046 m .44205 .66051 L .44232 .66013 L F
.4411 .65984 m .43597 .66917 L .4422 .6601 L F
.44142 .65987 m .4422 .6601 L .44231 .65994 L F
.4411 .65984 m .4422 .6601 L .44142 .65987 L F
.43597 .66917 m .44238 .68096 L .44235 .66941 L F
.43597 .66917 m .42975 .68051 L .44238 .68096 L F
.43611 .67537 m .44256 .68718 L .44253 .6756 L .654 .783 .943 r
F
.43611 .67537 m .42985 .68673 L .44256 .68718 L F
.43629 .68153 m .44274 .6933 L .44271 .68176 L .653 .784 .944 r
F
.43629 .68153 m .43001 .69285 L .44274 .6933 L F
.44123 .62852 m .4409 .65971 L .44042 .65957 L .83 .576 .556 r
F
.44055 .62804 m .44123 .62852 L .44042 .65957 L .908 .647 .532 r
F
.44055 .62804 m .44042 .65957 L .44007 .65937 L F
.44123 .62852 m .44142 .65987 L .4409 .65971 L .83 .576 .556 r
F
.44222 .62891 m .44217 .65993 L .44142 .65987 L .747 .505 .564 r
F
.44231 .65764 m .43618 .66289 L .43597 .66917 L .654 .782 .942 r
F
.43618 .66289 m .43002 .66816 L .43252 .66858 L F
.43618 .66289 m .43252 .66858 L .43597 .66917 L F
.44015 .62747 m .43953 .65893 L .43933 .6587 L .984 .727 .46 r
F
.44007 .6268 m .43929 .6584 L .43924 .65813 L .868 .695 .169 r
F
.44007 .6268 m .43933 .6587 L .43929 .6584 L F
.44015 .62747 m .43974 .65918 L .43953 .65893 L .984 .727 .46 r
F
.44055 .62595 m .44007 .6268 L .43924 .65813 L 0 0 .377 r
F
.44055 .62804 m .44007 .65937 L .43974 .65918 L .908 .647 .532 r
F
.43618 .66289 m .42489 .66643 L .43002 .66816 L .654 .782 .942 r
F
.44231 .65764 m .43823 .6597 L .43618 .66289 L F
.43823 .6597 m .42489 .66643 L .43618 .66289 L F
.44251 .66847 m .43611 .67537 L .44253 .6756 L .654 .783 .943 r
F
.4409 .65971 m .44142 .65987 L .44127 .66576 L .83 .576 .556 r
F
.4425 .66612 m .44093 .66664 L .44251 .66847 L .654 .783 .943 r
F
.4414 .6658 m .44093 .66664 L .4425 .66612 L F
.44093 .66664 m .43981 .66867 L .44251 .66847 L F
.43981 .66867 m .43611 .67537 L .44018 .67099 L F
.43981 .66867 m .44018 .67099 L .44251 .66847 L F
.44231 .65764 m .43557 .65968 L .42489 .66643 L .654 .782 .942 r
F
.43557 .65968 m .42091 .6641 L .42414 .66599 L F
.43557 .65968 m .42414 .66599 L .42489 .66643 L F
.44161 .62531 m .44055 .62595 L .43972 .65738 L .428 .243 .527 r
F
.4409 .65971 m .44127 .66576 L .44084 .66563 L .83 .576 .556 r
F
.43953 .65893 m .43941 .66487 L .43933 .6587 L .984 .727 .46 r
F
.43002 .66816 m .42975 .68051 L .43597 .66917 L .654 .782 .942 r
F
.44093 .66664 m .43522 .67002 L .43611 .67537 L .654 .783 .943 r
F
.44072 .6664 m .43958 .66715 L .44093 .66664 L F
.43958 .66715 m .43522 .67002 L .43962 .66742 L F
.43958 .66715 m .43962 .66742 L .44093 .66664 L F
.44055 .62595 m .43924 .65813 L .43949 .65774 L 0 0 .377 r
F
.43557 .65968 m .41838 .66132 L .42091 .6641 L .654 .782 .942 r
F
.44231 .65764 m .43807 .65829 L .43557 .65968 L F
.43807 .65829 m .41838 .66132 L .43557 .65968 L F
.44115 .66597 m .43956 .66705 L .44127 .66604 L .654 .783 .943 r
F
.43956 .66705 m .43522 .67002 L .43958 .66715 L F
.43956 .66705 m .43958 .66715 L .44127 .66604 L F
.44127 .66604 m .44072 .6664 L .44093 .66664 L F
.4414 .6658 m .44115 .66597 L .44127 .66604 L F
.44044 .66556 m .44019 .66578 L .44115 .66597 L F
.44019 .66578 m .43522 .67002 L .44065 .66631 L F
.44019 .66578 m .44065 .66631 L .44115 .66597 L F
.43953 .65893 m .43974 .65918 L .43958 .66507 L .984 .727 .46 r
F
.4425 .66634 m .44253 .6756 L .4437 .66593 L .654 .783 .943 r
F
.44269 .67477 m .43629 .68153 L .44271 .68176 L .653 .784 .944 r
F
.44268 .67285 m .44192 .67388 L .44269 .67477 L F
.44192 .67388 m .43629 .68153 L .44269 .67477 L F
.44142 .65987 m .44154 .66578 L .44127 .66576 L .747 .505 .564 r
F
.44007 .65937 m .43997 .6653 L .43974 .65918 L .908 .647 .532 r
F
.43997 .6653 m .4397 .66514 L .43974 .65918 L F
.44042 .65957 m .44044 .66552 L .44027 .66546 L .83 .576 .556 r
F
.43002 .66816 m .41792 .67852 L .42975 .68051 L .654 .782 .942 r
F
.43522 .67002 m .42495 .67263 L .43012 .67436 L .654 .783 .943 r
F
.4409 .65971 m .44084 .66563 L .44042 .65957 L .83 .576 .556 r
F
.44044 .66556 m .43765 .66625 L .43522 .67002 L .654 .783 .943 r
F
.44049 .66553 m .44041 .66555 L .44044 .66556 L F
.44041 .66555 m .43765 .66625 L .44044 .66556 L F
.44007 .65937 m .44042 .65957 L .44027 .66546 L .908 .647 .532 r
F
.44007 .65937 m .44027 .66546 L .43997 .6653 L F
.44084 .66563 m .44044 .66552 L .44042 .65957 L .83 .576 .556 r
F
.43961 .66527 m .43765 .66625 L .44049 .66553 L .654 .783 .943 r
F
.44232 .66066 m .44171 .66148 L .44232 .6622 L .654 .782 .942 r
F
.44217 .65993 m .44216 .66583 L .44142 .65987 L .747 .505 .564 r
F
.44218 .67256 m .44158 .67348 L .44268 .67285 L .653 .784 .944 r
F
.44158 .67348 m .43629 .68153 L .44192 .67388 L F
.44158 .67348 m .44192 .67388 L .44268 .67285 L F
.44173 .67172 m .44148 .67216 L .44268 .6718 L F
.44216 .66583 m .44154 .66578 L .44142 .65987 L .747 .505 .564 r
F
.43953 .65893 m .43958 .66507 L .43941 .66487 L .984 .727 .46 r
F
.43941 .66487 m .43925 .66468 L .43933 .6587 L F
.43974 .65918 m .4397 .66514 L .43958 .66507 L .908 .647 .532 r
F
.44217 .65993 m .44284 .66588 L .44216 .66583 L .747 .505 .564 r
F
.44249 .66382 m .43843 .66504 L .43899 .66558 L .654 .783 .943 r
F
.43843 .66504 m .43713 .66543 L .43813 .66551 L F
.43843 .66504 m .43813 .66551 L .43899 .66558 L F
.44055 .62595 m .43949 .65774 L .43972 .65738 L 0 0 .377 r
F
.43049 .65946 m .41747 .65827 L .41838 .66132 L .654 .782 .942 r
F
.44231 .65764 m .43697 .65778 L .43049 .65946 L F
.43697 .65778 m .41747 .65827 L .43049 .65946 L F
.44268 .62503 m .44161 .62531 L .4408 .65679 L .585 .37 .555 r
F
.44148 .67216 m .43977 .67526 L .44218 .67256 L .653 .784 .944 r
F
.43977 .67526 m .43989 .67605 L .44218 .67256 L F
.44249 .66382 m .43961 .66527 L .44049 .66553 L .654 .783 .943 r
F
.44161 .62531 m .43972 .65738 L .44027 .65708 L .428 .243 .527 r
F
.43697 .65778 m .41825 .65517 L .41747 .65827 L .654 .782 .942 r
F
.44231 .65764 m .43886 .65729 L .43697 .65778 L F
.43886 .65729 m .41825 .65517 L .43697 .65778 L F
.44148 .67216 m .44218 .67256 L .44268 .6718 L .653 .784 .944 r
F
.44249 .66382 m .4414 .6658 L .4425 .66612 L .654 .783 .943 r
F
.44216 .66583 m .44215 .67176 L .44154 .66578 L .747 .505 .564 r
F
.44049 .66553 m .44044 .66556 L .44123 .66576 L .654 .783 .943 r
F
.44084 .66563 m .44078 .67157 L .44044 .66552 L .83 .576 .556 r
F
.43012 .67436 m .42985 .68673 L .43611 .67537 L .654 .783 .943 r
F
.43977 .67526 m .43385 .67778 L .43629 .68153 L .653 .784 .944 r
F
.43949 .67349 m .43385 .67778 L .43977 .67526 L F
.4397 .66514 m .43967 .67113 L .43958 .66507 L .908 .647 .532 r
F
.4413 .67206 m .43948 .67345 L .44134 .67208 L .653 .784 .944 r
F
.43948 .67345 m .43949 .67349 L .44167 .67184 L F
.44148 .67216 m .43949 .67349 L .43977 .67526 L F
.44134 .67208 m .43949 .67349 L .44148 .67216 L F
.44032 .67202 m .43938 .67281 L .44073 .67249 L F
.42489 .66643 m .41792 .67852 L .43002 .66816 L .654 .782 .942 r
F
.42489 .66643 m .40767 .67511 L .41792 .67852 L F
.42091 .6641 m .40767 .67511 L .42489 .66643 L F
.43843 .66504 m .41841 .66751 L .42096 .67029 L .654 .783 .943 r
F
.43929 .6584 m .43914 .66435 L .43924 .65813 L .868 .695 .169 r
F
.43914 .66435 m .4391 .66413 L .43924 .65813 L F
.43929 .6584 m .43933 .6587 L .43918 .6646 L F
.43929 .6584 m .43918 .6646 L .43914 .66435 L F
.43933 .6587 m .43925 .66468 L .43918 .6646 L .984 .727 .46 r
F
.44249 .66382 m .43886 .66438 L .43843 .66504 L .654 .783 .943 r
F
.43886 .66438 m .41841 .66751 L .43843 .66504 L F
.43924 .65813 m .4391 .66413 L .43909 .66403 L .868 .695 .169 r
F
.43949 .65774 m .43924 .65813 L .43909 .66403 L 0 0 .377 r
F
.43908 .66664 m .43899 .67033 L .43904 .66754 L .868 .695 .169 r
F
.43949 .65774 m .43909 .66403 L .43921 .66383 L 0 0 .377 r
F
.42091 .6641 m .3997 .6705 L .40767 .67511 L .654 .782 .942 r
F
.41838 .66132 m .3997 .6705 L .42091 .6641 L F
.43886 .66438 m .41749 .66446 L .41841 .66751 L .654 .783 .943 r
F
.44249 .66382 m .43916 .6639 L .43886 .66438 L F
.43916 .6639 m .41749 .66446 L .43886 .66438 L F
.43914 .66435 m .43902 .67052 L .43899 .67033 L .868 .695 .169 r
F
.43918 .6646 m .43911 .67062 L .43902 .67052 L .984 .727 .46 r
F
.43938 .67281 m .43425 .67716 L .43948 .67345 L .653 .784 .944 r
F
.43425 .67716 m .43385 .67778 L .43948 .67345 L F
.43948 .67345 m .43385 .67778 L .43949 .67349 L F
.43977 .67526 m .43629 .68153 L .43989 .67605 L F
.43925 .66468 m .43916 .67068 L .43918 .6646 L .984 .727 .46 r
F
.43522 .67002 m .43219 .67471 L .43611 .67537 L .654 .783 .943 r
F
.43012 .67436 m .41794 .68474 L .42985 .68673 L F
.44032 .67202 m .42511 .6788 L .43029 .68052 L .653 .784 .944 r
F
.43982 .67144 m .43707 .67282 L .44032 .67202 L F
.43707 .67282 m .42511 .6788 L .43648 .67373 L F
.43707 .67282 m .43648 .67373 L .44032 .67202 L F
.44027 .66546 m .44032 .67144 L .44011 .67138 L .83 .576 .556 r
F
.43967 .67113 m .43957 .67107 L .43958 .66507 L .908 .647 .532 r
F
.43958 .66507 m .43957 .67107 L .43943 .67099 L F
.44078 .67157 m .44046 .67148 L .44044 .66552 L .83 .576 .556 r
F
.44215 .67176 m .44166 .67172 L .44154 .66578 L .747 .505 .564 r
F
.43997 .6653 m .44027 .66546 L .44011 .67138 L .908 .647 .532 r
F
.43997 .6653 m .44011 .67138 L .43988 .67125 L F
.43522 .67002 m .43012 .67436 L .43219 .67471 L .654 .783 .943 r
F
.42495 .67263 m .41794 .68474 L .43012 .67436 L F
.42495 .67263 m .40763 .68133 L .41794 .68474 L F
.43707 .67282 m .42111 .67647 L .42511 .6788 L .653 .784 .944 r
F
.43997 .6653 m .43988 .67125 L .4397 .66514 L .908 .647 .532 r
F
.43988 .67125 m .43967 .67113 L .4397 .66514 L F
.44127 .66576 m .44145 .6717 L .44112 .67167 L .747 .505 .564 r
F
.44127 .66576 m .44123 .66576 L .4414 .6658 L .654 .783 .943 r
F
.44154 .66578 m .44166 .67172 L .44127 .66576 L .747 .505 .564 r
F
.44075 .67165 m .44032 .67202 L .4416 .67182 L .653 .784 .944 r
F
.44032 .67202 m .44073 .67249 L .4416 .67182 L F
.44112 .67167 m .4416 .67182 L .44173 .67172 L F
.4416 .67182 m .4413 .67206 L .44167 .67184 L F
.44167 .67184 m .44134 .67208 L .44148 .67216 L F
.44166 .67172 m .44212 .69423 L .44145 .6717 L .747 .505 .564 r
F
.44166 .67172 m .44145 .6717 L .44127 .66576 L F
.44044 .66552 m .44046 .67148 L .44027 .66546 L .83 .576 .556 r
F
.44046 .67148 m .44032 .67144 L .44027 .66546 L F
.44082 .67159 m .43982 .67144 L .44032 .67202 L .653 .784 .944 r
F
.44049 .66553 m .44123 .66576 L .44127 .66576 L .654 .783 .943 r
F
.44044 .66556 m .44115 .66597 L .4414 .6658 L F
.44084 .66563 m .44127 .66576 L .44112 .67167 L .83 .576 .556 r
F
.44084 .66563 m .44112 .67167 L .44078 .67157 L F
.44268 .6718 m .44218 .67256 L .44268 .67285 L .653 .784 .944 r
F
.44268 .6718 m .44268 .6718 L .44268 .6718 L F
.44268 .6718 m .44218 .67256 L .44268 .6718 L F
.44388 .67211 m .44271 .68176 L .44474 .68159 L F
.44299 .65999 m .44311 .66585 L .44284 .66588 L .651 .424 .562 r
F
.44232 .66013 m .44205 .66051 L .44232 .66066 L .654 .782 .942 r
F
.44231 .65994 m .4422 .6601 L .44232 .66013 L F
.44217 .65993 m .44299 .65999 L .44284 .66588 L .747 .505 .564 r
F
.44368 .66005 m .44368 .66009 L .4437 .66008 L .654 .782 .942 r
F
.4436 .65991 m .44359 .66004 L .44368 .66005 L F
.44373 .65989 m .44373 .66577 L .44299 .65999 L .651 .424 .562 r
F
.44362 .66578 m .44288 .66588 L .4437 .66593 L .654 .783 .943 r
F
.4425 .66586 m .4425 .66634 L .44364 .66595 L F
.4425 .66586 m .44364 .66595 L .4437 .66593 L F
.44363 .67168 m .44268 .67286 L .44388 .67211 L .653 .784 .944 r
F
.44372 .67167 m .44323 .67173 L .44311 .66585 L .651 .424 .562 r
F
.44284 .66588 m .44323 .67173 L .44269 .6718 L F
.44311 .66585 m .44323 .67173 L .44284 .66588 L F
.44216 .66583 m .44284 .66588 L .44269 .6718 L .747 .505 .564 r
F
.44268 .6718 m .44268 .6718 L .44269 .6718 L .653 .784 .944 r
F
.44215 .67176 m .44269 .6718 L .44212 .69423 L .747 .505 .564 r
F
.44216 .66583 m .44269 .6718 L .44215 .67176 L F
.44267 .67002 m .44268 .6718 L .44363 .67168 L .653 .784 .944 r
F
.44268 .6718 m .44269 .6718 L .44363 .67168 L F
.44268 .6718 m .44268 .67286 L .44363 .67168 L F
.44373 .66577 m .44372 .67167 L .44311 .66585 L .651 .424 .562 r
F
.44268 .67286 m .44271 .68176 L .44388 .67211 L .653 .784 .944 r
F
.44497 .66549 m .44492 .67137 L .44458 .66562 L .539 .332 .549 r
F
.44894 .67504 m .45527 .68606 L .46714 .68346 L .654 .783 .943 r
F
.44595 .67308 m .44913 .6812 L .45358 .68022 L .653 .784 .944 r
F
.44577 .67433 m .44913 .6812 L .44595 .67308 L F
.44443 .67177 m .44576 .67443 L .4445 .67172 L F
.44576 .67443 m .44913 .6812 L .44577 .67433 L F
.44576 .67443 m .44577 .67433 L .4445 .67172 L F
.44373 .66577 m .44311 .66585 L .44299 .65999 L .651 .424 .562 r
F
.44249 .66382 m .44613 .66546 L .44674 .66538 L .654 .783 .943 r
F
.44613 .66546 m .448 .6663 L .44674 .66538 L F
.45148 .66499 m .45339 .66781 L .45465 .66753 L .654 .782 .942 r
F
.45465 .66753 m .477 .67333 L .45977 .66554 L F
.44249 .66382 m .46151 .6708 L .45246 .6663 L .654 .783 .943 r
F
.44652 .66409 m .44649 .66432 L .44662 .65852 L 0 0 .082 r
F
.44662 .65852 m .44649 .66432 L .44648 .66442 L F
.44641 .65878 m .44631 .66463 L .44622 .65902 L .095 0 .426 r
F
.44639 .65989 m .44648 .66442 L .44631 .66463 L F
.44249 .66382 m .45246 .6663 L .4493 .66473 L .654 .783 .943 r
F
.45977 .66554 m .477 .67333 L .48492 .66831 L .654 .782 .942 r
F
.44875 .66446 m .46598 .66695 L .45902 .6655 L .654 .783 .943 r
F
.44249 .66382 m .4493 .66473 L .44875 .66446 L F
.4493 .66473 m .46598 .66695 L .44875 .66446 L F
.44697 .62605 m .44569 .65696 L .44621 .65722 L .889 .63 .539 r
F
.44659 .65699 m .46712 .65701 L .46632 .65395 L .654 .782 .942 r
F
.44231 .65764 m .44892 .65747 L .44659 .65699 L F
.44892 .65747 m .46712 .65701 L .44659 .65699 L F
.4459 .62537 m .44483 .62506 L .44404 .65645 L .799 .548 .56 r
F
.44434 .67157 m .44443 .67177 L .4445 .67172 L .653 .784 .944 r
F
.44362 .66578 m .4439 .66628 L .44449 .66567 L .654 .783 .943 r
F
.44373 .66577 m .4444 .66568 L .44426 .6716 L .651 .424 .562 r
F
.4437 .67179 m .44388 .67211 L .44432 .67159 L .653 .784 .944 r
F
.4437 .67179 m .44432 .67159 L .44426 .6716 L F
.44388 .67211 m .4443 .67284 L .44443 .67177 L F
.46372 .66301 m .48492 .66831 L .49002 .66254 L .654 .782 .942 r
F
.45977 .66554 m .48492 .66831 L .46372 .66301 L F
.45001 .66363 m .46657 .66627 L .46747 .66318 L .654 .783 .943 r
F
.44666 .65824 m .4467 .65794 L .44656 .66384 L 0 0 .082 r
F
.44666 .65824 m .44656 .66384 L .44652 .66409 L F
.4467 .65794 m .44647 .66372 L .44656 .66384 L .993 .743 .421 r
F
.44249 .66382 m .45902 .6655 L .45001 .66363 L .654 .783 .943 r
F
.45902 .6655 m .46657 .66627 L .45001 .66363 L F
.44231 .65764 m .4436 .65991 L .44493 .65974 L .654 .782 .942 r
F
.4459 .62537 m .44404 .65645 L .4446 .65657 L .799 .548 .56 r
F
.4459 .62537 m .4446 .65657 L .44513 .65668 L F
.44697 .62605 m .44513 .65668 L .44569 .65696 L .889 .63 .539 r
F
.44483 .62506 m .44352 .65643 L .44404 .65645 L .733 .492 .564 r
F
.44372 .65644 m .45994 .64875 L .45478 .64696 L .654 .782 .942 r
F
.44231 .65764 m .44461 .65648 L .44372 .65644 L F
.44461 .65648 m .45994 .64875 L .44372 .65644 L F
.44373 .66577 m .44426 .6716 L .44372 .67167 L .651 .424 .562 r
F
.44388 .67211 m .44443 .67177 L .44434 .67157 L .653 .784 .944 r
F
.44388 .67211 m .44474 .68159 L .44565 .67517 L F
.44426 .6716 m .44471 .69372 L .4437 .69407 L .539 .332 .549 r
F
.4444 .66568 m .44447 .67152 L .44426 .6716 L F
.4443 .67284 m .44565 .67517 L .44471 .67233 L .653 .784 .944 r
F
.4443 .67284 m .44471 .67233 L .44443 .67177 L F
.44426 .6716 m .44432 .67159 L .44434 .67157 L F
.44894 .67504 m .46714 .68346 L .45492 .67372 L .654 .783 .943 r
F
.44506 .67191 m .45358 .68022 L .45125 .67681 L .653 .784 .944 r
F
.44502 .67196 m .45358 .68022 L .44506 .67191 L F
.44434 .67157 m .4449 .6721 L .44454 .6715 L F
.4449 .6721 m .45358 .68022 L .44502 .67196 L F
.4449 .6721 m .44502 .67196 L .44454 .6715 L F
.44615 .66483 m .44607 .67066 L .44608 .66491 L .095 0 .426 r
F
.44565 .67517 m .44913 .6812 L .44576 .67443 L .653 .784 .944 r
F
.44565 .67517 m .44474 .68159 L .44913 .6812 L F
.44447 .66566 m .4444 .66568 L .44449 .66567 L .654 .783 .943 r
F
.44458 .66562 m .4446 .67148 L .4444 .66568 L .539 .332 .549 r
F
.4446 .67148 m .44447 .67152 L .4444 .66568 L F
.4454 .66534 m .4454 .67116 L .44526 .67125 L .387 .212 .518 r
F
.44492 .67137 m .4446 .67148 L .44458 .66562 L .539 .332 .549 r
F
.45492 .67372 m .46714 .68346 L .4774 .67952 L .654 .783 .943 r
F
.44832 .67254 m .45512 .67988 L .46028 .67789 L .653 .784 .944 r
F
.44579 .66509 m .44608 .66491 L .44593 .67083 L .387 .212 .518 r
F
.44555 .6713 m .45125 .67681 L .44832 .67254 L .653 .784 .944 r
F
.44533 .67121 m .4455 .67136 L .44555 .6713 L F
.4455 .67136 m .45125 .67681 L .44555 .6713 L F
.44631 .66463 m .44648 .66442 L .44634 .67033 L .095 0 .426 r
F
.44497 .66549 m .4454 .66534 L .44526 .67125 L .539 .332 .549 r
F
.44468 .67161 m .45125 .67681 L .44535 .67122 L .653 .784 .944 r
F
.44468 .67161 m .44535 .67122 L .44526 .67125 L F
.44454 .6715 m .44502 .67196 L .44506 .67191 L F
.44565 .67517 m .44576 .67443 L .44471 .67233 L F
.4445 .67172 m .44577 .67433 L .44595 .67308 L F
.44492 .67137 m .44526 .67125 L .44471 .69372 L .539 .332 .549 r
F
.44497 .66549 m .44526 .67125 L .44492 .67137 L F
.44526 .67125 m .44535 .67122 L .44533 .67121 L .653 .784 .944 r
F
.44579 .66509 m .44593 .67083 L .4457 .67097 L .387 .212 .518 r
F
.44608 .66491 m .44602 .67072 L .44593 .67083 L .095 0 .426 r
F
.44552 .66526 m .44549 .6711 L .4454 .66534 L .387 .212 .518 r
F
.44549 .6711 m .4454 .67116 L .4454 .66534 L F
.4457 .67097 m .44549 .6711 L .44552 .66526 L F
.46623 .6601 m .49002 .66254 L .49191 .65638 L .654 .782 .942 r
F
.46372 .66301 m .49002 .66254 L .46623 .6601 L F
.45018 .66264 m .46747 .66318 L .46667 .66012 L .654 .783 .943 r
F
.44628 .66343 m .44647 .66372 L .4467 .65794 L .993 .743 .421 r
F
.44461 .65648 m .46388 .65113 L .45994 .64875 L .654 .782 .942 r
F
.44231 .65764 m .44596 .65654 L .44461 .65648 L F
.44596 .65654 m .46388 .65113 L .44461 .65648 L F
.44483 .62506 m .44375 .62496 L .44296 .6564 L .733 .492 .564 r
F
.44641 .65878 m .44643 .65876 L .44639 .65989 L .095 0 .426 r
F
.44647 .6576 m .44607 .66312 L .44628 .66343 L .993 .743 .421 r
F
.44249 .66382 m .45001 .66363 L .44735 .66308 L .654 .783 .943 r
F
.44267 .67002 m .44832 .67254 L .44788 .67189 L .653 .784 .944 r
F
.44579 .66509 m .4457 .67097 L .44552 .66526 L .387 .212 .518 r
F
.45136 .67089 m .45492 .67372 L .44834 .66645 L .654 .783 .943 r
F
.45136 .67089 m .45351 .67403 L .45492 .67372 L F
.45492 .67372 m .4774 .67952 L .46007 .67172 L F
.44739 .67118 m .46182 .67691 L .45311 .6726 L .653 .784 .944 r
F
.44267 .67002 m .44788 .67189 L .44739 .67118 L F
.44788 .67189 m .46182 .67691 L .44739 .67118 L F
.46623 .6601 m .49191 .65638 L .46712 .65701 L .654 .782 .942 r
F
.44691 .66249 m .46667 .66012 L .46421 .65729 L .654 .783 .943 r
F
.44544 .66281 m .44588 .66303 L .44621 .65722 L .889 .63 .539 r
F
.44621 .65722 m .44588 .66303 L .44607 .66312 L F
.44647 .6576 m .44621 .65722 L .44607 .66312 L .993 .743 .421 r
F
.44249 .66382 m .45018 .66264 L .44691 .66249 L .654 .783 .943 r
F
.45018 .66264 m .46667 .66012 L .44691 .66249 L F
.44231 .65764 m .44232 .66008 L .4436 .65991 L .654 .782 .942 r
F
.44483 .62506 m .44296 .6564 L .44352 .65643 L .733 .492 .564 r
F
.44375 .62496 m .44268 .62503 L .44188 .65651 L .667 .437 .562 r
F
.44375 .62496 m .44188 .65651 L .44243 .65645 L F
.44231 .65764 m .44299 .6564 L .4423 .65647 L .654 .782 .942 r
F
.44249 .66382 m .4425 .66586 L .44288 .66588 L .654 .783 .943 r
F
.44249 .66382 m .44288 .66588 L .44362 .66578 L F
.44267 .67002 m .44001 .67135 L .44082 .67159 L .653 .784 .944 r
F
.44267 .67002 m .43911 .67108 L .43911 .67108 L F
.44267 .67002 m .43797 .67143 L .4396 .67155 L F
.44173 .67172 m .4416 .67182 L .44167 .67184 L F
.44215 .67176 m .44212 .69423 L .44166 .67172 L .747 .505 .564 r
F
.44267 .67002 m .44075 .67165 L .44173 .67172 L .653 .784 .944 r
F
.44267 .67002 m .44173 .67172 L .44268 .6718 L F
.44112 .67167 m .44212 .69423 L .44054 .69402 L .747 .505 .564 r
F
.44075 .67165 m .4416 .67182 L .44112 .67167 L .653 .784 .944 r
F
.4413 .67206 m .44134 .67208 L .44167 .67184 L F
.44145 .6717 m .44212 .69423 L .44112 .67167 L .747 .505 .564 r
F
.44249 .66382 m .44049 .66553 L .4414 .6658 L .654 .783 .943 r
F
.44231 .65764 m .4411 .65984 L .44231 .65994 L .654 .782 .942 r
F
.44249 .66382 m .44484 .66569 L .44559 .66522 L .654 .783 .943 r
F
.44249 .66382 m .44447 .66566 L .4447 .66558 L F
.44249 .66382 m .44362 .66578 L .4444 .66568 L F
.44249 .66382 m .4444 .66568 L .44447 .66566 L F
.43916 .67068 m .43911 .67062 L .43918 .6646 L .984 .727 .46 r
F
.43941 .66487 m .43929 .67083 L .43925 .66468 L F
.43929 .67083 m .43916 .67068 L .43925 .66468 L F
.43941 .66487 m .43958 .66507 L .43943 .67099 L F
.43941 .66487 m .43943 .67099 L .43929 .67083 L F
.43797 .67143 m .4361 .67102 L .43223 .67315 L .653 .784 .944 r
F
.44267 .67002 m .43847 .67066 L .43797 .67143 L F
.43847 .67066 m .4361 .67102 L .43797 .67143 L F
.4396 .67155 m .43797 .67143 L .43707 .67282 L F
.43892 .68784 m .43885 .69317 L .43891 .68797 L .984 .727 .46 r
F
.43911 .67108 m .43797 .67143 L .43797 .67143 L .653 .784 .944 r
F
.43911 .67108 m .43797 .67143 L .43911 .67108 L F
.43892 .68784 m .43891 .68797 L .43911 .67062 L .984 .727 .46 r
F
.43916 .67068 m .43892 .68784 L .43911 .67062 L F
.43914 .66435 m .43918 .6646 L .43902 .67052 L .868 .695 .169 r
F
.43899 .67033 m .43896 .67015 L .4391 .66413 L F
.42096 .67029 m .40763 .68133 L .42495 .67263 L .654 .783 .943 r
F
.42096 .67029 m .3996 .67671 L .40763 .68133 L F
.41841 .66751 m .3996 .67671 L .42096 .67029 L F
.42388 .67289 m .41763 .67066 L .41855 .6737 L .653 .784 .944 r
F
.4391 .66413 m .43896 .67015 L .43909 .66403 L .868 .695 .169 r
F
.43896 .67015 m .43895 .67007 L .43909 .66403 L F
.43899 .66558 m .42096 .67029 L .42495 .67263 L .654 .783 .943 r
F
.43765 .66625 m .42495 .67263 L .43522 .67002 L F
.44231 .65764 m .42068 .65223 L .41825 .65517 L .654 .782 .942 r
F
.44161 .62531 m .44027 .65708 L .4408 .65679 L .428 .243 .527 r
F
.44231 .65764 m .4246 .64964 L .42068 .65223 L .654 .782 .942 r
F
.44268 .62503 m .4408 .65679 L .44135 .65664 L .585 .37 .555 r
F
.44231 .65764 m .42976 .64759 L .4246 .64964 L .654 .782 .942 r
F
.41838 .66132 m .39454 .66498 L .3997 .6705 L F
.4384 .66392 m .41827 .66135 L .41749 .66446 L .654 .783 .943 r
F
.43949 .65774 m .43921 .66383 L .43929 .66371 L 0 0 .377 r
F
.43949 .65774 m .43929 .66371 L .43972 .65738 L F
.43929 .66371 m .43948 .66341 L .43972 .65738 L F
.44249 .66382 m .4392 .66348 L .4384 .66392 L .654 .783 .943 r
F
.4392 .66348 m .41827 .66135 L .4384 .66392 L F
.44027 .65708 m .44002 .66303 L .4408 .65679 L .428 .243 .527 r
F
.41747 .65827 m .39454 .66498 L .41838 .66132 L .654 .782 .942 r
F
.4392 .66348 m .42072 .6584 L .41827 .66135 L .654 .783 .943 r
F
.44249 .66382 m .4398 .66315 L .4392 .66348 L F
.43972 .65738 m .43948 .66341 L .4395 .66338 L 0 0 .377 r
F
.43972 .65738 m .4395 .66338 L .43957 .66328 L F
.43847 .67066 m .4377 .67014 L .4361 .67102 L .653 .784 .944 r
F
.44267 .67002 m .43882 .67012 L .43847 .67066 L F
.43882 .67012 m .4377 .67014 L .43847 .67066 L F
.4395 .66338 m .43928 .66941 L .43957 .66328 L 0 0 .377 r
F
.43902 .67052 m .43896 .67807 L .43846 .69177 L .984 .727 .46 r
F
.43896 .67807 m .43885 .69317 L .43846 .69177 L F
.43846 .69177 m .43885 .69317 L .43844 .69261 L F
.43911 .67062 m .43885 .69317 L .43902 .67052 L F
.43929 .67083 m .43885 .69317 L .43916 .67068 L F
.44027 .65708 m .43972 .65738 L .43957 .66328 L .428 .243 .527 r
F
.44027 .65708 m .43957 .66328 L .43984 .66313 L F
.4398 .66315 m .42467 .65581 L .42072 .6584 L .654 .783 .943 r
F
.44249 .66382 m .44034 .66285 L .4398 .66315 L F
.44002 .66303 m .43941 .6692 L .43977 .66901 L .428 .243 .527 r
F
.44027 .65708 m .43984 .66313 L .44002 .66303 L F
.43984 .66313 m .43941 .6692 L .44002 .66303 L F
.44028 .66289 m .44045 .66279 L .4408 .65679 L F
.44002 .66303 m .44028 .66289 L .4408 .65679 L F
.44034 .66285 m .42986 .65376 L .42467 .65581 L .654 .783 .943 r
F
.44268 .62503 m .44135 .65664 L .44188 .65651 L .585 .37 .555 r
F
.44231 .65764 m .43579 .64624 L .42976 .64759 L .654 .782 .942 r
F
.44231 .65764 m .44227 .64566 L .43579 .64624 L F
.44135 .65664 m .4411 .66257 L .44188 .65651 L .585 .37 .555 r
F
.44249 .66382 m .44097 .66261 L .44034 .66285 L .654 .783 .943 r
F
.4411 .66257 m .44137 .6625 L .44188 .65651 L .585 .37 .555 r
F
.44064 .66269 m .44011 .66882 L .44049 .66861 L .428 .243 .527 r
F
.4408 .65679 m .44045 .66279 L .44064 .66269 L F
.44045 .66279 m .44011 .66882 L .44064 .66269 L F
.44135 .65664 m .4408 .65679 L .44064 .66269 L .585 .37 .555 r
F
.44135 .65664 m .44064 .66269 L .4411 .66257 L F
.4409 .66255 m .43593 .65239 L .42986 .65376 L .654 .783 .943 r
F
.44097 .66261 m .44093 .66253 L .4409 .66255 L F
.44093 .66253 m .43593 .65239 L .4409 .66255 L F
.44249 .66382 m .44169 .66242 L .44097 .66261 L F
.44137 .6625 m .44154 .66246 L .44188 .65651 L .585 .37 .555 r
F
.44173 .66241 m .44119 .66843 L .44158 .66833 L F
.44188 .65651 m .44154 .66246 L .44173 .66241 L F
.44154 .66246 m .44119 .66843 L .44173 .66241 L F
.43929 .66371 m .43893 .66995 L .43909 .6697 L 0 0 .377 r
F
.43921 .66383 m .43893 .66995 L .43929 .66371 L F
.43908 .66664 m .43904 .66754 L .4391 .66413 L .868 .695 .169 r
F
.43914 .66435 m .43908 .66664 L .4391 .66413 L F
.43909 .66403 m .43895 .67007 L .43893 .66995 L F
.43921 .66383 m .43909 .66403 L .43893 .66995 L 0 0 .377 r
F
.43929 .66371 m .43909 .6697 L .43948 .66341 L F
.43909 .6697 m .43924 .66947 L .43948 .66341 L F
.44267 .67002 m .43867 .66961 L .4377 .67014 L .653 .784 .944 r
F
.44231 .65764 m .45478 .64696 L .44875 .64591 L .654 .782 .942 r
F
.44231 .65764 m .46632 .65395 L .46388 .65113 L F
.44296 .6564 m .44262 .66232 L .44281 .66231 L .667 .437 .562 r
F
.44375 .62496 m .44243 .65645 L .44296 .6564 L F
.44249 .66382 m .44331 .66233 L .44249 .66234 L .654 .783 .943 r
F
.44352 .65643 m .44281 .66231 L .44327 .66233 L .733 .492 .564 r
F
.44331 .66233 m .44336 .66225 L .44281 .66231 L .654 .783 .943 r
F
.44331 .66233 m .44281 .66231 L .44249 .66234 L F
.44352 .65643 m .44327 .66233 L .44404 .65645 L .733 .492 .564 r
F
.44267 .67002 m .44468 .67161 L .44533 .67121 L .653 .784 .944 r
F
.44267 .67002 m .44434 .67157 L .44454 .6715 L F
.44267 .67002 m .4437 .67179 L .44434 .67157 L F
.44269 .6718 m .4437 .69407 L .44212 .69423 L .651 .424 .562 r
F
.44323 .67173 m .4437 .69407 L .44269 .6718 L F
.44631 .66463 m .44634 .67033 L .4462 .6705 L .095 0 .426 r
F
.44607 .67066 m .44602 .67072 L .44608 .66491 L F
.44631 .66463 m .4462 .6705 L .44615 .66483 L F
.4462 .6705 m .44607 .67066 L .44615 .66483 L F
.44267 .67002 m .45311 .6726 L .44964 .67088 L .653 .784 .944 r
F
.46007 .67172 m .4774 .67952 L .48538 .6745 L .654 .783 .943 r
F
.44923 .67068 m .46635 .67296 L .46119 .67189 L .653 .784 .944 r
F
.44267 .67002 m .44964 .67088 L .44923 .67068 L F
.44964 .67088 m .46635 .67296 L .44923 .67068 L F
.44588 .66303 m .44554 .66885 L .44607 .66312 L .889 .63 .539 r
F
.4446 .67148 m .44471 .69372 L .44447 .67152 L .539 .332 .549 r
F
.44447 .67152 m .44471 .69372 L .44426 .6716 L F
.44549 .6711 m .44539 .69327 L .4454 .67116 L .387 .212 .518 r
F
.44526 .67125 m .44539 .69327 L .44471 .69372 L F
.4454 .67116 m .44539 .69327 L .44526 .67125 L F
.44492 .67137 m .44471 .69372 L .4446 .67148 L .539 .332 .549 r
F
.4457 .67097 m .44539 .69327 L .44549 .6711 L .387 .212 .518 r
F
.4479 .66581 m .46007 .67172 L .46151 .6708 L .654 .783 .943 r
F
.44834 .66645 m .46007 .67172 L .4479 .66581 L F
.45246 .6663 m .46151 .6708 L .46404 .66919 L F
.48492 .66831 m .50591 .67357 L .51367 .66497 L .654 .782 .942 r
F
.477 .67333 m .50591 .67357 L .48492 .66831 L F
.46404 .66919 m .48538 .6745 L .49051 .66871 L .654 .783 .943 r
F
.46007 .67172 m .48538 .6745 L .46404 .66919 L F
.4511 .6698 m .46679 .67246 L .46769 .66937 L .653 .784 .944 r
F
.44652 .66409 m .44642 .66976 L .44639 .66995 L 0 0 .082 r
F
.44649 .66432 m .44636 .67013 L .44648 .66442 L F
.44636 .67013 m .44635 .67021 L .44648 .66442 L F
.44648 .66442 m .44635 .67021 L .44634 .67033 L F
.44243 .65645 m .44218 .66237 L .44296 .6564 L .667 .437 .562 r
F
.44569 .65696 m .44544 .66281 L .44621 .65722 L .889 .63 .539 r
F
.44569 .65696 m .44498 .66258 L .44544 .66281 L F
.44249 .66382 m .44971 .66165 L .44614 .66199 L .654 .783 .943 r
F
.44249 .66382 m .44249 .66234 L .44169 .66242 L F
.44218 .66237 m .44262 .66232 L .44296 .6564 L .667 .437 .562 r
F
.44249 .66234 m .44249 .66221 L .44173 .66241 L .654 .783 .943 r
F
.44249 .66234 m .44173 .66241 L .44169 .66242 L F
.44243 .65645 m .44188 .65651 L .44173 .66241 L .667 .437 .562 r
F
.43713 .66543 m .42096 .67029 L .43899 .66558 L .654 .783 .943 r
F
.43356 .66909 m .42087 .66462 L .41842 .66756 L .653 .784 .944 r
F
.43928 .66941 m .43933 .66933 L .43957 .66328 L 0 0 .377 r
F
.43957 .66328 m .43933 .66933 L .43941 .6692 L F
.43948 .66341 m .43924 .66947 L .4395 .66338 L F
.43924 .66947 m .43926 .66944 L .4395 .66338 L F
.4395 .66338 m .43926 .66944 L .43928 .66941 L F
.44097 .66261 m .44064 .66269 L .44034 .66285 L .654 .783 .943 r
F
.4411 .66257 m .44064 .66269 L .44049 .66861 L .585 .37 .555 r
F
.44267 .67002 m .43878 .66905 L .43719 .66946 L .653 .784 .944 r
F
.44001 .67135 m .43982 .67144 L .44082 .67159 L F
.43938 .67281 m .43948 .67345 L .44073 .67249 L F
.44046 .67148 m .44054 .69402 L .44032 .67144 L .83 .576 .556 r
F
.44011 .67138 m .44054 .69402 L .43953 .69364 L F
.44032 .67144 m .44054 .69402 L .44011 .67138 L F
.44078 .67157 m .44054 .69402 L .44046 .67148 L F
.43745 .66872 m .42483 .66203 L .42087 .66462 L .653 .784 .944 r
F
.43984 .66313 m .43957 .66328 L .43941 .6692 L .428 .243 .527 r
F
.43977 .66901 m .44011 .66882 L .44045 .66279 L F
.43977 .66901 m .44045 .66279 L .44028 .66289 L F
.44002 .66303 m .43977 .66901 L .44028 .66289 L F
.44267 .67002 m .43938 .66854 L .43745 .66872 L .653 .784 .944 r
F
.43938 .66854 m .42483 .66203 L .43745 .66872 L F
.44218 .66237 m .44194 .6683 L .44262 .66232 L .667 .437 .562 r
F
.4411 .66257 m .44049 .66861 L .44085 .66852 L .585 .37 .555 r
F
.4398 .66315 m .42072 .6584 L .4392 .66348 L .654 .783 .943 r
F
.43938 .66854 m .43003 .65999 L .42483 .66203 L .653 .784 .944 r
F
.44267 .67002 m .44066 .66842 L .43938 .66854 L F
.44066 .66842 m .43003 .65999 L .43938 .66854 L F
.44218 .66237 m .44173 .66241 L .44158 .66833 L .667 .437 .562 r
F
.44218 .66237 m .44158 .66833 L .44194 .6683 L F
.4409 .66255 m .42986 .65376 L .44034 .66285 L .654 .783 .943 r
F
.44034 .66285 m .42467 .65581 L .4398 .66315 L F
.44066 .66842 m .4361 .65863 L .43003 .65999 L .653 .784 .944 r
F
.44267 .67002 m .4417 .66832 L .44066 .66842 L F
.44085 .66852 m .44119 .66843 L .44154 .66246 L .585 .37 .555 r
F
.44085 .66852 m .44154 .66246 L .44137 .6625 L F
.4411 .66257 m .44085 .66852 L .44137 .6625 L F
.4417 .66832 m .4361 .65863 L .44066 .66842 L .653 .784 .944 r
F
.44327 .66233 m .4437 .66235 L .44404 .65645 L .733 .492 .564 r
F
.4446 .65657 m .44436 .66245 L .44513 .65668 L .799 .548 .56 r
F
.44436 .66245 m .44479 .66254 L .44513 .65668 L F
.44404 .65645 m .4437 .66235 L .4439 .66236 L .733 .492 .564 r
F
.4446 .65657 m .44404 .65645 L .4439 .66236 L .799 .548 .56 r
F
.4446 .65657 m .4439 .66236 L .44436 .66245 L F
.44513 .65668 m .44479 .66254 L .44498 .66258 L F
.44569 .65696 m .44513 .65668 L .44498 .66258 L .889 .63 .539 r
F
.44249 .66382 m .45505 .65312 L .44898 .65206 L .654 .783 .943 r
F
.44249 .66382 m .46024 .6549 L .45505 .65312 L F
.44262 .66232 m .44228 .66827 L .44281 .66231 L .667 .437 .562 r
F
.44228 .66827 m .44243 .66825 L .44281 .66231 L F
.44281 .66231 m .44243 .66825 L .44266 .66823 L F
.44194 .6683 m .44228 .66827 L .44262 .66232 L F
.44243 .65645 m .44173 .66241 L .44218 .66237 L F
.4423 .65647 m .44875 .64591 L .44227 .64566 L .654 .782 .942 r
F
.44299 .6564 m .44875 .64591 L .4423 .65647 L F
.44352 .65643 m .44296 .6564 L .44281 .66231 L .733 .492 .564 r
F
.44249 .66234 m .44898 .65206 L .44245 .65182 L .654 .783 .943 r
F
.44336 .66225 m .44898 .65206 L .44249 .66234 L F
.44169 .66242 m .44245 .65182 L .43593 .65239 L F
.44249 .66221 m .44245 .65182 L .44169 .66242 L F
.44169 .66242 m .43593 .65239 L .44097 .66261 L F
.44097 .66261 m .4409 .66255 L .44064 .66269 L F
.44162 .66818 m .44264 .65805 L .4361 .65863 L .653 .784 .944 r
F
.44267 .67002 m .44267 .66823 L .44162 .66818 L F
.44267 .66823 m .44264 .65805 L .44162 .66818 L F
.44327 .66233 m .44281 .66231 L .44266 .66823 L .733 .492 .564 r
F
.44652 .66409 m .44639 .66995 L .44649 .66432 L 0 0 .082 r
F
.44639 .66995 m .44636 .67013 L .44649 .66432 L F
.44267 .67002 m .44923 .67068 L .44763 .66989 L .653 .784 .944 r
F
.44267 .67002 m .4511 .6698 L .45108 .6698 L F
.44647 .66372 m .44624 .66951 L .44656 .66384 L .993 .743 .421 r
F
.44624 .66951 m .44631 .66961 L .44656 .66384 L F
.44652 .66409 m .44656 .66384 L .44642 .66976 L 0 0 .082 r
F
.44656 .66384 m .44631 .66961 L .44642 .66976 L .993 .743 .421 r
F
.44812 .66919 m .46769 .66937 L .4517 .66864 L .653 .784 .944 r
F
.44609 .66928 m .44624 .66951 L .44647 .66372 L .993 .743 .421 r
F
.44267 .67002 m .45108 .6698 L .44812 .66919 L .653 .784 .944 r
F
.45108 .6698 m .46769 .66937 L .44812 .66919 L F
.44479 .66254 m .44445 .66843 L .44498 .66258 L .799 .548 .56 r
F
.44372 .67167 m .44426 .6716 L .4437 .69407 L .651 .424 .562 r
F
.44372 .67167 m .4437 .69407 L .44323 .67173 L F
.44445 .66843 m .4446 .66846 L .44498 .66258 L .799 .548 .56 r
F
.44498 .66258 m .4446 .66846 L .44484 .6685 L F
.44614 .66199 m .46421 .65729 L .46024 .6549 L .654 .783 .943 r
F
.44971 .66165 m .46421 .65729 L .44614 .66199 L F
.44544 .66281 m .44498 .66258 L .44484 .6685 L .889 .63 .539 r
F
.44544 .66281 m .44484 .6685 L .4452 .66868 L F
.44436 .66245 m .4439 .66236 L .44375 .66828 L .799 .548 .56 r
F
.44436 .66245 m .44375 .66828 L .44411 .66835 L F
.44554 .66885 m .44569 .66893 L .44607 .66312 L .889 .63 .539 r
F
.44607 .66312 m .44569 .66893 L .44593 .66904 L F
.44436 .66245 m .44411 .66835 L .44479 .66254 L .799 .548 .56 r
F
.44411 .66835 m .44445 .66843 L .44479 .66254 L F
.44628 .66343 m .44607 .66312 L .44593 .66904 L .993 .743 .421 r
F
.44628 .66343 m .44593 .66904 L .44609 .66928 L F
.44735 .66308 m .46392 .66327 L .45018 .66264 L .654 .783 .943 r
F
.45001 .66363 m .46392 .66327 L .44735 .66308 L F
.46392 .66327 m .46747 .66318 L .45018 .66264 L F
.4439 .66236 m .44337 .66826 L .44375 .66828 L .733 .492 .564 r
F
.44544 .66281 m .4452 .66868 L .44588 .66303 L .889 .63 .539 r
F
.4452 .66868 m .44554 .66885 L .44588 .66303 L F
.44628 .66343 m .44609 .66928 L .44647 .66372 L .993 .743 .421 r
F
.44674 .66538 m .448 .6663 L .4479 .66581 L .654 .783 .943 r
F
.44267 .67002 m .45526 .65935 L .44918 .6583 L .653 .784 .944 r
F
.4493 .66473 m .46404 .66919 L .46598 .66695 L .654 .783 .943 r
F
.45246 .6663 m .46404 .66919 L .4493 .66473 L F
.448 .6663 m .44834 .66645 L .44825 .66632 L F
.448 .6663 m .44825 .66632 L .4479 .66581 L F
.44267 .67002 m .46046 .66113 L .45526 .65935 L .653 .784 .944 r
F
.44267 .67002 m .46442 .66351 L .46046 .66113 L F
.45902 .6655 m .46598 .66695 L .46657 .66627 L .654 .783 .943 r
F
.48492 .66831 m .51367 .66497 L .49002 .66254 L .654 .782 .942 r
F
.49002 .66254 m .51367 .66497 L .51667 .65575 L F
.46657 .66627 m .49051 .66871 L .49242 .66254 L .654 .783 .943 r
F
.46404 .66919 m .49051 .66871 L .46657 .66627 L F
.46657 .66627 m .49242 .66254 L .46747 .66318 L F
.44267 .67002 m .46689 .66632 L .46442 .66351 L .653 .784 .944 r
F
.44445 .66843 m .4432 .69026 L .4446 .66846 L .799 .548 .56 r
F
.44484 .6685 m .4432 .69026 L .44429 .69056 L F
.4446 .66846 m .4432 .69026 L .44484 .6685 L F
.45108 .6698 m .46769 .66937 L .46769 .66937 L .653 .784 .944 r
F
.4511 .6698 m .46769 .66937 L .45108 .6698 L F
.4517 .66864 m .46769 .66937 L .46689 .66632 L F
.44327 .66233 m .44302 .66825 L .4437 .66235 L .733 .492 .564 r
F
.44302 .66825 m .44337 .66826 L .4437 .66235 L F
.44327 .66233 m .44266 .66823 L .44302 .66825 L F
.4437 .66235 m .44337 .66826 L .4439 .66236 L F
.44267 .67002 m .44918 .6583 L .44264 .65805 L .653 .784 .944 r
F
.44302 .66825 m .44211 .69016 L .44337 .66826 L .733 .492 .564 r
F
.44302 .66825 m .44266 .66823 L .44211 .69016 L F
.44228 .66827 m .44102 .69023 L .44243 .66825 L .667 .437 .562 r
F
.44266 .66823 m .44102 .69023 L .44211 .69016 L F
.44243 .66825 m .44102 .69023 L .44266 .66823 L F
.44194 .6683 m .44102 .69023 L .44228 .66827 L F
.44085 .66852 m .44049 .66861 L .43992 .6905 L .585 .37 .555 r
F
.43719 .66946 m .43745 .66872 L .43356 .66909 L .653 .784 .944 r
F
.43878 .66905 m .43745 .66872 L .43719 .66946 L F
.43745 .66872 m .42087 .66462 L .43356 .66909 L F
.44194 .6683 m .44158 .66833 L .44102 .69023 L .667 .437 .562 r
F
.4452 .66868 m .44484 .6685 L .44429 .69056 L .889 .63 .539 r
F
.44763 .66989 m .46119 .67189 L .4511 .6698 L .653 .784 .944 r
F
.44923 .67068 m .46119 .67189 L .44763 .66989 L F
.46119 .67189 m .46679 .67246 L .4511 .6698 L F
.44411 .66835 m .44375 .66828 L .4432 .69026 L .799 .548 .56 r
F
.44554 .66885 m .44429 .69056 L .44569 .66893 L .889 .63 .539 r
F
.4457 .67097 m .44593 .67083 L .44539 .69327 L .387 .212 .518 r
F
.44593 .66904 m .44429 .69056 L .44539 .69123 L .889 .63 .539 r
F
.44569 .66893 m .44429 .69056 L .44593 .66904 L F
.44964 .67088 m .46426 .67536 L .46635 .67296 L .653 .784 .944 r
F
.45311 .6726 m .46426 .67536 L .44964 .67088 L F
.46119 .67189 m .46635 .67296 L .46679 .67246 L F
.44411 .66835 m .4432 .69026 L .44445 .66843 L .799 .548 .56 r
F
.43967 .67113 m .43953 .69364 L .43957 .67107 L .908 .647 .532 r
F
.43943 .67099 m .43953 .69364 L .43885 .69317 L F
.43957 .67107 m .43953 .69364 L .43943 .67099 L F
.43929 .67083 m .43943 .67099 L .43885 .69317 L .984 .727 .46 r
F
.43988 .67125 m .43953 .69364 L .43967 .67113 L .908 .647 .532 r
F
.43977 .66901 m .43941 .6692 L .43884 .69113 L .428 .243 .527 r
F
.4377 .67014 m .41842 .66756 L .41763 .67066 L .653 .784 .944 r
F
.43867 .66961 m .41842 .66756 L .4377 .67014 L F
.43928 .66941 m .43846 .69177 L .43933 .66933 L 0 0 .377 r
F
.43988 .67125 m .44011 .67138 L .43953 .69364 L .908 .647 .532 r
F
.43977 .66901 m .43884 .69113 L .44011 .66882 L .428 .243 .527 r
F
.4361 .67102 m .43418 .67023 L .42388 .67289 L .653 .784 .944 r
F
.4377 .67014 m .43418 .67023 L .4361 .67102 L F
.43418 .67023 m .41763 .67066 L .42388 .67289 L F
.44078 .67157 m .44112 .67167 L .44054 .69402 L .83 .576 .556 r
F
.44085 .66852 m .43992 .6905 L .44119 .66843 L .585 .37 .555 r
F
.43941 .6692 m .43846 .69177 L .43892 .68784 L 0 0 .377 r
F
.43933 .66933 m .43846 .69177 L .43941 .6692 L F
.44049 .66861 m .43884 .69113 L .43992 .6905 L .428 .243 .527 r
F
.44011 .66882 m .43884 .69113 L .44049 .66861 L F
.43223 .67315 m .42388 .67289 L .42111 .67647 L .653 .784 .944 r
F
.4361 .67102 m .42388 .67289 L .43223 .67315 L F
.42388 .67289 m .41855 .6737 L .41897 .67415 L F
.42388 .67289 m .41897 .67415 L .42111 .67647 L F
.44158 .66833 m .43992 .6905 L .44102 .69023 L .585 .37 .555 r
F
.44119 .66843 m .43992 .6905 L .44158 .66833 L F
.44607 .67066 m .4458 .69272 L .44602 .67072 L .095 0 .426 r
F
.44593 .67083 m .4458 .69272 L .44539 .69327 L F
.44602 .67072 m .4458 .69272 L .44593 .67083 L F
.44609 .66928 m .44593 .66904 L .44539 .69123 L .993 .743 .421 r
F
.4462 .6705 m .44634 .67033 L .4458 .69272 L .095 0 .426 r
F
.4462 .6705 m .4458 .69272 L .44607 .67066 L F
.44624 .66951 m .44539 .69123 L .44631 .66961 L .993 .743 .421 r
F
.44788 .67189 m .46028 .67789 L .46182 .67691 L .653 .784 .944 r
F
.44832 .67254 m .46028 .67789 L .44788 .67189 L F
.45311 .6726 m .46182 .67691 L .46426 .67536 L F
.4452 .66868 m .44429 .69056 L .44554 .66885 L .889 .63 .539 r
F
.45125 .67681 m .45512 .67988 L .44832 .67254 L .653 .784 .944 r
F
.44639 .66995 m .44642 .66976 L .44588 .69207 L 0 0 .082 r
F
.44636 .67013 m .44588 .69207 L .44635 .67021 L F
.44634 .67033 m .44588 .69207 L .4458 .69272 L F
.44635 .67021 m .44588 .69207 L .44634 .67033 L F
.44639 .66995 m .44588 .69207 L .44636 .67013 L F
.44642 .66976 m .44539 .69123 L .44588 .69207 L .993 .743 .421 r
F
.44631 .66961 m .44539 .69123 L .44642 .66976 L F
.44375 .66828 m .44211 .69016 L .4432 .69026 L .733 .492 .564 r
F
.44337 .66826 m .44211 .69016 L .44375 .66828 L F
.45125 .67681 m .45358 .68022 L .45512 .67988 L .653 .784 .944 r
F
.44609 .66928 m .44539 .69123 L .44624 .66951 L .993 .743 .421 r
F
.43797 .67143 m .42111 .67647 L .43707 .67282 L .653 .784 .944 r
F
.43899 .67033 m .43902 .67052 L .43844 .69261 L .868 .695 .169 r
F
.43899 .67033 m .43844 .69261 L .43896 .67015 L F
.43893 .66995 m .43844 .69261 L .43835 .69196 L F
.43895 .67007 m .43844 .69261 L .43893 .66995 L F
.43896 .67015 m .43844 .69261 L .43895 .67007 L F
.43924 .66947 m .43835 .69196 L .43926 .66944 L 0 0 .377 r
F
.43928 .66941 m .43835 .69196 L .43846 .69177 L F
.43926 .66944 m .43835 .69196 L .43928 .66941 L F
.43909 .6697 m .43893 .66995 L .43835 .69196 L F
.43425 .67716 m .43029 .68052 L .43385 .67778 L .653 .784 .944 r
F
.43385 .67778 m .43029 .68052 L .4319 .68079 L F
.43385 .67778 m .4319 .68079 L .43629 .68153 L F
.43909 .6697 m .43835 .69196 L .43924 .66947 L 0 0 .377 r
F
.43892 .68784 m .43846 .69177 L .43884 .69113 L F
0 g
.43486 .57696 m
.43558 .57665 L
s
.41802 .58348 m .38532 .58147 L .41505 .58733 L .641 .739 .92 r
F
.47414 .59045 m .49796 .57933 L .47114 .58628 L F
.47414 .59045 m .50384 .58771 L .49796 .57933 L F
.49477 .69332 m .5065 .67976 L .50678 .68589 L .423 .271 .569 r
F
.47764 .68566 m .49477 .69332 L .50678 .68589 L .653 .784 .944 r
F
.46736 .68959 m .49477 .69332 L .47764 .68566 L F
0 g
.4794 .69913 m
.49477 .69332 L
s
.41867 .57578 m .39185 .56597 L .38605 .57376 L .642 .739 .919 r
F
.42347 .57256 m .39185 .56597 L .41867 .57578 L F
.42423 .56494 m .40232 .55186 L .39283 .55837 L .643 .738 .918 r
F
.4305 .56261 m .40232 .55186 L .42423 .56494 L F
.47168 .57857 m .48883 .56405 L .46685 .57485 L .642 .739 .919 r
F
.47168 .57857 m .49844 .57158 L .48883 .56405 L F
.46729 .56721 m .47649 .55035 L .461 .56422 L .643 .738 .918 r
F
.46729 .56721 m .48911 .55643 L .47649 .55035 L F
.53475 .56826 m .55373 .5696 L .55338 .57729 L .847 .602 .567 r
F
.53475 .56826 m .53515 .56055 L .55373 .5696 L F
.55774 .5496 m .55373 .5696 L .57017 .55573 L .643 .738 .918 r
F
.55774 .5496 m .53515 .56055 L .55373 .5696 L F
0 g
.55373 .5696 m
.56032 .57147 L
s
.43558 .57665 m
.43719 .57627 L
s
.39185 .56597 m .35622 .56785 L .38605 .57376 L .642 .739 .919 r
F
.64557 .57444 m .66582 .55972 L .66571 .56742 L .529 .332 .558 r
F
.64541 .58214 m .64557 .57444 L .66571 .56742 L F
.63198 .55899 m .64557 .57444 L .66571 .56742 L .643 .738 .918 r
F
.6167 .56161 m .64557 .57444 L .63198 .55899 L F
0 g
.63285 .57658 m
.64557 .57444 L
s
.50431 .57999 m .5255 .56452 L .49844 .57158 L .642 .739 .919 r
F
.50431 .57999 m .53411 .57723 L .5255 .56452 L F
.3785 .68923 m .39051 .68992 L .39061 .69605 L .905 .653 .548 r
F
.3785 .68923 m .37842 .68308 L .39051 .68992 L F
.3996 .67671 m .39051 .68992 L .40763 .68133 L .654 .783 .943 r
F
.3996 .67671 m .37842 .68308 L .39051 .68992 L F
0 g
.39051 .68992 m
.39799 .69236 L
s
.39283 .55837 m .36592 .54849 L .35746 .56026 L .643 .738 .918 r
F
.36473 .55605 m .35701 .56018 L .35622 .56785 L .021 0 .363 r
F
.36473 .55605 m .36551 .54834 L .35701 .56018 L F
0 g
.35471 .57302 m
.35701 .56018 L
s
.53241 .57298 m .53451 .56953 L .52592 .55679 L .986 .743 .482 r
F
.52096 .54915 m .53555 .55286 L .53515 .56055 L .917 .667 .545 r
F
.53411 .57723 m .52592 .55679 L .5255 .56452 L .986 .743 .482 r
F
.49865 .56395 m .52509 .55701 L .51128 .54549 L .643 .738 .918 r
F
.52509 .55701 m .52552 .55689 L .52441 .55601 L F
.52509 .55701 m .52441 .55601 L .51128 .54549 L F
.5255 .56452 m .52592 .55679 L .51162 .54532 L .917 .667 .546 r
F
.51171 .54387 m .51905 .54806 L .52053 .55689 L .986 .743 .482 r
F
.51905 .54806 m .52096 .54915 L .52087 .55076 L F
.51905 .54806 m .52087 .55076 L .52053 .55689 L F
.52053 .55689 m .53515 .56055 L .53475 .56826 L .917 .667 .545 r
F
.52053 .55689 m .52096 .54915 L .53515 .56055 L F
.54898 .5341 m .53589 .5527 L .55832 .54177 L .644 .737 .917 r
F
.54833 .54191 m .53515 .56055 L .55774 .5496 L .643 .738 .918 r
F
.52096 .54915 m .5214 .54144 L .53555 .55286 L .917 .667 .545 r
F
.54898 .5341 m .5218 .54133 L .53589 .5527 L .644 .737 .917 r
F
.54833 .54191 m .52096 .54915 L .53515 .56055 L .643 .738 .918 r
F
.54796 .54968 m .52137 .55667 L .53475 .56826 L .642 .738 .919 r
F
.52137 .55667 m .52053 .55689 L .52269 .55862 L F
.52137 .55667 m .52269 .55862 L .53475 .56826 L F
.53411 .57723 m .5342 .57562 L .53241 .57298 L .986 .743 .482 r
F
.5342 .57562 m .53451 .56953 L .53241 .57298 L F
0 g
.53451 .56953 m
.53691 .58263 L
s
.53238 .56636 m
.53451 .56953 L
s
.60131 .44691 m .60441 .50788 L .60282 .50806 L .648 .418 .556 r
F
.60131 .44691 m .60287 .44673 L .60441 .50788 L F
.59979 .44667 m .60131 .44691 L .60282 .50806 L .749 .498 .552 r
F
0 g
.60131 .44691 m
.60131 .44691 L
s
.60287 .44673 m .60545 .50749 L .60441 .50788 L .539 .333 .549 r
F
.60287 .44673 m .60389 .44633 L .60545 .50749 L F
0 g
.60131 .44691 m
.60287 .44673 L
s
.59979 .44667 m .60282 .50806 L .60127 .50783 L .749 .498 .552 r
F
.59885 .44624 m .59979 .44667 L .60127 .50783 L .84 .573 .536 r
F
0 g
.59979 .44667 m
.60131 .44691 L
s
.60389 .44633 m .60618 .50698 L .60545 .50749 L .402 .228 .528 r
F
.60389 .44633 m .6046 .44581 L .60618 .50698 L F
0 g
.60287 .44673 m
.60389 .44633 L
s
.59885 .44624 m .60127 .50783 L .60031 .5074 L .84 .573 .536 r
F
.59823 .44571 m .59885 .44624 L .60031 .5074 L .925 .648 .496 r
F
0 g
.59885 .44624 m
.59979 .44667 L
s
.6046 .44581 m .60664 .50637 L .60618 .50698 L .163 .05 .467 r
F
.6046 .44581 m .60505 .4452 L .60664 .50637 L F
0 g
.60389 .44633 m
.6046 .44581 L
s
.59823 .44571 m .60031 .5074 L .59967 .50687 L .925 .648 .496 r
F
.59788 .44507 m .59823 .44571 L .59967 .50687 L .988 .718 .377 r
F
0 g
.59823 .44571 m
.59885 .44624 L
s
.4305 .56261 m .4149 .5471 L .40232 .55186 L .643 .738 .918 r
F
.43784 .56132 m .4149 .5471 L .4305 .56261 L F
.461 .56422 m .46166 .54614 L .45364 .56215 L F
.461 .56422 m .47649 .55035 L .46166 .54614 L F
.60505 .4452 m .60679 .50564 L .60664 .50637 L 0 0 .235 r
F
.60505 .4452 m .6052 .44446 L .60679 .50564 L F
0 g
.6046 .44581 m
.60505 .4452 L
s
.59788 .44507 m .59967 .50687 L .59933 .50625 L .988 .718 .377 r
F
.59786 .44433 m .59788 .44507 L .59933 .50625 L .712 .567 0 r
F
0 g
.59788 .44507 m
.59823 .44571 L
s
.39971 .68288 m .39061 .69605 L .40776 .68748 L .653 .784 .944 r
F
.39971 .68288 m .3785 .68923 L .39061 .69605 L F
0 g
.39061 .69605 m
.40607 .70106 L
s
.41802 .58348 m .39113 .5737 L .38532 .58147 L .641 .739 .92 r
F
.42283 .58028 m .39113 .5737 L .41802 .58348 L F
.5065 .67976 m .50622 .67365 L .51402 .66501 L .212 .113 .518 r
F
0 g
.49657 .67968 m
.50622 .67365 L
s
.42347 .57256 m .4014 .55945 L .39185 .56597 L .642 .739 .919 r
F
.42979 .57023 m .4014 .55945 L .42347 .57256 L F
.47114 .58628 m .48832 .57181 L .4663 .58257 L .641 .739 .92 r
F
.47114 .58628 m .49796 .57933 L .48832 .57181 L F
.55739 .55736 m .55338 .57729 L .56984 .56347 L .642 .738 .919 r
F
.55739 .55736 m .53475 .56826 L .55338 .57729 L F
0 g
.55338 .57729 m
.57516 .58346 L
s
.53893 .56239 m
.54292 .56433 L
s
.46685 .57485 m .47611 .55795 L .46051 .57184 L .642 .739 .919 r
F
.46685 .57485 m .48883 .56405 L .47611 .55795 L F
.39113 .5737 m .35543 .57557 L .38532 .58147 L .641 .739 .92 r
F
.6052 .44446 m .60638 .50471 L .60679 .50564 L .978 .72 .315 r
F
.6052 .44446 m .6048 .44351 L .60638 .50471 L F
.61648 .56934 m .64541 .58214 L .63179 .56674 L .642 .738 .919 r
F
.64541 .58214 m .66571 .56742 L .6656 .57516 L .529 .332 .558 r
F
.63179 .56674 m .64541 .58214 L .6656 .57516 L .642 .738 .919 r
F
0 g
.62265 .58596 m
.64541 .58214 L
s
.59786 .44433 m .59933 .50625 L .59931 .50552 L .712 .567 0 r
F
.59842 .4434 m .59786 .44433 L .59931 .50552 L .07 0 .435 r
F
.44913 .6812 m .45547 .69219 L .46736 .68959 L .653 .784 .944 r
F
.50384 .58771 m .52508 .57229 L .49796 .57933 L .641 .739 .92 r
F
.50384 .58771 m .53371 .58497 L .52508 .57229 L F
.43784 .56132 m .42971 .54446 L .4149 .5471 L .643 .738 .918 r
F
.44574 .56116 m .42971 .54446 L .43784 .56132 L F
.45364 .56215 m .44568 .54412 L .44574 .56116 L F
.45364 .56215 m .46166 .54614 L .44568 .54412 L F
.6048 .44351 m .60536 .50397 L .60638 .50471 L .906 .63 .507 r
F
.6048 .44351 m .6038 .44276 L .60536 .50397 L F
0 g
.6048 .44351 m
.6052 .44446 L
s
.6048 .44351 m
.6048 .44351 L
s
.39185 .56597 m .36473 .55605 L .35622 .56785 L .642 .739 .919 r
F
.36395 .5638 m .35622 .56785 L .35543 .57557 L .021 0 .363 r
F
.36395 .5638 m .36473 .55605 L .35622 .56785 L F
0 g
.35392 .58067 m
.35622 .56785 L
s
.59955 .44269 m .59842 .4434 L .59987 .5046 L .438 .255 .533 r
F
.59842 .4434 m .59931 .50552 L .59987 .5046 L .07 0 .435 r
F
0 g
.59786 .44433 m
.59842 .4434 L
s
.59842 .4434 m
.59842 .4434 L
s
.43029 .68052 m .43001 .69285 L .43629 .68153 L .653 .784 .944 r
F
.43029 .68052 m .41809 .69087 L .43001 .69285 L F
.40232 .55186 m .36592 .54849 L .39283 .55837 L .643 .738 .918 r
F
.53371 .58497 m .53411 .57723 L .5255 .56452 L .986 .743 .482 r
F
0 g
.53411 .57723 m
.53652 .59029 L
s
.44574 .56116 m .44568 .54412 L .42971 .54446 L .643 .738 .918 r
F
.66571 .56742 m .66582 .55972 L .68204 .5499 L .412 .24 .535 r
F
0 g
.65295 .56423 m
.66582 .55972 L
s
.49865 .56395 m .51128 .54549 L .48911 .55643 L .643 .738 .918 r
F
.6038 .44276 m .60431 .50363 L .60536 .50397 L .805 .544 .543 r
F
.6038 .44276 m .60277 .44242 L .60431 .50363 L F
0 g
.6038 .44276 m
.6048 .44351 L
s
.59955 .44269 m .59987 .5046 L .60102 .5039 L .438 .255 .533 r
F
.60064 .44238 m .59955 .44269 L .60102 .5039 L .583 .366 .552 r
F
0 g
.59842 .4434 m
.59955 .44269 L
s
.64542 .54636 m .66552 .55953 L .68166 .54975 L .644 .737 .917 r
F
.63203 .55112 m .66552 .55953 L .64542 .54636 L F
.60277 .44242 m .60323 .50352 L .60431 .50363 L .733 .485 .553 r
F
.60277 .44242 m .60171 .4423 L .60323 .50352 L F
0 g
.60277 .44242 m
.6038 .44276 L
s
.60064 .44238 m .60102 .5039 L .60214 .50359 L .583 .366 .552 r
F
.60171 .4423 m .60064 .44238 L .60214 .50359 L .665 .431 .556 r
F
0 g
.59955 .44269 m
.60064 .44238 L
s
.60171 .4423 m .60214 .50359 L .60323 .50352 L .665 .431 .556 r
F
0 g
.60064 .44238 m
.60171 .4423 L
s
.60171 .4423 m
.60277 .44242 L
s
.5065 .67976 m .51402 .66501 L .51431 .67114 L .212 .113 .518 r
F
.50678 .68589 m .5065 .67976 L .51431 .67114 L F
.48538 .6745 m .5065 .67976 L .51431 .67114 L .654 .783 .943 r
F
.4774 .67952 m .5065 .67976 L .48538 .6745 L F
0 g
.49677 .68581 m
.5065 .67976 L
s
.42979 .57023 m .41407 .55468 L .4014 .55945 L .642 .739 .919 r
F
.43718 .56893 m .41407 .55468 L .42979 .57023 L F
.45512 .67988 m .46736 .68959 L .47764 .68566 L .653 .784 .944 r
F
.44913 .6812 m .46736 .68959 L .45512 .67988 L F
.46051 .57184 m .46117 .55372 L .4531 .56977 L .642 .739 .919 r
F
.46051 .57184 m .47611 .55795 L .46117 .55372 L F
.42283 .58028 m .4007 .5672 L .39113 .5737 L .641 .739 .92 r
F
.42915 .57795 m .4007 .5672 L .42283 .58028 L F
.4663 .58257 m .47558 .56572 L .45995 .57958 L F
.4663 .58257 m .48832 .57181 L .47558 .56572 L F
.60256 .53692 m .6009 .55406 L .61686 .55374 L .644 .737 .917 r
F
.5946 .53591 m .6009 .55406 L .60256 .53692 L F
.5946 .53591 m .58516 .55207 L .6009 .55406 L F
.37051 .67484 m .37833 .67695 L .37842 .68308 L .975 .719 .481 r
F
.37051 .67484 m .37044 .66868 L .37833 .67695 L F
0 g
.37833 .67695 m
.38542 .68097 L
s
.39454 .66498 m .37865 .67685 L .3997 .6705 L .654 .782 .942 r
F
.39454 .66498 m .3708 .66863 L .37865 .67685 L F
.42511 .6788 m .41809 .69087 L .43029 .68052 L .653 .784 .944 r
F
.42511 .6788 m .40776 .68748 L .41809 .69087 L F
.43718 .56893 m .42898 .55203 L .41407 .55468 L .642 .739 .919 r
F
.44514 .56878 m .42898 .55203 L .43718 .56893 L F
.39113 .5737 m .36395 .5638 L .35543 .57557 L .641 .739 .92 r
F
0 g
.35312 .58834 m
.35543 .57557 L
s
.4531 .56977 m .44507 .5517 L .44514 .56878 L .642 .739 .919 r
F
.4531 .56977 m .46117 .55372 L .44507 .5517 L F
.50678 .68589 m .51431 .67114 L .51461 .6773 L .212 .113 .518 r
F
.48563 .68065 m .50678 .68589 L .51461 .6773 L .653 .784 .944 r
F
.47764 .68566 m .50678 .68589 L .48563 .68065 L F
0 g
.49477 .69332 m
.50678 .68589 L
s
.58729 .53378 m .58516 .55207 L .5946 .53591 L .644 .737 .917 r
F
.58729 .53378 m .57065 .54789 L .58516 .55207 L F
.53371 .58497 m .5255 .56452 L .52508 .57229 L .986 .743 .482 r
F
0 g
.53371 .58497 m
.53613 .59799 L
s
.61062 .53675 m .61686 .55374 L .63203 .55112 L .644 .737 .917 r
F
.60256 .53692 m .61686 .55374 L .61062 .53675 L F
.4014 .55945 m .36473 .55605 L .39185 .56597 L .642 .739 .919 r
F
.66571 .56742 m .68204 .5499 L .68197 .55763 L .412 .24 .535 r
F
.6656 .57516 m .66571 .56742 L .68197 .55763 L F
.64547 .55422 m .66571 .56742 L .68197 .55763 L .643 .738 .918 r
F
.63198 .55899 m .66571 .56742 L .64547 .55422 L F
0 g
.65272 .57195 m
.66571 .56742 L
s
.44514 .56878 m .44507 .5517 L .42898 .55203 L .642 .739 .919 r
F
.49844 .57158 m .51116 .55308 L .48883 .56405 L F
.49844 .57158 m .5255 .56452 L .51116 .55308 L F
0 g
.52312 .55088 m
.52812 .5549 L
s
.42915 .57795 m .4134 .56245 L .4007 .5672 L .641 .739 .92 r
F
.43656 .57666 m .4134 .56245 L .42915 .57795 L F
.45995 .57958 m .4606 .56151 L .45252 .57751 L F
.45995 .57958 m .47558 .56572 L .4606 .56151 L F
.37058 .68102 m .37842 .68308 L .3785 .68923 L .975 .719 .481 r
F
.37058 .68102 m .37051 .67484 L .37842 .68308 L F
.39441 .67118 m .37842 .68308 L .3996 .67671 L .654 .783 .943 r
F
.39441 .67118 m .37051 .67484 L .37842 .68308 L F
0 g
.37842 .68308 m
.38555 .68712 L
s
.46028 .67789 m .47764 .68566 L .48563 .68065 L .653 .784 .944 r
F
.45512 .67988 m .47764 .68566 L .46028 .67789 L F
.6023 .54475 m .60063 .56193 L .6167 .56161 L .643 .738 .918 r
F
.59429 .54374 m .60063 .56193 L .6023 .54475 L F
.59429 .54374 m .58478 .55993 L .60063 .56193 L F
0 g
.44697 .62605 m
.44779 .59234 L
s
.43656 .57666 m .42834 .55981 L .4134 .56245 L .641 .739 .92 r
F
.44454 .57651 m .42834 .55981 L .43656 .57666 L F
.45252 .57751 m .44446 .55948 L .44454 .57651 L F
.45252 .57751 m .4606 .56151 L .44446 .55948 L F
0 g
.44055 .62595 m
.44144 .59201 L
s
.58692 .5416 m .58478 .55993 L .59429 .54374 L .643 .738 .918 r
F
.58692 .5416 m .57017 .55573 L .58478 .55993 L F
.61042 .54459 m .6167 .56161 L .63198 .55899 L F
.6023 .54475 m .6167 .56161 L .61042 .54459 L F
.58111 .53068 m .57065 .54789 L .58729 .53378 L .644 .737 .917 r
F
.58111 .53068 m .55832 .54177 L .57065 .54789 L F
.54796 .54968 m .53475 .56826 L .55739 .55736 L .642 .738 .919 r
F
0 g
.53475 .56826 m
.55338 .57729 L
s
.61827 .53541 m .63203 .55112 L .64542 .54636 L .644 .737 .917 r
F
.61062 .53675 m .63203 .55112 L .61827 .53541 L F
.4007 .5672 m .36395 .5638 L .39113 .5737 L .641 .739 .92 r
F
.6656 .57516 m .68197 .55763 L .6819 .56539 L .412 .24 .535 r
F
.64531 .56199 m .6656 .57516 L .6819 .56539 L .642 .738 .919 r
F
.63179 .56674 m .6656 .57516 L .64531 .56199 L F
0 g
.64541 .58214 m
.6656 .57516 L
s
.39191 .5401 m .37432 .54175 L .39654 .53773 L .601 .383 .557 r
F
.40232 .55186 m .38752 .54303 L .36592 .54849 L .643 .738 .918 r
F
.38752 .54303 m .38478 .54139 L .38001 .54318 L F
.38752 .54303 m .38001 .54318 L .36592 .54849 L F
.38478 .54139 m .37302 .54351 L .36592 .54849 L F
.37059 .55051 m .36551 .54834 L .36489 .55449 L .343 .165 .489 r
F
.37226 .54723 m .36551 .54834 L .37059 .55051 L F
.37204 .54951 m .37059 .55051 L .37188 .55107 L F
.37226 .54723 m .37059 .55051 L .37204 .54951 L F
.37204 .54951 m .37223 .54756 L .37356 .54947 L .672 .445 .569 r
F
.37281 .54897 m .37356 .54947 L .37317 .54872 L .642 .738 .919 r
F
.37281 .54897 m .37204 .54951 L .37356 .54947 L F
.37265 .54334 m .37432 .54175 L .37417 .5433 L .672 .445 .569 r
F
.36934 .5434 m .37276 .54227 L .37265 .54334 L F
.37276 .54227 m .37432 .54175 L .37265 .54334 L F
.37304 .54351 m .37303 .5435 L .37302 .54351 L .643 .738 .918 r
F
.37417 .5433 m .37432 .54175 L .39191 .5401 L .601 .383 .557 r
F
.38478 .54139 m .37303 .5435 L .37304 .54351 L .643 .738 .918 r
F
.3653 .52426 m .37419 .54149 L .3963 .5375 L F
.38478 .54139 m .38007 .53858 L .37303 .5435 L F
.37223 .54756 m .37417 .5433 L .37356 .54947 L .672 .445 .569 r
F
.37226 .54723 m .37265 .54334 L .36551 .54834 L .343 .165 .489 r
F
.36934 .5434 m .37265 .54334 L .37223 .54756 L .672 .445 .569 r
F
.37265 .54334 m .37417 .5433 L .37223 .54756 L F
.4149 .5471 m .38868 .54069 L .40232 .55186 L .643 .738 .918 r
F
.38868 .54069 m .38007 .53858 L .38478 .54139 L F
.38868 .54069 m .38478 .54139 L .40232 .55186 L F
.39191 .5401 m .39654 .53773 L .3964 .53929 L .601 .383 .557 r
F
.38016 .52153 m .3963 .5375 L .41532 .53021 L .643 .738 .918 r
F
.3653 .52426 m .3963 .5375 L .38016 .52153 L F
.39116 .54129 m .39901 .5313 L .38007 .53858 L F
.4149 .5471 m .40409 .53635 L .39116 .54129 L F
.41165 .53346 m .39654 .53773 L .41566 .53042 L .504 .3 .537 r
F
.3964 .53929 m .39654 .53773 L .41165 .53346 L F
.40409 .53635 m .39901 .5313 L .39116 .54129 L .643 .738 .918 r
F
.42971 .54446 m .40763 .535 L .4149 .5471 L F
.40763 .535 m .39901 .5313 L .40409 .53635 L F
.40763 .535 m .40409 .53635 L .4149 .5471 L F
.41165 .53346 m .41566 .53042 L .41552 .53198 L .504 .3 .537 r
F
.42728 .52385 m .42287 .52634 L .4304 .52021 L .349 .172 .494 r
F
.42287 .52634 m .41566 .53042 L .42295 .52537 L F
.42287 .52634 m .42295 .52537 L .4304 .52021 L F
.41552 .53198 m .41566 .53042 L .42287 .52634 L F
.42281 .52694 m .42287 .52634 L .42728 .52385 L F
.41552 .53198 m .42287 .52634 L .42281 .52694 L F
.44568 .54412 m .44561 .52671 L .42242 .52721 L .643 .738 .918 r
F
.42189 .52757 m .42242 .52721 L .4214 .52723 L F
.44568 .54412 m .42242 .52721 L .42189 .52757 L F
.44052 .53276 m .44561 .52644 L .42281 .52694 L .671 .443 .567 r
F
.445 .53424 m .44512 .53267 L .44052 .53276 L F
.44512 .53267 m .44561 .52644 L .44052 .53276 L F
.445 .53424 m .42281 .52694 L .42277 .52743 L F
.42971 .54446 m .42165 .52774 L .40981 .53593 L .643 .738 .918 r
F
.44568 .54412 m .4214 .52723 L .42971 .54446 L F
.445 .53424 m .42277 .52743 L .42215 .53473 L .671 .443 .567 r
F
.41498 .53818 m .42728 .52385 L .42976 .52801 L .349 .172 .494 r
F
.41498 .53818 m .41552 .53198 L .42728 .52385 L F
.42277 .52743 m .42281 .52694 L .42127 .52697 L .671 .443 .567 r
F
.39288 .51658 m .41532 .53021 L .42999 .52006 L .643 .738 .918 r
F
.38016 .52153 m .41532 .53021 L .39288 .51658 L F
.41588 .53137 m .4214 .52723 L .40254 .53066 L F
.41588 .53137 m .40254 .53066 L .39901 .5313 L F
.40981 .53593 m .41588 .53137 L .39901 .5313 L F
.42165 .52774 m .4214 .52723 L .40981 .53593 L F
.39583 .54548 m .41165 .53346 L .41498 .53818 L .504 .3 .537 r
F
.41165 .53346 m .41552 .53198 L .41498 .53818 L F
.39583 .54548 m .3964 .53929 L .41165 .53346 L F
.42074 .53319 m .41498 .53818 L .42229 .53315 L .642 .738 .919 r
F
.41619 .53401 m .39876 .53106 L .39819 .53726 L .6 .382 .556 r
F
.40994 .53514 m .41498 .53818 L .42074 .53319 L .642 .738 .919 r
F
.41619 .53401 m .42127 .52697 L .39876 .53106 L .6 .382 .556 r
F
.4222 .53413 m .41498 .53818 L .42229 .53315 L .349 .172 .494 r
F
.41484 .53975 m .41498 .53818 L .4222 .53413 L F
.42215 .53473 m .4222 .53413 L .42663 .53164 L F
.41484 .53975 m .4222 .53413 L .42215 .53473 L F
.44507 .5517 m .445 .53424 L .42215 .53473 L .642 .739 .919 r
F
.42135 .53527 m .42215 .53473 L .42061 .53476 L F
.44507 .5517 m .42215 .53473 L .42135 .53527 L F
.4399 .54059 m .445 .53424 L .42215 .53473 L .671 .443 .567 r
F
.44439 .54207 m .44451 .54049 L .4399 .54059 L F
.44451 .54049 m .445 .53424 L .4399 .54059 L F
.44439 .54207 m .42215 .53473 L .42211 .53522 L F
.41097 .54123 m .39583 .54548 L .41498 .53818 L .504 .3 .537 r
F
.40924 .54361 m .41357 .54024 L .40711 .5427 L .642 .739 .919 r
F
.39568 .54704 m .39583 .54548 L .41097 .54123 L .504 .3 .537 r
F
.37356 .54947 m .39191 .5401 L .39583 .54548 L .601 .383 .557 r
F
.39191 .5401 m .3964 .53929 L .39583 .54548 L F
.39089 .54062 m .39061 .54034 L .39191 .5401 L F
.37356 .54947 m .39061 .54034 L .39089 .54062 L F
.37356 .54947 m .37417 .5433 L .39061 .54034 L F
.39048 .54021 m .39583 .54548 L .40329 .53531 L .642 .738 .919 r
F
.39434 .53874 m .37973 .53838 L .37913 .54456 L .503 .298 .535 r
F
.38463 .54072 m .37356 .54947 L .39583 .54548 L .642 .738 .919 r
F
.3777 .54556 m .37973 .53838 L .37265 .54334 L .343 .165 .489 r
F
.37913 .54456 m .37973 .53838 L .3777 .54556 L F
.37317 .54872 m .37356 .54947 L .38463 .54072 L .642 .738 .919 r
F
.37898 .54612 m .37265 .54334 L .37226 .54723 L .343 .165 .489 r
F
.34876 .55772 m .34958 .54997 L .37356 .54947 L .672 .445 .569 r
F
.39118 .54785 m .37356 .54947 L .39583 .54548 L .601 .383 .557 r
F
.4014 .55945 m .38678 .55076 L .36473 .55605 L .642 .739 .919 r
F
.38678 .55076 m .38404 .54913 L .37904 .55092 L F
.38678 .55076 m .37904 .55092 L .36473 .55605 L F
.38404 .54913 m .37142 .55139 L .36473 .55605 L F
.37188 .55107 m .37059 .55051 L .36473 .55605 L .343 .165 .489 r
F
.37059 .55051 m .36489 .55449 L .36473 .55605 L F
.36982 .55827 m .36473 .55605 L .3641 .56224 L F
.3715 .55497 m .36473 .55605 L .36982 .55827 L F
.37127 .55726 m .36982 .55827 L .37111 .55883 L F
.3715 .55497 m .36982 .55827 L .37127 .55726 L F
.37127 .55726 m .37146 .55531 L .37279 .55723 L .672 .445 .569 r
F
.37204 .55673 m .37279 .55723 L .3724 .55648 L .641 .739 .92 r
F
.37204 .55673 m .37127 .55726 L .37279 .55723 L F
.37188 .55107 m .37356 .54947 L .37341 .55104 L .672 .445 .569 r
F
.36857 .55113 m .37199 .55 L .37188 .55107 L F
.37199 .55 m .37356 .54947 L .37188 .55107 L F
.37341 .55104 m .37356 .54947 L .39118 .54785 L .601 .383 .557 r
F
.38404 .54913 m .37898 .54612 L .37859 .55011 L .642 .739 .919 r
F
.37227 .55124 m .37188 .55107 L .37142 .55139 L F
.37146 .55531 m .37341 .55104 L .37279 .55723 L .672 .445 .569 r
F
.3715 .55497 m .37188 .55107 L .36473 .55605 L .343 .165 .489 r
F
.36857 .55113 m .37188 .55107 L .37146 .55531 L .672 .445 .569 r
F
.37188 .55107 m .37341 .55104 L .37146 .55531 L F
.41407 .55468 m .38822 .54838 L .4014 .55945 L .642 .739 .919 r
F
.38822 .54838 m .37898 .54612 L .38404 .54913 L F
.38822 .54838 m .38404 .54913 L .4014 .55945 L F
.39118 .54785 m .39583 .54548 L .39568 .54704 L .601 .383 .557 r
F
.40329 .53531 m .39583 .54548 L .41498 .53818 L .642 .738 .919 r
F
.34925 .52461 m .37419 .54149 L .3653 .52426 L .643 .738 .918 r
F
.39434 .53874 m .39876 .53106 L .37973 .53838 L .503 .298 .535 r
F
.3646 .53221 m .38678 .54163 L .37957 .52948 L .642 .738 .919 r
F
.38678 .54163 m .39583 .54548 L .39048 .54021 L F
.38678 .54163 m .39048 .54021 L .37957 .52948 L F
.39805 .53883 m .39819 .53726 L .39434 .53874 L .503 .298 .535 r
F
.39819 .53726 m .39876 .53106 L .39434 .53874 L F
.39063 .54896 m .39805 .53883 L .37898 .54612 L .642 .739 .919 r
F
.41407 .55468 m .40339 .54411 L .39063 .54896 L F
.40339 .54411 m .39805 .53883 L .39063 .54896 L F
.40924 .54361 m .40711 .5427 L .40549 .54619 L F
.40711 .5427 m .39805 .53883 L .40339 .54411 L F
.40711 .5427 m .40339 .54411 L .40549 .54619 L F
.42898 .55203 m .42098 .53553 L .40924 .54361 L F
.41097 .54123 m .41498 .53818 L .41484 .53975 L .504 .3 .537 r
F
.42098 .53553 m .42061 .53476 L .40924 .54361 L .642 .739 .919 r
F
.42898 .55203 m .40924 .54361 L .41407 .55468 L F
.40924 .54361 m .40549 .54619 L .41407 .55468 L F
.39511 .55325 m .41097 .54123 L .4143 .54598 L .504 .3 .537 r
F
.41097 .54123 m .41484 .53975 L .4143 .54598 L F
.37279 .55723 m .39118 .54785 L .39511 .55325 L .601 .383 .557 r
F
.39118 .54785 m .39568 .54704 L .39511 .55325 L F
.37279 .55723 m .37341 .55104 L .39118 .54785 L F
.38604 .54942 m .37279 .55723 L .39511 .55325 L .641 .739 .92 r
F
.37963 .55185 m .37279 .55723 L .38604 .54942 L F
.39511 .55325 m .39568 .54704 L .41097 .54123 L .504 .3 .537 r
F
.39361 .54653 m .37898 .54612 L .37837 .55233 L .503 .298 .535 r
F
.37624 .54657 m .37226 .54723 L .37204 .54951 L .343 .165 .489 r
F
.34958 .54997 m .3504 .54225 L .37432 .54175 L .672 .445 .569 r
F
.34925 .52461 m .35038 .54199 L .37419 .54149 L .643 .738 .918 r
F
.3646 .53221 m .37317 .54872 L .38463 .54072 L .642 .738 .919 r
F
.39805 .53883 m .39434 .53874 L .37898 .54612 L .503 .298 .535 r
F
.39434 .53874 m .37913 .54456 L .37898 .54612 L F
.37957 .52948 m .39048 .54021 L .40329 .53531 L .642 .738 .919 r
F
.40501 .54371 m .39511 .55325 L .4143 .54598 L .641 .739 .92 r
F
.40171 .5443 m .39511 .55325 L .40501 .54371 L F
.37957 .52948 m .41498 .53818 L .39238 .52452 L .642 .738 .919 r
F
.40711 .5427 m .42061 .53476 L .39805 .53883 L .642 .739 .919 r
F
.41357 .54024 m .42061 .53476 L .40711 .5427 L F
.44507 .5517 m .42061 .53476 L .42898 .55203 L F
.4143 .54598 m .41484 .53975 L .42264 .53439 L .349 .172 .494 r
F
.44439 .54207 m .42211 .53522 L .42149 .54255 L .671 .443 .567 r
F
.42246 .5365 m .42256 .53536 L .42325 .53557 L .349 .172 .494 r
F
.42256 .53536 m .42264 .53439 L .42325 .53557 L F
.42325 .53557 m .42264 .53439 L .42663 .53164 L F
.4143 .54598 m .42264 .53439 L .42246 .5365 L F
.41551 .54182 m .39805 .53883 L .39748 .54506 L .6 .382 .556 r
F
.38975 .548 m .39511 .55325 L .40259 .54312 L .641 .739 .92 r
F
.4143 .54598 m .42663 .53164 L .4291 .53584 L .349 .172 .494 r
F
.42007 .541 m .4143 .54598 L .42162 .54097 L .641 .739 .92 r
F
.41551 .54182 m .42061 .53476 L .39805 .53883 L .6 .382 .556 r
F
.42007 .541 m .42061 .53476 L .41551 .54182 L F
.40649 .54129 m .40925 .54295 L .42007 .541 L .641 .739 .92 r
F
.40925 .54295 m .4143 .54598 L .42007 .541 L F
.41994 .54258 m .42007 .541 L .41551 .54182 L .6 .382 .556 r
F
.39361 .54653 m .39805 .53883 L .37898 .54612 L .503 .298 .535 r
F
.39748 .54506 m .39805 .53883 L .39361 .54653 L F
.42061 .53476 m .41619 .53401 L .39805 .53883 L .6 .382 .556 r
F
.41619 .53401 m .39819 .53726 L .39805 .53883 L F
.3788 .53729 m .4143 .54598 L .39164 .53235 L .641 .739 .92 r
F
.41994 .54258 m .41551 .54182 L .39733 .54664 L .6 .382 .556 r
F
.41551 .54182 m .39748 .54506 L .39733 .54664 L F
.40259 .54312 m .40171 .5443 L .40501 .54371 L .641 .739 .92 r
F
.3788 .53729 m .38975 .548 L .40259 .54312 L F
.39733 .54664 m .39748 .54506 L .39361 .54653 L .503 .298 .535 r
F
.37694 .55333 m .37898 .54612 L .37188 .55107 L .343 .165 .489 r
F
.37837 .55233 m .37898 .54612 L .37694 .55333 L F
.37898 .54612 m .37624 .54657 L .37188 .55107 L F
.37898 .54612 m .37913 .54456 L .3777 .54556 L F
.34958 .54997 m .36934 .5434 L .37223 .54756 L .672 .445 .569 r
F
.34958 .54997 m .37223 .54756 L .37204 .54951 L F
.33306 .52257 m .35038 .54199 L .34925 .52461 L .643 .738 .918 r
F
.34844 .53255 m .37281 .54897 L .3646 .53221 L .642 .738 .919 r
F
.37281 .54897 m .37317 .54872 L .3646 .53221 L F
.3638 .54001 m .39511 .55325 L .3788 .53729 L .641 .739 .92 r
F
.39733 .54664 m .39361 .54653 L .37822 .5539 L .503 .298 .535 r
F
.3724 .55648 m .37279 .55723 L .38389 .54851 L .641 .739 .92 r
F
.39361 .54653 m .37837 .55233 L .37822 .5539 L .503 .298 .535 r
F
.38389 .54851 m .37963 .55185 L .38604 .54942 L .641 .739 .92 r
F
.37822 .5539 m .37188 .55107 L .3715 .55497 L .343 .165 .489 r
F
.37822 .5539 m .37548 .55434 L .37111 .55883 L F
.37548 .55434 m .3715 .55497 L .37127 .55726 L F
.37548 .55434 m .37127 .55726 L .37111 .55883 L F
.37624 .54657 m .37204 .54951 L .37188 .55107 L F
.32538 .54694 m .3504 .54225 L .34958 .54997 L .731 .498 .575 r
F
.32538 .54694 m .32625 .53922 L .3504 .54225 L F
.33306 .52257 m .32635 .53897 L .35038 .54199 L .643 .738 .918 r
F
.34844 .53255 m .34958 .54997 L .37204 .54951 L .642 .738 .919 r
F
.34844 .53255 m .37204 .54951 L .37281 .54897 L F
.3638 .54001 m .3724 .55648 L .38389 .54851 L .641 .739 .92 r
F
.37822 .5539 m .37837 .55233 L .37694 .55333 L .343 .165 .489 r
F
.34876 .55772 m .36857 .55113 L .37146 .55531 L .672 .445 .569 r
F
.34876 .55772 m .37146 .55531 L .37127 .55726 L F
.33212 .5305 m .34958 .54997 L .34844 .53255 L .642 .738 .919 r
F
.34761 .54035 m .37204 .55673 L .3638 .54001 L .641 .739 .92 r
F
.37204 .55673 m .3724 .55648 L .3638 .54001 L F
.3245 .55469 m .34958 .54997 L .34876 .55772 L .731 .498 .575 r
F
.3245 .55469 m .32538 .54694 L .34958 .54997 L F
.33212 .5305 m .32538 .54694 L .34958 .54997 L .642 .738 .919 r
F
.34761 .54035 m .34876 .55772 L .37127 .55726 L .641 .739 .92 r
F
.34761 .54035 m .37127 .55726 L .37204 .55673 L F
.37111 .55883 m .36982 .55827 L .36395 .5638 L .343 .165 .489 r
F
.36982 .55827 m .3641 .56224 L .36395 .5638 L F
.42211 .53522 m .42215 .53473 L .42061 .53476 L .671 .443 .567 r
F
.42149 .54255 m .42061 .53476 L .41994 .54258 L F
.42211 .53522 m .42061 .53476 L .42149 .54255 L F
.42074 .53319 m .42127 .52697 L .41619 .53401 L .6 .382 .556 r
F
.40719 .53347 m .40994 .53514 L .42074 .53319 L .642 .738 .919 r
F
.39164 .53235 m .40649 .54129 L .4291 .53584 L .641 .739 .92 r
F
.40649 .54129 m .42162 .54097 L .4291 .53584 L F
.42663 .53164 m .42976 .52801 L .42962 .52958 L .349 .172 .494 r
F
.42663 .53164 m .42962 .52958 L .4291 .53584 L F
.42663 .53164 m .4222 .53413 L .42976 .52801 L F
.4222 .53413 m .42229 .53315 L .42976 .52801 L F
.42061 .53476 m .42074 .53319 L .41619 .53401 L .6 .382 .556 r
F
.42215 .53473 m .42197 .53316 L .42061 .53476 L .671 .443 .567 r
F
.42197 .53316 m .42127 .52697 L .42074 .53319 L F
.42197 .53316 m .42074 .53319 L .42061 .53476 L F
.42277 .52743 m .42127 .52697 L .42215 .53473 L F
.40719 .53347 m .42074 .53319 L .42976 .52801 L .642 .738 .919 r
F
.42074 .53319 m .42229 .53315 L .42277 .53282 L F
.42074 .53319 m .42277 .53282 L .42976 .52801 L F
.39238 .52452 m .40719 .53347 L .42976 .52801 L F
.42728 .52385 m .4304 .52021 L .43027 .52178 L .349 .172 .494 r
F
.42728 .52385 m .43027 .52178 L .42976 .52801 L F
.44454 .57651 m .44446 .55948 L .42834 .55981 L .641 .739 .92 r
F
.49796 .57933 m .5107 .56088 L .48832 .57181 L F
.49796 .57933 m .52508 .57229 L .5107 .56088 L F
0 g
.44649 .64582 m
.44697 .62605 L
s
.48911 .55643 m .49228 .53621 L .47649 .55035 L .643 .738 .918 r
F
.48911 .55643 m .51128 .54549 L .49228 .53621 L F
0 g
.44002 .64586 m
.44055 .62595 L
s
.39452 .67737 m .3785 .68923 L .39971 .68288 L .653 .784 .944 r
F
.39452 .67737 m .37058 .68102 L .3785 .68923 L F
0 g
.3785 .68923 m
.39061 .69605 L
s
.42111 .67647 m .40776 .68748 L .42511 .6788 L .653 .784 .944 r
F
.42111 .67647 m .39971 .68288 L .40776 .68748 L F
.51431 .67114 m .51402 .66501 L .51705 .65574 L 0 0 .336 r
F
0 g
.5078 .6719 m
.51402 .66501 L
s
.35622 .56785 m
.36375 .55742 L
s
.35701 .56018 m
.35892 .55751 L
s
.48538 .6745 m .51431 .67114 L .49051 .66871 L .654 .783 .943 r
F
.60204 .55253 m .60037 .56966 L .61648 .56934 L .642 .738 .919 r
F
.59401 .55151 m .60037 .56966 L .60204 .55253 L F
.59401 .55151 m .58449 .56766 L .60037 .56966 L F
.58069 .53849 m .57017 .55573 L .58692 .5416 L .643 .738 .918 r
F
.58069 .53849 m .55774 .5496 L .57017 .55573 L F
.58663 .54938 m .58449 .56766 L .59401 .55151 L .642 .738 .919 r
F
.58663 .54938 m .56984 .56347 L .58449 .56766 L F
.61019 .55237 m .61648 .56934 L .63179 .56674 L F
.60204 .55253 m .61648 .56934 L .61019 .55237 L F
.61813 .54324 m .63198 .55899 L .64547 .55422 L .643 .738 .918 r
F
.61042 .54459 m .63198 .55899 L .61813 .54324 L F
.51217 .5361 m .5214 .54144 L .52096 .54915 L .986 .743 .482 r
F
.51217 .5361 m .51262 .52836 L .5214 .54144 L F
0 g
.5214 .54144 m
.52848 .54716 L
s
.54329 .52536 m .5218 .54133 L .54898 .5341 L .644 .737 .917 r
F
.54329 .52536 m .51308 .52831 L .5218 .54133 L F
.48883 .56405 m .49202 .54378 L .47611 .55795 L .642 .739 .919 r
F
.48883 .56405 m .51116 .55308 L .49202 .54378 L F
.68197 .55763 m .68204 .5499 L .69325 .53786 L .211 .084 .48 r
F
0 g
.67098 .5566 m
.68204 .5499 L
s
.51431 .67114 m .51705 .65574 L .51735 .66191 L 0 0 .336 r
F
.51461 .6773 m .51431 .67114 L .51735 .66191 L F
.49051 .66871 m .51431 .67114 L .51735 .66191 L .654 .783 .943 r
F
0 g
.50805 .67806 m
.51431 .67114 L
s
.65614 .53974 m .68166 .54975 L .69281 .53777 L .644 .737 .917 r
F
.64542 .54636 m .68166 .54975 L .65614 .53974 L F
.48563 .68065 m .51461 .6773 L .49077 .67488 L .653 .784 .944 r
F
.46426 .67536 m .48563 .68065 L .49077 .67488 L F
.46028 .67789 m .48563 .68065 L .46426 .67536 L F
.41841 .66751 m .39441 .67118 L .3996 .67671 L .654 .783 .943 r
F
.57646 .52679 m .55832 .54177 L .58111 .53068 L .644 .737 .917 r
F
.57646 .52679 m .54898 .5341 L .55832 .54177 L F
.625 .53299 m .64542 .54636 L .65614 .53974 L F
.61827 .53541 m .64542 .54636 L .625 .53299 L F
.5255 .56452 m .51162 .54532 L .51116 .55308 L .917 .667 .546 r
F
.52508 .57229 m .5255 .56452 L .51116 .55308 L F
0 g
.5255 .56452 m
.53411 .57723 L
s
.52269 .55862 m
.53475 .56826 L
s
.52335 .5628 m
.5255 .56452 L
s
.47649 .55035 m .46984 .52978 L .46166 .54614 L .643 .738 .918 r
F
.47649 .55035 m .49228 .53621 L .46984 .52978 L F
.49002 .66254 m .51667 .65575 L .49191 .65638 L .654 .782 .942 r
F
.76422 .54838 m .76411 .54066 L .78854 .54016 L .673 .448 .572 r
F
.74045 .54535 m .76411 .54066 L .76422 .54838 L .731 .495 .57 r
F
.74045 .54535 m .74039 .53763 L .76411 .54066 L F
.3674 .66574 m .37044 .66868 L .37051 .67484 L .949 .728 .264 r
F
.3674 .66574 m .36734 .65955 L .37044 .66868 L F
0 g
.37044 .66868 m
.37558 .67407 L
s
.3926 .65891 m .3708 .66863 L .39454 .66498 L .654 .782 .942 r
F
.3926 .65891 m .36771 .65954 L .3708 .66863 L F
.76766 .52299 m .76417 .5404 L .78848 .5399 L .644 .736 .916 r
F
.75176 .52094 m .76417 .5404 L .76766 .52299 L F
.75176 .52094 m .74056 .53738 L .76417 .5404 L F
.30243 .54056 m .32625 .53922 L .32538 .54694 L .785 .548 .579 r
F
.30243 .54056 m .30336 .53283 L .32625 .53922 L F
0 g
.32625 .53922 m
.32843 .53949 L
s
.51461 .6773 m .51735 .66191 L .51765 .66809 L 0 0 .336 r
F
.49077 .67488 m .51461 .6773 L .51765 .66809 L .653 .784 .944 r
F
0 g
.50678 .68589 m
.51461 .6773 L
s
.58038 .54628 m .56984 .56347 L .58663 .54938 L .642 .738 .919 r
F
.58038 .54628 m .55739 .55736 L .56984 .56347 L F
.31774 .51825 m .32635 .53897 L .33306 .52257 L .643 .738 .918 r
F
.31774 .51825 m .30357 .53261 L .32635 .53897 L F
.61791 .55103 m .63179 .56674 L .64531 .56199 L .642 .738 .919 r
F
.61019 .55237 m .63179 .56674 L .61791 .55103 L F
.41855 .6737 m .39971 .68288 L .42111 .67647 L .653 .784 .944 r
F
.41855 .6737 m .39452 .67737 L .39971 .68288 L F
.51171 .54387 m .51217 .5361 L .52096 .54915 L .986 .743 .482 r
F
.5426 .53315 m .52096 .54915 L .54833 .54191 L .643 .738 .918 r
F
.5426 .53315 m .51217 .5361 L .52096 .54915 L F
0 g
.52096 .54915 m
.52312 .55088 L
s
.4007 .5672 m .37822 .5539 L .36395 .5638 L .641 .739 .92 r
F
0 g
.35543 .57557 m
.36395 .5638 L
s
.4134 .56245 m .37822 .5539 L .4007 .5672 L .641 .739 .92 r
F
.48832 .57181 m .49151 .5516 L .47558 .56572 L F
.48832 .57181 m .5107 .56088 L .49151 .5516 L F
.68197 .55763 m .69325 .53786 L .6932 .54563 L .211 .084 .48 r
F
.6819 .56539 m .68197 .55763 L .6932 .54563 L F
.65627 .54759 m .68197 .55763 L .6932 .54563 L .643 .738 .918 r
F
.64547 .55422 m .68197 .55763 L .65627 .54759 L F
0 g
.6708 .56436 m
.68197 .55763 L
s
.71886 .53896 m .74039 .53763 L .74045 .54535 L .791 .544 .565 r
F
.71886 .53896 m .71885 .53122 L .74039 .53763 L F
0 g
.74039 .53763 m
.76411 .54066 L
s
.78871 .54789 m .78854 .54016 L .81218 .53613 L .61 .399 .57 r
F
.76422 .54838 m .78854 .54016 L .78871 .54789 L .673 .448 .572 r
F
0 g
.76411 .54066 m
.78854 .54016 L
s
.73735 .51661 m .74056 .53738 L .75176 .52094 L .644 .736 .916 r
F
.73735 .51661 m .71913 .53101 L .74056 .53738 L F
.78405 .52264 m .78848 .5399 L .812 .5359 L F
.76766 .52299 m .78848 .5399 L .78405 .52264 L F
.49051 .66871 m .51735 .66191 L .49242 .66254 L .654 .783 .943 r
F
0 g
.36395 .5638 m
.37111 .55883 L
s
.57601 .53459 m .55774 .5496 L .58069 .53849 L .643 .738 .918 r
F
.57601 .53459 m .54833 .54191 L .55774 .5496 L F
.36747 .67195 m .37051 .67484 L .37058 .68102 L .949 .728 .264 r
F
.36747 .67195 m .3674 .66574 L .37051 .67484 L F
.39246 .6651 m .37051 .67484 L .39441 .67118 L .654 .783 .943 r
F
.39246 .6651 m .3674 .66574 L .37051 .67484 L F
0 g
.37051 .67484 m
.37569 .68024 L
s
.6249 .54081 m .64547 .55422 L .65627 .54759 L .643 .738 .918 r
F
.61813 .54324 m .64547 .55422 L .6249 .54081 L F
.52508 .57229 m .51116 .55308 L .5107 .56088 L .917 .667 .546 r
F
0 g
.52508 .57229 m
.53371 .58497 L
s
.41747 .65827 m .3926 .65891 L .39454 .66498 L .654 .782 .942 r
F
.46166 .54614 m .44561 .52671 L .44568 .54412 L .643 .738 .918 r
F
.46166 .54614 m .46984 .52978 L .44561 .52671 L F
.47611 .55795 m .46941 .53733 L .46117 .55372 L .642 .739 .919 r
F
.47611 .55795 m .49202 .54378 L .46941 .53733 L F
.76434 .55614 m .76422 .54838 L .78871 .54789 L .673 .448 .572 r
F
.74051 .5531 m .76422 .54838 L .76434 .55614 L .731 .495 .57 r
F
.74051 .5531 m .74045 .54535 L .76422 .54838 L F
.76775 .53094 m .76422 .54838 L .78871 .54789 L .644 .737 .917 r
F
.75173 .52888 m .76422 .54838 L .76775 .53094 L F
.75173 .52888 m .74045 .54535 L .76422 .54838 L F
.3015 .54832 m .32538 .54694 L .3245 .55469 L .785 .548 .579 r
F
.3015 .54832 m .30243 .54056 L .32538 .54694 L F
.31669 .52617 m .32538 .54694 L .33212 .5305 L .642 .738 .919 r
F
.31669 .52617 m .30243 .54056 L .32538 .54694 L F
0 g
.32538 .54694 m
.34824 .5498 L
s
.54221 .54094 m .52053 .55689 L .54796 .54968 L .642 .738 .919 r
F
.54221 .54094 m .51171 .54387 L .52053 .55689 L F
0 g
.52053 .55689 m
.52269 .55862 L
s
.49077 .67488 m .51765 .66809 L .49268 .66873 L .653 .784 .944 r
F
.46679 .67246 m .49077 .67488 L .49268 .66873 L F
.46426 .67536 m .49077 .67488 L .46679 .67246 L F
.6819 .56539 m .6932 .54563 L .69316 .55343 L .211 .084 .48 r
F
.65614 .55538 m .6819 .56539 L .69316 .55343 L .642 .738 .919 r
F
.64531 .56199 m .6819 .56539 L .65614 .55538 L F
0 g
.6656 .57516 m
.6819 .56539 L
s
.39256 .6713 m .37058 .68102 L .39452 .67737 L .653 .784 .944 r
F
.39256 .6713 m .36747 .67195 L .37058 .68102 L F
0 g
.37058 .68102 m
.3785 .68923 L
s
.71887 .54672 m .74045 .54535 L .74051 .5531 L .791 .544 .565 r
F
.71887 .54672 m .71886 .53896 L .74045 .54535 L F
.73722 .52454 m .74045 .54535 L .75173 .52888 L .644 .737 .917 r
F
.73722 .52454 m .71886 .53896 L .74045 .54535 L F
0 g
.74045 .54535 m
.76422 .54838 L
s
.78871 .54789 m .81218 .53613 L .8124 .54388 L .61 .399 .57 r
F
.78888 .55565 m .78871 .54789 L .8124 .54388 L F
.76434 .55614 m .78871 .54789 L .78888 .55565 L .673 .448 .572 r
F
.78425 .53059 m .78871 .54789 L .8124 .54388 L .644 .737 .917 r
F
.76775 .53094 m .78871 .54789 L .78425 .53059 L F
0 g
.76422 .54838 m
.78871 .54789 L
s
.28219 .53119 m .30336 .53283 L .30243 .54056 L .84 .601 .578 r
F
.28219 .53119 m .28317 .52344 L .30336 .53283 L F
0 g
.30336 .53283 m
.30863 .5343 L
s
.41749 .66446 m .39441 .67118 L .41841 .66751 L .654 .783 .943 r
F
.41749 .66446 m .39246 .6651 L .39441 .67118 L F
.33126 .5383 m .34876 .55772 L .34761 .54035 L .641 .739 .92 r
F
.33126 .5383 m .3245 .55469 L .34876 .55772 L F
0 g
.34876 .55772 m
.37127 .55726 L
s
.30429 .51192 m .30357 .53261 L .31774 .51825 L .643 .738 .918 r
F
.30429 .51192 m .28348 .52327 L .30357 .53261 L F
.5757 .54239 m .55739 .55736 L .58038 .54628 L .642 .738 .919 r
F
.5757 .54239 m .54796 .54968 L .55739 .55736 L F
.62469 .54861 m .64531 .56199 L .65614 .55538 L F
.61791 .55103 m .64531 .56199 L .62469 .54861 L F
.57368 .52239 m .54898 .5341 L .57646 .52679 L .644 .737 .917 r
F
.57368 .52239 m .54329 .52536 L .54898 .5341 L F
.60537 .52245 m .60256 .53692 L .60332 .53691 L F
.60611 .52446 m .60332 .53691 L .61062 .53675 L F
.60537 .52245 m .60332 .53691 L .60611 .52446 L F
.60664 .50637 m .60679 .50564 L .60715 .5198 L 0 0 .235 r
F
.60663 .52212 m .61062 .53675 L .61446 .53608 L .644 .737 .917 r
F
.60983 .52577 m .61446 .53608 L .61827 .53541 L F
.60663 .52212 m .61446 .53608 L .60983 .52577 L F
.60653 .52258 m .61062 .53675 L .60663 .52212 L F
.60618 .50698 m .60664 .50637 L .607 .52048 L .163 .05 .467 r
F
.60596 .52174 m .61062 .53675 L .60628 .52172 L .644 .737 .917 r
F
.60551 .52228 m .61062 .53675 L .60596 .52174 L F
.60517 .52189 m .61062 .53675 L .60534 .52178 L F
.60545 .50749 m .60597 .52139 L .60581 .52149 L .402 .228 .528 r
F
.60282 .50806 m .60441 .50788 L .60476 .52183 L .648 .418 .556 r
F
.60282 .50806 m .60476 .52183 L .60352 .52191 L F
.60618 .50698 m .60664 .52092 L .60654 .52104 L .163 .05 .467 r
F
.60618 .50698 m .607 .52048 L .60664 .52092 L F
.60664 .50637 m .60715 .5198 L .60703 .52033 L 0 0 .235 r
F
.60664 .50637 m .60703 .52033 L .607 .52048 L F
.60679 .50564 m .60638 .50471 L .60675 .5189 L .978 .72 .315 r
F
.60691 .52114 m .60884 .52356 L .6081 .52192 L .644 .737 .917 r
F
.60441 .50788 m .605 .52175 L .60476 .52183 L .539 .333 .549 r
F
.60534 .52178 m .60551 .52228 L .60596 .52174 L .644 .737 .917 r
F
.60513 .5218 m .60517 .52189 L .60534 .52178 L F
.60441 .50788 m .60545 .50749 L .60581 .52149 L .539 .333 .549 r
F
.60603 .52142 m .60569 .52156 L .60628 .52172 L .644 .737 .917 r
F
.60569 .52156 m .60513 .5218 L .60534 .52178 L F
.60569 .52156 m .60534 .52178 L .60628 .52172 L F
.60545 .50749 m .60618 .50698 L .60654 .52104 L .402 .228 .528 r
F
.60441 .50788 m .60581 .52149 L .605 .52175 L .539 .333 .549 r
F
.60425 .5194 m .6051 .52172 L .60603 .52142 L .644 .737 .917 r
F
.6051 .52172 m .60513 .5218 L .60603 .52142 L F
.60665 .52097 m .60603 .52142 L .60691 .52114 L F
.60545 .50749 m .60654 .52104 L .60597 .52139 L .402 .228 .528 r
F
.60425 .5194 m .60599 .52138 L .60665 .52097 L .644 .737 .917 r
F
.60599 .52138 m .60603 .52142 L .60665 .52097 L F
.60603 .52142 m .61827 .53541 L .60691 .52114 L F
.60628 .52172 m .60653 .52258 L .60663 .52212 L F
.60425 .5194 m .625 .53299 L .62574 .53252 L F
.61129 .52216 m .62574 .53252 L .63034 .52963 L F
.60425 .5194 m .62574 .53252 L .61129 .52216 L F
.60528 .52255 m .60256 .53692 L .60537 .52245 L F
.60505 .52227 m .60256 .53692 L .60533 .52232 L F
.60401 .52188 m .60399 .52209 L .60513 .5218 L F
.60399 .52209 m .60256 .53692 L .60505 .52227 L F
.60399 .52209 m .60505 .52227 L .60513 .5218 L F
.60618 .52588 m .60586 .52839 L .60893 .52767 L .667 .747 .91 r
F
.60458 .52485 m .60573 .52802 L .60618 .52588 L F
.60573 .52802 m .60586 .52839 L .60618 .52588 L F
.60874 .52033 m .63034 .52963 L .63394 .52556 L .644 .737 .917 r
F
.60425 .5194 m .61129 .52216 L .60874 .52033 L F
.61129 .52216 m .63034 .52963 L .60874 .52033 L F
.60638 .50471 m .60536 .50397 L .60573 .51817 L .906 .63 .507 r
F
.60127 .50783 m .60282 .50806 L .60317 .52194 L .749 .498 .552 r
F
.60127 .50783 m .60317 .52194 L .60195 .52172 L F
.60282 .50806 m .60352 .52191 L .60317 .52194 L .648 .418 .556 r
F
.59967 .50687 m .60031 .5074 L .60064 .52123 L .925 .648 .496 r
F
.59931 .50552 m .59933 .50625 L .59965 .5201 L .712 .567 0 r
F
.59994 .53045 m .5946 .53591 L .60011 .53661 L .644 .737 .917 r
F
.6027 .52532 m .5999 .52898 L .60354 .52676 L F
.5999 .52898 m .5946 .53591 L .59994 .53045 L F
.5999 .52898 m .59994 .53045 L .60354 .52676 L F
.60339 .52348 m .60242 .52485 L .60382 .52384 L F
.60242 .52485 m .5946 .53591 L .6027 .52532 L F
.60242 .52485 m .6027 .52532 L .60382 .52384 L F
.60354 .52676 m .59994 .53045 L .60256 .53692 L F
.59994 .53045 m .60011 .53661 L .60256 .53692 L F
.60266 .52213 m .60236 .52264 L .60393 .52271 L F
.60236 .52264 m .5946 .53591 L .60339 .52348 L F
.60236 .52264 m .60339 .52348 L .60393 .52271 L F
.60031 .5074 m .60127 .50783 L .60161 .52166 L .84 .573 .536 r
F
.60031 .5074 m .60161 .52166 L .60085 .52132 L F
.60127 .50783 m .60195 .52172 L .60161 .52166 L .749 .498 .552 r
F
.59967 .50687 m .60014 .52082 L .6 .5207 L .925 .648 .496 r
F
.59933 .50625 m .59973 .52024 L .59965 .5201 L .988 .718 .377 r
F
.59931 .50552 m .59964 .51957 L .59963 .51941 L .712 .567 0 r
F
.59931 .50552 m .59965 .5201 L .59964 .51957 L F
.59933 .50625 m .59967 .50687 L .6 .5207 L .988 .718 .377 r
F
.59933 .50625 m .6 .5207 L .59973 .52024 L F
.59967 .50687 m .60064 .52123 L .60014 .52082 L .925 .648 .496 r
F
.59987 .5046 m .59931 .50552 L .59963 .51941 L .07 0 .435 r
F
.60266 .52213 m .59268 .52969 L .5946 .53591 L .644 .737 .917 r
F
.60159 .52166 m .59345 .52856 L .60266 .52213 L F
.59345 .52856 m .58729 .53378 L .59268 .52969 L F
.59345 .52856 m .59268 .52969 L .60266 .52213 L F
.60031 .5074 m .60085 .52132 L .60064 .52123 L .84 .573 .536 r
F
.60425 .5194 m .58111 .53068 L .58729 .53378 L .644 .737 .917 r
F
.6024 .53538 m .60715 .53197 L .60729 .53502 L .671 .44 .562 r
F
.60295 .53803 m .59429 .54374 L .6023 .54475 L .643 .738 .918 r
F
.60287 .53802 m .59429 .54374 L .60295 .53803 L F
.59869 .53749 m .6024 .53538 L .60252 .53798 L .73 .486 .559 r
F
.6024 .53538 m .60227 .53233 L .60715 .53197 L .671 .44 .562 r
F
.59758 .535 m .60227 .53233 L .6024 .53538 L .73 .486 .559 r
F
.60296 .53797 m .60287 .53802 L .60295 .53803 L .643 .738 .918 r
F
.59945 .53804 m .59429 .54374 L .60296 .53797 L F
.60794 .53786 m .60345 .54473 L .61042 .54459 L F
.60319 .53796 m .6024 .53538 L .60729 .53502 L .671 .44 .562 r
F
.60261 .52863 m .60227 .53228 L .60713 .53192 L .667 .747 .91 r
F
.60274 .53172 m .6024 .53538 L .60729 .53502 L F
.6077 .53782 m .60729 .53502 L .61192 .53393 L .605 .389 .562 r
F
.60742 .53787 m .60345 .54473 L .60794 .53786 L .643 .738 .918 r
F
.60498 .53792 m .60489 .53832 L .60742 .53787 L F
.60489 .53832 m .60345 .54473 L .60742 .53787 L F
.61088 .53727 m .61192 .53393 L .61207 .53699 L .605 .389 .562 r
F
.60791 .53779 m .60742 .53787 L .60794 .53786 L .643 .738 .918 r
F
.6077 .53782 m .61192 .53393 L .61088 .53727 L .605 .389 .562 r
F
.60742 .53787 m .60729 .53502 L .6077 .53782 L F
.6068 .52073 m .607 .52048 L .60703 .52157 L .163 .05 .467 r
F
.6081 .52192 m .61827 .53541 L .625 .53299 L .644 .737 .917 r
F
.60884 .52356 m .61827 .53541 L .6081 .52192 L F
.60612 .52448 m .60893 .52767 L .61163 .52651 L .667 .747 .91 r
F
.60458 .52485 m .60893 .52767 L .60612 .52448 L F
.60612 .52448 m .61163 .52651 L .60747 .5239 L F
.60586 .52839 m .60713 .53192 L .61174 .53084 L F
.60893 .52767 m .61174 .53084 L .61578 .52911 L F
.60586 .52839 m .61174 .53084 L .60893 .52767 L F
.60627 .52755 m .6091 .53075 L .61181 .52959 L F
.60658 .52742 m .61181 .52959 L .60763 .52697 L F
.60627 .52755 m .60653 .52765 L .60658 .52742 L F
.60653 .52765 m .61181 .52959 L .60658 .52742 L F
.60612 .52306 m .60612 .52448 L .60747 .5239 L F
.605 .52175 m .60581 .52149 L .60584 .52297 L .539 .333 .549 r
F
.60584 .52297 m .60553 .52382 L .60593 .52294 L .667 .747 .91 r
F
.60505 .52327 m .60518 .52343 L .60584 .52297 L F
.60518 .52343 m .60553 .52382 L .60584 .52297 L F
.60593 .52294 m .60553 .52382 L .60612 .52306 L F
.60553 .52382 m .60612 .52448 L .60612 .52306 L F
.60518 .52343 m .60458 .52485 L .60612 .52448 L F
.6062 .52608 m .60627 .52755 L .60658 .52742 L F
.6062 .52608 m .60658 .52742 L .60678 .52644 L F
.60563 .52683 m .60627 .52755 L .6062 .52608 L F
.60261 .52863 m .60713 .53192 L .60586 .52839 L F
.60382 .52384 m .6027 .52532 L .60354 .52676 L .644 .737 .917 r
F
.60295 .52497 m .60261 .52863 L .60586 .52839 L .667 .747 .91 r
F
.60472 .52792 m .60601 .53148 L .6091 .53075 L F
.60295 .52497 m .60586 .52839 L .60458 .52485 L F
.6048 .5279 m .6091 .53075 L .60627 .52755 L F
.60472 .52792 m .60476 .52795 L .6048 .5279 L F
.60476 .52795 m .6091 .53075 L .6048 .5279 L F
.60678 .52644 m .60658 .52742 L .60763 .52697 L F
.6068 .52073 m .60703 .52157 L .60704 .52186 L .163 .05 .467 r
F
.6068 .52073 m .60704 .52186 L .6069 .52204 L F
.60679 .50564 m .60675 .5189 L .60706 .5196 L .978 .72 .315 r
F
.60679 .50564 m .60706 .5196 L .60715 .5198 L F
.61032 .51972 m .63394 .52556 L .63554 .52105 L .644 .737 .917 r
F
.60425 .5194 m .61752 .52215 L .61032 .51972 L F
.61752 .52215 m .63394 .52556 L .61032 .51972 L F
.60644 .52264 m .60747 .5239 L .60818 .52339 L .667 .747 .91 r
F
.60612 .52306 m .60747 .5239 L .60644 .52264 L F
.60597 .52139 m .60612 .52278 L .60602 .52284 L .402 .228 .528 r
F
.605 .52175 m .6052 .52322 L .60506 .52327 L .539 .333 .549 r
F
.60581 .52149 m .60587 .52295 L .60584 .52297 L .402 .228 .528 r
F
.60533 .52232 m .60528 .52255 L .60537 .52245 L .644 .737 .917 r
F
.60513 .5218 m .60505 .52227 L .60533 .52232 L F
.605 .52175 m .60584 .52297 L .6052 .52322 L .539 .333 .549 r
F
.60689 .52256 m .60818 .52339 L .60799 .52295 L .667 .747 .91 r
F
.60687 .52262 m .60818 .52339 L .60689 .52256 L F
.60703 .52033 m .60707 .52169 L .607 .52048 L 0 0 .235 r
F
.60683 .52281 m .60818 .52339 L .60687 .52262 L .667 .747 .91 r
F
.60695 .52567 m .60763 .52697 L .6083 .52649 L F
.60666 .52549 m .60691 .52587 L .60695 .52567 L F
.60691 .52587 m .60763 .52697 L .60695 .52567 L F
.60597 .52139 m .60654 .52104 L .60657 .52246 L .402 .228 .528 r
F
.60597 .52139 m .60657 .52246 L .60612 .52278 L F
.6068 .52073 m .6069 .52204 L .60687 .52208 L .163 .05 .467 r
F
.60664 .52092 m .60674 .52224 L .60669 .52231 L F
.60756 .52198 m .60853 .52314 L .60924 .52226 L .667 .747 .91 r
F
.60689 .52256 m .60799 .52295 L .60703 .5219 L F
.60703 .52033 m .60709 .5216 L .60707 .52169 L 0 0 .235 r
F
.60707 .52169 m .60704 .52184 L .607 .52048 L F
.607 .52048 m .60704 .52184 L .60704 .52186 L F
.60747 .5213 m .60924 .52226 L .60955 .5213 L .667 .747 .91 r
F
.60664 .52092 m .6068 .52073 L .60687 .52208 L .163 .05 .467 r
F
.60664 .52092 m .60687 .52208 L .60674 .52224 L F
.60425 .5194 m .60266 .52213 L .60393 .52271 L .644 .737 .917 r
F
.60703 .52033 m .60719 .52115 L .60709 .5216 L 0 0 .235 r
F
.60597 .52139 m .60602 .52284 L .60581 .52149 L .402 .228 .528 r
F
.60602 .52284 m .60587 .52295 L .60581 .52149 L F
.60476 .52183 m .60483 .52335 L .6048 .52337 L .539 .333 .549 r
F
.60505 .52327 m .60495 .52359 L .60518 .52343 L .667 .747 .91 r
F
.60495 .52359 m .60458 .52485 L .60518 .52343 L F
.60413 .52362 m .60458 .52485 L .60503 .52334 L F
.6048 .52337 m .60503 .52334 L .60505 .52327 L F
.60413 .52362 m .60503 .52334 L .6048 .52337 L F
.60352 .52191 m .60476 .52183 L .6048 .52337 L .648 .418 .556 r
F
.60393 .52271 m .60339 .52348 L .60382 .52384 L .644 .737 .917 r
F
.60352 .52191 m .6048 .52337 L .6036 .52352 L .648 .418 .556 r
F
.60416 .52369 m .60295 .52497 L .60458 .52485 L .667 .747 .91 r
F
.60321 .52356 m .60295 .52497 L .60416 .52369 L F
.60308 .52355 m .60308 .52358 L .60321 .52356 L F
.60308 .52358 m .60295 .52497 L .60321 .52356 L F
.60352 .52191 m .6036 .52352 L .60317 .52194 L .648 .418 .556 r
F
.60407 .52346 m .60321 .52356 L .60416 .52369 L .667 .747 .91 r
F
.60135 .52484 m .60261 .52863 L .60295 .52497 L F
.60308 .52804 m .60274 .53172 L .60601 .53148 L F
.59941 .52837 m .60227 .53228 L .60261 .52863 L F
.60135 .52484 m .59941 .52837 L .60261 .52863 L F
.60147 .52791 m .60274 .53172 L .60308 .52804 L F
.60308 .52804 m .60601 .53148 L .60472 .52792 L F
.60195 .52172 m .60317 .52194 L .60321 .52356 L .749 .498 .552 r
F
.60195 .52172 m .60321 .52356 L .60203 .52341 L F
.60305 .52394 m .60135 .52484 L .60295 .52497 L .667 .747 .91 r
F
.60329 .52129 m .60206 .52353 L .60305 .52394 L F
.60206 .52353 m .60135 .52484 L .60305 .52394 L F
.60085 .52132 m .60161 .52166 L .60165 .52336 L .84 .573 .536 r
F
.60252 .53798 m .6024 .53538 L .60319 .53796 L .671 .44 .562 r
F
.59869 .53749 m .59758 .535 L .6024 .53538 L .73 .486 .559 r
F
.59768 .53736 m .59758 .535 L .59869 .53749 L F
.59941 .52837 m .59748 .53189 L .60227 .53228 L .667 .747 .91 r
F
.60147 .52791 m .59952 .53146 L .60274 .53172 L F
.60233 .53004 m .60177 .53099 L .60362 .5311 L .643 .738 .918 r
F
.60425 .5194 m .59316 .52235 L .58111 .53068 L .644 .737 .917 r
F
.59316 .52235 m .57646 .52679 L .57976 .52955 L F
.59316 .52235 m .57976 .52955 L .58111 .53068 L F
.60102 .5039 m .59987 .5046 L .60021 .51857 L .438 .255 .533 r
F
.59758 .535 m .59745 .53195 L .60227 .53233 L .73 .486 .559 r
F
.59952 .53146 m .6024 .53538 L .60274 .53172 L .667 .747 .91 r
F
.59952 .53146 m .59758 .535 L .6024 .53538 L F
.60177 .53099 m .60001 .534 L .60262 .53245 L .643 .738 .918 r
F
.60001 .534 m .60006 .53592 L .60262 .53245 L F
.60337 .53372 m .59982 .53764 L .60296 .53797 L F
.59982 .53764 m .59945 .53804 L .60252 .53798 L F
.59982 .53764 m .60252 .53798 L .60296 .53797 L F
.59987 .52447 m .59941 .52837 L .60135 .52484 L .667 .747 .91 r
F
.60085 .52132 m .60165 .52336 L .60092 .52305 L .84 .573 .536 r
F
.60186 .5239 m .59987 .52447 L .60135 .52484 L .667 .747 .91 r
F
.60425 .5194 m .60159 .52166 L .60266 .52213 L .644 .737 .917 r
F
.60212 .52342 m .60112 .52331 L .60186 .5239 L .667 .747 .91 r
F
.60112 .52331 m .60075 .52365 L .60186 .5239 L F
.60075 .52365 m .59987 .52447 L .60103 .52414 L F
.60075 .52365 m .60103 .52414 L .60186 .5239 L F
.59316 .52235 m .57368 .52239 L .57646 .52679 L .644 .737 .917 r
F
.60425 .5194 m .59741 .52007 L .59316 .52235 L F
.59741 .52007 m .57368 .52239 L .59316 .52235 L F
.60161 .52166 m .6017 .52336 L .60165 .52336 L .749 .498 .552 r
F
.60114 .52329 m .60112 .52331 L .60212 .52342 L .667 .747 .91 r
F
.60274 .53172 m .60729 .53502 L .60601 .53148 L F
.60177 .53099 m .60262 .53245 L .60362 .5311 L .643 .738 .918 r
F
.60377 .5296 m .60233 .53004 L .60362 .5311 L F
.60359 .52956 m .60233 .53004 L .60377 .5296 L F
.60014 .52082 m .6002 .52257 L .6 .5207 L .925 .648 .496 r
F
.60112 .52331 m .59863 .52388 L .59987 .52447 L .667 .747 .91 r
F
.60111 .5233 m .59863 .52388 L .60112 .52331 L F
.60195 .52172 m .60203 .52341 L .60161 .52166 L .749 .498 .552 r
F
.60203 .52341 m .60177 .52337 L .60161 .52166 L F
.60114 .52329 m .60111 .5233 L .60112 .52331 L .667 .747 .91 r
F
.59997 .52313 m .59863 .52388 L .60111 .5233 L F
.60109 .52328 m .60111 .5233 L .60114 .52329 L F
.59997 .52313 m .60111 .5233 L .60109 .52328 L F
.60014 .52082 m .60064 .52123 L .60068 .52295 L .925 .648 .496 r
F
.60014 .52082 m .60068 .52295 L .6002 .52257 L F
.60177 .52337 m .6017 .52336 L .60161 .52166 L .749 .498 .552 r
F
.6002 .52257 m .60007 .52246 L .6 .5207 L .925 .648 .496 r
F
.59973 .52024 m .6 .5207 L .60004 .52245 L .988 .718 .377 r
F
.59973 .52024 m .60004 .52245 L .59978 .52199 L F
.6 .5207 m .60007 .52246 L .60004 .52245 L .925 .648 .496 r
F
.59973 .52024 m .59978 .52199 L .59965 .5201 L .988 .718 .377 r
F
.59971 .52246 m .59973 .5231 L .59997 .52313 L .667 .747 .91 r
F
.59997 .52313 m .59771 .52311 L .59863 .52388 L F
.59832 .52291 m .59771 .52311 L .59997 .52313 L F
.59987 .52447 m .59647 .52763 L .59941 .52837 L F
.59863 .52388 m .59647 .52763 L .59987 .52447 L F
.59647 .52763 m .59748 .53189 L .59941 .52837 L F
.59647 .52763 m .59308 .53079 L .59748 .53189 L F
.59999 .52754 m .59656 .53072 L .59952 .53146 L F
.59874 .52695 m .59656 .53072 L .59984 .52767 L F
.59984 .52746 m .59984 .52767 L .59999 .52754 L F
.59874 .52695 m .59984 .52767 L .59984 .52746 L F
.59987 .5046 m .59963 .51941 L .60008 .51875 L .07 0 .435 r
F
.58702 .52109 m .57297 .51776 L .57368 .52239 L .644 .737 .917 r
F
.60425 .5194 m .59656 .519 L .58702 .52109 L F
.59656 .519 m .57297 .51776 L .58702 .52109 L F
.60214 .50359 m .60102 .5039 L .60136 .51794 L .583 .366 .552 r
F
.60064 .52123 m .60071 .52297 L .60068 .52295 L .84 .573 .536 r
F
.60124 .52319 m .59997 .52313 L .60114 .52329 L .667 .747 .91 r
F
.60085 .52132 m .60092 .52305 L .60064 .52123 L .84 .573 .536 r
F
.60092 .52305 m .60071 .52297 L .60064 .52123 L F
.60329 .52129 m .60046 .52286 L .60124 .52319 L .667 .747 .91 r
F
.60046 .52286 m .59997 .52313 L .60124 .52319 L F
.60001 .534 m .59798 .53745 L .60006 .53592 L .643 .738 .918 r
F
.59798 .53745 m .59429 .54374 L .59876 .53768 L F
.59798 .53745 m .59876 .53768 L .60006 .53592 L F
.59443 .53642 m .59758 .535 L .59768 .53736 L .79 .534 .55 r
F
.60046 .52286 m .60023 .52277 L .60033 .52293 L .667 .747 .91 r
F
.59999 .52754 m .59952 .53146 L .60147 .52791 L F
.60033 .52293 m .59971 .52246 L .59997 .52313 L F
.6 .52236 m .59971 .52246 L .60033 .52293 L F
.59971 .52246 m .59716 .52222 L .59771 .52311 L F
.60085 .52674 m .59874 .52695 L .59999 .52754 L F
.6002 .52257 m .60068 .52295 L .60075 .52598 L .925 .648 .496 r
F
.6002 .52257 m .60075 .52598 L .60052 .5258 L F
.60043 .52601 m .59981 .52635 L .60085 .52674 L .667 .747 .91 r
F
.59981 .52635 m .59874 .52695 L .59982 .52684 L F
.59981 .52635 m .59982 .52684 L .60085 .52674 L F
.6002 .52257 m .60052 .5258 L .6003 .52562 L .925 .648 .496 r
F
.59984 .525 m .59971 .52186 L .59972 .52189 L .988 .718 .377 r
F
.59971 .52246 m .59832 .52291 L .59973 .5231 L .667 .747 .91 r
F
.59967 .52118 m .59967 .52115 L .59963 .51941 L .712 .567 0 r
F
.59958 .52128 m .59733 .52031 L .59703 .52127 L .667 .747 .91 r
F
.59964 .51957 m .59965 .5201 L .59969 .52184 L .712 .567 0 r
F
.59964 .51957 m .59969 .52184 L .59968 .52149 L F
.59968 .52131 m .59976 .52487 L .59975 .52437 L F
.59964 .51957 m .59968 .52149 L .59968 .52131 L F
.59968 .52149 m .59976 .52487 L .59968 .52131 L F
.59981 .52635 m .5985 .52613 L .59874 .52695 L .667 .747 .91 r
F
.60043 .52601 m .5998 .52605 L .59981 .52635 L F
.5998 .52605 m .5985 .52613 L .59981 .52635 L F
.6002 .52257 m .6003 .52562 L .60007 .52246 L .925 .648 .496 r
F
.60012 .52547 m .59978 .52553 L .60043 .52601 L .667 .747 .91 r
F
.59978 .52553 m .5998 .52605 L .60043 .52601 L F
.6015 .52785 m .59999 .52754 L .60147 .52791 L F
.60113 .52721 m .59999 .52754 L .6015 .52785 L F
.60124 .52637 m .59999 .52754 L .60199 .52697 L F
.59268 .52969 m .58949 .53442 L .5946 .53591 L .644 .737 .917 r
F
.59315 .53389 m .59745 .53195 L .59758 .535 L .79 .534 .55 r
F
.59443 .53642 m .59315 .53389 L .59758 .535 L F
.59324 .53608 m .59315 .53389 L .59443 .53642 L F
.59315 .53389 m .59303 .53084 L .59745 .53195 L F
.59656 .53072 m .59758 .535 L .59952 .53146 L .667 .747 .91 r
F
.59656 .53072 m .59315 .53389 L .59758 .535 L F
.59312 .53685 m .58692 .5416 L .59298 .53705 L .643 .738 .918 r
F
.59312 .53685 m .59298 .53705 L .60233 .53004 L F
.60179 .52924 m .60146 .52934 L .60259 .5296 L F
.60146 .52934 m .60102 .52971 L .60217 .52992 L F
.60102 .52971 m .58692 .5416 L .60146 .53047 L F
.60102 .52971 m .60146 .53047 L .60217 .52992 L F
.60009 .52543 m .60007 .52544 L .60012 .52547 L .667 .747 .91 r
F
.60007 .52544 m .59978 .52553 L .60012 .52547 L F
.60165 .52336 m .60182 .5264 L .60172 .52638 L .749 .498 .552 r
F
.60329 .52129 m .59992 .52074 L .59967 .52113 L .667 .747 .91 r
F
.59965 .5201 m .59971 .52186 L .59969 .52184 L .988 .718 .377 r
F
.60329 .52129 m .59967 .52113 L .59968 .52128 L .667 .747 .91 r
F
.59972 .52189 m .59971 .52186 L .59965 .5201 L .988 .718 .377 r
F
.59978 .52199 m .59972 .52189 L .59965 .5201 L F
.60329 .52129 m .59968 .52128 L .59969 .52184 L .667 .747 .91 r
F
.60329 .52129 m .59969 .52184 L .59969 .52184 L F
.60329 .52129 m .59969 .52184 L .6 .52236 L F
.60329 .52129 m .6 .52236 L .60023 .52277 L F
.60102 .5039 m .60021 .51857 L .6011 .51808 L .438 .255 .533 r
F
.59987 .5046 m .60008 .51875 L .60021 .51857 L .07 0 .435 r
F
.60425 .5194 m .59935 .51838 L .59656 .519 L .644 .737 .917 r
F
.6003 .52562 m .60018 .52552 L .60007 .52246 L .925 .648 .496 r
F
.59997 .52523 m .59922 .52499 L .59889 .5255 L .667 .747 .91 r
F
.59978 .5249 m .59922 .52499 L .59997 .52523 L F
.59971 .52186 m .5998 .52493 L .59969 .52184 L .988 .718 .377 r
F
.60009 .52543 m .5976 .52583 L .5985 .52595 L .667 .747 .91 r
F
.59997 .52523 m .5976 .52583 L .60009 .52543 L F
.5998 .52493 m .59988 .52778 L .59979 .52492 L .988 .718 .377 r
F
.5998 .52493 m .59979 .52492 L .59969 .52184 L F
.59978 .52199 m .60004 .52245 L .60012 .52547 L F
.6 .52236 m .59969 .52184 L .59971 .52246 L .667 .747 .91 r
F
.59978 .52199 m .60012 .52547 L .59987 .52505 L .988 .718 .377 r
F
.60092 .52305 m .60104 .5261 L .60071 .52297 L .84 .573 .536 r
F
.60104 .5261 m .60115 .52896 L .60094 .52606 L F
.60104 .5261 m .60094 .52606 L .60071 .52297 L F
.60124 .52637 m .60043 .52601 L .60085 .52674 L .667 .747 .91 r
F
.60115 .52896 m .60097 .52888 L .60085 .52602 L .84 .573 .536 r
F
.60094 .52606 m .60085 .52602 L .60071 .52297 L F
.60115 .52896 m .60085 .52602 L .60094 .52606 L F
.60138 .52624 m .60075 .52598 L .60124 .52637 L .667 .747 .91 r
F
.60217 .52992 m .59378 .53635 L .60233 .53004 L .643 .738 .918 r
F
.59378 .53635 m .5938 .53635 L .60233 .53004 L F
.60233 .53004 m .594 .53629 L .59798 .53745 L F
.60075 .52598 m .60043 .52601 L .60124 .52637 L .667 .747 .91 r
F
.60131 .53834 m .6013 .53813 L .60254 .53844 L .73 .486 .559 r
F
.60262 .53245 m .59429 .54374 L .60337 .53372 L .643 .738 .918 r
F
.59771 .53805 m .6013 .53813 L .60131 .53834 L .73 .486 .559 r
F
.59771 .53805 m .59869 .53749 L .6013 .53813 L F
.59869 .53749 m .60252 .53798 L .60254 .53844 L F
.59066 .53478 m .59315 .53389 L .59324 .53608 L .855 .587 .533 r
F
.59978 .52553 m .59781 .52618 L .5998 .52605 L .667 .747 .91 r
F
.60068 .52295 m .60081 .52601 L .60075 .52598 L .84 .573 .536 r
F
.59969 .52184 m .59979 .52492 L .59976 .52487 L .988 .718 .377 r
F
.59863 .52388 m .59399 .52646 L .59647 .52763 L .667 .747 .91 r
F
.59771 .52311 m .59399 .52646 L .59863 .52388 L F
.59922 .52499 m .59713 .52433 L .59726 .52529 L F
.59969 .52184 m .59716 .52222 L .59971 .52246 L F
.59968 .52131 m .59975 .52437 L .59967 .52118 L .712 .567 0 r
F
.59975 .52437 m .59975 .52431 L .59967 .52118 L F
.59983 .52499 m .59971 .52186 L .59984 .525 L .988 .718 .377 r
F
.59983 .52499 m .5998 .52493 L .59971 .52186 L F
.59968 .52149 m .59969 .52184 L .59976 .52487 L .712 .567 0 r
F
.60165 .52918 m .59989 .52996 L .59991 .53064 L .643 .738 .918 r
F
.59268 .52969 m .58729 .53378 L .58949 .53442 L .644 .737 .917 r
F
.58941 .53213 m .59303 .53084 L .59315 .53389 L .855 .587 .533 r
F
.59066 .53478 m .58941 .53213 L .59315 .53389 L F
.58949 .5342 m .58941 .53213 L .59066 .53478 L F
.59399 .52646 m .59308 .53079 L .59647 .52763 L .667 .747 .91 r
F
.59407 .52954 m .59315 .53389 L .59656 .53072 L F
.58941 .53213 m .58929 .52908 L .59303 .53084 L .855 .587 .533 r
F
.59399 .52646 m .58936 .52904 L .59308 .53079 L .667 .747 .91 r
F
.59407 .52954 m .58941 .53213 L .59315 .53389 L F
.60074 .52877 m .58952 .53421 L .60165 .52918 L .643 .738 .918 r
F
.58951 .53421 m .58069 .53849 L .58979 .53444 L F
.59991 .53064 m .58069 .53849 L .58692 .5416 L F
.59989 .52996 m .58069 .53849 L .59991 .53064 L F
.58763 .53264 m .58941 .53213 L .58949 .5342 L .929 .65 .492 r
F
.60071 .52297 m .60097 .52888 L .60068 .52295 L .84 .573 .536 r
F
.58952 .53421 m .5899 .5344 L .60165 .52918 L .643 .738 .918 r
F
.5922 .52801 m .58941 .53213 L .59407 .52954 L .667 .747 .91 r
F
.59874 .52695 m .59407 .52954 L .59656 .53072 L F
.60074 .52877 m .59136 .53098 L .58069 .53849 L .643 .738 .918 r
F
.58661 .52984 m .58929 .52908 L .58941 .53213 L .929 .65 .492 r
F
.58763 .53264 m .58661 .52984 L .58941 .53213 L F
.58691 .53203 m .58682 .53205 L .58788 .53284 L .643 .738 .918 r
F
.58682 .53205 m .57601 .53459 L .58736 .53292 L F
.58682 .53205 m .58736 .53292 L .58788 .53284 L F
.58559 .5301 m .58661 .52984 L .58669 .53185 L .987 .712 .383 r
F
.58669 .53185 m .58661 .52984 L .58763 .53264 L .929 .65 .492 r
F
.60097 .52888 m .60094 .52886 L .60068 .52295 L .84 .573 .536 r
F
.59978 .52199 m .59987 .52505 L .59972 .52189 L .988 .718 .377 r
F
.59987 .52505 m .59984 .525 L .59972 .52189 L F
.60092 .52305 m .60165 .52336 L .60172 .52638 L .84 .573 .536 r
F
.60092 .52305 m .60172 .52638 L .60137 .52624 L F
.60202 .52642 m .60187 .5264 L .6017 .52336 L .749 .498 .552 r
F
.60205 .52643 m .6017 .52336 L .60177 .52337 L F
.60318 .52699 m .60147 .52791 L .60308 .52804 L .667 .747 .91 r
F
.60286 .52685 m .60147 .52791 L .60318 .52699 L F
.60227 .52646 m .6022 .52658 L .60322 .52658 L F
.6022 .52658 m .60147 .52791 L .60286 .52685 L F
.6022 .52658 m .60286 .52685 L .60322 .52658 L F
.60104 .5261 m .60179 .52924 L .60115 .52896 L .84 .573 .536 r
F
.60092 .52305 m .60137 .52624 L .60104 .5261 L F
.60199 .52697 m .60113 .52721 L .6015 .52785 L .667 .747 .91 r
F
.60137 .52624 m .60179 .52924 L .60104 .5261 L .84 .573 .536 r
F
.60232 .52934 m .60202 .52642 L .60205 .52643 L .749 .498 .552 r
F
.60202 .52642 m .6017 .52336 L .60205 .52643 L F
.60227 .52646 m .60124 .52637 L .60199 .52697 L .667 .747 .91 r
F
.60129 .52633 m .60124 .52637 L .60227 .52646 L F
.60203 .52341 m .60232 .52934 L .60177 .52337 L .749 .498 .552 r
F
.60428 .53794 m .6023 .54475 L .60345 .54473 L .643 .738 .918 r
F
.60319 .53796 m .60729 .53502 L .60742 .53787 L .671 .44 .562 r
F
.60521 .53046 m .60368 .53795 L .60428 .53794 L .643 .738 .918 r
F
.60368 .53795 m .6023 .54475 L .60428 .53794 L F
.60521 .53046 m .60345 .54473 L .60611 .5329 L F
.60471 .53106 m .6023 .54475 L .60521 .53046 L F
.6017 .52336 m .60203 .52929 L .60165 .52336 L .749 .498 .552 r
F
.60368 .5305 m .6023 .54475 L .60493 .5298 L .643 .738 .918 r
F
.60254 .53844 m .60319 .53796 L .60743 .53807 L .671 .44 .562 r
F
.60319 .54072 m .60021 .5424 L .60204 .55253 L .642 .738 .919 r
F
.60319 .53796 m .60742 .53787 L .60743 .53807 L .671 .44 .562 r
F
.60611 .5329 m .60498 .53792 L .60742 .53787 L .643 .738 .918 r
F
.60254 .53844 m .60252 .53798 L .60319 .53796 L .671 .44 .562 r
F
.60288 .53478 m .60254 .53844 L .60743 .53807 L .667 .747 .91 r
F
.6035 .53755 m .60234 .53926 L .60319 .54072 L .642 .738 .919 r
F
.60234 .53926 m .60021 .5424 L .60319 .54072 L F
.59985 .52838 m .59987 .52898 L .60074 .52877 L .643 .738 .918 r
F
.60203 .52929 m .60198 .52928 L .60165 .52336 L .749 .498 .552 r
F
.60075 .52598 m .60088 .52884 L .60082 .52881 L .84 .573 .536 r
F
.59965 .53452 m .60254 .53844 L .60288 .53478 L .667 .747 .91 r
F
.59771 .53805 m .59768 .53736 L .59869 .53749 L .73 .486 .559 r
F
.59965 .53452 m .59771 .53805 L .60254 .53844 L .667 .747 .91 r
F
.60229 .53748 m .60179 .53834 L .60301 .53807 L .642 .738 .919 r
F
.60179 .53834 m .60017 .54108 L .60216 .53897 L F
.60179 .53834 m .60216 .53897 L .60301 .53807 L F
.60081 .52601 m .60094 .52886 L .60075 .52598 L .84 .573 .536 r
F
.60017 .54108 m .60021 .5424 L .60234 .53926 L .642 .738 .919 r
F
.60017 .54108 m .60234 .53926 L .60221 .53904 L F
.60216 .53897 m .6031 .53814 L .60301 .53807 L F
.60017 .54108 m .60221 .53904 L .60216 .53897 L F
.60221 .53904 m .6031 .53814 L .60216 .53897 L F
.60014 .52821 m .59985 .52829 L .60037 .52861 L .643 .738 .918 r
F
.59985 .52829 m .59973 .52832 L .59985 .52838 L F
.59985 .52829 m .59985 .52838 L .60037 .52861 L F
.60012 .52547 m .60028 .52837 L .60018 .52829 L .925 .648 .496 r
F
.60004 .52245 m .60017 .52551 L .60012 .52547 L F
.60017 .52551 m .60028 .52837 L .60012 .52547 L F
.60007 .52246 m .60018 .52552 L .60004 .52245 L F
.60018 .52552 m .60028 .52837 L .60017 .52551 L F
.60018 .52552 m .60017 .52551 L .60004 .52245 L F
.59868 .52433 m .59743 .52337 L .59713 .52433 L .667 .747 .91 r
F
.60329 .52129 m .60023 .52277 L .60046 .52286 L F
.59689 .51787 m .57787 .50906 L .5744 .51321 L .644 .737 .917 r
F
.60425 .5194 m .6001 .51777 L .59689 .51787 L F
.6001 .51777 m .57787 .50906 L .59689 .51787 L F
.60323 .50352 m .60214 .50359 L .60248 .5177 L .665 .431 .556 r
F
.59963 .52433 m .59956 .52371 L .59868 .52433 L .667 .747 .91 r
F
.60322 .52658 m .60286 .52685 L .60318 .52699 L F
.60203 .52341 m .60321 .52356 L .60328 .52659 L .749 .498 .552 r
F
.60429 .52673 m .60308 .52804 L .60472 .52792 L .667 .747 .91 r
F
.60328 .52659 m .60308 .52804 L .60429 .52673 L F
.60322 .52658 m .60322 .5266 L .60328 .52659 L F
.60322 .5266 m .60308 .52804 L .60328 .52659 L F
.6036 .52352 m .60375 .52653 L .60326 .52356 L .648 .418 .556 r
F
.60375 .52653 m .6039 .52948 L .60358 .52655 L F
.60375 .52653 m .60358 .52655 L .60326 .52356 L F
.6027 .52651 m .60328 .52659 L .60335 .52952 L .749 .498 .552 r
F
.60203 .52341 m .60328 .52659 L .6027 .52651 L F
.6039 .52948 m .6036 .5295 L .60343 .52657 L .648 .418 .556 r
F
.60358 .52655 m .60343 .52657 L .60326 .52356 L F
.6039 .52948 m .60343 .52657 L .60358 .52655 L F
.6042 .52648 m .60328 .52659 L .60429 .52673 L .667 .747 .91 r
F
.6026 .52957 m .60233 .53004 L .60359 .52956 L .643 .738 .918 r
F
.60362 .5311 m .60262 .53245 L .60337 .53372 L F
.60288 .53478 m .60743 .53807 L .60615 .53453 L .667 .747 .91 r
F
.60322 .5311 m .60288 .53478 L .60615 .53453 L F
.60322 .5311 m .60615 .53453 L .60486 .53098 L F
.60368 .5305 m .60493 .5298 L .60485 .52979 L .643 .738 .918 r
F
.6026 .52957 m .60359 .52956 L .60335 .52952 L F
.60321 .52356 m .60355 .52951 L .60335 .52952 L .648 .418 .556 r
F
.60203 .52341 m .60335 .52952 L .60232 .52934 L .749 .498 .552 r
F
.60442 .52977 m .60322 .5311 L .60486 .53098 L .667 .747 .91 r
F
.60482 .52942 m .60368 .5305 L .60494 .52973 L .643 .738 .918 r
F
.60375 .52653 m .60495 .52941 L .6039 .52948 L .648 .418 .556 r
F
.60433 .52809 m .60378 .52949 L .60482 .52942 L .643 .738 .918 r
F
.60397 .52757 m .60378 .52949 L .60433 .52809 L F
.60378 .52949 m .60368 .5305 L .60482 .52942 L F
.6036 .52352 m .6048 .52337 L .60488 .52639 L .648 .418 .556 r
F
.60602 .52284 m .60614 .52585 L .60587 .52295 L .402 .228 .528 r
F
.60528 .52644 m .60472 .52792 L .60627 .52755 L .667 .747 .91 r
F
.60538 .52946 m .60617 .53067 L .60641 .53061 L F
.60515 .52653 m .60472 .52792 L .60528 .52644 L F
.6036 .52352 m .60488 .52639 L .60375 .52653 L .648 .418 .556 r
F
.60343 .52434 m .6042 .52648 L .60488 .52639 L .667 .747 .91 r
F
.60515 .52629 m .60488 .52639 L .60521 .52635 L F
.60696 .52559 m .6083 .52649 L .60807 .52599 L F
.60666 .52549 m .60695 .52567 L .60696 .52559 L F
.60695 .52567 m .6083 .52649 L .60696 .52559 L F
.60729 .53502 m .60715 .53197 L .61178 .53089 L .605 .389 .562 r
F
.61192 .53393 m .61178 .53089 L .61584 .52915 L .523 .326 .556 r
F
.60729 .53502 m .61178 .53089 L .61192 .53393 L .605 .389 .562 r
F
.60601 .53148 m .60729 .53502 L .61192 .53393 L .667 .747 .91 r
F
.61192 .53393 m .61584 .52915 L .61599 .5322 L .523 .326 .556 r
F
.61207 .53699 m .61192 .53393 L .61599 .5322 L F
.6091 .53075 m .61192 .53393 L .61599 .5322 L .667 .747 .91 r
F
.60601 .53148 m .61192 .53393 L .6091 .53075 L F
.61207 .53699 m .61599 .5322 L .61613 .53525 L .523 .326 .556 r
F
.60924 .53381 m .61207 .53699 L .61613 .53525 L .667 .747 .91 r
F
.61613 .53525 m .61599 .5322 L .61921 .52992 L .405 .238 .539 r
F
.6091 .53075 m .61599 .5322 L .61181 .52959 L .667 .747 .91 r
F
.61613 .53525 m .61921 .52992 L .61936 .53298 L .405 .238 .539 r
F
.61196 .53265 m .61613 .53525 L .61936 .53298 L .667 .747 .91 r
F
.60924 .53381 m .61613 .53525 L .61196 .53265 L F
.6066 .53069 m .60924 .53381 L .61011 .53343 L F
.6066 .53069 m .61011 .53343 L .60934 .53169 L F
.60658 .5308 m .60924 .53381 L .6066 .53069 L F
.60628 .52911 m .60686 .52947 L .60673 .52852 L F
.60686 .52947 m .60777 .53003 L .60699 .5289 L F
.60686 .52947 m .60699 .5289 L .60673 .52852 L F
.60704 .52863 m .60777 .53003 L .60884 .52927 L F
.60673 .52852 m .60699 .5289 L .60704 .52863 L F
.60699 .5289 m .60777 .53003 L .60704 .52863 L F
.60704 .52184 m .60713 .52483 L .60704 .52186 L 0 0 .235 r
F
.6062 .52608 m .60678 .52644 L .60665 .52549 L .667 .747 .91 r
F
.60678 .52644 m .60763 .52697 L .6069 .52587 L F
.60678 .52644 m .6069 .52587 L .60665 .52549 L F
.60657 .52246 m .60669 .52544 L .60665 .52549 L .163 .05 .467 r
F
.60654 .52104 m .60659 .52245 L .60657 .52246 L F
.60657 .52246 m .60659 .52245 L .60658 .52245 L .667 .747 .91 r
F
.60659 .52245 m .60669 .52544 L .60657 .52246 L .163 .05 .467 r
F
.60701 .52189 m .60659 .52245 L .60703 .5219 L .667 .747 .91 r
F
.605 .52175 m .60519 .52628 L .60476 .52183 L .539 .333 .549 r
F
.60658 .52245 m .60659 .52245 L .60701 .52189 L .667 .747 .91 r
F
.60659 .52245 m .60689 .52256 L .60697 .52219 L F
.60664 .52092 m .60669 .52231 L .60654 .52104 L .163 .05 .467 r
F
.60669 .52231 m .60679 .52531 L .60662 .52241 L F
.60669 .52231 m .60662 .52241 L .60654 .52104 L F
.60804 .52056 m .60955 .5213 L .60942 .52035 L .667 .747 .91 r
F
.60644 .52264 m .60683 .52281 L .60659 .52245 L F
.60679 .52531 m .60669 .52544 L .60654 .52104 L .163 .05 .467 r
F
.60703 .52033 m .60715 .5198 L .60719 .52115 L 0 0 .235 r
F
.60706 .5196 m .60709 .52092 L .60715 .5198 L .978 .72 .315 r
F
.60709 .52092 m .60716 .52109 L .60715 .5198 L F
.60425 .5194 m .60401 .52188 L .60513 .5218 L .644 .737 .917 r
F
.60329 .52129 m .60725 .5213 L .607 .52072 L .667 .747 .91 r
F
.60718 .52147 m .60719 .52167 L .60733 .52148 L F
.60329 .52129 m .60719 .52167 L .60718 .52147 L F
.60329 .52129 m .60701 .52189 L .60719 .52167 L F
.60708 .52494 m .60788 .52557 L .60764 .52503 L F
.60666 .52549 m .60807 .52599 L .60708 .52494 L F
.60807 .52599 m .6087 .52621 L .60788 .52557 L F
.60807 .52599 m .60788 .52557 L .60708 .52494 L F
.60747 .5239 m .61163 .52651 L .61376 .52499 L F
.60734 .52435 m .60941 .52532 L .60972 .52436 L F
.60713 .52484 m .60712 .52484 L .60704 .52186 L 0 0 .235 r
F
.60713 .52483 m .60713 .52484 L .60704 .52186 L F
.60704 .52186 m .60712 .52484 L .60711 .52489 L F
.60509 .52631 m .60498 .52636 L .60476 .52183 L .539 .333 .549 r
F
.60519 .52628 m .60509 .52631 L .60476 .52183 L F
.60614 .52585 m .60599 .52595 L .60587 .52295 L .402 .228 .528 r
F
.60488 .52639 m .60472 .52792 L .60521 .52635 L .667 .747 .91 r
F
.61599 .5322 m .61584 .52915 L .61906 .52687 L .405 .238 .539 r
F
.61599 .5322 m .61906 .52687 L .61921 .52992 L F
.61181 .52959 m .61599 .5322 L .61921 .52992 L .667 .747 .91 r
F
.61196 .53265 m .61936 .53298 L .6141 .53113 L F
.60777 .53003 m .61196 .53265 L .6141 .53113 L F
.61163 .52651 m .61578 .52911 L .61898 .52684 L F
.60893 .52767 m .61578 .52911 L .61163 .52651 L F
.61181 .52959 m .61921 .52992 L .61396 .52807 L F
.60763 .52697 m .61181 .52959 L .61396 .52807 L F
.60884 .52927 m .6141 .53113 L .61554 .52935 L F
.60777 .53003 m .6141 .53113 L .60884 .52927 L F
.60884 .52927 m .61554 .52935 L .60955 .52838 L F
.60488 .52639 m .60509 .52937 L .60495 .52941 L .539 .333 .549 r
F
.60494 .52637 m .60509 .52937 L .60488 .52639 L F
.60525 .52931 m .60533 .52949 L .60538 .52946 L .667 .747 .91 r
F
.60522 .52933 m .60533 .52949 L .60525 .52931 L F
.60509 .52937 m .60509 .52937 L .60488 .52639 L .539 .333 .549 r
F
.60531 .52929 m .60522 .52933 L .60498 .52636 L F
.60522 .52933 m .60512 .52936 L .60498 .52636 L F
.60531 .52929 m .60498 .52636 L .60509 .52631 L F
.60519 .52628 m .60531 .52929 L .60509 .52631 L F
.6042 .52648 m .60425 .52663 L .60488 .52639 L .667 .747 .91 r
F
.60425 .52663 m .60472 .52792 L .60488 .52639 L F
.60375 .52653 m .60488 .52639 L .60495 .52941 L .648 .418 .556 r
F
.60649 .52923 m .60641 .53061 L .60777 .53003 L .667 .747 .91 r
F
.63034 .52963 m .65614 .53974 L .66346 .53168 L .644 .737 .917 r
F
.625 .53299 m .65614 .53974 L .63034 .52963 L F
.63034 .52963 m .66346 .53168 L .63394 .52556 L F
.61921 .52992 m .61906 .52687 L .62121 .52421 L .204 .09 .493 r
F
.61921 .52992 m .62121 .52421 L .62136 .52726 L F
.61936 .53298 m .61921 .52992 L .62136 .52726 L F
.61396 .52807 m .61921 .52992 L .62136 .52726 L .667 .747 .91 r
F
.61936 .53298 m .62136 .52726 L .62151 .53032 L .204 .09 .493 r
F
.61163 .52651 m .61898 .52684 L .61376 .52499 L .667 .747 .91 r
F
.61396 .52807 m .62136 .52726 L .61539 .52629 L F
.6087 .52621 m .61396 .52807 L .61539 .52629 L F
.60763 .52697 m .61396 .52807 L .6087 .52621 L F
.62151 .53032 m .62136 .52726 L .6223 .52439 L 0 0 .346 r
F
.62151 .53032 m .6223 .52439 L .62246 .52746 L F
.61554 .52935 m .62151 .53032 L .62246 .52746 L .667 .747 .91 r
F
.61554 .52935 m .62246 .52746 L .61616 .52744 L F
.60955 .52838 m .61554 .52935 L .61616 .52744 L F
.60955 .52838 m .61616 .52744 L .60986 .52742 L F
.61084 .52755 m .63391 .53337 L .63552 .52885 L .643 .738 .918 r
F
.60483 .52335 m .60512 .52936 L .6048 .52337 L .539 .333 .549 r
F
.60512 .52936 m .60509 .52937 L .6048 .52337 L F
.60714 .52799 m .60884 .52927 L .60955 .52838 L .667 .747 .91 r
F
.60665 .52549 m .6069 .52587 L .60666 .52549 L F
.60679 .52531 m .60689 .52832 L .60669 .52544 L .163 .05 .467 r
F
.60689 .52832 m .60689 .52832 L .60669 .52544 L F
.60673 .52852 m .60884 .52927 L .60714 .52799 L .667 .747 .91 r
F
.60689 .52844 m .6068 .52854 L .6068 .52843 L .163 .05 .467 r
F
.60689 .52832 m .6068 .52843 L .60669 .52544 L F
.60689 .52844 m .6068 .52843 L .60689 .52832 L F
.60758 .52742 m .60955 .52838 L .60986 .52742 L .667 .747 .91 r
F
.6073 .52742 m .60719 .52792 L .60758 .52742 L F
.60725 .52768 m .60735 .52739 L .60725 .52784 L 0 0 .235 r
F
.6048 .52337 m .60494 .52637 L .60488 .52639 L .539 .333 .549 r
F
.60659 .52245 m .60697 .52219 L .60703 .5219 L .667 .747 .91 r
F
.60658 .52245 m .60687 .52262 L .60689 .52256 L F
.60674 .52224 m .60687 .52208 L .60703 .525 L .163 .05 .467 r
F
.60674 .52224 m .60703 .525 L .60697 .52508 L F
.60707 .52169 m .60722 .52441 L .60716 .52468 L 0 0 .235 r
F
.60733 .52148 m .60924 .52226 L .60747 .5213 L .667 .747 .91 r
F
.60701 .52189 m .60756 .52198 L .60733 .52148 L F
.60756 .52198 m .60924 .52226 L .60733 .52148 L F
.60709 .5216 m .60722 .52441 L .60707 .52169 L 0 0 .235 r
F
.60599 .52595 m .6062 .52608 L .60665 .52549 L .667 .747 .91 r
F
.60593 .52294 m .60633 .52279 L .60644 .52264 L F
.60644 .52264 m .60659 .52245 L .60657 .52246 L F
.60612 .52278 m .60657 .52246 L .60665 .52549 L .402 .228 .528 r
F
.60642 .52565 m .60665 .52549 L .60673 .52863 L F
.60612 .52278 m .60665 .52549 L .60642 .52565 L F
.60707 .52169 m .60716 .52468 L .60704 .52184 L 0 0 .235 r
F
.60716 .52468 m .60713 .52483 L .60704 .52184 L F
.60687 .52208 m .60711 .52489 L .60703 .525 L .163 .05 .467 r
F
.6069 .52204 m .60711 .52489 L .60687 .52208 L F
.60669 .52231 m .60697 .52508 L .60679 .52531 L F
.60683 .52281 m .60687 .52262 L .60659 .52245 L .667 .747 .91 r
F
.60674 .52224 m .60697 .52508 L .60669 .52231 L .163 .05 .467 r
F
.60602 .52284 m .60616 .52393 L .60606 .52394 L .402 .228 .528 r
F
.60616 .52393 m .60637 .52568 L .60606 .52394 L F
.60606 .52394 m .60637 .52568 L .60614 .52585 L F
.60593 .52294 m .60612 .52306 L .60633 .52279 L .667 .747 .91 r
F
.60612 .52278 m .60673 .52863 L .60602 .52284 L .402 .228 .528 r
F
.60515 .52629 m .60521 .52635 L .60583 .52603 L .667 .747 .91 r
F
.60521 .52635 m .60515 .52653 L .60528 .52644 L F
.60521 .52635 m .60528 .52644 L .60545 .52632 L F
.60519 .52628 m .606 .52908 L .60531 .5293 L .539 .333 .549 r
F
.60506 .52327 m .60552 .52615 L .60519 .52628 L F
.60521 .52635 m .60545 .52632 L .60592 .526 L .667 .747 .91 r
F
.60552 .52615 m .606 .52908 L .60519 .52628 L .539 .333 .549 r
F
.6052 .52322 m .60592 .526 L .60559 .52612 L F
.60601 .52596 m .60563 .52683 L .6062 .52608 L .667 .747 .91 r
F
.60587 .52295 m .60611 .52895 L .60584 .52297 L .402 .228 .528 r
F
.60611 .52895 m .60611 .52895 L .60584 .52297 L F
.60611 .52901 m .60609 .52902 L .60584 .52297 L F
.60599 .52595 m .60598 .52597 L .60601 .52596 L .667 .747 .91 r
F
.60614 .52585 m .60625 .52886 L .60599 .52595 L .402 .228 .528 r
F
.60625 .52886 m .60611 .52895 L .60599 .52595 L F
.60326 .52356 m .6036 .5295 L .60321 .52356 L .648 .418 .556 r
F
.60416 .52973 m .60322 .5311 L .60442 .52977 L .667 .747 .91 r
F
.60335 .52952 m .60359 .52956 L .60378 .52949 L .643 .738 .918 r
F
.6036 .5295 m .60361 .52959 L .60355 .52951 L .648 .418 .556 r
F
.60336 .52962 m .60322 .5311 L .60432 .5295 L .667 .747 .91 r
F
.6061 .52899 m .60588 .52911 L .60649 .52923 L F
.60588 .52911 m .6054 .52937 L .60553 .52935 L F
.60588 .52911 m .60553 .52935 L .60649 .52923 L F
.60714 .52799 m .60955 .52838 L .60758 .52742 L F
.60736 .52737 m .60779 .52798 L .60867 .52744 L .643 .738 .918 r
F
.60592 .526 m .60605 .529 L .606 .52903 L .402 .228 .528 r
F
.60697 .52508 m .60703 .525 L .6072 .52807 L .163 .05 .467 r
F
.60716 .52468 m .60734 .52724 L .60725 .52768 L 0 0 .235 r
F
.60521 .52635 m .60592 .526 L .60583 .52603 L .667 .747 .91 r
F
.6052 .52322 m .60559 .52612 L .60506 .52327 L .539 .333 .549 r
F
.60528 .52644 m .60563 .52683 L .60598 .52597 L .667 .747 .91 r
F
.60559 .52612 m .606 .52908 L .60552 .52615 L .539 .333 .549 r
F
.60559 .52612 m .60552 .52615 L .60506 .52327 L F
.60592 .526 m .60598 .52597 L .60599 .52595 L .667 .747 .91 r
F
.60528 .52644 m .60598 .52597 L .60592 .526 L F
.6052 .52322 m .60584 .52297 L .60592 .526 L .539 .333 .549 r
F
.60584 .52297 m .60597 .52596 L .60592 .526 L .402 .228 .528 r
F
.6069 .52204 m .60704 .52186 L .60711 .52489 L .163 .05 .467 r
F
.60709 .5216 m .60727 .52418 L .60722 .52441 L 0 0 .235 r
F
.60343 .52434 m .60734 .52435 L .60709 .52378 L .667 .747 .91 r
F
.60723 .52435 m .60713 .52483 L .60734 .52435 L F
.60722 .52441 m .60727 .52418 L .60735 .52721 L 0 0 .235 r
F
.60722 .52782 m .60721 .52783 L .60712 .52484 L F
.60722 .52782 m .60712 .52484 L .60713 .52484 L F
.60713 .52483 m .60722 .52782 L .60713 .52484 L F
.60665 .52549 m .6068 .52843 L .60673 .52853 L .163 .05 .467 r
F
.60669 .52544 m .6068 .52843 L .60665 .52549 L F
.60712 .52484 m .60721 .52783 L .60711 .52489 L 0 0 .235 r
F
.60721 .52783 m .6072 .52788 L .60711 .52489 L F
.60711 .52489 m .6072 .52788 L .60719 .52792 L F
.60716 .52468 m .60725 .52784 L .60713 .52483 L F
.60725 .52784 m .60722 .52797 L .60713 .52483 L F
.60608 .52898 m .6061 .52899 L .60673 .52853 L .667 .747 .91 r
F
.6061 .52899 m .60648 .52885 L .60673 .52853 L F
.60625 .52886 m .60673 .52863 L .60625 .52892 L .402 .228 .528 r
F
.60614 .52585 m .60671 .52854 L .60625 .52886 L F
.60671 .52854 m .60673 .52863 L .60625 .52886 L F
.60637 .52568 m .60673 .52863 L .60614 .52585 L F
.6069 .52587 m .60691 .52587 L .60666 .52549 L .667 .747 .91 r
F
.60679 .52531 m .6072 .52807 L .60689 .52844 L .163 .05 .467 r
F
.60697 .52508 m .6072 .52807 L .60679 .52531 L F
.60598 .52597 m .60563 .52683 L .60601 .52596 L .667 .747 .91 r
F
.60559 .52612 m .60592 .526 L .606 .52908 L .539 .333 .549 r
F
.60611 .54138 m .60359 .5525 L .61019 .55237 L .642 .738 .919 r
F
.60597 .52596 m .60609 .52897 L .60592 .526 L .402 .228 .528 r
F
.60608 .52898 m .606 .52903 L .6061 .52899 L .667 .747 .91 r
F
.6054 .52937 m .60641 .53061 L .60649 .52923 L F
.60502 .52904 m .60641 .53061 L .60408 .52773 L F
.60521 .53046 m .61042 .54459 L .60621 .53072 L .643 .738 .918 r
F
.60565 .52993 m .60621 .53072 L .60588 .52965 L F
.60521 .53046 m .60621 .53072 L .60565 .52993 L F
.60641 .53061 m .60658 .5308 L .6066 .53069 L .667 .747 .91 r
F
.60975 .53569 m .61042 .54459 L .61476 .54383 L .643 .738 .918 r
F
.60853 .53397 m .61207 .53699 L .60924 .53381 L .667 .747 .91 r
F
.6101 .53617 m .61207 .53699 L .60853 .53397 L F
.60621 .53072 m .61042 .54459 L .60975 .53569 L .643 .738 .918 r
F
.60611 .5329 m .60742 .53787 L .60791 .53779 L F
.60486 .53098 m .60615 .53453 L .60853 .53397 L .667 .747 .91 r
F
.6077 .53281 m .60853 .53397 L .60924 .53381 L F
.60486 .53098 m .60853 .53397 L .6077 .53281 L F
.60486 .53098 m .60924 .53381 L .60641 .53061 L F
.60641 .53061 m .61196 .53265 L .60777 .53003 L F
.60574 .52916 m .60975 .53569 L .61068 .53478 L .643 .738 .918 r
F
.60975 .53569 m .61476 .54383 L .61339 .5408 L F
.6101 .53617 m .61088 .53727 L .61207 .53699 L .667 .747 .91 r
F
.60975 .53569 m .61339 .5408 L .61068 .53478 L .643 .738 .918 r
F
.60574 .52916 m .60621 .53072 L .60975 .53569 L F
.60615 .53453 m .6101 .53617 L .60853 .53397 L .667 .747 .91 r
F
.60743 .53807 m .6077 .53782 L .61088 .53727 L .605 .389 .562 r
F
.60743 .53807 m .60742 .53787 L .6077 .53782 L F
.60615 .53453 m .60743 .53807 L .61088 .53727 L .667 .747 .91 r
F
.60615 .53453 m .61088 .53727 L .6101 .53617 L F
.60483 .52945 m .60521 .53046 L .6055 .52973 L .643 .738 .918 r
F
.60527 .52954 m .60486 .53098 L .60617 .53067 L .667 .747 .91 r
F
.6036 .5295 m .60355 .52951 L .60321 .52356 L .648 .418 .556 r
F
.60172 .52638 m .60198 .52928 L .60179 .52924 L .749 .498 .552 r
F
.60182 .5264 m .60198 .52928 L .60172 .52638 L F
.60137 .52624 m .60172 .52638 L .60179 .52924 L .84 .573 .536 r
F
.60232 .52934 m .60203 .52929 L .60187 .5264 L .749 .498 .552 r
F
.60232 .52934 m .60187 .5264 L .60202 .52642 L F
.60386 .52742 m .60165 .52918 L .60254 .52958 L .643 .738 .918 r
F
.60381 .52735 m .60165 .52918 L .60386 .52742 L F
.60397 .52757 m .6026 .52957 L .60378 .52949 L F
.60386 .52743 m .6026 .52957 L .60397 .52757 L F
.60483 .52945 m .6055 .52973 L .60522 .52933 L F
.60509 .52937 m .60509 .52937 L .60509 .52937 L .539 .333 .549 r
F
.60495 .52941 m .60509 .52937 L .60495 .52943 L F
.60509 .52937 m .60509 .52937 L .60495 .52941 L F
.6039 .52948 m .60495 .52941 L .60495 .52943 L .648 .418 .556 r
F
.60485 .52979 m .60493 .5298 L .60494 .52973 L .643 .738 .918 r
F
.60516 .5294 m .60452 .53005 L .60527 .52954 L .667 .747 .91 r
F
.60432 .5295 m .60452 .53005 L .60516 .5294 L F
.60494 .52973 m .60471 .53106 L .60521 .53046 L .643 .738 .918 r
F
.60452 .53005 m .60486 .53098 L .60527 .52954 L .667 .747 .91 r
F
.60504 .5385 m .60204 .55253 L .60359 .5525 L .642 .738 .919 r
F
.60504 .5385 m .60359 .5525 L .60611 .54138 L F
.60471 .53761 m .60442 .53925 L .60504 .5385 L F
.60442 .53925 m .60204 .55253 L .60504 .5385 L F
.60451 .53707 m .6044 .5378 L .60471 .53761 L F
.6044 .5378 m .60438 .53793 L .60471 .53761 L F
.60438 .53793 m .60204 .55253 L .60463 .53805 L F
.60438 .53793 m .60463 .53805 L .60471 .53761 L F
.6016 .53097 m .59965 .53452 L .60288 .53478 L .667 .747 .91 r
F
.60012 .5306 m .59965 .53452 L .6016 .53097 L F
.60233 .52964 m .60012 .5306 L .6016 .53097 L F
.60203 .52929 m .60204 .52945 L .60198 .52928 L .749 .498 .552 r
F
.60146 .52934 m .60217 .52992 L .60259 .5296 L .643 .738 .918 r
F
.60179 .52942 m .60012 .5306 L .60233 .52964 L .667 .747 .91 r
F
.60152 .5293 m .60144 .52937 L .60179 .52942 L F
.60144 .52937 m .60012 .5306 L .60179 .52942 L F
.60354 .53714 m .60354 .53714 L .60451 .53707 L .642 .738 .919 r
F
.60165 .52918 m .60161 .52921 L .60179 .52924 L .643 .738 .918 r
F
.60161 .52921 m .60146 .52934 L .60179 .52924 L F
.6016 .53097 m .60288 .53478 L .60322 .5311 L .667 .747 .91 r
F
.60332 .53005 m .6016 .53097 L .60322 .5311 L F
.60232 .52934 m .60335 .52952 L .60336 .52962 L .749 .498 .552 r
F
.60232 .52934 m .60336 .52962 L .60233 .52949 L F
.60335 .52952 m .60336 .52962 L .60336 .52962 L .648 .418 .556 r
F
.6026 .52957 m .60254 .52958 L .60259 .5296 L .643 .738 .918 r
F
.60609 .52897 m .60605 .529 L .60592 .526 L .402 .228 .528 r
F
.6069 .52587 m .60763 .52697 L .60691 .52587 L .667 .747 .91 r
F
.60703 .525 m .60711 .52489 L .6072 .52807 L .163 .05 .467 r
F
.60382 .52737 m .60744 .52742 L .60719 .52685 L .667 .747 .91 r
F
.60385 .52741 m .60744 .52742 L .60382 .52737 L F
.60386 .52743 m .60254 .52958 L .6026 .52957 L .643 .738 .918 r
F
.60722 .52441 m .60735 .52721 L .60734 .52723 L 0 0 .235 r
F
.60727 .52418 m .60729 .52708 L .60735 .52721 L .978 .72 .315 r
F
.60724 .52411 m .60728 .52708 L .60727 .52418 L F
.60728 .52708 m .60729 .52725 L .60729 .52708 L F
.60722 .52441 m .60734 .52723 L .60716 .52468 L 0 0 .235 r
F
.60734 .52723 m .60735 .52739 L .60734 .52724 L F
.60734 .52723 m .60734 .52724 L .60716 .52468 L F
.60744 .52742 m .60986 .52742 L .60741 .5269 L .667 .747 .91 r
F
.60735 .52721 m .60741 .5269 L .60719 .52685 L F
.60744 .52742 m .60741 .5269 L .60735 .52721 L F
.60728 .52708 m .60729 .52708 L .60727 .52418 L .978 .72 .315 r
F
.60708 .52494 m .60764 .52503 L .60741 .5245 L .667 .747 .91 r
F
.60329 .52129 m .60733 .52148 L .60725 .5213 L F
.60703 .5219 m .60799 .52295 L .60756 .52198 L F
.60709 .5216 m .60719 .52115 L .60727 .52418 L 0 0 .235 r
F
.60718 .52112 m .60723 .5241 L .60719 .52115 L .978 .72 .315 r
F
.60723 .5241 m .60728 .52708 L .60724 .52411 L F
.60728 .52708 m .60728 .52708 L .60724 .52411 L F
.60764 .52503 m .60941 .52532 L .60734 .52435 L .667 .747 .91 r
F
.60721 .5269 m .60719 .52401 L .60718 .52399 L .978 .72 .315 r
F
.60721 .5269 m .60728 .52708 L .60723 .5241 L F
.60721 .5269 m .60723 .5241 L .60719 .52401 L F
.60343 .52434 m .60713 .52483 L .60723 .52435 L .667 .747 .91 r
F
.60715 .52391 m .60721 .5269 L .60718 .52399 L .978 .72 .315 r
F
.60764 .52503 m .6087 .52621 L .60941 .52532 L .667 .747 .91 r
F
.60788 .52557 m .6087 .52621 L .60764 .52503 L F
.60343 .52434 m .60708 .52494 L .60713 .52483 L F
.60343 .52434 m .60666 .52549 L .60708 .52494 L F
.60715 .52391 m .60695 .5265 L .60721 .52708 L .978 .72 .315 r
F
.60709 .52092 m .60702 .52362 L .60715 .52391 L F
.60723 .5241 m .60724 .52411 L .60719 .52115 L F
.60719 .52115 m .60724 .52411 L .60727 .52418 L F
.60718 .52399 m .60718 .52112 L .60716 .52109 L F
.60719 .52401 m .60718 .52112 L .60718 .52399 L F
.60719 .52401 m .60723 .5241 L .60718 .52112 L F
.60709 .52092 m .60715 .52391 L .60716 .52109 L F
.60715 .52391 m .60718 .52399 L .60716 .52109 L F
.60704 .52082 m .607 .52357 L .60709 .52092 L F
.60343 .52434 m .60709 .52378 L .60688 .52331 L .667 .747 .91 r
F
.607 .52357 m .60695 .5265 L .60702 .52362 L .978 .72 .315 r
F
.607 .52357 m .60702 .52362 L .60709 .52092 L F
.60799 .52295 m .60853 .52314 L .60756 .52198 L .667 .747 .91 r
F
.60704 .52082 m .60686 .52327 L .607 .52357 L .978 .72 .315 r
F
.60799 .52295 m .60818 .52339 L .60853 .52314 L .667 .747 .91 r
F
.60853 .52314 m .61376 .52499 L .61518 .52323 L F
.60747 .5239 m .61376 .52499 L .60853 .52314 L F
.60853 .52314 m .61518 .52323 L .60924 .52226 L F
.60688 .52331 m .6096 .5234 L .60914 .52264 L F
.60709 .52378 m .6096 .5234 L .60688 .52331 L F
.60875 .5226 m .60914 .52264 L .60905 .5225 L F
.60329 .52129 m .60658 .52245 L .60701 .52189 L F
.607 .52073 m .60686 .52327 L .60704 .52082 L .978 .72 .315 r
F
.60715 .5198 m .60718 .52112 L .60719 .52115 L F
.60716 .52109 m .60718 .52112 L .60715 .5198 L F
.60706 .5196 m .60704 .52082 L .60709 .52092 L F
.60706 .5196 m .607 .52073 L .60704 .52082 L F
.60706 .5196 m .60678 .52024 L .607 .52073 L F
.6068 .52025 m .60881 .52044 L .60748 .52004 L .667 .747 .91 r
F
.60329 .52129 m .60739 .52066 L .6068 .52025 L F
.60739 .52066 m .60881 .52044 L .6068 .52025 L F
.60536 .50397 m .60549 .51809 L .60573 .51817 L .805 .544 .543 r
F
.60638 .50471 m .60573 .51817 L .60652 .51874 L .906 .63 .507 r
F
.60638 .50471 m .60652 .51874 L .60675 .5189 L F
.60571 .51817 m .62777 .50795 L .62155 .50474 L .644 .737 .917 r
F
.60425 .5194 m .60635 .51838 L .60571 .51817 L F
.60635 .51838 m .62777 .50795 L .60571 .51817 L F
.60536 .50397 m .60431 .50363 L .60466 .51781 L .805 .544 .543 r
F
.61128 .51871 m .63554 .52105 L .63501 .5164 L .644 .737 .917 r
F
.60425 .5194 m .62386 .52043 L .61128 .51871 L F
.62386 .52043 m .63554 .52105 L .61128 .51871 L F
.60425 .5194 m .63501 .5164 L .63236 .51193 L F
.60706 .5196 m .60675 .5189 L .60678 .52024 L .978 .72 .315 r
F
.60329 .52129 m .6068 .52025 L .60669 .52017 L .667 .747 .91 r
F
.60329 .52129 m .60644 .52264 L .60658 .52245 L F
.60425 .5194 m .63236 .51193 L .62777 .50795 L .644 .737 .917 r
F
.60652 .51874 m .60653 .52006 L .60675 .5189 L .906 .63 .507 r
F
.60656 .52306 m .60677 .52321 L .60676 .52022 L F
.60669 .52018 m .60676 .52022 L .60675 .5189 L F
.60656 .52306 m .60676 .52022 L .60669 .52018 L F
.60653 .52006 m .60669 .52018 L .60675 .5189 L F
.60675 .5189 m .60676 .52022 L .60678 .52024 L F
.60652 .51874 m .60576 .51953 L .60653 .52006 L F
.60606 .51974 m .60888 .51945 L .60796 .51869 L .667 .747 .91 r
F
.60329 .52129 m .60669 .52017 L .60606 .51974 L F
.60669 .52017 m .60888 .51945 L .60606 .51974 L F
.60652 .51874 m .60573 .51817 L .60576 .51953 L .906 .63 .507 r
F
.60573 .51817 m .60573 .51952 L .60576 .51953 L .805 .544 .543 r
F
.60536 .50397 m .60466 .51781 L .60549 .51809 L F
.60425 .5194 m .62155 .50474 L .61412 .50253 L .644 .737 .917 r
F
.60549 .51809 m .6055 .51945 L .60573 .51817 L .805 .544 .543 r
F
.60329 .52129 m .60606 .51974 L .60576 .51953 L .667 .747 .91 r
F
.60329 .52129 m .60576 .51953 L .60532 .5194 L F
.60343 .52434 m .60691 .5233 L .60681 .52324 L F
.60653 .52006 m .60656 .52306 L .60669 .52018 L .906 .63 .507 r
F
.60377 .52729 m .60694 .5263 L .60632 .52588 L .667 .747 .91 r
F
.60094 .52886 m .60088 .52884 L .60075 .52598 L .84 .573 .536 r
F
.6003 .52562 m .60082 .52881 L .6004 .52847 L .925 .648 .496 r
F
.60059 .52592 m .6003 .5258 L .60043 .52601 L .667 .747 .91 r
F
.60052 .5258 m .60082 .52881 L .6003 .52562 L .925 .648 .496 r
F
.60064 .52589 m .60059 .52592 L .60075 .52598 L .667 .747 .91 r
F
.60059 .52592 m .60043 .52601 L .60075 .52598 L F
.60052 .5258 m .60075 .52598 L .60082 .52881 L .925 .648 .496 r
F
.60381 .52735 m .60074 .52877 L .60165 .52918 L .643 .738 .918 r
F
.60379 .52733 m .60694 .5263 L .60377 .52729 L .667 .747 .91 r
F
.604 .52719 m .60377 .5273 L .60381 .52735 L .643 .738 .918 r
F
.60377 .5273 m .60074 .52877 L .60381 .52735 L F
.6068 .52322 m .60681 .52621 L .60686 .52327 L .906 .63 .507 r
F
.60379 .52733 m .60719 .52685 L .60694 .5263 L .667 .747 .91 r
F
.60382 .52737 m .60719 .52685 L .60379 .52733 L F
.60388 .52745 m .60714 .52799 L .60719 .52792 L F
.60389 .52746 m .60714 .52799 L .60388 .52745 L F
.60609 .52897 m .60609 .52902 L .60605 .529 L .402 .228 .528 r
F
.60934 .53169 m .61011 .53343 L .61196 .53265 L .667 .747 .91 r
F
.606 .52908 m .61813 .54324 L .6066 .52889 L .643 .738 .918 r
F
.60574 .52916 m .60578 .52921 L .606 .52908 L F
.60578 .52921 m .61813 .54324 L .606 .52908 L F
.60533 .52949 m .60617 .53067 L .60538 .52946 L .667 .747 .91 r
F
.60433 .52809 m .60483 .52945 L .60522 .52933 L .643 .738 .918 r
F
.60386 .52742 m .60254 .52958 L .60386 .52743 L F
.60521 .53046 m .60588 .52965 L .60574 .52916 L F
.60522 .52933 m .60512 .52936 L .60512 .52936 L .539 .333 .549 r
F
.60356 .52741 m .60617 .53067 L .60502 .52904 L .667 .747 .91 r
F
.60677 .53844 m .61019 .55237 L .61502 .55153 L .642 .738 .919 r
F
.61153 .54382 m .61502 .55153 L .61791 .55103 L F
.60677 .53844 m .61502 .55153 L .61153 .54382 L F
.60394 .52754 m .60608 .52898 L .60673 .52852 L .667 .747 .91 r
F
.60608 .52898 m .60673 .52853 L .60673 .52852 L F
.60356 .52741 m .60719 .52792 L .6073 .52742 L F
.60356 .52741 m .60673 .52852 L .60714 .52799 L F
.60676 .5286 m .6066 .52889 L .60704 .52875 L .643 .738 .918 r
F
.60644 .53993 m .61019 .55237 L .60677 .53844 L .642 .738 .919 r
F
.60471 .53761 m .60504 .5385 L .60557 .53708 L F
.60712 .52841 m .60704 .52875 L .60757 .52858 L .643 .738 .918 r
F
.6066 .52889 m .6249 .54081 L .60757 .52858 L F
.60696 .52912 m .60968 .53256 L .60861 .5302 L F
.60692 .52929 m .61813 .54324 L .60696 .52912 L F
.6072 .52788 m .60743 .53553 L .60719 .52792 L 0 0 .235 r
F
.60611 .54138 m .61019 .55237 L .60644 .53993 L .642 .738 .919 r
F
.60722 .52782 m .60744 .53549 L .60721 .52783 L 0 0 .235 r
F
.61068 .53478 m .61476 .54383 L .61813 .54324 L .643 .738 .918 r
F
.60913 .53851 m .61791 .55103 L .62469 .54861 L .642 .738 .919 r
F
.60706 .53717 m .61052 .54159 L .60913 .53851 L F
.61052 .54159 m .61791 .55103 L .60913 .53851 L F
.607 .53744 m .61077 .54214 L .60706 .53717 L F
.61077 .54214 m .61791 .55103 L .61052 .54159 L F
.61077 .54214 m .61052 .54159 L .60706 .53717 L F
.60724 .52786 m .60757 .52858 L .60882 .52819 L .643 .738 .918 r
F
.60712 .52841 m .60757 .52858 L .60724 .52786 L F
.60734 .52724 m .60735 .52739 L .60732 .52733 L 0 0 .235 r
F
.60729 .52747 m .60729 .52755 L .60725 .52768 L F
.60744 .53549 m .60744 .5355 L .60721 .52783 L F
.604 .52719 m .60724 .52786 L .60736 .52737 L .643 .738 .918 r
F
.60725 .52784 m .60747 .53538 L .60722 .52797 L 0 0 .235 r
F
.60677 .53844 m .61153 .54382 L .607 .53744 L .642 .738 .919 r
F
.61153 .54382 m .61791 .55103 L .61077 .54214 L F
.61153 .54382 m .61077 .54214 L .607 .53744 L F
.60689 .52832 m .60689 .52844 L .60689 .52832 L .163 .05 .467 r
F
.60697 .52835 m .60704 .52875 L .60712 .52841 L .643 .738 .918 r
F
.6068 .52843 m .6068 .52854 L .60673 .52853 L .163 .05 .467 r
F
.6068 .52854 m .60673 .52863 L .60673 .52853 L F
.604 .52719 m .60676 .5286 L .60697 .52835 L .643 .738 .918 r
F
.60676 .5286 m .60704 .52875 L .60697 .52835 L F
.60648 .53679 m .607 .53744 L .60706 .53717 L .642 .738 .919 r
F
.6066 .52889 m .60675 .52907 L .60675 .52898 L .643 .738 .918 r
F
.60675 .52907 m .60692 .52929 L .60675 .52898 L F
.60675 .52898 m .60692 .52929 L .60696 .52912 L F
.60861 .5302 m .61813 .54324 L .6249 .54081 L F
.60968 .53256 m .61813 .54324 L .60861 .5302 L F
.60723 .53643 m .62469 .54861 L .6262 .54767 L .642 .738 .919 r
F
.60693 .53625 m .60722 .53646 L .60723 .53643 L F
.60722 .53646 m .62469 .54861 L .60723 .53643 L F
.60725 .52784 m .60735 .52739 L .60755 .53502 L 0 0 .235 r
F
.60693 .53625 m .6262 .54767 L .61401 .53901 L .642 .738 .919 r
F
.60648 .53679 m .62469 .54861 L .60693 .53625 L F
.6068 .52854 m .60707 .53608 L .60673 .52863 L .163 .05 .467 r
F
.60707 .53608 m .60702 .53615 L .60673 .52863 L F
.60673 .52863 m .60702 .53615 L .60673 .52863 L F
.60702 .53615 m .60701 .53615 L .60673 .52863 L F
.60673 .52863 m .60701 .53615 L .60693 .53625 L F
.606 .52908 m .60633 .53662 L .60619 .5367 L .402 .228 .528 r
F
.60757 .52858 m .6249 .54081 L .63028 .53745 L .643 .738 .918 r
F
.6249 .54081 m .65627 .54759 L .63028 .53745 L F
.60764 .53582 m .63009 .54526 L .63372 .54119 L .642 .738 .919 r
F
.606 .52908 m .60633 .53662 L .606 .52908 L .402 .228 .528 r
F
.60633 .53662 m .60633 .53662 L .606 .52908 L F
.60609 .52902 m .60641 .53657 L .60605 .52905 L F
.60591 .53746 m .60677 .53844 L .60648 .53679 L .642 .738 .919 r
F
.60432 .5295 m .60416 .52973 L .60442 .52977 L .667 .747 .91 r
F
.6039 .52956 m .60495 .52943 L .60515 .53703 L .648 .418 .556 r
F
.6039 .52956 m .60515 .53703 L .60428 .53709 L F
.60605 .529 m .60637 .53659 L .606 .52903 L .402 .228 .528 r
F
.6063 .53667 m .60581 .53694 L .60648 .53679 L .642 .738 .919 r
F
.60627 .53665 m .60619 .5367 L .6063 .53667 L F
.60619 .5367 m .60581 .53694 L .6063 .53667 L F
.60533 .52928 m .6054 .52937 L .6061 .52899 L .667 .747 .91 r
F
.60522 .52933 m .6055 .52973 L .60574 .52916 L .643 .738 .918 r
F
.60531 .5293 m .606 .52908 L .60619 .5367 L .539 .333 .549 r
F
.60551 .537 m .60591 .53746 L .60635 .53695 L .642 .738 .919 r
F
.60581 .53694 m .60635 .53695 L .60648 .53679 L F
.60551 .537 m .60572 .53699 L .60581 .53694 L F
.60572 .53699 m .60635 .53695 L .60581 .53694 L F
.60625 .52886 m .60654 .53649 L .60611 .52895 L .402 .228 .528 r
F
.60693 .53625 m .60648 .53679 L .60693 .53625 L .642 .738 .919 r
F
.60627 .53665 m .60648 .53679 L .60693 .53625 L F
.60677 .53844 m .607 .53744 L .60648 .53679 L F
.60557 .53708 m .60644 .53993 L .60677 .53844 L F
.60654 .53649 m .60781 .57064 L .60642 .53656 L .402 .228 .528 r
F
.60654 .53649 m .60642 .53656 L .60611 .52895 L F
.60504 .5385 m .60611 .54138 L .60575 .53766 L .642 .738 .919 r
F
.60611 .54138 m .60644 .53993 L .60575 .53766 L F
.60504 .5385 m .60575 .53766 L .60557 .53708 L F
.60563 .53688 m .60619 .5367 L .60707 .57113 L .539 .333 .549 r
F
.60531 .5293 m .60619 .5367 L .60563 .53688 L F
.60637 .53659 m .60781 .57064 L .60633 .53662 L .402 .228 .528 r
F
.60637 .53659 m .60633 .53662 L .606 .52903 L F
.60361 .52959 m .60404 .53711 L .60356 .5296 L .648 .418 .556 r
F
.60404 .53711 m .604 .53711 L .60356 .5296 L F
.60512 .52936 m .60547 .53693 L .60509 .52937 L .539 .333 .549 r
F
.60545 .53694 m .60471 .53761 L .60557 .53708 L .642 .738 .919 r
F
.60495 .52943 m .60534 .53697 L .60515 .53703 L .539 .333 .549 r
F
.60456 .53721 m .60471 .53761 L .60545 .53694 L .642 .738 .919 r
F
.60509 .52937 m .60545 .53694 L .60495 .52943 L .539 .333 .549 r
F
.60545 .53694 m .60707 .57113 L .60534 .53697 L F
.60545 .53694 m .60534 .53697 L .60495 .52943 L F
.60547 .53693 m .60545 .53694 L .60509 .52937 L F
.60571 .53685 m .60551 .537 L .60581 .53694 L .642 .738 .919 r
F
.60545 .53694 m .60551 .537 L .60571 .53685 L F
.60531 .52929 m .60563 .53688 L .60512 .52936 L .539 .333 .549 r
F
.60563 .53688 m .60707 .57113 L .60547 .53693 L F
.60563 .53688 m .60547 .53693 L .60512 .52936 L F
.6141 .53113 m .61936 .53298 L .62151 .53032 L .667 .747 .91 r
F
.6141 .53113 m .62151 .53032 L .61554 .52935 L F
.60882 .52819 m .63028 .53745 L .63391 .53337 L .643 .738 .918 r
F
.60757 .52858 m .63028 .53745 L .60882 .52819 L F
.65614 .53974 m .69281 .53777 L .66346 .53168 L .644 .737 .917 r
F
.63028 .53745 m .65627 .54759 L .66364 .53952 L .643 .738 .918 r
F
.63028 .53745 m .66364 .53952 L .63391 .53337 L F
.61044 .53537 m .63372 .54119 L .63533 .53668 L .642 .738 .919 r
F
.60641 .53657 m .60637 .53659 L .60605 .52905 L .402 .228 .528 r
F
.60725 .52784 m .60755 .53502 L .60747 .53538 L 0 0 .235 r
F
.60747 .53538 m .60744 .53549 L .60722 .52797 L F
.60743 .53553 m .60742 .53557 L .60719 .52792 L F
.60744 .5355 m .60743 .53553 L .60721 .52802 L F
.60744 .5355 m .60721 .52802 L .60721 .52802 L F
.6072 .52807 m .60742 .53557 L .60739 .5357 L F
.6072 .52807 m .60742 .53557 L .6072 .52807 L F
.60721 .52802 m .60721 .52802 L .6072 .52788 L F
.60719 .52792 m .6072 .52807 L .6072 .52807 L F
.60721 .52783 m .60722 .52798 L .6072 .52788 L F
.60722 .52798 m .60721 .52802 L .6072 .52788 L F
.604 .52719 m .60712 .52841 L .60724 .52786 L .643 .738 .918 r
F
.60689 .52844 m .60715 .53599 L .6068 .52854 L .163 .05 .467 r
F
.60655 .52885 m .6066 .52889 L .60676 .5286 L .643 .738 .918 r
F
.6061 .52899 m .60628 .52911 L .60648 .52885 L .667 .747 .91 r
F
.60646 .52879 m .606 .52908 L .6066 .52889 L .643 .738 .918 r
F
.60625 .52892 m .60673 .52863 L .60693 .53625 L .402 .228 .528 r
F
.60689 .52844 m .6072 .52807 L .60739 .5357 L .163 .05 .467 r
F
.60693 .53625 m .61401 .53901 L .60764 .53582 L .642 .738 .919 r
F
.60693 .53625 m .61401 .53901 L .60693 .53625 L F
.60689 .52844 m .60739 .5357 L .60715 .53599 L .163 .05 .467 r
F
.60625 .52892 m .60693 .53625 L .60654 .53649 L .402 .228 .528 r
F
.60722 .52798 m .60744 .5355 L .60721 .52802 L 0 0 .235 r
F
.60715 .53599 m .60707 .53608 L .6068 .52854 L .163 .05 .467 r
F
.60611 .52901 m .60642 .53656 L .60609 .52902 L .402 .228 .528 r
F
.60642 .53656 m .60641 .53657 L .60609 .52902 L F
.60336 .52962 m .604 .53711 L .60354 .53714 L .648 .418 .556 r
F
.60336 .52962 m .604 .53711 L .60336 .52962 L F
.60355 .52951 m .604 .53711 L .60335 .52952 L F
.60378 .52949 m .60359 .52956 L .60377 .5296 L .643 .738 .918 r
F
.6039 .52948 m .60428 .53709 L .6036 .5295 L .648 .418 .556 r
F
.60354 .53714 m .6035 .53755 L .60448 .53731 L .642 .738 .919 r
F
.6035 .53755 m .60204 .55253 L .60438 .53793 L F
.6035 .53755 m .60438 .53793 L .60448 .53731 L F
.60354 .53714 m .60448 .53731 L .60451 .53707 L F
.60428 .53709 m .60601 .57152 L .60404 .53711 L .648 .418 .556 r
F
.60428 .53709 m .60404 .53711 L .6036 .5295 L F
.60375 .53502 m .60451 .53707 L .60545 .53694 L .642 .738 .919 r
F
.60451 .53707 m .60456 .53721 L .60515 .53703 L F
.60451 .53707 m .60515 .53703 L .60545 .53694 L F
.60375 .53502 m .60764 .53582 L .60808 .53555 L F
.60375 .53502 m .60693 .53625 L .60764 .53582 L F
.60715 .53599 m .60739 .5357 L .60828 .57004 L .163 .05 .467 r
F
.60693 .53625 m .60693 .53625 L .60693 .53625 L .642 .738 .919 r
F
.61401 .53901 m .63009 .54526 L .61226 .53776 L F
.61401 .53901 m .61226 .53776 L .60764 .53582 L F
.60681 .52621 m .60687 .52626 L .60686 .52327 L .906 .63 .507 r
F
.604 .52719 m .60686 .52644 L .60634 .52606 L .643 .738 .918 r
F
.60654 .53649 m .60693 .53625 L .60781 .57064 L .402 .228 .528 r
F
.60375 .53502 m .60937 .53571 L .60877 .53528 L .642 .738 .919 r
F
.60641 .53657 m .60781 .57064 L .60637 .53659 L .402 .228 .528 r
F
.60375 .53502 m .60627 .53665 L .60693 .53625 L .642 .738 .919 r
F
.60633 .53662 m .60781 .57064 L .60633 .53662 L .402 .228 .528 r
F
.60673 .52853 m .60673 .52863 L .60673 .52863 L .163 .05 .467 r
F
.604 .52719 m .60655 .52885 L .60676 .5286 L .643 .738 .918 r
F
.60619 .5367 m .60781 .57064 L .60707 .57113 L .402 .228 .528 r
F
.60633 .53662 m .60781 .57064 L .60619 .5367 L F
.60343 .52434 m .60681 .52324 L .60638 .52294 L .667 .747 .91 r
F
.60663 .52547 m .60662 .52551 L .60666 .52549 L F
.60343 .52434 m .60662 .52551 L .60663 .52547 L F
.60343 .52434 m .60599 .52595 L .60662 .52551 L F
.60656 .52306 m .60659 .52606 L .60677 .52321 L .906 .63 .507 r
F
.60642 .53656 m .60781 .57064 L .60641 .53657 L .402 .228 .528 r
F
.60719 .52685 m .60741 .5269 L .60743 .52682 L .667 .747 .91 r
F
.604 .52719 m .60745 .52686 L .60686 .52644 L .643 .738 .918 r
F
.60712 .52689 m .60823 .52741 L .60745 .52686 L F
.604 .52719 m .60734 .52737 L .60712 .52689 L F
.60721 .5269 m .60721 .52708 L .60728 .52708 L .978 .72 .315 r
F
.60721 .52708 m .60729 .52725 L .60728 .52708 L F
.60728 .52708 m .60729 .52725 L .60728 .52708 L F
.60734 .52723 m .60735 .52721 L .60735 .52739 L 0 0 .235 r
F
.60735 .52721 m .60729 .52725 L .60735 .52739 L .978 .72 .315 r
F
.60729 .52708 m .60729 .52725 L .60735 .52721 L F
.60734 .52737 m .60823 .52741 L .60712 .52689 L .643 .738 .918 r
F
.60721 .52708 m .60736 .5346 L .60729 .52725 L .978 .72 .315 r
F
.60689 .53395 m .60695 .53399 L .60694 .52649 L .906 .63 .507 r
F
.60694 .52649 m .60694 .52649 L .60694 .5263 L F
.60689 .53395 m .60694 .52649 L .60694 .52649 L F
.60743 .52682 m .60986 .52742 L .60974 .52646 L .667 .747 .91 r
F
.60741 .5269 m .60986 .52742 L .60743 .52682 L F
.63394 .52556 m .66346 .53168 L .66682 .52269 L .644 .737 .917 r
F
.61376 .52499 m .61898 .52684 L .62112 .52419 L .667 .747 .91 r
F
.63394 .52556 m .66682 .52269 L .63554 .52105 L .644 .737 .917 r
F
.62136 .52726 m .62121 .52421 L .62215 .52134 L 0 0 .346 r
F
.62136 .52726 m .62215 .52134 L .6223 .52439 L F
.61539 .52629 m .62136 .52726 L .6223 .52439 L .667 .747 .91 r
F
.61376 .52499 m .62112 .52419 L .61518 .52323 L F
.61539 .52629 m .6223 .52439 L .61601 .52438 L F
.60941 .52532 m .61539 .52629 L .61601 .52438 L F
.6087 .52621 m .61539 .52629 L .60941 .52532 L F
.61518 .52323 m .62112 .52419 L .62205 .52134 L F
.61601 .52438 m .6223 .52439 L .62196 .52151 L F
.62246 .52746 m .6223 .52439 L .62196 .52151 L .785 .599 .034 r
F
.62246 .52746 m .62196 .52151 L .62211 .52458 L F
.61616 .52744 m .62246 .52746 L .62211 .52458 L .667 .747 .91 r
F
.61616 .52744 m .62211 .52458 L .61592 .52552 L F
.60986 .52742 m .61616 .52744 L .61592 .52552 L F
.60986 .52742 m .61592 .52552 L .60974 .52646 L F
.60745 .52686 m .63552 .52885 L .63498 .52419 L .643 .738 .918 r
F
.60823 .52741 m .63552 .52885 L .60745 .52686 L F
.60681 .52621 m .60684 .53391 L .60687 .52626 L .906 .63 .507 r
F
.60684 .53391 m .60689 .53395 L .60687 .52626 L F
.60694 .5263 m .60695 .53399 L .60714 .53412 L F
.60702 .52362 m .60695 .5265 L .60715 .52391 L .978 .72 .315 r
F
.60807 .52599 m .6083 .52649 L .6087 .52621 L .667 .747 .91 r
F
.60694 .5263 m .60974 .52646 L .6092 .52557 L F
.60719 .52685 m .60974 .52646 L .60694 .5263 L F
.607 .52357 m .60686 .52327 L .60694 .5263 L .978 .72 .315 r
F
.60695 .52632 m .60694 .5263 L .60695 .5265 L F
.607 .52357 m .60694 .5263 L .60695 .52632 L F
.60329 .52129 m .60593 .52294 L .60644 .52264 L .667 .747 .91 r
F
.60653 .52006 m .60584 .52256 L .60656 .52306 L .906 .63 .507 r
F
.60619 .52281 m .60666 .52281 L .60636 .52272 L .667 .747 .91 r
F
.60343 .52434 m .60638 .52294 L .60619 .52281 L F
.60638 .52294 m .60666 .52281 L .60619 .52281 L F
.60653 .52006 m .60576 .51953 L .60584 .52256 L .906 .63 .507 r
F
.6055 .51945 m .60552 .52247 L .60573 .51952 L .805 .544 .543 r
F
.60552 .52247 m .60574 .52253 L .60573 .51952 L F
.6055 .51945 m .60573 .51952 L .60573 .51817 L F
.60329 .52129 m .60544 .51928 L .60444 .51919 L .667 .747 .91 r
F
.60329 .52129 m .60505 .52327 L .60593 .52294 L F
.60343 .52434 m .60636 .52272 L .6061 .52264 L F
.60329 .52129 m .60413 .52362 L .60505 .52327 L F
.60343 .52434 m .6061 .52264 L .60546 .52245 L F
.60573 .51952 m .60574 .52253 L .60576 .51953 L .805 .544 .543 r
F
.60574 .52253 m .60576 .52254 L .60576 .51953 L F
.60575 .52555 m .60578 .52556 L .60576 .51953 L F
.60576 .51953 m .60577 .52254 L .60584 .52256 L F
.60431 .50363 m .60442 .51778 L .60466 .51781 L .733 .485 .553 r
F
.60431 .50363 m .60358 .51766 L .60442 .51778 L F
.60425 .5194 m .61412 .50253 L .60599 .50148 L .644 .737 .917 r
F
.60442 .51778 m .60443 .51919 L .60466 .51781 L .733 .485 .553 r
F
.60445 .52222 m .60468 .52224 L .60466 .51781 L F
.60214 .50359 m .60136 .51794 L .60223 .51775 L .583 .366 .552 r
F
.60102 .5039 m .6011 .51808 L .60136 .51794 L .438 .255 .533 r
F
.6001 .51777 m .58318 .5056 L .57787 .50906 L .644 .737 .917 r
F
.60425 .5194 m .60169 .51772 L .6001 .51777 L F
.60169 .51772 m .58318 .5056 L .6001 .51777 L F
.60323 .50352 m .60248 .5177 L .60333 .51767 L .665 .431 .556 r
F
.60214 .50359 m .60223 .51775 L .60248 .5177 L .583 .366 .552 r
F
.60425 .5194 m .58996 .50308 L .58318 .5056 L .644 .737 .917 r
F
.60323 .50352 m .60333 .51767 L .60358 .51766 L .665 .431 .556 r
F
.60431 .50363 m .60323 .50352 L .60358 .51766 L .733 .485 .553 r
F
.60425 .5194 m .59774 .50167 L .58996 .50308 L .644 .737 .917 r
F
.60425 .5194 m .60599 .50148 L .59774 .50167 L F
.60329 .52129 m .60444 .51919 L .60362 .51912 L .667 .747 .91 r
F
.60329 .52129 m .60362 .51912 L .60349 .51913 L F
.60333 .51767 m .60334 .51914 L .60358 .51766 L .665 .431 .556 r
F
.60343 .52434 m .60546 .52245 L .60461 .52219 L .667 .747 .91 r
F
.60583 .52603 m .60592 .526 L .60599 .52595 L F
.60343 .52434 m .60515 .52629 L .60599 .52595 L F
.60515 .52629 m .60583 .52603 L .60599 .52595 L F
.60343 .52434 m .60488 .52639 L .60515 .52629 L F
.60375 .52726 m .60632 .52588 L .60592 .5256 L F
.59987 .52505 m .60012 .52547 L .60018 .52829 L .988 .718 .377 r
F
.59987 .52505 m .60018 .52829 L .59995 .52789 L F
.60044 .52573 m .60012 .52547 L .6003 .5258 L .667 .747 .91 r
F
.6003 .52562 m .6004 .52847 L .60018 .52552 L .925 .648 .496 r
F
.6004 .52847 m .60028 .52837 L .60018 .52552 L F
.60377 .5273 m .60014 .52821 L .60074 .52877 L .643 .738 .918 r
F
.60377 .52729 m .60632 .52588 L .60375 .52726 L .667 .747 .91 r
F
.604 .52719 m .60374 .52726 L .60377 .5273 L .643 .738 .918 r
F
.60374 .52726 m .60014 .52821 L .60377 .5273 L F
.60373 .52725 m .60592 .5256 L .60561 .52551 L .667 .747 .91 r
F
.60356 .52741 m .60375 .52726 L .60373 .52725 L F
.60375 .52726 m .60592 .5256 L .60373 .52725 L F
.60356 .52741 m .60377 .52729 L .60375 .52726 L F
.59987 .52505 m .59995 .52789 L .59984 .525 L .988 .718 .377 r
F
.59975 .52448 m .59963 .52433 L .59954 .52448 L .667 .747 .91 r
F
.60343 .52434 m .59975 .52433 L .59975 .52448 L F
.59975 .52433 m .59963 .52433 L .59975 .52448 L F
.60343 .52434 m .59954 .52448 L .59978 .5249 L F
.59975 .52437 m .59976 .52487 L .59983 .52769 L .712 .567 0 r
F
.59975 .52437 m .59983 .52769 L .59982 .52724 L F
.59976 .52487 m .59988 .52778 L .59983 .52769 L .988 .718 .377 r
F
.59979 .52492 m .59988 .52778 L .59976 .52487 L F
.59995 .52789 m .59983 .52499 L .59984 .525 L F
.59995 .52789 m .59988 .52778 L .5998 .52493 L F
.59995 .52789 m .5998 .52493 L .59983 .52499 L F
.58661 .52984 m .58649 .52678 L .58929 .52908 L .929 .65 .492 r
F
.59214 .52494 m .58936 .52904 L .59399 .52646 L .667 .747 .91 r
F
.59214 .52494 m .58658 .52676 L .58936 .52904 L F
.5922 .52801 m .58661 .52984 L .58941 .53213 L F
.58495 .52717 m .58649 .52678 L .58661 .52984 L .987 .712 .383 r
F
.58559 .5301 m .58495 .52717 L .58661 .52984 L F
.58665 .53178 m .58511 .52933 L .58505 .52937 L .643 .738 .918 r
F
.58545 .5321 m .58505 .52937 L .57601 .53459 L F
.58665 .53178 m .58505 .52937 L .58545 .5321 L F
.58475 .5273 m .58495 .52717 L .58503 .52919 L .82 .628 .075 r
F
.58503 .52919 m .58495 .52717 L .58559 .5301 L .987 .712 .383 r
F
.58571 .52898 m .57321 .53018 L .57406 .53152 L .643 .738 .918 r
F
.58571 .52898 m .57406 .53152 L .57601 .53459 L F
.60343 .52434 m .59998 .52378 L .59963 .52433 L .667 .747 .91 r
F
.60343 .52434 m .60009 .52543 L .60012 .52547 L F
.60343 .52434 m .60012 .52547 L .60044 .52573 L F
.60343 .52434 m .60064 .52589 L .60075 .52598 L F
.60343 .52434 m .6003 .5258 L .60059 .52592 L F
.60343 .52434 m .59997 .52523 L .60009 .52543 L F
.60343 .52434 m .59978 .5249 L .59997 .52523 L F
.60329 .52129 m .60114 .52329 L .60212 .52342 L F
.6011 .51808 m .60111 .51969 L .60136 .51794 L .438 .255 .533 r
F
.59951 .52067 m .59804 .51942 L .59733 .52031 L .667 .747 .91 r
F
.60329 .52129 m .60024 .52022 L .59992 .52074 L F
.60024 .52022 m .60026 .52334 L .60032 .52325 L .07 0 .435 r
F
.60021 .51857 m .60023 .52025 L .60024 .52022 L F
.60023 .52025 m .60026 .52334 L .60024 .52022 L F
.60329 .52129 m .60026 .52021 L .60024 .52022 L .667 .747 .91 r
F
.60008 .51875 m .6001 .52045 L .60021 .51857 L .07 0 .435 r
F
.6001 .52045 m .60015 .52352 L .60018 .52032 L F
.6001 .52045 m .60018 .52032 L .60021 .51857 L F
.6002 .52344 m .60026 .52334 L .60023 .52025 L F
.6002 .52029 m .60023 .52025 L .60021 .51857 L F
.6002 .52344 m .60023 .52025 L .6002 .52029 L F
.60015 .52352 m .6002 .52344 L .6002 .52029 L F
.60018 .52032 m .6002 .52029 L .60021 .51857 L F
.60015 .52352 m .6002 .52029 L .60018 .52032 L F
.6011 .51808 m .60021 .51857 L .60024 .52022 L .438 .255 .533 r
F
.6011 .51808 m .60024 .52022 L .60083 .51986 L F
.60329 .52129 m .60093 .51981 L .60026 .52021 L .667 .747 .91 r
F
.60329 .52129 m .60166 .51945 L .60093 .51981 L F
.60166 .51945 m .6014 .51952 L .60093 .51981 L F
.60223 .51775 m .60136 .51794 L .6014 .51952 L .583 .366 .552 r
F
.60372 .52722 m .59722 .52785 L .60374 .52726 L .643 .738 .918 r
F
.59722 .52785 m .59715 .52788 L .60374 .52726 L F
.5911 .52623 m .58661 .52984 L .5922 .52801 L .667 .747 .91 r
F
.5911 .52623 m .58495 .52717 L .58661 .52984 L F
.59781 .52618 m .59407 .52954 L .59874 .52695 L F
.59781 .52618 m .5922 .52801 L .59407 .52954 L F
.58586 .52895 m .58571 .52898 L .60374 .52726 L .643 .738 .918 r
F
.60374 .52726 m .59714 .52789 L .59301 .5301 L F
.60259 .5296 m .60217 .52992 L .60233 .53004 L F
.60233 .52964 m .6016 .53097 L .60332 .53005 L .667 .747 .91 r
F
.60115 .52896 m .60179 .52924 L .60179 .52942 L .84 .573 .536 r
F
.60115 .52896 m .60179 .52942 L .60117 .52916 L F
.60152 .5293 m .59887 .53001 L .60012 .5306 L .667 .747 .91 r
F
.60115 .52896 m .60117 .52916 L .60116 .52915 L .84 .573 .536 r
F
.60115 .52896 m .60116 .52915 L .60097 .52888 L F
.60116 .52915 m .60098 .52908 L .60097 .52888 L F
.6004 .52847 m .60082 .52881 L .60083 .52902 L .925 .648 .496 r
F
.60076 .52896 m .60073 .52898 L .60083 .52902 L .667 .747 .91 r
F
.60073 .52898 m .59887 .53001 L .60152 .5293 L F
.60014 .52821 m .60037 .52861 L .60074 .52877 L .643 .738 .918 r
F
.6004 .52847 m .60083 .52902 L .60042 .52869 L .925 .648 .496 r
F
.59874 .52858 m .57601 .53459 L .5982 .52937 L .643 .738 .918 r
F
.60053 .52909 m .59794 .52924 L .59887 .53001 L .667 .747 .91 r
F
.60094 .52886 m .60095 .52907 L .60088 .52884 L .84 .573 .536 r
F
.60021 .5424 m .60048 .55233 L .60204 .55253 L .642 .738 .919 r
F
.59874 .52858 m .5982 .52937 L .59987 .52898 L .643 .738 .918 r
F
.60019 .52851 m .59794 .52924 L .60053 .52909 L .667 .747 .91 r
F
.60012 .5306 m .59669 .53378 L .59965 .53452 L F
.59887 .53001 m .59669 .53378 L .60012 .5306 L F
.58586 .52895 m .57249 .52553 L .57321 .53018 L .643 .738 .918 r
F
.6036 .52352 m .60326 .52356 L .60317 .52194 L .648 .418 .556 r
F
.60329 .52129 m .60321 .52356 L .60407 .52346 L .667 .747 .91 r
F
.60343 .52434 m .60468 .52206 L .60363 .52215 L F
.60369 .52718 m .60561 .52551 L .60485 .52528 L F
.60369 .52718 m .60485 .52528 L .60474 .52527 L F
.60356 .52741 m .60373 .52725 L .60369 .52718 L F
.60373 .52725 m .60561 .52551 L .60369 .52718 L F
.59975 .52423 m .59981 .52711 L .59974 .52416 L .712 .567 0 r
F
.59981 .52711 m .59981 .52705 L .59974 .52416 L F
.59974 .52416 m .59981 .52705 L .59981 .527 L F
.59726 .52529 m .5922 .52801 L .59781 .52618 L .667 .747 .91 r
F
.59771 .52311 m .59214 .52494 L .59399 .52646 L F
.59726 .52529 m .5911 .52623 L .5922 .52801 L F
.59983 .5276 m .5959 .52677 L .58586 .52895 L .643 .738 .918 r
F
.60372 .52722 m .59981 .52699 L .59983 .5276 L F
.59981 .52699 m .5959 .52677 L .59983 .5276 L F
.604 .52719 m .60368 .52717 L .60372 .52722 L F
.59975 .52437 m .59982 .52724 L .59975 .52431 L .712 .567 0 r
F
.59982 .52724 m .59981 .52711 L .59975 .52423 L F
.59982 .52724 m .59975 .52423 L .59975 .52431 L F
.59812 .52348 m .59814 .52247 L .59743 .52337 L .667 .747 .91 r
F
.59967 .52113 m .59975 .52423 L .59974 .52416 L .712 .567 0 r
F
.59963 .51941 m .59967 .52115 L .59967 .52113 L F
.59967 .52115 m .59975 .52423 L .59967 .52113 L F
.59964 .51999 m .5991 .51866 L .59804 .51942 L .667 .747 .91 r
F
.59964 .51957 m .59968 .52131 L .59963 .51941 L .712 .567 0 r
F
.59968 .52131 m .59967 .52118 L .59963 .51941 L F
.60008 .51875 m .59963 .51941 L .59967 .52113 L .07 0 .435 r
F
.60008 .51875 m .59974 .52416 L .60015 .52352 L F
.60025 .52021 m .59962 .51936 L .59964 .51999 L .667 .747 .91 r
F
.59962 .51936 m .5991 .51866 L .59964 .51999 L F
.59975 .52431 m .59975 .52423 L .59967 .52115 L .712 .567 0 r
F
.59975 .52431 m .59967 .52115 L .59967 .52118 L F
.59996 .52067 m .59967 .52113 L .59974 .52416 L .07 0 .435 r
F
.60343 .52434 m .60032 .52325 L .59956 .52371 L .667 .747 .91 r
F
.59969 .52184 m .59703 .52127 L .59716 .52222 L F
.59972 .52303 m .59921 .52171 L .59814 .52247 L F
.60136 .51954 m .60136 .52262 L .6014 .51952 L .438 .255 .533 r
F
.60343 .52434 m .60101 .52283 L .60032 .52325 L .667 .747 .91 r
F
.60136 .52262 m .60138 .5226 L .6014 .51952 L .438 .255 .533 r
F
.6014 .51952 m .60138 .5226 L .60147 .52255 L F
.60223 .51775 m .6014 .51952 L .60224 .51928 L .583 .366 .552 r
F
.60136 .51794 m .60136 .51954 L .6014 .51952 L .438 .255 .533 r
F
.60223 .51775 m .60224 .51928 L .60248 .5177 L .583 .366 .552 r
F
.60224 .51928 m .60244 .51923 L .60248 .5177 L F
.60132 .51957 m .60136 .51954 L .60136 .51794 L .438 .255 .533 r
F
.60111 .51969 m .60132 .51957 L .60136 .51794 L F
.60095 .51979 m .60032 .52325 L .60066 .52304 L F
.6011 .51808 m .60083 .51986 L .60095 .51979 L F
.60083 .51986 m .60032 .52325 L .60095 .51979 L F
.6011 .51808 m .60066 .52304 L .60113 .52276 L F
.60083 .51986 m .60024 .52022 L .60032 .52325 L F
.60101 .52283 m .60057 .52112 L .59921 .52171 L .667 .747 .91 r
F
.60343 .52434 m .60176 .52247 L .60101 .52283 L F
.60343 .52434 m .60129 .52633 L .60227 .52646 L F
.60343 .52434 m .60075 .52598 L .60138 .52624 L F
.60329 .52129 m .60254 .51921 L .60166 .51945 L F
.60333 .51767 m .60252 .51921 L .60334 .51914 L .665 .431 .556 r
F
.60254 .51921 m .60254 .5192 L .60252 .51921 L .667 .747 .91 r
F
.60254 .51921 m .60252 .51921 L .60166 .51945 L F
.60333 .51767 m .60248 .5177 L .60252 .51921 L .665 .431 .556 r
F
.60155 .52222 m .60146 .52213 L .60147 .52255 L .583 .366 .552 r
F
.60224 .51928 m .60146 .52213 L .60155 .52222 L F
.60224 .51928 m .6014 .51952 L .60146 .52213 L F
.60224 .51928 m .60147 .52255 L .60189 .52243 L F
.60176 .52247 m .60147 .52255 L .60101 .52283 L .667 .747 .91 r
F
.60115 .52575 m .60137 .52563 L .60136 .51954 L .438 .255 .533 r
F
.60115 .52575 m .60136 .51954 L .60132 .51957 L F
.60111 .51969 m .60115 .52575 L .60132 .51957 L F
.60163 .52232 m .60213 .52075 L .60057 .52112 L .667 .747 .91 r
F
.60248 .51922 m .60249 .52227 L .60252 .51921 L .583 .366 .552 r
F
.60343 .52434 m .60259 .52224 L .60176 .52247 L .667 .747 .91 r
F
.60113 .52276 m .60039 .52616 L .60115 .52575 L .438 .255 .533 r
F
.60066 .52304 m .60039 .52616 L .60113 .52276 L F
.60136 .52262 m .60137 .52563 L .60138 .5226 L F
.60226 .52233 m .60154 .52554 L .60228 .52538 L .583 .366 .552 r
F
.60189 .52243 m .60154 .52554 L .60226 .52233 L F
.60147 .52255 m .60137 .52563 L .60154 .52554 L .438 .255 .533 r
F
.60138 .5226 m .60137 .52563 L .60147 .52255 L F
.60189 .52243 m .60147 .52255 L .60154 .52554 L .583 .366 .552 r
F
.60343 .52434 m .60266 .52223 L .60259 .52224 L .667 .747 .91 r
F
.60317 .52194 m .60326 .52356 L .60321 .52356 L .648 .418 .556 r
F
.60329 .52129 m .60308 .52355 L .60321 .52356 L .667 .747 .91 r
F
.60249 .52227 m .60251 .52226 L .60252 .51921 L .583 .366 .552 r
F
.60248 .5177 m .60248 .51922 L .60252 .51921 L F
.60244 .51923 m .60248 .51922 L .60248 .5177 L F
.60334 .51914 m .60359 .51912 L .60358 .51766 L .665 .431 .556 r
F
.60329 .52129 m .60363 .51759 L .602 .51771 L .667 .747 .91 r
F
.60334 .51914 m .60252 .51921 L .60259 .52224 L .665 .431 .556 r
F
.60334 .51914 m .60259 .52224 L .60337 .52217 L F
.60252 .51921 m .60251 .52226 L .60259 .52224 L .583 .366 .552 r
F
.60224 .51928 m .60189 .52243 L .60226 .52233 L F
.60343 .52434 m .60322 .52658 L .60328 .52659 L .667 .747 .91 r
F
.60343 .52434 m .60227 .52646 L .60322 .52658 L F
.60369 .52215 m .60369 .52519 L .60377 .52518 L .665 .431 .556 r
F
.60032 .52325 m .60084 .52273 L .59972 .52303 L .667 .747 .91 r
F
.60101 .52283 m .60084 .52273 L .60032 .52325 L F
.60084 .52273 m .59921 .52171 L .59972 .52303 L F
.60238 .52535 m .60234 .5253 L .60343 .52682 L .643 .738 .918 r
F
.60228 .52538 m .60249 .52533 L .60249 .52227 L .583 .366 .552 r
F
.60238 .5223 m .60249 .52227 L .60248 .51922 L F
.60228 .52538 m .60249 .52227 L .60238 .5223 L F
.60228 .52538 m .60248 .51922 L .60244 .51923 L F
.60224 .51928 m .60228 .52538 L .60244 .51923 L F
.60259 .52224 m .60213 .52075 L .60163 .52232 L .667 .747 .91 r
F
.60266 .52223 m .60266 .52222 L .60259 .52224 L F
.60266 .52222 m .60213 .52075 L .60259 .52224 L F
.60066 .52304 m .60032 .52325 L .60039 .52616 L .438 .255 .533 r
F
.59935 .51838 m .58103 .51458 L .59656 .519 L .644 .737 .917 r
F
.59896 .52058 m .59733 .52031 L .59929 .52115 L .667 .747 .91 r
F
.59968 .52128 m .59703 .52127 L .59969 .52184 L F
.59804 .51942 m .59137 .51934 L .59733 .52031 L F
.59656 .519 m .58103 .51458 L .57297 .51776 L .644 .737 .917 r
F
.59804 .51942 m .59277 .51756 L .59137 .51934 L .667 .747 .91 r
F
.5991 .51866 m .59277 .51756 L .59804 .51942 L F
.5991 .51866 m .5949 .51603 L .59277 .51756 L F
.59703 .52127 m .59104 .52316 L .59716 .52222 L F
.59703 .52127 m .59078 .52125 L .59104 .52316 L F
.59733 .52031 m .59078 .52125 L .59703 .52127 L F
.59733 .52031 m .59137 .51934 L .59078 .52125 L F
.59921 .52171 m .59284 .5206 L .59814 .52247 L F
.5949 .51603 m .58749 .51569 L .59277 .51756 L F
.59921 .52171 m .59498 .51906 L .59284 .5206 L F
.59992 .52074 m .59896 .52058 L .59958 .52128 L F
.59896 .52058 m .59929 .52115 L .59958 .52128 L F
.59968 .52128 m .59967 .52113 L .59958 .52128 L F
.60008 .51875 m .59967 .52113 L .59996 .52067 L .07 0 .435 r
F
.60057 .52112 m .59498 .51906 L .59921 .52171 L .667 .747 .91 r
F
.60024 .52022 m .59804 .51942 L .59951 .52067 L F
.60025 .52021 m .59804 .51942 L .60024 .52022 L F
.59992 .52074 m .60024 .52022 L .59951 .52067 L F
.60057 .52112 m .5977 .51789 L .59498 .51906 L F
.5949 .51603 m .59068 .51339 L .58749 .51569 L F
.5976 .51485 m .59068 .51339 L .5949 .51603 L F
.5976 .51485 m .59474 .51162 L .59068 .51339 L F
.59277 .51756 m .58539 .51837 L .59137 .51934 L F
.59277 .51756 m .58749 .51569 L .58539 .51837 L F
.5977 .51789 m .59074 .51641 L .59498 .51906 L F
.60045 .51808 m .5949 .51603 L .5991 .51866 L F
.60045 .51808 m .5976 .51485 L .5949 .51603 L F
.5977 .51789 m .59483 .51464 L .59074 .51641 L F
.59483 .51464 m .59062 .51335 L .59074 .51641 L .518 .32 .552 r
F
.59483 .51464 m .5947 .51157 L .59062 .51335 L F
.59481 .51766 m .59483 .51464 L .59074 .51641 L F
.59495 .51761 m .59483 .51464 L .59481 .51766 L F
.59956 .52371 m .59972 .52303 L .59812 .52348 L .667 .747 .91 r
F
.60032 .52325 m .59972 .52303 L .59956 .52371 L F
.59972 .52303 m .59814 .52247 L .59812 .52348 L F
.60015 .52352 m .59974 .52416 L .59981 .527 L .07 0 .435 r
F
.59998 .52378 m .59956 .52371 L .59963 .52433 L .667 .747 .91 r
F
.60032 .52325 m .6003 .52629 L .60039 .52616 L .07 0 .435 r
F
.60026 .52334 m .6003 .52629 L .60032 .52325 L F
.59956 .52371 m .59749 .52338 L .59862 .52428 L .667 .747 .91 r
F
.59956 .52371 m .59862 .52428 L .59868 .52433 L F
.60015 .52352 m .59981 .527 L .60019 .52645 L .07 0 .435 r
F
.59963 .52433 m .59713 .52433 L .59922 .52499 L .667 .747 .91 r
F
.60019 .52645 m .6003 .52629 L .60026 .52334 L .07 0 .435 r
F
.60019 .52645 m .60026 .52334 L .6002 .52344 L F
.60015 .52352 m .60019 .52645 L .6002 .52344 L F
.59716 .52222 m .59214 .52494 L .59771 .52311 L .667 .747 .91 r
F
.59716 .52222 m .59104 .52316 L .59214 .52494 L F
.59814 .52247 m .59143 .52239 L .59743 .52337 L F
.58753 .51872 m .58741 .51566 L .5853 .51835 L .184 .071 .482 r
F
.59814 .52247 m .59284 .5206 L .59143 .52239 L .667 .747 .91 r
F
.59137 .51934 m .58452 .52123 L .59078 .52125 L F
.59137 .51934 m .58539 .51837 L .58452 .52123 L F
.59498 .51906 m .58753 .51872 L .59284 .5206 L F
.59074 .51641 m .58741 .51566 L .58753 .51872 L .395 .228 .533 r
F
.59074 .51641 m .59062 .51335 L .58741 .51566 L F
.59498 .51906 m .59074 .51641 L .58753 .51872 L .667 .747 .91 r
F
.59044 .51938 m .59074 .51641 L .58753 .51872 L .395 .228 .533 r
F
.59085 .51912 m .59074 .51641 L .59044 .51938 L F
.60327 .52659 m .60377 .52518 L .60279 .52527 L .667 .747 .91 r
F
.59749 .52338 m .59743 .52337 L .59868 .52433 L F
.59978 .5249 m .59954 .52448 L .59922 .52499 L F
.58103 .51458 m .5744 .51321 L .57426 .51366 L .644 .737 .917 r
F
.58103 .51458 m .57426 .51366 L .57297 .51776 L F
.59922 .52499 m .59726 .52529 L .59889 .5255 L .667 .747 .91 r
F
.59078 .52125 m .58492 .5241 L .59104 .52316 L F
.59078 .52125 m .58452 .52123 L .58492 .5241 L F
.59713 .52433 m .5911 .52623 L .59726 .52529 L F
.59104 .52316 m .58658 .52676 L .59214 .52494 L F
.59713 .52433 m .59084 .52431 L .5911 .52623 L F
.58542 .52141 m .5853 .51835 L .58442 .52123 L 0 0 .319 r
F
.59743 .52337 m .59084 .52431 L .59713 .52433 L .667 .747 .91 r
F
.59743 .52337 m .59143 .52239 L .59084 .52431 L F
.58753 .51872 m .5853 .51835 L .58542 .52141 L .184 .071 .482 r
F
.59284 .5206 m .58542 .52141 L .59143 .52239 L .667 .747 .91 r
F
.59284 .5206 m .58753 .51872 L .58542 .52141 L F
.58718 .52171 m .58753 .51872 L .58542 .52141 L .184 .071 .482 r
F
.58763 .52119 m .58753 .51872 L .58718 .52171 L F
.60358 .52703 m .5913 .51895 L .58801 .52095 L .643 .738 .918 r
F
.59481 .51766 m .59074 .51641 L .59085 .51912 L .518 .32 .552 r
F
.5913 .51895 m .5912 .51889 L .59085 .51912 L .643 .738 .918 r
F
.5913 .51895 m .59085 .51912 L .58801 .52095 L F
.60343 .52682 m .58277 .51335 L .60358 .52703 L F
.60101 .52524 m .59497 .51761 L .59124 .51887 L F
.59497 .51761 m .59437 .51686 L .59252 .51805 L F
.59497 .51761 m .59252 .51805 L .59124 .51887 L F
.602 .51771 m .5976 .51485 L .60045 .51808 L .667 .747 .91 r
F
.60082 .51715 m .59483 .51464 L .5977 .51789 L F
.602 .51771 m .6007 .51412 L .5976 .51485 L F
.6007 .51412 m .59474 .51162 L .5976 .51485 L F
.6007 .51412 m .5994 .51051 L .59474 .51162 L F
.60082 .51715 m .59951 .51353 L .59483 .51464 L F
.59964 .5166 m .59483 .51464 L .59495 .51761 L .602 .385 .559 r
F
.59964 .5166 m .59495 .51761 L .59665 .51731 L F
.60104 .52519 m .5896 .51082 L .60101 .52524 L .643 .738 .918 r
F
.60234 .5253 m .59542 .51744 L .60212 .52531 L F
.59542 .51744 m .59535 .51747 L .60212 .52531 L F
.60212 .52531 m .5896 .51082 L .60116 .52534 L F
.60343 .52434 m .60328 .52659 L .6042 .52648 L .667 .747 .91 r
F
.60359 .52705 m .60377 .52518 L .60327 .52659 L F
.60362 .52215 m .60363 .52526 L .60369 .52215 L .665 .431 .556 r
F
.60445 .52222 m .60448 .52525 L .60468 .52224 L .733 .485 .553 r
F
.60448 .52525 m .60469 .52527 L .60468 .52224 L F
.60552 .52247 m .60478 .52224 L .60485 .52528 L .805 .544 .543 r
F
.60375 .53502 m .60571 .53685 L .60627 .53665 L .642 .738 .919 r
F
.60515 .53703 m .60707 .57113 L .60601 .57152 L .539 .333 .549 r
F
.60534 .53697 m .60707 .57113 L .60515 .53703 L F
.60547 .53693 m .60707 .57113 L .60545 .53694 L F
.60375 .53502 m .60545 .53694 L .60571 .53685 L .642 .738 .919 r
F
.60408 .52773 m .606 .52903 L .60608 .52898 L .667 .747 .91 r
F
.604 .52719 m .60574 .52916 L .606 .52908 L .643 .738 .918 r
F
.606 .52903 m .606 .52908 L .606 .52908 L .402 .228 .528 r
F
.60609 .52902 m .60605 .52905 L .60605 .529 L F
.60611 .52895 m .60611 .52901 L .60611 .52895 L F
.604 .52719 m .606 .52908 L .60646 .52879 L .643 .738 .918 r
F
.60408 .52773 m .60533 .52928 L .606 .52903 L .667 .747 .91 r
F
.60408 .52773 m .60608 .52898 L .60394 .52754 L F
.604 .52719 m .60433 .52809 L .60574 .52916 L .643 .738 .918 r
F
.60502 .52904 m .60522 .52933 L .60525 .52931 L .667 .747 .91 r
F
.60433 .52809 m .60522 .52933 L .60574 .52916 L .643 .738 .918 r
F
.60356 .52741 m .60432 .5295 L .60516 .5294 L .667 .747 .91 r
F
.60356 .52741 m .60502 .52904 L .60408 .52773 L F
.60552 .52247 m .60485 .52528 L .60555 .52549 L .805 .544 .543 r
F
.604 .52719 m .60502 .52546 L .60486 .5254 L .643 .738 .918 r
F
.60428 .53709 m .60515 .53703 L .60601 .57152 L .648 .418 .556 r
F
.6039 .52948 m .60495 .52943 L .6039 .52956 L F
.60404 .53711 m .60601 .57152 L .604 .53711 L F
.60354 .53714 m .60601 .57152 L .60439 .5717 L F
.604 .53711 m .60601 .57152 L .60354 .53714 L F
.60555 .52549 m .60485 .52528 L .60486 .5254 L .805 .544 .543 r
F
.60555 .52549 m .60486 .5254 L .60555 .52564 L F
.60574 .52253 m .60575 .52555 L .60576 .52254 L F
.60571 .53685 m .60581 .53694 L .60619 .5367 L .642 .738 .919 r
F
.60571 .53685 m .60619 .5367 L .60627 .53665 L F
.60584 .52256 m .60584 .52574 L .60592 .52576 L .805 .544 .543 r
F
.604 .52719 m .60634 .52606 L .60576 .52571 L .643 .738 .918 r
F
.60659 .52606 m .60592 .52576 L .60659 .52624 L .906 .63 .507 r
F
.60634 .52606 m .60653 .52597 L .60592 .52576 L .643 .738 .918 r
F
.60634 .52606 m .60592 .52576 L .60576 .52571 L F
.60659 .52606 m .60592 .5256 L .60592 .52576 L .906 .63 .507 r
F
.60659 .52624 m .60592 .52576 L .60611 .53339 L F
.60659 .52624 m .60611 .53339 L .60666 .53378 L F
.6058 .53329 m .60586 .53331 L .60584 .52256 L .805 .544 .543 r
F
.60656 .52306 m .60592 .5256 L .60659 .52606 L .906 .63 .507 r
F
.60592 .5256 m .60667 .52569 L .60568 .52544 L .667 .747 .91 r
F
.60632 .52588 m .60651 .52577 L .60592 .5256 L F
.60651 .52577 m .60667 .52569 L .60592 .5256 L F
.60577 .52254 m .60578 .52556 L .60584 .52256 L .805 .544 .543 r
F
.60578 .52556 m .6058 .53329 L .60583 .52557 L F
.60578 .52556 m .60583 .52557 L .60584 .52256 L F
.60656 .52306 m .60584 .52256 L .60592 .5256 L .906 .63 .507 r
F
.60659 .52606 m .60679 .5262 L .60677 .52321 L F
.60568 .52544 m .60667 .52569 L .6063 .52487 L .667 .747 .91 r
F
.60686 .52327 m .60687 .52626 L .60694 .5263 L .906 .63 .507 r
F
.60676 .52022 m .60677 .52321 L .60678 .52024 L F
.60677 .52321 m .60679 .52322 L .60678 .52024 L F
.60679 .52638 m .6068 .52639 L .60679 .52322 L F
.60679 .52322 m .60679 .52322 L .60678 .52024 L F
.60679 .52638 m .60679 .52322 L .60679 .52322 L F
.6055 .51945 m .60478 .52224 L .60552 .52247 L .805 .544 .543 r
F
.60546 .52245 m .60555 .52237 L .60461 .52219 L .667 .747 .91 r
F
.60682 .5339 m .60684 .53391 L .60681 .5264 L .906 .63 .507 r
F
.6068 .52639 m .60681 .5264 L .60678 .52024 L F
.60682 .5339 m .60681 .5264 L .6068 .52639 L F
.60677 .52321 m .60679 .52638 L .60679 .52322 L F
.60552 .52247 m .60555 .52549 L .60574 .52253 L .805 .544 .543 r
F
.60555 .52549 m .60575 .52555 L .60574 .52253 L F
.60493 .52492 m .6063 .52487 L .60553 .52383 L .667 .747 .91 r
F
.60524 .52513 m .6063 .52487 L .60493 .52492 L F
.60485 .52528 m .6063 .52487 L .60475 .52525 L F
.60561 .52551 m .60577 .52536 L .60485 .52528 L F
.60577 .52536 m .6063 .52487 L .60485 .52528 L F
.60468 .52224 m .60469 .52527 L .60478 .52224 L .733 .485 .553 r
F
.60575 .52571 m .60578 .53328 L .60578 .52572 L .805 .544 .543 r
F
.60375 .53502 m .60581 .53329 L .60564 .53323 L .642 .738 .919 r
F
.60679 .52638 m .60682 .5339 L .6068 .52639 L .906 .63 .507 r
F
.60592 .52576 m .60592 .53333 L .60611 .53339 L .805 .544 .543 r
F
.60375 .53502 m .60652 .53368 L .60581 .53329 L .642 .738 .919 r
F
.60652 .53368 m .60671 .53359 L .60611 .53339 L F
.60652 .53368 m .60611 .53339 L .60581 .53329 L F
.60659 .52624 m .60666 .53378 L .60679 .52638 L .906 .63 .507 r
F
.60666 .53378 m .60682 .5339 L .60679 .52638 L F
.60584 .52574 m .60586 .53331 L .60592 .52576 L .805 .544 .543 r
F
.60687 .52644 m .60689 .53395 L .60694 .52649 L .906 .63 .507 r
F
.60721 .52708 m .60695 .5265 L .60714 .53412 L .978 .72 .315 r
F
.60721 .52708 m .60714 .53412 L .60736 .5346 L F
.60729 .52725 m .60742 .53474 L .60735 .52739 L F
.60742 .53474 m .60747 .53485 L .60735 .52739 L F
.60735 .52739 m .60747 .53485 L .60755 .53502 L F
.60724 .52786 m .60779 .52798 L .60736 .52737 L .643 .738 .918 r
F
.60736 .5346 m .60742 .53474 L .60728 .52708 L .978 .72 .315 r
F
.60375 .53502 m .60779 .53395 L .60671 .53359 L .642 .738 .919 r
F
.60882 .52819 m .63391 .53337 L .61084 .52755 L .643 .738 .918 r
F
.69758 .52669 m .70086 .52182 L .70082 .52957 L .934 .67 .515 r
F
.68753 .51775 m .69761 .52083 L .69758 .52669 L F
.69761 .52083 m .70086 .52182 L .69758 .52669 L F
.6932 .54563 m .69325 .53786 L .69758 .5269 L 0 0 .317 r
F
.6932 .54563 m .69758 .5269 L .69758 .52835 L F
.66346 .53168 m .69536 .52492 L .66682 .52269 L .644 .737 .917 r
F
.70047 .52947 m .69758 .52685 L .70082 .52957 L .934 .67 .515 r
F
.69758 .52685 m .68753 .51775 L .69758 .52669 L F
.69758 .52685 m .69758 .52669 L .70082 .52957 L F
.6932 .54563 m .69335 .54506 L .69754 .5347 L 0 0 .317 r
F
.69335 .54506 m .69758 .52835 L .69755 .53449 L F
.69335 .54506 m .69755 .53449 L .69754 .5347 L F
.70082 .52957 m .71885 .53122 L .71886 .53896 L .857 .601 .55 r
F
.70082 .52957 m .70086 .52182 L .71885 .53122 L F
.72538 .51028 m .70122 .52165 L .71913 .53101 L .644 .736 .916 r
F
.70079 .53736 m .70082 .52957 L .71886 .53896 L .857 .601 .55 r
F
.72538 .51028 m .71913 .53101 L .73735 .51661 L .644 .736 .916 r
F
.72516 .51818 m .70082 .52957 L .71886 .53896 L .644 .737 .917 r
F
.71665 .50231 m .70122 .52165 L .72538 .51028 L .644 .736 .916 r
F
.71637 .5102 m .70082 .52957 L .72516 .51818 L .644 .737 .917 r
F
.68753 .51775 m .68759 .50997 L .70086 .52182 L .934 .67 .515 r
F
.71665 .50231 m .68802 .50986 L .70122 .52165 L .644 .736 .916 r
F
.71637 .5102 m .68753 .51775 L .70082 .52957 L .644 .737 .917 r
F
.71637 .51804 m .70266 .52161 L .70079 .53736 L .643 .738 .918 r
F
.69536 .52492 m .69449 .52415 L .66682 .52269 L .644 .737 .917 r
F
.68753 .51796 m .68753 .51775 L .70047 .52947 L .934 .67 .515 r
F
.67995 .50419 m .68759 .50997 L .68753 .51775 L .992 .739 .41 r
F
.66682 .52269 m .69089 .52396 L .68583 .51492 L .644 .737 .917 r
F
.68733 .5176 m .67995 .50419 L .68753 .51775 L .992 .739 .41 r
F
.66682 .52269 m .68583 .51492 L .66594 .51337 L .644 .737 .917 r
F
.68583 .51492 m .68398 .51161 L .66594 .51337 L F
.67994 .5044 m .67995 .50419 L .68733 .5176 L .992 .739 .41 r
F
.67995 .50419 m .68003 .49638 L .68759 .50997 L F
.71177 .49323 m .68802 .50986 L .71665 .50231 L .644 .736 .916 r
F
.71177 .49323 m .6805 .49633 L .68802 .50986 L F
.71145 .50109 m .67995 .50419 L .68753 .51775 L .644 .737 .917 r
F
.67871 .48977 m .68003 .49638 L .67995 .50419 L .813 .652 .102 r
F
.66594 .51337 m .68059 .51194 L .67987 .50354 L .644 .737 .917 r
F
.67991 .50402 m .67871 .48977 L .67995 .50419 L .813 .652 .102 r
F
.66594 .51337 m .67987 .50354 L .66079 .50436 L .644 .737 .917 r
F
.67987 .50354 m .67951 .49938 L .66079 .50436 L F
.67871 .48998 m .67871 .48977 L .67991 .50402 L .813 .652 .102 r
F
.67871 .48977 m .67879 .48192 L .68003 .49638 L F
.71114 .48362 m .6805 .49633 L .71177 .49323 L .644 .736 .916 r
F
.71114 .48362 m .67927 .48194 L .6805 .49633 L F
.71081 .49146 m .67871 .48977 L .67995 .50419 L .644 .737 .917 r
F
.6797 .48711 m .67879 .48192 L .67871 .48977 L 0 0 .293 r
F
.71487 .47412 m .67927 .48194 L .71114 .48362 L .644 .736 .916 r
F
.71487 .47412 m .6846 .46764 L .67927 .48194 L F
.68407 .47543 m .67977 .48072 L .6797 .48711 L 0 0 .293 r
F
.67977 .48072 m .67879 .48192 L .6797 .48711 L F
.74302 .48529 m .71114 .48362 L .71177 .49323 L .644 .736 .916 r
F
.74497 .48056 m .71114 .48362 L .74302 .48529 L F
.74497 .48056 m .71487 .47412 L .71114 .48362 L F
.71457 .48194 m .67871 .48977 L .71081 .49146 L .644 .737 .917 r
F
.71457 .48194 m .68407 .47543 L .67871 .48977 L F
.68588 .49769 m .68955 .49672 L .68036 .48843 L F
.68588 .49769 m .68036 .48843 L .67956 .48771 L F
.68588 .49769 m .67956 .48771 L .67917 .48874 L F
.67885 .4896 m .67871 .48977 L .67871 .48998 L 0 0 .293 r
F
.66079 .50436 m .67471 .50066 L .67597 .48447 L .644 .737 .917 r
F
.67471 .50066 m .68588 .49769 L .67917 .48874 L F
.67885 .4896 m .6797 .48729 L .67871 .48977 L 0 0 .293 r
F
.6797 .48729 m .68407 .47543 L .6797 .48711 L F
.6797 .48729 m .6797 .48711 L .67871 .48977 L F
.68407 .47564 m .68407 .47543 L .67885 .4896 L F
.67471 .50066 m .67917 .48874 L .67597 .48447 L .644 .737 .917 r
F
.67987 .50354 m .68955 .49672 L .67951 .49938 L F
.71081 .49146 m .67995 .50419 L .71145 .50109 L F
.67987 .50354 m .69706 .51033 L .68955 .49672 L F
.67862 .49765 m .67871 .48998 L .67991 .50402 L .813 .652 .102 r
F
.68281 .49787 m .67862 .49765 L .69053 .50535 L .643 .738 .918 r
F
.67991 .50402 m .67995 .50419 L .67994 .5044 L .813 .652 .102 r
F
.68059 .51194 m .69706 .51033 L .67987 .50354 L .644 .737 .917 r
F
.68583 .51492 m .69706 .51033 L .68398 .51161 L F
.71145 .50109 m .68753 .51775 L .71637 .5102 L F
.68583 .51492 m .69811 .52434 L .69706 .51033 L F
.69729 .51755 m .68998 .4966 L .68993 .50426 L .992 .738 .403 r
F
.68993 .50426 m .69053 .50535 L .69272 .50677 L .643 .738 .918 r
F
.68281 .49787 m .69053 .50535 L .68993 .50426 L F
.67862 .49765 m .67991 .50402 L .67987 .51204 L .813 .652 .102 r
F
.67991 .50402 m .67994 .5044 L .67987 .51204 L F
.67987 .51204 m .67994 .5044 L .68733 .5176 L .992 .739 .41 r
F
.69272 .50677 m .67862 .49765 L .67987 .51204 L .643 .738 .918 r
F
.68733 .5176 m .68753 .51775 L .68753 .51796 L .992 .739 .41 r
F
.69089 .52396 m .69811 .52434 L .68583 .51492 L .644 .737 .917 r
F
.67987 .51204 m .68733 .5176 L .68747 .52556 L .992 .739 .41 r
F
.68733 .5176 m .68753 .51796 L .68747 .52556 L F
.68747 .52556 m .68753 .51796 L .69413 .52383 L .934 .67 .515 r
F
.69754 .51859 m .67987 .51204 L .68747 .52556 L .643 .738 .918 r
F
.69964 .52922 m .69978 .52886 L .70047 .52947 L .934 .67 .515 r
F
.66346 .53168 m .69281 .53777 L .69723 .52658 L .644 .737 .917 r
F
.66346 .53168 m .69723 .52658 L .69536 .52492 L F
.69316 .55343 m .6932 .54563 L .69754 .5347 L 0 0 .317 r
F
.69755 .53449 m .70047 .52947 L .70079 .53736 L .934 .67 .515 r
F
.69757 .5286 m .70047 .52947 L .69755 .53449 L F
.70047 .52947 m .70082 .52957 L .70082 .52978 L F
.70047 .52947 m .70082 .52978 L .70079 .53736 L F
.69855 .53196 m .69755 .53449 L .69883 .53562 L .643 .738 .918 r
F
.69536 .52492 m .69723 .52658 L .69811 .52434 L .644 .737 .917 r
F
.69754 .5347 m .69859 .52436 L .69855 .53217 L 0 0 .317 r
F
.69758 .52835 m .69859 .52436 L .69754 .5347 L F
.69536 .52492 m .69811 .52434 L .69449 .52415 L .644 .737 .917 r
F
.69758 .52835 m .69758 .5269 L .69859 .52436 L 0 0 .317 r
F
.69852 .53159 m .69753 .51029 L .69749 .51792 L .798 .639 .083 r
F
.68747 .52556 m .69757 .5286 L .69755 .53449 L .934 .67 .515 r
F
.69852 .53159 m .69859 .52436 L .69753 .51029 L .798 .639 .083 r
F
.69855 .53196 m .68747 .52556 L .69755 .53449 L .643 .738 .918 r
F
.69855 .53196 m .69859 .52436 L .69852 .53159 L .798 .639 .083 r
F
.70266 .52161 m .69786 .52286 L .69855 .53196 L .643 .738 .918 r
F
.69786 .52286 m .68747 .52556 L .69855 .53196 L F
.69855 .53217 m .69852 .53159 L .69823 .52785 L .798 .639 .083 r
F
.69749 .51792 m .67987 .51204 L .69754 .51859 L .643 .738 .918 r
F
.69729 .51755 m .69753 .51029 L .68998 .4966 L .992 .738 .403 r
F
.69749 .51792 m .69753 .51029 L .69729 .51755 L F
.69692 .51038 m .6935 .51071 L .69749 .51792 L .643 .738 .918 r
F
.6935 .51071 m .67987 .51204 L .69749 .51792 L F
.69749 .51813 m .69749 .51792 L .69729 .51755 L .992 .738 .403 r
F
.71144 .50896 m .68747 .52556 L .71637 .51804 L .643 .738 .918 r
F
.69855 .53217 m .69823 .52785 L .69749 .51813 L .798 .639 .083 r
F
.69852 .53159 m .69749 .51792 L .69749 .51813 L F
.70266 .52161 m .69855 .53196 L .70079 .53736 L .643 .738 .918 r
F
.69855 .53196 m .69883 .53562 L .70079 .53736 L F
.69788 .53479 m .69761 .53454 L .69855 .53217 L 0 0 .317 r
F
.69754 .53615 m .69761 .53454 L .69788 .53479 L F
.69754 .53615 m .69754 .5347 L .69761 .53454 L F
.69316 .55343 m .69754 .5347 L .69754 .53615 L F
.71144 .50896 m .69692 .51038 L .69754 .51859 L .643 .738 .918 r
F
.69855 .53217 m .69855 .53196 L .69852 .53159 L .798 .639 .083 r
F
.7108 .49935 m .67987 .51204 L .71144 .50896 L .643 .738 .918 r
F
.69749 .51813 m .69729 .51755 L .68993 .50447 L .992 .738 .403 r
F
.69729 .51755 m .68993 .50426 L .68993 .50447 L F
.68956 .50394 m .67968 .48925 L .67962 .49501 L .936 .671 .51 r
F
.68993 .50447 m .68998 .4966 L .6797 .48732 L F
.68993 .50447 m .6797 .48732 L .67968 .48925 L F
.74324 .49011 m .71177 .49323 L .71665 .50231 L .644 .736 .916 r
F
.74302 .48529 m .71177 .49323 L .74324 .49011 L F
.74324 .49011 m .71665 .50231 L .74561 .49469 L F
.74292 .49314 m .71081 .49146 L .71145 .50109 L .644 .737 .917 r
F
.77239 .47562 m .77387 .48958 L .7735 .48961 L .648 .416 .554 r
F
.76787 .53874 m .78888 .55565 L .78441 .53839 L .643 .738 .918 r
F
.77124 .50518 m .76766 .52299 L .78405 .52264 L .644 .736 .916 r
F
.77124 .50518 m .78405 .52264 L .77952 .505 L F
.77135 .51309 m .76775 .53094 L .78425 .53059 L .644 .737 .917 r
F
.77135 .51309 m .78425 .53059 L .77969 .51291 L F
.77148 .52094 m .76787 .53874 L .78441 .53839 L .643 .738 .918 r
F
.77148 .52094 m .78441 .53839 L .77984 .52076 L F
.77239 .47562 m .77402 .47543 L .77515 .48949 L .648 .416 .554 r
F
.76989 .47493 m .77083 .47537 L .77193 .48932 L .848 .57 .516 r
F
.769 .47374 m .7693 .47438 L .77039 .48833 L .966 .687 .262 r
F
.77487 .49785 m .77124 .50518 L .77825 .50503 L .644 .736 .916 r
F
.77543 .49292 m .77422 .49646 L .77673 .49411 L F
.77422 .49646 m .77124 .50518 L .77487 .49785 L F
.77422 .49646 m .77487 .49785 L .77673 .49411 L F
.77539 .49097 m .77495 .49248 L .776 .49126 L F
.77495 .49248 m .77124 .50518 L .77543 .49292 L F
.77495 .49248 m .77543 .49292 L .776 .49126 L F
.7754 .48996 m .77515 .49086 L .77567 .49001 L F
.77515 .49086 m .77124 .50518 L .77539 .49097 L F
.77515 .49086 m .77539 .49097 L .77567 .49001 L F
.77505 .48989 m .77124 .50518 L .7754 .48996 L F
.77434 .48974 m .77124 .50518 L .77515 .48949 L F
.77083 .47537 m .77239 .47562 L .7735 .48961 L .75 .494 .544 r
F
.77083 .47537 m .7735 .48961 L .77228 .48939 L F
.77239 .47562 m .77515 .48949 L .77387 .48958 L .648 .416 .554 r
F
.77489 .48697 m .76955 .49482 L .77124 .50518 L .644 .736 .916 r
F
.76955 .49482 m .7632 .50414 L .76877 .50486 L F
.76955 .49482 m .76877 .50486 L .77124 .50518 L F
.769 .47374 m .77017 .48784 L .7701 .4877 L .966 .687 .262 r
F
.769 .47374 m .77039 .48833 L .77017 .48784 L F
.76905 .47298 m .769 .47374 L .7701 .4877 L 0 0 .196 r
F
.76905 .47298 m .7701 .4877 L .77014 .48715 L F
.77083 .47537 m .77228 .48939 L .77193 .48932 L .75 .494 .544 r
F
.76989 .47493 m .7712 .48897 L .77099 .48887 L .848 .57 .516 r
F
.7693 .47438 m .77053 .48845 L .77039 .48833 L .941 .646 .452 r
F
.7693 .47438 m .76989 .47493 L .77099 .48887 L F
.7693 .47438 m .77099 .48887 L .77053 .48845 L F
.76989 .47493 m .77193 .48932 L .7712 .48897 L .848 .57 .516 r
F
.7701 .48771 m .74324 .49011 L .74409 .49175 L .644 .736 .916 r
F
.77489 .48697 m .77012 .48744 L .7701 .48771 L F
.77012 .48744 m .74324 .49011 L .7701 .48771 L F
.76897 .48853 m .74409 .49175 L .76158 .49048 L F
.77489 .48697 m .76953 .4878 L .76897 .48853 L F
.76953 .4878 m .74409 .49175 L .76897 .48853 L F
.76502 .4133 m .77083 .47537 L .76989 .47493 L .848 .57 .516 r
F
.76444 .41274 m .76502 .4133 L .76989 .47493 L .941 .646 .452 r
F
.76444 .41274 m .76989 .47493 L .7693 .47438 L F
.76415 .41209 m .76444 .41274 L .7693 .47438 L .966 .687 .262 r
F
.76415 .41209 m .7693 .47438 L .769 .47374 L F
.76973 .47203 m .76905 .47298 L .77016 .48699 L .159 .061 .485 r
F
.77489 .48697 m .76282 .4965 L .7632 .50414 L .644 .736 .916 r
F
.76282 .4965 m .75594 .50194 L .75812 .5026 L F
.76282 .4965 m .75812 .5026 L .7632 .50414 L F
.77489 .48697 m .74994 .49872 L .75594 .50194 L F
.77673 .49411 m .77487 .49785 L .77952 .505 L F
.77487 .49785 m .77825 .50503 L .77952 .505 L F
.77207 .50343 m .77177 .50035 L .77677 .49998 L .67 .437 .559 r
F
.7725 .49651 m .77178 .5003 L .77676 .49993 L .667 .747 .91 r
F
.77402 .47543 m .7754 .48941 L .77515 .48949 L .544 .339 .553 r
F
.77704 .48979 m .77952 .505 L .78352 .5043 L .644 .736 .916 r
F
.77704 .48979 m .78352 .5043 L .77991 .49359 L F
.77682 .49047 m .77952 .505 L .77704 .48979 L F
.77652 .48925 m .77678 .49059 L .77658 .48919 L F
.77678 .49059 m .77952 .505 L .77682 .49047 L F
.77678 .49059 m .77682 .49047 L .77658 .48919 L F
.77644 .47386 m .77666 .47311 L .77782 .48738 L 0 0 .362 r
F
.77591 .47449 m .77644 .47386 L .77759 .48809 L .231 .113 .505 r
F
.77632 .48947 m .77952 .505 L .77652 .48925 L .644 .736 .916 r
F
.77556 .48955 m .77952 .505 L .77626 .48914 L F
.77868 .50156 m .77852 .49957 L .78159 .49885 L .605 .39 .563 r
F
.77708 .50305 m .77852 .49957 L .77868 .50156 L F
.77708 .50305 m .77677 .49998 L .77852 .49957 L F
.77207 .50343 m .77677 .49998 L .77708 .50305 L .67 .437 .559 r
F
.77708 .50305 m .78159 .49885 L .7819 .50193 L .605 .39 .563 r
F
.77302 .50603 m .77207 .50343 L .77708 .50305 L .67 .437 .559 r
F
.77279 .49962 m .77207 .50343 L .77708 .50305 L .667 .747 .91 r
F
.77789 .50592 m .77736 .50593 L .77969 .51291 L .644 .737 .917 r
F
.77736 .50593 m .77598 .50596 L .77609 .50616 L F
.77736 .50593 m .77609 .50616 L .77969 .51291 L F
.77765 .50588 m .77708 .50305 L .7819 .50193 L .605 .39 .563 r
F
.77738 .50613 m .77736 .50593 L .77765 .50588 L F
.77736 .50593 m .77708 .50305 L .77765 .50588 L F
.77572 .50597 m .77135 .51309 L .779 .51292 L .644 .737 .917 r
F
.77277 .50604 m .77135 .51309 L .77572 .50597 L F
.77302 .50603 m .77708 .50305 L .77736 .50593 L .67 .437 .559 r
F
.77366 .50162 m .779 .51292 L .77969 .51291 L .644 .737 .917 r
F
.77232 .50605 m .77207 .50343 L .77302 .50603 L .67 .437 .559 r
F
.7725 .49651 m .77676 .49993 L .77583 .49626 L .667 .747 .91 r
F
.77323 .4927 m .7725 .49651 L .77583 .49626 L F
.77161 .49257 m .7725 .49651 L .77323 .4927 L F
.77323 .4927 m .77583 .49626 L .77489 .49258 L F
.77352 .4958 m .77279 .49962 L .77614 .49937 L F
.77352 .4958 m .77614 .49937 L .7752 .49568 L F
.77228 .48939 m .7735 .48961 L .77363 .49125 L .75 .494 .544 r
F
.77459 .49138 m .77323 .4927 L .77489 .49258 L .667 .747 .91 r
F
.77363 .49125 m .77323 .4927 L .77459 .49138 L F
.77351 .49123 m .7735 .49126 L .77363 .49125 L F
.7735 .49126 m .77323 .4927 L .77363 .49125 L F
.77438 .48955 m .77434 .48974 L .77515 .48949 L .644 .736 .916 r
F
.77387 .48958 m .77515 .48949 L .77528 .49104 L .648 .416 .554 r
F
.77387 .48958 m .77528 .49104 L .77404 .4912 L F
.77453 .49114 m .77363 .49125 L .77459 .49138 L .667 .747 .91 r
F
.77489 .48697 m .7632 .49005 L .74994 .49872 L .644 .736 .916 r
F
.7632 .49005 m .74561 .49469 L .74869 .49755 L F
.7632 .49005 m .74869 .49755 L .74994 .49872 L F
.76595 .41375 m .77239 .47562 L .77083 .47537 L .75 .494 .544 r
F
.76502 .4133 m .76595 .41375 L .77083 .47537 L .848 .57 .516 r
F
.77097 .4713 m .76973 .47203 L .77084 .48611 L .454 .273 .545 r
F
.7632 .50414 m .76766 .52299 L .77124 .50518 L .644 .736 .916 r
F
.76721 .50303 m .77177 .50035 L .77207 .50343 L .73 .482 .552 r
F
.76845 .50555 m .77207 .50343 L .77232 .50605 L F
.76845 .50555 m .76721 .50303 L .77207 .50343 L F
.76743 .50541 m .76721 .50303 L .76845 .50555 L F
.76927 .49624 m .77178 .5003 L .7725 .49651 L .667 .747 .91 r
F
.77161 .49257 m .76927 .49624 L .7725 .49651 L F
.7719 .49567 m .77279 .49962 L .77352 .4958 L F
.7712 .48897 m .77193 .48932 L .77207 .49103 L .848 .57 .516 r
F
.77343 .49163 m .77161 .49257 L .77323 .4927 L .667 .747 .91 r
F
.77313 .4915 m .77161 .49257 L .77343 .49163 L F
.77254 .4911 m .77161 .49257 L .77351 .49123 L F
.77334 .49731 m .77332 .49734 L .77446 .49732 L .644 .737 .917 r
F
.77015 .49218 m .76927 .49624 L .77161 .49257 L .667 .747 .91 r
F
.76927 .49624 m .76695 .4999 L .77178 .5003 L F
.77043 .49528 m .76955 .49935 L .7719 .49567 L F
.77223 .49159 m .77015 .49218 L .77161 .49257 L F
.7712 .48897 m .77207 .49103 L .77136 .49072 L .848 .57 .516 r
F
.77228 .48939 m .77246 .49108 L .77193 .48932 L .75 .494 .544 r
F
.77246 .49108 m .77219 .49105 L .77193 .48932 L F
.77154 .49098 m .77112 .49134 L .77223 .49159 L .667 .747 .91 r
F
.77112 .49134 m .77015 .49218 L .77136 .49184 L F
.77112 .49134 m .77136 .49184 L .77223 .49159 L F
.77017 .48784 m .77039 .48833 L .77053 .49008 L .966 .687 .262 r
F
.7719 .49567 m .76955 .49935 L .77279 .49962 L .667 .747 .91 r
F
.773 .4978 m .77233 .49879 L .77355 .4983 L .644 .737 .917 r
F
.76721 .50303 m .76691 .49995 L .77177 .50035 L .73 .482 .552 r
F
.76955 .49935 m .77207 .50343 L .77279 .49962 L .667 .747 .91 r
F
.76955 .49935 m .76721 .50303 L .77207 .50343 L F
.77233 .49879 m .77019 .50191 L .77258 .49934 L .644 .737 .917 r
F
.77233 .49879 m .77258 .49934 L .77355 .4983 L F
.77219 .49105 m .77212 .49104 L .77193 .48932 L .75 .494 .544 r
F
.77154 .49098 m .76895 .49157 L .77015 .49218 L .667 .747 .91 r
F
.7712 .48897 m .77136 .49072 L .77099 .48887 L .848 .57 .516 r
F
.77113 .49061 m .77077 .49059 L .77154 .49098 L .667 .747 .91 r
F
.77077 .49059 m .77101 .4911 L .77154 .49098 L F
.77098 .49048 m .77091 .49052 L .77113 .49061 L F
.77091 .49052 m .77077 .49059 L .77113 .49061 L F
.77077 .49059 m .76895 .49157 L .77101 .4911 L F
.77098 .49048 m .76809 .49078 L .76895 .49157 L F
.77053 .48845 m .77099 .48887 L .77113 .49061 L .941 .646 .452 r
F
.77053 .48845 m .77113 .49061 L .77077 .4903 L F
.77026 .48951 m .77025 .48948 L .7701 .4877 L .966 .687 .262 r
F
.77017 .48784 m .77031 .48961 L .7701 .4877 L F
.76973 .47203 m .77016 .48699 L .77069 .4863 L .159 .061 .485 r
F
.76905 .47298 m .77014 .48715 L .77016 .48699 L 0 0 .196 r
F
.7678 .48767 m .74302 .48529 L .74324 .49011 L .644 .736 .916 r
F
.77489 .48697 m .76969 .4867 L .7678 .48767 L F
.76969 .4867 m .74302 .48529 L .7678 .48767 L F
.77045 .49001 m .77019 .4901 L .77073 .49051 L .667 .747 .91 r
F
.77053 .48845 m .77077 .4903 L .77068 .49022 L .941 .646 .452 r
F
.77136 .49072 m .77116 .49063 L .77099 .48887 L .848 .57 .516 r
F
.77031 .48961 m .77026 .48951 L .7701 .4877 L .966 .687 .262 r
F
.77099 .48887 m .77116 .49063 L .77113 .49061 L .848 .57 .516 r
F
.77058 .49013 m .77055 .4901 L .77039 .48833 L .941 .646 .452 r
F
.77017 .48784 m .77053 .49008 L .77031 .48961 L .966 .687 .262 r
F
.77053 .48845 m .77068 .49022 L .77039 .48833 L .941 .646 .452 r
F
.77068 .49022 m .77058 .49013 L .77039 .48833 L F
.77019 .4901 m .76763 .48985 L .76809 .49078 L .667 .747 .91 r
F
.77193 .49561 m .77043 .49528 L .7719 .49567 L F
.77162 .49494 m .77043 .49528 L .77193 .49561 L F
.77182 .49407 m .77139 .49445 L .77252 .49469 L F
.77139 .49445 m .77043 .49528 L .77162 .49494 L F
.77139 .49445 m .77162 .49494 L .77252 .49469 L F
.77039 .48833 m .77055 .4901 L .77053 .49008 L .941 .646 .452 r
F
.77168 .49086 m .77113 .49061 L .77154 .49098 L .667 .747 .91 r
F
.77156 .49096 m .77154 .49098 L .77254 .4911 L F
.77136 .49072 m .77207 .49103 L .77231 .49408 L .848 .57 .516 r
F
.77373 .49471 m .7719 .49567 L .77352 .4958 L .667 .747 .91 r
F
.77342 .49457 m .7719 .49567 L .77373 .49471 L F
.77286 .49416 m .77278 .49429 L .77381 .49429 L F
.77278 .49429 m .7719 .49567 L .77342 .49457 L F
.77278 .49429 m .77342 .49457 L .77381 .49429 L F
.77139 .49445 m .77034 .49441 L .77043 .49528 L F
.77182 .49407 m .77127 .4942 L .77139 .49445 L F
.77127 .4942 m .77034 .49441 L .77139 .49445 L F
.77103 .49369 m .77037 .49405 L .77127 .4942 L F
.77015 .49218 m .76636 .49547 L .76927 .49624 L F
.77037 .49405 m .76922 .49467 L .77034 .49441 L F
.77037 .49405 m .77034 .49441 L .77127 .4942 L F
.77049 .49 m .77021 .4898 L .77045 .49001 L F
.77254 .4911 m .77154 .49098 L .77223 .49159 L F
.77193 .48932 m .77246 .4941 L .77231 .49408 L .75 .494 .544 r
F
.77381 .49429 m .77342 .49457 L .77373 .49471 L .667 .747 .91 r
F
.77277 .49415 m .77411 .49726 L .77308 .49707 L .75 .494 .544 r
F
.77228 .48939 m .77341 .49424 L .77277 .49415 L F
.77351 .49123 m .77313 .4915 L .77343 .49163 L .667 .747 .91 r
F
.77268 .49112 m .77363 .49125 L .77388 .4943 L .75 .494 .544 r
F
.77489 .49444 m .77352 .4958 L .7752 .49568 L .667 .747 .91 r
F
.77464 .49441 m .77352 .4958 L .77489 .49444 L F
.77381 .49431 m .77352 .4958 L .77482 .49418 L F
.77341 .49424 m .77388 .4943 L .77411 .49726 L .75 .494 .544 r
F
.77268 .49112 m .77388 .4943 L .77341 .49424 L F
.77482 .49418 m .77464 .49441 L .77489 .49444 L .667 .747 .91 r
F
.77387 .48958 m .77436 .49424 L .7735 .48961 L .648 .416 .554 r
F
.77436 .49424 m .77422 .49426 L .7735 .48961 L F
.77468 .49721 m .77437 .49724 L .7735 .48961 L F
.77359 .49833 m .77366 .49839 L .77416 .49774 L .644 .737 .917 r
F
.7741 .49771 m .77416 .49774 L .77455 .49722 L F
.77019 .50191 m .77416 .49774 L .7741 .49771 L F
.77332 .49734 m .7741 .49771 L .77446 .49732 L F
.77411 .49726 m .77446 .49732 L .77455 .49722 L F
.77334 .49731 m .77446 .49732 L .77411 .49726 L F
.77442 .49786 m .77384 .49856 L .77421 .4989 L F
.77453 .49733 m .7742 .49776 L .77442 .49786 L F
.77279 .49962 m .77708 .50305 L .77614 .49937 L .667 .747 .91 r
F
.7742 .49776 m .7701 .50307 L .77442 .49786 L .644 .737 .917 r
F
.77448 .49732 m .7701 .50307 L .77453 .49733 L F
.77276 .5061 m .77044 .5058 L .77135 .51309 L F
.77237 .50651 m .77302 .50603 L .77738 .50613 L .67 .437 .559 r
F
.77302 .50603 m .77736 .50593 L .77738 .50613 L F
.77366 .50162 m .77277 .50604 L .77572 .50597 L .644 .737 .917 r
F
.77583 .49626 m .77676 .49993 L .78131 .49886 L .667 .747 .91 r
F
.78125 .49867 m .78131 .49886 L .78155 .4988 L F
.77583 .49626 m .78131 .49886 L .78125 .49867 L F
.77644 .47386 m .77782 .48738 L .77764 .48793 L 0 0 .362 r
F
.77144 .41221 m .77666 .47311 L .77644 .47386 L F
.7779 .48761 m .80051 .49757 L .80464 .49334 L .644 .736 .916 r
F
.77591 .47449 m .77759 .48809 L .77718 .48854 L .231 .113 .505 r
F
.77512 .47502 m .77643 .48904 L .77626 .48914 L .424 .252 .542 r
F
.77644 .47386 m .77764 .48793 L .77759 .48809 L 0 0 .362 r
F
.77591 .47449 m .77718 .48854 L .77706 .48867 L .231 .113 .505 r
F
.77402 .47543 m .77512 .47502 L .77626 .48914 L .544 .339 .553 r
F
.77402 .47543 m .77626 .48914 L .7754 .48941 L F
.77512 .47502 m .77591 .47449 L .77706 .48867 L .424 .252 .542 r
F
.77583 .49626 m .78155 .4988 L .77903 .49551 L .667 .747 .91 r
F
.776 .49126 m .77543 .49292 L .77673 .49411 L .644 .736 .916 r
F
.77489 .49258 m .77583 .49626 L .77903 .49551 L .667 .747 .91 r
F
.7752 .49568 m .77614 .49937 L .77936 .49862 L F
.77658 .48919 m .77682 .49047 L .77704 .48979 L .644 .736 .916 r
F
.77649 .48907 m .77652 .48925 L .77658 .48919 L F
.77512 .47502 m .77706 .48867 L .77643 .48904 L .424 .252 .542 r
F
.77489 .48697 m .78751 .5036 L .79466 .50107 L .644 .736 .916 r
F
.77991 .49359 m .78352 .5043 L .78751 .5036 L F
.7765 .4922 m .77903 .49551 L .78189 .49431 L .667 .747 .91 r
F
.7765 .4922 m .78189 .49431 L .77793 .4916 L F
.77813 .48831 m .79466 .50107 L .80051 .49757 L .644 .736 .916 r
F
.77489 .48697 m .77856 .48959 L .77813 .48831 L F
.77856 .48959 m .79466 .50107 L .77813 .48831 L F
.77489 .48697 m .77786 .4882 L .7779 .48761 L F
.77786 .4882 m .77813 .48831 L .77806 .48808 L F
.77786 .4882 m .77806 .48808 L .7779 .48761 L F
.78405 .52264 m .812 .5359 L .79987 .5199 L F
.77952 .505 m .78405 .52264 L .79987 .5199 L F
.77969 .51291 m .78425 .53059 L .80019 .52785 L .644 .737 .917 r
F
.78425 .53059 m .8124 .54388 L .80019 .52785 L F
.77984 .52076 m .78441 .53839 L .80038 .53567 L .643 .738 .918 r
F
.77969 .51291 m .80019 .52785 L .78774 .5115 L .644 .737 .917 r
F
.77984 .52076 m .80038 .53567 L .7879 .51936 L .643 .738 .918 r
F
.77489 .49258 m .77903 .49551 L .7765 .4922 L .667 .747 .91 r
F
.77793 .4916 m .78189 .49431 L .78421 .49274 L F
.77666 .47311 m .77753 .48653 L .77775 .48717 L .919 .662 .17 r
F
.77666 .47311 m .77775 .48717 L .77782 .48738 L F
.7784 .48715 m .80464 .49334 L .80677 .48865 L .644 .736 .916 r
F
.77489 .48697 m .77939 .48793 L .7784 .48715 L F
.77939 .48793 m .80464 .49334 L .7784 .48715 L F
.77952 .505 m .79987 .5199 L .78751 .5036 L F
.77614 .49937 m .77708 .50305 L .7819 .50193 L .667 .747 .91 r
F
.78097 .5053 m .7819 .50193 L .78221 .50501 L .605 .39 .563 r
F
.77862 .50571 m .77969 .51291 L .78095 .5053 L .644 .737 .917 r
F
.77765 .50588 m .7819 .50193 L .78097 .5053 L .605 .39 .563 r
F
.77614 .49937 m .7819 .50193 L .77936 .49862 L .667 .747 .91 r
F
.78029 .50416 m .78097 .5053 L .78221 .50501 L .667 .748 .911 r
F
.78221 .50501 m .7819 .50193 L .78621 .50013 L .529 .335 .561 r
F
.78221 .50501 m .78621 .50013 L .78652 .50321 L F
.77967 .50171 m .78221 .50501 L .78652 .50321 L .667 .748 .911 r
F
.77893 .50188 m .78221 .50501 L .77967 .50171 L F
.77775 .4999 m .77862 .50571 L .7809 .50518 L .644 .737 .917 r
F
.77656 .50077 m .77969 .51291 L .77775 .4999 L F
.77793 .4916 m .78421 .49274 L .77909 .49081 L .667 .747 .91 r
F
.77903 .49551 m .78155 .4988 L .78584 .49701 L F
.77903 .49551 m .78584 .49701 L .78189 .49431 L F
.77714 .49516 m .78224 .49742 L .77825 .4947 L F
.77681 .4953 m .77707 .4954 L .77714 .49516 L F
.77707 .4954 m .78224 .49742 L .77714 .49516 L F
.77748 .49021 m .77793 .4916 L .77909 .49081 L F
.77643 .48904 m .77717 .49011 L .77675 .49038 L .424 .252 .542 r
F
.77665 .49072 m .7765 .4922 L .77793 .4916 L .667 .747 .91 r
F
.77657 .4905 m .77742 .49316 L .77686 .49353 L .424 .252 .542 r
F
.77643 .48904 m .77675 .49038 L .77657 .4905 L F
.77675 .49038 m .77742 .49316 L .77657 .4905 L F
.77719 .4901 m .7772 .4911 L .77748 .49021 L .667 .747 .91 r
F
.77712 .49839 m .77727 .49859 L .77729 .49853 L .667 .748 .911 r
F
.77712 .49839 m .78059 .50132 L .77998 .4995 L F
.77729 .49853 m .77967 .50171 L .78059 .50132 L F
.77727 .49859 m .77967 .50171 L .77729 .49853 L F
.77656 .50077 m .77775 .4999 L .77717 .49893 L .644 .737 .917 r
F
.77688 .49844 m .77967 .50171 L .77712 .49839 L .667 .748 .911 r
F
.77614 .49722 m .77656 .50077 L .77717 .49893 L .644 .737 .917 r
F
.77571 .49747 m .77656 .50077 L .77614 .49722 L F
.77591 .49822 m .77556 .49875 L .77586 .49868 L F
.77556 .49875 m .77366 .50162 L .77586 .49868 L F
.77586 .49868 m .77366 .50162 L .77529 .50466 L F
.77591 .49822 m .77529 .50466 L .77656 .50077 L F
.77476 .49946 m .77366 .50162 L .77591 .49822 L F
.7755 .49876 m .7782 .50067 L .77688 .49844 L .667 .748 .911 r
F
.7782 .50067 m .77967 .50171 L .77688 .49844 L F
.77528 .49566 m .77936 .49862 L .77681 .4953 L .667 .747 .91 r
F
.7752 .49568 m .77524 .49571 L .77528 .49566 L F
.77524 .49571 m .77936 .49862 L .77528 .49566 L F
.77656 .50077 m .77529 .50466 L .77598 .50596 L .644 .737 .917 r
F
.77656 .50077 m .77598 .50596 L .77789 .50592 L F
.7755 .49876 m .77644 .50246 L .77893 .50188 L .667 .748 .911 r
F
.7755 .49876 m .77893 .50188 L .7782 .50067 L F
.77644 .50246 m .78029 .50416 L .77893 .50188 L F
.7782 .50067 m .77893 .50188 L .77967 .50171 L F
.78029 .50416 m .78221 .50501 L .77893 .50188 L F
.77712 .49839 m .77998 .4995 L .77856 .49778 L F
.7819 .50193 m .78159 .49885 L .7859 .49705 L .529 .335 .561 r
F
.7819 .50193 m .7859 .49705 L .78621 .50013 L F
.77936 .49862 m .7819 .50193 L .78621 .50013 L .667 .747 .91 r
F
.77936 .49862 m .78621 .50013 L .78224 .49742 L F
.77998 .4995 m .78255 .5005 L .77966 .49853 L .667 .748 .911 r
F
.77998 .4995 m .77966 .49853 L .77856 .49778 L F
.78189 .49431 m .78584 .49701 L .78933 .49466 L .667 .747 .91 r
F
.77825 .4947 m .78224 .49742 L .78458 .49584 L F
.77898 .4942 m .78458 .49584 L .77942 .4939 L F
.77825 .4947 m .77921 .49487 L .77898 .4942 L F
.77921 .49487 m .78458 .49584 L .77898 .4942 L F
.78189 .49431 m .78933 .49466 L .78421 .49274 L F
.77942 .4939 m .78458 .49584 L .78622 .49399 L F
.77856 .49444 m .78096 .49508 L .78094 .49408 L .667 .748 .911 r
F
.77842 .49483 m .77843 .49486 L .77842 .49487 L 0 0 .362 r
F
.77769 .48952 m .77909 .49081 L .7799 .48989 L .667 .747 .91 r
F
.77748 .49021 m .77909 .49081 L .77769 .48952 L F
.77773 .49327 m .77825 .4947 L .77898 .4942 L F
.77773 .49327 m .77898 .4942 L .77881 .49367 L F
.77764 .48793 m .77782 .48738 L .77793 .48874 L 0 0 .362 r
F
.77813 .48831 m .80051 .49757 L .7779 .48761 L .644 .736 .916 r
F
.77798 .48889 m .7799 .48989 L .78031 .4889 L .667 .747 .91 r
F
.77788 .48889 m .778 .48895 L .77798 .48889 L F
.778 .48895 m .7799 .48989 L .77798 .48889 L F
.77769 .48952 m .77822 .48961 L .77788 .48889 L F
.77822 .48961 m .7799 .48989 L .778 .48895 L F
.77822 .48961 m .778 .48895 L .77788 .48889 L F
.77775 .48717 m .77785 .48851 L .77782 .48738 L .919 .662 .17 r
F
.77773 .49327 m .77881 .49367 L .77793 .49259 L .667 .747 .91 r
F
.77881 .49367 m .77942 .4939 L .77866 .49323 L F
.77881 .49367 m .77866 .49323 L .77793 .49259 L F
.77764 .48793 m .77793 .48874 L .77779 .48921 L 0 0 .362 r
F
.77706 .48867 m .77719 .49009 L .77717 .49011 L .231 .113 .505 r
F
.77715 .49682 m .77712 .49839 L .77856 .49778 L .667 .748 .911 r
F
.77746 .49802 m .77775 .4999 L .7809 .50518 L .644 .737 .917 r
F
.77967 .50171 m .78652 .50321 L .78255 .5005 L .667 .748 .911 r
F
.77746 .49802 m .7809 .50518 L .78104 .50272 L .644 .737 .917 r
F
.7809 .50518 m .77862 .50571 L .78095 .5053 L F
.7809 .50518 m .78422 .51212 L .78316 .50897 L F
.77738 .50613 m .77765 .50588 L .78097 .5053 L .605 .39 .563 r
F
.77644 .50246 m .77738 .50613 L .78097 .5053 L .667 .748 .911 r
F
.77644 .50246 m .78097 .5053 L .78029 .50416 L F
.77998 .4995 m .78059 .50132 L .78255 .5005 L F
.78751 .5036 m .79987 .5199 L .81412 .51494 L .644 .736 .916 r
F
.78652 .50321 m .78621 .50013 L .78972 .49777 L .426 .261 .553 r
F
.78652 .50321 m .78972 .49777 L .79004 .50085 L F
.78255 .5005 m .78652 .50321 L .79004 .50085 L .667 .748 .911 r
F
.77681 .4953 m .77936 .49862 L .78224 .49742 L .667 .747 .91 r
F
.78621 .50013 m .7859 .49705 L .7894 .49469 L .426 .261 .553 r
F
.78621 .50013 m .7894 .49469 L .78972 .49777 L F
.78224 .49742 m .78621 .50013 L .78972 .49777 L .667 .747 .91 r
F
.78255 .5005 m .79004 .50085 L .78489 .49892 L .667 .748 .911 r
F
.77856 .49778 m .78255 .5005 L .78489 .49892 L F
.77856 .49778 m .78489 .49892 L .77973 .49699 L F
.77662 .49368 m .77699 .49666 L .77687 .49674 L .424 .252 .542 r
F
.77767 .49622 m .77856 .49778 L .77973 .49699 L .667 .748 .911 r
F
.77638 .49063 m .77669 .49364 L .77662 .49368 L .424 .252 .542 r
F
.77626 .48914 m .7764 .49062 L .77638 .49063 L F
.77646 .49094 m .7765 .4922 L .77665 .49072 L .667 .747 .91 r
F
.7764 .49062 m .77669 .49364 L .77638 .49063 L .424 .252 .542 r
F
.77718 .48854 m .7777 .48948 L .77737 .48988 L .231 .113 .505 r
F
.77643 .48904 m .77706 .48867 L .77717 .49011 L .424 .252 .542 r
F
.778 .49238 m .77797 .49247 L .77771 .48946 L 0 0 .362 r
F
.77772 .48943 m .77771 .48946 L .77759 .48809 L F
.778 .49238 m .77771 .48946 L .77772 .48943 L F
.77808 .48825 m .78031 .4889 L .78029 .48791 L .667 .747 .91 r
F
.77718 .48854 m .77737 .48988 L .7773 .48995 L .231 .113 .505 r
F
.77779 .48921 m .77793 .48874 L .77818 .4918 L 0 0 .362 r
F
.77812 .4916 m .77815 .49171 L .77792 .48872 L .919 .662 .17 r
F
.77791 .48868 m .77792 .48872 L .77782 .48738 L F
.77812 .4916 m .77792 .48872 L .77791 .48868 L F
.77764 .48793 m .77779 .48921 L .77779 .48921 L 0 0 .362 r
F
.77764 .48793 m .77776 .4893 L .77759 .48809 L F
.77776 .4893 m .77772 .48941 L .77759 .48809 L F
.77802 .49232 m .778 .49238 L .77772 .48943 L F
.77772 .48941 m .77772 .48943 L .77759 .48809 L F
.77802 .49232 m .77772 .48943 L .77772 .48941 L F
.7778 .48668 m .80677 .48865 L .80674 .48381 L .644 .736 .916 r
F
.77489 .48697 m .7784 .48715 L .7778 .48668 L F
.7784 .48715 m .80677 .48865 L .7778 .48668 L F
.77015 .41339 m .77591 .47449 L .77512 .47502 L .424 .252 .542 r
F
.77015 .41339 m .77092 .41286 L .77591 .47449 L F
.77092 .41286 m .77644 .47386 L .77591 .47449 L .231 .113 .505 r
F
.77092 .41286 m .77144 .41221 L .77644 .47386 L F
.77635 .47214 m .77538 .47137 L .77654 .48569 L .921 .628 .471 r
F
.77785 .48851 m .7779 .48866 L .77782 .48738 L .919 .662 .17 r
F
.7779 .48866 m .77791 .48868 L .77782 .48738 L F
.77793 .48874 m .77815 .49171 L .77818 .4918 L F
.77782 .48738 m .77792 .48872 L .77793 .48874 L F
.77792 .48872 m .77815 .49171 L .77793 .48874 L F
.77776 .48823 m .77808 .48825 L .77811 .48817 L .667 .747 .91 r
F
.77812 .49198 m .78024 .49298 L .78065 .49199 L F
.77764 .48793 m .77811 .49204 L .77802 .49232 L 0 0 .362 r
F
.7773 .48995 m .77775 .49278 L .77758 .49298 L .231 .113 .505 r
F
.77718 .49009 m .77719 .4901 L .77768 .48951 L .667 .747 .91 r
F
.7772 .4911 m .77793 .4916 L .77748 .49021 L F
.77737 .48988 m .77778 .49274 L .7773 .48995 L .231 .113 .505 r
F
.77745 .49415 m .77714 .49516 L .77825 .4947 L .667 .747 .91 r
F
.77793 .49259 m .77848 .49268 L .77812 .49198 L F
.77848 .49268 m .78024 .49298 L .77826 .49204 L F
.77848 .49268 m .77826 .49204 L .77812 .49198 L F
.77836 .49507 m .78055 .49607 L .78096 .49508 L .667 .748 .911 r
F
.77802 .49232 m .77842 .49488 L .77828 .49534 L 0 0 .362 r
F
.77793 .49259 m .77866 .49323 L .77848 .49268 L .667 .747 .91 r
F
.77745 .49415 m .77825 .4947 L .77773 .49327 L F
.77909 .49081 m .78421 .49274 L .78585 .4909 L F
.77832 .49134 m .78065 .49199 L .78063 .49099 L F
.77759 .48809 m .77797 .49247 L .77795 .49254 L 0 0 .362 r
F
.77718 .48854 m .77759 .48809 L .7777 .48948 L .231 .113 .505 r
F
.77768 .48951 m .77719 .4901 L .77769 .48952 L .667 .747 .91 r
F
.77719 .4901 m .77748 .49021 L .7776 .48982 L F
.77719 .4901 m .7776 .48982 L .77769 .48952 L F
.77791 .49258 m .77743 .49315 L .77793 .49259 L F
.77718 .48854 m .77758 .49298 L .77706 .48867 L .231 .113 .505 r
F
.77758 .49298 m .77753 .49303 L .77706 .48867 L F
.77742 .49315 m .77743 .49315 L .77791 .49258 L .667 .747 .91 r
F
.77743 .49315 m .77773 .49327 L .77785 .49288 L F
.77743 .49315 m .77785 .49288 L .77793 .49259 L F
.77785 .496 m .77775 .49612 L .77747 .4931 L .231 .113 .505 r
F
.77753 .49303 m .77747 .4931 L .77706 .48867 L F
.77742 .49315 m .77745 .49415 L .77773 .49327 L .667 .747 .91 r
F
.77785 .496 m .77747 .4931 L .77753 .49303 L .231 .113 .505 r
F
.77553 .49095 m .77489 .49258 L .7765 .4922 L .667 .747 .91 r
F
.77457 .49131 m .77489 .49258 L .77553 .49095 L F
.77528 .49104 m .77562 .49406 L .77552 .49409 L .544 .339 .553 r
F
.77515 .48949 m .77531 .49103 L .77528 .49104 L F
.77531 .49103 m .77562 .49406 L .77528 .49104 L F
.77567 .49001 m .77539 .49097 L .776 .49126 L .644 .736 .916 r
F
.77553 .48946 m .7754 .48996 L .77567 .49001 L F
.7754 .48941 m .77638 .49063 L .77555 .49094 L .544 .339 .553 r
F
.77645 .49059 m .7772 .4911 L .77719 .4901 L .667 .747 .91 r
F
.77645 .49059 m .77646 .49094 L .77665 .49072 L F
.77626 .48914 m .77632 .48947 L .77649 .48907 L .644 .736 .916 r
F
.77632 .48947 m .77652 .48925 L .77649 .48907 L F
.77643 .48904 m .77686 .49353 L .77626 .48914 L .424 .252 .542 r
F
.77672 .49365 m .77657 .49372 L .7769 .49377 L .667 .747 .91 r
F
.77657 .49372 m .77621 .49396 L .7769 .49377 L F
.77586 .49405 m .77623 .49454 L .77675 .49394 L F
.77586 .49405 m .77675 .49394 L .7769 .49377 L F
.77686 .49353 m .77669 .49364 L .77626 .48914 L .424 .252 .542 r
F
.77553 .49095 m .77566 .49111 L .77638 .49063 L .667 .747 .91 r
F
.77566 .49111 m .7765 .4922 L .77645 .49059 L F
.77555 .49094 m .77638 .49063 L .77662 .49368 L .544 .339 .553 r
F
.77555 .49094 m .77662 .49368 L .77585 .49397 L F
.77404 .4912 m .77528 .49104 L .77552 .49409 L .648 .416 .554 r
F
.77404 .4912 m .77552 .49409 L .7749 .49417 L F
.77436 .49424 m .77576 .49714 L .77468 .49721 L F
.77404 .4912 m .7749 .49417 L .77436 .49424 L F
.77586 .49405 m .7752 .49568 L .77681 .4953 L .667 .747 .91 r
F
.7749 .49417 m .77576 .49714 L .77436 .49424 L .648 .416 .554 r
F
.77581 .49399 m .77578 .49406 L .77586 .49405 L .667 .747 .91 r
F
.77578 .49406 m .7752 .49568 L .77586 .49405 L F
.77585 .49397 m .77562 .49406 L .77515 .48949 L .544 .339 .553 r
F
.77426 .49197 m .77486 .49434 L .77581 .49399 L .667 .747 .91 r
F
.77486 .49434 m .7752 .49568 L .77581 .49399 L F
.77515 .48949 m .77505 .48989 L .77553 .48946 L .644 .736 .916 r
F
.77505 .48989 m .7754 .48996 L .77553 .48946 L F
.7754 .48941 m .77585 .49397 L .77515 .48949 L .544 .339 .553 r
F
.77585 .49397 m .77614 .49701 L .77562 .49406 L F
.77608 .49704 m .7762 .49718 L .77687 .49674 L .667 .748 .911 r
F
.77614 .49701 m .77614 .49702 L .77614 .49701 L .544 .339 .553 r
F
.77614 .49701 m .77614 .49701 L .77562 .49406 L F
.77614 .49701 m .77594 .49708 L .77562 .49406 L F
.77614 .49702 m .77604 .49705 L .77614 .49701 L F
.77604 .49705 m .77594 .49708 L .77614 .49701 L F
.77527 .49576 m .77449 .49753 L .77564 .49718 L .644 .737 .917 r
F
.77614 .49711 m .7755 .49876 L .77712 .49839 L .667 .748 .911 r
F
.77695 .49669 m .77699 .49701 L .77715 .49682 L F
.77687 .49679 m .77685 .49721 L .77739 .49663 L .644 .737 .917 r
F
.77657 .49372 m .77586 .49405 L .77621 .49396 L .667 .747 .91 r
F
.77581 .49399 m .77586 .49405 L .77672 .49365 L F
.77623 .49454 m .77681 .4953 L .7769 .49377 L F
.77585 .49397 m .77662 .49368 L .77687 .49674 L .544 .339 .553 r
F
.7762 .49718 m .77712 .49839 L .77696 .49671 L .667 .748 .911 r
F
.7762 .49718 m .77696 .49671 L .77687 .49674 L F
.77659 .49688 m .77663 .49693 L .77687 .49679 L .644 .737 .917 r
F
.77663 .49693 m .77685 .49721 L .77687 .49679 L F
.77767 .49622 m .77856 .49778 L .77767 .49622 L .667 .748 .911 r
F
.77695 .49669 m .77715 .49682 L .77767 .49622 L F
.77715 .49682 m .77856 .49778 L .77767 .49622 L F
.77747 .4931 m .77775 .49612 L .77742 .49316 L .231 .113 .505 r
F
.77699 .49701 m .77712 .49839 L .77715 .49682 L .667 .748 .911 r
F
.77685 .49721 m .78774 .5115 L .77749 .4966 L .644 .737 .917 r
F
.77767 .49622 m .77973 .49699 L .77814 .49566 L .667 .748 .911 r
F
.77746 .49655 m .78774 .5115 L .79494 .50897 L .644 .737 .917 r
F
.77818 .49567 m .78055 .49607 L .77857 .49516 L .667 .748 .911 r
F
.7782 .49559 m .77857 .49516 L .77836 .49507 L F
.77818 .49567 m .77857 .49516 L .7782 .49559 L F
.77791 .49258 m .77793 .49259 L .77795 .49254 L .667 .747 .91 r
F
.77768 .48951 m .77769 .48952 L .7777 .48948 L F
.77737 .48988 m .7777 .48948 L .77795 .49254 L .231 .113 .505 r
F
.77737 .48988 m .77795 .49254 L .77778 .49273 L F
.77778 .49274 m .7782 .49559 L .77819 .4956 L F
.77737 .48988 m .77778 .49273 L .77778 .49274 L F
.77778 .49273 m .7782 .49559 L .77778 .49274 L F
.77909 .49081 m .78585 .4909 L .7799 .48989 L .667 .747 .91 r
F
.78003 .4901 m .78063 .49099 L .78017 .49006 L F
.77489 .48697 m .77551 .48938 L .77649 .48907 L .644 .736 .916 r
F
.77489 .48697 m .77438 .48955 L .77553 .48946 L F
.77395 .48888 m .77787 .48889 L .77787 .48874 L .667 .747 .91 r
F
.77787 .48889 m .77788 .48889 L .77787 .48874 L F
.77787 .48874 m .77788 .48889 L .77793 .48874 L F
.77395 .48888 m .77793 .48874 L .77778 .48829 L F
.77779 .48921 m .77818 .4918 L .77811 .49203 L 0 0 .362 r
F
.77779 .48921 m .77811 .49203 L .77811 .49204 L F
.77779 .48921 m .77811 .49203 L .77779 .48921 L F
.77811 .49203 m .77843 .49486 L .77811 .49203 L F
.77811 .49203 m .77811 .49203 L .77779 .48921 L F
.77856 .49058 m .77907 .49123 L .78003 .4901 L .667 .747 .91 r
F
.77778 .49274 m .77775 .49278 L .7773 .48995 L .231 .113 .505 r
F
.77717 .49011 m .77747 .4931 L .77742 .49316 L F
.77719 .49009 m .77747 .4931 L .77717 .49011 L F
.77776 .4893 m .77802 .49232 L .77772 .48941 L 0 0 .362 r
F
.77675 .49038 m .77717 .49011 L .77742 .49316 L .424 .252 .542 r
F
.77426 .49197 m .77804 .49139 L .77786 .49085 L .667 .747 .91 r
F
.77778 .49273 m .77795 .49254 L .7782 .49559 L .231 .113 .505 r
F
.77819 .4956 m .7782 .49559 L .77821 .49574 L F
.78095 .5053 m .77969 .51291 L .78422 .51212 L .644 .737 .917 r
F
.7778 .50656 m .77984 .52076 L .78489 .51988 L .643 .738 .918 r
F
.77366 .50162 m .77044 .5058 L .77276 .5061 L .644 .737 .917 r
F
.77237 .50651 m .77232 .50605 L .77302 .50603 L .67 .437 .559 r
F
.77309 .50271 m .77237 .50651 L .77738 .50613 L .667 .748 .911 r
F
.77309 .50271 m .77738 .50613 L .77644 .50246 L F
.77712 .50527 m .7775 .50746 L .7778 .50656 L .643 .738 .918 r
F
.7775 .50746 m .77984 .52076 L .7778 .50656 L F
.77818 .49567 m .77973 .49699 L .78055 .49607 L .667 .748 .911 r
F
.77817 .49569 m .77973 .49699 L .77818 .49567 L F
.77426 .49197 m .77786 .49085 L .77782 .49082 L .667 .747 .91 r
F
.77395 .48888 m .77778 .48829 L .77776 .48823 L F
.77775 .48717 m .77762 .4878 L .77785 .48851 L .919 .662 .17 r
F
.77395 .48888 m .77811 .48817 L .77753 .48773 L .667 .747 .91 r
F
.77551 .48938 m .77556 .48955 L .77626 .48914 L .644 .736 .916 r
F
.7754 .48941 m .77626 .48914 L .77638 .49063 L .544 .339 .553 r
F
.77395 .48888 m .77718 .49009 L .77768 .48951 L .667 .747 .91 r
F
.77395 .48888 m .77768 .48951 L .77788 .48889 L F
.77635 .47214 m .77654 .48569 L .77729 .48628 L .921 .628 .471 r
F
.77635 .47214 m .77729 .48628 L .77751 .48645 L F
.77666 .47311 m .77635 .47214 L .77751 .48645 L .919 .662 .17 r
F
.77666 .47311 m .77751 .48645 L .77753 .48653 L F
.77715 .48591 m .80452 .47916 L .80026 .47503 L .644 .736 .916 r
F
.77489 .48697 m .77791 .48617 L .77715 .48591 L F
.77791 .48617 m .80452 .47916 L .77715 .48591 L F
.77426 .49197 m .77782 .49082 L .77723 .49037 L .667 .747 .91 r
F
.77794 .49603 m .77785 .49683 L .7781 .49609 L .644 .737 .917 r
F
.77775 .49612 m .77776 .49623 L .7777 .49618 L .231 .113 .505 r
F
.77776 .49623 m .77771 .49628 L .7777 .49618 L F
.77775 .49612 m .7777 .49618 L .77742 .49316 L F
.77585 .49397 m .77687 .49674 L .77614 .49701 L .544 .339 .553 r
F
.7769 .49377 m .77681 .4953 L .77714 .49516 L .667 .747 .91 r
F
.77686 .49353 m .77715 .49663 L .77669 .49364 L .424 .252 .542 r
F
.77715 .49663 m .777 .49672 L .77669 .49364 L F
.77552 .49409 m .77594 .49708 L .77576 .49714 L .544 .339 .553 r
F
.77562 .49406 m .77594 .49708 L .77552 .49409 L F
.7749 .49417 m .77552 .49409 L .77576 .49714 L .648 .416 .554 r
F
.77758 .49298 m .77785 .496 L .77753 .49303 L .231 .113 .505 r
F
.7782 .49507 m .77823 .49548 L .77816 .49507 L 0 0 .362 r
F
.77816 .49507 m .77823 .49548 L .7782 .49559 L F
.77778 .49274 m .77819 .4956 L .77775 .49278 L .231 .113 .505 r
F
.77819 .4956 m .77819 .49561 L .77775 .49278 L F
.77828 .49534 m .77823 .49548 L .77797 .49247 L 0 0 .362 r
F
.77828 .49534 m .77797 .49247 L .778 .49238 L F
.7769 .49377 m .77714 .49516 L .77745 .49415 L .667 .747 .91 r
F
.77814 .49566 m .77818 .49567 L .7782 .49559 L .667 .748 .911 r
F
.77814 .49566 m .77817 .49569 L .77818 .49567 L F
.77758 .49298 m .77821 .49574 L .77786 .49612 L .231 .113 .505 r
F
.77775 .49278 m .77821 .49574 L .77758 .49298 L F
.77687 .49543 m .77699 .49666 L .77684 .49542 L .424 .252 .542 r
F
.77687 .49543 m .77684 .49542 L .77662 .49368 L F
.77669 .49364 m .77687 .49543 L .77662 .49368 L F
.77699 .49666 m .77699 .49666 L .77662 .49368 L F
.77742 .49316 m .7777 .49618 L .77767 .49622 L .231 .113 .505 r
F
.77672 .49365 m .7769 .49377 L .77713 .49349 L .667 .747 .91 r
F
.77672 .49365 m .77713 .49349 L .77742 .49315 L F
.7769 .49377 m .77745 .49415 L .77742 .49315 L F
.77686 .49353 m .77742 .49316 L .77767 .49632 L .424 .252 .542 r
F
.77686 .49353 m .77767 .49632 L .77715 .49663 L F
.77802 .49232 m .77828 .49534 L .778 .49238 L 0 0 .362 r
F
.77485 .49506 m .77814 .49566 L .77836 .49507 L .667 .748 .911 r
F
.77488 .49511 m .77814 .49566 L .77485 .49506 L F
.77549 .49751 m .77366 .50162 L .77574 .49755 L .644 .737 .917 r
F
.77449 .49753 m .77366 .50162 L .77564 .49718 L F
.77663 .49693 m .77649 .49702 L .77746 .49802 L F
.77505 .49539 m .77608 .49704 L .77695 .49669 L .667 .748 .911 r
F
.77587 .49676 m .77608 .49704 L .77505 .49539 L F
.77614 .49701 m .77687 .49679 L .77614 .49702 L .544 .339 .553 r
F
.77587 .49676 m .77604 .49705 L .77608 .49704 L .667 .748 .911 r
F
.77608 .49704 m .77605 .49712 L .77614 .49711 L F
.77608 .49704 m .77687 .49674 L .77695 .49669 L F
.77527 .49576 m .77717 .49893 L .77746 .49802 L .644 .737 .917 r
F
.77614 .49702 m .77687 .49679 L .77749 .50448 L .544 .339 .553 r
F
.77658 .50817 m .77148 .52094 L .77984 .52076 L .643 .738 .918 r
F
.77611 .50635 m .77577 .50743 L .77658 .50817 L F
.7632 .50414 m .75176 .52094 L .76766 .52299 L .644 .736 .916 r
F
.76282 .50187 m .76691 .49995 L .76721 .50303 L .794 .529 .538 r
F
.76718 .50631 m .76282 .50488 L .76325 .51204 L .644 .737 .917 r
F
.76773 .5055 m .76504 .50516 L .76718 .50631 L F
.76504 .50516 m .76282 .50488 L .76718 .50631 L F
.76366 .50427 m .76282 .50488 L .76773 .5055 L F
.76421 .50444 m .76282 .50187 L .76721 .50303 L .794 .529 .538 r
F
.75594 .50194 m .75176 .52094 L .7632 .50414 L .644 .736 .916 r
F
.76336 .50418 m .75594 .50983 L .76282 .50488 L .644 .737 .917 r
F
.76324 .50414 m .75594 .50983 L .76336 .50418 L F
.76303 .50408 m .76282 .50187 L .76421 .50444 L .794 .529 .538 r
F
.76282 .50187 m .76253 .4988 L .76691 .49995 L F
.76636 .49547 m .76695 .4999 L .76927 .49624 L .667 .747 .91 r
F
.76636 .49547 m .76258 .49875 L .76695 .4999 L F
.76662 .49858 m .76721 .50303 L .76955 .49935 L F
.76662 .49858 m .76282 .50187 L .76721 .50303 L F
.76363 .50384 m .76282 .50488 L .77334 .49731 L .644 .737 .917 r
F
.77363 .49125 m .77432 .49724 L .77411 .49726 L .648 .416 .554 r
F
.77436 .49424 m .77468 .49721 L .77422 .49426 L F
.77341 .49424 m .77411 .49726 L .77277 .49415 L .75 .494 .544 r
F
.77252 .49469 m .77162 .49494 L .77193 .49561 L .667 .747 .91 r
F
.77165 .49379 m .77254 .49697 L .77192 .49667 L .848 .57 .516 r
F
.77188 .49402 m .77175 .49401 L .77182 .49407 L .667 .747 .91 r
F
.77197 .49393 m .77254 .49697 L .77165 .49379 L .848 .57 .516 r
F
.77188 .49402 m .77182 .49407 L .77286 .49416 L .667 .747 .91 r
F
.77197 .49393 m .77231 .49408 L .77254 .49697 L .848 .57 .516 r
F
.77308 .49707 m .77278 .49701 L .77246 .4941 L .75 .494 .544 r
F
.77308 .49707 m .77246 .4941 L .77261 .49413 L F
.77231 .49408 m .77278 .49701 L .77254 .49697 L F
.77286 .49416 m .77182 .49407 L .77252 .49469 L .667 .747 .91 r
F
.77246 .4941 m .77278 .49701 L .77231 .49408 L .75 .494 .544 r
F
.77264 .49413 m .77212 .49104 L .77219 .49105 L F
.77308 .49707 m .77261 .49413 L .77264 .49413 L F
.77261 .49413 m .77212 .49104 L .77264 .49413 L F
.77103 .49369 m .7704 .49366 L .77072 .49386 L .667 .747 .91 r
F
.7704 .49366 m .76923 .49359 L .77039 .4938 L F
.7704 .49366 m .77039 .4938 L .77072 .49386 L F
.77038 .48976 m .77021 .4898 L .77049 .49 L F
.77395 .48888 m .77024 .48945 L .77024 .48946 L F
.77395 .48888 m .77024 .48946 L .77038 .48976 L F
.77031 .48961 m .77053 .49008 L .77077 .49314 L .966 .687 .262 r
F
.76971 .48953 m .7676 .48886 L .76763 .48985 L .667 .747 .91 r
F
.77395 .48888 m .77028 .48887 L .77024 .48945 L F
.77031 .48961 m .77077 .49314 L .77067 .49291 L .966 .687 .262 r
F
.77016 .48699 m .77029 .48874 L .77029 .48872 L 0 0 .196 r
F
.77018 .48887 m .768 .48787 L .7676 .48886 L .667 .747 .91 r
F
.77031 .48961 m .77067 .49291 L .77057 .4927 L .966 .687 .262 r
F
.77052 .49193 m .77053 .49184 L .77029 .48874 L 0 0 .196 r
F
.77029 .48877 m .77029 .48874 L .77016 .48699 L F
.77052 .49193 m .77029 .48874 L .77029 .48877 L F
.77395 .48888 m .77059 .48831 L .77029 .48872 L .667 .747 .91 r
F
.77014 .48715 m .77024 .48946 L .77028 .4889 L 0 0 .196 r
F
.77028 .48887 m .77029 .48872 L .77018 .48887 L .667 .747 .91 r
F
.77395 .48888 m .77029 .48872 L .77028 .48887 L F
.7701 .4877 m .77025 .48948 L .77024 .48946 L .966 .687 .262 r
F
.77014 .48715 m .77028 .4889 L .77016 .48699 L 0 0 .196 r
F
.77028 .4889 m .77029 .48877 L .77016 .48699 L F
.77014 .48715 m .7701 .4877 L .77024 .48946 L F
.77077 .49314 m .76923 .49359 L .77103 .49369 L .667 .747 .91 r
F
.77075 .4931 m .77073 .4931 L .77077 .49314 L F
.77073 .4931 m .76923 .49359 L .77077 .49314 L F
.77055 .4901 m .77083 .49319 L .77053 .49008 L .941 .646 .452 r
F
.77083 .49319 m .77109 .49606 L .77082 .49318 L F
.77083 .49319 m .77082 .49318 L .77053 .49008 L F
.77395 .48888 m .77038 .48976 L .77049 .49 L .667 .747 .91 r
F
.77228 .48939 m .77363 .49125 L .77268 .49112 L .75 .494 .544 r
F
.77395 .48888 m .77045 .49001 L .77098 .49048 L .667 .747 .91 r
F
.77019 .4901 m .77016 .49057 L .77073 .49051 L F
.77045 .49001 m .77073 .49051 L .77053 .49008 L F
.77097 .4713 m .77084 .48611 L .77181 .4856 L .454 .273 .545 r
F
.76973 .47203 m .77069 .4863 L .77084 .48611 L .159 .061 .485 r
F
.76705 .48656 m .74497 .48056 L .74302 .48529 L .644 .736 .916 r
F
.77489 .48697 m .76998 .48592 L .76705 .48656 L F
.76998 .48592 m .74497 .48056 L .76705 .48656 L F
.76747 .41399 m .77402 .47543 L .77239 .47562 L .648 .416 .554 r
F
.76595 .41375 m .76747 .41399 L .77239 .47562 L .75 .494 .544 r
F
.77213 .47098 m .77097 .4713 L .77209 .48546 L .585 .369 .554 r
F
.77024 .48946 m .77051 .49257 L .77048 .49251 L .966 .687 .262 r
F
.77045 .49001 m .77021 .4898 L .77019 .4901 L .667 .747 .91 r
F
.77025 .48948 m .77051 .49257 L .77024 .48946 L .966 .687 .262 r
F
.77054 .49265 m .77025 .48948 L .77026 .48951 L F
.77054 .49263 m .77025 .48948 L .77054 .49265 L F
.77136 .49072 m .77197 .49393 L .77165 .49379 L .848 .57 .516 r
F
.77136 .49072 m .77231 .49408 L .77197 .49393 L F
.77261 .49413 m .77246 .4941 L .77212 .49104 L .75 .494 .544 r
F
.77053 .49008 m .77082 .49318 L .77077 .49314 L .941 .646 .452 r
F
.77054 .49263 m .77051 .49257 L .77025 .48948 L .966 .687 .262 r
F
.77068 .49022 m .77115 .49348 L .77095 .49329 L .941 .646 .452 r
F
.77073 .4931 m .76992 .49263 L .76923 .49359 L .667 .747 .91 r
F
.77053 .49008 m .77073 .49051 L .77098 .49048 L F
.77077 .4903 m .7712 .49351 L .77068 .49022 L .941 .646 .452 r
F
.7712 .49351 m .77115 .49348 L .77068 .49022 L F
.77077 .4903 m .77113 .49061 L .77137 .49367 L F
.77137 .49367 m .77103 .49369 L .77182 .49407 L .667 .747 .91 r
F
.77126 .49357 m .77121 .4936 L .77137 .49367 L F
.77121 .4936 m .77103 .49369 L .77137 .49367 L F
.77136 .49072 m .77165 .49379 L .77116 .49063 L .848 .57 .516 r
F
.77165 .49379 m .77192 .49667 L .77155 .49375 L F
.77165 .49379 m .77155 .49375 L .77116 .49063 L F
.77103 .49369 m .77127 .4942 L .77182 .49407 L .667 .747 .91 r
F
.7712 .49351 m .77137 .49367 L .77159 .49652 L .941 .646 .452 r
F
.77077 .4903 m .77137 .49367 L .7712 .49351 L F
.77192 .49667 m .77174 .49659 L .77146 .49371 L .848 .57 .516 r
F
.77155 .49375 m .77146 .49371 L .77116 .49063 L F
.77192 .49667 m .77146 .49371 L .77155 .49375 L F
.77137 .49367 m .77174 .49659 L .77159 .49652 L F
.77113 .49061 m .77144 .4937 L .77137 .49367 L F
.77144 .4937 m .77174 .49659 L .77137 .49367 L F
.77028 .4889 m .77052 .49199 L .77029 .48877 L 0 0 .196 r
F
.77052 .49199 m .77052 .49193 L .77029 .48877 L F
.77038 .48976 m .77024 .48946 L .77021 .4898 L .667 .747 .91 r
F
.77031 .48961 m .77057 .4927 L .77026 .48951 L .966 .687 .262 r
F
.77057 .4927 m .7708 .49557 L .77054 .49265 L F
.77057 .4927 m .77054 .49265 L .77026 .48951 L F
.76895 .49157 m .76636 .49547 L .77015 .49218 L .667 .747 .91 r
F
.76895 .49157 m .76396 .49425 L .76636 .49547 L F
.76809 .49078 m .76396 .49425 L .76895 .49157 L F
.77049 .49254 m .76787 .49212 L .76925 .49273 L F
.77028 .4889 m .77024 .48946 L .77048 .49251 L 0 0 .196 r
F
.77116 .49063 m .77174 .49659 L .77113 .49061 L .848 .57 .516 r
F
.7712 .49616 m .77109 .49606 L .77083 .49319 L .941 .646 .452 r
F
.77089 .49324 m .77083 .49319 L .77055 .4901 L F
.7712 .49616 m .77083 .49319 L .77089 .49324 L F
.76944 .49195 m .76826 .49095 L .76786 .49195 L .667 .747 .91 r
F
.77395 .48888 m .77098 .49048 L .77113 .49061 L F
.77395 .48888 m .77113 .49061 L .77168 .49086 L F
.75162 .48199 m .74899 .47625 L .74497 .48056 L .644 .736 .916 r
F
.77489 .48697 m .77153 .48558 L .76998 .48592 L F
.77069 .4863 m .77016 .48699 L .77029 .48872 L .159 .061 .485 r
F
.77395 .48888 m .77098 .48777 L .77059 .48831 L .667 .747 .91 r
F
.77098 .48777 m .77097 .48777 L .77059 .48831 L F
.77213 .47098 m .77209 .48546 L .773 .48526 L .585 .369 .554 r
F
.77097 .4713 m .77181 .4856 L .77209 .48546 L .454 .273 .545 r
F
.77082 .48528 m .75481 .47264 L .74899 .47625 L .644 .736 .916 r
F
.77489 .48697 m .77245 .48523 L .77082 .48528 L F
.77245 .48523 m .75481 .47264 L .77082 .48528 L F
.77325 .4709 m .77213 .47098 L .77326 .4852 L .664 .428 .553 r
F
.76916 .48708 m .76997 .48615 L .76881 .48695 L .667 .747 .91 r
F
.77181 .4856 m .77084 .48611 L .77097 .48777 L .454 .273 .545 r
F
.77181 .4856 m .77097 .48777 L .77191 .48723 L F
.77069 .4863 m .77029 .48872 L .77063 .48824 L .159 .061 .485 r
F
.77181 .4856 m .77191 .48723 L .77209 .48546 L .454 .273 .545 r
F
.77395 .48888 m .77171 .48734 L .77155 .48744 L .667 .747 .91 r
F
.77395 .48888 m .77131 .48729 L .77098 .48776 L F
.77063 .48824 m .77029 .48872 L .77053 .49177 L .159 .061 .485 r
F
.7709 .49325 m .77055 .4901 L .77058 .49013 L .941 .646 .452 r
F
.7712 .49616 m .77089 .49324 L .7709 .49325 L F
.77089 .49324 m .77055 .4901 L .7709 .49325 L F
.77126 .49357 m .77077 .49314 L .77103 .49369 L .667 .747 .91 r
F
.77068 .49022 m .7712 .49616 L .77058 .49013 L .941 .646 .452 r
F
.7708 .48801 m .77053 .49177 L .77101 .49111 L .159 .061 .485 r
F
.77063 .48824 m .77053 .49177 L .7708 .48801 L F
.77069 .4863 m .77063 .48824 L .7708 .48801 L F
.77191 .48723 m .77218 .48707 L .77209 .48546 L .454 .273 .545 r
F
.77092 .48785 m .77095 .48781 L .77084 .48611 L .159 .061 .485 r
F
.77069 .4863 m .7708 .48801 L .77084 .48611 L F
.77246 .49108 m .77308 .49707 L .77219 .49105 L .75 .494 .544 r
F
.77369 .49124 m .77437 .49724 L .77363 .49125 L .648 .416 .554 r
F
.77577 .50743 m .77481 .51044 L .77658 .50817 L .643 .738 .918 r
F
.77481 .51044 m .77528 .51142 L .77658 .50817 L F
.77587 .50542 m .77539 .50713 L .77611 .50635 L F
.77173 .49743 m .77046 .49842 L .77178 .49742 L .644 .737 .917 r
F
.77437 .49724 m .77432 .49724 L .77363 .49125 L .648 .416 .554 r
F
.77046 .49842 m .77045 .49852 L .77487 .49508 L .644 .737 .917 r
F
.77043 .49528 m .76662 .49858 L .76955 .49935 L .667 .747 .91 r
F
.77186 .49742 m .76363 .50384 L .77334 .49731 L .644 .737 .917 r
F
.76421 .50444 m .76721 .50303 L .76743 .50541 L .794 .529 .538 r
F
.77334 .49731 m .76366 .50427 L .76773 .5055 L .644 .737 .917 r
F
.77019 .50191 m .7701 .50307 L .77366 .49839 L F
.77019 .50191 m .77366 .49839 L .77359 .49833 L F
.77366 .50162 m .7701 .50307 L .77044 .5058 L F
.77297 .50016 m .7701 .50307 L .77366 .50162 L F
.77384 .49856 m .7701 .50307 L .77421 .4989 L F
.7712 .49351 m .77159 .49652 L .77115 .49348 L .941 .646 .452 r
F
.76052 .50274 m .76282 .50187 L .76303 .50408 L .865 .584 .51 r
F
.75594 .50194 m .73735 .51661 L .75176 .52094 L .644 .736 .916 r
F
.74994 .49872 m .73735 .51661 L .75594 .50194 L F
.76372 .50372 m .7499 .5066 L .75594 .50983 L .644 .737 .917 r
F
.77488 .49511 m .77767 .49622 L .77814 .49566 L .667 .748 .911 r
F
.77482 .495 m .77173 .49743 L .77487 .49508 L .644 .737 .917 r
F
.77456 .49506 m .77494 .4952 L .77488 .49511 L .667 .748 .911 r
F
.77494 .4952 m .77767 .49622 L .77488 .49511 L F
.77095 .49329 m .77159 .49652 L .7712 .49616 L .941 .646 .452 r
F
.77115 .49348 m .77159 .49652 L .77095 .49329 L F
.77482 .495 m .76809 .49808 L .76372 .50372 L .644 .737 .917 r
F
.77426 .49197 m .77672 .49365 L .77742 .49315 L .667 .747 .91 r
F
.77395 .48888 m .77553 .49095 L .77645 .49059 L F
.77426 .49197 m .77581 .49399 L .77672 .49365 L F
.77395 .48888 m .77457 .49131 L .77553 .49095 L F
.77426 .49197 m .77742 .49315 L .77791 .49258 L F
.77785 .48851 m .77799 .49122 L .77809 .49152 L .919 .662 .17 r
F
.77788 .4889 m .77809 .49152 L .77791 .4888 L F
.77809 .49152 m .77812 .4916 L .77791 .48868 L F
.77809 .49152 m .77791 .48868 L .7779 .48866 L F
.77426 .49197 m .77812 .49198 L .77832 .49134 L .667 .747 .91 r
F
.77426 .49197 m .77791 .49258 L .77812 .49198 L F
.77395 .48888 m .77645 .49059 L .77719 .4901 L F
.77325 .4709 m .77326 .4852 L .77414 .48517 L .664 .428 .553 r
F
.77213 .47098 m .773 .48526 L .77326 .4852 L .585 .369 .554 r
F
.77245 .48523 m .76203 .47001 L .75481 .47264 L .644 .736 .916 r
F
.77489 .48697 m .77355 .48519 L .77245 .48523 L F
.77355 .48519 m .76203 .47001 L .77245 .48523 L F
.77478 .49494 m .77811 .49391 L .77753 .49347 L .667 .748 .911 r
F
.77479 .49495 m .76809 .49808 L .77482 .495 L .644 .737 .917 r
F
.77456 .49506 m .77481 .49498 L .77478 .49494 L .667 .748 .911 r
F
.77481 .49498 m .77811 .49391 L .77478 .49494 L F
.77495 .49523 m .77334 .49731 L .77455 .49722 L .644 .737 .917 r
F
.77795 .49254 m .7782 .49507 L .77816 .49507 L 0 0 .362 r
F
.77797 .49247 m .7782 .49507 L .77795 .49254 L F
.77456 .49506 m .77836 .49507 L .77843 .49486 L .667 .748 .911 r
F
.7783 .49448 m .77843 .49486 L .77856 .49444 L F
.77456 .49506 m .77843 .49486 L .7783 .49448 L F
.77942 .4939 m .78622 .49399 L .78024 .49298 L .667 .747 .91 r
F
.77879 .49369 m .78094 .49408 L .78048 .49315 L .667 .748 .911 r
F
.77811 .49204 m .77842 .49487 L .77802 .49232 L 0 0 .362 r
F
.77842 .49487 m .77842 .49488 L .77802 .49232 L F
.77809 .49152 m .77813 .49395 L .77832 .49453 L .919 .662 .17 r
F
.77811 .49204 m .77843 .49486 L .77842 .49483 L 0 0 .362 r
F
.77811 .49391 m .77856 .49444 L .77879 .49369 L .667 .748 .911 r
F
.77456 .49506 m .7783 .49448 L .77811 .49391 L F
.77789 .50628 m .78489 .51988 L .78217 .51187 L .643 .738 .918 r
F
.77712 .50527 m .7778 .50656 L .77789 .50628 L F
.7778 .50656 m .78489 .51988 L .77789 .50628 L F
.78751 .5036 m .81412 .51494 L .79466 .50107 L .644 .736 .916 r
F
.7781 .49609 m .79494 .50897 L .79617 .50824 L .644 .737 .917 r
F
.78224 .49742 m .78972 .49777 L .78458 .49584 L .667 .747 .91 r
F
.77973 .49699 m .78489 .49892 L .78653 .49708 L .667 .748 .911 r
F
.77973 .49699 m .78653 .49708 L .78055 .49607 L F
.7781 .49609 m .79617 .50824 L .78352 .49833 L .644 .737 .917 r
F
.77785 .49683 m .79494 .50897 L .7781 .49609 L F
.77836 .49507 m .78096 .49508 L .77856 .49444 L .667 .748 .911 r
F
.79466 .50107 m .81412 .51494 L .82583 .50805 L .644 .736 .916 r
F
.79466 .50107 m .82583 .50805 L .80051 .49757 L F
.79004 .50085 m .78972 .49777 L .79219 .495 L .264 .146 .525 r
F
.79004 .50085 m .79219 .495 L .79251 .49809 L F
.78489 .49892 m .79004 .50085 L .79251 .49809 L .667 .748 .911 r
F
.78972 .49777 m .7894 .49469 L .79187 .49192 L .264 .146 .525 r
F
.78972 .49777 m .79187 .49192 L .79219 .495 L F
.78458 .49584 m .78972 .49777 L .79219 .495 L .667 .747 .91 r
F
.78489 .49892 m .79251 .49809 L .78653 .49708 L .667 .748 .911 r
F
.77822 .49571 m .80083 .50547 L .80358 .50267 L .644 .737 .917 r
F
.7781 .49609 m .78352 .49833 L .77822 .49571 L F
.78352 .49833 m .80083 .50547 L .78257 .49758 L F
.78352 .49833 m .78257 .49758 L .77822 .49571 L F
.77778 .49079 m .77797 .4938 L .77786 .49085 L .921 .628 .471 r
F
.77797 .4938 m .77797 .4938 L .77786 .49085 L F
.77798 .49399 m .77806 .49405 L .77805 .49386 L F
.77797 .4938 m .77805 .49386 L .77786 .49085 L F
.77798 .49399 m .77805 .49386 L .77797 .4938 L F
.77538 .47137 m .7763 .4856 L .77654 .48569 L .811 .54 .528 r
F
.77538 .47137 m .77549 .48532 L .7763 .4856 L F
.77592 .48547 m .79423 .4717 L .78685 .46941 L .644 .736 .916 r
F
.77489 .48697 m .77652 .48568 L .77592 .48547 L F
.77652 .48568 m .79423 .4717 L .77592 .48547 L F
.76908 .4138 m .77512 .47502 L .77402 .47543 L .544 .339 .553 r
F
.76908 .4138 m .77015 .41339 L .77512 .47502 L F
.77538 .47137 m .77434 .47102 L .77549 .48532 L .811 .54 .528 r
F
.77471 .49482 m .77684 .49308 L .7761 .49285 L .667 .748 .911 r
F
.77475 .49489 m .77684 .49308 L .77471 .49482 L F
.77478 .49494 m .77753 .49347 L .77753 .49347 L F
.77057 .4927 m .771 .49598 L .7708 .49557 L .966 .687 .262 r
F
.7592 .50005 m .76253 .4988 L .76282 .50187 L .865 .584 .51 r
F
.7592 .50005 m .75891 .49697 L .76253 .4988 L F
.76396 .49425 m .76258 .49875 L .76636 .49547 L .667 .747 .91 r
F
.76396 .49425 m .75898 .49693 L .76258 .49875 L F
.76052 .50274 m .7592 .50005 L .76282 .50187 L .865 .584 .51 r
F
.75939 .50213 m .7592 .50005 L .76052 .50274 L F
.7642 .49736 m .76282 .50187 L .76662 .49858 L .667 .747 .91 r
F
.7642 .49736 m .7592 .50005 L .76282 .50187 L F
.76809 .49808 m .75941 .50215 L .76372 .50372 L .644 .737 .917 r
F
.75941 .50215 m .7499 .5066 L .76157 .50417 L F
.75941 .50215 m .76157 .50417 L .76372 .50372 L F
.75766 .50051 m .7592 .50005 L .75939 .50213 L .944 .648 .447 r
F
.76922 .49467 m .76662 .49858 L .77043 .49528 L .667 .747 .91 r
F
.76922 .49467 m .7642 .49736 L .76662 .49858 L F
.77129 .49659 m .76333 .49793 L .75799 .50138 L .644 .737 .917 r
F
.75942 .50214 m .75799 .50138 L .7499 .5066 L F
.77129 .49659 m .75799 .50138 L .75942 .50214 L F
.74994 .49872 m .72538 .51028 L .73735 .51661 L .644 .736 .916 r
F
.75659 .49767 m .75891 .49697 L .7592 .50005 L .944 .648 .447 r
F
.75789 .50073 m .74553 .50256 L .74867 .50546 L .644 .737 .917 r
F
.75766 .50051 m .75659 .49767 L .7592 .50005 L .944 .648 .447 r
F
.75678 .49969 m .75659 .49767 L .75766 .50051 L F
.76247 .49577 m .7592 .50005 L .7642 .49736 L .667 .747 .91 r
F
.75659 .49767 m .75631 .49459 L .75891 .49697 L .944 .648 .447 r
F
.76223 .49267 m .75898 .49693 L .76396 .49425 L .667 .747 .91 r
F
.76223 .49267 m .75639 .49456 L .75898 .49693 L F
.76247 .49577 m .75659 .49767 L .7592 .50005 L F
.75673 .49965 m .74553 .50256 L .75789 .50073 L .644 .737 .917 r
F
.75585 .49787 m .75659 .49767 L .75678 .49969 L .97 .683 .274 r
F
.77426 .49197 m .77194 .4911 L .77186 .49155 L .667 .747 .91 r
F
.77126 .49144 m .77121 .49083 L .77082 .49137 L F
.77426 .49197 m .77122 .49083 L .77121 .49083 L F
.76895 .49107 m .76829 .49093 L .76832 .49096 L F
.77029 .48872 m .77053 .49184 L .77053 .49177 L 0 0 .196 r
F
.77029 .48874 m .77053 .49184 L .77029 .48872 L F
.77028 .4889 m .77048 .49251 L .77052 .49199 L F
.77426 .49197 m .77041 .4913 L .77039 .49131 L .667 .747 .91 r
F
.77067 .49291 m .771 .49598 L .77057 .4927 L .966 .687 .262 r
F
.77426 .49197 m .77051 .49206 L .77049 .49254 L .667 .747 .91 r
F
.77051 .49206 m .77048 .49251 L .77049 .49254 L F
.77051 .49206 m .7704 .49195 L .77033 .49206 L F
.77426 .49197 m .77052 .49195 L .77051 .49206 L F
.77052 .49195 m .7704 .49195 L .77051 .49206 L F
.77426 .49197 m .77016 .49259 L .77073 .4931 L F
.76923 .49359 m .76918 .49365 L .77072 .49386 L F
.76908 .49364 m .76836 .49387 L .77072 .49386 L F
.77048 .49251 m .77075 .49545 L .7707 .49535 L .966 .687 .262 r
F
.77051 .49257 m .77075 .49545 L .77048 .49251 L F
.77052 .49199 m .77048 .49251 L .7707 .49535 L 0 0 .196 r
F
.7708 .49557 m .77054 .49263 L .77054 .49265 L .966 .687 .262 r
F
.7708 .49557 m .77075 .49545 L .77051 .49257 L F
.7708 .49557 m .77051 .49257 L .77054 .49263 L F
.77052 .49199 m .7707 .49535 L .77074 .49488 L 0 0 .196 r
F
.77077 .49314 m .77109 .49606 L .771 .49598 L .941 .646 .452 r
F
.77082 .49318 m .77109 .49606 L .77077 .49314 L F
.77067 .49291 m .77077 .49314 L .771 .49598 L .966 .687 .262 r
F
.77476 .4949 m .76792 .49557 L .76345 .49787 L .644 .737 .917 r
F
.77479 .49495 m .77098 .49594 L .77129 .49659 L F
.77395 .48888 m .77249 .48697 L .77154 .48723 L .667 .747 .91 r
F
.773 .48526 m .77209 .48546 L .77222 .48705 L .585 .369 .554 r
F
.77395 .48888 m .77341 .48672 L .77249 .48697 L .667 .747 .91 r
F
.77282 .48688 m .77222 .48705 L .77246 .4901 L .585 .369 .554 r
F
.773 .48526 m .77222 .48705 L .77282 .48688 L F
.77209 .48546 m .77218 .48707 L .77222 .48705 L .454 .273 .545 r
F
.77249 .48697 m .77301 .48517 L .7714 .48555 L .667 .747 .91 r
F
.773 .48526 m .77309 .4868 L .77326 .4852 L .585 .369 .554 r
F
.77309 .4868 m .77335 .48673 L .77326 .4852 L F
.77395 .48888 m .77156 .49096 L .77254 .4911 L .667 .747 .91 r
F
.773 .48526 m .77246 .4901 L .77328 .48987 L .585 .369 .554 r
F
.77341 .48672 m .77301 .48517 L .77249 .48697 L .667 .747 .91 r
F
.77154 .48723 m .77237 .48681 L .77108 .48692 L F
.77249 .48697 m .77237 .48681 L .77154 .48723 L F
.77474 .49486 m .76801 .49552 L .77476 .4949 L .644 .737 .917 r
F
.76801 .49552 m .76794 .49556 L .77476 .4949 L F
.75518 .49489 m .75631 .49459 L .75659 .49767 L .97 .683 .274 r
F
.75585 .49787 m .75518 .49489 L .75659 .49767 L F
.75537 .49693 m .75518 .49489 L .75585 .49787 L F
.76153 .49392 m .75659 .49767 L .76247 .49577 L .667 .747 .91 r
F
.76153 .49392 m .75518 .49489 L .75659 .49767 L F
.76345 .49787 m .75609 .49672 L .75537 .49711 L .644 .737 .917 r
F
.75548 .49995 m .75537 .49711 L .74553 .50256 L F
.76345 .49787 m .75537 .49711 L .75548 .49995 L F
.75529 .49496 m .75518 .49489 L .75537 .49693 L 0 0 .117 r
F
.74561 .49469 m .72538 .51028 L .74994 .49872 L .644 .736 .916 r
F
.75609 .49672 m .74315 .49797 L .74387 .49937 L .644 .737 .917 r
F
.75609 .49672 m .74387 .49937 L .74553 .50256 L F
.76158 .49048 m .74409 .49175 L .74561 .49469 L .644 .736 .916 r
F
.74561 .49469 m .71665 .50231 L .72538 .51028 L F
.75625 .49668 m .74292 .49314 L .74315 .49797 L .644 .737 .917 r
F
.77426 .49197 m .7725 .49167 L .77251 .49196 L .667 .747 .91 r
F
.7725 .49167 m .77039 .49131 L .77251 .49196 L F
.77251 .49196 m .77039 .49131 L .76944 .49195 L F
.77426 .49197 m .77126 .49357 L .77137 .49367 L F
.77426 .49197 m .77137 .49367 L .77189 .4939 L F
.77426 .49197 m .77075 .4931 L .77077 .49314 L F
.77426 .49197 m .77077 .49314 L .77126 .49357 L F
.77024 .48945 m .76763 .48985 L .77019 .4901 L F
.77063 .4906 m .77025 .48923 L .76908 .49002 L F
.77218 .48707 m .77234 .49017 L .77222 .48705 L .454 .273 .545 r
F
.7735 .48961 m .77369 .49124 L .77363 .49125 L .648 .416 .554 r
F
.77395 .48888 m .77254 .4911 L .77351 .49123 L .667 .747 .91 r
F
.77426 .49197 m .77196 .49039 L .77122 .49083 L F
.77234 .49017 m .77236 .49016 L .77222 .48705 L .454 .273 .545 r
F
.77084 .48611 m .77115 .49092 L .77121 .49083 L .159 .061 .485 r
F
.77107 .49103 m .77115 .49092 L .77095 .48781 L F
.77107 .49103 m .77095 .48781 L .77092 .48785 L F
.77191 .48723 m .77097 .48777 L .77121 .49083 L .454 .273 .545 r
F
.77191 .48723 m .77121 .49083 L .77209 .49032 L F
.77101 .49111 m .77107 .49103 L .77092 .48785 L .159 .061 .485 r
F
.77101 .49111 m .77092 .48785 L .7709 .48787 L F
.7708 .48801 m .77101 .49111 L .7709 .48787 L F
.7718 .49028 m .77169 .48862 L .77025 .48923 L .667 .747 .91 r
F
.77426 .49197 m .77246 .4901 L .77196 .49039 L F
.7725 .49321 m .77254 .49319 L .77238 .49015 L .454 .273 .545 r
F
.77236 .49016 m .77238 .49015 L .77222 .48705 L F
.7725 .49321 m .77238 .49015 L .77236 .49016 L F
.77395 .48888 m .77351 .49123 L .77363 .49125 L .667 .747 .91 r
F
.77426 .49197 m .77276 .49002 L .77246 .4901 L F
.77196 .49039 m .77246 .4901 L .7718 .49028 L F
.77222 .48705 m .77238 .49015 L .77246 .4901 L .454 .273 .545 r
F
.77191 .48723 m .77209 .49032 L .77218 .48707 L F
.77209 .49032 m .77234 .49017 L .77218 .48707 L F
.77276 .49002 m .77169 .48862 L .7718 .49028 L .667 .747 .91 r
F
.77426 .49197 m .77188 .49402 L .77286 .49416 L F
.77426 .49197 m .77175 .49401 L .77188 .49402 L F
.77341 .48984 m .77352 .48981 L .77335 .48673 L .585 .369 .554 r
F
.77309 .4868 m .77328 .48987 L .77335 .48673 L F
.77328 .48987 m .77341 .48984 L .77335 .48673 L F
.77276 .49002 m .77331 .48824 L .77169 .48862 L .667 .747 .91 r
F
.77426 .49197 m .7737 .48976 L .77276 .49002 L F
.77347 .49295 m .77369 .4929 L .77352 .48981 L .585 .369 .554 r
F
.77347 .49295 m .77352 .48981 L .77341 .48984 L F
.77234 .49017 m .7725 .49321 L .77236 .49016 L .454 .273 .545 r
F
.77328 .48987 m .77347 .49295 L .77341 .48984 L .585 .369 .554 r
F
.77238 .49015 m .77254 .49319 L .77246 .4901 L .454 .273 .545 r
F
.77254 .49319 m .77261 .49316 L .77246 .4901 L F
.77101 .49111 m .77053 .49177 L .77076 .49464 L .159 .061 .485 r
F
.77101 .49111 m .77076 .49464 L .77121 .49406 L F
.77052 .49199 m .77074 .49488 L .77052 .49193 L 0 0 .196 r
F
.77053 .49177 m .77075 .49475 L .77076 .49464 L F
.77053 .49184 m .77075 .49475 L .77053 .49177 L F
.77074 .49488 m .77075 .49475 L .77053 .49184 L F
.77074 .49488 m .77053 .49184 L .77052 .49193 L F
.77034 .49441 m .76922 .49467 L .77028 .49521 L .667 .747 .91 r
F
.77034 .49441 m .77028 .49521 L .77043 .49528 L F
.77474 .49486 m .76988 .49456 L .76801 .49552 L .644 .737 .917 r
F
.76836 .49387 m .7642 .49736 L .76922 .49467 L .667 .747 .91 r
F
.76836 .49387 m .76247 .49577 L .7642 .49736 L F
.75625 .49668 m .75609 .49672 L .77476 .4949 L .644 .737 .917 r
F
.77553 .49095 m .77638 .49063 L .77645 .49059 L .667 .747 .91 r
F
.77434 .47102 m .77524 .48528 L .77549 .48532 L .734 .481 .546 r
F
.77434 .47102 m .7744 .48516 L .77524 .48528 L F
.77523 .48528 m .78685 .46941 L .77864 .46833 L .644 .736 .916 r
F
.77489 .48697 m .77597 .48538 L .77523 .48528 L F
.77597 .48538 m .78685 .46941 L .77523 .48528 L F
.77489 .48697 m .80026 .47503 L .79423 .4717 L F
.77489 .48697 m .80674 .48381 L .80452 .47916 L F
.77549 .48532 m .77553 .48672 L .7756 .48673 L .734 .481 .546 r
F
.77524 .48528 m .77533 .4867 L .77549 .48532 L F
.77395 .48888 m .77621 .48692 L .77534 .48671 L .667 .747 .91 r
F
.7763 .4856 m .7756 .48673 L .77626 .48694 L .811 .54 .528 r
F
.7763 .4856 m .77626 .48694 L .77639 .48698 L F
.77639 .48698 m .77658 .48704 L .77654 .48569 L F
.77395 .48888 m .77709 .4872 L .77621 .48692 L .667 .747 .91 r
F
.77769 .49072 m .77778 .49079 L .77759 .48778 L .921 .628 .471 r
F
.77767 .4907 m .77759 .48778 L .77756 .48775 L F
.77778 .49366 m .77769 .49072 L .77767 .4907 L F
.77769 .49072 m .77759 .48778 L .77767 .4907 L F
.77426 .49197 m .77723 .49037 L .7769 .49012 L .667 .747 .91 r
F
.77426 .49197 m .7769 .49012 L .77653 .49 L F
.77679 .49307 m .77698 .49313 L .7768 .49009 L .811 .54 .528 r
F
.77679 .49322 m .7768 .49009 L .7767 .49006 L F
.77395 .48888 m .77753 .48773 L .77694 .48728 L .667 .747 .91 r
F
.77669 .49005 m .77662 .48705 L .77658 .48704 L .811 .54 .528 r
F
.77679 .49322 m .7767 .49006 L .77669 .49005 L F
.7767 .49006 m .77662 .48705 L .77669 .49005 L F
.7767 .49006 m .7768 .49009 L .77662 .48705 L F
.77678 .49306 m .77679 .49307 L .77658 .48704 L F
.77678 .49306 m .77658 .48704 L .77658 .48704 L F
.77639 .48698 m .77659 .49002 L .77658 .48704 L F
.77659 .49002 m .77678 .49306 L .77668 .49005 L F
.77659 .49002 m .77668 .49005 L .77658 .48704 L F
.77426 .49197 m .77653 .49 L .77585 .48979 L .667 .747 .91 r
F
.77426 .49197 m .77585 .48979 L .77566 .48977 L F
.77585 .48979 m .77572 .49281 L .7761 .49285 L .734 .481 .546 r
F
.7756 .48673 m .77566 .48977 L .77585 .48979 L F
.77566 .48977 m .77572 .49281 L .77585 .48979 L F
.77621 .48692 m .7756 .48673 L .77534 .48671 L .667 .747 .91 r
F
.77626 .48694 m .7756 .48673 L .77585 .48979 L .811 .54 .528 r
F
.77618 .48989 m .77585 .48979 L .7761 .49285 L F
.77626 .48694 m .77585 .48979 L .77618 .48989 L F
.77533 .4867 m .77553 .48976 L .77553 .48672 L .734 .481 .546 r
F
.77553 .48976 m .77563 .48977 L .77553 .48672 L F
.77659 .49002 m .7761 .49285 L .77678 .49306 L .811 .54 .528 r
F
.77639 .48698 m .77624 .48991 L .77659 .49002 L F
.77624 .48991 m .7761 .49285 L .77659 .49002 L F
.77626 .48694 m .7761 .49285 L .77639 .48698 L F
.77553 .48672 m .77563 .48977 L .7756 .48673 L .734 .481 .546 r
F
.77563 .48977 m .77572 .49281 L .77566 .48977 L F
.77563 .48977 m .77566 .48977 L .7756 .48673 L F
.77426 .49197 m .77566 .48977 L .77476 .48968 L .667 .747 .91 r
F
.77325 .4709 m .77414 .48517 L .7744 .48516 L .664 .428 .553 r
F
.76747 .41399 m .76908 .4138 L .77402 .47543 L .648 .416 .554 r
F
.77434 .47102 m .77325 .4709 L .7744 .48516 L .734 .481 .546 r
F
.7642 .41132 m .76415 .41209 L .769 .47374 L 0 0 .196 r
F
.7642 .41132 m .769 .47374 L .76905 .47298 L F
.76486 .41035 m .7642 .41132 L .76905 .47298 L .159 .061 .485 r
F
.76607 .40961 m .76486 .41035 L .76973 .47203 L .454 .273 .545 r
F
.76486 .41035 m .76905 .47298 L .76973 .47203 L .159 .061 .485 r
F
.76607 .40961 m .76973 .47203 L .77097 .4713 L .454 .273 .545 r
F
.77489 .48697 m .77016 .46854 L .76203 .47001 L .644 .736 .916 r
F
.77144 .41221 m .77166 .41145 L .77666 .47311 L 0 0 .362 r
F
.77166 .41145 m .77635 .47214 L .77666 .47311 L .919 .662 .17 r
F
.77166 .41145 m .77134 .41046 L .77635 .47214 L F
.77134 .41046 m .77538 .47137 L .77635 .47214 L .921 .628 .471 r
F
.77134 .41046 m .7704 .40969 L .77538 .47137 L F
.7704 .40969 m .77434 .47102 L .77538 .47137 L .811 .54 .528 r
F
.7704 .40969 m .76937 .40933 L .77434 .47102 L F
.76721 .40929 m .76607 .40961 L .77097 .4713 L .585 .369 .554 r
F
.76937 .40933 m .77325 .4709 L .77434 .47102 L .734 .481 .546 r
F
.76937 .40933 m .76831 .40921 L .77325 .4709 L F
.76721 .40929 m .77097 .4713 L .77213 .47098 L .585 .369 .554 r
F
.76831 .40921 m .76721 .40929 L .77213 .47098 L .664 .428 .553 r
F
.76831 .40921 m .77213 .47098 L .77325 .4709 L F
.77489 .48697 m .77864 .46833 L .77016 .46854 L .644 .736 .916 r
F
.77395 .48888 m .77534 .48671 L .77451 .48663 L .667 .747 .91 r
F
.77451 .48663 m .77465 .48969 L .77476 .48968 L .664 .428 .553 r
F
.7744 .48516 m .77448 .48663 L .77451 .48663 L F
.77448 .48663 m .77465 .48969 L .77451 .48663 L F
.77442 .48971 m .77465 .48969 L .77448 .48663 L F
.7744 .48664 m .77448 .48663 L .7744 .48516 L F
.77442 .48971 m .77448 .48663 L .7744 .48664 L F
.7763 .4856 m .77549 .48532 L .7756 .48673 L .811 .54 .528 r
F
.77533 .4867 m .77553 .48672 L .77549 .48532 L .734 .481 .546 r
F
.77414 .48517 m .77423 .48665 L .7744 .48516 L .664 .428 .553 r
F
.77395 .48888 m .77451 .48663 L .77438 .48664 L .667 .747 .91 r
F
.77423 .48665 m .77442 .48971 L .7744 .48664 L .664 .428 .553 r
F
.77423 .48665 m .7744 .48664 L .7744 .48516 L F
.77414 .48517 m .77339 .48672 L .77397 .48667 L F
.77341 .48672 m .77439 .48662 L .77336 .48652 L .667 .747 .91 r
F
.77395 .48888 m .77438 .48664 L .77341 .48672 L F
.77414 .48517 m .77397 .48667 L .77423 .48665 L .664 .428 .553 r
F
.77438 .48664 m .77439 .48662 L .77341 .48672 L .667 .747 .91 r
F
.77326 .4852 m .77335 .48673 L .77339 .48672 L .585 .369 .554 r
F
.77414 .48517 m .77326 .4852 L .77339 .48672 L .664 .428 .553 r
F
.77336 .48652 m .77469 .48504 L .77301 .48517 L .667 .747 .91 r
F
.77439 .48662 m .77469 .48504 L .77336 .48652 L F
.77524 .48528 m .7744 .48516 L .77451 .48663 L .734 .481 .546 r
F
.77509 .48668 m .77451 .48663 L .77476 .48968 L F
.77524 .48528 m .77451 .48663 L .77509 .48668 L F
.7751 .48972 m .77476 .48968 L .775 .49275 L F
.77524 .48528 m .77476 .48968 L .7751 .48972 L F
.77354 .4898 m .77355 .4898 L .77339 .48672 L .585 .369 .554 r
F
.77335 .48673 m .77352 .48981 L .77339 .48672 L F
.77352 .48981 m .77354 .4898 L .77339 .48672 L F
.77339 .48672 m .77355 .4898 L .77363 .48978 L F
.77423 .48665 m .77363 .48978 L .77442 .48971 L .664 .428 .553 r
F
.77397 .48667 m .77363 .48978 L .77423 .48665 L F
.77397 .48667 m .77339 .48672 L .77363 .48978 L F
.77395 .48888 m .77363 .49125 L .77453 .49114 L .667 .747 .91 r
F
.77365 .48958 m .77499 .48811 L .77331 .48824 L F
.7737 .48976 m .77383 .4896 L .77365 .48958 L F
.77383 .4896 m .77499 .48811 L .77365 .48958 L F
.77524 .48528 m .775 .49275 L .77572 .49281 L .734 .481 .546 r
F
.77451 .48663 m .77631 .48518 L .77439 .48662 L .667 .747 .91 r
F
.77534 .48671 m .77544 .48655 L .77451 .48663 L F
.77544 .48655 m .77631 .48518 L .77451 .48663 L F
.77438 .48664 m .77451 .48663 L .77439 .48662 L F
.77469 .48969 m .77476 .48968 L .77469 .48968 L F
.77426 .49197 m .77476 .48968 L .77469 .48969 L F
.77471 .49481 m .76988 .49456 L .77474 .49486 L .644 .737 .917 r
F
.77476 .4949 m .74553 .50256 L .77479 .49495 L F
.77426 .49197 m .77381 .49431 L .77482 .49418 L .667 .747 .91 r
F
.75518 .49489 m .75489 .49181 L .75631 .49459 L .97 .683 .274 r
F
.7613 .49082 m .75639 .49456 L .76223 .49267 L .667 .747 .91 r
F
.7613 .49082 m .75499 .49179 L .75639 .49456 L F
.76809 .49078 m .76223 .49267 L .76396 .49425 L F
.75506 .49191 m .75489 .49181 L .75518 .49489 L 0 0 .117 r
F
.76789 .49294 m .76247 .49577 L .76836 .49387 L .667 .747 .91 r
F
.76789 .49294 m .76153 .49392 L .76247 .49577 L F
.76146 .49193 m .75518 .49489 L .76153 .49392 L F
.76146 .49193 m .75506 .49191 L .75518 .49489 L F
.75529 .49496 m .75506 .49191 L .75518 .49489 L 0 0 .117 r
F
.75526 .49403 m .75506 .49191 L .75529 .49496 L F
.76678 .4944 m .75536 .4938 L .75625 .49668 L .644 .737 .917 r
F
.75613 .49198 m .75506 .49191 L .75526 .49403 L 0 0 .418 r
F
.75536 .4938 m .74292 .49314 L .75435 .49618 L .644 .737 .917 r
F
.75536 .4938 m .75435 .49618 L .75625 .49668 L F
.76786 .49195 m .76153 .49392 L .76789 .49294 L .667 .747 .91 r
F
.76763 .48985 m .76223 .49267 L .76809 .49078 L F
.76763 .48985 m .7613 .49082 L .76223 .49267 L F
.76786 .49195 m .76146 .49193 L .76153 .49392 L F
.76678 .4944 m .76669 .49309 L .75524 .49346 L .644 .737 .917 r
F
.76678 .4944 m .75524 .49346 L .75525 .49379 L F
.76123 .48884 m .75499 .49179 L .7613 .49082 L .667 .747 .91 r
F
.76123 .48884 m .75487 .48882 L .75499 .49179 L F
.75506 .49191 m .75478 .48882 L .75489 .49181 L 0 0 .117 r
F
.75625 .48891 m .75478 .48882 L .75506 .49191 L 0 0 .418 r
F
.7676 .48886 m .7613 .49082 L .76763 .48985 L .667 .747 .91 r
F
.7676 .48886 m .76123 .48884 L .7613 .49082 L F
.76226 .48993 m .75506 .49191 L .76146 .49193 L F
.7555 .49346 m .74489 .4884 L .7514 .49359 L .644 .737 .917 r
F
.76226 .48993 m .75625 .48891 L .75506 .49191 L .667 .747 .91 r
F
.76669 .49309 m .7567 .49094 L .7555 .49346 L .644 .737 .917 r
F
.768 .48787 m .76123 .48884 L .7676 .48886 L .667 .747 .91 r
F
.76203 .48686 m .75487 .48882 L .76123 .48884 L F
.768 .48787 m .76203 .48686 L .76123 .48884 L F
.76389 .48807 m .75625 .48891 L .76226 .48993 L F
.7584 .48915 m .75625 .48891 L .75647 .49119 L .248 .131 .517 r
F
.75613 .49198 m .75625 .48891 L .75506 .49191 L 0 0 .418 r
F
.75647 .49119 m .75625 .48891 L .75613 .49198 L F
.77121 .49406 m .77134 .49389 L .77115 .49092 L .159 .061 .485 r
F
.77121 .49406 m .77115 .49092 L .77107 .49103 L F
.76923 .49359 m .76789 .49294 L .76836 .49387 L .667 .747 .91 r
F
.77101 .49111 m .77121 .49406 L .77107 .49103 L .159 .061 .485 r
F
.77072 .49386 m .77038 .49386 L .77037 .49405 L .667 .747 .91 r
F
.77038 .49386 m .76836 .49387 L .77037 .49405 L F
.77467 .49475 m .74489 .4884 L .77471 .49481 L .644 .737 .917 r
F
.77442 .48971 m .77461 .49278 L .77465 .48969 L .664 .428 .553 r
F
.77461 .49278 m .77483 .49276 L .77465 .48969 L F
.77469 .49478 m .77599 .49282 L .77561 .4927 L .667 .748 .911 r
F
.77471 .49482 m .77599 .49282 L .77469 .49478 L F
.77209 .49032 m .77121 .49083 L .77144 .49376 L .454 .273 .545 r
F
.77209 .49032 m .77144 .49376 L .77227 .49334 L F
.77121 .49083 m .77134 .49389 L .77144 .49376 L .159 .061 .485 r
F
.77115 .49092 m .77134 .49389 L .77121 .49083 L F
.77027 .49206 m .76787 .49212 L .77049 .49254 L .667 .747 .91 r
F
.77033 .49206 m .76786 .49195 L .76787 .49212 L F
.7704 .49195 m .76786 .49195 L .77033 .49206 L F
.76925 .49273 m .76787 .49212 L .76789 .49294 L F
.77189 .4939 m .77137 .49367 L .77175 .49401 L F
.76992 .49263 m .76789 .49294 L .76923 .49359 L F
.77426 .49197 m .77286 .49416 L .77381 .49429 L F
.76203 .48686 m .75606 .48584 L .75487 .48882 L F
.75625 .48891 m .75597 .48583 L .75478 .48882 L 0 0 .418 r
F
.76826 .49095 m .76146 .49193 L .76786 .49195 L .667 .747 .91 r
F
.76826 .49095 m .76226 .48993 L .76146 .49193 L F
.76908 .49002 m .76226 .48993 L .76826 .49095 L F
.76365 .48501 m .75606 .48584 L .76203 .48686 L F
.75868 .48612 m .75597 .48583 L .75625 .48891 L .248 .131 .517 r
F
.76908 .49002 m .76389 .48807 L .76226 .48993 L .667 .747 .91 r
F
.75672 .49093 m .74894 .48407 L .74489 .4884 L .644 .737 .917 r
F
.76389 .48807 m .75868 .48612 L .75625 .48891 L .667 .747 .91 r
F
.77467 .49475 m .7593 .48837 L .75672 .49093 L .644 .737 .917 r
F
.76881 .48695 m .76203 .48686 L .768 .48787 L .667 .747 .91 r
F
.76881 .48695 m .76365 .48501 L .76203 .48686 L F
.76622 .48648 m .75868 .48612 L .76389 .48807 L F
.76199 .48673 m .75868 .48612 L .75892 .48861 L .418 .252 .548 r
F
.7584 .48915 m .75868 .48612 L .75625 .48891 L .248 .131 .517 r
F
.75892 .48861 m .75868 .48612 L .7584 .48915 L F
.77016 .49259 m .76992 .49263 L .77073 .4931 L .667 .747 .91 r
F
.77462 .49466 m .74894 .48407 L .77467 .49475 L .644 .737 .917 r
F
.77463 .49469 m .77561 .4927 L .775 .49275 L .667 .748 .911 r
F
.77456 .49506 m .77469 .49478 L .77463 .49469 L F
.77469 .49478 m .77561 .4927 L .77463 .49469 L F
.77039 .49131 m .76901 .49105 L .76895 .49107 L .667 .747 .91 r
F
.77041 .4913 m .76901 .49105 L .77039 .49131 L F
.76901 .49105 m .76829 .49093 L .76895 .49107 L F
.77209 .49032 m .77227 .49334 L .77234 .49017 L .454 .273 .545 r
F
.77227 .49334 m .7725 .49321 L .77234 .49017 L F
.77019 .4901 m .76809 .49078 L .77016 .49057 L .667 .747 .91 r
F
.77041 .4913 m .76908 .49002 L .76829 .49093 L F
.76832 .49096 m .76829 .49093 L .76826 .49095 L F
.77039 .49131 m .76895 .49107 L .7694 .49188 L F
.77039 .49131 m .7694 .49188 L .76944 .49195 L F
.76998 .48592 m .76857 .48435 L .75162 .48199 L .644 .736 .916 r
F
.76857 .48435 m .74899 .47625 L .75162 .48199 L F
.76895 .49107 m .76832 .49096 L .76856 .49117 L .667 .747 .91 r
F
.76895 .49107 m .76856 .49117 L .76944 .49195 L F
.76832 .49096 m .76826 .49095 L .76944 .49195 L F
.77051 .49206 m .77027 .49206 L .77048 .49251 L F
.76365 .48501 m .75847 .48306 L .75606 .48584 L F
.75868 .48612 m .7584 .48303 L .75597 .48583 L .248 .131 .517 r
F
.77024 .48945 m .77018 .48887 L .76971 .48953 L .667 .747 .91 r
F
.77018 .48887 m .7676 .48886 L .76971 .48953 L F
.77025 .48923 m .76389 .48807 L .76908 .49002 L F
.77059 .48831 m .76881 .48695 L .768 .48787 L F
.77059 .48831 m .768 .48787 L .77018 .48887 L F
.77025 .48923 m .76622 .48648 L .76389 .48807 L F
.76597 .48342 m .75847 .48306 L .76365 .48501 L F
.76219 .48372 m .7584 .48303 L .75868 .48612 L .418 .252 .548 r
F
.76997 .48615 m .76365 .48501 L .76881 .48695 L .667 .747 .91 r
F
.76997 .48615 m .76597 .48342 L .76365 .48501 L F
.76622 .48648 m .76219 .48372 L .75868 .48612 L F
.76199 .48673 m .76219 .48372 L .75868 .48612 L .418 .252 .548 r
F
.77462 .49466 m .76292 .48628 L .75933 .48836 L .644 .737 .917 r
F
.77153 .48558 m .76857 .48435 L .76998 .48592 L .644 .736 .916 r
F
.7714 .48555 m .76597 .48342 L .76997 .48615 L .667 .747 .91 r
F
.76911 .48526 m .76219 .48372 L .76622 .48648 L F
.76666 .48494 m .76219 .48372 L .76245 .48645 L .525 .329 .558 r
F
.76292 .48628 m .76283 .48622 L .76245 .48645 L .644 .737 .917 r
F
.76292 .48628 m .76245 .48645 L .75933 .48836 L F
.76245 .48645 m .76219 .48372 L .76199 .48673 L .418 .252 .548 r
F
.77449 .49444 m .77265 .49314 L .77462 .49466 L .644 .737 .917 r
F
.77246 .4901 m .77261 .49316 L .7727 .49311 L .454 .273 .545 r
F
.76597 .48342 m .76195 .48067 L .75847 .48306 L .667 .747 .91 r
F
.76219 .48372 m .76189 .48063 L .7584 .48303 L .418 .252 .548 r
F
.77265 .49314 m .7548 .48046 L .77256 .49318 L .644 .737 .917 r
F
.77265 .49314 m .77256 .49318 L .77462 .49466 L F
.7727 .49311 m .77262 .49321 L .7727 .49316 L .454 .273 .545 r
F
.77261 .49316 m .77262 .49321 L .7727 .49311 L F
.77434 .49421 m .7748 .49276 L .774 .49283 L .667 .748 .911 r
F
.77476 .48968 m .77493 .49275 L .775 .49275 L .664 .428 .553 r
F
.77463 .49469 m .775 .49275 L .77434 .49421 L .667 .748 .911 r
F
.775 .49275 m .7753 .4912 L .7748 .49276 L F
.775 .49275 m .7748 .49276 L .77434 .49421 L F
.77465 .48969 m .77483 .49276 L .77476 .48968 L .664 .428 .553 r
F
.77122 .49083 m .7718 .49028 L .77063 .4906 L .667 .747 .91 r
F
.7718 .49028 m .77025 .48923 L .77063 .4906 L F
.77082 .49137 m .77121 .49083 L .77041 .4913 L F
.77122 .49083 m .76908 .49002 L .77041 .4913 L F
.77097 .48777 m .77036 .48813 L .77059 .48831 L F
.77028 .48887 m .77018 .48887 L .77024 .48945 L F
.77169 .48862 m .76622 .48648 L .77025 .48923 L F
.7709 .48787 m .77092 .48785 L .77084 .48611 L .159 .061 .485 r
F
.7708 .48801 m .7709 .48787 L .77084 .48611 L F
.77131 .48729 m .77108 .48692 L .7704 .48755 L .667 .747 .91 r
F
.77098 .48776 m .77131 .48729 L .7704 .48755 L F
.7704 .48755 m .77108 .48692 L .76916 .48708 L F
.77108 .48692 m .76997 .48615 L .76916 .48708 L F
.77098 .48776 m .76881 .48695 L .77036 .48813 L F
.77098 .48776 m .77036 .48813 L .77097 .48777 L F
.77098 .48777 m .77098 .48776 L .77097 .48777 L F
.77169 .48862 m .76911 .48526 L .76622 .48648 L F
.76884 .4822 m .76195 .48067 L .76597 .48342 L F
.76884 .4822 m .76627 .47884 L .76195 .48067 L F
.7714 .48555 m .76884 .4822 L .76597 .48342 L F
.76911 .48526 m .76653 .48188 L .76219 .48372 L F
.76653 .48188 m .76189 .48063 L .76219 .48372 L .525 .329 .558 r
F
.76653 .48188 m .76623 .47879 L .76189 .48063 L F
.76666 .48494 m .76653 .48188 L .76219 .48372 L F
.77233 .49291 m .76686 .48487 L .76297 .48626 L .644 .737 .917 r
F
.77301 .48517 m .76884 .4822 L .7714 .48555 L .667 .747 .91 r
F
.77301 .48517 m .77207 .48144 L .76884 .4822 L F
.77236 .48449 m .76653 .48188 L .76911 .48526 L F
.77207 .48144 m .76627 .47884 L .76884 .4822 L F
.77207 .48144 m .77111 .47769 L .76627 .47884 L F
.77236 .48449 m .7714 .48073 L .76653 .48188 L F
.7717 .48383 m .76653 .48188 L .76681 .48488 L .603 .386 .559 r
F
.76686 .48487 m .76686 .48486 L .76681 .48488 L .644 .737 .917 r
F
.76686 .48487 m .76681 .48488 L .76297 .48626 L F
.7717 .48383 m .76681 .48488 L .76859 .48456 L .603 .386 .559 r
F
.76681 .48488 m .76653 .48188 L .76666 .48494 L .525 .329 .558 r
F
.77328 .48987 m .77246 .4901 L .7727 .49311 L .585 .369 .554 r
F
.77328 .48987 m .7727 .49311 L .77347 .49295 L F
.77196 .49039 m .7718 .49028 L .77122 .49083 L .667 .747 .91 r
F
.77354 .49287 m .76208 .47783 L .77233 .49291 L .644 .737 .917 r
F
.77483 .49276 m .77493 .49275 L .77476 .48968 L .664 .428 .553 r
F
.77426 .49197 m .77473 .48948 L .7737 .48976 L .667 .747 .91 r
F
.77363 .48978 m .77372 .49288 L .77387 .49284 L .585 .369 .554 r
F
.77442 .48971 m .77363 .48978 L .77387 .49284 L .664 .428 .553 r
F
.77442 .48971 m .77387 .49284 L .77461 .49278 L F
.77399 .49281 m .7753 .4912 L .77361 .49133 L .667 .748 .911 r
F
.774 .49283 m .77402 .4928 L .77399 .49281 L F
.77402 .4928 m .7753 .4912 L .77399 .49281 L F
.77434 .49421 m .77399 .49281 L .77358 .49292 L F
.77387 .49284 m .77372 .49289 L .77388 .49286 L .585 .369 .554 r
F
.77372 .49288 m .77372 .49289 L .77387 .49284 L F
.7748 .49276 m .7753 .4912 L .774 .49283 L .667 .748 .911 r
F
.77461 .49278 m .77387 .49284 L .77388 .49286 L .664 .428 .553 r
F
.77461 .49278 m .77388 .49286 L .77462 .49283 L F
.77354 .49287 m .77353 .49285 L .76208 .47783 L .644 .737 .917 r
F
.7714 .48073 m .76623 .47879 L .76653 .48188 L .603 .386 .559 r
F
.7717 .48383 m .7714 .48073 L .76653 .48188 L F
.77353 .49285 m .76433 .47742 L .76208 .47783 L .644 .737 .917 r
F
.77298 .493 m .77323 .49234 L .77199 .49171 L .667 .748 .911 r
F
.77323 .49234 m .77361 .49133 L .77275 .49153 L F
.77323 .49234 m .77275 .49153 L .77199 .49171 L F
.77308 .49294 m .77326 .49239 L .77298 .493 L F
.77326 .49239 m .77361 .49133 L .77323 .49234 L F
.77326 .49239 m .77323 .49234 L .77298 .493 L F
.77355 .49287 m .77353 .49285 L .77354 .49287 L .644 .737 .917 r
F
.77369 .49289 m .77372 .49288 L .77355 .4898 L .585 .369 .554 r
F
.77399 .49281 m .77361 .49133 L .77304 .49307 L .667 .748 .911 r
F
.77369 .4929 m .77355 .4898 L .77354 .4898 L .585 .369 .554 r
F
.77473 .48948 m .77499 .48811 L .7737 .48976 L .667 .747 .91 r
F
.7737 .48976 m .77331 .48824 L .77276 .49002 L F
.77352 .48981 m .77369 .4929 L .77354 .4898 L .585 .369 .554 r
F
.77355 .4898 m .77372 .49289 L .77363 .48978 L F
.77237 .48681 m .7714 .48555 L .77108 .48692 L .667 .747 .91 r
F
.77108 .48692 m .7714 .48555 L .76997 .48615 L F
.77154 .48723 m .77142 .48715 L .77131 .48729 L F
.77142 .48715 m .77108 .48692 L .77131 .48729 L F
.77155 .48744 m .77154 .48723 L .77131 .48729 L F
.77171 .48734 m .77154 .48723 L .77155 .48744 L F
.77331 .48824 m .76911 .48526 L .77169 .48862 L F
.77331 .48824 m .77236 .48449 L .76911 .48526 L F
.77499 .48811 m .77236 .48449 L .77331 .48824 L F
.77439 .48662 m .77631 .48518 L .77469 .48504 L F
.77631 .48518 m .77542 .48119 L .77469 .48504 L F
.77469 .48504 m .77207 .48144 L .77301 .48517 L F
.77469 .48504 m .77542 .48119 L .77207 .48144 L F
.77499 .48811 m .77573 .48424 L .77236 .48449 L F
.77361 .49133 m .76941 .48835 L .77199 .49171 L .667 .748 .911 r
F
.77361 .49133 m .77266 .48759 L .76941 .48835 L F
.7753 .4912 m .77266 .48759 L .77361 .49133 L F
.77469 .48968 m .77478 .48968 L .77474 .48944 L .667 .747 .91 r
F
.77478 .48968 m .77568 .48973 L .77536 .48963 L F
.77478 .48968 m .77536 .48963 L .77474 .48944 L F
.77566 .48977 m .77568 .48973 L .77469 .48968 L F
.77474 .48944 m .77663 .48825 L .77499 .48811 L F
.77568 .48973 m .77663 .48825 L .77474 .48944 L F
.77658 .48704 m .77662 .48705 L .77654 .48569 L .811 .54 .528 r
F
.77658 .48704 m .77658 .48704 L .77654 .48569 L F
.7763 .4856 m .77639 .48698 L .77654 .48569 L F
.77654 .48569 m .77698 .49313 L .77714 .49318 L F
.77729 .48628 m .77654 .48569 L .77665 .48706 L .921 .628 .471 r
F
.77635 .4868 m .77777 .48557 L .77541 .48667 L .667 .747 .91 r
F
.7756 .48673 m .77541 .48667 L .77534 .48671 L F
.77635 .4868 m .77541 .48667 L .7756 .48673 L F
.77729 .48628 m .77738 .48761 L .77751 .48645 L .921 .628 .471 r
F
.77738 .48761 m .77758 .49063 L .77753 .48773 L F
.77738 .48761 m .77753 .48773 L .77751 .48645 L F
.77758 .49063 m .77767 .4907 L .77756 .48775 L F
.77753 .48773 m .77756 .48775 L .77751 .48645 L F
.77758 .49063 m .77756 .48775 L .77753 .48773 L F
.77751 .48645 m .77778 .49079 L .77786 .49085 L F
.77729 .48628 m .77665 .48706 L .77738 .48761 L F
.77753 .48653 m .77751 .48645 L .77762 .4878 L .919 .662 .17 r
F
.77709 .4872 m .77898 .48618 L .7764 .48687 L .667 .747 .91 r
F
.77665 .48706 m .7764 .48687 L .77621 .48692 L F
.77709 .4872 m .7764 .48687 L .77665 .48706 L F
.77633 .48682 m .77898 .48618 L .77777 .48557 L F
.77621 .48692 m .7764 .48687 L .77633 .48682 L F
.7764 .48687 m .77898 .48618 L .77633 .48682 L F
.77537 .48666 m .77777 .48557 L .77631 .48518 L F
.77534 .48671 m .77541 .48667 L .77537 .48666 L F
.77541 .48667 m .77777 .48557 L .77537 .48666 L F
.77621 .48692 m .77635 .4868 L .7756 .48673 L F
.77663 .48825 m .77573 .48424 L .77499 .48811 L F
.7753 .4912 m .77604 .48733 L .77266 .48759 L .667 .748 .911 r
F
.77542 .48119 m .77111 .47769 L .77207 .48144 L .667 .747 .91 r
F
.77573 .48424 m .7714 .48073 L .77236 .48449 L F
.77266 .48759 m .76682 .48498 L .76941 .48835 L .667 .748 .911 r
F
.7714 .48073 m .7711 .47764 L .76623 .47879 L .603 .386 .559 r
F
.77266 .48759 m .7717 .48383 L .76682 .48498 L .667 .748 .911 r
F
.77604 .48733 m .7717 .48383 L .77266 .48759 L F
.77777 .48557 m .77868 .48146 L .77631 .48518 L .667 .747 .91 r
F
.77631 .48518 m .77868 .48146 L .77542 .48119 L F
.77756 .48775 m .77759 .48778 L .77751 .48645 L .921 .628 .471 r
F
.77694 .48728 m .77814 .48753 L .77709 .4872 L .667 .747 .91 r
F
.77753 .48773 m .77814 .48753 L .77694 .48728 L F
.77753 .48653 m .77762 .4878 L .77775 .48717 L .919 .662 .17 r
F
.77709 .4872 m .77983 .48698 L .77898 .48618 L .667 .747 .91 r
F
.77814 .48753 m .77983 .48698 L .77709 .4872 L F
.77738 .48761 m .77665 .48706 L .77714 .49318 L .921 .628 .471 r
F
.77475 .49489 m .7777 .49335 L .77684 .49308 L .667 .748 .911 r
F
.77738 .48761 m .77714 .49318 L .77778 .49366 L .921 .628 .471 r
F
.77778 .49366 m .77797 .4938 L .77778 .49079 L F
.77778 .49366 m .77778 .49079 L .77769 .49072 L F
.77786 .49085 m .77805 .49386 L .77811 .49391 L F
.77478 .49494 m .77753 .49347 L .77475 .49489 L .667 .748 .911 r
F
.77758 .49063 m .77778 .49366 L .77767 .4907 L .921 .628 .471 r
F
.77778 .49366 m .77778 .49366 L .77767 .4907 L F
.77799 .49122 m .77812 .49393 L .77809 .49152 L .919 .662 .17 r
F
.77812 .49393 m .77813 .4941 L .77813 .49395 L F
.77812 .49393 m .77813 .49395 L .77809 .49152 L F
.77811 .49391 m .77811 .49391 L .77753 .49347 L .667 .748 .911 r
F
.77812 .49198 m .78065 .49199 L .77832 .49134 L .667 .747 .91 r
F
.77811 .49203 m .77818 .4918 L .77843 .49486 L 0 0 .362 r
F
.77832 .49453 m .77838 .49471 L .77815 .49171 L .919 .662 .17 r
F
.77818 .4918 m .77838 .49471 L .77843 .49486 L F
.77811 .49391 m .77879 .49369 L .77799 .49355 L .667 .748 .911 r
F
.77811 .49391 m .77799 .49355 L .77753 .49347 L F
.77791 .49258 m .77795 .49254 L .77812 .49198 L .667 .747 .91 r
F
.77799 .49122 m .77786 .49085 L .77813 .4941 L .919 .662 .17 r
F
.77811 .49203 m .77843 .49486 L .77811 .49204 L 0 0 .362 r
F
.77832 .49453 m .77815 .49171 L .77812 .4916 L .919 .662 .17 r
F
.77848 .49268 m .77942 .4939 L .78024 .49298 L .667 .747 .91 r
F
.77866 .49323 m .77942 .4939 L .77848 .49268 L F
.77809 .49152 m .77832 .49453 L .77812 .4916 L .919 .662 .17 r
F
.77815 .49171 m .77838 .49471 L .77818 .4918 L F
.77753 .49347 m .77962 .49235 L .7775 .49345 L .667 .748 .911 r
F
.77753 .49347 m .7775 .49345 L .77475 .49489 L F
.77778 .49366 m .77779 .49384 L .77778 .49366 L .921 .628 .471 r
F
.77478 .49494 m .77753 .49347 L .77478 .49494 L .667 .748 .911 r
F
.77503 .49483 m .7781 .49609 L .77822 .49571 L .644 .737 .917 r
F
.77825 .49563 m .77825 .49563 L .77823 .49548 L 0 0 .362 r
F
.77829 .4955 m .77825 .49563 L .77823 .49548 L F
.77814 .49566 m .7782 .49559 L .77836 .49507 L .667 .748 .911 r
F
.7782 .49559 m .77825 .49563 L .77821 .49574 L 0 0 .362 r
F
.77823 .49548 m .77825 .49563 L .7782 .49559 L F
.77819 .4956 m .77821 .49574 L .77819 .49561 L .231 .113 .505 r
F
.78421 .49274 m .78933 .49466 L .79178 .49191 L .667 .747 .91 r
F
.78458 .49584 m .79219 .495 L .78622 .49399 L F
.78055 .49607 m .78653 .49708 L .78737 .49509 L .667 .748 .911 r
F
.78055 .49607 m .78737 .49509 L .78096 .49508 L F
.77863 .4956 m .80358 .50267 L .79105 .49825 L .644 .737 .917 r
F
.77503 .49483 m .77872 .49584 L .77863 .4956 L F
.77872 .49584 m .80358 .50267 L .77863 .4956 L F
.77842 .49487 m .77843 .49486 L .77844 .49504 L 0 0 .362 r
F
.77843 .49486 m .77844 .49503 L .77844 .49504 L .919 .662 .17 r
F
.77842 .49487 m .77844 .49504 L .77842 .49488 L 0 0 .362 r
F
.77828 .49534 m .77829 .4955 L .77823 .49548 L F
.77828 .49534 m .77844 .49504 L .77829 .4955 L F
.77842 .49488 m .77844 .49504 L .77828 .49534 L F
.77503 .49483 m .77863 .4956 L .77843 .49501 L .644 .737 .917 r
F
.77829 .4955 m .77841 .49513 L .7788 .50028 L 0 0 .362 r
F
.77841 .49513 m .77844 .49504 L .7788 .50028 L F
.7788 .50028 m .77844 .49504 L .77907 .50273 L F
.7809 .50518 m .78316 .50897 L .78104 .50272 L .644 .737 .917 r
F
.78104 .50272 m .78422 .51212 L .78774 .5115 L F
.79987 .5199 m .812 .5359 L .83326 .5286 L .644 .736 .916 r
F
.79987 .5199 m .83326 .5286 L .81412 .51494 L F
.78774 .5115 m .80019 .52785 L .81454 .52288 L .644 .737 .917 r
F
.7803 .50635 m .7879 .51936 L .79513 .51684 L .643 .738 .918 r
F
.77614 .49702 m .77749 .50448 L .7769 .50466 L .544 .339 .553 r
F
.77605 .49712 m .7755 .49876 L .77614 .49711 L .667 .748 .911 r
F
.77608 .49711 m .77571 .49747 L .77614 .49722 L .644 .737 .917 r
F
.77563 .49715 m .77571 .49747 L .77608 .49711 L F
.77574 .49755 m .77476 .49946 L .77591 .49822 L F
.77564 .49718 m .77549 .49751 L .77574 .49755 L F
.77515 .49738 m .7755 .49876 L .77608 .49704 L .667 .748 .911 r
F
.77421 .4989 m .77297 .50016 L .77366 .50162 L .644 .737 .917 r
F
.77383 .49889 m .77309 .50271 L .77644 .50246 L .667 .748 .911 r
F
.77383 .49889 m .77644 .50246 L .7755 .49876 L F
.77487 .49508 m .77334 .49731 L .77495 .49523 L .644 .737 .917 r
F
.77308 .49707 m .77411 .49726 L .77412 .49736 L .75 .494 .544 r
F
.77518 .49751 m .77383 .49889 L .7755 .49876 L .667 .748 .911 r
F
.77493 .49747 m .77383 .49889 L .77518 .49751 L F
.77412 .49736 m .77383 .49889 L .77512 .49723 L F
.77539 .50713 m .77459 .50996 L .77577 .50743 L .643 .738 .918 r
F
.77459 .50996 m .77148 .52094 L .77481 .51044 L F
.77459 .50996 m .77481 .51044 L .77577 .50743 L F
.77481 .51044 m .77148 .52094 L .77528 .51142 L F
.77561 .50557 m .77555 .50579 L .77587 .50542 L F
.77524 .50696 m .77449 .50975 L .7754 .5071 L F
.77449 .50975 m .77148 .52094 L .77459 .50996 L F
.77449 .50975 m .77459 .50996 L .7754 .5071 L F
.77568 .50504 m .77566 .50511 L .77577 .50501 L F
.77173 .49743 m .77178 .49742 L .77487 .49508 L .644 .737 .917 r
F
.77487 .49508 m .77186 .49742 L .77334 .49731 L F
.76989 .50573 m .76325 .51204 L .76933 .51283 L F
.76823 .50552 m .76325 .51204 L .76989 .50573 L F
.7701 .50307 m .76933 .51283 L .77135 .51309 L F
.76845 .50555 m .77232 .50605 L .77237 .50651 L .73 .482 .552 r
F
.76984 .50244 m .77237 .50651 L .77309 .50271 L .667 .748 .911 r
F
.7722 .49875 m .77309 .50271 L .77383 .49889 L F
.7722 .49875 m .76984 .50244 L .77309 .50271 L F
.77404 .4978 m .7722 .49875 L .77383 .49889 L F
.77308 .49707 m .77412 .49736 L .77309 .49722 L .75 .494 .544 r
F
.77432 .49724 m .77433 .49733 L .77411 .49726 L .648 .416 .554 r
F
.77549 .50576 m .77519 .50691 L .77555 .50579 L .643 .738 .918 r
F
.77098 .49594 m .76333 .49793 L .77129 .49659 L .644 .737 .917 r
F
.77019 .50191 m .76325 .51204 L .7701 .50307 L F
.77073 .49837 m .76984 .50244 L .7722 .49875 L .667 .748 .911 r
F
.77221 .49874 m .77073 .49837 L .7722 .49875 L F
.77192 .49667 m .77254 .49697 L .77255 .49714 L .848 .57 .516 r
F
.77192 .49667 m .77255 .49714 L .77195 .49687 L F
.77308 .49737 m .77166 .49757 L .77221 .49874 L .667 .748 .911 r
F
.77255 .49714 m .77166 .49757 L .77308 .49737 L F
.77228 .49702 m .7722 .49709 L .77255 .49714 L F
.7722 .49709 m .77166 .49757 L .77255 .49714 L F
.77308 .49707 m .77309 .49722 L .77278 .49701 L .75 .494 .544 r
F
.77309 .49722 m .7728 .49718 L .77278 .49701 L F
.77254 .49697 m .77256 .49714 L .77255 .49714 L F
.77317 .49723 m .77255 .49714 L .77308 .49737 L .667 .748 .911 r
F
.77446 .50968 m .77148 .52094 L .77449 .50975 L .643 .738 .918 r
F
.77332 .49734 m .773 .4978 L .7741 .49771 L .644 .737 .917 r
F
.773 .4978 m .77355 .4983 L .7741 .49771 L F
.77308 .49737 m .7722 .49875 L .77404 .4978 L .667 .748 .911 r
F
.77278 .49701 m .77364 .50474 L .77254 .49697 L .75 .494 .544 r
F
.77473 .50494 m .77464 .50536 L .77566 .50511 L .643 .738 .918 r
F
.77464 .50536 m .77148 .52094 L .77549 .50576 L F
.77464 .50536 m .77549 .50576 L .77566 .50511 L F
.77166 .49757 m .77073 .49837 L .77221 .49874 L .667 .748 .911 r
F
.77075 .49545 m .77077 .49567 L .7707 .49535 L .966 .687 .262 r
F
.77228 .49702 m .7706 .49718 L .77073 .49837 L .667 .748 .911 r
F
.77152 .49669 m .7706 .49718 L .77198 .49705 L F
.77161 .49673 m .77198 .49705 L .77228 .49702 L F
.77152 .49669 m .77198 .49705 L .77161 .49673 L F
.7712 .49616 m .77159 .49652 L .77161 .49673 L .941 .646 .452 r
F
.7712 .49616 m .77161 .49673 L .77123 .49639 L F
.7706 .49718 m .76865 .49696 L .76952 .49775 L .667 .748 .911 r
F
.7713 .4968 m .77067 .49631 L .7706 .49718 L F
.77101 .4962 m .77067 .49631 L .7713 .4968 L F
.7708 .49557 m .771 .49598 L .77101 .4962 L .966 .687 .262 r
F
.77101 .4962 m .76819 .49603 L .76865 .49696 L .667 .748 .911 r
F
.77044 .49569 m .76819 .49603 L .77101 .4962 L F
.7708 .49557 m .77101 .4962 L .77083 .4958 L .966 .687 .262 r
F
.77109 .49606 m .77111 .49628 L .771 .49598 L .941 .646 .452 r
F
.77111 .49628 m .77102 .4962 L .771 .49598 L F
.77082 .49579 m .77077 .49567 L .77075 .49545 L .966 .687 .262 r
F
.77144 .50333 m .7714 .50323 L .77077 .49567 L F
.77077 .49567 m .77077 .49567 L .77075 .49545 L F
.77144 .50333 m .77077 .49567 L .77077 .49567 L F
.76988 .49456 m .76678 .4944 L .76801 .49552 L .644 .737 .917 r
F
.77075 .49564 m .76816 .49504 L .76819 .49603 L .667 .748 .911 r
F
.7708 .49557 m .77082 .49579 L .77075 .49545 L .966 .687 .262 r
F
.7707 .49535 m .77072 .49557 L .77072 .49557 L F
.77072 .49558 m .77072 .49557 L .7707 .49535 L F
.77074 .49488 m .7707 .49535 L .77072 .49557 L 0 0 .196 r
F
.77074 .49488 m .77072 .49557 L .77076 .4951 L F
.77077 .49567 m .77072 .49558 L .7707 .49535 L .966 .687 .262 r
F
.7708 .49557 m .7716 .50366 L .77144 .50333 L F
.77074 .49488 m .77076 .49509 L .77075 .49475 L 0 0 .196 r
F
.77456 .49506 m .77076 .49504 L .77075 .49564 L .667 .748 .911 r
F
.7712 .49616 m .77122 .49638 L .77109 .49606 L .941 .646 .452 r
F
.77102 .4962 m .77101 .4962 L .77155 .49667 L .667 .748 .911 r
F
.77122 .49638 m .77188 .50391 L .77111 .49628 L .941 .646 .452 r
F
.77122 .49638 m .77111 .49628 L .77109 .49606 L F
.77155 .49667 m .77101 .4962 L .7713 .4968 L .667 .748 .911 r
F
.77188 .50391 m .77179 .50383 L .77109 .49606 L .941 .646 .452 r
F
.77174 .49659 m .77249 .50434 L .77159 .49652 L .848 .57 .516 r
F
.76325 .51204 m .76775 .53094 L .77135 .51309 L .644 .737 .917 r
F
.77464 .50536 m .77074 .51018 L .77148 .52094 L .643 .738 .918 r
F
.77447 .50528 m .77074 .51018 L .77464 .50536 L F
.77377 .50477 m .77083 .50904 L .77473 .50494 L F
.76325 .51204 m .75173 .52888 L .76775 .53094 L .644 .737 .917 r
F
.77083 .50904 m .76336 .51989 L .77074 .51018 L .643 .738 .918 r
F
.77083 .50904 m .77074 .51018 L .77473 .50494 L F
.7708 .49563 m .77075 .49564 L .77081 .49576 L .667 .748 .911 r
F
.7708 .49563 m .77081 .49576 L .77102 .4962 L F
.77456 .49506 m .7708 .49563 L .77102 .4962 L F
.77075 .49564 m .77044 .49569 L .77101 .4962 L F
.77082 .49579 m .77144 .50333 L .77077 .49567 L .966 .687 .262 r
F
.77076 .49509 m .77077 .49495 L .77075 .49475 L 0 0 .196 r
F
.77074 .49488 m .77076 .4951 L .77076 .49509 L F
.77037 .49405 m .76836 .49387 L .76922 .49467 L .667 .747 .91 r
F
.77471 .49481 m .76976 .49375 L .76678 .4944 L .644 .737 .917 r
F
.77062 .49504 m .76856 .49404 L .76816 .49504 L .667 .748 .911 r
F
.77456 .49506 m .77077 .49483 L .77076 .49504 L F
.77075 .49564 m .77101 .4962 L .77102 .4962 L F
.77083 .4958 m .77101 .4962 L .7716 .50366 L .966 .687 .262 r
F
.7675 .50611 m .76845 .50555 L .77237 .50651 L .73 .482 .552 r
F
.75594 .50983 m .75173 .52888 L .76325 .51204 L .644 .737 .917 r
F
.77083 .50904 m .75604 .51769 L .76336 .51989 L .643 .738 .918 r
F
.77255 .49714 m .77343 .5047 L .77315 .50465 L .75 .494 .544 r
F
.77364 .50474 m .77344 .50471 L .77254 .49697 L F
.77256 .49714 m .77344 .50471 L .77255 .49714 L F
.7675 .50611 m .76743 .50541 L .76845 .50555 L .73 .482 .552 r
F
.7701 .50307 m .76823 .50552 L .76989 .50573 L .644 .737 .917 r
F
.76984 .50244 m .7675 .50611 L .77237 .50651 L .667 .748 .911 r
F
.77377 .50477 m .77108 .50593 L .77083 .50904 L .643 .738 .918 r
F
.7728 .50459 m .77108 .50593 L .77377 .50477 L F
.77344 .50471 m .7775 .5398 L .77343 .5047 L .75 .494 .544 r
F
.77344 .50471 m .77343 .5047 L .77255 .49714 L F
.77456 .49506 m .77308 .49737 L .77328 .49746 L .667 .748 .911 r
F
.77309 .49722 m .77388 .50479 L .7728 .49718 L .75 .494 .544 r
F
.77388 .50479 m .7775 .5398 L .77364 .50474 L F
.77388 .50479 m .77364 .50474 L .7728 .49718 L F
.77077 .49483 m .77135 .50246 L .77077 .49483 L 0 0 .196 r
F
.7728 .50459 m .77113 .50531 L .77108 .50593 L .643 .738 .918 r
F
.77075 .49475 m .77135 .50255 L .77076 .49464 L 0 0 .196 r
F
.77164 .50438 m .77119 .50459 L .7728 .50459 L .643 .738 .918 r
F
.77119 .50459 m .77115 .50505 L .7728 .50459 L F
.7687 .50574 m .76798 .50667 L .7728 .50459 L F
.77156 .50515 m .77435 .53858 L .77182 .50861 L .966 .687 .262 r
F
.77249 .50434 m .77237 .50429 L .77159 .49652 L .848 .57 .516 r
F
.77111 .49628 m .77179 .50383 L .77102 .4962 L .941 .646 .452 r
F
.77123 .49639 m .77161 .49673 L .7722 .5042 L F
.77161 .49673 m .77237 .50429 L .7722 .5042 L .848 .57 .516 r
F
.77162 .49673 m .77237 .50429 L .77161 .49673 L F
.77194 .49687 m .77315 .50465 L .77264 .50441 L F
.77195 .49687 m .77315 .50465 L .77194 .49687 L F
.77179 .50383 m .77171 .50376 L .771 .49598 L .941 .646 .452 r
F
.77046 .49842 m .75594 .50983 L .77045 .49852 L .644 .737 .917 r
F
.76311 .50495 m .76421 .50444 L .7675 .50611 L .794 .529 .538 r
F
.76421 .50444 m .76743 .50541 L .7675 .50611 L F
.76282 .50488 m .75594 .50983 L .75841 .51058 L .644 .737 .917 r
F
.76282 .50488 m .75841 .51058 L .76325 .51204 L F
.75594 .50983 m .73722 .52454 L .75173 .52888 L F
.7499 .5066 m .73722 .52454 L .75594 .50983 L F
.7499 .5066 m .72516 .51818 L .73722 .52454 L F
.76691 .50167 m .7675 .50611 L .76984 .50244 L .667 .748 .911 r
F
.76311 .50495 m .76303 .50408 L .76421 .50444 L .794 .529 .538 r
F
.76691 .50167 m .76311 .50495 L .7675 .50611 L .667 .748 .911 r
F
.76965 .5053 m .7456 .51043 L .74998 .51446 L .643 .738 .918 r
F
.77433 .49733 m .7752 .50491 L .77412 .49736 L .648 .416 .554 r
F
.7752 .50491 m .77503 .50492 L .77412 .49736 L F
.77195 .49687 m .77255 .49714 L .77315 .50465 L .848 .57 .516 r
F
.77412 .49736 m .77328 .49746 L .77404 .4978 L .667 .748 .911 r
F
.77309 .49722 m .77412 .49736 L .77472 .50494 L .75 .494 .544 r
F
.77309 .49722 m .77472 .50494 L .77388 .50479 L F
.771 .49598 m .77171 .50376 L .7716 .50366 L .941 .646 .452 r
F
.77192 .49667 m .77264 .50441 L .77174 .49659 L .848 .57 .516 r
F
.77264 .50441 m .77249 .50434 L .77174 .49659 L F
.77438 .49733 m .77524 .5049 L .77433 .49733 L .648 .416 .554 r
F
.77473 .50494 m .77566 .50511 L .77573 .50487 L .643 .738 .918 r
F
.77519 .50691 m .77524 .50696 L .77555 .50579 L F
.77555 .50579 m .77524 .50696 L .77574 .50588 L F
.77524 .50696 m .7754 .5071 L .77574 .50588 L F
.77541 .50711 m .77577 .50743 L .77611 .50635 L F
.77539 .50713 m .77577 .50743 L .77541 .50711 L F
.77524 .5049 m .77917 .53961 L .7752 .50491 L .648 .416 .554 r
F
.77524 .5049 m .7752 .50491 L .77433 .49733 L F
.77411 .49726 m .77503 .50492 L .77472 .50494 L F
.77473 .50494 m .77473 .50494 L .77573 .50487 L .643 .738 .918 r
F
.77566 .50511 m .77549 .50576 L .77573 .50512 L F
.77549 .50576 m .77555 .50579 L .77573 .50512 L F
.77555 .50579 m .77574 .50588 L .77587 .50542 L F
.77455 .49722 m .77448 .49732 L .77453 .49733 L .644 .737 .917 r
F
.77468 .49721 m .77549 .50488 L .77437 .49724 L .648 .416 .554 r
F
.77549 .50488 m .77917 .53961 L .77524 .5049 L F
.77549 .50488 m .77524 .5049 L .77437 .49724 L F
.77675 .50479 m .77611 .50635 L .77712 .50527 L .643 .738 .918 r
F
.77512 .49723 m .77493 .49747 L .77518 .49751 L .667 .748 .911 r
F
.77468 .49729 m .77577 .49715 L .77638 .50482 L .648 .416 .554 r
F
.77468 .49729 m .77638 .50482 L .77549 .50488 L F
.77614 .49702 m .7769 .50466 L .77594 .49708 L .544 .339 .553 r
F
.77638 .50482 m .77611 .50635 L .77675 .50479 L .643 .738 .918 r
F
.77573 .50487 m .77577 .50501 L .77638 .50482 L F
.77577 .50501 m .77611 .50635 L .77638 .50482 L F
.77611 .50635 m .77984 .52076 L .77712 .50527 L F
.77638 .50482 m .78029 .53921 L .77917 .53961 L .544 .339 .553 r
F
.77576 .49714 m .77658 .50476 L .77638 .50482 L F
.77658 .50476 m .78029 .53921 L .77638 .50482 L F
.7769 .50466 m .77673 .50471 L .77594 .49708 L F
.77594 .49708 m .77673 .50471 L .77576 .49714 L F
.7767 .50472 m .77638 .50482 L .77675 .50479 L .643 .738 .918 r
F
.77673 .50471 m .78029 .53921 L .77658 .50476 L .544 .339 .553 r
F
.77673 .50471 m .77658 .50476 L .77576 .49714 L F
.77688 .50467 m .77675 .50479 L .77698 .50478 L .643 .738 .918 r
F
.77517 .50273 m .7767 .50472 L .77688 .50467 L F
.7767 .50472 m .77675 .50479 L .77688 .50467 L F
.77758 .50443 m .77698 .50478 L .77797 .50471 L F
.77814 .50554 m .78217 .51187 L .77825 .50519 L F
.77724 .50514 m .77795 .50611 L .77762 .50473 L F
.77795 .50611 m .78217 .51187 L .77814 .50554 L F
.77795 .50611 m .77814 .50554 L .77762 .50473 L F
.77825 .49563 m .77891 .50321 L .77821 .49574 L 0 0 .362 r
F
.77681 .50487 m .77712 .50527 L .77698 .50478 L .643 .738 .918 r
F
.77712 .50527 m .78217 .51187 L .77724 .50514 L F
.77712 .50527 m .77724 .50514 L .77698 .50478 L F
.77771 .49628 m .77843 .50387 L .77768 .49632 L .231 .113 .505 r
F
.77797 .50471 m .78217 .51187 L .7803 .50635 L .643 .738 .918 r
F
.77687 .49679 m .77764 .50439 L .77749 .50448 L .424 .252 .542 r
F
.77717 .49893 m .7774 .49933 L .77732 .49846 L .644 .737 .917 r
F
.7774 .49933 m .77775 .4999 L .77732 .49846 L F
.77732 .49846 m .77775 .4999 L .77746 .49802 L F
.77715 .49663 m .7783 .50401 L .77787 .50426 L .424 .252 .542 r
F
.78774 .5115 m .81454 .52288 L .79494 .50897 L .644 .737 .917 r
F
.7797 .50459 m .79513 .51684 L .80103 .51334 L .643 .738 .918 r
F
.77659 .49688 m .77739 .49663 L .77746 .49655 L .644 .737 .917 r
F
.77715 .49663 m .77787 .50426 L .777 .49672 L .424 .252 .542 r
F
.77787 .50426 m .77774 .50433 L .777 .49672 L F
.77768 .49632 m .7784 .5039 L .77767 .49632 L .231 .113 .505 r
F
.77829 .50401 m .7803 .50635 L .7797 .50459 L .643 .738 .918 r
F
.77777 .50457 m .7803 .50635 L .77829 .50401 L F
.7784 .5039 m .77839 .5039 L .77767 .49632 L .231 .113 .505 r
F
.77843 .50387 m .7784 .5039 L .77768 .49632 L F
.77785 .496 m .77855 .50374 L .77775 .49612 L F
.77855 .50374 m .77846 .50383 L .77775 .49612 L F
.77739 .49663 m .77749 .4966 L .77746 .49655 L .644 .737 .917 r
F
.77685 .49721 m .77749 .4966 L .77739 .49663 L F
.77715 .49663 m .77767 .49632 L .7783 .50401 L .424 .252 .542 r
F
.78352 .49833 m .79617 .50824 L .80083 .50547 L .644 .737 .917 r
F
.81412 .51494 m .83326 .5286 L .85088 .51842 L .644 .736 .916 r
F
.81412 .51494 m .85088 .51842 L .82583 .50805 L F
.79494 .50897 m .81454 .52288 L .82634 .51598 L .644 .737 .917 r
F
.79494 .50897 m .82634 .51598 L .80083 .50547 L F
.77937 .50362 m .80103 .51334 L .80521 .50911 L .643 .738 .918 r
F
.77767 .49632 m .77839 .5039 L .7783 .50401 L .231 .113 .505 r
F
.77746 .49655 m .77785 .49683 L .77794 .49603 L .644 .737 .917 r
F
.77776 .49623 m .77846 .50383 L .77771 .49628 L .231 .113 .505 r
F
.77846 .50383 m .77843 .50387 L .7777 .49618 L F
.777 .49672 m .77774 .50433 L .77687 .49679 L .424 .252 .542 r
F
.77774 .50433 m .77764 .50439 L .77687 .49679 L F
.77517 .50273 m .77777 .50457 L .77829 .50401 L .643 .738 .918 r
F
.77762 .50473 m .77814 .50554 L .77797 .50471 L F
.77774 .50433 m .7811 .53869 L .77764 .50439 L .424 .252 .542 r
F
.77907 .50356 m .7797 .50459 L .77937 .50362 L .643 .738 .918 r
F
.77786 .49612 m .77821 .49574 L .77883 .50343 L .231 .113 .505 r
F
.77877 .5035 m .7783 .50401 L .77907 .50356 L .643 .738 .918 r
F
.77829 .50401 m .7797 .50459 L .77907 .50356 L F
.77786 .49612 m .77883 .50343 L .77855 .50374 L .231 .113 .505 r
F
.77891 .50321 m .77888 .5033 L .77821 .49574 L 0 0 .362 r
F
.77821 .49574 m .77888 .5033 L .77883 .50343 L F
.82583 .50805 m .85088 .51842 L .86362 .50596 L .644 .736 .916 r
F
.82583 .50805 m .86362 .50596 L .83422 .49967 L F
.80051 .49757 m .82583 .50805 L .83422 .49967 L F
.80083 .50547 m .82634 .51598 L .83479 .50758 L .644 .737 .917 r
F
.80083 .50547 m .83479 .50758 L .805 .50122 L F
.78029 .503 m .80521 .50911 L .80736 .50442 L .643 .738 .918 r
F
.77894 .5031 m .77891 .50321 L .77825 .49563 L 0 0 .362 r
F
.77894 .5031 m .77825 .49563 L .77825 .49563 L F
.77829 .4955 m .77907 .50273 L .77894 .5031 L F
.77829 .4955 m .77894 .5031 L .77825 .49563 L F
.7783 .49448 m .77856 .49444 L .77811 .49391 L .667 .748 .911 r
F
.77832 .49453 m .77813 .4941 L .77833 .49471 L .919 .662 .17 r
F
.77813 .49395 m .77813 .4941 L .77832 .49453 L F
.77503 .49483 m .77861 .49448 L .77805 .49404 L .644 .737 .917 r
F
.77517 .50273 m .77937 .50362 L .77914 .50294 L .643 .738 .918 r
F
.77855 .50374 m .77883 .50343 L .78164 .53807 L .231 .113 .505 r
F
.77517 .50273 m .7783 .50401 L .77877 .5035 L .643 .738 .918 r
F
.7784 .5039 m .78164 .53807 L .77839 .5039 L .231 .113 .505 r
F
.77843 .50387 m .78164 .53807 L .7784 .5039 L F
.77883 .50343 m .78188 .53733 L .78164 .53807 L 0 0 .362 r
F
.77888 .5033 m .78188 .53733 L .77883 .50343 L F
.77855 .50374 m .78164 .53807 L .77846 .50383 L .231 .113 .505 r
F
.77698 .50478 m .77724 .50514 L .77762 .50473 L .643 .738 .918 r
F
.77749 .50448 m .7811 .53869 L .78029 .53921 L .424 .252 .542 r
F
.77764 .50439 m .7811 .53869 L .77749 .50448 L F
.77814 .50554 m .77825 .50519 L .77797 .50471 L .643 .738 .918 r
F
.77787 .50426 m .7783 .50401 L .7811 .53869 L .424 .252 .542 r
F
.7783 .50401 m .77933 .51449 L .77982 .52282 L .231 .113 .505 r
F
.77933 .51449 m .78164 .53807 L .77982 .52282 L F
.77982 .52282 m .78164 .53807 L .7811 .53869 L F
.77839 .5039 m .78164 .53807 L .7783 .50401 L F
.77787 .50426 m .7811 .53869 L .77774 .50433 L .424 .252 .542 r
F
.77846 .50383 m .78164 .53807 L .77843 .50387 L .231 .113 .505 r
F
.77778 .49366 m .77714 .49318 L .77716 .49334 L .921 .628 .471 r
F
.77753 .49347 m .77879 .49369 L .77774 .49336 L .667 .748 .911 r
F
.77774 .49336 m .78022 .49323 L .77832 .49306 L F
.77879 .49369 m .78022 .49323 L .77774 .49336 L F
.77832 .49306 m .78048 .49315 L .77963 .49236 L F
.78022 .49323 m .78048 .49315 L .77832 .49306 L F
.78421 .49274 m .79178 .49191 L .78585 .4909 L .667 .747 .91 r
F
.79219 .495 m .79187 .49192 L .79312 .48894 L 0 0 .437 r
F
.78585 .4909 m .79178 .49191 L .79303 .48894 L .667 .747 .91 r
F
.78585 .4909 m .79303 .48894 L .78667 .48892 L F
.7799 .48989 m .78585 .4909 L .78667 .48892 L F
.79219 .495 m .79312 .48894 L .79344 .49203 L 0 0 .437 r
F
.78024 .49298 m .78622 .49399 L .78705 .49201 L .667 .747 .91 r
F
.79344 .49203 m .79312 .48894 L .79307 .48595 L 0 0 .158 r
F
.78667 .48892 m .79303 .48894 L .79298 .48596 L .667 .747 .91 r
F
.78024 .49298 m .78705 .49201 L .78065 .49199 L F
.79344 .49203 m .79307 .48595 L .79339 .48903 L 0 0 .158 r
F
.79377 .49511 m .79344 .49203 L .79339 .48903 L F
.78705 .49201 m .79344 .49203 L .79339 .48903 L .667 .747 .91 r
F
.78705 .49201 m .79339 .48903 L .78701 .49001 L F
.78065 .49199 m .78705 .49201 L .78701 .49001 L F
.78065 .49199 m .78701 .49001 L .78063 .49099 L F
.7799 .48989 m .78667 .48892 L .78031 .4889 L F
.78031 .4889 m .78667 .48892 L .78663 .48694 L F
.78063 .49099 m .78701 .49001 L .7861 .48815 L F
.78667 .48892 m .79298 .48596 L .78663 .48694 L F
.78663 .48694 m .79298 .48596 L .79163 .48317 L F
.79339 .48903 m .79307 .48595 L .79172 .48314 L .961 .673 .245 r
F
.79377 .49511 m .79339 .48903 L .79372 .49212 L 0 0 .158 r
F
.78701 .49001 m .79204 .48623 L .7861 .48815 L .667 .747 .91 r
F
.78701 .49001 m .79339 .48903 L .79204 .48623 L F
.78094 .49408 m .78641 .49124 L .78048 .49315 L .667 .748 .911 r
F
.78622 .49399 m .79344 .49203 L .78705 .49201 L .667 .747 .91 r
F
.78094 .49408 m .78733 .4931 L .78641 .49124 L .667 .748 .911 r
F
.79339 .48903 m .79172 .48314 L .79204 .48623 L .961 .673 .245 r
F
.79372 .49212 m .79339 .48903 L .79204 .48623 L F
.78733 .4931 m .79236 .48932 L .78641 .49124 L .667 .748 .911 r
F
.79251 .49809 m .79219 .495 L .79344 .49203 L 0 0 .437 r
F
.78622 .49399 m .79219 .495 L .79344 .49203 L .667 .747 .91 r
F
.79251 .49809 m .79344 .49203 L .79377 .49511 L 0 0 .437 r
F
.78733 .4931 m .79372 .49212 L .79236 .48932 L .667 .748 .911 r
F
.78048 .49315 m .78469 .48963 L .77962 .49235 L F
.78048 .49315 m .78641 .49124 L .78469 .48963 L F
.79372 .49212 m .79204 .48623 L .79236 .48932 L .961 .673 .245 r
F
.78663 .48694 m .79163 .48317 L .78572 .48508 L .667 .747 .91 r
F
.78572 .48508 m .79163 .48317 L .78906 .48076 L F
.7861 .48815 m .79204 .48623 L .78946 .48381 L F
.78641 .49124 m .78978 .48691 L .78469 .48963 L .667 .748 .911 r
F
.78641 .49124 m .79236 .48932 L .78978 .48691 L F
.79236 .48932 m .79204 .48623 L .78946 .48381 L .947 .647 .435 r
F
.79236 .48932 m .78946 .48381 L .78978 .48691 L F
.77755 .49365 m .80488 .48701 L .80059 .48287 L .644 .737 .917 r
F
.77503 .49483 m .77805 .49404 L .77755 .49365 L F
.77797 .4938 m .77798 .49399 L .77797 .4938 L .921 .628 .471 r
F
.77805 .49386 m .77806 .49405 L .77811 .49391 L F
.77827 .49451 m .77934 .49506 L .77861 .49448 L .644 .737 .917 r
F
.77503 .49483 m .77843 .49501 L .77827 .49451 L F
.77838 .49471 m .77839 .49489 L .77843 .49486 L .919 .662 .17 r
F
.77839 .49489 m .77844 .49503 L .77843 .49486 L F
.77832 .49453 m .77833 .49471 L .77838 .49471 L F
.77833 .49471 m .77839 .49489 L .77838 .49471 L F
.77843 .49501 m .77934 .49506 L .77827 .49451 L .644 .737 .917 r
F
.77839 .49489 m .77897 .50244 L .77844 .49503 L .919 .662 .17 r
F
.77806 .49405 m .77851 .50161 L .77812 .4941 L .921 .628 .471 r
F
.77851 .50161 m .77857 .50165 L .77812 .4941 L F
.77806 .49405 m .77812 .4941 L .77811 .49391 L F
.80464 .49334 m .83422 .49967 L .83866 .49032 L .644 .736 .916 r
F
.80051 .49757 m .83422 .49967 L .80464 .49334 L F
.80464 .49334 m .83866 .49032 L .80677 .48865 L F
.78653 .49708 m .79251 .49809 L .79377 .49511 L .667 .748 .911 r
F
.78653 .49708 m .79377 .49511 L .78737 .49509 L F
.78737 .49509 m .79377 .49511 L .79372 .49212 L F
.78737 .49509 m .79372 .49212 L .78733 .4931 L F
.78096 .49508 m .78737 .49509 L .78733 .4931 L F
.78096 .49508 m .78733 .4931 L .78094 .49408 L F
.77861 .49448 m .80715 .49652 L .80712 .49167 L .644 .737 .917 r
F
.77934 .49506 m .80715 .49652 L .77861 .49448 L F
.77881 .49367 m .77898 .4942 L .77942 .4939 L .667 .747 .91 r
F
.77856 .49444 m .78094 .49408 L .77879 .49369 L .667 .748 .911 r
F
.77779 .49384 m .77798 .49399 L .77797 .4938 L .921 .628 .471 r
F
.77779 .49384 m .77797 .4938 L .77778 .49366 L F
.77805 .49404 m .80488 .48701 L .77755 .49365 L .644 .737 .917 r
F
.77813 .4941 m .77857 .50166 L .77875 .5018 L .921 .628 .471 r
F
.77812 .4941 m .77857 .50165 L .77813 .4941 L F
.77857 .50165 m .77857 .50166 L .77813 .4941 L F
.77805 .49404 m .80712 .49167 L .80488 .48701 L .644 .737 .917 r
F
.77811 .49391 m .77812 .4941 L .77813 .4941 L .921 .628 .471 r
F
.77861 .49448 m .80712 .49167 L .77805 .49404 L .644 .737 .917 r
F
.77833 .49471 m .77813 .4941 L .77875 .5018 L .919 .662 .17 r
F
.77833 .49471 m .77875 .5018 L .77892 .50229 L F
.77456 .49506 m .77695 .49669 L .77767 .49622 L .667 .748 .911 r
F
.7777 .49618 m .77771 .49628 L .77767 .49622 L .231 .113 .505 r
F
.77771 .49628 m .77768 .49632 L .77767 .49622 L F
.77767 .49622 m .77768 .49632 L .77767 .49632 L F
.77503 .49483 m .77746 .49655 L .77794 .49603 L .644 .737 .917 r
F
.77778 .49366 m .77778 .50104 L .7783 .50144 L .921 .628 .471 r
F
.77844 .49503 m .77901 .50255 L .77844 .49504 L .919 .662 .17 r
F
.77901 .50255 m .77901 .50256 L .77844 .49504 L F
.77844 .49504 m .77901 .50256 L .77907 .50273 L F
.77897 .50244 m .77901 .50255 L .77843 .49486 L F
.77843 .49501 m .805 .50122 L .80715 .49652 L .644 .737 .917 r
F
.77863 .4956 m .805 .50122 L .77843 .49501 L F
.77833 .49471 m .77892 .50229 L .77839 .49489 L .919 .662 .17 r
F
.77517 .50273 m .77875 .5018 L .77816 .50134 L .643 .738 .918 r
F
.77798 .49399 m .77845 .50156 L .77806 .49405 L .921 .628 .471 r
F
.77614 .49701 m .77687 .49674 L .77687 .49679 L .544 .339 .553 r
F
.77687 .49674 m .77696 .49671 L .77695 .49669 L .667 .748 .911 r
F
.77699 .49666 m .777 .49672 L .77699 .49666 L .424 .252 .542 r
F
.77687 .49674 m .777 .49672 L .77687 .49679 L F
.77699 .49666 m .777 .49672 L .77687 .49674 L F
.77503 .49483 m .77659 .49688 L .77746 .49655 L .644 .737 .917 r
F
.77503 .49483 m .77527 .49576 L .77649 .49702 L F
.77503 .49483 m .77649 .49702 L .77663 .49693 L F
.77649 .48762 m .77715 .48436 L .77573 .48424 L .667 .747 .91 r
F
.77663 .48825 m .77715 .48436 L .77649 .48762 L F
.77898 .48618 m .78161 .48224 L .77777 .48557 L F
.77777 .48557 m .78161 .48224 L .77868 .48146 L F
.77663 .48825 m .77901 .48451 L .77715 .48436 L F
.77568 .48973 m .77607 .48981 L .77591 .48937 L F
.77607 .48981 m .77663 .48991 L .77655 .48985 L F
.77607 .48981 m .77655 .48985 L .77591 .48937 L F
.77553 .48976 m .77572 .49281 L .77563 .48977 L .734 .481 .546 r
F
.77653 .49 m .77663 .48991 L .77568 .48973 L .667 .747 .91 r
F
.77768 .48951 m .7777 .48948 L .77788 .48889 L F
.77785 .48851 m .77762 .4878 L .77786 .49085 L .919 .662 .17 r
F
.77785 .48851 m .77786 .49085 L .77799 .49122 L F
.7769 .49012 m .77931 .48926 L .77663 .48991 L .667 .747 .91 r
F
.77723 .49037 m .77741 .49028 L .7769 .49012 L F
.77741 .49028 m .77931 .48926 L .7769 .49012 L F
.77505 .49252 m .77694 .49134 L .7753 .4912 L .667 .748 .911 r
F
.77599 .49282 m .77694 .49134 L .77505 .49252 L F
.77653 .49 m .7769 .49012 L .77663 .48991 L .667 .747 .91 r
F
.77663 .48991 m .77931 .48926 L .7781 .48864 L F
.77785 .48851 m .77788 .4889 L .7779 .48866 L .919 .662 .17 r
F
.77591 .48937 m .7781 .48864 L .77663 .48825 L .667 .747 .91 r
F
.77788 .4889 m .77791 .4888 L .7779 .48866 L .919 .662 .17 r
F
.77663 .48991 m .7781 .48864 L .77591 .48937 L .667 .747 .91 r
F
.77723 .49037 m .78003 .4901 L .77931 .48926 L F
.77782 .49082 m .78003 .4901 L .77723 .49037 L F
.77778 .48829 m .77808 .48825 L .77776 .48823 L F
.77753 .48773 m .77811 .48817 L .77832 .48747 L F
.77832 .48747 m .78029 .48791 L .77983 .48698 L F
.77808 .48825 m .78029 .48791 L .77832 .48747 L F
.77778 .48829 m .77793 .48874 L .77808 .48825 L F
.77788 .48889 m .78031 .4889 L .77808 .48825 L F
.77983 .48698 m .78401 .48348 L .77898 .48618 L F
.77898 .48618 m .78401 .48348 L .78161 .48224 L F
.78029 .48791 m .78572 .48508 L .77983 .48698 L F
.77983 .48698 m .78572 .48508 L .78401 .48348 L F
.77931 .48926 m .78196 .4853 L .7781 .48864 L F
.7781 .48864 m .77901 .48451 L .77663 .48825 L F
.7781 .48864 m .78196 .4853 L .77901 .48451 L F
.78401 .48348 m .78546 .4789 L .78161 .48224 L F
.78401 .48348 m .78906 .48076 L .78546 .4789 L F
.78161 .48224 m .78105 .47773 L .77868 .48146 L F
.78161 .48224 m .78546 .4789 L .78105 .47773 L F
.77566 .48977 m .77585 .48979 L .77568 .48973 L F
.77694 .49134 m .77604 .48733 L .7753 .4912 L .667 .748 .911 r
F
.77694 .49134 m .77932 .48761 L .77604 .48733 L F
.77868 .48146 m .77616 .47731 L .77542 .48119 L .667 .747 .91 r
F
.77868 .48146 m .78105 .47773 L .77616 .47731 L F
.78572 .48508 m .78906 .48076 L .78401 .48348 L F
.78946 .48381 m .78914 .48072 L .78551 .47885 L .868 .583 .504 r
F
.78196 .4853 m .7814 .48076 L .77901 .48451 L .667 .747 .91 r
F
.78196 .4853 m .78583 .48194 L .7814 .48076 L F
.77901 .48451 m .77648 .48035 L .77573 .48424 L F
.77901 .48451 m .7814 .48076 L .77648 .48035 L F
.78946 .48381 m .78551 .47885 L .78583 .48194 L .868 .583 .504 r
F
.78583 .48194 m .78551 .47885 L .78109 .47767 L .795 .528 .533 r
F
.78031 .4889 m .78663 .48694 L .78029 .48791 L .667 .747 .91 r
F
.78029 .48791 m .78663 .48694 L .78572 .48508 L F
.78017 .49006 m .78438 .48654 L .77931 .48926 L F
.78017 .49006 m .7861 .48815 L .78438 .48654 L F
.77931 .48926 m .78438 .48654 L .78196 .4853 L F
.78227 .48839 m .78171 .48386 L .77932 .48761 L .667 .748 .911 r
F
.7861 .48815 m .78946 .48381 L .78438 .48654 L .667 .747 .91 r
F
.78438 .48654 m .78583 .48194 L .78196 .4853 L F
.78438 .48654 m .78946 .48381 L .78583 .48194 L F
.78227 .48839 m .78615 .48504 L .78171 .48386 L .667 .748 .911 r
F
.77932 .48761 m .77679 .48345 L .77604 .48733 L F
.77932 .48761 m .78171 .48386 L .77679 .48345 L F
.7814 .48076 m .78109 .47767 L .77617 .47725 L .731 .48 .548 r
F
.78583 .48194 m .78109 .47767 L .7814 .48076 L .795 .528 .533 r
F
.78615 .48504 m .78583 .48194 L .7814 .48076 L F
.7814 .48076 m .77617 .47725 L .77648 .48035 L .731 .48 .548 r
F
.78171 .48386 m .7814 .48076 L .77648 .48035 L F
.78615 .48504 m .7814 .48076 L .78171 .48386 L .795 .528 .533 r
F
.78171 .48386 m .77648 .48035 L .77679 .48345 L .731 .48 .548 r
F
.77546 .49274 m .78708 .47723 L .77881 .47615 L .644 .737 .917 r
F
.77503 .49483 m .77627 .49303 L .77611 .49297 L F
.77471 .49482 m .7761 .49285 L .77598 .49284 L .667 .748 .911 r
F
.77503 .49483 m .77611 .49297 L .77559 .4929 L .644 .737 .917 r
F
.77572 .49281 m .77573 .49292 L .7761 .49285 L .734 .481 .546 r
F
.7794 .5023 m .78098 .50216 L .78094 .50215 L .643 .738 .918 r
F
.77892 .50229 m .77897 .50244 L .77838 .49471 L .919 .662 .17 r
F
.77517 .50273 m .77942 .50232 L .7794 .5023 L .643 .738 .918 r
F
.77942 .50232 m .78098 .50216 L .7794 .5023 L F
.77779 .49384 m .7783 .50144 L .77798 .49399 L .921 .628 .471 r
F
.79105 .49825 m .80358 .50267 L .805 .50122 L .644 .737 .917 r
F
.83422 .49967 m .87054 .492 L .83866 .49032 L .644 .736 .916 r
F
.805 .50122 m .83927 .49821 L .80715 .49652 L .644 .737 .917 r
F
.78088 .50124 m .80729 .4995 L .78482 .50022 L .643 .738 .918 r
F
.77678 .49306 m .7761 .49285 L .77611 .49297 L .811 .54 .528 r
F
.77678 .49306 m .77611 .49297 L .77678 .49321 L F
.77599 .49282 m .77693 .49301 L .77621 .49247 L .667 .748 .911 r
F
.77684 .49308 m .77693 .49301 L .77599 .49282 L F
.77621 .49247 m .77841 .49173 L .77694 .49134 L F
.77693 .49301 m .77841 .49173 L .77621 .49247 L F
.77782 .49082 m .77786 .49085 L .77785 .49081 L .667 .747 .91 r
F
.77785 .49081 m .77842 .49101 L .77856 .49058 L F
.77842 .49101 m .77907 .49123 L .77856 .49058 L F
.77804 .49139 m .77907 .49123 L .77785 .49081 L F
.77907 .49123 m .78063 .49099 L .78003 .4901 L F
.78003 .4901 m .78017 .49006 L .78011 .49 L F
.78003 .4901 m .78011 .49 L .77931 .48926 L F
.78063 .49099 m .7861 .48815 L .78017 .49006 L F
.79204 .48623 m .79172 .48314 L .78914 .48072 L .947 .647 .435 r
F
.77962 .49235 m .78227 .48839 L .77841 .49173 L .667 .748 .911 r
F
.77962 .49235 m .78469 .48963 L .78227 .48839 L F
.77841 .49173 m .77932 .48761 L .77694 .49134 L F
.77841 .49173 m .78227 .48839 L .77932 .48761 L F
.79204 .48623 m .78914 .48072 L .78946 .48381 L .947 .647 .435 r
F
.78469 .48963 m .78615 .48504 L .78227 .48839 L .667 .748 .911 r
F
.78469 .48963 m .78978 .48691 L .78615 .48504 L F
.78978 .48691 m .78946 .48381 L .78583 .48194 L .868 .583 .504 r
F
.78978 .48691 m .78583 .48194 L .78615 .48504 L F
.77627 .49303 m .79451 .47953 L .78708 .47723 L .644 .737 .917 r
F
.77503 .49483 m .777 .49329 L .77627 .49303 L F
.77678 .49306 m .77678 .49321 L .77679 .49322 L .811 .54 .528 r
F
.77693 .49301 m .77962 .49235 L .77841 .49173 L .667 .748 .911 r
F
.77684 .49308 m .77697 .49305 L .77693 .49301 L F
.77697 .49305 m .77962 .49235 L .77693 .49301 L F
.77679 .49322 m .77699 .49329 L .77698 .49313 L .811 .54 .528 r
F
.77679 .49322 m .77698 .49313 L .77679 .49307 L F
.7777 .49335 m .77962 .49235 L .77684 .49308 L .667 .748 .911 r
F
.77678 .49306 m .77679 .49322 L .77679 .49307 L .811 .54 .528 r
F
.77517 .50273 m .78094 .50215 L .77944 .50162 L .643 .738 .918 r
F
.77778 .49366 m .77716 .49334 L .77778 .49383 L .921 .628 .471 r
F
.77503 .49483 m .77776 .49356 L .777 .49329 L .644 .737 .917 r
F
.77745 .50092 m .77758 .50097 L .77714 .49318 L .811 .54 .528 r
F
.77517 .50273 m .77816 .50134 L .77778 .50104 L .643 .738 .918 r
F
.77517 .50273 m .77778 .50104 L .77748 .50093 L F
.77517 .50273 m .77829 .50401 L .7783 .50401 L F
.77675 .50479 m .77681 .50487 L .77698 .50478 L F
.77517 .50273 m .77698 .50478 L .77758 .50443 L F
.7769 .50466 m .78029 .53921 L .77673 .50471 L .544 .339 .553 r
F
.7769 .50466 m .77749 .50448 L .78029 .53921 L F
.83422 .49967 m .86362 .50596 L .87054 .492 L .644 .736 .916 r
F
.805 .50122 m .83479 .50758 L .83927 .49821 L .644 .737 .917 r
F
.78481 .50179 m .80736 .50442 L .80733 .49959 L .643 .738 .918 r
F
.77517 .50273 m .80163 .50412 L .78481 .50179 L F
.80163 .50412 m .80736 .50442 L .78481 .50179 L F
.77611 .49297 m .77652 .50064 L .77672 .50067 L .734 .481 .546 r
F
.77679 .49322 m .77672 .50067 L .77729 .50087 L .811 .54 .528 r
F
.77678 .49321 m .77672 .50067 L .77679 .49322 L F
.77517 .50273 m .77756 .50087 L .77743 .50077 L .643 .738 .918 r
F
.77661 .50065 m .77743 .50077 L .77684 .50031 L F
.77517 .50273 m .77743 .50077 L .77661 .50065 L F
.7761 .49297 m .77652 .50064 L .77611 .49297 L .734 .481 .546 r
F
.77652 .50064 m .77652 .50064 L .77611 .49297 L F
.77495 .49523 m .77449 .49753 L .77527 .49576 L .644 .737 .917 r
F
.77468 .49721 m .77576 .49714 L .77577 .49715 L .648 .416 .554 r
F
.77527 .49576 m .77563 .49715 L .77608 .49711 L .644 .737 .917 r
F
.77456 .49506 m .77515 .49738 L .77604 .49705 L .667 .748 .911 r
F
.77456 .49506 m .77604 .49705 L .77587 .49676 L F
.77573 .49292 m .77621 .5006 L .7761 .49297 L .734 .481 .546 r
F
.77621 .5006 m .77652 .50064 L .7761 .49297 L F
.77678 .49321 m .77611 .49297 L .77672 .50067 L .811 .54 .528 r
F
.77572 .49281 m .77501 .49282 L .77572 .49292 L .734 .481 .546 r
F
.77543 .49288 m .77562 .4928 L .77544 .49281 L .644 .737 .917 r
F
.77503 .49483 m .77559 .4929 L .77543 .49288 L F
.77559 .4929 m .77562 .4928 L .77543 .49288 L F
.77572 .49281 m .775 .49275 L .77501 .49282 L .734 .481 .546 r
F
.77456 .49506 m .77587 .49676 L .77505 .49539 L .667 .748 .911 r
F
.77468 .49721 m .77577 .49715 L .77468 .49729 L .648 .416 .554 r
F
.775 .49275 m .77501 .49282 L .77501 .49282 L .664 .428 .553 r
F
.77233 .48433 m .77219 .48379 L .7717 .48383 L .667 .748 .911 r
F
.77604 .48733 m .77219 .48379 L .77233 .48433 L F
.77542 .48119 m .77616 .47731 L .77111 .47769 L .667 .747 .91 r
F
.77573 .48424 m .77648 .48035 L .7714 .48073 L F
.77604 .48733 m .77679 .48345 L .77219 .48379 L .667 .748 .911 r
F
.77461 .49278 m .77462 .49283 L .77483 .49276 L .664 .428 .553 r
F
.77462 .49283 m .77483 .49283 L .77483 .49276 L F
.77483 .49276 m .77483 .49283 L .77493 .49275 L F
.77483 .49283 m .77493 .49282 L .77493 .49275 L F
.77493 .49275 m .77493 .49282 L .775 .49275 L F
.77503 .49483 m .77544 .49281 L .77452 .49284 L .644 .737 .917 r
F
.77517 .50273 m .77672 .50048 L .77562 .50052 L .643 .738 .918 r
F
.77517 .50273 m .77573 .50487 L .77638 .50482 L F
.77517 .50273 m .77638 .50482 L .7767 .50472 L F
.7752 .50491 m .77917 .53961 L .77503 .50492 L .648 .416 .554 r
F
.77566 .50511 m .77573 .50512 L .77577 .50501 L .643 .738 .918 r
F
.77577 .50501 m .77561 .50557 L .77587 .50542 L F
.77573 .50487 m .77568 .50504 L .77577 .50501 L F
.77549 .50488 m .77638 .50482 L .77917 .53961 L .648 .416 .554 r
F
.77517 .50273 m .77473 .50494 L .77573 .50487 L .643 .738 .918 r
F
.77519 .50691 m .77446 .50968 L .77524 .50696 L F
.77446 .50968 m .77449 .50975 L .77524 .50696 L F
.77472 .50494 m .77917 .53961 L .7775 .5398 L .648 .416 .554 r
F
.77503 .50492 m .77917 .53961 L .77472 .50494 L F
.77503 .49483 m .77495 .49523 L .77527 .49576 L .644 .737 .917 r
F
.77493 .49282 m .77535 .50052 L .77501 .49282 L .664 .428 .553 r
F
.77535 .50052 m .77542 .50052 L .77501 .49282 L F
.77493 .49282 m .77501 .49282 L .775 .49275 L F
.77648 .48035 m .7711 .47764 L .7714 .48073 L .669 .434 .556 r
F
.77648 .48035 m .77617 .47725 L .7711 .47764 L F
.77679 .48345 m .7714 .48073 L .7717 .48383 L F
.77679 .48345 m .77648 .48035 L .7714 .48073 L F
.77452 .49284 m .77881 .47615 L .77027 .47635 L .644 .737 .917 r
F
.775 .49275 m .77561 .4927 L .77505 .49252 L .667 .748 .911 r
F
.77544 .49281 m .77881 .47615 L .77452 .49284 L .644 .737 .917 r
F
.77572 .49292 m .77501 .49282 L .77563 .50052 L .734 .481 .546 r
F
.77572 .49281 m .77563 .50052 L .77621 .5006 L F
.77501 .49282 m .77542 .50052 L .77563 .50052 L .664 .428 .553 r
F
.77698 .49313 m .77699 .49329 L .77714 .49318 L .811 .54 .528 r
F
.777 .49329 m .79451 .47953 L .77627 .49303 L .644 .737 .917 r
F
.77573 .49292 m .7761 .49297 L .7761 .49285 L .734 .481 .546 r
F
.7761 .49285 m .7761 .49297 L .77611 .49297 L F
.77598 .49284 m .7761 .49285 L .77599 .49282 L .667 .748 .911 r
F
.77611 .49297 m .78708 .47723 L .77546 .49274 L .644 .737 .917 r
F
.77627 .49303 m .77629 .493 L .77611 .49297 L F
.77629 .493 m .78708 .47723 L .77611 .49297 L F
.77559 .4929 m .77611 .49297 L .77562 .4928 L F
.77517 .50273 m .77562 .50052 L .77461 .50055 L .643 .738 .918 r
F
.77501 .49282 m .77726 .53524 L .77501 .49282 L .664 .428 .553 r
F
.77544 .49281 m .77562 .4928 L .77546 .49274 L .644 .737 .917 r
F
.77433 .49733 m .77412 .49736 L .77411 .49726 L .648 .416 .554 r
F
.77437 .49724 m .77438 .49733 L .77432 .49724 L F
.77438 .49733 m .77433 .49733 L .77432 .49724 L F
.77456 .49506 m .77412 .49736 L .77512 .49723 L .667 .748 .911 r
F
.77369 .4929 m .77372 .49289 L .77372 .49288 L .585 .369 .554 r
F
.77369 .4929 m .77372 .49288 L .77369 .49289 L F
.77503 .49483 m .77452 .49284 L .77354 .49287 L .644 .737 .917 r
F
.77503 .49483 m .77354 .49287 L .77233 .49291 L F
.77503 .49483 m .77449 .49444 L .77462 .49466 L F
.77503 .49483 m .77462 .49466 L .77467 .49475 L F
.77503 .49483 m .77467 .49475 L .77471 .49481 L F
.77503 .49483 m .77471 .49481 L .77474 .49486 L F
.77503 .49483 m .77474 .49486 L .77476 .4949 L F
.77503 .49483 m .77476 .4949 L .77479 .49495 L F
.77503 .49483 m .77479 .49495 L .77482 .495 L F
.77503 .49483 m .77482 .495 L .77487 .49508 L F
.77456 .49506 m .77488 .49511 L .77485 .49506 L .667 .748 .911 r
F
.77462 .49283 m .7751 .50053 L .77483 .49283 L .664 .428 .553 r
F
.77503 .49483 m .77487 .49508 L .77495 .49523 L .644 .737 .917 r
F
.7751 .50053 m .77527 .50053 L .77483 .49283 L .664 .428 .553 r
F
.77456 .49506 m .77104 .49446 L .77077 .49483 L .667 .748 .911 r
F
.77456 .49506 m .77102 .4962 L .77155 .49667 L F
.77159 .49652 m .77162 .49673 L .77161 .49673 L .848 .57 .516 r
F
.77192 .49667 m .77195 .49687 L .77194 .49687 L F
.77456 .49506 m .77152 .49669 L .77228 .49702 L .667 .748 .911 r
F
.77456 .49506 m .77228 .49702 L .77255 .49714 L F
.77456 .49506 m .77255 .49714 L .77317 .49723 L F
.77456 .49506 m .77328 .49746 L .77412 .49736 L F
.77452 .49284 m .77027 .47635 L .77353 .49285 L .644 .737 .917 r
F
.77452 .49284 m .77353 .49285 L .77355 .49287 L F
.77353 .49285 m .77027 .47635 L .76433 .47742 L F
.77483 .49283 m .77726 .53524 L .77493 .49282 L .664 .428 .553 r
F
.77456 .49506 m .77463 .49469 L .77434 .49421 L .667 .748 .911 r
F
.77456 .49506 m .77434 .49421 L .77304 .49307 L F
.77434 .49421 m .77358 .49292 L .77304 .49307 L F
.76923 .49359 m .76908 .49364 L .76918 .49365 L .667 .747 .91 r
F
.76976 .49375 m .76669 .49309 L .76678 .4944 L .644 .737 .917 r
F
.76915 .49414 m .76938 .49311 L .76856 .49404 L .667 .748 .911 r
F
.77121 .49406 m .77076 .49464 L .77077 .49483 L .159 .061 .485 r
F
.77121 .49406 m .77077 .49483 L .77122 .49422 L F
.77227 .49334 m .77144 .49376 L .77145 .49389 L .454 .273 .545 r
F
.77121 .49406 m .77122 .49422 L .77134 .49389 L .159 .061 .485 r
F
.77122 .49422 m .77135 .49404 L .77134 .49389 L F
.77456 .49506 m .77145 .49389 L .77104 .49446 L .667 .748 .911 r
F
.7712 .49616 m .7722 .5042 L .77188 .50391 L .941 .646 .452 r
F
.77517 .50273 m .77 .50408 L .76965 .5053 L .643 .738 .918 r
F
.77517 .50273 m .77164 .50438 L .7728 .50459 L F
.7722 .5042 m .77592 .53956 L .77496 .53912 L .848 .57 .516 r
F
.77237 .50429 m .77592 .53956 L .7722 .5042 L F
.77179 .50383 m .77496 .53912 L .77171 .50376 L .941 .646 .452 r
F
.7716 .50366 m .77496 .53912 L .77435 .53858 L F
.77171 .50376 m .77496 .53912 L .7716 .50366 L F
.76333 .49793 m .74867 .50546 L .7499 .5066 L .644 .737 .917 r
F
.75948 .50313 m .76052 .50274 L .76311 .50495 L .865 .584 .51 r
F
.76052 .50274 m .76303 .50408 L .76311 .50495 L F
.74553 .50256 m .72516 .51818 L .7499 .5066 L .644 .737 .917 r
F
.76363 .50384 m .76324 .50414 L .76336 .50418 L F
.76449 .50045 m .76311 .50495 L .76691 .50167 L .667 .748 .911 r
F
.75948 .50313 m .75939 .50213 L .76052 .50274 L .865 .584 .51 r
F
.76449 .50045 m .75948 .50313 L .76311 .50495 L .667 .748 .911 r
F
.77 .50408 m .74321 .50585 L .7456 .51043 L .643 .738 .918 r
F
.77047 .49504 m .76816 .49504 L .77075 .49564 L .667 .748 .911 r
F
.77072 .49557 m .77136 .50315 L .77131 .50304 L .966 .687 .262 r
F
.77072 .49557 m .77136 .50315 L .77072 .49557 L F
.7714 .50323 m .77136 .50315 L .77072 .49557 L F
.7714 .50323 m .77072 .49557 L .77072 .49558 L F
.77077 .49567 m .7714 .50323 L .77072 .49558 L F
.7716 .50366 m .77071 .50317 L .77 .50408 L .643 .738 .918 r
F
.77517 .50273 m .77134 .50311 L .7716 .50366 L F
.77134 .50311 m .77071 .50317 L .7716 .50366 L F
.77071 .50317 m .74321 .50585 L .77 .50408 L F
.77122 .49422 m .77173 .50186 L .77135 .49404 L .159 .061 .485 r
F
.77366 .53021 m .77435 .53858 L .77369 .53066 L .966 .687 .262 r
F
.77366 .53021 m .77369 .53066 L .7714 .50323 L F
.77144 .50333 m .77366 .53021 L .7714 .50323 L F
.75688 .50075 m .75766 .50051 L .75948 .50313 L .944 .648 .447 r
F
.75766 .50051 m .75939 .50213 L .75948 .50313 L F
.74553 .50256 m .71637 .5102 L .72516 .51818 L .644 .737 .917 r
F
.74315 .49797 m .71637 .5102 L .74553 .50256 L F
.76276 .49886 m .75948 .50313 L .76449 .50045 L .667 .748 .911 r
F
.76333 .49793 m .75675 .49964 L .75789 .50073 L .644 .737 .917 r
F
.75675 .49964 m .75678 .49969 L .75789 .50073 L F
.76276 .49886 m .75688 .50075 L .75948 .50313 L .667 .748 .911 r
F
.76821 .50341 m .74299 .50104 L .74321 .50585 L .643 .738 .918 r
F
.77135 .50255 m .77135 .50246 L .77076 .49464 L 0 0 .196 r
F
.77076 .49509 m .77134 .50266 L .77077 .49495 L F
.77134 .50266 m .77135 .50255 L .77077 .49495 L F
.77076 .49509 m .77131 .50304 L .77134 .50266 L F
.77076 .4951 m .77131 .50304 L .77076 .49509 L F
.77076 .49504 m .77072 .49557 L .77075 .49564 L .667 .748 .911 r
F
.77076 .4951 m .77072 .49557 L .77131 .50304 L 0 0 .196 r
F
.77145 .49389 m .77055 .49232 L .76938 .49311 L .667 .748 .911 r
F
.77227 .49334 m .77145 .49389 L .77227 .49341 L .454 .273 .545 r
F
.77254 .49319 m .77254 .49326 L .77261 .49316 L F
.77456 .49506 m .77221 .49345 L .77145 .49389 L .667 .748 .911 r
F
.77517 .50273 m .77121 .50252 L .77071 .50317 L .643 .738 .918 r
F
.77517 .50273 m .7728 .50459 L .77377 .50477 L F
.77249 .50434 m .77592 .53956 L .77237 .50429 L .848 .57 .516 r
F
.77315 .50465 m .7775 .5398 L .77592 .53956 L .75 .494 .544 r
F
.77343 .5047 m .7775 .5398 L .77315 .50465 L F
.77264 .50441 m .77315 .50465 L .77592 .53956 L .848 .57 .516 r
F
.77264 .50441 m .77592 .53956 L .77249 .50434 L F
.77254 .49326 m .77262 .49321 L .77261 .49316 L .454 .273 .545 r
F
.77347 .49295 m .7727 .49311 L .7727 .49316 L .585 .369 .554 r
F
.77347 .49295 m .7727 .49316 L .77347 .49295 L F
.77205 .49334 m .77199 .49171 L .77055 .49232 L .667 .748 .911 r
F
.7725 .49321 m .77251 .49328 L .77254 .49319 L .454 .273 .545 r
F
.77456 .49506 m .7727 .49316 L .77221 .49345 L .667 .748 .911 r
F
.75529 .49678 m .74315 .49797 L .75529 .49679 L .644 .737 .917 r
F
.75546 .49798 m .75585 .49787 L .75688 .50075 L .97 .683 .274 r
F
.75675 .49964 m .75673 .49965 L .75678 .49969 L .644 .737 .917 r
F
.75585 .49787 m .75678 .49969 L .75688 .50075 L .97 .683 .274 r
F
.75688 .50075 m .75678 .49969 L .75766 .50051 L .944 .648 .447 r
F
.77073 .49837 m .76691 .50167 L .76984 .50244 L .667 .748 .911 r
F
.76792 .49557 m .75609 .49672 L .76345 .49787 L .644 .737 .917 r
F
.76182 .497 m .75688 .50075 L .76276 .49886 L .667 .748 .911 r
F
.76182 .497 m .75546 .49798 L .75688 .50075 L F
.77007 .50246 m .74496 .49631 L .74299 .50104 L .643 .738 .918 r
F
.77122 .49422 m .77077 .49483 L .77136 .50233 L .159 .061 .485 r
F
.77122 .49422 m .77136 .50233 L .77173 .50186 L F
.77135 .50246 m .77135 .50246 L .77077 .49483 L 0 0 .196 r
F
.77077 .49483 m .77135 .50246 L .77136 .50233 L F
.77517 .50273 m .7712 .50189 L .77007 .50246 L .643 .738 .918 r
F
.76952 .49775 m .76691 .50167 L .77073 .49837 L .667 .748 .911 r
F
.76952 .49775 m .76449 .50045 L .76691 .50167 L F
.7712 .50189 m .74496 .49631 L .77007 .50246 L .643 .738 .918 r
F
.77251 .49328 m .77292 .50101 L .77254 .49326 L .454 .273 .545 r
F
.75654 .49201 m .75613 .49198 L .75535 .495 L 0 0 .418 r
F
.75613 .49198 m .75526 .49403 L .75535 .495 L F
.75535 .495 m .75526 .49403 L .75529 .49496 L 0 0 .117 r
F
.75525 .49379 m .75524 .49346 L .7514 .49359 L .644 .737 .917 r
F
.7514 .49359 m .74489 .4884 L .74292 .49314 L F
.76801 .49552 m .76678 .4944 L .75625 .49668 L F
.75535 .495 m .75529 .49496 L .75546 .49798 L 0 0 .117 r
F
.75529 .49496 m .75537 .49693 L .75546 .49798 L F
.75546 .49798 m .75537 .49693 L .75585 .49787 L .97 .683 .274 r
F
.75625 .49668 m .75529 .49678 L .75609 .49672 L .644 .737 .917 r
F
.75529 .49678 m .75529 .49679 L .75609 .49672 L F
.76801 .49552 m .75625 .49668 L .76794 .49556 L F
.76865 .49696 m .76449 .50045 L .76952 .49775 L .667 .748 .911 r
F
.76865 .49696 m .76276 .49886 L .76449 .50045 L F
.76819 .49603 m .76276 .49886 L .76865 .49696 L F
.76819 .49603 m .76182 .497 L .76276 .49886 L F
.76175 .49502 m .75546 .49798 L .76182 .497 L F
.76175 .49502 m .75535 .495 L .75546 .49798 L F
.76256 .49303 m .75535 .495 L .76175 .49502 L F
.76256 .49303 m .75654 .49201 L .75535 .495 L F
.7712 .50189 m .74902 .49199 L .74496 .49631 L .643 .738 .918 r
F
.77517 .50273 m .77205 .50145 L .7712 .50189 L F
.77135 .49404 m .77184 .50172 L .77145 .4939 L .159 .061 .485 r
F
.77184 .50172 m .77192 .50161 L .77144 .49376 L F
.77221 .49345 m .77145 .49389 L .77145 .49389 L .667 .748 .911 r
F
.77227 .49341 m .77145 .49389 L .77205 .50145 L .454 .273 .545 r
F
.77227 .49341 m .77205 .50145 L .77272 .50111 L F
.77173 .50186 m .77184 .50172 L .77135 .49404 L .159 .061 .485 r
F
.77144 .49376 m .77192 .50161 L .77205 .50145 L F
.77205 .50145 m .74902 .49199 L .7712 .50189 L .643 .738 .918 r
F
.77254 .49326 m .77295 .50099 L .77262 .49321 L .454 .273 .545 r
F
.7593 .48837 m .75892 .48861 L .75672 .49093 L .644 .737 .917 r
F
.75918 .48833 m .74894 .48407 L .75672 .49093 L F
.75897 .48922 m .7584 .48915 L .75654 .49201 L .248 .131 .517 r
F
.7584 .48915 m .75647 .49119 L .75654 .49201 L F
.7567 .49094 m .75658 .49092 L .75647 .49119 L .644 .737 .917 r
F
.7567 .49094 m .75647 .49119 L .7555 .49346 L F
.75658 .49092 m .74489 .4884 L .7555 .49346 L F
.75654 .49201 m .75647 .49119 L .75613 .49198 L 0 0 .418 r
F
.76816 .49504 m .76182 .497 L .76819 .49603 L .667 .748 .911 r
F
.76816 .49504 m .76175 .49502 L .76182 .497 L F
.76856 .49404 m .76175 .49502 L .76816 .49504 L F
.76856 .49404 m .76256 .49303 L .76175 .49502 L F
.76418 .49117 m .75654 .49201 L .76256 .49303 L F
.76418 .49117 m .75897 .48922 L .75654 .49201 L F
.7702 .50069 m .75489 .48839 L .74902 .49199 L .643 .738 .918 r
F
.77517 .50273 m .77281 .50106 L .77205 .50145 L F
.77364 .50474 m .7775 .5398 L .77344 .50471 L .75 .494 .544 r
F
.7727 .49316 m .77308 .50092 L .77331 .50081 L .454 .273 .545 r
F
.77295 .50099 m .77301 .50096 L .77262 .49321 L F
.77292 .50101 m .77295 .50099 L .77254 .49326 L F
.77456 .49506 m .77304 .49307 L .7727 .49316 L .667 .748 .911 r
F
.77347 .49295 m .77331 .50081 L .77394 .50067 L .585 .369 .554 r
F
.77347 .49295 m .77331 .50081 L .77347 .49295 L F
.77347 .49295 m .7727 .49316 L .77331 .50081 L F
.77067 .49631 m .76865 .49696 L .7706 .49718 L .667 .748 .911 r
F
.7706 .49718 m .76952 .49775 L .77052 .49826 L F
.7706 .49718 m .77052 .49826 L .77073 .49837 L F
.76682 .48498 m .76666 .48494 L .76248 .48682 L .525 .329 .558 r
F
.76666 .48494 m .76245 .48645 L .76248 .48682 L F
.76248 .48682 m .76245 .48645 L .76199 .48673 L .418 .252 .548 r
F
.75933 .48836 m .7548 .48046 L .74894 .48407 L .644 .737 .917 r
F
.76283 .48622 m .7548 .48046 L .75933 .48836 L F
.76248 .48682 m .76199 .48673 L .75897 .48922 L .418 .252 .548 r
F
.76199 .48673 m .75892 .48861 L .75897 .48922 L F
.7593 .48837 m .75918 .48833 L .75892 .48861 L .644 .737 .917 r
F
.75897 .48922 m .75892 .48861 L .7584 .48915 L .248 .131 .517 r
F
.77517 .50273 m .77365 .50073 L .77281 .50106 L .643 .738 .918 r
F
.77365 .50073 m .77359 .50066 L .77331 .50081 L F
.77365 .50073 m .77331 .50081 L .77281 .50106 L F
.77347 .49295 m .77394 .50067 L .77369 .4929 L .585 .369 .554 r
F
.77517 .50273 m .77377 .50477 L .77472 .50494 L .643 .738 .918 r
F
.77473 .50494 m .77447 .50528 L .77464 .50536 L F
.77388 .50479 m .77472 .50494 L .7775 .5398 L .75 .494 .544 r
F
.77394 .50067 m .77412 .50063 L .77369 .4929 L .585 .369 .554 r
F
.77227 .49334 m .77272 .50111 L .7725 .49321 L .454 .273 .545 r
F
.77272 .50111 m .7748 .53626 L .77292 .50101 L F
.77272 .50111 m .77292 .50101 L .7725 .49321 L F
.77262 .49321 m .77301 .50096 L .7727 .49316 L F
.77301 .50096 m .77308 .50092 L .7727 .49316 L F
.77251 .49328 m .77254 .49326 L .77254 .49319 L F
.77221 .49345 m .7727 .49316 L .77205 .49334 L .667 .748 .911 r
F
.77304 .49307 m .77199 .49171 L .77205 .49334 L F
.77221 .49345 m .77191 .49325 L .77145 .49389 L F
.77191 .49325 m .77055 .49232 L .77145 .49389 L F
.77134 .49389 m .77135 .49404 L .77144 .49376 L .159 .061 .485 r
F
.77135 .49404 m .77145 .4939 L .77144 .49376 L F
.77104 .49446 m .77145 .49389 L .7706 .49439 L .667 .748 .911 r
F
.77145 .49389 m .77145 .49389 L .77104 .49446 L F
.7706 .49439 m .77086 .49367 L .76915 .49414 L F
.77145 .49389 m .77086 .49367 L .7706 .49439 L F
.77086 .49367 m .76938 .49311 L .76915 .49414 L F
.77076 .49464 m .77077 .49483 L .77077 .49483 L 0 0 .196 r
F
.77076 .49504 m .77077 .49483 L .77062 .49504 L .667 .748 .911 r
F
.77104 .49446 m .76856 .49404 L .77062 .49504 L F
.77076 .49504 m .77047 .49504 L .77072 .49557 L F
.76297 .48626 m .76208 .47783 L .7548 .48046 L .644 .737 .917 r
F
.76686 .48486 m .76208 .47783 L .76297 .48626 L F
.76938 .49311 m .76256 .49303 L .76856 .49404 L .667 .748 .911 r
F
.76938 .49311 m .76418 .49117 L .76256 .49303 L F
.77055 .49232 m .76418 .49117 L .76938 .49311 L F
.77055 .49232 m .76652 .48957 L .76418 .49117 L F
.77199 .49171 m .76652 .48957 L .77055 .49232 L F
.77199 .49171 m .76941 .48835 L .76652 .48957 L F
.76652 .48957 m .75897 .48922 L .76418 .49117 L F
.76652 .48957 m .76248 .48682 L .75897 .48922 L F
.76941 .48835 m .76248 .48682 L .76652 .48957 L F
.76941 .48835 m .76682 .48498 L .76248 .48682 L F
.77359 .50066 m .7704 .4843 L .76219 .48576 L .643 .738 .918 r
F
.77462 .49283 m .77388 .49286 L .77449 .50055 L .664 .428 .553 r
F
.77369 .4929 m .77412 .50063 L .77372 .49289 L .585 .369 .554 r
F
.77517 .50273 m .7746 .50053 L .77365 .50073 L .643 .738 .918 r
F
.77412 .50063 m .77607 .53555 L .77415 .50063 L .585 .369 .554 r
F
.77412 .50063 m .77415 .50063 L .77372 .49289 L F
.77388 .49286 m .77607 .53555 L .77726 .53524 L F
.77372 .49289 m .77607 .53555 L .77388 .49286 L F
.77365 .50073 m .77452 .50019 L .77359 .50066 L .643 .738 .918 r
F
.7746 .50053 m .77452 .50019 L .77365 .50073 L F
.77456 .49506 m .77471 .49482 L .77469 .49478 L .667 .748 .911 r
F
.77456 .49506 m .77478 .49494 L .77475 .49489 L F
.77456 .49506 m .77478 .49494 L .77478 .49494 L F
.77456 .49506 m .77475 .49489 L .77471 .49482 L F
.77462 .49283 m .77449 .50055 L .7751 .50053 L .664 .428 .553 r
F
.77452 .50019 m .7704 .4843 L .77359 .50066 L .643 .738 .918 r
F
.77394 .50067 m .77607 .53555 L .77412 .50063 L .585 .369 .554 r
F
.77281 .50106 m .76219 .48576 L .75489 .48839 L .643 .738 .918 r
F
.77359 .50066 m .76219 .48576 L .77281 .50106 L F
.77301 .50096 m .7748 .53626 L .77308 .50092 L .454 .273 .545 r
F
.77331 .50081 m .7748 .53626 L .77607 .53555 L F
.77308 .50092 m .7748 .53626 L .77331 .50081 L F
.77205 .50145 m .7722 .50063 L .7702 .50069 L .643 .738 .918 r
F
.77281 .50106 m .7722 .50063 L .77205 .50145 L F
.7722 .50063 m .75489 .48839 L .7702 .50069 L F
.7751 .50053 m .77449 .50055 L .77726 .53524 L .664 .428 .553 r
F
.77295 .50099 m .7748 .53626 L .77301 .50096 L .454 .273 .545 r
F
.77292 .50101 m .7748 .53626 L .77295 .50099 L F
.77347 .49295 m .77347 .49295 L .77347 .49295 L .585 .369 .554 r
F
.77188 .50391 m .77496 .53912 L .77179 .50383 L .941 .646 .452 r
F
.77144 .50333 m .7716 .50366 L .77435 .53858 L .966 .687 .262 r
F
.77188 .50391 m .7722 .5042 L .77496 .53912 L .941 .646 .452 r
F
.77184 .50172 m .77369 .53066 L .77192 .50161 L .159 .061 .485 r
F
.77071 .50317 m .77007 .50246 L .76821 .50341 L .643 .738 .918 r
F
.77121 .50252 m .77007 .50246 L .77071 .50317 L F
.77007 .50246 m .74299 .50104 L .76821 .50341 L F
.77272 .50111 m .77205 .50145 L .7748 .53626 L .454 .273 .545 r
F
.77131 .50304 m .77435 .53858 L .77405 .53795 L .966 .687 .262 r
F
.77136 .50315 m .77435 .53858 L .77131 .50304 L F
.77173 .50186 m .77411 .5372 L .77184 .50172 L .159 .061 .485 r
F
.77205 .50145 m .77369 .53066 L .7748 .53626 L F
.77192 .50161 m .77369 .53066 L .77205 .50145 L F
.77 .50408 m .76364 .50573 L .76901 .50535 L .643 .738 .918 r
F
.77 .50408 m .76901 .50535 L .76965 .5053 L F
.77394 .50067 m .77331 .50081 L .77607 .53555 L .585 .369 .554 r
F
.77304 .49307 m .77308 .49294 L .77298 .493 L .667 .748 .911 r
F
.7746 .50053 m .77896 .4841 L .7704 .4843 L .643 .738 .918 r
F
.77461 .50055 m .77462 .50052 L .7746 .50053 L F
.77462 .50052 m .77896 .4841 L .7746 .50053 L F
.77714 .49318 m .77758 .50097 L .77778 .50104 L .811 .54 .528 r
F
.777 .49329 m .80059 .48287 L .79451 .47953 L .644 .737 .917 r
F
.77699 .49329 m .77715 .49334 L .77714 .49318 L .811 .54 .528 r
F
.77753 .49347 m .77963 .49236 L .77959 .49236 L .667 .748 .911 r
F
.77753 .49347 m .77963 .49236 L .77753 .49347 L F
.77959 .49236 m .77963 .49236 L .77962 .49235 L F
.77776 .49356 m .80059 .48287 L .777 .49329 L .644 .737 .917 r
F
.77699 .49329 m .77745 .50092 L .77715 .49334 L .811 .54 .528 r
F
.77679 .49322 m .77729 .50087 L .77699 .49329 L F
.77729 .50087 m .77745 .50092 L .77699 .49329 L F
.77562 .50052 m .77896 .4841 L .77461 .50055 L .643 .738 .918 r
F
.77535 .50052 m .77726 .53524 L .77542 .50052 L .664 .428 .553 r
F
.77621 .5006 m .77563 .50052 L .7784 .53516 L .734 .481 .546 r
F
.77562 .50051 m .77684 .50031 L .77583 .49952 L .643 .738 .918 r
F
.77672 .50048 m .77684 .50031 L .77562 .50052 L F
.77563 .50052 m .77726 .53524 L .7784 .53516 L .664 .428 .553 r
F
.77542 .50052 m .77726 .53524 L .77563 .50052 L F
.77652 .50064 m .7784 .53516 L .77652 .50064 L .734 .481 .546 r
F
.77672 .50067 m .7784 .53516 L .77951 .53527 L F
.77652 .50064 m .7784 .53516 L .77672 .50067 L F
.77778 .50104 m .77951 .53527 L .78057 .53562 L .811 .54 .528 r
F
.77758 .50097 m .77951 .53527 L .77778 .50104 L F
.7783 .50144 m .77845 .50156 L .77798 .49399 L .921 .628 .471 r
F
.77845 .50156 m .77851 .50161 L .77806 .49405 L F
.77778 .49383 m .77716 .49334 L .77778 .50104 L F
.77778 .50104 m .80079 .49081 L .77756 .50087 L .643 .738 .918 r
F
.77816 .50134 m .77837 .50124 L .77778 .50104 L F
.77837 .50124 m .80079 .49081 L .77778 .50104 L F
.77745 .50092 m .77951 .53527 L .77758 .50097 L .811 .54 .528 r
F
.77748 .50093 m .77778 .50104 L .77756 .50087 L .643 .738 .918 r
F
.77729 .50087 m .77951 .53527 L .77745 .50092 L .811 .54 .528 r
F
.77944 .50162 m .78469 .50177 L .78088 .50124 L .643 .738 .918 r
F
.78094 .50215 m .78469 .50177 L .77944 .50162 L F
.78469 .50177 m .80729 .4995 L .78088 .50124 L F
.77621 .5006 m .7784 .53516 L .77652 .50064 L .734 .481 .546 r
F
.7783 .50144 m .78057 .53562 L .77845 .50156 L .921 .628 .471 r
F
.77729 .50087 m .77672 .50067 L .77951 .53527 L .811 .54 .528 r
F
.78094 .50215 m .80733 .49959 L .80729 .4995 L .643 .738 .918 r
F
.78098 .50216 m .80733 .49959 L .78094 .50215 L F
.78482 .50022 m .80729 .4995 L .80509 .49494 L F
.7751 .50053 m .77726 .53524 L .77527 .50053 L .664 .428 .553 r
F
.77845 .50156 m .78057 .53562 L .77851 .50161 L .921 .628 .471 r
F
.77756 .50087 m .80079 .49081 L .7947 .48747 L .643 .738 .918 r
F
.77816 .50134 m .80509 .49494 L .80079 .49081 L F
.77875 .5018 m .80509 .49494 L .77816 .50134 L F
.77857 .50165 m .78057 .53562 L .77857 .50166 L .921 .628 .471 r
F
.77875 .5018 m .78057 .53562 L .78156 .53637 L F
.77857 .50166 m .78057 .53562 L .77875 .5018 L F
.77684 .50031 m .7947 .48747 L .78725 .48518 L .643 .738 .918 r
F
.77756 .50087 m .7947 .48747 L .77684 .50031 L F
.77583 .49952 m .78725 .48518 L .77896 .4841 L F
.77684 .50031 m .78725 .48518 L .77583 .49952 L F
.77851 .50161 m .78057 .53562 L .77857 .50165 L .921 .628 .471 r
F
.77891 .50321 m .78188 .53733 L .77888 .5033 L 0 0 .362 r
F
.77894 .5031 m .77897 .50301 L .77935 .50783 L F
.77897 .50301 m .77907 .50273 L .77935 .50783 L F
.77935 .50783 m .77907 .50273 L .78188 .53733 L F
.77894 .5031 m .78188 .53733 L .77891 .50321 L F
.77892 .50229 m .77875 .5018 L .78156 .53637 L .919 .662 .17 r
F
.77914 .50294 m .78173 .50412 L .78029 .503 L .643 .738 .918 r
F
.77937 .50362 m .78173 .50412 L .77914 .50294 L F
.78173 .50412 m .80521 .50911 L .78029 .503 L F
.7783 .50144 m .77778 .50104 L .78057 .53562 L .921 .628 .471 r
F
.7797 .50459 m .80103 .51334 L .77937 .50362 L .643 .738 .918 r
F
.77901 .50255 m .78156 .53637 L .77901 .50256 L .919 .662 .17 r
F
.7803 .50635 m .79513 .51684 L .7797 .50459 L .643 .738 .918 r
F
.77907 .50273 m .78156 .53637 L .78188 .53733 L .919 .662 .17 r
F
.77901 .50256 m .78156 .53637 L .77907 .50273 L F
.76364 .50573 m .7456 .51043 L .76965 .5053 L .643 .738 .918 r
F
.77156 .50515 m .77182 .50861 L .77136 .50315 L .966 .687 .262 r
F
.7714 .50323 m .77156 .50515 L .77136 .50315 L F
.77135 .50255 m .77405 .53795 L .77135 .50246 L 0 0 .196 r
F
.77119 .50459 m .7687 .50574 L .77115 .50505 L .643 .738 .918 r
F
.7687 .50574 m .74998 .51446 L .76798 .50667 L F
.77173 .50186 m .77136 .50233 L .77411 .5372 L .159 .061 .485 r
F
.77135 .50246 m .77405 .53795 L .77135 .50246 L 0 0 .196 r
F
.77108 .50593 m .74998 .51446 L .75604 .51769 L .643 .738 .918 r
F
.77113 .50531 m .74998 .51446 L .77108 .50593 L F
.77108 .50593 m .75604 .51769 L .77083 .50904 L F
.77136 .50233 m .77405 .53795 L .77204 .51086 L 0 0 .196 r
F
.77135 .50246 m .77405 .53795 L .77136 .50233 L F
.77134 .50266 m .77405 .53795 L .77135 .50255 L F
.77134 .50266 m .77131 .50304 L .77405 .53795 L F
.77074 .51018 m .76336 .51989 L .7699 .52074 L .643 .738 .918 r
F
.77074 .51018 m .7699 .52074 L .77148 .52094 L F
.78217 .51187 m .7879 .51936 L .7803 .50635 L F
.77897 .50244 m .78156 .53637 L .77901 .50255 L .919 .662 .17 r
F
.76859 .48456 m .76681 .48488 L .76682 .48498 L .603 .386 .559 r
F
.76682 .48498 m .76681 .48488 L .76666 .48494 L .525 .329 .558 r
F
.77892 .50229 m .78156 .53637 L .77897 .50244 L .919 .662 .17 r
F
.78217 .51187 m .78489 .51988 L .7879 .51936 L .643 .738 .918 r
F
.77369 .53066 m .77411 .5372 L .77422 .53705 L .159 .061 .485 r
F
.77369 .53066 m .77422 .53705 L .7748 .53626 L F
.77204 .51086 m .77405 .53795 L .77411 .5372 L 0 0 .196 r
F
.74489 .4884 m .71081 .49146 L .74292 .49314 L .644 .737 .917 r
F
.74489 .4884 m .71457 .48194 L .71081 .49146 L F
.71457 .48985 m .67862 .49765 L .7108 .49935 L .643 .738 .918 r
F
.71457 .48985 m .684 .48335 L .67962 .49501 L F
.6818 .49696 m .67962 .49501 L .67862 .49765 L F
.71457 .48985 m .67962 .49501 L .6818 .49696 L F
.67962 .49501 m .67885 .4896 L .67862 .49765 L 0 0 .293 r
F
.684 .48335 m .67969 .48858 L .67962 .49501 L F
.67969 .48858 m .67885 .4896 L .67962 .49501 L F
.67885 .4896 m .67871 .48998 L .67862 .49765 L F
.67962 .49522 m .67953 .49493 L .67625 .49219 L .936 .671 .51 r
F
.67917 .48874 m .67956 .48771 L .67597 .48447 L .644 .737 .917 r
F
.67953 .49493 m .67634 .48429 L .67625 .49198 L .936 .671 .51 r
F
.67953 .49493 m .67625 .49198 L .67625 .49219 L F
.68993 .50447 m .68956 .50394 L .67962 .49522 L F
.68956 .50394 m .67962 .49501 L .67962 .49522 L F
.7108 .49935 m .68281 .49787 L .69272 .50677 L .643 .738 .918 r
F
.684 .48335 m .68407 .47564 L .67885 .4896 L 0 0 .293 r
F
.67968 .48925 m .67634 .48429 L .67962 .49522 L .936 .671 .51 r
F
.67968 .48925 m .6797 .48732 L .67634 .48429 L F
.63391 .53337 m .66703 .53051 L .63552 .52885 L .643 .738 .918 r
F
.60917 .53359 m .6348 .53203 L .63213 .52756 L .642 .738 .919 r
F
.604 .52719 m .60576 .52571 L .60502 .52546 L .643 .738 .918 r
F
.60555 .52564 m .60486 .5254 L .60505 .53304 L .805 .544 .543 r
F
.60375 .53502 m .60935 .53448 L .60779 .53395 L .642 .738 .919 r
F
.60375 .53502 m .60564 .53323 L .60493 .53302 L F
.60555 .52564 m .60505 .53304 L .60562 .53323 L .805 .544 .543 r
F
.60564 .53323 m .60574 .53313 L .60505 .53304 L .642 .738 .919 r
F
.60564 .53323 m .60505 .53304 L .60493 .53302 L F
.60555 .52549 m .60562 .53323 L .60575 .52555 L .805 .544 .543 r
F
.63391 .53337 m .66364 .53952 L .66703 .53051 L .643 .738 .918 r
F
.61305 .53412 m .63533 .53668 L .6348 .53203 L .642 .738 .919 r
F
.60375 .53502 m .62971 .53638 L .61305 .53412 L F
.62971 .53638 m .63533 .53668 L .61305 .53412 L F
.60505 .53304 m .60481 .56723 L .60591 .56734 L .733 .485 .553 r
F
.60486 .5254 m .60485 .53301 L .60505 .53304 L F
.60469 .52527 m .60478 .52527 L .60478 .52224 L F
.60369 .52718 m .60474 .52527 L .60359 .52705 L .667 .747 .91 r
F
.60474 .52527 m .60553 .52383 L .60467 .52526 L F
.60474 .52527 m .60467 .52526 L .60359 .52705 L F
.60485 .52528 m .60478 .52539 L .60486 .5254 L .733 .485 .553 r
F
.60478 .52224 m .60478 .52527 L .60485 .52528 L F
.60478 .52527 m .60478 .52539 L .60485 .52528 L F
.604 .52719 m .60486 .5254 L .60419 .52531 L .643 .738 .918 r
F
.60445 .52222 m .60377 .52518 L .60448 .52525 L .733 .485 .553 r
F
.60377 .52518 m .60477 .5251 L .60377 .52518 L .667 .747 .91 r
F
.60359 .52705 m .60467 .52526 L .60377 .52518 L F
.60467 .52526 m .60477 .5251 L .60377 .52518 L F
.60445 .52222 m .60369 .52215 L .60377 .52518 L .733 .485 .553 r
F
.60361 .52959 m .60356 .5296 L .60355 .52951 L .648 .418 .556 r
F
.60356 .52741 m .60336 .52962 L .60432 .5295 L .667 .747 .91 r
F
.60448 .52525 m .60396 .53289 L .60454 .53297 L .733 .485 .553 r
F
.60454 .53279 m .60454 .53297 L .60454 .53279 L F
.60454 .53279 m .60454 .53279 L .60469 .52538 L F
.60448 .52535 m .60454 .53279 L .60469 .52538 L F
.60454 .53297 m .60471 .53299 L .60469 .52538 L F
.60469 .52527 m .60471 .53299 L .60478 .52527 L F
.60471 .53299 m .60478 .533 L .60478 .52527 L F
.60375 .53502 m .60493 .53302 L .60396 .53289 L .642 .738 .919 r
F
.60229 .53748 m .60011 .53897 L .60017 .54108 L F
.60252 .53711 m .60217 .53738 L .60229 .53748 L F
.60217 .53738 m .60011 .53897 L .60229 .53748 L F
.60368 .52717 m .59983 .52697 L .60372 .52722 L .643 .738 .918 r
F
.59983 .52697 m .5959 .52677 L .59982 .52699 L F
.59983 .52697 m .59982 .52699 L .60372 .52722 L F
.59995 .52789 m .60018 .52829 L .60019 .52851 L .988 .718 .377 r
F
.59973 .52832 m .59874 .52858 L .59987 .52898 L .643 .738 .918 r
F
.59973 .52832 m .59987 .52898 L .59985 .52838 L F
.60019 .52851 m .59739 .52835 L .59794 .52924 L .667 .747 .91 r
F
.59982 .52724 m .59983 .52769 L .59984 .5279 L .712 .567 0 r
F
.59995 .52789 m .60019 .52851 L .59996 .52812 L .988 .718 .377 r
F
.60018 .52829 m .60019 .52851 L .60019 .52851 L .925 .648 .496 r
F
.59984 .52823 m .59985 .52849 L .60019 .52851 L .667 .747 .91 r
F
.59995 .52789 m .59996 .52811 L .59988 .52778 L .988 .718 .377 r
F
.59996 .52811 m .60017 .53559 L .59989 .528 L F
.59996 .52811 m .59989 .528 L .59988 .52778 L F
.59981 .52711 m .59982 .52731 L .59981 .52705 L .712 .567 0 r
F
.59983 .52769 m .59984 .52791 L .59984 .5279 L .988 .718 .377 r
F
.59982 .52724 m .59984 .5279 L .59982 .52745 L .712 .567 0 r
F
.59984 .52791 m .59984 .52791 L .59983 .52769 L .988 .718 .377 r
F
.59988 .52778 m .59989 .528 L .59983 .52769 L F
.59989 .528 m .59984 .52791 L .59983 .52769 L F
.60017 .53559 m .60012 .5355 L .59988 .52778 L F
.59995 .52789 m .60036 .53591 L .60017 .53559 L F
.60356 .52741 m .59982 .5274 L .59987 .52797 L .667 .747 .91 r
F
.59982 .5274 m .59954 .5274 L .59984 .5279 L F
.59982 .5274 m .59984 .5279 L .59987 .52797 L F
.59954 .5274 m .59726 .52739 L .59984 .52796 L F
.59984 .5279 m .59984 .52796 L .59987 .52797 L F
.59954 .5274 m .59984 .52796 L .59984 .5279 L F
.59987 .52797 m .59957 .52802 L .60019 .52851 L F
.59982 .52724 m .59982 .52724 L .59981 .52705 L .712 .567 0 r
F
.59982 .52724 m .59982 .52745 L .59982 .52744 L F
.59982 .52731 m .59982 .52724 L .59981 .52705 L F
.57297 .51776 m .54329 .52536 L .57368 .52239 L .644 .737 .917 r
F
.58081 .52597 m .57393 .52098 L .57249 .52553 L .643 .738 .918 r
F
.5985 .52595 m .5976 .52583 L .59781 .52618 L .667 .747 .91 r
F
.5985 .52613 m .59781 .52618 L .59824 .52654 L F
.5985 .52613 m .59824 .52654 L .59874 .52695 L F
.58495 .52717 m .58483 .52411 L .58649 .52678 L .987 .712 .383 r
F
.59104 .52316 m .58492 .5241 L .58658 .52676 L .667 .747 .91 r
F
.58454 .52429 m .58483 .52411 L .58495 .52717 L .82 .628 .075 r
F
.58475 .5273 m .58454 .52429 L .58495 .52717 L F
.58462 .5264 m .58454 .52429 L .58475 .5273 L F
.59084 .52431 m .58495 .52717 L .5911 .52623 L .667 .747 .91 r
F
.59084 .52431 m .58454 .52429 L .58495 .52717 L F
.60368 .52717 m .59584 .5255 L .5848 .52585 L .643 .738 .918 r
F
.60368 .52717 m .5848 .52585 L .58479 .52587 L F
.58526 .52443 m .58454 .52429 L .58462 .5264 L 0 0 .319 r
F
.60368 .52717 m .58454 .52586 L .58459 .52617 L .643 .738 .918 r
F
.58454 .52429 m .58442 .52123 L .58483 .52411 L .82 .628 .075 r
F
.58542 .52141 m .58442 .52123 L .58454 .52429 L 0 0 .319 r
F
.59143 .52239 m .58454 .52429 L .59084 .52431 L .667 .747 .91 r
F
.5848 .52585 m .57393 .52098 L .58081 .52597 L .643 .738 .918 r
F
.59143 .52239 m .58542 .52141 L .58454 .52429 L .667 .747 .91 r
F
.59584 .5255 m .58573 .52341 L .5848 .52585 L .643 .738 .918 r
F
.58718 .52171 m .58542 .52141 L .58551 .52367 L .184 .071 .482 r
F
.58526 .52443 m .58542 .52141 L .58454 .52429 L 0 0 .319 r
F
.58551 .52367 m .58542 .52141 L .58526 .52443 L F
.57701 .52161 m .57743 .51682 L .57393 .52098 L .643 .738 .918 r
F
.6036 .5252 m .6036 .52526 L .60363 .52519 L .665 .431 .556 r
F
.59889 .5255 m .59726 .52529 L .5976 .52583 L .667 .747 .91 r
F
.604 .52719 m .5994 .52539 L .59584 .5255 L .643 .738 .918 r
F
.60364 .52712 m .59584 .5255 L .60368 .52717 L F
.60051 .52877 m .60019 .52851 L .60038 .52883 L .667 .747 .91 r
F
.60019 .52851 m .60019 .52851 L .60051 .52877 L F
.6004 .52847 m .60041 .52868 L .60028 .52837 L .925 .648 .496 r
F
.60041 .52868 m .60066 .53615 L .60029 .52859 L F
.60041 .52868 m .60029 .52859 L .60028 .52837 L F
.60076 .52896 m .60038 .52883 L .60073 .52898 L .667 .747 .91 r
F
.60175 .53704 m .6001 .5384 L .6021 .53733 L .642 .738 .919 r
F
.6001 .5384 m .60011 .53888 L .60252 .53711 L F
.59798 .53745 m .59298 .53705 L .59429 .54374 L .643 .738 .918 r
F
.59298 .53705 m .5894 .54232 L .59429 .54374 L F
.59404 .54334 m .59358 .54401 L .60011 .53897 L .642 .738 .919 r
F
.60011 .53888 m .60011 .53897 L .60252 .53711 L F
.59404 .54334 m .60011 .53897 L .60011 .53888 L F
.60356 .52741 m .60004 .52683 L .59982 .52719 L .667 .747 .91 r
F
.59982 .5274 m .59982 .52719 L .59969 .5274 L F
.59982 .52724 m .59982 .52744 L .59981 .52711 L .712 .567 0 r
F
.59982 .52744 m .59982 .52731 L .59981 .52711 L F
.60356 .52741 m .59982 .52719 L .59982 .5274 L .667 .747 .91 r
F
.59982 .52744 m .6 .53494 L .59982 .52731 L .712 .567 0 r
F
.6001 .5384 m .59404 .54334 L .60011 .53888 L .642 .738 .919 r
F
.60162 .5368 m .59432 .54293 L .60197 .53686 L F
.59432 .54293 m .58663 .54938 L .59404 .54334 L F
.59432 .54293 m .59404 .54334 L .60197 .53686 L F
.60066 .53615 m .60056 .53607 L .60028 .52837 L .925 .648 .496 r
F
.60356 .52741 m .60019 .52851 L .60051 .52877 L .667 .747 .91 r
F
.60028 .52837 m .60029 .52859 L .60018 .52829 L .925 .648 .496 r
F
.60029 .52859 m .60056 .53607 L .60019 .52851 L F
.60029 .52859 m .60019 .52851 L .60018 .52829 L F
.60056 .53607 m .60048 .53601 L .60018 .52829 L F
.60356 .52741 m .59987 .52797 L .60019 .52851 L .667 .747 .91 r
F
.60019 .52851 m .60048 .53601 L .60019 .52851 L .925 .648 .496 r
F
.60004 .52683 m .59827 .52554 L .59756 .52643 L .667 .747 .91 r
F
.60356 .52741 m .60039 .52629 L .60004 .52683 L F
.60019 .52645 m .60019 .5266 L .6003 .52629 L .07 0 .435 r
F
.60019 .5266 m .6003 .52643 L .6003 .52629 L F
.60019 .52645 m .59982 .52719 L .60019 .52661 L F
.60017 .54108 m .58663 .54938 L .59401 .55151 L .642 .738 .919 r
F
.60011 .53897 m .58663 .54938 L .60017 .54108 L F
.60017 .54108 m .59401 .55151 L .60021 .5424 L F
.60021 .5424 m .59401 .55151 L .60048 .55233 L F
.594 .53629 m .59298 .53705 L .59798 .53745 L .643 .738 .918 r
F
.59328 .53694 m .59443 .53642 L .59771 .53805 L .79 .534 .55 r
F
.59443 .53642 m .59768 .53736 L .59771 .53805 L F
.59669 .53378 m .59771 .53805 L .59965 .53452 L .667 .747 .91 r
F
.59378 .53635 m .59312 .53685 L .5938 .53635 L .643 .738 .918 r
F
.59328 .53694 m .59324 .53608 L .59443 .53642 L .79 .534 .55 r
F
.59669 .53378 m .59328 .53694 L .59771 .53805 L .667 .747 .91 r
F
.6017 .53674 m .59775 .53791 L .59432 .54293 L .642 .738 .919 r
F
.60091 .53639 m .59775 .53791 L .6017 .53674 L F
.601 .53643 m .60281 .57147 L .60183 .57105 L .84 .573 .536 r
F
.60082 .52881 m .60118 .53651 L .601 .53643 L F
.60118 .53651 m .60281 .57147 L .601 .53643 L F
.6018 .52942 m .60226 .53692 L .60179 .52942 L .749 .498 .552 r
F
.60226 .53692 m .60226 .53691 L .60179 .52942 L F
.60095 .52907 m .60128 .53655 L .60089 .52904 L .84 .573 .536 r
F
.60128 .53655 m .60123 .53653 L .60089 .52904 L F
.60051 .52877 m .60038 .52883 L .60076 .52896 L .667 .747 .91 r
F
.60073 .52898 m .60038 .52883 L .60053 .52909 L F
.60042 .52869 m .60083 .52902 L .601 .53643 L .925 .648 .496 r
F
.60116 .52915 m .60197 .53686 L .60145 .53663 L .84 .573 .536 r
F
.60117 .52916 m .60197 .53686 L .60116 .52915 L F
.60194 .53654 m .60197 .53651 L .60197 .53686 L F
.60117 .52916 m .60197 .53651 L .60194 .53654 L F
.60117 .52916 m .60179 .52942 L .60197 .53651 L F
.60179 .52942 m .60226 .53691 L .60197 .53686 L .749 .498 .552 r
F
.60197 .53686 m .60175 .53704 L .60252 .53711 L .642 .738 .919 r
F
.60175 .53704 m .6021 .53733 L .60252 .53711 L F
.60204 .52945 m .60246 .53695 L .60199 .52944 L .749 .498 .552 r
F
.60221 .53904 m .60234 .53926 L .6031 .53814 L .642 .738 .919 r
F
.60252 .53711 m .60229 .53748 L .6035 .53755 L F
.60229 .53748 m .60301 .53807 L .6035 .53755 L F
.60246 .53695 m .60439 .5717 L .60242 .53694 L .749 .498 .552 r
F
.60246 .53695 m .60242 .53694 L .60199 .52944 L F
.60336 .52962 m .60233 .52964 L .60332 .53005 L .667 .747 .91 r
F
.60356 .52741 m .60241 .5295 L .60336 .52962 L F
.60241 .5295 m .60233 .52964 L .60336 .52962 L F
.60232 .52934 m .60233 .52949 L .60203 .52929 L .749 .498 .552 r
F
.6026 .53697 m .60197 .53686 L .60252 .53711 L .642 .738 .919 r
F
.60241 .5295 m .60179 .52942 L .60233 .52964 L .667 .747 .91 r
F
.60281 .53701 m .60252 .53711 L .60272 .5372 L .642 .738 .919 r
F
.60233 .52949 m .6027 .53699 L .60204 .52945 L .749 .498 .552 r
F
.6027 .53699 m .60246 .53695 L .60204 .52945 L F
.60233 .52949 m .60336 .52962 L .60354 .53714 L F
.60354 .53714 m .60272 .5372 L .6035 .53755 L .642 .738 .919 r
F
.60301 .53807 m .6031 .53814 L .6035 .53755 L F
.6027 .53699 m .60354 .53714 L .60439 .5717 L .749 .498 .552 r
F
.60233 .52949 m .60354 .53714 L .6027 .53699 L F
.60375 .53502 m .6026 .53697 L .60281 .53701 L .642 .738 .919 r
F
.6026 .53697 m .60252 .53711 L .60281 .53701 L F
.6027 .53699 m .60439 .5717 L .60246 .53695 L .749 .498 .552 r
F
.60233 .52949 m .60204 .52945 L .60203 .52929 L F
.60198 .52928 m .60242 .53694 L .60179 .52924 L F
.60242 .53694 m .60439 .5717 L .60226 .53692 L F
.60242 .53694 m .60226 .53692 L .60179 .52924 L F
.59298 .53705 m .58692 .5416 L .5894 .54232 L .643 .738 .918 r
F
.5994 .52539 m .59652 .52427 L .59584 .5255 L F
.60039 .52629 m .59934 .52477 L .59827 .52554 L .667 .747 .91 r
F
.60115 .52575 m .60115 .52583 L .60137 .52563 L .438 .255 .533 r
F
.60356 .52741 m .60109 .52586 L .60039 .52629 L .667 .747 .91 r
F
.60019 .52851 m .60048 .53601 L .60036 .53591 L .925 .648 .496 r
F
.60116 .52915 m .60145 .53663 L .60098 .52908 L .84 .573 .536 r
F
.60145 .53663 m .6013 .53657 L .60097 .52888 L F
.6004 .52847 m .601 .53643 L .60066 .53615 L .925 .648 .496 r
F
.60097 .52888 m .6013 .53657 L .60094 .52886 L .84 .573 .536 r
F
.6013 .53657 m .60128 .53655 L .60094 .52886 L F
.60091 .53639 m .59883 .53631 L .60047 .5366 L .642 .738 .919 r
F
.60088 .52884 m .60123 .53653 L .60082 .52881 L .84 .573 .536 r
F
.60123 .53653 m .60118 .53651 L .60082 .52881 L F
.60375 .53502 m .60003 .536 L .60091 .53639 L .642 .738 .919 r
F
.60003 .536 m .59883 .53631 L .60091 .53639 L F
.60123 .53653 m .60281 .57147 L .60118 .53651 L .84 .573 .536 r
F
.60375 .53502 m .60091 .53639 L .6017 .53674 L .642 .738 .919 r
F
.60356 .52741 m .60051 .52877 L .60076 .52896 L .667 .747 .91 r
F
.60056 .53607 m .60183 .57105 L .60048 .53601 L .925 .648 .496 r
F
.60047 .5366 m .5983 .53711 L .59775 .53791 L .642 .738 .919 r
F
.59883 .53631 m .5757 .54239 L .60047 .5366 L F
.60036 .53591 m .60183 .57105 L .60118 .57053 L .925 .648 .496 r
F
.60048 .53601 m .60183 .57105 L .60036 .53591 L F
.60128 .53655 m .60281 .57147 L .60123 .53653 L .84 .573 .536 r
F
.60095 .52907 m .60089 .52904 L .60088 .52884 L F
.60356 .52741 m .60076 .52896 L .60152 .5293 L .667 .747 .91 r
F
.60076 .52896 m .60083 .52902 L .60152 .5293 L F
.60145 .53663 m .60281 .57147 L .6013 .53657 L .84 .573 .536 r
F
.60066 .53615 m .601 .53643 L .60183 .57105 L .925 .648 .496 r
F
.60066 .53615 m .60183 .57105 L .60056 .53607 L F
.6013 .53657 m .60281 .57147 L .60128 .53655 L .84 .573 .536 r
F
.59136 .53098 m .57937 .53739 L .58069 .53849 L .643 .738 .918 r
F
.59287 .53788 m .57289 .53799 L .5757 .54239 L .642 .738 .919 r
F
.59984 .5279 m .60007 .53542 L .60001 .53531 L .988 .718 .377 r
F
.59984 .52791 m .60007 .53542 L .59984 .5279 L F
.60012 .5355 m .60007 .53542 L .59984 .52791 L F
.60012 .5355 m .59984 .52791 L .59984 .52791 L F
.59996 .52812 m .60019 .52851 L .60036 .53591 L F
.59987 .52797 m .59984 .52796 L .59984 .52797 L .667 .747 .91 r
F
.59989 .528 m .60012 .5355 L .59984 .52791 L .988 .718 .377 r
F
.60375 .53502 m .59703 .53566 L .59287 .53788 L .642 .738 .919 r
F
.58788 .53284 m .57601 .53459 L .57937 .53739 L .643 .738 .918 r
F
.58953 .53519 m .59066 .53478 L .59328 .53694 L .855 .587 .533 r
F
.59066 .53478 m .59324 .53608 L .59328 .53694 L F
.59419 .5326 m .59328 .53694 L .59669 .53378 L .667 .747 .91 r
F
.58952 .53421 m .58951 .53421 L .5899 .5344 L .643 .738 .918 r
F
.58951 .53421 m .58979 .53444 L .5899 .5344 L F
.58953 .53519 m .58949 .5342 L .59066 .53478 L .855 .587 .533 r
F
.59419 .5326 m .58953 .53519 L .59328 .53694 L .667 .747 .91 r
F
.59703 .53566 m .57289 .53799 L .59287 .53788 L .642 .738 .919 r
F
.60115 .52583 m .60137 .52569 L .60137 .52563 L .438 .255 .533 r
F
.60116 .52534 m .60104 .52519 L .60101 .52524 L .643 .738 .918 r
F
.60343 .52682 m .60212 .52531 L .60116 .52534 L F
.60092 .52576 m .6007 .52419 L .59934 .52477 L .667 .747 .91 r
F
.60356 .52741 m .60155 .52559 L .60109 .52586 L F
.60375 .53502 m .6017 .53674 L .60197 .53686 L .642 .738 .919 r
F
.6017 .53674 m .60162 .5368 L .60197 .53686 L F
.60145 .53663 m .60197 .53686 L .60281 .57147 L .84 .573 .536 r
F
.60179 .52924 m .6018 .52942 L .60179 .52942 L .749 .498 .552 r
F
.60356 .52741 m .60152 .5293 L .60179 .52942 L .667 .747 .91 r
F
.58673 .5329 m .58763 .53264 L .58953 .53519 L .929 .65 .492 r
F
.58763 .53264 m .58949 .5342 L .58953 .53519 L F
.57321 .53018 m .54833 .54191 L .57601 .53459 L .643 .738 .918 r
F
.59233 .53107 m .58953 .53519 L .59419 .5326 L .667 .747 .91 r
F
.59136 .53098 m .58691 .53203 L .58788 .53284 L .643 .738 .918 r
F
.59233 .53107 m .58673 .5329 L .58953 .53519 L .667 .747 .91 r
F
.59703 .53566 m .57217 .53336 L .57289 .53799 L .642 .738 .919 r
F
.6 .53494 m .6 .53484 L .59981 .52711 L .712 .567 0 r
F
.6 .53484 m .6 .53479 L .59982 .52724 L F
.6 .53484 m .59982 .52724 L .59982 .52724 L F
.59982 .52744 m .60001 .53531 L .6 .53494 L F
.59982 .52745 m .60001 .53531 L .59982 .52744 L F
.59982 .52731 m .6 .53484 L .59982 .52724 L F
.59982 .52745 m .59984 .5279 L .60001 .53531 L F
.60375 .53502 m .59874 .53475 L .59703 .53566 L .642 .738 .919 r
F
.59874 .53475 m .57217 .53336 L .59703 .53566 L F
.58586 .52895 m .57321 .53018 L .58571 .52898 L .643 .738 .918 r
F
.58507 .53023 m .58559 .5301 L .58673 .5329 L .987 .712 .383 r
F
.58559 .5301 m .58669 .53185 L .58673 .5329 L F
.58673 .5329 m .58669 .53185 L .58763 .53264 L .929 .65 .492 r
F
.57321 .53018 m .5426 .53315 L .54833 .54191 L .643 .738 .918 r
F
.57249 .52553 m .5426 .53315 L .57321 .53018 L F
.59301 .5301 m .58571 .52898 L .58511 .52933 L F
.59301 .5301 m .58511 .52933 L .58665 .53178 L F
.59714 .52789 m .58571 .52898 L .59301 .5301 L F
.59123 .52929 m .58673 .5329 L .59233 .53107 L .667 .747 .91 r
F
.59123 .52929 m .58507 .53023 L .58673 .5329 L F
.59874 .53475 m .5736 .52881 L .57217 .53336 L .642 .738 .919 r
F
.59981 .52705 m .6 .53479 L .59981 .527 L .712 .567 0 r
F
.6 .53479 m .59999 .53475 L .59981 .527 L F
.59987 .52797 m .60019 .52851 L .60019 .52851 L .667 .747 .91 r
F
.59981 .527 m .59999 .53475 L .59999 .53463 L .712 .567 0 r
F
.60019 .52661 m .59982 .52719 L .59999 .53463 L .07 0 .435 r
F
.60019 .52645 m .59999 .53463 L .6003 .53417 L F
.60375 .53502 m .59978 .5342 L .59874 .53475 L .642 .738 .919 r
F
.59887 .53001 m .59419 .5326 L .59669 .53378 L .667 .747 .91 r
F
.59978 .5342 m .5736 .52881 L .59874 .53475 L .642 .738 .919 r
F
.60154 .52559 m .60152 .53328 L .60155 .52559 L .438 .255 .533 r
F
.5959 .52677 m .57249 .52553 L .58586 .52895 L .643 .738 .918 r
F
.59722 .52785 m .58586 .52895 L .59715 .52788 L F
.58466 .52736 m .58475 .5273 L .58507 .53023 L .82 .628 .075 r
F
.58475 .5273 m .58503 .52919 L .58507 .53023 L F
.58507 .53023 m .58503 .52919 L .58559 .5301 L .987 .712 .383 r
F
.59794 .52924 m .59419 .5326 L .59887 .53001 L .667 .747 .91 r
F
.59794 .52924 m .59233 .53107 L .59419 .5326 L F
.59096 .52737 m .58507 .53023 L .59123 .52929 L F
.59096 .52737 m .58466 .52736 L .58507 .53023 L F
.59833 .5339 m .57711 .52466 L .5736 .52881 L .642 .738 .919 r
F
.6003 .52643 m .60039 .53404 L .60039 .52629 L .07 0 .435 r
F
.60039 .53404 m .60046 .53394 L .60039 .52616 L F
.60039 .52616 m .60046 .53394 L .60057 .53378 L F
.60019 .5266 m .6003 .53417 L .6003 .52643 L F
.6003 .53417 m .60039 .53404 L .6003 .52629 L F
.60137 .52563 m .60137 .53336 L .60154 .52554 L .438 .255 .533 r
F
.60375 .53502 m .60057 .53378 L .59978 .5342 L .642 .738 .919 r
F
.60115 .52583 m .60119 .53345 L .60137 .52569 L .438 .255 .533 r
F
.60119 .53345 m .60137 .53336 L .60137 .52569 L F
.59584 .5255 m .59652 .52427 L .57701 .52161 L .643 .738 .918 r
F
.59044 .51938 m .58753 .51872 L .58763 .52119 L .395 .228 .533 r
F
.59652 .52427 m .57743 .51682 L .57701 .52161 L .643 .738 .918 r
F
.58766 .52179 m .58718 .52171 L .58554 .52448 L .184 .071 .482 r
F
.58718 .52171 m .58551 .52367 L .58554 .52448 L F
.58573 .52341 m .5856 .52339 L .58551 .52367 L .643 .738 .918 r
F
.58573 .52341 m .58551 .52367 L .5848 .52585 L F
.5856 .52339 m .57393 .52098 L .5848 .52585 L F
.58554 .52448 m .58551 .52367 L .58526 .52443 L 0 0 .319 r
F
.58554 .52448 m .58526 .52443 L .58466 .52736 L F
.58466 .52736 m .58462 .5264 L .58475 .5273 L .82 .628 .075 r
F
.58526 .52443 m .58462 .5264 L .58466 .52736 L 0 0 .319 r
F
.58479 .52587 m .5848 .52585 L .58454 .52586 L .643 .738 .918 r
F
.58459 .52617 m .58454 .52586 L .58081 .52597 L F
.59739 .52835 m .59233 .53107 L .59794 .52924 L .667 .747 .91 r
F
.59739 .52835 m .59123 .52929 L .59233 .53107 L F
.59726 .52739 m .59123 .52929 L .59739 .52835 L F
.59726 .52739 m .59096 .52737 L .59123 .52929 L F
.59155 .52546 m .58466 .52736 L .59096 .52737 L F
.59155 .52546 m .58554 .52448 L .58466 .52736 L F
.59297 .52367 m .58554 .52448 L .59155 .52546 L F
.59297 .52367 m .58766 .52179 L .58554 .52448 L F
.59869 .53305 m .58247 .52121 L .57711 .52466 L .642 .738 .919 r
F
.60356 .52741 m .60187 .5255 L .60155 .52559 L .667 .747 .91 r
F
.60356 .52741 m .60327 .52659 L .60187 .5255 L F
.60234 .5253 m .60212 .52531 L .60343 .52682 L .643 .738 .918 r
F
.60327 .52659 m .60238 .52535 L .60187 .5255 L .667 .747 .91 r
F
.60327 .52659 m .60278 .52524 L .60238 .52535 L F
.604 .52719 m .60329 .52527 L .60235 .5253 L .643 .738 .918 r
F
.604 .52719 m .60235 .5253 L .60238 .52535 L F
.604 .52719 m .60239 .52535 L .60343 .52682 L F
.60228 .52538 m .60155 .52559 L .60228 .52538 L .583 .366 .552 r
F
.60238 .52535 m .60235 .5253 L .60234 .5253 L .643 .738 .918 r
F
.60278 .52524 m .60226 .52382 L .60202 .52484 L .667 .747 .91 r
F
.60234 .5253 m .60233 .52528 L .5896 .51082 L .643 .738 .918 r
F
.60233 .52528 m .59175 .51044 L .5896 .51082 L F
.60238 .52535 m .60202 .52484 L .60187 .5255 L .667 .747 .91 r
F
.60278 .52524 m .60202 .52484 L .60238 .52535 L F
.60202 .52484 m .60226 .52382 L .60143 .52402 L F
.60176 .52247 m .60171 .52241 L .60147 .52255 L F
.60171 .52241 m .60057 .52112 L .60101 .52283 L F
.60026 .52021 m .60076 .5197 L .60025 .52021 L F
.60093 .51981 m .60076 .5197 L .60026 .52021 L F
.60076 .5197 m .60063 .51962 L .60054 .51976 L F
.60076 .5197 m .60054 .51976 L .60025 .52021 L F
.60063 .51962 m .60045 .51808 L .5991 .51866 L F
.60063 .51962 m .5991 .51866 L .60025 .52021 L F
.60026 .52021 m .60025 .52021 L .60024 .52022 L F
.60213 .52075 m .5977 .51789 L .60057 .52112 L F
.60161 .51939 m .602 .51771 L .60045 .51808 L F
.60161 .51939 m .60112 .51883 L .60096 .51964 L F
.6014 .51952 m .60096 .51964 L .60093 .51981 L F
.60161 .51939 m .60096 .51964 L .6014 .51952 L F
.60166 .51945 m .60161 .51939 L .6014 .51952 L F
.60093 .51981 m .60112 .51883 L .60063 .51962 L F
.60112 .51883 m .60045 .51808 L .60063 .51962 L F
.60213 .52075 m .60082 .51715 L .5977 .51789 L F
.60143 .52402 m .59784 .52096 L .6007 .52419 L F
.60226 .52382 m .60046 .52266 L .60143 .52402 L F
.60046 .52266 m .59784 .52096 L .60143 .52402 L F
.60359 .51912 m .60359 .52215 L .60362 .51912 L .665 .431 .556 r
F
.60359 .52215 m .6036 .5252 L .60361 .52215 L F
.60359 .52215 m .60361 .52215 L .60362 .51912 L F
.60266 .52223 m .60365 .52195 L .60266 .52222 L .667 .747 .91 r
F
.60343 .52434 m .60363 .52215 L .60266 .52223 L F
.60363 .52215 m .60365 .52195 L .60266 .52223 L F
.6036 .5252 m .60363 .52519 L .60362 .51912 L .665 .431 .556 r
F
.60363 .52526 m .60369 .52526 L .60369 .52215 L F
.60337 .52217 m .60339 .52527 L .60359 .52215 L F
.60339 .52527 m .6036 .52526 L .60359 .52215 L F
.60337 .52217 m .60259 .52224 L .60267 .52529 L F
.60337 .52217 m .60267 .52529 L .60339 .52527 L F
.60249 .52227 m .60249 .52532 L .60251 .52226 L .583 .366 .552 r
F
.60259 .52224 m .60249 .52532 L .60267 .52527 L F
.60251 .52226 m .60249 .52533 L .60259 .52224 L F
.60278 .52524 m .60391 .5237 L .60226 .52382 L .667 .747 .91 r
F
.60279 .52527 m .60281 .52524 L .60278 .52524 L F
.60281 .52524 m .60391 .5237 L .60278 .52524 L F
.60267 .52527 m .60249 .52533 L .60267 .52529 L .583 .366 .552 r
F
.60249 .52532 m .60249 .52533 L .60267 .52527 L F
.60377 .52518 m .60391 .5237 L .60279 .52527 L .667 .747 .91 r
F
.60176 .52247 m .60259 .52224 L .60163 .52232 L F
.60226 .52382 m .60095 .52022 L .59784 .52096 L F
.60391 .5237 m .60095 .52022 L .60226 .52382 L F
.60362 .51912 m .60362 .52215 L .60369 .52215 L .665 .431 .556 r
F
.60334 .51914 m .60337 .52217 L .60359 .51912 L F
.60337 .52217 m .60359 .52215 L .60359 .51912 L F
.60419 .51917 m .60362 .51912 L .60369 .52215 L .733 .485 .553 r
F
.60266 .52222 m .60377 .52063 L .60213 .52075 L .667 .747 .91 r
F
.60365 .52195 m .60377 .52063 L .60266 .52222 L F
.60443 .51919 m .60445 .52222 L .6046 .5192 L .733 .485 .553 r
F
.6047 .51921 m .60468 .52224 L .60478 .52224 L F
.60467 .51921 m .60468 .52224 L .6047 .51921 L F
.6055 .51945 m .6047 .51921 L .60478 .52224 L .805 .544 .543 r
F
.60442 .51778 m .60369 .52215 L .60445 .52222 L .733 .485 .553 r
F
.60363 .52215 m .60539 .52076 L .60377 .52063 L .667 .747 .91 r
F
.60468 .52206 m .60539 .52076 L .60363 .52215 L F
.60442 .51778 m .60362 .51912 L .60419 .51917 L .733 .485 .553 r
F
.60362 .51912 m .60524 .51772 L .60349 .5191 L .667 .747 .91 r
F
.60444 .51919 m .60452 .51904 L .60362 .51912 L F
.60443 .51919 m .6046 .5192 L .60466 .51781 L .733 .485 .553 r
F
.60466 .51781 m .60467 .51921 L .6047 .51921 L F
.60452 .51904 m .60524 .51772 L .60362 .51912 L .667 .747 .91 r
F
.60442 .51778 m .6044 .51778 L .60441 .51779 L .733 .485 .553 r
F
.6044 .51778 m .60358 .51766 L .60441 .51779 L F
.60441 .51779 m .60358 .51766 L .60362 .51912 L F
.60358 .51766 m .60359 .51912 L .60362 .51912 L .665 .431 .556 r
F
.60349 .5191 m .60524 .51772 L .60363 .51759 L .667 .747 .91 r
F
.60549 .51809 m .60466 .51781 L .6047 .51921 L .805 .544 .543 r
F
.60549 .51809 m .6047 .51921 L .6055 .51945 L F
.60444 .51919 m .60672 .51809 L .60524 .51772 L .667 .747 .91 r
F
.60544 .51928 m .60672 .51809 L .60444 .51919 L F
.60524 .51772 m .60398 .51388 L .60363 .51759 L F
.60539 .52076 m .60412 .5169 L .60377 .52063 L F
.60166 .51945 m .60168 .51935 L .60161 .51939 L F
.60168 .51935 m .602 .51771 L .60161 .51939 L F
.60254 .5192 m .602 .51771 L .60166 .51945 L F
.60377 .52063 m .60082 .51715 L .60213 .52075 L F
.60349 .51913 m .60362 .51912 L .60349 .5191 L F
.60363 .51759 m .6007 .51412 L .602 .51771 L F
.60363 .51759 m .60398 .51388 L .6007 .51412 L F
.60377 .52063 m .60412 .5169 L .60082 .51715 L F
.60391 .5237 m .60425 .51997 L .60095 .52022 L F
.60095 .52022 m .59496 .51771 L .59784 .52096 L F
.59951 .51353 m .5947 .51157 L .59483 .51464 L .602 .385 .559 r
F
.59951 .51353 m .59938 .51046 L .5947 .51157 L F
.60095 .52022 m .59964 .5166 L .59496 .51771 L .667 .747 .91 r
F
.60425 .51997 m .59964 .5166 L .60095 .52022 L F
.60532 .5194 m .60576 .51953 L .60543 .5193 L F
.60543 .5193 m .60796 .51869 L .60672 .51809 L F
.60606 .51974 m .60796 .51869 L .60543 .5193 L F
.60796 .51869 m .61016 .51489 L .60672 .51809 L F
.60672 .51809 m .6072 .51414 L .60524 .51772 L F
.60672 .51809 m .61016 .51489 L .6072 .51414 L F
.60524 .51772 m .6072 .51414 L .60398 .51388 L F
.60539 .52076 m .60736 .51717 L .60412 .5169 L F
.6072 .51414 m .60432 .51015 L .60398 .51388 L F
.60736 .51717 m .60446 .51316 L .60412 .5169 L F
.60412 .5169 m .59951 .51353 L .60082 .51715 L F
.60398 .51388 m .5994 .51051 L .6007 .51412 L F
.60398 .51388 m .60432 .51015 L .5994 .51051 L F
.60412 .5169 m .60446 .51316 L .59951 .51353 L F
.60425 .51997 m .6046 .51623 L .59964 .5166 L F
.59964 .5166 m .59951 .51353 L .59483 .51464 L .602 .385 .559 r
F
.6046 .51623 m .59951 .51353 L .59964 .5166 L .67 .437 .559 r
F
.60329 .52527 m .59744 .50941 L .60233 .52528 L .643 .738 .918 r
F
.60235 .5253 m .60233 .52528 L .60234 .5253 L F
.60329 .52527 m .60233 .52528 L .60235 .5253 L F
.60233 .52528 m .59744 .50941 L .59175 .51044 L F
.60239 .52535 m .60238 .52535 L .60238 .52535 L F
.60239 .52535 m .60238 .52535 L .60343 .52682 L F
.60204 .52945 m .60199 .52944 L .60198 .52928 L .749 .498 .552 r
F
.60356 .52741 m .60179 .52942 L .60241 .5295 L .667 .747 .91 r
F
.60228 .52538 m .60233 .53303 L .60249 .52533 L .583 .366 .552 r
F
.60109 .52586 m .60039 .52629 L .60039 .52629 L .667 .747 .91 r
F
.60115 .52575 m .60039 .52616 L .60057 .53378 L .438 .255 .533 r
F
.60115 .52575 m .60057 .53378 L .60119 .53345 L F
.60057 .53378 m .6011 .5333 L .59997 .53355 L .642 .738 .919 r
F
.60375 .53502 m .60127 .53341 L .60057 .53378 L F
.60127 .53341 m .6011 .5333 L .60057 .53378 L F
.60119 .53345 m .60057 .53378 L .60139 .5683 L .438 .255 .533 r
F
.60375 .53502 m .60197 .53686 L .6026 .53697 L .642 .738 .919 r
F
.60252 .54111 m .60439 .5717 L .60252 .54119 L .749 .498 .552 r
F
.60252 .54111 m .60252 .54119 L .60226 .53691 L F
.60226 .53692 m .60252 .54111 L .60226 .53691 L F
.60197 .53686 m .6024 .54294 L .6025 .55858 L F
.6024 .54294 m .60439 .5717 L .6025 .55858 L F
.6025 .55858 m .60439 .5717 L .60281 .57147 L F
.60226 .53691 m .60439 .5717 L .60197 .53686 L F
.60137 .53336 m .60152 .53328 L .60154 .52554 L .438 .255 .533 r
F
.60228 .52538 m .60155 .52559 L .60173 .53317 L .583 .366 .552 r
F
.60228 .52538 m .60173 .53317 L .60233 .53303 L F
.60152 .53328 m .60152 .53328 L .60155 .52559 L .438 .255 .533 r
F
.60155 .52559 m .60152 .53328 L .60173 .53317 L F
.59984 .52797 m .59726 .52739 L .59739 .52835 L .667 .747 .91 r
F
.59957 .52802 m .59739 .52835 L .59985 .52849 L F
.59087 .51948 m .59044 .51938 L .58766 .52179 L .395 .228 .533 r
F
.59044 .51938 m .58763 .52119 L .58766 .52179 L F
.58801 .52095 m .59017 .51821 L .58788 .5209 L .643 .738 .918 r
F
.5912 .51889 m .59017 .51821 L .58801 .52095 L F
.58788 .5209 m .58277 .51335 L .57743 .51682 L F
.59017 .51821 m .58277 .51335 L .58788 .5209 L F
.58766 .52179 m .58763 .52119 L .58718 .52171 L .184 .071 .482 r
F
.59756 .52643 m .59096 .52737 L .59726 .52739 L .667 .747 .91 r
F
.59756 .52643 m .59155 .52546 L .59096 .52737 L F
.59827 .52554 m .59155 .52546 L .59756 .52643 L F
.59827 .52554 m .59297 .52367 L .59155 .52546 L F
.59934 .52477 m .59297 .52367 L .59827 .52554 L F
.59934 .52477 m .59511 .52213 L .59297 .52367 L F
.59511 .52213 m .58766 .52179 L .59297 .52367 L F
.59511 .52213 m .59087 .51948 L .58766 .52179 L F
.60063 .53299 m .58931 .51869 L .58247 .52121 L .642 .738 .919 r
F
.60375 .53502 m .60205 .5331 L .6011 .5333 L F
.60375 .53502 m .60272 .5372 L .60354 .53714 L F
.60267 .52529 m .60265 .53297 L .60285 .53292 L .583 .366 .552 r
F
.60233 .53303 m .60251 .533 L .60249 .52533 L F
.60109 .52586 m .60078 .52567 L .60039 .52629 L .667 .747 .91 r
F
.60078 .52567 m .59934 .52477 L .60039 .52629 L F
.6003 .52629 m .6003 .52643 L .60039 .52616 L .07 0 .435 r
F
.6003 .52643 m .60039 .52629 L .60039 .52616 L F
.60039 .52629 m .59827 .52554 L .60004 .52683 L .667 .747 .91 r
F
.59969 .5274 m .59756 .52643 L .59726 .52739 L F
.60019 .52645 m .59981 .527 L .59982 .52719 L .07 0 .435 r
F
.60004 .52683 m .59756 .52643 L .59969 .5274 L .667 .747 .91 r
F
.59984 .52796 m .59726 .52739 L .59984 .52797 L F
.59957 .52802 m .59985 .52849 L .59984 .52823 L F
.59496 .51771 m .59481 .51766 L .59087 .51948 L .518 .32 .552 r
F
.59481 .51766 m .59085 .51912 L .59087 .51948 L F
.59087 .51948 m .59085 .51912 L .59044 .51938 L .395 .228 .533 r
F
.59124 .51887 m .5896 .51082 L .58277 .51335 L .643 .738 .918 r
F
.59437 .51686 m .5896 .51082 L .59124 .51887 L F
.6007 .52419 m .59511 .52213 L .59934 .52477 L .667 .747 .91 r
F
.6007 .52419 m .59784 .52096 L .59511 .52213 L F
.59784 .52096 m .59087 .51948 L .59511 .52213 L F
.59784 .52096 m .59496 .51771 L .59087 .51948 L F
.60192 .53295 m .59717 .51729 L .58931 .51869 L .642 .738 .919 r
F
.60249 .52533 m .60251 .533 L .60267 .52529 L .583 .366 .552 r
F
.60375 .53502 m .60285 .53292 L .60205 .5331 L .642 .738 .919 r
F
.60251 .533 m .60256 .56761 L .60265 .53297 L .583 .366 .552 r
F
.60251 .533 m .60265 .53297 L .60267 .52529 L F
.60375 .53502 m .60297 .53292 L .60285 .53292 L .642 .738 .919 r
F
.60205 .5331 m .60285 .53292 L .60192 .53295 L F
.60356 .52741 m .60359 .52705 L .60327 .52659 L .667 .747 .91 r
F
.6036 .52526 m .60363 .52526 L .60363 .52519 L .665 .431 .556 r
F
.60448 .52525 m .60377 .52518 L .60377 .52526 L .733 .485 .553 r
F
.60448 .52525 m .60377 .52526 L .60447 .52535 L F
.60377 .52518 m .60377 .52526 L .60377 .52526 L .665 .431 .556 r
F
.60425 .52466 m .60553 .52383 L .60434 .52373 L .667 .747 .91 r
F
.60425 .52466 m .60434 .52373 L .60391 .5237 L F
.60379 .52496 m .60425 .52466 L .60391 .5237 L F
.60377 .52518 m .60398 .52502 L .60379 .52496 L F
.60398 .52502 m .60553 .52383 L .60379 .52496 L F
.60477 .5251 m .60553 .52383 L .60377 .52518 L F
.60369 .52519 m .60369 .52526 L .60377 .52518 L .665 .431 .556 r
F
.604 .52719 m .60419 .52524 L .60329 .52527 L .643 .738 .918 r
F
.604 .52719 m .60364 .52712 L .60368 .52717 L F
.604 .52719 m .60343 .52682 L .60358 .52703 L F
.604 .52719 m .60372 .52722 L .60374 .52726 L F
.60356 .52741 m .60382 .52737 L .60379 .52733 L .667 .747 .91 r
F
.60356 .52741 m .60379 .52733 L .60377 .52729 L F
.60356 .52741 m .60389 .52746 L .60388 .52745 L F
.60356 .52741 m .60385 .52741 L .60382 .52737 L F
.60375 .53502 m .60354 .53714 L .60451 .53707 L .642 .738 .919 r
F
.60356 .52741 m .60408 .52773 L .60394 .52754 L .667 .747 .91 r
F
.60369 .52526 m .60369 .5329 L .60377 .52526 L .665 .431 .556 r
F
.60369 .5329 m .60376 .53289 L .60377 .52526 L F
.60369 .52526 m .60377 .52526 L .60377 .52518 L F
.6072 .51414 m .60917 .51054 L .60432 .51015 L .667 .747 .91 r
F
.61016 .51489 m .60917 .51054 L .6072 .51414 L F
.60736 .51717 m .60935 .51355 L .60446 .51316 L F
.60669 .52017 m .60748 .52004 L .60727 .51998 L F
.6068 .52025 m .60748 .52004 L .60669 .52017 L F
.60727 .51998 m .60897 .5196 L .60855 .51956 L F
.60748 .52004 m .60897 .5196 L .60727 .51998 L F
.60688 .52114 m .60736 .51717 L .60539 .52076 L F
.60748 .52004 m .60942 .52035 L .60897 .5196 L F
.60881 .52044 m .60942 .52035 L .60748 .52004 L F
.607 .52073 m .60694 .5206 L .60698 .52104 L .978 .72 .315 r
F
.60694 .5206 m .60678 .52024 L .60698 .52104 L F
.60698 .52104 m .60678 .52024 L .60686 .52327 L F
.60888 .51945 m .61265 .51608 L .60796 .51869 L .667 .747 .91 r
F
.60796 .51869 m .61265 .51608 L .61016 .51489 L F
.60688 .52114 m .61034 .51792 L .60736 .51717 L F
.6075 .52024 m .6046 .51623 L .60425 .51997 L F
.61034 .51792 m .60935 .51355 L .60736 .51717 L F
.6075 .52024 m .60949 .51663 L .6046 .51623 L F
.60935 .51355 m .6092 .51049 L .60433 .51009 L .73 .484 .556 r
F
.60446 .51316 m .59938 .51046 L .59951 .51353 L .67 .437 .559 r
F
.60446 .51316 m .60433 .51009 L .59938 .51046 L F
.60935 .51355 m .60433 .51009 L .60446 .51316 L .73 .484 .556 r
F
.60949 .51663 m .60935 .51355 L .60446 .51316 L F
.6046 .51623 m .60446 .51316 L .59951 .51353 L .67 .437 .559 r
F
.60949 .51663 m .60446 .51316 L .6046 .51623 L .73 .484 .556 r
F
.60329 .52527 m .60575 .50923 L .59744 .50941 L .643 .738 .918 r
F
.60555 .52237 m .60502 .522 L .60461 .52219 L .667 .747 .91 r
F
.60678 .52024 m .6068 .52322 L .60686 .52327 L .906 .63 .507 r
F
.6048 .52184 m .60688 .52114 L .60539 .52076 L .667 .747 .91 r
F
.60461 .52219 m .60502 .522 L .6048 .52184 L F
.60502 .522 m .60688 .52114 L .6048 .52184 L F
.60553 .52383 m .60425 .51997 L .60391 .5237 L F
.60555 .52237 m .60688 .52114 L .60502 .522 L F
.60546 .52245 m .60648 .5224 L .6056 .52232 L F
.6061 .52264 m .60648 .5224 L .60546 .52245 L F
.6056 .52232 m .60648 .5224 L .6062 .52177 L F
.6062 .52177 m .60813 .52173 L .60688 .52114 L F
.60656 .5226 m .60813 .52173 L .6062 .52177 L F
.60855 .51956 m .60897 .5196 L .60888 .51945 L F
.607 .52072 m .60747 .5213 L .60804 .52056 L F
.60725 .5213 m .60747 .5213 L .607 .52072 L F
.60747 .5213 m .60955 .5213 L .60804 .52056 L F
.60725 .5213 m .60733 .52148 L .60747 .5213 L F
.60942 .52035 m .61449 .51762 L .60888 .51945 L F
.60888 .51945 m .61449 .51762 L .61265 .51608 L F
.60813 .52173 m .61034 .51792 L .60688 .52114 L F
.60553 .52383 m .6075 .52024 L .60425 .51997 L F
.60419 .52524 m .60575 .50923 L .60329 .52527 L .643 .738 .918 r
F
.60339 .52527 m .60267 .52529 L .60285 .53292 L .665 .431 .556 r
F
.60375 .53502 m .60396 .53289 L .60297 .53292 L .642 .738 .919 r
F
.60345 .5329 m .60285 .53292 L .6037 .56731 L .665 .431 .556 r
F
.60339 .52527 m .60285 .53292 L .60345 .5329 L F
.60339 .52527 m .60345 .5329 L .6036 .52526 L F
.60345 .5329 m .60362 .5329 L .6036 .52526 L F
.60363 .52526 m .60364 .5329 L .60369 .52526 L F
.60364 .5329 m .60369 .5329 L .60369 .52526 L F
.60356 .52741 m .60369 .52718 L .60359 .52705 L .667 .747 .91 r
F
.6036 .52526 m .60362 .5329 L .60363 .52526 L .665 .431 .556 r
F
.60362 .5329 m .60364 .5329 L .60363 .52526 L F
.60154 .52554 m .60154 .52559 L .60155 .52559 L .438 .255 .533 r
F
.60109 .52586 m .60155 .52559 L .60092 .52576 L .667 .747 .91 r
F
.60228 .52538 m .60154 .52554 L .60155 .52559 L .583 .366 .552 r
F
.60187 .5255 m .6007 .52419 L .60092 .52576 L .667 .747 .91 r
F
.604 .52719 m .60386 .52742 L .60386 .52743 L .643 .738 .918 r
F
.604 .52719 m .60381 .52735 L .60386 .52742 L F
.604 .52719 m .60386 .52743 L .60397 .52757 L F
.604 .52719 m .60397 .52757 L .60433 .52809 L F
.60447 .52535 m .60377 .52526 L .60396 .53289 L .733 .485 .553 r
F
.60377 .52526 m .60376 .53289 L .60396 .53289 L .665 .431 .556 r
F
.60377 .52526 m .60376 .53289 L .60377 .52526 L F
.60448 .52535 m .60469 .52538 L .60469 .52527 L .733 .485 .553 r
F
.60419 .52531 m .60486 .5254 L .6042 .52518 L .643 .738 .918 r
F
.61265 .51608 m .61362 .51167 L .61016 .51489 L .667 .747 .91 r
F
.61016 .51489 m .61362 .51167 L .60917 .51054 L F
.61265 .51608 m .61735 .51346 L .61362 .51167 L F
.61034 .51792 m .61382 .51469 L .60935 .51355 L F
.61382 .51469 m .61367 .51163 L .6092 .51049 L .791 .532 .547 r
F
.60955 .5213 m .61556 .51941 L .60942 .52035 L .667 .747 .91 r
F
.60942 .52035 m .61556 .51941 L .61449 .51762 L F
.60924 .52226 m .61518 .52323 L .6158 .52132 L F
.60924 .52226 m .6158 .52132 L .60955 .5213 L F
.60955 .5213 m .6158 .52132 L .61556 .51941 L F
.60905 .5225 m .61284 .51911 L .60813 .52173 L F
.60813 .52173 m .61284 .51911 L .61034 .51792 L F
.61048 .52099 m .60949 .51663 L .6075 .52024 L F
.61449 .51762 m .61735 .51346 L .61265 .51608 L F
.61284 .51911 m .61382 .51469 L .61034 .51792 L F
.61556 .51941 m .62011 .51578 L .61449 .51762 L F
.61449 .51762 m .62011 .51578 L .61735 .51346 L F
.61284 .51911 m .61757 .51649 L .61382 .51469 L F
.61048 .52099 m .61396 .51776 L .60949 .51663 L F
.61382 .51469 m .6092 .51049 L .60935 .51355 L .791 .532 .547 r
F
.61396 .51776 m .61382 .51469 L .60935 .51355 L F
.61396 .51776 m .60935 .51355 L .60949 .51663 L F
.6042 .52518 m .61393 .51028 L .60575 .50923 L .643 .738 .918 r
F
.60448 .52525 m .60448 .52535 L .60469 .52527 L .733 .485 .553 r
F
.60474 .52527 m .60485 .52528 L .60475 .52525 L .667 .747 .91 r
F
.6061 .52264 m .60656 .5226 L .60648 .5224 L F
.60636 .52272 m .60656 .5226 L .6061 .52264 L F
.60475 .52525 m .60524 .52513 L .60493 .52492 L F
.6063 .52487 m .60702 .5242 L .60588 .52392 L F
.6063 .52487 m .60588 .52392 L .60553 .52383 L F
.60638 .52294 m .60684 .52323 L .60666 .52281 L F
.60681 .52324 m .60684 .52323 L .60638 .52294 L F
.60636 .52272 m .60666 .52281 L .60656 .5226 L F
.60656 .5226 m .60905 .5225 L .60813 .52173 L F
.60684 .52323 m .60905 .5225 L .60656 .5226 L F
.60681 .52324 m .60914 .52264 L .60875 .5226 L F
.60691 .5233 m .60914 .52264 L .60681 .52324 L F
.60702 .5242 m .6075 .52024 L .60553 .52383 L F
.60709 .52378 m .60829 .52436 L .6096 .5234 L F
.60734 .52435 m .60829 .52436 L .60709 .52378 L F
.60702 .5242 m .61048 .52099 L .6075 .52024 L F
.60502 .52546 m .61393 .51028 L .6042 .52518 L .643 .738 .918 r
F
.60187 .5255 m .60202 .52484 L .6007 .52419 L .667 .747 .91 r
F
.60202 .52484 m .60143 .52402 L .6007 .52419 L F
.60297 .53292 m .6055 .5171 L .59717 .51729 L .642 .738 .919 r
F
.60396 .53289 m .6055 .5171 L .60297 .53292 L F
.60369 .5329 m .6037 .56731 L .60376 .53289 L .665 .431 .556 r
F
.60297 .53292 m .59717 .51729 L .60192 .53295 L .642 .738 .919 r
F
.60345 .5329 m .6037 .56731 L .60362 .5329 L .665 .431 .556 r
F
.60285 .53292 m .60256 .56761 L .6037 .56731 L .583 .366 .552 r
F
.60265 .53297 m .60256 .56761 L .60285 .53292 L F
.6011 .5333 m .60192 .53295 L .60063 .53299 L .642 .738 .919 r
F
.60205 .5331 m .60192 .53295 L .6011 .5333 L F
.60192 .53295 m .58931 .51869 L .60063 .53299 L F
.60364 .5329 m .6037 .56731 L .60369 .5329 L .665 .431 .556 r
F
.60233 .53303 m .60256 .56761 L .60251 .533 L .583 .366 .552 r
F
.59997 .53355 m .60063 .53299 L .59869 .53305 L .642 .738 .919 r
F
.6011 .5333 m .60063 .53299 L .59997 .53355 L F
.60063 .53299 m .58247 .52121 L .59869 .53305 L F
.60362 .5329 m .6037 .56731 L .60364 .5329 L .665 .431 .556 r
F
.60137 .53336 m .60139 .5683 L .60152 .53328 L .438 .255 .533 r
F
.59978 .5342 m .59997 .53355 L .59833 .5339 L .642 .738 .919 r
F
.60057 .53378 m .59997 .53355 L .59978 .5342 L F
.59997 .53355 m .57711 .52466 L .59833 .5339 L F
.60233 .53303 m .60173 .53317 L .60256 .56761 L .583 .366 .552 r
F
.60152 .53328 m .60139 .5683 L .60152 .53328 L .438 .255 .533 r
F
.60173 .53317 m .60139 .5683 L .60256 .56761 L F
.60152 .53328 m .60139 .5683 L .60173 .53317 L F
.60119 .53345 m .60139 .5683 L .60137 .53336 L F
.6008 .56899 m .60083 .56992 L .6008 .56899 L .712 .567 0 r
F
.6008 .56899 m .6008 .56899 L .6 .53484 L F
.6 .53494 m .6008 .56899 L .6 .53484 L F
.6 .53479 m .60083 .56992 L .59999 .53475 L F
.6 .53484 m .60083 .56992 L .6 .53479 L F
.60012 .5355 m .60118 .57053 L .60007 .53542 L .988 .718 .377 r
F
.60001 .53531 m .60118 .57053 L .60083 .56992 L F
.60007 .53542 m .60118 .57053 L .60001 .53531 L F
.60017 .53559 m .60118 .57053 L .60012 .5355 L F
.59999 .53463 m .60083 .56992 L .60081 .5692 L .712 .567 0 r
F
.59999 .53475 m .60083 .56992 L .59999 .53463 L F
.60017 .53559 m .60036 .53591 L .60118 .57053 L .988 .718 .377 r
F
.6 .53494 m .60001 .53531 L .60083 .56992 L .712 .567 0 r
F
.60039 .53404 m .60081 .5692 L .60046 .53394 L .07 0 .435 r
F
.59775 .53791 m .5757 .54239 L .58038 .54628 L .642 .738 .919 r
F
.5983 .53711 m .5757 .54239 L .59775 .53791 L F
.60057 .53378 m .60081 .5692 L .60139 .5683 L .07 0 .435 r
F
.60046 .53394 m .60081 .5692 L .60057 .53378 L F
.59432 .54293 m .58038 .54628 L .58663 .54938 L .642 .738 .919 r
F
.59775 .53791 m .58038 .54628 L .59432 .54293 L F
.6003 .53417 m .60081 .5692 L .60039 .53404 L .07 0 .435 r
F
.6003 .53417 m .59999 .53463 L .60081 .5692 L F
.59404 .54334 m .58663 .54938 L .59358 .54401 L .642 .738 .919 r
F
.60396 .53289 m .6037 .56731 L .60481 .56723 L .665 .431 .556 r
F
.60376 .53289 m .6037 .56731 L .60396 .53289 L F
.60478 .52539 m .60481 .56723 L .60486 .5254 L .733 .485 .553 r
F
.60396 .53289 m .60512 .53269 L .60405 .53193 L .642 .738 .919 r
F
.60493 .53302 m .60512 .53269 L .60396 .53289 L F
.60454 .53297 m .60396 .53289 L .60481 .56723 L .733 .485 .553 r
F
.60485 .53301 m .60481 .56723 L .60505 .53304 L F
.60562 .53323 m .60591 .56734 L .60578 .53328 L .805 .544 .543 r
F
.60562 .53323 m .60578 .53328 L .60575 .52555 L F
.60562 .53323 m .60505 .53304 L .60591 .56734 L F
.60779 .53395 m .61305 .53412 L .60917 .53359 L .642 .738 .919 r
F
.60935 .53448 m .61305 .53412 L .60779 .53395 L F
.61305 .53412 m .6348 .53203 L .60917 .53359 L F
.60454 .53297 m .60481 .56723 L .60471 .53299 L .733 .485 .553 r
F
.60586 .53331 m .60591 .56734 L .60592 .53333 L .805 .544 .543 r
F
.60586 .53331 m .60592 .53333 L .60592 .52576 L F
.61518 .52323 m .62205 .52134 L .6158 .52132 L .667 .747 .91 r
F
.6158 .52132 m .62205 .52134 L .62171 .51847 L F
.6223 .52439 m .62215 .52134 L .6218 .51845 L .785 .599 .034 r
F
.60941 .52532 m .61601 .52438 L .60972 .52436 L .667 .747 .91 r
F
.6223 .52439 m .6218 .51845 L .62196 .52151 L .785 .599 .034 r
F
.61601 .52438 m .62196 .52151 L .61577 .52246 L .667 .747 .91 r
F
.60972 .52436 m .61601 .52438 L .61577 .52246 L F
.60974 .52646 m .61484 .52373 L .6092 .52557 L F
.60974 .52646 m .61592 .52552 L .61484 .52373 L F
.6158 .52132 m .62171 .51847 L .61556 .51941 L F
.61577 .52246 m .62196 .52151 L .62034 .51881 L F
.62211 .52458 m .62196 .52151 L .62034 .51881 L .986 .708 .363 r
F
.61592 .52552 m .6205 .52188 L .61484 .52373 L .667 .747 .91 r
F
.61592 .52552 m .62211 .52458 L .6205 .52188 L F
.62211 .52458 m .62034 .51881 L .6205 .52188 L .986 .708 .363 r
F
.60686 .52644 m .63498 .52419 L .63232 .51971 L .643 .738 .918 r
F
.60745 .52686 m .63498 .52419 L .60686 .52644 L F
.60671 .53359 m .63213 .52756 L .62749 .52358 L .642 .738 .919 r
F
.60779 .53395 m .63213 .52756 L .60671 .53359 L F
.60666 .53378 m .60699 .56768 L .60682 .5339 L .906 .63 .507 r
F
.60652 .52602 m .60694 .5263 L .60678 .52595 L .667 .747 .91 r
F
.60652 .52602 m .60678 .52595 L .60667 .52569 L F
.60632 .52588 m .60652 .52602 L .60667 .52569 L F
.60694 .5263 m .60694 .5263 L .60632 .52588 L F
.60667 .52569 m .6092 .52557 L .60827 .5248 L F
.60694 .5263 m .6092 .52557 L .60667 .52569 L F
.60972 .52436 m .61577 .52246 L .6096 .5234 L F
.6096 .5234 m .61577 .52246 L .61469 .52066 L F
.61556 .51941 m .62171 .51847 L .62011 .51578 L F
.62196 .52151 m .6218 .51845 L .62019 .51575 L .986 .708 .363 r
F
.61577 .52246 m .62034 .51881 L .61469 .52066 L .667 .747 .91 r
F
.62196 .52151 m .62019 .51575 L .62034 .51881 L .986 .708 .363 r
F
.60829 .52436 m .60972 .52436 L .6096 .52345 L .667 .747 .91 r
F
.6092 .52557 m .61299 .52218 L .60827 .5248 L F
.6092 .52557 m .61484 .52373 L .61299 .52218 L F
.61469 .52066 m .62034 .51881 L .61757 .51649 L F
.61484 .52373 m .61772 .51956 L .61299 .52218 L F
.61484 .52373 m .6205 .52188 L .61772 .51956 L F
.6205 .52188 m .62034 .51881 L .61757 .51649 L .932 .65 .483 r
F
.6205 .52188 m .61757 .51649 L .61772 .51956 L F
.60634 .52606 m .63232 .51971 L .62769 .51571 L .643 .738 .918 r
F
.60659 .52606 m .60659 .52624 L .60679 .5262 L .906 .63 .507 r
F
.60659 .52624 m .60679 .52638 L .60679 .5262 L F
.60687 .52626 m .60687 .52644 L .60694 .5263 L F
.60687 .52644 m .60694 .52649 L .60694 .5263 L F
.60686 .52644 m .63232 .51971 L .60634 .52606 L .643 .738 .918 r
F
.60581 .53329 m .62749 .52358 L .62121 .52037 L .642 .738 .919 r
F
.60671 .53359 m .62749 .52358 L .60581 .53329 L F
.60611 .53339 m .60591 .56734 L .60699 .56768 L .805 .544 .543 r
F
.60592 .53333 m .60591 .56734 L .60611 .53339 L F
.60578 .53328 m .60591 .56734 L .6058 .53329 L F
.60578 .53328 m .6058 .53329 L .60578 .52572 L F
.60564 .53323 m .60588 .53323 L .60574 .53313 L .642 .738 .919 r
F
.60581 .53329 m .60588 .53323 L .60564 .53323 L F
.60493 .53302 m .60574 .53313 L .60512 .53269 L F
.60471 .53299 m .60481 .56723 L .60478 .533 L .733 .485 .553 r
F
.60905 .5225 m .61469 .52066 L .61284 .51911 L .667 .747 .91 r
F
.61469 .52066 m .61757 .51649 L .61284 .51911 L F
.62034 .51881 m .62019 .51575 L .61742 .51342 L .932 .65 .483 r
F
.6096 .5234 m .61469 .52066 L .60905 .5225 L .667 .747 .91 r
F
.60827 .5248 m .61048 .52099 L .60702 .5242 L F
.60829 .52436 m .6096 .52345 L .6096 .5234 L F
.60827 .5248 m .61299 .52218 L .61048 .52099 L F
.62034 .51881 m .61742 .51342 L .61757 .51649 L .932 .65 .483 r
F
.61757 .51649 m .61742 .51342 L .61367 .51163 L .857 .586 .527 r
F
.61299 .52218 m .61396 .51776 L .61048 .52099 L .667 .747 .91 r
F
.61299 .52218 m .61772 .51956 L .61396 .51776 L F
.61757 .51649 m .61367 .51163 L .61382 .51469 L .857 .586 .527 r
F
.61772 .51956 m .61757 .51649 L .61382 .51469 L F
.61772 .51956 m .61382 .51469 L .61396 .51776 L F
.60516 .52522 m .62142 .5125 L .61393 .51028 L .643 .738 .918 r
F
.60504 .52543 m .60523 .52527 L .60516 .52522 L F
.60523 .52527 m .62142 .5125 L .60516 .52522 L F
.60708 .52494 m .60741 .5245 L .60734 .52435 L .667 .747 .91 r
F
.6063 .52487 m .60827 .5248 L .60702 .5242 L F
.60667 .52569 m .60827 .5248 L .6063 .52487 L F
.60653 .52597 m .62769 .51571 L .60581 .52569 L .643 .738 .918 r
F
.60592 .52576 m .60581 .52569 L .60576 .52571 L F
.60653 .52597 m .60581 .52569 L .60592 .52576 L F
.6058 .52568 m .62769 .51571 L .62142 .5125 L F
.60581 .52569 m .62769 .51571 L .6058 .52568 L F
.60561 .52551 m .60592 .5256 L .60568 .52544 L .667 .747 .91 r
F
.60594 .52555 m .62142 .5125 L .60504 .52543 L .643 .738 .918 r
F
.60867 .52744 m .60882 .52819 L .61084 .52755 L F
.60779 .52798 m .60882 .52819 L .60867 .52744 L F
.60512 .53269 m .62121 .52037 L .6137 .51815 L .642 .738 .919 r
F
.60588 .53323 m .62121 .52037 L .60512 .53269 L F
.60682 .5339 m .60699 .56768 L .60684 .53391 L .906 .63 .507 r
F
.60576 .52571 m .60581 .52569 L .6058 .52568 L .643 .738 .918 r
F
.6058 .53329 m .60591 .56734 L .60586 .53331 L .805 .544 .543 r
F
.60575 .52555 m .60575 .52571 L .60578 .52556 L F
.60575 .52571 m .60578 .52572 L .60578 .52556 L F
.60502 .52546 m .60594 .52555 L .60504 .52543 L .643 .738 .918 r
F
.60576 .52571 m .60594 .52555 L .60502 .52546 L F
.60405 .53193 m .6137 .51815 L .6055 .5171 L .642 .738 .919 r
F
.60512 .53269 m .6137 .51815 L .60405 .53193 L F
.60666 .53378 m .60611 .53339 L .60699 .56768 L .906 .63 .507 r
F
.59665 .51731 m .59495 .51761 L .59496 .51771 L .602 .385 .559 r
F
.59496 .51771 m .59495 .51761 L .59481 .51766 L .518 .32 .552 r
F
.59542 .51744 m .5896 .51082 L .59535 .51747 L .643 .738 .918 r
F
.60693 .53625 m .60828 .57004 L .60781 .57064 L .163 .05 .467 r
F
.60701 .53615 m .60828 .57004 L .60693 .53625 L F
.60689 .53395 m .60699 .56768 L .60695 .53399 L .906 .63 .507 r
F
.60808 .53555 m .60846 .53599 L .60937 .53571 L .642 .738 .919 r
F
.60764 .53582 m .60846 .53599 L .60808 .53555 L F
.60684 .53391 m .60699 .56768 L .60689 .53395 L .906 .63 .507 r
F
.60877 .53528 m .60937 .53571 L .61044 .53537 L .642 .738 .919 r
F
.60846 .53599 m .63372 .54119 L .61044 .53537 L F
.60747 .53538 m .60755 .53502 L .60844 .56932 L 0 0 .235 r
F
.60707 .53608 m .60828 .57004 L .60702 .53615 L .163 .05 .467 r
F
.60702 .53615 m .60828 .57004 L .60701 .53615 L F
.60715 .53599 m .60828 .57004 L .60707 .53608 L F
.60714 .53412 m .60699 .56768 L .60803 .5684 L .906 .63 .507 r
F
.60695 .53399 m .60699 .56768 L .60714 .53412 L F
.61401 .53901 m .6262 .54767 L .63009 .54526 L .642 .738 .919 r
F
.60736 .5346 m .60714 .53412 L .60803 .5684 L .978 .72 .315 r
F
.60747 .53538 m .60844 .56932 L .60744 .53549 L 0 0 .235 r
F
.60754 .53871 m .60844 .56932 L .60754 .53896 L F
.60754 .53871 m .60754 .53896 L .60744 .5355 L F
.60744 .53549 m .60754 .53871 L .60744 .5355 L F
.60743 .53553 m .60844 .56932 L .60742 .53557 L F
.60739 .5357 m .60844 .56932 L .60828 .57004 L F
.60742 .53557 m .60844 .56932 L .60739 .5357 L F
.60744 .5355 m .60844 .56932 L .60743 .53553 L F
.60742 .53474 m .60803 .5684 L .60747 .53485 L .978 .72 .315 r
F
.60755 .53502 m .60803 .5684 L .60844 .56932 L F
.60747 .53485 m .60803 .5684 L .60755 .53502 L F
.60736 .5346 m .60803 .5684 L .60742 .53474 L F
.49191 .65638 m .51667 .65575 L .51463 .64653 L .654 .782 .942 r
F
.51735 .66191 m .51705 .65574 L .51499 .64648 L .864 .655 .122 r
F
0 g
.51501 .66197 m
.51661 .65708 L
s
.51116 .55308 m .51162 .54532 L .49252 .536 L .848 .601 .566 r
F
0 g
.51162 .54532 m
.51396 .5472 L
s
.4134 .56245 m .39733 .54664 L .37822 .5539 L .641 .739 .92 r
F
0 g
.37111 .55883 m
.37822 .5539 L
s
.42834 .55981 m .39733 .54664 L .4134 .56245 L .641 .739 .92 r
F
.46117 .55372 m .445 .53424 L .44507 .5517 L .642 .739 .919 r
F
.46117 .55372 m .46941 .53733 L .445 .53424 L F
.47558 .56572 m .46885 .54516 L .4606 .56151 L .641 .739 .92 r
F
.47558 .56572 m .49151 .5516 L .46885 .54516 L F
0 g
.72101 .53187 m
.726 .53335 L
s
.76787 .53874 m .76434 .55614 L .78888 .55565 L .643 .738 .918 r
F
.75181 .53668 m .76434 .55614 L .76787 .53874 L F
.75181 .53668 m .74051 .5531 L .76434 .55614 L F
.8124 .54388 m .81218 .53613 L .83355 .5288 L .535 .34 .563 r
F
0 g
.80715 .53699 m
.81218 .53613 L
s
.49191 .65638 m .51463 .64653 L .49043 .65025 L .654 .782 .942 r
F
.46712 .65701 m .49191 .65638 L .49043 .65025 L F
.31579 .53397 m .3245 .55469 L .33126 .5383 L .641 .739 .92 r
F
.31579 .53397 m .3015 .54832 L .3245 .55469 L F
0 g
.3245 .55469 m
.34876 .55772 L
s
.41763 .67066 m .39452 .67737 L .41855 .6737 L .653 .784 .944 r
F
.41763 .67066 m .39256 .6713 L .39452 .67737 L F
.46712 .65701 m .49043 .65025 L .46632 .65395 L .654 .782 .942 r
F
.73727 .53235 m .74051 .5531 L .75181 .53668 L .643 .738 .918 r
F
.73727 .53235 m .71887 .54672 L .74051 .5531 L F
0 g
.74051 .5531 m
.76434 .55614 L
s
.78888 .55565 m .8124 .54388 L .81262 .55166 L .61 .399 .57 r
F
.78441 .53839 m .78888 .55565 L .81262 .55166 L .643 .738 .918 r
F
0 g
.76434 .55614 m
.78888 .55565 L
s
.51735 .66191 m .51499 .64648 L .51529 .65267 L .864 .655 .122 r
F
.49242 .66254 m .51735 .66191 L .51529 .65267 L .654 .783 .943 r
F
.51765 .66809 m .51735 .66191 L .51529 .65267 L .864 .655 .122 r
F
0 g
.5153 .66815 m
.51691 .66325 L
s
.28121 .53898 m .30243 .54056 L .3015 .54832 L .84 .601 .578 r
F
.28121 .53898 m .28219 .53119 L .30243 .54056 L F
.30314 .51982 m .30243 .54056 L .31669 .52617 L .642 .738 .919 r
F
.30314 .51982 m .28219 .53119 L .30243 .54056 L F
0 g
.30243 .54056 m
.30776 .54204 L
s
.46679 .67246 m .49268 .66873 L .46769 .66937 L .653 .784 .944 r
F
.41825 .65517 m .3926 .65891 L .41747 .65827 L .654 .782 .942 r
F
.49242 .66254 m .51529 .65267 L .49093 .6564 L .654 .783 .943 r
F
.46747 .66318 m .49242 .66254 L .49093 .6564 L F
.65627 .54759 m .6932 .54563 L .66364 .53952 L .643 .738 .918 r
F
0 g
.68718 .54438 m
.69325 .53786 L
s
.50948 .52222 m .51262 .52836 L .51217 .5361 L .932 .75 .272 r
F
.50948 .52222 m .50995 .51444 L .51262 .52836 L F
0 g
.51262 .52836 m
.51747 .53558 L
s
.54169 .51611 m .51308 .52831 L .54329 .52536 L .644 .737 .917 r
F
.54169 .51611 m .51042 .51446 L .51308 .52831 L F
.51116 .55308 m .49252 .536 L .49202 .54378 L .848 .601 .566 r
F
.5107 .56088 m .51116 .55308 L .49202 .54378 L F
0 g
.51116 .55308 m
.52335 .5628 L
s
.42834 .55981 m .41994 .54258 L .39733 .54664 L .641 .739 .92 r
F
.44446 .55948 m .41994 .54258 L .42834 .55981 L F
.4606 .56151 m .44439 .54207 L .44446 .55948 L F
.4606 .56151 m .46885 .54516 L .44439 .54207 L F
.35061 .41571 m .34864 .47712 L .34705 .47731 L .644 .409 .547 r
F
.35061 .41571 m .35216 .41552 L .34864 .47712 L F
.34902 .41547 m .35061 .41571 L .34705 .47731 L .749 .499 .553 r
F
0 g
.35061 .41571 m
.35061 .41571 L
s
.70079 .53736 m .71886 .53896 L .71887 .54672 L .857 .601 .55 r
F
.72516 .51818 m .71886 .53896 L .73722 .52454 L .644 .737 .917 r
F
0 g
.71886 .53896 m
.72608 .54109 L
s
.39405 .65269 m .36771 .65954 L .3926 .65891 L .654 .782 .942 r
F
.41825 .65517 m .39405 .65269 L .3926 .65891 L F
.46747 .66318 m .49093 .6564 L .46667 .66012 L .654 .783 .943 r
F
.35216 .41552 m .34964 .47672 L .34864 .47712 L .516 .302 .527 r
F
.35216 .41552 m .35314 .41511 L .34964 .47672 L F
0 g
.35061 .41571 m
.35216 .41552 L
s
.34902 .41547 m .34705 .47731 L .34544 .47707 L .749 .499 .553 r
F
.348 .41502 m .34902 .41547 L .34544 .47707 L .834 .575 .548 r
F
0 g
.34902 .41547 m
.35061 .41571 L
s
.8124 .54388 m .83355 .5288 L .83382 .53657 L .535 .34 .563 r
F
.81262 .55166 m .8124 .54388 L .83382 .53657 L F
.80019 .52785 m .8124 .54388 L .83382 .53657 L .644 .737 .917 r
F
0 g
.8004 .54591 m
.8124 .54388 L
s
.35314 .41511 m .3503 .47619 L .34964 .47672 L .335 .155 .483 r
F
.35314 .41511 m .35379 .41458 L .3503 .47619 L F
0 g
.35216 .41552 m
.35314 .41511 L
s
.348 .41502 m .34544 .47707 L .34439 .47663 L .834 .575 .548 r
F
.34729 .41446 m .348 .41502 L .34439 .47663 L .909 .647 .529 r
F
0 g
.348 .41502 m
.34902 .41547 L
s
.39405 .65269 m .36971 .65019 L .36771 .65954 L .654 .782 .942 r
F
.36941 .65637 m .36734 .65955 L .3674 .66574 L 0 0 .207 r
F
0 g
.36819 .66206 m
.36942 .66569 L
s
.36941 .65637 m .36934 .65015 L .36734 .65955 L 0 0 .207 r
F
.51765 .66809 m .51529 .65267 L .51559 .65889 L .864 .655 .122 r
F
.49268 .66873 m .51765 .66809 L .51559 .65889 L .653 .784 .944 r
F
0 g
.51461 .6773 m
.51765 .66809 L
s
.35379 .41458 m .35068 .47556 L .3503 .47619 L 0 0 .355 r
F
.35379 .41458 m .35416 .41394 L .35068 .47556 L F
0 g
.35314 .41511 m
.35379 .41458 L
s
.44446 .55948 m .44439 .54207 L .41994 .54258 L .641 .739 .92 r
F
.34729 .41446 m .34439 .47663 L .34367 .47608 L .909 .647 .529 r
F
.34685 .41381 m .34729 .41446 L .34367 .47608 L .981 .727 .472 r
F
0 g
.34729 .41446 m
.348 .41502 L
s
.46632 .65395 m .48563 .64457 L .46388 .65113 L .654 .782 .942 r
F
.46632 .65395 m .49043 .65025 L .48563 .64457 L F
.35416 .41394 m .35072 .47481 L .35068 .47556 L 0 0 0 r
F
.35416 .41394 m .35421 .41317 L .35072 .47481 L F
0 g
.35379 .41458 m
.35416 .41394 L
s
.34685 .41381 m .34367 .47608 L .34322 .47544 L .981 .727 .472 r
F
.34673 .41304 m .34685 .41381 L .34322 .47544 L .923 .74 .252 r
F
0 g
.34685 .41381 m
.34729 .41446 L
s
.41827 .66135 m .39246 .6651 L .41749 .66446 L .654 .783 .943 r
F
.49268 .66873 m .51559 .65889 L .49119 .66261 L .653 .784 .944 r
F
.46769 .66937 m .49268 .66873 L .49119 .66261 L F
.3022 .52764 m .3015 .54832 L .31579 .53397 L .641 .739 .92 r
F
.3022 .52764 m .28121 .53898 L .3015 .54832 L F
0 g
.3015 .54832 m
.3245 .55469 L
s
.35421 .41317 m .35017 .47384 L .35072 .47481 L .992 .745 .442 r
F
.35421 .41317 m .35367 .41219 L .35017 .47384 L F
.34673 .41304 m .34322 .47544 L .34309 .47468 L .923 .74 .252 r
F
.34716 .41208 m .34673 .41304 L .34309 .47468 L 0 0 .29 r
F
.39391 .65887 m .3674 .66574 L .39246 .6651 L .654 .783 .943 r
F
.41827 .66135 m .39391 .65887 L .39246 .6651 L F
.46769 .66937 m .49119 .66261 L .46689 .66632 L .653 .784 .944 r
F
.57289 .53799 m .54796 .54968 L .5757 .54239 L .642 .738 .919 r
F
.57289 .53799 m .54221 .54094 L .54796 .54968 L F
.42068 .65223 m .39405 .65269 L .41825 .65517 L .654 .782 .942 r
F
0 g
.37822 .5539 m
.39733 .54664 L
s
.35367 .41219 m .34902 .47307 L .35017 .47384 L .892 .63 .535 r
F
.35367 .41219 m .35255 .41141 L .34902 .47307 L F
0 g
.35367 .41219 m
.35421 .41317 L
s
.35367 .41219 m
.35367 .41219 L
s
.65614 .55538 m .69316 .55343 L .66352 .54733 L .642 .738 .919 r
F
.63009 .54526 m .65614 .55538 L .66352 .54733 L F
.62469 .54861 m .65614 .55538 L .63009 .54526 L F
0 g
.76415 .41209 m
.7642 .41132 L
s
.34821 .41134 m .34716 .41208 L .34353 .47373 L .385 .194 .495 r
F
.34716 .41208 m .34309 .47468 L .34353 .47373 L 0 0 .29 r
F
0 g
.34673 .41304 m
.34716 .41208 L
s
.34716 .41208 m
.34716 .41208 L
s
.50901 .53003 m .51217 .5361 L .51171 .54387 L .932 .75 .272 r
F
.50901 .53003 m .50948 .52222 L .51217 .5361 L F
.54099 .52388 m .51217 .5361 L .5426 .53315 L .643 .738 .918 r
F
.54099 .52388 m .50948 .52222 L .51217 .5361 L F
0 g
.51217 .5361 m
.51706 .54336 L
s
.5107 .56088 m .49202 .54378 L .49151 .5516 L .848 .601 .566 r
F
0 g
.5107 .56088 m
.52508 .57229 L
s
.26598 .51939 m .28317 .52344 L .28219 .53119 L .9 .663 .57 r
F
.26598 .51939 m .267 .51161 L .28317 .52344 L F
0 g
.28317 .52344 m
.29033 .52677 L
s
.39391 .65887 m .36941 .65637 L .3674 .66574 L .654 .783 .943 r
F
.36948 .66261 m .3674 .66574 L .36747 .67195 L 0 0 .207 r
F
0 g
.36826 .66826 m
.3695 .6719 L
s
.36948 .66261 m .36941 .65637 L .3674 .66574 L 0 0 .207 r
F
.2936 .50397 m .28348 .52327 L .30429 .51192 L .643 .738 .918 r
F
.2936 .50397 m .26739 .5115 L .28348 .52327 L F
.66364 .53952 m .6932 .54563 L .69855 .53217 L F
0 g
.68707 .55218 m
.6932 .54563 L
s
.69523 .53287 m
.69535 .53255 L
s
.72519 .526 m .71887 .54672 L .73727 .53235 L .643 .738 .918 r
F
.72519 .526 m .70079 .53736 L .71887 .54672 L F
0 g
.71887 .54672 m
.74051 .5531 L
s
.70523 .53186 m
.70871 .53368 L
s
.42041 .52713 m
.42295 .52537 L
s
.77134 .41046 m
.77166 .41145 L
s
.35255 .41141 m .3479 .47272 L .34902 .47307 L .802 .546 .551 r
F
.35255 .41141 m .35144 .41106 L .3479 .47272 L F
0 g
.35255 .41141 m
.35367 .41219 L
s
.34821 .41134 m .34353 .47373 L .34459 .473 L .385 .194 .495 r
F
.34927 .41102 m .34821 .41134 L .34459 .473 L .57 .346 .536 r
F
0 g
.34716 .41208 m
.34821 .41134 L
s
.81262 .55166 m .83382 .53657 L .83409 .54438 L .535 .34 .563 r
F
.80038 .53567 m .81262 .55166 L .83409 .54438 L .643 .738 .918 r
F
.78441 .53839 m .81262 .55166 L .80038 .53567 L F
0 g
.78888 .55565 m
.81262 .55166 L
s
.7642 .41132 m
.76486 .41035 L
s
.46667 .66012 m .4861 .65071 L .46421 .65729 L .654 .783 .943 r
F
.46667 .66012 m .49093 .6564 L .4861 .65071 L F
.35144 .41106 m .34678 .4726 L .3479 .47272 L .733 .485 .553 r
F
.35144 .41106 m .35035 .41094 L .34678 .4726 L F
0 g
.35144 .41106 m
.35255 .41141 L
s
.34927 .41102 m .34459 .473 L .34568 .47269 L .57 .346 .536 r
F
.35035 .41094 m .34927 .41102 L .34568 .47269 L .663 .424 .548 r
F
0 g
.34821 .41134 m
.34927 .41102 L
s
.35035 .41094 m .34568 .47269 L .34678 .4726 L .663 .424 .548 r
F
0 g
.35035 .41094 m
.35144 .41106 L
s
.34927 .41102 m
.35035 .41094 L
s
.41842 .66756 m .39256 .6713 L .41763 .67066 L .653 .784 .944 r
F
.57297 .51776 m .54169 .51611 L .54329 .52536 L .644 .737 .917 r
F
.49043 .65025 m .50756 .63795 L .48563 .64457 L .654 .782 .942 r
F
.49043 .65025 m .51463 .64653 L .50756 .63795 L F
0 g
.42037 .52713 m
.42127 .52697 L
s
.44038 .77016 m .43999 .76505 L .45455 .76326 L .678 .469 .595 r
F
.42578 .7703 m .43999 .76505 L .44038 .77016 L .731 .509 .59 r
F
.42578 .7703 m .42541 .76519 L .43999 .76505 L F
0 g
.77134 .41046 m
.77604 .4684 L
s
.77134 .41046 m
.77134 .41046 L
s
.7704 .40969 m
.77134 .41046 L
s
.4421 .75776 m .44105 .7648 L .45448 .76314 L .657 .808 .956 r
F
.44228 .75653 m .45448 .76314 L .44967 .75562 L F
.43995 .75682 m .4421 .75776 L .44228 .75653 L F
.4421 .75776 m .45448 .76314 L .44228 .75653 L F
.4458 .69272 m .44588 .69207 L .44472 .74027 L 0 0 .082 r
F
.4399 .7486 m .43995 .75682 L .44967 .75562 L .657 .808 .956 r
F
.4399 .7486 m .44967 .75562 L .4448 .74799 L F
.43995 .75682 m .43999 .76493 L .44105 .7648 L F
.43995 .75682 m .44105 .7648 L .4421 .75776 L F
.44029 .7538 m .44033 .76203 L .45012 .76083 L .656 .808 .956 r
F
.44029 .7538 m .45012 .76083 L .44522 .75319 L F
.44038 .77016 m .45455 .76326 L .45495 .76836 L .678 .469 .595 r
F
.44033 .76203 m .45495 .76836 L .45012 .76083 L .656 .808 .956 r
F
.44068 .75896 m .45052 .76597 L .44561 .75836 L .656 .809 .957 r
F
.44054 .69402 m .44212 .69423 L .44091 .74236 L .747 .505 .564 r
F
.44212 .7438 m .4399 .7486 L .4448 .74799 L .657 .808 .956 r
F
.44158 .74295 m .44089 .74525 L .44212 .7438 L F
.44089 .74525 m .4399 .7486 L .44212 .7438 L F
.44054 .69402 m .44091 .74236 L .44045 .74235 L .747 .505 .564 r
F
.44212 .69423 m .44205 .74218 L .44091 .74236 L .651 .424 .562 r
F
.4437 .69407 m .44471 .69372 L .44353 .74174 L .539 .332 .549 r
F
.44539 .69327 m .4458 .69272 L .44464 .74082 L .095 0 .426 r
F
.44317 .74256 m .4448 .74799 L .44936 .74686 L .657 .808 .956 r
F
.44293 .74284 m .4448 .74799 L .44317 .74256 L F
.4426 .74232 m .4448 .74799 L .44271 .74225 L F
.44117 .74232 m .4448 .74799 L .44251 .7421 L F
.4437 .69407 m .44353 .74174 L .44324 .74184 L .539 .332 .549 r
F
.44212 .69423 m .4437 .69407 L .44251 .7421 L .651 .424 .562 r
F
.44212 .69423 m .44251 .7421 L .44205 .74218 L F
.44471 .69372 m .44403 .74143 L .44353 .74174 L .387 .212 .518 r
F
.4437 .69407 m .44324 .74184 L .44251 .7421 L .539 .332 .549 r
F
.44592 .74253 m .44936 .74686 L .45329 .74529 L .657 .808 .956 r
F
.44054 .69402 m .44045 .74235 L .4393 .74231 L .747 .505 .564 r
F
.43985 .74026 m .44298 .74243 L .44592 .74253 L .657 .808 .956 r
F
.44298 .74243 m .44936 .74686 L .44592 .74253 L F
.43021 .75691 m .43999 .76493 L .43995 .75748 L F
.43984 .75682 m .43995 .75748 L .43995 .75682 L F
.43021 .75691 m .43995 .75748 L .43984 .75682 L F
.43835 .69196 m .43844 .69261 L .43716 .74129 L .868 .695 .169 r
F
.43842 .74861 m .43995 .75682 L .4399 .7486 L .657 .808 .956 r
F
.435 .74864 m .43979 .75656 L .43842 .74861 L F
.43979 .75656 m .43995 .75682 L .43842 .74861 L F
.435 .74864 m .43021 .75691 L .43995 .75682 L F
.43536 .75384 m .44033 .76203 L .44029 .7538 L .656 .808 .956 r
F
.43021 .75691 m .42549 .76507 L .43999 .76493 L .657 .808 .956 r
F
.43536 .75384 m .43054 .76212 L .44033 .76203 L .656 .808 .956 r
F
.44033 .76203 m .44038 .77016 L .45495 .76836 L F
.43054 .76212 m .44038 .77016 L .44033 .76203 L F
.43575 .75901 m .44072 .76718 L .44068 .75896 L .656 .809 .957 r
F
.43885 .69317 m .43953 .69364 L .43827 .74207 L .908 .647 .532 r
F
.43988 .74411 m .435 .74864 L .4399 .7486 L .657 .808 .956 r
F
.43987 .74285 m .43931 .74352 L .43988 .74411 L F
.43931 .74352 m .435 .74864 L .43988 .74411 L F
.43844 .69261 m .43885 .69317 L .43757 .74173 L .984 .727 .46 r
F
.43964 .74273 m .43915 .74335 L .43987 .74285 L .657 .808 .956 r
F
.43915 .74335 m .435 .74864 L .43931 .74352 L F
.43915 .74335 m .43931 .74352 L .43987 .74285 L F
.43874 .74218 m .43869 .74227 L .43987 .74244 L F
.43869 .74227 m .435 .74864 L .43964 .74273 L F
.43869 .74227 m .43964 .74273 L .43987 .74244 L F
.43885 .69317 m .43808 .74197 L .43757 .74173 L .908 .647 .532 r
F
.43885 .69317 m .43827 .74207 L .43808 .74197 L F
.43953 .69364 m .44054 .69402 L .4393 .74231 L .83 .576 .556 r
F
.43953 .69364 m .4393 .74231 L .43901 .74224 L F
.43844 .69261 m .43746 .7416 L .43716 .74129 L .984 .727 .46 r
F
.43844 .69261 m .43757 .74173 L .43746 .7416 L F
.43835 .69196 m .43713 .74114 L .43706 .74075 L .868 .695 .169 r
F
.43835 .69196 m .43716 .74129 L .43713 .74114 L F
.43884 .69113 m .43835 .69196 L .43706 .74075 L 0 0 .377 r
F
.43874 .74218 m .43363 .74583 L .435 .74864 L .657 .808 .956 r
F
.43781 .74196 m .43422 .74495 L .43874 .74218 L F
.43422 .74495 m .43042 .74811 L .43363 .74583 L F
.43422 .74495 m .43363 .74583 L .43874 .74218 L F
.44027 .74961 m .43536 .75384 L .44029 .7538 L .656 .808 .956 r
F
.43874 .74803 m .43536 .75384 L .44027 .74961 L F
.43953 .69364 m .43901 .74224 L .43827 .74207 L .83 .576 .556 r
F
.43985 .74026 m .42648 .74705 L .43042 .74811 L .657 .808 .956 r
F
.43985 .74026 m .43334 .74235 L .42648 .74705 L F
.43334 .74235 m .42343 .74552 L .42559 .74661 L F
.43334 .74235 m .42559 .74661 L .42648 .74705 L F
.43992 .6905 m .43884 .69113 L .43755 .74003 L .428 .243 .527 r
F
.43042 .74811 m .43021 .75691 L .435 .74864 L .657 .808 .956 r
F
.43874 .74803 m .4331 .75137 L .43536 .75384 L .656 .808 .956 r
F
.43854 .74782 m .43742 .74855 L .43874 .74803 L F
.43742 .74855 m .4331 .75137 L .43746 .74879 L F
.43742 .74855 m .43746 .74879 L .43874 .74803 L F
.43713 .74114 m .43716 .74129 L .43702 .74627 L .868 .695 .169 r
F
.43895 .74743 m .43847 .74776 L .43906 .74748 L .656 .808 .956 r
F
.43847 .74776 m .4331 .75137 L .43854 .74782 L F
.43847 .74776 m .43854 .74782 L .43906 .74748 L F
.43746 .7416 m .43757 .74173 L .43744 .7467 L .984 .727 .46 r
F
.43828 .74707 m .43825 .74709 L .43918 .74728 L .656 .808 .956 r
F
.4373 .74788 m .4331 .75137 L .43741 .74847 L F
.43808 .74197 m .438 .74697 L .43757 .74173 L .908 .647 .532 r
F
.438 .74697 m .43762 .74679 L .43757 .74173 L F
.43757 .74173 m .43762 .74679 L .43744 .7467 L F
.43827 .74207 m .43841 .7471 L .43815 .74704 L .83 .576 .556 r
F
.43042 .74811 m .4211 .75587 L .43021 .75691 L .657 .808 .956 r
F
.4331 .75137 m .42678 .75225 L .43076 .75331 L .656 .808 .956 r
F
.43363 .74583 m .43196 .74829 L .435 .74864 L .657 .808 .956 r
F
.43901 .74224 m .43896 .74723 L .43827 .74207 L .83 .576 .556 r
F
.43825 .74709 m .4373 .74788 L .43895 .74743 L .656 .808 .956 r
F
.4373 .74788 m .43741 .74847 L .43895 .74743 L F
.43825 .74709 m .43895 .74743 L .43918 .74728 L F
.43906 .74748 m .43854 .74782 L .43874 .74803 L F
.44115 .74322 m .4399 .7486 L .44158 .74295 L .657 .808 .956 r
F
.44116 .74259 m .4399 .7486 L .44131 .74254 L F
.44116 .74237 m .4399 .7486 L .4412 .74237 L F
.43987 .74253 m .4399 .7486 L .44117 .74232 L F
.44026 .74753 m .43874 .74803 L .44027 .74961 L .656 .808 .956 r
F
.43918 .74728 m .43874 .74803 L .44026 .74753 L F
.43918 .74728 m .43895 .74743 L .43906 .74748 L F
.43896 .74723 m .43917 .74728 L .43904 .75227 L .83 .576 .556 r
F
.4373 .74788 m .43549 .74784 L .4331 .75137 L .656 .808 .956 r
F
.43808 .74197 m .43827 .74207 L .43815 .74704 L .908 .647 .532 r
F
.43825 .74709 m .43721 .74737 L .4373 .74788 L .656 .808 .956 r
F
.43823 .74708 m .43721 .74737 L .43825 .74709 L F
.44471 .69372 m .44539 .69327 L .44423 .74131 L .387 .212 .518 r
F
.44471 .69372 m .44423 .74131 L .44403 .74143 L F
.44539 .69327 m .44452 .74096 L .44423 .74131 L .095 0 .426 r
F
.44552 .74133 m .45329 .74529 L .45631 .74336 L .657 .808 .956 r
F
.43985 .74026 m .44664 .7428 L .44552 .74133 L F
.44664 .7428 m .45329 .74529 L .44552 .74133 L F
.44539 .69327 m .44464 .74082 L .44452 .74096 L .095 0 .426 r
F
.4458 .69272 m .44469 .74043 L .44464 .74082 L 0 0 .082 r
F
.44491 .74052 m .45631 .74336 L .45823 .74122 L .657 .808 .956 r
F
.43985 .74026 m .44552 .74133 L .44491 .74052 L F
.44552 .74133 m .45631 .74336 L .44491 .74052 L F
.4458 .69272 m .44472 .74027 L .44469 .74043 L 0 0 .082 r
F
.44588 .69207 m .44539 .69123 L .44421 .73961 L .993 .743 .421 r
F
.44222 .74851 m .44029 .7538 L .44522 .75319 L .656 .808 .956 r
F
.44403 .74143 m .44423 .74131 L .44411 .74628 L .387 .212 .518 r
F
.4448 .74799 m .44967 .75562 L .45874 .75339 L .657 .808 .956 r
F
.44416 .74815 m .44522 .75319 L .44981 .75205 L .656 .808 .956 r
F
.44313 .74743 m .44394 .74966 L .44416 .74815 L F
.44394 .74966 m .44522 .75319 L .44416 .74815 L F
.44293 .74767 m .44389 .74998 L .44313 .74743 L F
.44389 .74998 m .44522 .75319 L .44394 .74966 L F
.44389 .74998 m .44394 .74966 L .44313 .74743 L F
.44588 .69207 m .44436 .7398 L .44472 .74027 L .993 .743 .421 r
F
.44496 .73992 m .45823 .74122 L .4589 .73901 L .657 .808 .956 r
F
.43985 .74026 m .4466 .74061 L .44496 .73992 L F
.4466 .74061 m .45823 .74122 L .44496 .73992 L F
.44313 .74743 m .44981 .75205 L .44981 .75205 L .656 .808 .956 r
F
.44271 .74714 m .44313 .74743 L .44313 .74743 L F
.44313 .74743 m .44981 .75205 L .44313 .74743 L F
.44452 .74096 m .44443 .7459 L .44423 .74131 L .095 0 .426 r
F
.44173 .74775 m .44375 .7509 L .44271 .74714 L .656 .808 .956 r
F
.44375 .7509 m .44522 .75319 L .44389 .74998 L F
.44375 .7509 m .44389 .74998 L .44271 .74714 L F
.44469 .74043 m .44472 .74027 L .4446 .74525 L 0 0 .082 r
F
.4448 .74799 m .45874 .75339 L .44936 .74686 L .657 .808 .956 r
F
.44654 .74778 m .44981 .75205 L .45376 .75047 L .656 .808 .956 r
F
.43987 .74244 m .43964 .74273 L .43987 .74285 L .657 .808 .956 r
F
.44045 .74235 m .44044 .74732 L .4393 .74231 L .747 .505 .564 r
F
.44324 .74184 m .44353 .74174 L .44341 .74671 L .539 .332 .549 r
F
.44341 .74671 m .44981 .75205 L .44353 .74666 L .656 .808 .956 r
F
.44254 .74702 m .44271 .74714 L .44341 .74671 L F
.44271 .74714 m .44981 .75205 L .44341 .74671 L F
.44068 .75896 m .44072 .76718 L .45052 .76597 L .656 .809 .957 r
F
.44353 .74666 m .44981 .75205 L .44654 .74778 L .656 .808 .956 r
F
.44353 .74174 m .44359 .7466 L .44341 .74671 L .387 .212 .518 r
F
.44324 .74184 m .44341 .74671 L .44319 .74679 L .539 .332 .549 r
F
.44443 .7459 m .44421 .74616 L .44423 .74131 L .095 0 .426 r
F
.44539 .69123 m .44341 .73928 L .44421 .73961 L .889 .63 .539 r
F
.44588 .69207 m .44421 .73961 L .44436 .7398 L .993 .743 .421 r
F
.44396 .7395 m .4589 .73901 L .45827 .73687 L .657 .808 .956 r
F
.43985 .74026 m .44496 .73992 L .44396 .7395 L F
.44496 .73992 m .4589 .73901 L .44396 .7395 L F
.44539 .69123 m .44429 .69056 L .4431 .73915 L .889 .63 .539 r
F
.445 .74666 m .44654 .74778 L .44584 .74687 L .656 .808 .956 r
F
.44205 .74218 m .44251 .7421 L .44239 .74708 L .651 .424 .562 r
F
.44205 .74218 m .44239 .74708 L .44205 .74713 L F
.44403 .74143 m .44396 .74637 L .44353 .74174 L .387 .212 .518 r
F
.4435 .74665 m .44397 .74682 L .44393 .74639 L .656 .808 .956 r
F
.44396 .74637 m .44359 .7466 L .44353 .74174 L .387 .212 .518 r
F
.44423 .74131 m .44421 .74616 L .44411 .74628 L .095 0 .426 r
F
.44403 .74143 m .44411 .74628 L .44396 .74637 L .387 .212 .518 r
F
.44936 .74686 m .45874 .75339 L .46657 .75026 L .657 .808 .956 r
F
.44465 .74626 m .45552 .74936 L .45093 .74744 L .656 .808 .956 r
F
.44251 .7421 m .44265 .74698 L .44239 .74708 L .539 .332 .549 r
F
.44231 .75323 m .44068 .75896 L .44561 .75836 L .656 .809 .957 r
F
.44271 .74714 m .44293 .74767 L .44313 .74743 L .656 .808 .956 r
F
.44271 .74225 m .44293 .74284 L .44317 .74256 L .657 .808 .956 r
F
.44251 .7421 m .4426 .74232 L .44271 .74225 L F
.44324 .74184 m .44319 .74679 L .44251 .7421 L .539 .332 .549 r
F
.44257 .74705 m .44173 .74775 L .44271 .74714 L .656 .808 .956 r
F
.44254 .74702 m .4425 .74706 L .44257 .74705 L F
.4425 .74706 m .44173 .74775 L .44257 .74705 L F
.44131 .74254 m .44115 .74322 L .44158 .74295 L .657 .808 .956 r
F
.4412 .74237 m .44116 .74259 L .44131 .74254 L F
.44117 .74232 m .44116 .74237 L .4412 .74237 L F
.44205 .74218 m .44205 .74713 L .44091 .74236 L .651 .424 .562 r
F
.4415 .74739 m .44173 .74775 L .44254 .74702 L .656 .808 .956 r
F
.44188 .75256 m .4416 .75407 L .44231 .75323 L .656 .809 .957 r
F
.4416 .75407 m .44068 .75896 L .44231 .75323 L F
.44162 .75216 m .44065 .75332 L .44188 .75256 L F
.441 .74994 m .44029 .7538 L .44222 .74851 L .656 .808 .956 r
F
.44078 .74733 m .44029 .7538 L .44147 .74735 L F
.44026 .74731 m .44026 .74742 L .44078 .74733 L F
.44026 .74742 m .44029 .7538 L .44078 .74733 L F
.44065 .75232 m .44065 .75332 L .44147 .75234 L .656 .809 .957 r
F
.44066 .75232 m .44147 .75234 L .44162 .75216 L F
.44065 .75232 m .44147 .75234 L .44066 .75232 L F
.44045 .74235 m .44091 .74236 L .44078 .74733 L .747 .505 .564 r
F
.44045 .74235 m .44078 .74733 L .44055 .74732 L F
.43985 .74026 m .43987 .74253 L .44117 .74232 L .657 .808 .956 r
F
.44044 .74732 m .44066 .75232 L .44043 .75231 L .747 .505 .564 r
F
.44045 .74235 m .44055 .74732 L .44044 .74732 L F
.44055 .74732 m .44066 .75232 L .44044 .74732 L F
.44091 .74236 m .44119 .74727 L .44078 .74733 L .651 .424 .562 r
F
.44205 .74713 m .44119 .74727 L .44091 .74236 L F
.44319 .74679 m .44265 .74698 L .44251 .7421 L .539 .332 .549 r
F
.44539 .69123 m .4431 .73915 L .44341 .73928 L .889 .63 .539 r
F
.44429 .69056 m .4423 .73902 L .4431 .73915 L .799 .548 .56 r
F
.43985 .74026 m .44325 .73917 L .44229 .73902 L .657 .808 .956 r
F
.44464 .74082 m .44454 .74566 L .44452 .74579 L 0 0 .082 r
F
.44452 .74096 m .44464 .74082 L .44452 .74579 L .095 0 .426 r
F
.44936 .74686 m .46657 .75026 L .45329 .74529 L .657 .808 .956 r
F
.44462 .74567 m .45093 .74744 L .44697 .74579 L .656 .808 .956 r
F
.44452 .74096 m .44452 .74579 L .44443 .7459 L .095 0 .426 r
F
.44025 .74544 m .44419 .74618 L .44462 .74567 L .656 .808 .956 r
F
.44419 .74618 m .45093 .74744 L .44462 .74567 L F
.44025 .74544 m .44147 .74735 L .44254 .74702 L F
.44147 .74735 m .4416 .74736 L .44254 .74702 L F
.44065 .75332 m .44068 .75896 L .44188 .75256 L .656 .809 .957 r
F
.44147 .74735 m .441 .74994 L .44222 .74851 L .656 .808 .956 r
F
.44065 .75331 m .43782 .75659 L .44068 .75896 L .656 .809 .957 r
F
.43782 .75659 m .43824 .75899 L .44068 .75896 L F
.44027 .75312 m .43959 .75402 L .44065 .75331 L F
.43959 .75402 m .43575 .75901 L .43983 .75426 L F
.43959 .75402 m .43983 .75426 L .44065 .75331 L F
.44044 .74732 m .43958 .74729 L .4393 .74231 L .747 .505 .564 r
F
.43808 .74197 m .43815 .74704 L .438 .74697 L .908 .647 .532 r
F
.4393 .74231 m .43958 .74729 L .43917 .74728 L .747 .505 .564 r
F
.43901 .74224 m .4393 .74231 L .43917 .74728 L .83 .576 .556 r
F
.43901 .74224 m .43917 .74728 L .43896 .74723 L F
.43896 .74723 m .43841 .7471 L .43827 .74207 L F
.44025 .74544 m .43742 .74687 L .43828 .74707 L .656 .808 .956 r
F
.43742 .74687 m .43715 .74701 L .43828 .74707 L F
.43715 .74701 m .43549 .74784 L .43721 .74737 L F
.43715 .74701 m .43721 .74737 L .43828 .74707 L F
.43721 .74737 m .43549 .74784 L .4373 .74788 L F
.43746 .7416 m .43744 .7467 L .43736 .74661 L .984 .727 .46 r
F
.43746 .7416 m .43736 .74661 L .43716 .74129 L F
.43736 .74661 m .43713 .74638 L .43716 .74129 L F
.43334 .74235 m .42149 .74364 L .42343 .74552 L .657 .808 .956 r
F
.43985 .74026 m .43577 .74101 L .43334 .74235 L F
.43577 .74101 m .42149 .74364 L .43334 .74235 L F
.44025 .74544 m .43626 .74671 L .43549 .74784 L .656 .808 .956 r
F
.43782 .75659 m .43575 .75901 L .43824 .75899 L .656 .809 .957 r
F
.44045 .75259 m .44012 .75305 L .44065 .75263 L F
.42648 .74705 m .4211 .75587 L .43042 .74811 L .657 .808 .956 r
F
.42648 .74705 m .41322 .75378 L .4211 .75587 L F
.42343 .74552 m .41322 .75378 L .42648 .74705 L F
.43158 .74821 m .42176 .74883 L .42372 .75072 L .656 .808 .956 r
F
.43884 .69113 m .4372 .74056 L .43755 .74003 L 0 0 .377 r
F
.43884 .69113 m .43706 .74075 L .4372 .74056 L F
.42757 .74252 m .42079 .74151 L .42149 .74364 L .657 .808 .956 r
F
.43985 .74026 m .43438 .74062 L .42757 .74252 L F
.43438 .74062 m .42079 .74151 L .42757 .74252 L F
.44102 .69023 m .43992 .6905 L .43866 .73942 L .585 .37 .555 r
F
.43713 .74114 m .437 .74616 L .43706 .74075 L .868 .695 .169 r
F
.43363 .74583 m .43042 .74811 L .43196 .74829 L .657 .808 .956 r
F
.43706 .74646 m .43482 .74644 L .43158 .74821 L .656 .808 .956 r
F
.437 .74616 m .43697 .74596 L .43706 .74075 L .868 .695 .169 r
F
.43713 .74114 m .43702 .74627 L .437 .74616 L F
.43716 .74129 m .43713 .74638 L .43702 .74627 L .984 .727 .46 r
F
.44025 .74544 m .43698 .74604 L .43706 .74646 L .656 .808 .956 r
F
.43698 .74604 m .43482 .74644 L .43706 .74646 L F
.43948 .75391 m .43575 .75901 L .43959 .75402 L .656 .809 .957 r
F
.43968 .75229 m .43961 .7524 L .44065 .75232 L F
.437 .74616 m .43702 .74627 L .43689 .75126 L .868 .695 .169 r
F
.43767 .75572 m .43575 .75901 L .43776 .75625 L .656 .809 .957 r
F
.43896 .74723 m .4389 .75223 L .43841 .7471 L .83 .576 .556 r
F
.4389 .75223 m .43854 .75215 L .43841 .7471 L F
.44055 .74732 m .44078 .74733 L .44066 .75232 L .747 .505 .564 r
F
.44026 .74731 m .43918 .74728 L .44026 .74753 L .656 .808 .956 r
F
.44044 .74732 m .44043 .75231 L .43958 .74729 L .747 .505 .564 r
F
.43961 .7524 m .43943 .75271 L .44045 .75259 L .656 .809 .957 r
F
.43943 .75271 m .43767 .75572 L .44007 .75302 L F
.43943 .75271 m .44007 .75302 L .44045 .75259 L F
.43762 .74679 m .43768 .75186 L .43744 .7467 L .908 .647 .532 r
F
.43076 .75331 m .43054 .76212 L .43536 .75384 L .656 .808 .956 r
F
.43767 .75572 m .43197 .75779 L .43575 .75901 L .656 .809 .957 r
F
.43943 .75271 m .43736 .75394 L .43767 .75572 L F
.43922 .75261 m .43736 .75394 L .43943 .75271 L F
.43736 .75394 m .43197 .75779 L .43767 .75572 L F
.43868 .75225 m .43727 .75342 L .4395 .75237 L F
.43727 .75342 m .43736 .75394 L .43954 .75238 L F
.4395 .75237 m .43954 .75238 L .43968 .75229 L F
.43727 .75342 m .43954 .75238 L .4395 .75237 L F
.43828 .74707 m .43823 .74708 L .43825 .74709 L .656 .808 .956 r
F
.43841 .7471 m .43854 .75215 L .43815 .74704 L .83 .576 .556 r
F
.43767 .75572 m .43776 .75625 L .44045 .75259 L .656 .809 .957 r
F
.43854 .75215 m .43837 .75211 L .43815 .74704 L .83 .576 .556 r
F
.43815 .74704 m .43837 .75211 L .43802 .75203 L F
.44043 .75231 m .43986 .75229 L .43958 .74729 L .747 .505 .564 r
F
.438 .74697 m .43815 .74704 L .43802 .75203 L .908 .647 .532 r
F
.438 .74697 m .43802 .75203 L .43792 .75198 L F
.43896 .74723 m .43904 .75227 L .4389 .75223 L .83 .576 .556 r
F
.43917 .74728 m .43959 .75228 L .43904 .75227 L .747 .505 .564 r
F
.4331 .75137 m .4317 .75342 L .43536 .75384 L .656 .808 .956 r
F
.4211 .75587 m .42549 .76507 L .43021 .75691 L .657 .808 .956 r
F
.4211 .75587 m .41189 .76355 L .42549 .76507 L F
.43076 .75331 m .42137 .76109 L .43054 .76212 L .656 .808 .956 r
F
.43823 .75263 m .42716 .75743 L .43113 .75849 L .656 .809 .957 r
F
.43811 .75251 m .42716 .75743 L .43823 .75263 L F
.43713 .74638 m .43711 .75148 L .43702 .74627 L .984 .727 .46 r
F
.43751 .75222 m .43488 .75354 L .43807 .75246 L .656 .809 .957 r
F
.43488 .75354 m .43446 .75415 L .43868 .75225 L F
.43727 .75342 m .43197 .75779 L .43736 .75394 L F
.43918 .74728 m .43918 .74728 L .44026 .74731 L .656 .808 .956 r
F
.43958 .74729 m .43986 .75229 L .43917 .74728 L .747 .505 .564 r
F
.43986 .75229 m .43959 .75228 L .43917 .74728 L F
.43744 .7467 m .43756 .75181 L .43731 .75169 L .908 .647 .532 r
F
.43768 .75186 m .43756 .75181 L .43744 .7467 L F
.438 .74697 m .43792 .75198 L .43762 .74679 L F
.43792 .75198 m .43768 .75186 L .43762 .74679 L F
.44064 .75064 m .43581 .75217 L .43488 .75354 L .656 .809 .957 r
F
.43711 .75148 m .43704 .75141 L .43702 .74627 L .984 .727 .46 r
F
.43702 .74627 m .43704 .75141 L .43689 .75126 L F
.42678 .75225 m .42137 .76109 L .43076 .75331 L .656 .808 .956 r
F
.41322 .75378 m .41189 .76355 L .4211 .75587 L .657 .808 .956 r
F
.42678 .75225 m .41345 .759 L .42137 .76109 L .656 .808 .956 r
F
.42372 .75072 m .41345 .759 L .42678 .75225 L F
.42982 .75408 m .42213 .75402 L .42409 .75591 L .656 .809 .957 r
F
.43736 .74661 m .43726 .75163 L .43713 .74638 L .984 .727 .46 r
F
.43726 .75163 m .43711 .75148 L .43713 .74638 L F
.43736 .74661 m .43744 .7467 L .43731 .75169 L F
.43736 .74661 m .43731 .75169 L .43726 .75163 L F
.4331 .75137 m .43076 .75331 L .4317 .75342 L .656 .808 .956 r
F
.42343 .74552 m .4071 .75076 L .41322 .75378 L .657 .808 .956 r
F
.42426 .74837 m .42107 .7467 L .42176 .74883 L .656 .808 .956 r
F
.43985 .74026 m .43781 .74196 L .43874 .74218 L .657 .808 .956 r
F
.43438 .74062 m .4214 .73929 L .42079 .74151 L F
.43985 .74026 m .43633 .74007 L .43438 .74062 L F
.43633 .74007 m .4214 .73929 L .43438 .74062 L F
.43697 .74596 m .43696 .74587 L .43706 .74075 L .868 .695 .169 r
F
.43698 .74604 m .43614 .74571 L .43482 .74644 L .656 .808 .956 r
F
.43706 .74075 m .43696 .74587 L .43693 .74573 L .868 .695 .169 r
F
.4372 .74056 m .43706 .74075 L .43693 .74573 L 0 0 .377 r
F
.4372 .74056 m .43693 .74573 L .43703 .74558 L F
.44025 .74544 m .43692 .74566 L .43698 .74604 L .656 .808 .956 r
F
.43692 .74566 m .43614 .74571 L .43698 .74604 L F
.44064 .75064 m .43632 .75143 L .43581 .75217 L .656 .809 .957 r
F
.43784 .75223 m .43807 .75246 L .43868 .75225 L F
.43868 .75225 m .43811 .75251 L .43823 .75263 L F
.44064 .75064 m .43751 .75222 L .43868 .75225 L F
.43854 .75215 m .4388 .7618 L .43837 .75211 L .83 .576 .556 r
F
.43802 .75203 m .4388 .7618 L .43777 .76143 L F
.43837 .75211 m .4388 .7618 L .43802 .75203 L F
.43904 .75227 m .4395 .75237 L .43968 .75229 L .656 .809 .957 r
F
.43868 .75225 m .4395 .75237 L .43904 .75227 L F
.43968 .75229 m .43922 .75261 L .43943 .75271 L F
.44064 .75064 m .43868 .75225 L .43968 .75229 L F
.4389 .75223 m .4388 .7618 L .43854 .75215 L .83 .576 .556 r
F
.4389 .75223 m .43904 .75227 L .4388 .7618 L F
.43904 .75227 m .44041 .76201 L .4388 .7618 L .747 .505 .564 r
F
.44012 .75305 m .43948 .75391 L .44027 .75312 L .656 .809 .957 r
F
.43948 .75391 m .43959 .75402 L .44027 .75312 L F
.43959 .75228 m .44041 .76201 L .43904 .75227 L .747 .505 .564 r
F
.44025 .74544 m .43918 .74728 L .44026 .74731 L .656 .808 .956 r
F
.44025 .74544 m .43828 .74707 L .43918 .74728 L F
.43985 .74026 m .43874 .74218 L .43987 .74244 L .657 .808 .956 r
F
.43992 .6905 m .43755 .74003 L .43786 .73986 L .428 .243 .527 r
F
.43346 .73992 m .42327 .73713 L .4214 .73929 L .657 .808 .956 r
F
.43985 .74026 m .43621 .73957 L .43346 .73992 L F
.43621 .73957 m .42327 .73713 L .43346 .73992 L F
.44211 .69016 m .44102 .69023 L .43976 .73912 L .667 .437 .562 r
F
.43985 .74026 m .44117 .74232 L .44251 .7421 L .657 .808 .956 r
F
.43992 .6905 m .43786 .73986 L .43866 .73942 L .428 .243 .527 r
F
.43985 .74026 m .42628 .73518 L .42327 .73713 L .657 .808 .956 r
F
.43985 .74026 m .43023 .73357 L .42628 .73518 L F
.44102 .69023 m .43896 .73934 L .43976 .73912 L .585 .37 .555 r
F
.44102 .69023 m .43866 .73942 L .43896 .73934 L F
.43985 .74026 m .43484 .73242 L .43023 .73357 L .657 .808 .956 r
F
.44211 .69016 m .43976 .73912 L .44007 .73908 L .667 .437 .562 r
F
.43985 .74026 m .43981 .7318 L .43484 .73242 L .657 .808 .956 r
F
.44429 .69056 m .4432 .69026 L .44199 .73898 L .799 .548 .56 r
F
.4412 .75223 m .44202 .76185 L .44066 .75232 L .651 .424 .562 r
F
.44025 .74544 m .44026 .74731 L .44147 .74735 L .656 .808 .956 r
F
.44119 .74727 m .44147 .75219 L .44078 .74733 L .651 .424 .562 r
F
.44147 .75219 m .44202 .76185 L .4412 .75223 L F
.44147 .75219 m .4412 .75223 L .44078 .74733 L F
.44025 .74544 m .44415 .74644 L .44465 .74626 L .656 .808 .956 r
F
.44396 .74637 m .44389 .75133 L .44359 .7466 L .387 .212 .518 r
F
.44967 .75562 m .45448 .76314 L .46801 .75983 L .657 .808 .956 r
F
.44967 .75562 m .46801 .75983 L .45874 .75339 L F
.44522 .75319 m .45012 .76083 L .45925 .75858 L .656 .808 .956 r
F
.44406 .75299 m .44561 .75836 L .45021 .75722 L .656 .809 .957 r
F
.44309 .75232 m .44383 .7545 L .44406 .75299 L F
.44383 .7545 m .44561 .75836 L .44406 .75299 L F
.44266 .75208 m .44383 .75455 L .4427 .75206 L F
.44383 .75455 m .44561 .75836 L .44383 .7545 L F
.44383 .75455 m .44383 .7545 L .4427 .75206 L F
.44415 .74644 m .45552 .74936 L .44465 .74626 L .656 .808 .956 r
F
.44393 .74639 m .44397 .74682 L .445 .74666 L F
.44397 .74682 m .44654 .74778 L .445 .74666 L F
.45329 .74529 m .46657 .75026 L .47263 .74644 L .657 .808 .956 r
F
.45329 .74529 m .47263 .74644 L .45631 .74336 L F
.44821 .74492 m .45873 .7464 L .45941 .74418 L .656 .808 .956 r
F
.44469 .74043 m .4446 .74525 L .44458 .74536 L 0 0 .082 r
F
.44384 .73898 m .45827 .73687 L .45638 .73496 L .657 .808 .956 r
F
.43985 .74026 m .44677 .73899 L .44384 .73898 L F
.44677 .73899 m .45827 .73687 L .44384 .73898 L F
.44469 .74043 m .44458 .74536 L .44464 .74082 L 0 0 .082 r
F
.44458 .74536 m .44454 .74566 L .44464 .74082 L F
.44472 .74027 m .44447 .74508 L .4446 .74525 L .993 .743 .421 r
F
.44025 .74544 m .44697 .74579 L .44533 .74511 L .656 .808 .956 r
F
.44078 .74733 m .4412 .75223 L .44066 .75232 L .651 .424 .562 r
F
.44147 .74735 m .4415 .74739 L .4416 .74736 L .656 .808 .956 r
F
.44205 .74713 m .44204 .7521 L .44119 .74727 L .651 .424 .562 r
F
.44204 .7521 m .44147 .75219 L .44119 .74727 L F
.44359 .7466 m .44364 .75148 L .44341 .74671 L .387 .212 .518 r
F
.44237 .75226 m .44377 .7549 L .44266 .75208 L .656 .809 .957 r
F
.44377 .7549 m .44561 .75836 L .44383 .75455 L F
.44377 .7549 m .44383 .75455 L .44266 .75208 L F
.44169 .75227 m .4437 .75539 L .44227 .75206 L F
.4437 .75539 m .44561 .75836 L .44377 .7549 L F
.4437 .75539 m .44377 .7549 L .44227 .75206 L F
.44454 .74566 m .44444 .75051 L .44452 .74579 L 0 0 .082 r
F
.44319 .74679 m .44314 .75175 L .44265 .74698 L .539 .332 .549 r
F
.44314 .75175 m .44278 .75188 L .44265 .74698 L F
.44205 .74713 m .44239 .74708 L .44227 .75206 L .651 .424 .562 r
F
.44204 .7521 m .44227 .75206 L .44202 .76185 L F
.44205 .74713 m .44227 .75206 L .44204 .7521 L F
.44443 .7459 m .44434 .75085 L .44421 .74616 L .095 0 .426 r
F
.44522 .75319 m .45925 .75858 L .44981 .75205 L .656 .808 .956 r
F
.44382 .75181 m .44918 .75635 L .44643 .75278 L .656 .809 .957 r
F
.44421 .74616 m .44419 .75102 L .44411 .74628 L .095 0 .426 r
F
.44347 .75187 m .44928 .75649 L .44382 .75181 L .656 .809 .957 r
F
.44928 .75649 m .45021 .75722 L .44918 .75635 L F
.44928 .75649 m .44918 .75635 L .44382 .75181 L F
.44309 .75232 m .44944 .7567 L .44347 .75187 L F
.44944 .7567 m .45021 .75722 L .44928 .75649 L F
.44944 .7567 m .44928 .75649 L .44347 .75187 L F
.44443 .7459 m .44452 .74579 L .44439 .75078 L .095 0 .426 r
F
.45874 .75339 m .46801 .75983 L .47972 .75518 L .657 .808 .956 r
F
.44981 .75205 m .45925 .75858 L .46713 .75545 L .656 .808 .956 r
F
.44547 .75153 m .45417 .75564 L .45722 .75372 L .656 .809 .957 r
F
.44399 .75126 m .44589 .75208 L .44547 .75153 L F
.44589 .75208 m .45417 .75564 L .44547 .75153 L F
.44396 .74637 m .44411 .74628 L .44398 .75127 L .387 .212 .518 r
F
.44359 .75173 m .45417 .75564 L .44399 .75126 L .656 .809 .957 r
F
.44389 .75133 m .44398 .75127 L .44375 .76106 L .387 .212 .518 r
F
.44396 .74637 m .44398 .75127 L .44389 .75133 L F
.44364 .75148 m .44352 .75155 L .44341 .74671 L F
.44239 .74708 m .44261 .75194 L .44227 .75206 L .539 .332 .549 r
F
.44389 .75133 m .44364 .75148 L .44359 .7466 L .387 .212 .518 r
F
.44263 .752 m .44309 .75232 L .44347 .75187 L .656 .809 .957 r
F
.44265 .74698 m .44278 .75188 L .44239 .74708 L .539 .332 .549 r
F
.44263 .752 m .44266 .75208 L .4427 .75206 L .656 .809 .957 r
F
.44278 .75188 m .44305 .76151 L .44261 .75194 L .539 .332 .549 r
F
.44278 .75188 m .44261 .75194 L .44239 .74708 L F
.4434 .75166 m .44263 .752 L .44382 .75181 L .656 .809 .957 r
F
.44341 .74671 m .44352 .75155 L .44329 .75169 L .387 .212 .518 r
F
.44256 .75196 m .44263 .752 L .4434 .75166 L .656 .809 .957 r
F
.44292 .75252 m .44383 .7545 L .44309 .75232 L F
.44319 .74679 m .44341 .74671 L .44329 .75169 L .539 .332 .549 r
F
.44314 .75175 m .44329 .75169 L .44305 .76151 L F
.44319 .74679 m .44329 .75169 L .44314 .75175 L F
.44981 .75205 m .44981 .75205 L .44654 .74778 L .656 .808 .956 r
F
.46657 .75026 m .47972 .75518 L .48883 .74949 L .657 .808 .956 r
F
.45874 .75339 m .47972 .75518 L .46657 .75026 L F
.45376 .75047 m .46713 .75545 L .47323 .75162 L .656 .808 .956 r
F
.44981 .75205 m .46713 .75545 L .45376 .75047 L F
.44555 .75089 m .45722 .75372 L .45915 .75158 L .656 .809 .957 r
F
.44443 .7459 m .44439 .75078 L .44434 .75085 L .095 0 .426 r
F
.44419 .75102 m .44412 .7511 L .44411 .74628 L F
.44411 .74628 m .44412 .7511 L .44398 .75127 L F
.44434 .75085 m .44419 .75102 L .44421 .74616 L F
.44064 .75064 m .44433 .75132 L .44555 .75089 L .656 .809 .957 r
F
.44981 .75205 m .44981 .75205 L .44981 .75205 L .656 .808 .956 r
F
.44433 .75132 m .45722 .75372 L .44555 .75089 L .656 .809 .957 r
F
.44064 .75064 m .44256 .75196 L .4434 .75166 L F
.44064 .75064 m .44337 .75165 L .44399 .75126 L F
.44337 .75165 m .44359 .75173 L .44398 .75127 L F
.44337 .75165 m .44398 .75127 L .44399 .75126 L F
.44025 .74544 m .44821 .74492 L .44785 .74486 L .656 .808 .956 r
F
.44541 .74449 m .45935 .74399 L .44828 .74397 L F
.44436 .7398 m .4442 .74473 L .44472 .74027 L .993 .743 .421 r
F
.4442 .74473 m .44447 .74508 L .44472 .74027 L F
.44436 .7398 m .44409 .74459 L .4442 .74473 L F
.44025 .74544 m .44785 .74486 L .44541 .74449 L .656 .808 .956 r
F
.44785 .74486 m .45935 .74399 L .44541 .74449 L F
.4423 .73902 m .44209 .74399 L .4431 .73915 L .799 .548 .56 r
F
.44162 .75216 m .44169 .75227 L .44227 .75206 L .656 .809 .957 r
F
.44064 .75064 m .44162 .75216 L .44227 .75206 L F
.44064 .75064 m .44227 .75206 L .44256 .75196 L F
.44204 .7521 m .44202 .76185 L .44147 .75219 L .651 .424 .562 r
F
.44025 .74544 m .4435 .74665 L .44393 .74639 L .656 .808 .956 r
F
.44025 .74544 m .44254 .74702 L .44353 .74666 L F
.4431 .73915 m .44269 .74408 L .44298 .74412 L .799 .548 .56 r
F
.44341 .73928 m .44321 .74422 L .44421 .73961 L .889 .63 .539 r
F
.44321 .74422 m .4438 .74447 L .44421 .73961 L F
.44341 .73928 m .44298 .74412 L .44321 .74422 L F
.44421 .73961 m .4438 .74447 L .44409 .74459 L F
.44436 .7398 m .44421 .73961 L .44409 .74459 L .993 .743 .421 r
F
.44318 .74396 m .45688 .74012 L .45383 .73857 L .656 .808 .956 r
F
.44341 .73928 m .4431 .73915 L .44298 .74412 L .889 .63 .539 r
F
.44025 .74544 m .44488 .74396 L .44318 .74396 L .656 .808 .956 r
F
.44488 .74396 m .45688 .74012 L .44318 .74396 L F
.4432 .69026 m .44118 .73897 L .44199 .73898 L .733 .492 .564 r
F
.44429 .69056 m .44199 .73898 L .4423 .73902 L .799 .548 .56 r
F
.4432 .69026 m .44211 .69016 L .44087 .73897 L .733 .492 .564 r
F
.4432 .69026 m .44087 .73897 L .44118 .73897 L F
.43985 .74026 m .4414 .73897 L .44087 .73897 L .657 .808 .956 r
F
.43986 .75229 m .44041 .76201 L .43959 .75228 L .747 .505 .564 r
F
.43961 .7524 m .44045 .75259 L .44065 .75232 L .656 .809 .957 r
F
.44012 .75305 m .44027 .75312 L .44065 .75263 L F
.44043 .75231 m .44041 .76201 L .43986 .75229 L .747 .505 .564 r
F
.44065 .75263 m .44027 .75312 L .44065 .75331 L .656 .809 .957 r
F
.44065 .75232 m .44045 .75259 L .44065 .75263 L F
.44043 .75231 m .44066 .75232 L .44041 .76201 L .747 .505 .564 r
F
.44064 .75064 m .43968 .75229 L .44065 .75232 L .656 .809 .957 r
F
.43985 .74026 m .45335 .7334 L .4494 .73231 L .657 .808 .956 r
F
.42149 .74364 m .4071 .75076 L .42343 .74552 L F
.43312 .74591 m .42167 .74448 L .42107 .7467 L .656 .808 .956 r
F
.4372 .74056 m .43703 .74558 L .43755 .74003 L 0 0 .377 r
F
.43703 .74558 m .43729 .7452 L .43755 .74003 L F
.44025 .74544 m .43566 .7452 L .43312 .74591 L .656 .808 .956 r
F
.43566 .7452 m .42167 .74448 L .43312 .74591 L F
.43233 .74503 m .42355 .74231 L .42167 .74448 L F
.43896 .73934 m .43875 .74434 L .43976 .73912 L .585 .37 .555 r
F
.43786 .73986 m .43755 .74003 L .43742 .74501 L .428 .243 .527 r
F
.43786 .73986 m .43742 .74501 L .43765 .74489 L F
.43755 .74003 m .43729 .7452 L .43742 .74501 L 0 0 .377 r
F
.44025 .74544 m .43699 .74483 L .43566 .7452 L .656 .808 .956 r
F
.43693 .74573 m .43683 .75091 L .4368 .75072 L .868 .695 .169 r
F
.43696 .74587 m .43685 .751 L .43693 .74573 L F
.43685 .751 m .43683 .75091 L .43693 .74573 L F
.437 .74616 m .43689 .75126 L .43688 .75119 L F
.43688 .75119 m .43685 .751 L .43696 .74587 L F
.43688 .75119 m .43696 .74587 L .43697 .74596 L F
.437 .74616 m .43688 .75119 L .43697 .74596 L F
.44064 .75064 m .43551 .75097 L .43386 .75188 L .656 .809 .957 r
F
.43574 .74459 m .42659 .74035 L .42355 .74231 L .656 .808 .956 r
F
.43786 .73986 m .43765 .74489 L .43866 .73942 L .428 .243 .527 r
F
.43765 .74489 m .43824 .74456 L .43866 .73942 L F
.44025 .74544 m .4374 .74438 L .43574 .74459 L .656 .808 .956 r
F
.4374 .74438 m .42659 .74035 L .43574 .74459 L F
.43985 .74026 m .44087 .73897 L .44058 .73901 L .657 .808 .956 r
F
.44211 .69016 m .44007 .73908 L .44087 .73897 L .667 .437 .562 r
F
.43985 .74026 m .44071 .73878 L .43985 .73865 L .657 .808 .956 r
F
.44007 .73908 m .43976 .73912 L .43964 .7441 L .667 .437 .562 r
F
.43896 .73934 m .43866 .73942 L .43853 .7444 L .585 .37 .555 r
F
.43896 .73934 m .43853 .7444 L .43875 .74434 L F
.43866 .73942 m .43824 .74456 L .43853 .7444 L .428 .243 .527 r
F
.44025 .74544 m .43056 .73874 L .42659 .74035 L .656 .808 .956 r
F
.43875 .74434 m .43934 .74418 L .43976 .73912 L .585 .37 .555 r
F
.43976 .73912 m .43934 .74418 L .43964 .7441 L F
.44025 .74544 m .43521 .73758 L .43056 .73874 L .656 .808 .956 r
F
.44007 .73908 m .43964 .7441 L .43986 .74407 L .667 .437 .562 r
F
.44007 .73908 m .43986 .74407 L .44087 .73897 L F
.43986 .74407 m .44046 .74399 L .44087 .73897 L F
.43985 .73865 m .44477 .73177 L .43981 .7318 L .657 .808 .956 r
F
.44071 .73878 m .44477 .73177 L .43985 .73865 L F
.44025 .74544 m .4402 .73697 L .43521 .73758 L .656 .808 .956 r
F
.43875 .74434 m .43854 .74936 L .43934 .74418 L .585 .37 .555 r
F
.43703 .74558 m .43686 .75063 L .43729 .7452 L 0 0 .377 r
F
.43686 .75063 m .43703 .75038 L .43729 .7452 L F
.43703 .74558 m .43693 .74573 L .4368 .75072 L F
.43703 .74558 m .4368 .75072 L .43686 .75063 L F
.43549 .74784 m .42678 .75225 L .4331 .75137 L .656 .808 .956 r
F
.43551 .75097 m .43498 .75035 L .43186 .75121 L .656 .809 .957 r
F
.44064 .75064 m .43652 .75042 L .43551 .75097 L F
.43652 .75042 m .43498 .75035 L .43551 .75097 L F
.43765 .74489 m .43742 .74501 L .43729 .75 L .428 .243 .527 r
F
.43731 .75169 m .43777 .76143 L .43707 .76097 L .908 .647 .532 r
F
.43756 .75181 m .43777 .76143 L .43731 .75169 L F
.43716 .75652 m .43723 .75475 L .43707 .76097 L .984 .727 .46 r
F
.43726 .75163 m .43723 .75475 L .43716 .75652 L F
.43726 .75163 m .43731 .75169 L .43723 .75475 L F
.43482 .74644 m .43312 .74591 L .42426 .74837 L .656 .808 .956 r
F
.43312 .74591 m .42107 .7467 L .42426 .74837 L F
.43482 .74644 m .42176 .74883 L .43158 .74821 L F
.43549 .74784 m .43158 .74821 L .42678 .75225 L F
.43158 .74821 m .42372 .75072 L .42543 .75158 L F
.43158 .74821 m .42543 .75158 L .42678 .75225 L F
.41322 .75378 m .40009 .76045 L .41189 .76355 L .657 .808 .956 r
F
.4071 .75076 m .40009 .76045 L .41322 .75378 L F
.42176 .74883 m .40729 .75598 L .42372 .75072 L .656 .808 .956 r
F
.4312 .75015 m .42393 .74753 L .42204 .74969 L .656 .809 .957 r
F
.43875 .74434 m .43853 .7444 L .4384 .7494 L .585 .37 .555 r
F
.43729 .7452 m .43703 .75038 L .43742 .74501 L 0 0 .377 r
F
.43703 .75038 m .43712 .75026 L .43742 .74501 L F
.43742 .74501 m .43712 .75026 L .43729 .75 L F
.44064 .75064 m .43663 .74989 L .43498 .75035 L .656 .809 .957 r
F
.43765 .74489 m .43729 .75 L .43743 .74993 L .428 .243 .527 r
F
.43765 .74489 m .43743 .74993 L .43824 .74456 L F
.43743 .74993 m .43781 .74972 L .43824 .74456 L F
.43626 .74671 m .43158 .74821 L .43549 .74784 L .656 .808 .956 r
F
.43526 .74963 m .42696 .74557 L .42393 .74753 L .656 .809 .957 r
F
.43824 .74456 m .43781 .74972 L .43853 .7444 L .428 .243 .527 r
F
.43781 .74972 m .438 .74962 L .43853 .7444 L F
.44064 .75064 m .43725 .74938 L .43526 .74963 L .656 .809 .957 r
F
.43725 .74938 m .42696 .74557 L .43526 .74963 L F
.43875 .74434 m .4384 .7494 L .43854 .74936 L .585 .37 .555 r
F
.43854 .74936 m .43892 .74925 L .43934 .74418 L F
.43566 .7452 m .43574 .74459 L .43233 .74503 L .656 .808 .956 r
F
.43574 .74459 m .42355 .74231 L .43233 .74503 L F
.43607 .74894 m .43094 .74396 L .42696 .74557 L .656 .809 .957 r
F
.43853 .7444 m .438 .74962 L .4384 .7494 L .428 .243 .527 r
F
.44064 .75064 m .43818 .74895 L .43607 .74894 L .656 .809 .957 r
F
.43614 .74571 m .43312 .74591 L .43482 .74644 L .656 .808 .956 r
F
.43818 .74895 m .43094 .74396 L .43607 .74894 L .656 .809 .957 r
F
.44118 .73897 m .44087 .73897 L .44075 .74395 L .733 .492 .564 r
F
.44118 .73897 m .44075 .74395 L .4409 .74395 L F
.44025 .74544 m .44111 .74395 L .44075 .74395 L .656 .808 .956 r
F
.44024 .74402 m .44075 .74395 L .44024 .74395 L F
.44025 .74544 m .44075 .74395 L .44024 .74402 L F
.44025 .74544 m .44204 .74396 L .44111 .74395 L F
.44209 .74399 m .44269 .74408 L .4431 .73915 L .799 .548 .56 r
F
.4423 .73902 m .44186 .74396 L .44209 .74399 L F
.44025 .74544 m .45383 .73857 L .44985 .73748 L .656 .808 .956 r
F
.45631 .74336 m .47651 .74218 L .45823 .74122 L .657 .808 .956 r
F
.44025 .74544 m .45878 .74204 L .45688 .74012 L .656 .808 .956 r
F
.44098 .74395 m .44062 .74895 L .44077 .74895 L .733 .492 .564 r
F
.44118 .73897 m .4409 .74395 L .44098 .74395 L F
.4409 .74395 m .44062 .74895 L .44098 .74395 L F
.44098 .74395 m .44157 .74395 L .44199 .73898 L F
.44199 .73898 m .44157 .74395 L .44186 .74396 L F
.4423 .73902 m .44199 .73898 L .44186 .74396 L .799 .548 .56 r
F
.44229 .73902 m .45638 .73496 L .45335 .7334 L .657 .808 .956 r
F
.44325 .73917 m .45638 .73496 L .44229 .73902 L F
.44111 .74395 m .44985 .73748 L .4452 .73693 L .656 .808 .956 r
F
.44204 .74396 m .44985 .73748 L .44111 .74395 L F
.44075 .74395 m .44004 .74902 L .44062 .74895 L .667 .437 .562 r
F
.44087 .73897 m .44046 .74399 L .44075 .74395 L F
.44046 .74399 m .44004 .74902 L .44075 .74395 L F
.44058 .73901 m .44087 .73897 L .4406 .73897 L .657 .808 .956 r
F
.4406 .73897 m .4494 .73231 L .44477 .73177 L F
.4414 .73897 m .4494 .73231 L .4406 .73897 L F
.44118 .73897 m .44098 .74395 L .44199 .73898 L .733 .492 .564 r
F
.44024 .74395 m .4452 .73693 L .4402 .73697 L .656 .808 .956 r
F
.44111 .74395 m .4452 .73693 L .44024 .74395 L F
.4409 .74395 m .44075 .74395 L .44062 .74895 L .733 .492 .564 r
F
.44064 .75064 m .44734 .75098 L .44732 .75097 L .656 .809 .957 r
F
.44444 .75051 m .44442 .7506 L .44452 .74579 L 0 0 .082 r
F
.44452 .74579 m .44442 .7506 L .44439 .75078 L F
.44447 .75031 m .44444 .75051 L .44454 .74566 L F
.44571 .7503 m .45915 .75156 L .4492 .75007 L .656 .809 .957 r
F
.44064 .75064 m .44732 .75097 L .44571 .7503 L F
.44732 .75097 m .45915 .75156 L .44571 .7503 L F
.44321 .74422 m .44298 .74412 L .44285 .74912 L .889 .63 .539 r
F
.4427 .75206 m .44292 .75252 L .44309 .75232 L .656 .809 .957 r
F
.44314 .75175 m .44305 .76151 L .44278 .75188 L .539 .332 .549 r
F
.44227 .75206 m .44305 .76151 L .44202 .76185 L F
.44227 .75206 m .44237 .75226 L .44263 .752 L .656 .809 .957 r
F
.44237 .75226 m .44266 .75208 L .44263 .752 L F
.44256 .75196 m .44227 .75206 L .44263 .752 L F
.44261 .75194 m .44305 .76151 L .44227 .75206 L .539 .332 .549 r
F
.44458 .74536 m .44447 .75031 L .44454 .74566 L 0 0 .082 r
F
.44458 .74536 m .44448 .75024 L .44447 .75031 L F
.44549 .75021 m .4492 .75007 L .44844 .74996 L .656 .809 .957 r
F
.44064 .75064 m .44571 .7503 L .44549 .75021 L F
.44571 .7503 m .4492 .75007 L .44549 .75021 L F
.44584 .74687 m .45376 .75047 L .45552 .74936 L .656 .808 .956 r
F
.44654 .74778 m .45376 .75047 L .44584 .74687 L F
.45093 .74744 m .45552 .74936 L .4568 .74854 L F
.46657 .75026 m .48883 .74949 L .47263 .74644 L .657 .808 .956 r
F
.4568 .74854 m .47323 .75162 L .47713 .74735 L .656 .808 .956 r
F
.45376 .75047 m .47323 .75162 L .4568 .74854 L F
.44619 .74962 m .45971 .74897 L .44978 .74896 L .656 .809 .957 r
F
.44422 .7499 m .4443 .75001 L .4446 .74525 L .993 .743 .421 r
F
.44458 .74536 m .4446 .74525 L .44448 .75024 L 0 0 .082 r
F
.4446 .74525 m .4443 .75001 L .44448 .75024 L .993 .743 .421 r
F
.4438 .74447 m .44339 .74934 L .44409 .74459 L .889 .63 .539 r
F
.44064 .75064 m .44549 .75021 L .44471 .74989 L .656 .809 .957 r
F
.44329 .75169 m .44375 .76106 L .44305 .76151 L .387 .212 .518 r
F
.44352 .75155 m .44375 .76106 L .44329 .75169 L F
.44339 .74934 m .44358 .74942 L .44409 .74459 L .889 .63 .539 r
F
.44409 .74459 m .44358 .74942 L .44397 .74958 L F
.44301 .74918 m .44339 .74934 L .4438 .74447 L F
.44785 .74486 m .45941 .74418 L .45935 .74399 L .656 .808 .956 r
F
.44821 .74492 m .45941 .74418 L .44785 .74486 L F
.45631 .74336 m .47263 .74644 L .47651 .74218 L .657 .808 .956 r
F
.44828 .74397 m .45935 .74399 L .45878 .74204 L .656 .808 .956 r
F
.4442 .74473 m .44409 .74459 L .44397 .74958 L .993 .743 .421 r
F
.4442 .74473 m .44397 .74958 L .44404 .74967 L F
.44447 .74508 m .44422 .7499 L .4446 .74525 L F
.4442 .74473 m .44404 .74967 L .44447 .74508 L F
.44404 .74967 m .44422 .7499 L .44447 .74508 L F
.44533 .74511 m .45764 .74634 L .44821 .74492 L .656 .808 .956 r
F
.44697 .74579 m .45764 .74634 L .44533 .74511 L F
.45764 .74634 m .45873 .7464 L .44821 .74492 L F
.44697 .74579 m .45238 .74771 L .45873 .7464 L F
.45093 .74744 m .45238 .74771 L .44697 .74579 L F
.44398 .74895 m .45729 .74533 L .45425 .74378 L .656 .809 .957 r
F
.44209 .74399 m .44186 .74396 L .44174 .74895 L .799 .548 .56 r
F
.44064 .75064 m .44459 .74938 L .44347 .74921 L .656 .809 .957 r
F
.44209 .74399 m .44174 .74895 L .44189 .74897 L .799 .548 .56 r
F
.44186 .74396 m .44134 .74895 L .44174 .74895 L .733 .492 .564 r
F
.44269 .74408 m .44227 .74903 L .44298 .74412 L .799 .548 .56 r
F
.44227 .74903 m .44246 .74906 L .44298 .74412 L F
.44298 .74412 m .44246 .74906 L .44285 .74912 L F
.44321 .74422 m .44285 .74912 L .44301 .74918 L .889 .63 .539 r
F
.44321 .74422 m .44301 .74918 L .4438 .74447 L F
.44209 .74399 m .44189 .74897 L .44269 .74408 L .799 .548 .56 r
F
.44189 .74897 m .44227 .74903 L .44269 .74408 L F
.44163 .74895 m .45026 .74269 L .4456 .74215 L .656 .809 .957 r
F
.44064 .75064 m .44268 .74895 L .44163 .74895 L F
.44268 .74895 m .45026 .74269 L .44163 .74895 L F
.44157 .74395 m .44115 .74895 L .44186 .74396 L .733 .492 .564 r
F
.44066 .75232 m .44202 .76185 L .44041 .76201 L .651 .424 .562 r
F
.44064 .75064 m .44065 .75232 L .44162 .75216 L .656 .809 .957 r
F
.44115 .74895 m .44134 .74895 L .44186 .74396 L .733 .492 .564 r
F
.44098 .74395 m .44077 .74895 L .44157 .74395 L F
.44077 .74895 m .44115 .74895 L .44157 .74395 L F
.44064 .75064 m .4456 .74215 L .4406 .74219 L .656 .809 .957 r
F
.44064 .75064 m .45425 .74378 L .45026 .74269 L F
.45238 .74771 m .4568 .74854 L .4574 .74788 L .656 .808 .956 r
F
.45238 .74771 m .4574 .74788 L .45873 .7464 L F
.4568 .74854 m .47713 .74735 L .45873 .7464 L F
.44064 .75064 m .45919 .74724 L .45729 .74533 L .656 .809 .957 r
F
.44115 .74895 m .44039 .75803 L .44134 .74895 L .733 .492 .564 r
F
.44189 .74897 m .44174 .74895 L .44151 .75813 L .799 .548 .56 r
F
.44347 .74921 m .44591 .74896 L .44398 .74895 L .656 .809 .957 r
F
.44459 .74938 m .44591 .74896 L .44347 .74921 L F
.44591 .74896 m .45729 .74533 L .44398 .74895 L F
.44174 .74895 m .44039 .75803 L .44151 .75813 L .733 .492 .564 r
F
.44134 .74895 m .44039 .75803 L .44174 .74895 L F
.44339 .74934 m .44263 .75843 L .44358 .74942 L .889 .63 .539 r
F
.44471 .74989 m .44844 .74996 L .44619 .74962 L .656 .809 .957 r
F
.44549 .75021 m .44844 .74996 L .44471 .74989 L F
.44844 .74996 m .45971 .74897 L .44619 .74962 L F
.44227 .74903 m .44151 .75813 L .44246 .74906 L .799 .548 .56 r
F
.44364 .75148 m .44375 .76106 L .44352 .75155 L .387 .212 .518 r
F
.44389 .75133 m .44375 .76106 L .44364 .75148 L F
.44397 .74958 m .44263 .75843 L .44374 .75907 L .889 .63 .539 r
F
.44358 .74942 m .44263 .75843 L .44397 .74958 L F
.44285 .74912 m .44151 .75813 L .44263 .75843 L .799 .548 .56 r
F
.44246 .74906 m .44151 .75813 L .44285 .74912 L F
.44844 .74996 m .45982 .74937 L .45971 .74897 L .656 .809 .957 r
F
.4492 .75007 m .45982 .74937 L .44844 .74996 L F
.44978 .74896 m .45971 .74897 L .45919 .74724 L F
.44077 .74895 m .44039 .75803 L .44115 .74895 L .733 .492 .564 r
F
.44301 .74918 m .44285 .74912 L .44263 .75843 L .889 .63 .539 r
F
.43986 .74407 m .43964 .7441 L .43951 .74909 L .667 .437 .562 r
F
.43986 .74407 m .43951 .74909 L .43965 .74907 L F
.43699 .74483 m .43574 .74459 L .43566 .7452 L .656 .808 .956 r
F
.43964 .7441 m .43892 .74925 L .43951 .74909 L .585 .37 .555 r
F
.43934 .74418 m .43892 .74925 L .43964 .7441 L F
.44064 .75064 m .4356 .74281 L .43094 .74396 L .656 .809 .957 r
F
.43986 .74407 m .43965 .74907 L .44046 .74399 L .667 .437 .562 r
F
.43965 .74907 m .44004 .74902 L .44046 .74399 L F
.44064 .75064 m .4406 .74219 L .4356 .74281 L .656 .809 .957 r
F
.44077 .74895 m .44062 .74895 L .44039 .75803 L .733 .492 .564 r
F
.44062 .74895 m .43928 .7581 L .44039 .75803 L .667 .437 .562 r
F
.44004 .74902 m .43928 .7581 L .44062 .74895 L F
.43854 .74936 m .4384 .7494 L .43817 .75836 L .585 .37 .555 r
F
.43498 .75035 m .43526 .74963 L .4312 .75015 L .656 .809 .957 r
F
.43663 .74989 m .43526 .74963 L .43498 .75035 L F
.43526 .74963 m .42393 .74753 L .4312 .75015 L F
.43965 .74907 m .43928 .7581 L .44004 .74902 L .667 .437 .562 r
F
.43743 .74993 m .43729 .75 L .43706 .75898 L .428 .243 .527 r
F
.43854 .74936 m .43817 .75836 L .43892 .74925 L .585 .37 .555 r
F
.42372 .75072 m .40729 .75598 L .41345 .759 L .656 .808 .956 r
F
.43186 .75121 m .4312 .75015 L .42143 .7519 L .656 .809 .957 r
F
.43498 .75035 m .4312 .75015 L .43186 .75121 L F
.4312 .75015 m .42204 .74969 L .42158 .75138 L F
.4312 .75015 m .42158 .75138 L .42143 .7519 L F
.43965 .74907 m .43951 .74909 L .43928 .7581 L .667 .437 .562 r
F
.43708 .75869 m .43707 .76097 L .43706 .75889 L .984 .727 .46 r
F
.43708 .75869 m .43706 .75889 L .43704 .75141 L F
.43711 .75148 m .43708 .75869 L .43704 .75141 L F
.43751 .75222 m .43807 .75246 L .43784 .75223 L .656 .809 .957 r
F
.43768 .75186 m .43777 .76143 L .43756 .75181 L .908 .647 .532 r
F
.43726 .75163 m .43707 .76097 L .43711 .75148 L .984 .727 .46 r
F
.43743 .74993 m .43706 .75898 L .43781 .74972 L .428 .243 .527 r
F
.43386 .75188 m .43186 .75121 L .42213 .75402 L .656 .809 .957 r
F
.43551 .75097 m .43186 .75121 L .43386 .75188 L F
.43186 .75121 m .42143 .7519 L .4221 .75392 L F
.43186 .75121 m .4221 .75392 L .42213 .75402 L F
.43951 .74909 m .43817 .75836 L .43928 .7581 L .585 .37 .555 r
F
.43892 .74925 m .43817 .75836 L .43951 .74909 L F
.44301 .74918 m .44263 .75843 L .44339 .74934 L .889 .63 .539 r
F
.44732 .75097 m .45915 .75158 L .45915 .75156 L .656 .809 .957 r
F
.44734 .75098 m .45915 .75158 L .44732 .75097 L F
.4492 .75007 m .45915 .75156 L .45982 .74937 L F
.44189 .74897 m .44151 .75813 L .44227 .74903 L .799 .548 .56 r
F
.44404 .74967 m .44397 .74958 L .44374 .75907 L .993 .743 .421 r
F
.44434 .75085 m .44439 .75078 L .44416 .76053 L .095 0 .426 r
F
.44419 .75102 m .44419 .75184 L .44416 .75106 L F
.44419 .75184 m .44416 .76053 L .44416 .75106 L F
.44416 .75106 m .44416 .76053 L .44412 .7511 L F
.44398 .75127 m .44416 .76053 L .44375 .76106 L F
.44412 .7511 m .44416 .76053 L .44398 .75127 L F
.44434 .75085 m .44416 .76053 L .44419 .75102 L F
.44422 .7499 m .44374 .75907 L .4443 .75001 L .993 .743 .421 r
F
.44444 .75051 m .44424 .75989 L .44442 .7506 L 0 0 .082 r
F
.44439 .75078 m .44424 .75989 L .44416 .76053 L F
.44442 .7506 m .44424 .75989 L .44439 .75078 L F
.44447 .75031 m .44424 .75989 L .44444 .75051 L F
.44447 .75031 m .44448 .75024 L .44424 .75989 L F
.44448 .75024 m .44374 .75907 L .44424 .75989 L .993 .743 .421 r
F
.4443 .75001 m .44374 .75907 L .44448 .75024 L F
.44404 .74967 m .44374 .75907 L .44422 .7499 L F
.44643 .75278 m .45021 .75722 L .45417 .75564 L .656 .809 .957 r
F
.44918 .75635 m .45021 .75722 L .44643 .75278 L F
.43689 .75126 m .43707 .76097 L .43665 .76042 L .984 .727 .46 r
F
.43704 .75141 m .43707 .76097 L .43689 .75126 L F
.4368 .75072 m .43665 .76042 L .43656 .75979 L .868 .695 .169 r
F
.43683 .75091 m .43665 .76042 L .4368 .75072 L F
.43685 .751 m .43665 .76042 L .43683 .75091 L F
.43688 .75119 m .43689 .75126 L .43665 .76042 L F
.43688 .75119 m .43665 .76042 L .43685 .751 L F
.43703 .75038 m .43656 .75979 L .43712 .75026 L 0 0 .377 r
F
.43581 .75217 m .43386 .75188 L .42982 .75408 L .656 .809 .957 r
F
.43632 .75143 m .43386 .75188 L .43581 .75217 L F
.43386 .75188 m .42213 .75402 L .42982 .75408 L F
.43792 .75198 m .43777 .76143 L .43768 .75186 L .908 .647 .532 r
F
.43781 .74972 m .43706 .75898 L .438 .74962 L .428 .243 .527 r
F
.43729 .75 m .43656 .75979 L .43706 .75898 L 0 0 .377 r
F
.43712 .75026 m .43656 .75979 L .43729 .75 L F
.43488 .75354 m .42982 .75408 L .42716 .75743 L .656 .809 .957 r
F
.43581 .75217 m .42982 .75408 L .43488 .75354 L F
.42982 .75408 m .42409 .75591 L .42534 .75653 L F
.42982 .75408 m .42534 .75653 L .42716 .75743 L F
.43792 .75198 m .43802 .75203 L .43777 .76143 L .908 .647 .532 r
F
.4384 .7494 m .43706 .75898 L .43817 .75836 L .428 .243 .527 r
F
.438 .74962 m .43706 .75898 L .4384 .7494 L F
.43488 .75354 m .42716 .75743 L .43446 .75415 L .656 .809 .957 r
F
.43686 .75063 m .43656 .75979 L .43703 .75038 L 0 0 .377 r
F
.43197 .75779 m .43113 .75849 L .43147 .75852 L .656 .809 .957 r
F
.43197 .75779 m .43147 .75852 L .43575 .75901 L F
.43686 .75063 m .4368 .75072 L .43656 .75979 L 0 0 .377 r
F
.49202 .54378 m .49252 .536 L .46997 .52953 L .788 .547 .572 r
F
0 g
.49252 .536 m
.51162 .54532 L
s
.76486 .41035 m
.76607 .40961 L
s
.76486 .41035 m
.76486 .41035 L
s
.76486 .41035 m
.76946 .46867 L
s
.45495 .76836 m .45455 .76326 L .46815 .75992 L .618 .424 .597 r
F
0 g
.45189 .76359 m
.45455 .76326 L
s
.46388 .65113 m .4778 .63974 L .45994 .64875 L .654 .782 .942 r
F
.46388 .65113 m .48563 .64457 L .4778 .63974 L F
.39402 .66509 m .36747 .67195 L .39256 .6713 L .653 .784 .944 r
F
.41842 .66756 m .39402 .66509 L .39256 .6713 L F
.83382 .53657 m .83355 .5288 L .85125 .51858 L .433 .262 .549 r
F
0 g
.82077 .53319 m
.83355 .5288 L
s
.76937 .40933 m
.7704 .40969 L
s
.76607 .40961 m
.76721 .40929 L
s
.42072 .6584 m .39391 .65887 L .41827 .66135 L .654 .783 .943 r
F
0 g
.76831 .40921 m
.76937 .40933 L
s
.76721 .40929 m
.76831 .40921 L
s
.3481 .50684 m .34925 .52461 L .3653 .52426 L .643 .738 .918 r
F
.33991 .5058 m .34925 .52461 L .3481 .50684 L F
.33991 .5058 m .33306 .52257 L .34925 .52461 L F
.39402 .66509 m .36948 .66261 L .36747 .67195 L .653 .784 .944 r
F
0 g
.36747 .67195 m
.37058 .68102 L
s
.4121 .76878 m .42541 .76519 L .42578 .7703 L .784 .549 .581 r
F
.4121 .76878 m .41175 .76366 L .42541 .76519 L F
0 g
.42541 .76519 m
.43419 .76511 L
s
.6048 .44351 m
.6063 .50152 L
s
.59842 .4434 m
.5998 .50162 L
s
.44076 .77527 m .44038 .77016 L .45495 .76836 L .678 .469 .595 r
F
.42615 .77542 m .44038 .77016 L .44076 .77527 L .731 .509 .59 r
F
.42615 .77542 m .42578 .7703 L .44038 .77016 L F
.43054 .76212 m .42578 .7703 L .44038 .77016 L .656 .808 .956 r
F
.46689 .66632 m .48636 .65694 L .46442 .66351 L .653 .784 .944 r
F
.46689 .66632 m .49119 .66261 L .48636 .65694 L F
.42068 .65223 m .39883 .64675 L .39405 .65269 L .654 .782 .942 r
F
.4246 .64964 m .39883 .64675 L .42068 .65223 L F
.54059 .53169 m .51171 .54387 L .54221 .54094 L .642 .738 .919 r
F
.54059 .53169 m .50901 .53003 L .51171 .54387 L F
0 g
.51171 .54387 m
.52053 .55689 L
s
.45495 .76836 m .46815 .75992 L .46857 .76503 L .618 .424 .597 r
F
.45535 .77348 m .45495 .76836 L .46857 .76503 L F
.44076 .77527 m .45495 .76836 L .45535 .77348 L .678 .469 .595 r
F
.45012 .76083 m .45495 .76836 L .46857 .76503 L .656 .808 .956 r
F
0 g
.44038 .77016 m
.45495 .76836 L
s
.49093 .6564 m .50818 .64408 L .4861 .65071 L .654 .783 .943 r
F
.49093 .6564 m .51529 .65267 L .50818 .64408 L F
.26495 .5272 m .28219 .53119 L .28121 .53898 L .9 .663 .57 r
F
.26495 .5272 m .26598 .51939 L .28219 .53119 L F
.29237 .51185 m .28219 .53119 L .30314 .51982 L .642 .738 .919 r
F
.29237 .51185 m .26598 .51939 L .28219 .53119 L F
0 g
.28219 .53119 m
.28943 .53454 L
s
.33219 .5036 m .33306 .52257 L .33991 .5058 L .643 .738 .918 r
F
.33219 .5036 m .31774 .51825 L .33306 .52257 L F
.35621 .50666 m .3653 .52426 L .38016 .52153 L F
.3481 .50684 m .3653 .52426 L .35621 .50666 L F
.69316 .55343 m .69855 .53217 L .69851 .54001 L 0 0 .317 r
F
.66352 .54733 m .69316 .55343 L .69851 .54001 L .642 .738 .919 r
F
0 g
.6819 .56539 m
.69316 .55343 L
s
.51529 .65267 m .51499 .64648 L .50789 .63785 L .985 .717 .427 r
F
0 g
.51499 .64648 m
.51705 .65574 L
s
.46857 .76503 m .46815 .75992 L .47992 .75525 L .542 .367 .594 r
F
0 g
.45755 .76252 m
.46815 .75992 L
s
.46421 .65729 m .47822 .64588 L .46024 .6549 L .654 .783 .943 r
F
.46421 .65729 m .4861 .65071 L .47822 .64588 L F
.39883 .64675 m .36971 .65019 L .39405 .65269 L .654 .782 .942 r
F
.57249 .52553 m .54099 .52388 L .5426 .53315 L .643 .738 .918 r
F
0 g
.41954 .53495 m
.42061 .53476 L
s
.42087 .66462 m .39402 .66509 L .41842 .66756 L .653 .784 .944 r
F
.66364 .53952 m .69855 .53217 L .66703 .53051 L .643 .738 .918 r
F
.45994 .64875 m .46745 .63612 L .45478 .64696 L .654 .782 .942 r
F
.45994 .64875 m .4778 .63974 L .46745 .63612 L F
.49202 .54378 m .46997 .52953 L .46941 .53733 L .788 .547 .572 r
F
.49151 .5516 m .49202 .54378 L .46941 .53733 L F
0 g
.49202 .54378 m
.51116 .55308 L
s
.41245 .77392 m .42578 .7703 L .42615 .77542 L .784 .549 .581 r
F
.41245 .77392 m .4121 .76878 L .42578 .7703 L F
.42137 .76109 m .42578 .7703 L .43054 .76212 L .656 .808 .956 r
F
.42137 .76109 m .4121 .76878 L .42578 .7703 L F
0 g
.42578 .7703 m
.44038 .77016 L
s
.44072 .76718 m .44076 .77527 L .45535 .77348 L .656 .809 .957 r
F
.43092 .76727 m .44076 .77527 L .44072 .76718 L F
.43092 .76727 m .42615 .77542 L .44076 .77527 L F
.83382 .53657 m .85125 .51858 L .85156 .52638 L .433 .262 .549 r
F
.83409 .54438 m .83382 .53657 L .85156 .52638 L F
.81454 .52288 m .83382 .53657 L .85156 .52638 L .644 .737 .917 r
F
.80019 .52785 m .83382 .53657 L .81454 .52288 L F
0 g
.82092 .54097 m
.83382 .53657 L
s
.45535 .77348 m .46857 .76503 L .46899 .77015 L .618 .424 .597 r
F
.45052 .76597 m .45535 .77348 L .46899 .77015 L .656 .809 .957 r
F
.44072 .76718 m .45535 .77348 L .45052 .76597 L F
0 g
.44076 .77527 m
.45535 .77348 L
s
.42072 .6584 m .39873 .65292 L .39391 .65887 L .654 .783 .943 r
F
.42467 .65581 m .39873 .65292 L .42072 .6584 L F
.34727 .51474 m .34844 .53255 L .3646 .53221 L .642 .738 .919 r
F
.33902 .5137 m .34844 .53255 L .34727 .51474 L F
.33902 .5137 m .33212 .5305 L .34844 .53255 L F
.4246 .64964 m .40666 .64153 L .39883 .64675 L .654 .782 .942 r
F
.42976 .64759 m .40666 .64153 L .4246 .64964 L F
.49119 .66261 m .50847 .65032 L .48636 .65694 L .653 .784 .944 r
F
.49119 .66261 m .51559 .65889 L .50847 .65032 L F
.46857 .76503 m .47992 .75525 L .48035 .76037 L .542 .367 .594 r
F
.46899 .77015 m .46857 .76503 L .48035 .76037 L F
.45925 .75858 m .46857 .76503 L .48035 .76037 L .656 .808 .956 r
F
.45012 .76083 m .46857 .76503 L .45925 .75858 L F
0 g
.4579 .76764 m
.46857 .76503 L
s
.42127 .52697 m
.42281 .52694 L
s
.60082 .6444 m .60038 .63821 L .61999 .63647 L .676 .463 .588 r
F
.58146 .64364 m .60038 .63821 L .60082 .6444 L .732 .505 .584 r
F
.58146 .64364 m .58105 .63745 L .60038 .63821 L F
.46941 .53733 m .46997 .52953 L .44561 .52644 L .731 .496 .572 r
F
0 g
.46997 .52953 m
.49252 .536 L
s
.51529 .65267 m .50789 .63785 L .50818 .64408 L .985 .717 .427 r
F
.51559 .65889 m .51529 .65267 L .50818 .64408 L F
0 g
.51529 .65267 m
.51735 .66191 L
s
.46442 .66351 m .47846 .65212 L .46046 .66113 L .653 .784 .944 r
F
.46442 .66351 m .48636 .65694 L .47846 .65212 L F
.39873 .65292 m .36941 .65637 L .39391 .65887 L .654 .783 .943 r
F
.60183 .62577 m .6004 .63802 L .61991 .63629 L .654 .782 .942 r
F
.5889 .62525 m .6004 .63802 L .60183 .62577 L F
.5889 .62525 m .58117 .63727 L .6004 .63802 L F
.42174 .76625 m .42615 .77542 L .43092 .76727 L .656 .809 .957 r
F
.42174 .76625 m .41245 .77392 L .42615 .77542 L F
0 g
.42615 .77542 m
.44076 .77527 L
s
.40023 .76569 m .41175 .76366 L .4121 .76878 L .841 .593 .565 r
F
.40023 .76569 m .39989 .76055 L .41175 .76366 L F
0 g
.41175 .76366 m
.4175 .76431 L
s
.33124 .51149 m .33212 .5305 L .33902 .5137 L .642 .738 .919 r
F
.33124 .51149 m .31669 .52617 L .33212 .5305 L F
.35544 .51456 m .3646 .53221 L .37957 .52948 L F
.34727 .51474 m .3646 .53221 L .35544 .51456 L F
.32543 .50039 m .31774 .51825 L .33219 .5036 L .643 .738 .918 r
F
.32543 .50039 m .30429 .51192 L .31774 .51825 L F
.2914 .51969 m .28121 .53898 L .3022 .52764 L .641 .739 .92 r
F
.2914 .51969 m .26495 .5272 L .28121 .53898 L F
0 g
.28121 .53898 m
.3015 .54832 L
s
.45478 .64696 m .45531 .63397 L .44875 .64591 L .654 .782 .942 r
F
.45478 .64696 m .46745 .63612 L .45531 .63397 L F
.3637 .50526 m .38016 .52153 L .39288 .51658 L .643 .738 .918 r
F
.35621 .50666 m .38016 .52153 L .3637 .50526 L F
.46024 .6549 m .46781 .64225 L .45505 .65312 L .654 .783 .943 r
F
.46024 .6549 m .47822 .64588 L .46781 .64225 L F
.62045 .64266 m .61999 .63647 L .63864 .63234 L .616 .417 .59 r
F
.60082 .6444 m .61999 .63647 L .62045 .64266 L .676 .463 .588 r
F
0 g
.60038 .63821 m
.61999 .63647 L
s
.42162 .54097 m
.42211 .54064 L
s
.61496 .6246 m .61991 .63629 L .63847 .63219 L .654 .782 .942 r
F
.60183 .62577 m .61991 .63629 L .61496 .6246 L F
.46899 .77015 m .48035 .76037 L .48079 .7655 L .542 .367 .594 r
F
.45966 .76373 m .46899 .77015 L .48079 .7655 L .656 .809 .957 r
F
.45052 .76597 m .46899 .77015 L .45966 .76373 L F
0 g
.45535 .77348 m
.46899 .77015 L
s
.57217 .53336 m .54221 .54094 L .57289 .53799 L .642 .738 .919 r
F
.57217 .53336 m .54059 .53169 L .54221 .54094 L F
.42976 .64759 m .417 .63738 L .40666 .64153 L .654 .782 .942 r
F
.43579 .64624 m .417 .63738 L .42976 .64759 L F
.42087 .66462 m .39884 .65917 L .39402 .66509 L .653 .784 .944 r
F
.42483 .66203 m .39884 .65917 L .42087 .66462 L F
0 g
.39733 .54664 m
.41994 .54258 L
s
.48563 .64457 m .49587 .63063 L .4778 .63974 L .654 .782 .942 r
F
.48563 .64457 m .50756 .63795 L .49587 .63063 L F
.46941 .53733 m .44561 .52644 L .445 .53424 L .731 .496 .572 r
F
0 g
.44561 .52644 m
.46997 .52953 L
s
.42986 .52678 m
.44561 .52644 L
s
.66352 .54733 m .69851 .54001 L .66692 .53834 L .642 .738 .919 r
F
0 g
.6955 .53985 m
.69754 .5347 L
s
.63372 .54119 m .66352 .54733 L .66692 .53834 L .642 .738 .919 r
F
.63009 .54526 m .66352 .54733 L .63372 .54119 L F
.49151 .5516 m .46941 .53733 L .46885 .54516 L .788 .547 .572 r
F
0 g
.49151 .5516 m
.5107 .56088 L
s
.42467 .65581 m .4066 .64768 L .39873 .65292 L .654 .783 .943 r
F
.42986 .65376 m .4066 .64768 L .42467 .65581 L F
.56359 .64044 m .58105 .63745 L .58146 .64364 L .788 .548 .574 r
F
.56359 .64044 m .56321 .63423 L .58105 .63745 L F
0 g
.58105 .63745 m
.60038 .63821 L
s
.71637 .51804 m .70079 .53736 L .72519 .526 L .643 .738 .918 r
F
0 g
.69853 .53536 m
.70079 .53736 L
s
.70079 .53736 m
.71887 .54672 L
s
.39883 .64675 m .37676 .64123 L .36971 .65019 L .654 .782 .942 r
F
.40057 .77083 m .4121 .76878 L .41245 .77392 L .841 .593 .565 r
F
.40057 .77083 m .40023 .76569 L .4121 .76878 L F
.41345 .759 m .4121 .76878 L .42137 .76109 L .656 .808 .956 r
F
.41345 .759 m .40023 .76569 L .4121 .76878 L F
0 g
.4121 .76878 m
.41789 .76943 L
s
.37651 .64739 m .36934 .65015 L .36941 .65637 L .127 .035 .472 r
F
.37651 .64739 m .37643 .64114 L .36934 .65015 L F
0 g
.36734 .65955 m
.36934 .65015 L
s
.48035 .76037 m .47992 .75525 L .48907 .74954 L .427 .283 .582 r
F
0 g
.46937 .75944 m
.47992 .75525 L
s
.57699 .62307 m .58117 .63727 L .5889 .62525 L .654 .782 .942 r
F
.57699 .62307 m .56341 .63406 L .58117 .63727 L F
.44875 .64591 m .44223 .63346 L .44227 .64566 L F
.44875 .64591 m .45531 .63397 L .44223 .63346 L F
.83409 .54438 m .85156 .52638 L .85187 .53421 L .433 .262 .549 r
F
.81476 .53072 m .83409 .54438 L .85187 .53421 L .643 .738 .918 r
F
.80038 .53567 m .83409 .54438 L .81476 .53072 L F
0 g
.81262 .55166 m
.83409 .54438 L
s
.60125 .65061 m .60082 .6444 L .62045 .64266 L .676 .463 .588 r
F
.58186 .64986 m .60082 .6444 L .60125 .65061 L .732 .505 .584 r
F
.58186 .64986 m .58146 .64364 L .60082 .6444 L F
.60226 .63212 m .60082 .6444 L .62045 .64266 L .654 .783 .943 r
F
.58924 .63161 m .60082 .6444 L .60226 .63212 L F
.58924 .63161 m .58146 .64364 L .60082 .6444 L F
.51559 .65889 m .50818 .64408 L .50847 .65032 L .985 .717 .427 r
F
0 g
.51559 .65889 m
.51765 .66809 L
s
.39884 .65917 m .36948 .66261 L .39402 .66509 L .653 .784 .944 r
F
.43579 .64624 m .42915 .63462 L .417 .63738 L .654 .782 .942 r
F
.44227 .64566 m .42915 .63462 L .43579 .64624 L F
.34643 .52259 m .34761 .54035 L .3638 .54001 L .641 .739 .92 r
F
.33816 .52154 m .34761 .54035 L .34643 .52259 L F
.33816 .52154 m .33126 .5383 L .34761 .54035 L F
.44227 .64566 m .44223 .63346 L .42915 .63462 L .654 .782 .942 r
F
.45505 .65312 m .45559 .6401 L .44898 .65206 L .654 .783 .943 r
F
.45505 .65312 m .46781 .64225 L .45559 .6401 L F
.46046 .66113 m .46804 .64851 L .45526 .65935 L .653 .784 .944 r
F
.46046 .66113 m .47846 .65212 L .46804 .64851 L F
.62045 .64266 m .63864 .63234 L .63914 .63854 L .616 .417 .59 r
F
.62092 .64887 m .62045 .64266 L .63914 .63854 L F
.60125 .65061 m .62045 .64266 L .62092 .64887 L .676 .463 .588 r
F
.61547 .63095 m .62045 .64266 L .63914 .63854 L .654 .783 .943 r
F
.60226 .63212 m .62045 .64266 L .61547 .63095 L F
0 g
.60082 .6444 m
.62045 .64266 L
s
.42061 .53476 m
.42215 .53473 L
s
.54437 .50698 m .51042 .51446 L .54169 .51611 L .644 .737 .917 r
F
.54437 .50698 m .51416 .50071 L .51042 .51446 L F
.51325 .50843 m .50995 .51444 L .50948 .52222 L 0 0 .157 r
F
0 g
.51063 .518 m
.51146 .52232 L
s
.51325 .50843 m .51371 .50062 L .50995 .51444 L 0 0 .157 r
F
.46885 .54516 m .46941 .53733 L .445 .53424 L .731 .496 .572 r
F
0 g
.46941 .53733 m
.49202 .54378 L
s
.5744 .51321 m .54169 .51611 L .57297 .51776 L .644 .737 .917 r
F
.5744 .51321 m .54437 .50698 L .54169 .51611 L F
.63554 .52105 m .66594 .51337 L .63501 .5164 L F
.63554 .52105 m .66682 .52269 L .66594 .51337 L F
.32443 .50827 m .31669 .52617 L .33124 .51149 L .642 .738 .919 r
F
.32443 .50827 m .30314 .51982 L .31669 .52617 L F
.42986 .65376 m .41702 .64352 L .4066 .64768 L .654 .783 .943 r
F
.43593 .65239 m .41702 .64352 L .42986 .65376 L F
.33036 .51934 m .33126 .5383 L .33816 .52154 L .641 .739 .92 r
F
.33036 .51934 m .31579 .53397 L .33126 .5383 L F
.35461 .52241 m .3638 .54001 L .3788 .53729 L F
.34643 .52259 m .3638 .54001 L .35461 .52241 L F
.36298 .51316 m .37957 .52948 L .39238 .52452 L .642 .738 .919 r
F
.35544 .51456 m .37957 .52948 L .36298 .51316 L F
.4138 .76416 m .41245 .77392 L .42174 .76625 L .656 .809 .957 r
F
.4138 .76416 m .40057 .77083 L .41245 .77392 L F
0 g
.41245 .77392 m
.42615 .77542 L
s
.4861 .65071 m .49642 .63674 L .47822 .64588 L .654 .783 .943 r
F
.4861 .65071 m .50818 .64408 L .49642 .63674 L F
.48035 .76037 m .48907 .74954 L .48952 .75467 L .427 .283 .582 r
F
.48079 .7655 m .48035 .76037 L .48952 .75467 L F
.46713 .75545 m .48035 .76037 L .48952 .75467 L .656 .808 .956 r
F
.45925 .75858 m .48035 .76037 L .46713 .75545 L F
0 g
.46973 .76457 m
.48035 .76037 L
s
.44539 .69123 m
.44593 .66904 L
s
.43884 .69113 m
.43941 .6692 L
s
.76336 .51989 m .76787 .53874 L .77148 .52094 L .643 .738 .918 r
F
.76336 .51989 m .75181 .53668 L .76787 .53874 L F
.42483 .66203 m .40673 .65394 L .39884 .65917 L .653 .784 .944 r
F
.43003 .65999 m .40673 .65394 L .42483 .66203 L F
.25493 .50586 m .267 .51161 L .26598 .51939 L .965 .736 .542 r
F
.25493 .50586 m .25598 .49805 L .267 .51161 L F
0 g
.267 .51161 m
.27436 .517 L
s
.40666 .64153 m .37676 .64123 L .39883 .64675 L .654 .782 .942 r
F
.56397 .64667 m .58146 .64364 L .58186 .64986 L .788 .548 .574 r
F
.56397 .64667 m .56359 .64044 L .58146 .64364 L F
.57725 .62943 m .58146 .64364 L .58924 .63161 L .654 .783 .943 r
F
.57725 .62943 m .56359 .64044 L .58146 .64364 L F
0 g
.58146 .64364 m
.60082 .6444 L
s
.63914 .63854 m .63864 .63234 L .65515 .62607 L .541 .362 .587 r
F
0 g
.62749 .63481 m
.63864 .63234 L
s
.28641 .49491 m .26739 .5115 L .2936 .50397 L .643 .738 .918 r
F
.28641 .49491 m .25643 .49801 L .26739 .5115 L F
.39873 .65292 m .37651 .64739 L .36941 .65637 L .654 .783 .943 r
F
.37659 .65366 m .36941 .65637 L .36948 .66261 L .127 .035 .472 r
F
.37659 .65366 m .37651 .64739 L .36941 .65637 L F
0 g
.3674 .66574 m
.36941 .65637 L
s
.62743 .62182 m .63847 .63219 L .65491 .62594 L .654 .782 .942 r
F
.61496 .6246 m .63847 .63219 L .62743 .62182 L F
.42976 .52801 m .4304 .52021 L .43974 .50772 L .054 0 .384 r
F
0 g
.42295 .52537 m
.4304 .52021 L
s
.44898 .65206 m .44242 .63959 L .44245 .65182 L .654 .783 .943 r
F
.44898 .65206 m .45559 .6401 L .44242 .63959 L F
.6027 .63837 m .60125 .65061 L .62092 .64887 L .653 .784 .944 r
F
.58966 .63786 m .60125 .65061 L .6027 .63837 L F
.58966 .63786 m .58186 .64986 L .60125 .65061 L F
.40261 .50971 m .42999 .52006 L .43928 .50762 L .643 .738 .918 r
F
.39288 .51658 m .42999 .52006 L .40261 .50971 L F
0 g
.4444 .73177 m
.44539 .69123 L
s
.43776 .73205 m
.43884 .69113 L
s
.46885 .54516 m .445 .53424 L .44439 .54207 L .731 .496 .572 r
F
0 g
.445 .53424 m
.46941 .53733 L
s
.46885 .54516 m
.49151 .5516 L
s
.42921 .53458 m
.445 .53424 L
s
.43593 .65239 m .42925 .64076 L .41702 .64352 L .654 .783 .943 r
F
.44245 .65182 m .42925 .64076 L .43593 .65239 L F
.75604 .51769 m .75181 .53668 L .76336 .51989 L .643 .738 .918 r
F
.75604 .51769 m .73727 .53235 L .75181 .53668 L F
.44245 .65182 m .44242 .63959 L .42925 .64076 L .654 .783 .943 r
F
.45526 .65935 m .45579 .64637 L .44918 .6583 L .653 .784 .944 r
F
.45526 .65935 m .46804 .64851 L .45579 .64637 L F
.62092 .64887 m .63914 .63854 L .63964 .64476 L .616 .417 .59 r
F
.61594 .6372 m .62092 .64887 L .63964 .64476 L .653 .784 .944 r
F
.6027 .63837 m .62092 .64887 L .61594 .6372 L F
0 g
.60125 .65061 m
.62092 .64887 L
s
.39096 .7612 m .39989 .76055 L .40023 .76569 L .907 .646 .532 r
F
.39096 .7612 m .39063 .75604 L .39989 .76055 L F
0 g
.39989 .76055 m
.4068 .76236 L
s
.4071 .75076 m .39087 .75596 L .40009 .76045 L .657 .808 .956 r
F
.48079 .7655 m .48952 .75467 L .48997 .75982 L .427 .283 .582 r
F
.46755 .7606 m .48079 .7655 L .48997 .75982 L .656 .809 .957 r
F
.45966 .76373 m .48079 .7655 L .46755 .7606 L F
0 g
.46899 .77015 m
.48079 .7655 L
s
.32011 .49636 m .30429 .51192 L .32543 .50039 L .643 .738 .918 r
F
.32011 .49636 m .2936 .50397 L .30429 .51192 L F
.63372 .54119 m .66692 .53834 L .63533 .53668 L .642 .738 .919 r
F
.85156 .52638 m .85125 .51858 L .86407 .50606 L .269 .14 .513 r
F
0 g
.83969 .52526 m
.85125 .51858 L
s
.37009 .50274 m .39288 .51658 L .40261 .50971 L .643 .738 .918 r
F
.3637 .50526 m .39288 .51658 L .37009 .50274 L F
.43003 .65999 m .41716 .64979 L .40673 .65394 L .653 .784 .944 r
F
.4361 .65863 m .41716 .64979 L .43003 .65999 L F
.48636 .65694 m .49669 .64301 L .47846 .65212 L F
.48636 .65694 m .50847 .65032 L .49669 .64301 L F
0 g
.41994 .54258 m
.42149 .54255 L
s
.42149 .54255 m
.44439 .54207 L
s
.4066 .64768 m .37651 .64739 L .39873 .65292 L .654 .783 .943 r
F
.54367 .51472 m .50948 .52222 L .54099 .52388 L .643 .738 .918 r
F
.54367 .51472 m .51325 .50843 L .50948 .52222 L F
.51278 .51629 m .50948 .52222 L .50901 .53003 L 0 0 .157 r
F
0 g
.51017 .5258 m
.51101 .53014 L
s
.51278 .51629 m .51325 .50843 L .50948 .52222 L 0 0 .157 r
F
.54837 .63497 m .56321 .63423 L .56359 .64044 L .85 .597 .556 r
F
.54837 .63497 m .54801 .62873 L .56321 .63423 L F
0 g
.56321 .63423 m
.56982 .63542 L
s
.57766 .63569 m .58186 .64986 L .58966 .63786 L .653 .784 .944 r
F
.57766 .63569 m .56397 .64667 L .58186 .64986 L F
0 g
.58186 .64986 m
.60125 .65061 L
s
.63914 .63854 m .65515 .62607 L .65568 .63228 L .541 .362 .587 r
F
.63964 .64476 m .63914 .63854 L .65568 .63228 L F
.62802 .62816 m .63914 .63854 L .65568 .63228 L .654 .783 .943 r
F
.61547 .63095 m .63914 .63854 L .62802 .62816 L F
0 g
.6279 .64102 m
.63914 .63854 L
s
.44439 .54207 m
.46885 .54516 L
s
.57393 .52098 m .54099 .52388 L .57249 .52553 L .643 .738 .918 r
F
.57393 .52098 m .54367 .51472 L .54099 .52388 L F
.56688 .61937 m .56341 .63406 L .57699 .62307 L .654 .782 .942 r
F
.56688 .61937 m .54829 .6286 L .56341 .63406 L F
.39884 .65917 m .37659 .65366 L .36948 .66261 L .653 .784 .944 r
F
0 g
.36747 .67195 m
.36948 .66261 L
s
.63552 .52885 m .66614 .52117 L .63498 .52419 L .643 .738 .918 r
F
.63552 .52885 m .66703 .53051 L .66614 .52117 L F
.66703 .53051 m .69749 .51813 L .66614 .52117 L F
.66703 .53051 m .69855 .53217 L .69749 .51813 L F
.44918 .6583 m .4426 .64586 L .44264 .65805 L .653 .784 .944 r
F
.44918 .6583 m .45579 .64637 L .4426 .64586 L F
.69851 .54001 m .69855 .53217 L .69749 .51813 L .798 .639 .083 r
F
0 g
.69754 .5347 m
.69819 .53308 L
s
.32353 .51612 m .31579 .53397 L .33036 .51934 L .641 .739 .92 r
F
.32353 .51612 m .3022 .52764 L .31579 .53397 L F
.36218 .52102 m .3788 .53729 L .39164 .53235 L F
.35461 .52241 m .3788 .53729 L .36218 .52102 L F
.4361 .65863 m .42941 .64703 L .41716 .64979 L .653 .784 .944 r
F
.44264 .65805 m .42941 .64703 L .4361 .65863 L F
.4778 .63974 m .48032 .6251 L .46745 .63612 L .654 .782 .942 r
F
.4778 .63974 m .49587 .63063 L .48032 .6251 L F
.39129 .76636 m .40023 .76569 L .40057 .77083 L .907 .646 .532 r
F
.39129 .76636 m .39096 .7612 L .40023 .76569 L F
.40729 .75598 m .40023 .76569 L .41345 .759 L .656 .808 .956 r
F
.40729 .75598 m .39096 .7612 L .40023 .76569 L F
0 g
.40023 .76569 m
.40718 .7675 L
s
.25387 .51371 m .26598 .51939 L .26495 .5272 L .965 .736 .542 r
F
.25387 .51371 m .25493 .50586 L .26598 .51939 L F
.28513 .50277 m .26598 .51939 L .29237 .51185 L .642 .738 .919 r
F
.28513 .50277 m .25493 .50586 L .26598 .51939 L F
0 g
.26598 .51939 m
.27341 .5248 L
s
.44264 .65805 m .4426 .64586 L .42941 .64703 L .653 .784 .944 r
F
.57787 .50906 m .54437 .50698 L .5744 .51321 L .644 .737 .917 r
F
.50818 .64408 m .50789 .63785 L .49615 .63049 L .919 .656 .524 r
F
0 g
.50789 .63785 m
.51499 .64648 L
s
.63501 .5164 m .66079 .50436 L .63236 .51193 L .644 .737 .917 r
F
.63501 .5164 m .66594 .51337 L .66079 .50436 L F
.42976 .52801 m .43974 .50772 L .4391 .51555 L .054 0 .384 r
F
.4291 .53584 m .42976 .52801 L .4391 .51555 L F
.40218 .51763 m .42976 .52801 L .4391 .51555 L .642 .738 .919 r
F
.39238 .52452 m .42976 .52801 L .40218 .51763 L F
0 g
.42229 .53315 m
.42976 .52801 L
s
.48952 .75467 m .48907 .74954 L .49498 .74315 L .222 .134 .539 r
F
0 g
.48034 .75499 m
.48907 .74954 L
s
.47263 .74644 m .48883 .74949 L .4947 .74313 L .657 .808 .956 r
F
.74998 .51446 m .73727 .53235 L .75604 .51769 L .643 .738 .918 r
F
.74998 .51446 m .72519 .526 L .73727 .53235 L F
.7879 .51936 m .80038 .53567 L .81476 .53072 L F
.43575 .75901 m .43092 .76727 L .44072 .76718 L .656 .809 .957 r
F
.40673 .65394 m .37659 .65366 L .39884 .65917 L .653 .784 .944 r
F
.54872 .64122 m .56359 .64044 L .56397 .64667 L .85 .597 .556 r
F
.54872 .64122 m .54837 .63497 L .56359 .64044 L F
.56708 .62572 m .56359 .64044 L .57725 .62943 L .654 .783 .943 r
F
.56708 .62572 m .54837 .63497 L .56359 .64044 L F
0 g
.56359 .64044 m
.57025 .64163 L
s
.61594 .6372 m .63964 .64476 L .62851 .63442 L .653 .784 .944 r
F
.63964 .64476 m .65568 .63228 L .65621 .63852 L .541 .362 .587 r
F
.62851 .63442 m .63964 .64476 L .65621 .63852 L .653 .784 .944 r
F
0 g
.62092 .64887 m
.63964 .64476 L
s
.31907 .50423 m .30314 .51982 L .32443 .50827 L .642 .738 .919 r
F
.31907 .50423 m .29237 .51185 L .30314 .51982 L F
.44561 .75836 m .45052 .76597 L .45966 .76373 L .656 .809 .957 r
F
.36941 .51063 m .39238 .52452 L .40218 .51763 L .642 .738 .919 r
F
.36298 .51316 m .39238 .52452 L .36941 .51063 L F
.85156 .52638 m .86407 .50606 L .86441 .51389 L .269 .14 .513 r
F
.85187 .53421 m .85156 .52638 L .86441 .51389 L F
.82634 .51598 m .85156 .52638 L .86441 .51389 L .644 .737 .917 r
F
.81454 .52288 m .85156 .52638 L .82634 .51598 L F
0 g
.83989 .53308 m
.85156 .52638 L
s
.40764 .76115 m .40057 .77083 L .4138 .76416 L .656 .809 .957 r
F
.40764 .76115 m .39129 .76636 L .40057 .77083 L F
0 g
.40057 .77083 m
.41245 .77392 L
s
.40666 .64153 m .38846 .6333 L .37676 .64123 L .654 .782 .942 r
F
.417 .63738 m .38846 .6333 L .40666 .64153 L F
.47822 .64588 m .48077 .63121 L .46781 .64225 L .654 .783 .943 r
F
.47822 .64588 m .49642 .63674 L .48077 .63121 L F
.43113 .75849 m .43092 .76727 L .43575 .75901 L .656 .809 .957 r
F
.43113 .75849 m .42174 .76625 L .43092 .76727 L F
.54328 .52257 m .50901 .53003 L .54059 .53169 L .642 .738 .919 r
F
.54328 .52257 m .51278 .51629 L .50901 .53003 L F
0 g
.50901 .53003 m
.51171 .54387 L
s
.48952 .75467 m .49498 .74315 L .49544 .7483 L .222 .134 .539 r
F
.48997 .75982 m .48952 .75467 L .49544 .7483 L F
.47323 .75162 m .48952 .75467 L .49544 .7483 L .656 .808 .956 r
F
.46713 .75545 m .48952 .75467 L .47323 .75162 L F
0 g
.48073 .76014 m
.48952 .75467 L
s
.5736 .52881 m .54059 .53169 L .57217 .53336 L .642 .738 .919 r
F
.5736 .52881 m .54328 .52257 L .54059 .53169 L F
.50818 .64408 m .49615 .63049 L .49642 .63674 L .919 .656 .524 r
F
.50847 .65032 m .50818 .64408 L .49642 .63674 L F
0 g
.50818 .64408 m
.51529 .65267 L
s
.63533 .53668 m .66603 .52903 L .6348 .53203 L .642 .738 .919 r
F
.63533 .53668 m .66692 .53834 L .66603 .52903 L F
.66692 .53834 m .69745 .526 L .66603 .52903 L F
.66692 .53834 m .69851 .54001 L .69745 .526 L F
.65568 .63228 m .65515 .62607 L .66845 .61802 L .436 .285 .576 r
F
0 g
.64355 .63048 m
.65515 .62607 L
s
.69851 .54001 m .69749 .51813 L .69745 .526 L .798 .639 .083 r
F
0 g
.69316 .55343 m
.69851 .54001 L
s
.63843 .6176 m .65491 .62594 L .66814 .61794 L .654 .782 .942 r
F
.62743 .62182 m .65491 .62594 L .63843 .6176 L F
.45021 .75722 m .45966 .76373 L .46755 .7606 L .656 .809 .957 r
F
.44561 .75836 m .45966 .76373 L .45021 .75722 L F
.28413 .51063 m .26495 .5272 L .2914 .51969 L .641 .739 .92 r
F
.28413 .51063 m .25387 .51371 L .26495 .5272 L F
0 g
.26495 .5272 m
.28121 .53898 L
s
.57743 .51682 m .54367 .51472 L .57393 .52098 L .643 .738 .918 r
F
.63498 .52419 m .66096 .51213 L .63232 .51971 L F
.63498 .52419 m .66614 .52117 L .66096 .51213 L F
.4291 .53584 m .4391 .51555 L .43847 .52342 L .054 0 .384 r
F
.40146 .52549 m .4291 .53584 L .43847 .52342 L .641 .739 .92 r
F
.39164 .53235 m .4291 .53584 L .40146 .52549 L F
0 g
.42211 .54064 m
.4291 .53584 L
s
.56747 .632 m .56397 .64667 L .57766 .63569 L .653 .784 .944 r
F
.56747 .632 m .54872 .64122 L .56397 .64667 L F
0 g
.56397 .64667 m
.58186 .64986 L
s
.57787 .50906 m .5512 .4986 L .54437 .50698 L .644 .737 .917 r
F
.58318 .5056 m .5512 .4986 L .57787 .50906 L F
.38828 .63944 m .37643 .64114 L .37651 .64739 L .387 .234 .548 r
F
.38828 .63944 m .38818 .63317 L .37643 .64114 L F
0 g
.36934 .65015 m
.37643 .64114 L
s
.63236 .51193 m .65168 .4963 L .62777 .50795 L .644 .737 .917 r
F
.63236 .51193 m .66079 .50436 L .65168 .4963 L F
.48997 .75982 m .49544 .7483 L .4959 .75346 L .222 .134 .539 r
F
.47366 .75678 m .48997 .75982 L .4959 .75346 L .656 .809 .957 r
F
.46755 .7606 m .48997 .75982 L .47366 .75678 L F
0 g
.48079 .7655 m
.48997 .75982 L
s
.5512 .4986 m .51416 .50071 L .54437 .50698 L .644 .737 .917 r
F
.4066 .64768 m .38828 .63944 L .37651 .64739 L .654 .783 .943 r
F
.41702 .64352 m .38828 .63944 L .4066 .64768 L F
.46745 .63612 m .46199 .62182 L .45531 .63397 L .654 .782 .942 r
F
.46745 .63612 m .48032 .6251 L .46199 .62182 L F
.47846 .65212 m .48102 .6375 L .46804 .64851 L .653 .784 .944 r
F
.47846 .65212 m .49669 .64301 L .48102 .6375 L F
.31815 .5121 m .3022 .52764 L .32353 .51612 L .641 .739 .92 r
F
.31815 .5121 m .2914 .51969 L .3022 .52764 L F
.42716 .75743 m .42174 .76625 L .43113 .75849 L .656 .809 .957 r
F
.42716 .75743 m .4138 .76416 L .42174 .76625 L F
.50847 .65032 m .49642 .63674 L .49669 .64301 L .919 .656 .524 r
F
0 g
.50847 .65032 m
.51559 .65889 L
s
.38494 .75559 m .39063 .75604 L .39096 .7612 L .977 .706 .449 r
F
.38494 .75559 m .38462 .75042 L .39063 .75604 L F
0 g
.39063 .75604 m
.39715 .75922 L
s
.40317 .747 m .39087 .75596 L .4071 .75076 L .657 .808 .956 r
F
.40317 .747 m .3849 .75037 L .39087 .75596 L F
.36862 .5185 m .39164 .53235 L .40146 .52549 L .641 .739 .92 r
F
.36218 .52102 m .39164 .53235 L .36862 .5185 L F
.85187 .53421 m .86441 .51389 L .86475 .52177 L .269 .14 .513 r
F
.8266 .52384 m .85187 .53421 L .86475 .52177 L .643 .738 .918 r
F
.81476 .53072 m .85187 .53421 L .8266 .52384 L F
0 g
.83409 .54438 m
.85187 .53421 L
s
.31658 .4918 m .2936 .50397 L .32011 .49636 L .643 .738 .918 r
F
.31658 .4918 m .28641 .49491 L .2936 .50397 L F
.65568 .63228 m .66845 .61802 L .669 .62426 L .436 .285 .576 r
F
.65621 .63852 m .65568 .63228 L .669 .62426 L F
.6391 .62393 m .65568 .63228 L .669 .62426 L .654 .783 .943 r
F
.62802 .62816 m .65568 .63228 L .6391 .62393 L F
0 g
.64398 .63671 m
.65568 .63228 L
s
.34705 .47731 m .34864 .47712 L .34784 .49118 L .644 .409 .547 r
F
.34784 .49154 m .3481 .50684 L .34821 .49128 L .643 .738 .918 r
F
.3471 .49143 m .3481 .50684 L .34784 .49118 L F
.34855 .49182 m .3481 .50684 L .34887 .50682 L F
.34963 .49391 m .34887 .50682 L .35621 .50666 L F
.34855 .49182 m .34887 .50682 L .34963 .49391 L F
.34964 .47672 m .3495 .49036 L .34898 .49073 L .335 .155 .483 r
F
.34964 .47672 m .34898 .49073 L .34883 .49083 L F
.34864 .47712 m .34806 .4911 L .34784 .49118 L .516 .302 .527 r
F
.34705 .47731 m .34784 .49118 L .3466 .49127 L .644 .409 .547 r
F
.3503 .47619 m .35068 .47556 L .34987 .48978 L 0 0 .355 r
F
.34977 .49148 m .35621 .50666 L .35997 .50596 L .643 .738 .918 r
F
.34977 .49148 m .35997 .50596 L .3536 .49527 L F
.34916 .49088 m .34973 .49216 L .34977 .49148 L F
.34973 .49216 m .35621 .50666 L .34977 .49148 L F
.34912 .49094 m .35621 .50666 L .34916 .49088 L F
.34816 .49107 m .35621 .50666 L .34904 .49076 L F
.34864 .47712 m .34964 .47672 L .34883 .49083 L .516 .302 .527 r
F
.34864 .47712 m .34883 .49083 L .34806 .4911 L F
.3503 .47619 m .34958 .49023 L .3495 .49036 L 0 0 .355 r
F
.34964 .47672 m .3503 .47619 L .3495 .49036 L .335 .155 .483 r
F
.35122 .49128 m .3637 .50526 L .37009 .50274 L .643 .738 .918 r
F
.34692 .48866 m .3536 .49527 L .35122 .49128 L F
.3536 .49527 m .3637 .50526 L .35122 .49128 L F
.3503 .47619 m .34987 .48978 L .34958 .49023 L 0 0 .355 r
F
.35072 .47481 m .35017 .47384 L .34936 .48815 L .992 .745 .442 r
F
.35068 .47556 m .34988 .48963 L .34987 .48978 L 0 0 0 r
F
.34692 .48866 m .37009 .50274 L .37076 .50225 L .643 .738 .918 r
F
.35447 .49152 m .37076 .50225 L .37493 .49925 L F
.34692 .48866 m .37076 .50225 L .35447 .49152 L F
.35068 .47556 m .34991 .48908 L .34988 .48963 L 0 0 0 r
F
.3516 .48962 m .37493 .49925 L .37789 .49502 L .643 .738 .918 r
F
.34692 .48866 m .35447 .49152 L .3516 .48962 L F
.35447 .49152 m .37493 .49925 L .3516 .48962 L F
.35017 .47384 m .34902 .47307 L .34821 .48739 L .892 .63 .535 r
F
.34824 .4923 m .3481 .50684 L .34855 .49182 L .643 .738 .918 r
F
.34544 .47707 m .34705 .47731 L .34624 .4913 L .749 .499 .553 r
F
.34367 .47608 m .34439 .47663 L .34358 .49056 L .909 .647 .529 r
F
.34309 .47468 m .34322 .47544 L .3424 .4894 L .923 .74 .252 r
F
.34439 .50013 m .33991 .5058 L .34558 .50652 L .643 .738 .918 r
F
.34633 .49481 m .34411 .49861 L .34742 .4963 L F
.34411 .49861 m .33991 .5058 L .34439 .50013 L F
.34411 .49861 m .34439 .50013 L .34742 .4963 L F
.34672 .4929 m .34597 .49432 L .34722 .49327 L F
.34597 .49432 m .33991 .5058 L .34633 .49481 L F
.34597 .49432 m .34633 .49481 L .34722 .49327 L F
.34685 .49197 m .34647 .49271 L .34715 .49209 L F
.34647 .49271 m .33991 .5058 L .34672 .4929 L F
.34647 .49271 m .34672 .4929 L .34715 .49209 L F
.34699 .49143 m .34675 .49192 L .3471 .49145 L F
.34675 .49192 m .33991 .5058 L .34685 .49197 L F
.34675 .49192 m .34685 .49197 L .3471 .49145 L F
.34583 .49133 m .33991 .5058 L .34699 .49143 L F
.34624 .4913 m .34699 .49143 L .34709 .49123 L F
.34583 .49133 m .34699 .49143 L .34624 .4913 L F
.34742 .4963 m .34439 .50013 L .3481 .50684 L F
.34439 .50013 m .34558 .50652 L .3481 .50684 L F
.34544 .47707 m .34498 .49108 L .34463 .49101 L .749 .499 .553 r
F
.34439 .47663 m .34544 .47707 L .34463 .49101 L .834 .575 .548 r
F
.34439 .47663 m .34463 .49101 L .34381 .49066 L F
.34544 .47707 m .34624 .4913 L .34498 .49108 L .749 .499 .553 r
F
.34705 .47731 m .3466 .49127 L .34624 .4913 L .644 .409 .547 r
F
.34692 .48866 m .33754 .49818 L .33991 .5058 L .643 .738 .918 r
F
.33754 .49818 m .33219 .5036 L .33451 .50426 L F
.33754 .49818 m .33451 .50426 L .33991 .5058 L F
.34322 .47544 m .3425 .48953 L .3424 .4894 L .981 .727 .472 r
F
.34309 .47468 m .34229 .48884 L .34226 .48868 L .923 .74 .252 r
F
.34309 .47468 m .3424 .4894 L .34229 .48884 L F
.34322 .47544 m .34367 .47608 L .34285 .49002 L .981 .727 .472 r
F
.34322 .47544 m .34285 .49002 L .3425 .48953 L F
.34353 .47373 m .34309 .47468 L .34226 .48868 L 0 0 .29 r
F
.34439 .47663 m .34381 .49066 L .34358 .49056 L .834 .575 .548 r
F
.34367 .47608 m .34358 .49056 L .34301 .49014 L .909 .647 .529 r
F
.33754 .49818 m .32543 .50039 L .33219 .5036 L .643 .738 .918 r
F
.34692 .48866 m .34054 .49215 L .33754 .49818 L F
.34054 .49215 m .32543 .50039 L .33754 .49818 L F
.34821 .49128 m .3481 .50684 L .34826 .49124 L F
.34646 .5051 m .34657 .50202 L .3515 .50165 L .669 .434 .556 r
F
.34147 .5047 m .34657 .50202 L .34646 .5051 L .73 .486 .558 r
F
.34646 .5051 m .3515 .50165 L .35139 .50472 L .669 .434 .556 r
F
.34705 .5077 m .34646 .5051 L .35139 .50472 L F
.34328 .50778 m .33902 .5137 L .34673 .50776 L .642 .738 .919 r
F
.34636 .50771 m .34673 .50776 L .34681 .5077 L F
.34328 .50778 m .34673 .50776 L .34636 .50771 L F
.34681 .5077 m .33902 .5137 L .34727 .51474 L F
.34243 .50722 m .34646 .5051 L .34636 .50771 L .73 .486 .558 r
F
.34636 .50771 m .34646 .5051 L .34705 .5077 L .669 .434 .556 r
F
.34243 .50722 m .34147 .5047 L .34646 .5051 L .73 .486 .558 r
F
.34147 .5047 m .34159 .50162 L .34657 .50202 L F
.34634 .49819 m .34656 .50197 L .35147 .5016 L .668 .746 .909 r
F
.34303 .49792 m .34656 .50197 L .34634 .49819 L F
.34303 .49792 m .34161 .50157 L .34656 .50197 L F
.34623 .5013 m .34646 .5051 L .35139 .50472 L .668 .747 .91 r
F
.3429 .50103 m .34646 .5051 L .34623 .5013 L F
.3429 .50103 m .34147 .5047 L .34646 .5051 L F
.34652 .5033 m .34359 .50736 L .34681 .5077 L .642 .738 .919 r
F
.34359 .50736 m .34328 .50778 L .34636 .50771 L F
.34359 .50736 m .34636 .50771 L .34681 .5077 L F
.34139 .50708 m .34147 .5047 L .34243 .50722 L .73 .486 .558 r
F
.34445 .49425 m .34303 .49792 L .34634 .49819 L .668 .746 .909 r
F
.34433 .49735 m .3429 .50103 L .34623 .5013 L .668 .747 .91 r
F
.34445 .50047 m .34317 .50359 L .34652 .5033 L .642 .738 .919 r
F
.34317 .50359 m .33902 .5137 L .34382 .50704 L F
.34317 .50359 m .34382 .50704 L .34652 .5033 L F
.34367 .47608 m .34301 .49014 L .34285 .49002 L .909 .647 .529 r
F
.34692 .48866 m .33622 .49174 L .32543 .50039 L .643 .738 .918 r
F
.33622 .49174 m .32011 .49636 L .3239 .49922 L F
.33622 .49174 m .3239 .49922 L .32543 .50039 L F
.34459 .473 m .34353 .47373 L .3427 .4878 L .385 .194 .495 r
F
.33622 .49174 m .31658 .4918 L .32011 .49636 L .643 .738 .918 r
F
.34692 .48866 m .34012 .48937 L .33622 .49174 L F
.34012 .48937 m .31658 .4918 L .33622 .49174 L F
.33678 .50355 m .34159 .50162 L .34147 .5047 L .788 .536 .556 r
F
.3417 .50717 m .3374 .50595 L .33902 .5137 L .642 .738 .919 r
F
.33795 .50611 m .33678 .50355 L .34147 .5047 L .788 .536 .556 r
F
.33702 .50591 m .33124 .51149 L .33386 .51224 L .642 .738 .919 r
F
.33705 .50585 m .337 .5059 L .33702 .50591 L F
.337 .5059 m .33124 .51149 L .33702 .50591 L F
.33687 .5058 m .33124 .51149 L .33705 .50585 L F
.33387 .50441 m .33678 .50355 L .33669 .50575 L .847 .589 .548 r
F
.33669 .50575 m .33678 .50355 L .33795 .50611 L .788 .536 .556 r
F
.34289 .49387 m .34303 .49792 L .34445 .49425 L .668 .746 .909 r
F
.33991 .49715 m .34161 .50157 L .34303 .49792 L F
.34289 .49387 m .33991 .49715 L .34303 .49792 L F
.34276 .49697 m .3429 .50103 L .34433 .49735 L .668 .747 .91 r
F
.34483 .49328 m .34289 .49387 L .34445 .49425 L .668 .746 .909 r
F
.34498 .4929 m .34456 .49309 L .34483 .49328 L F
.34456 .49309 m .34289 .49387 L .34483 .49328 L F
.34301 .49014 m .34358 .49056 L .34348 .4923 L .909 .647 .529 r
F
.34453 .49272 m .34289 .49387 L .34498 .4929 L .668 .746 .909 r
F
.34409 .49255 m .344 .49265 L .34453 .49272 L F
.344 .49265 m .34289 .49387 L .34453 .49272 L F
.34445 .49425 m .34634 .49819 L .34611 .49439 L F
.34433 .49735 m .34623 .5013 L .346 .49749 L .668 .747 .91 r
F
.34602 .49295 m .34445 .49425 L .34611 .49439 L .668 .746 .909 r
F
.33678 .50355 m .3369 .50047 L .34159 .50162 L .788 .536 .556 r
F
.33991 .49715 m .33694 .50042 L .34161 .50157 L .668 .746 .909 r
F
.33976 .50026 m .34147 .5047 L .3429 .50103 L .668 .747 .91 r
F
.33976 .50026 m .33678 .50355 L .34147 .5047 L F
.34276 .49697 m .33976 .50026 L .3429 .50103 L F
.34252 .50011 m .33945 .50106 L .33728 .50539 L .642 .738 .919 r
F
.3435 .49911 m .34243 .49963 L .34252 .50011 L F
.34243 .49963 m .33945 .50106 L .34252 .50011 L F
.34634 .49819 m .35147 .5016 L .34961 .49794 L .668 .746 .909 r
F
.34722 .49327 m .34633 .49481 L .34742 .4963 L .643 .738 .918 r
F
.34611 .49439 m .34634 .49819 L .34961 .49794 L .668 .746 .909 r
F
.346 .49749 m .34623 .5013 L .34953 .50105 L .668 .747 .91 r
F
.346 .49749 m .34953 .50105 L .34765 .49736 L F
.34591 .49598 m .34433 .49735 L .346 .49749 L F
.34492 .49585 m .34433 .49735 L .34591 .49598 L F
.34602 .49292 m .34597 .49296 L .34602 .49295 L .668 .746 .909 r
F
.34597 .49296 m .34445 .49425 L .34602 .49295 L F
.34502 .49279 m .34445 .49425 L .34602 .49292 L F
.34498 .49108 m .34624 .4913 L .34615 .49294 L .749 .499 .553 r
F
.34498 .49108 m .34615 .49294 L .34534 .49283 L F
.34493 .49277 m .34597 .49599 L .34483 .49584 L F
.34498 .49108 m .34534 .49283 L .34493 .49277 L F
.34534 .49283 m .34597 .49599 L .34493 .49277 L F
.34365 .49303 m .34153 .49326 L .34289 .49387 L .668 .746 .909 r
F
.34398 .49267 m .34348 .49279 L .34365 .49303 L F
.34348 .49279 m .34153 .49326 L .34365 .49303 L F
.3425 .48953 m .34285 .49002 L .34275 .49178 L .981 .727 .472 r
F
.34396 .49266 m .34153 .49326 L .34398 .49267 L .668 .746 .909 r
F
.34278 .49249 m .34153 .49326 L .34396 .49266 L F
.34394 .49264 m .34396 .49266 L .344 .49265 L F
.34278 .49249 m .34396 .49266 L .34394 .49264 L F
.34301 .49014 m .34293 .49191 L .34285 .49002 L .909 .647 .529 r
F
.34498 .49108 m .34493 .49277 L .34463 .49101 L .749 .499 .553 r
F
.34493 .49277 m .34458 .49273 L .34463 .49101 L F
.34463 .49101 m .34458 .49273 L .34453 .49272 L F
.34301 .49014 m .34348 .4923 L .34293 .49191 L .909 .647 .529 r
F
.34358 .49056 m .34351 .49232 L .34348 .4923 L .834 .575 .548 r
F
.34409 .49255 m .34278 .49249 L .344 .49265 L .668 .746 .909 r
F
.34381 .49066 m .34374 .49241 L .34358 .49056 L .834 .575 .548 r
F
.34374 .49241 m .34351 .49232 L .34358 .49056 L F
.34323 .49221 m .34278 .49249 L .34409 .49255 L .668 .746 .909 r
F
.344 .49265 m .34396 .49266 L .34398 .49267 L F
.34153 .49326 m .33991 .49715 L .34289 .49387 L F
.34139 .49635 m .33976 .50026 L .34263 .49711 L .668 .747 .91 r
F
.34259 .49689 m .34263 .49711 L .34276 .49697 L F
.34139 .49635 m .34263 .49711 L .34259 .49689 L F
.34353 .47373 m .34226 .48868 L .3426 .488 L 0 0 .29 r
F
.32982 .49043 m .3151 .48699 L .31658 .4918 L .643 .738 .918 r
F
.34692 .48866 m .33909 .48825 L .32982 .49043 L F
.33909 .48825 m .3151 .48699 L .32982 .49043 L F
.34568 .47269 m .34459 .473 L .34376 .48716 L .57 .346 .536 r
F
.34386 .49875 m .34327 .49886 L .3435 .49911 L .642 .738 .919 r
F
.34327 .49886 m .34095 .4993 L .34346 .49912 L F
.34327 .49886 m .34346 .49912 L .3435 .49911 L F
.34256 .49263 m .34047 .49247 L .34153 .49326 L .668 .746 .909 r
F
.34381 .49066 m .34463 .49101 L .34453 .49272 L .834 .575 .548 r
F
.34293 .49191 m .34348 .4923 L .3433 .49536 L .909 .647 .529 r
F
.34471 .49638 m .34276 .49697 L .34433 .49735 L .668 .747 .91 r
F
.34444 .49618 m .34276 .49697 L .34471 .49638 L F
.34435 .49577 m .34276 .49697 L .34487 .49598 L F
.34398 .49563 m .3439 .49571 L .34435 .49577 L F
.3439 .49571 m .34276 .49697 L .34435 .49577 L F
.34435 .49577 m .34443 .4987 L .34418 .49866 L .749 .499 .553 r
F
.34453 .49272 m .34448 .49579 L .34435 .49577 L F
.34448 .49579 m .34443 .4987 L .34435 .49577 L F
.34374 .49866 m .34095 .4993 L .34386 .49875 L .642 .738 .919 r
F
.34293 .49191 m .3433 .49536 L .34278 .49498 L .909 .647 .529 r
F
.34389 .49247 m .34453 .49272 L .34435 .49577 L .834 .575 .548 r
F
.34389 .49247 m .34435 .49577 L .34404 .49565 L F
.34248 .49624 m .34139 .49635 L .34259 .49689 L .668 .747 .91 r
F
.34297 .49538 m .34239 .49574 L .34351 .49614 L F
.34239 .49574 m .34139 .49635 L .34248 .49624 L F
.34239 .49574 m .34248 .49624 L .34351 .49614 L F
.34241 .49179 m .34047 .49247 L .34256 .49263 L .668 .746 .909 r
F
.34241 .49179 m .33977 .49154 L .34047 .49247 L F
.34381 .49066 m .34453 .49272 L .34389 .49247 L .834 .575 .548 r
F
.3425 .48953 m .34241 .4913 L .3424 .4894 L .981 .727 .472 r
F
.34178 .49123 m .34155 .49171 L .34241 .49179 L .668 .746 .909 r
F
.34239 .49574 m .34097 .49561 L .34139 .49635 L .668 .747 .91 r
F
.34153 .49326 m .33719 .49594 L .33991 .49715 L .668 .746 .909 r
F
.34233 .49543 m .34032 .49556 L .34239 .49574 L .668 .747 .91 r
F
.34291 .49531 m .34232 .49536 L .34297 .49538 L F
.34232 .49536 m .34032 .49556 L .34233 .49543 L F
.34232 .49536 m .34233 .49543 L .34297 .49538 L F
.34217 .49491 m .34113 .49528 L .34291 .49531 L F
.34113 .49528 m .34103 .49549 L .34291 .49531 L F
.34374 .49241 m .34404 .49565 L .34361 .49548 L .834 .575 .548 r
F
.34381 .49066 m .34389 .49247 L .34374 .49241 L F
.34389 .49247 m .34404 .49565 L .34374 .49241 L F
.34221 .49067 m .33949 .49055 L .33954 .49075 L .668 .746 .909 r
F
.34219 .49056 m .33949 .49055 L .34221 .49067 L F
.34241 .4913 m .34233 .4912 L .3424 .4894 L .981 .727 .472 r
F
.34229 .48884 m .34219 .49059 L .34226 .48868 L .923 .74 .252 r
F
.34229 .49114 m .33954 .49075 L .34105 .49134 L .668 .746 .909 r
F
.34221 .49067 m .33954 .49075 L .34229 .49114 L F
.34219 .49059 m .34218 .49049 L .34226 .48868 L .923 .74 .252 r
F
.34217 .49047 m .34217 .49044 L .34226 .48868 L F
.34209 .49056 m .33964 .48957 L .33949 .49055 L .668 .746 .909 r
F
.34202 .49368 m .34201 .49362 L .34217 .49047 L .923 .74 .252 r
F
.34218 .49049 m .34217 .49047 L .34226 .48868 L F
.34202 .49368 m .34217 .49047 L .34218 .49049 L F
.34229 .49115 m .34178 .49123 L .34241 .49179 L .668 .746 .909 r
F
.34219 .49059 m .34207 .49399 L .34202 .49368 L .923 .74 .252 r
F
.34229 .48884 m .34221 .4907 L .34219 .49059 L F
.34221 .4907 m .34207 .49399 L .34219 .49059 L F
.34216 .49041 m .33964 .48957 L .34209 .49056 L .668 .746 .909 r
F
.34226 .48868 m .34217 .49044 L .34216 .49041 L .923 .74 .252 r
F
.34459 .473 m .3427 .4878 L .34353 .4873 L .385 .194 .495 r
F
.34353 .47373 m .3426 .488 L .3427 .4878 L 0 0 .29 r
F
.34692 .48866 m .34181 .48761 L .33909 .48825 L .643 .738 .918 r
F
.34229 .48884 m .3424 .4894 L .34229 .49115 L .923 .74 .252 r
F
.34229 .48884 m .34229 .49115 L .34223 .49078 L F
.34221 .4907 m .34211 .4942 L .34207 .49399 L F
.34229 .48884 m .34223 .49078 L .34221 .4907 L F
.34223 .49078 m .34211 .4942 L .34221 .4907 L F
.34208 .48996 m .34022 .48864 L .33964 .48957 L .668 .746 .909 r
F
.3426 .488 m .34226 .48868 L .34216 .49041 L 0 0 .29 r
F
.34235 .49 m .34198 .48924 L .34208 .48996 L .668 .746 .909 r
F
.34293 .49191 m .34277 .49179 L .34285 .49002 L .909 .647 .529 r
F
.3425 .48953 m .34275 .49178 L .34241 .4913 L .981 .727 .472 r
F
.34293 .49191 m .34278 .49498 L .34277 .49179 L .909 .647 .529 r
F
.34351 .49614 m .34248 .49624 L .34276 .49697 L .668 .747 .91 r
F
.34278 .49498 m .34265 .49785 L .34271 .49493 L .909 .647 .529 r
F
.34278 .49498 m .34271 .49493 L .34277 .49179 L F
.34217 .49491 m .34291 .49531 L .34281 .49516 L .668 .747 .91 r
F
.34248 .49624 m .34259 .49689 L .34276 .49697 L F
.34265 .49785 m .34251 .49775 L .34264 .49488 L .909 .647 .529 r
F
.34271 .49493 m .34264 .49488 L .34277 .49179 L F
.34265 .49785 m .34264 .49488 L .34271 .49493 L F
.34257 .49483 m .34217 .49491 L .34281 .49516 L .668 .747 .91 r
F
.34254 .49479 m .34252 .49479 L .34257 .49483 L F
.34252 .49479 m .34217 .49491 L .34257 .49483 L F
.34374 .49241 m .34361 .49548 L .34351 .49232 L .834 .575 .548 r
F
.34398 .49563 m .34297 .49538 L .34351 .49614 L .668 .747 .91 r
F
.34312 .49529 m .34297 .49538 L .34398 .49563 L F
.34304 .49817 m .34095 .4993 L .34402 .49859 L .642 .738 .919 r
F
.34095 .4993 m .34009 .49977 L .3435 .49911 L F
.33268 .50172 m .3369 .50047 L .33678 .50355 L .847 .589 .548 r
F
.33387 .50441 m .33268 .50172 L .33678 .50355 L F
.33263 .50382 m .33262 .50382 L .33317 .50407 L .642 .738 .919 r
F
.33262 .50382 m .32443 .50827 L .33304 .50414 L F
.33262 .50382 m .33304 .50414 L .33317 .50407 L F
.3326 .50381 m .33268 .50172 L .33387 .50441 L .847 .589 .548 r
F
.33719 .49594 m .33694 .50042 L .33991 .49715 L .668 .746 .909 r
F
.33703 .49904 m .33678 .50355 L .33976 .50026 L .668 .747 .91 r
F
.33268 .50172 m .3328 .49865 L .3369 .50047 L .847 .589 .548 r
F
.33719 .49594 m .33287 .49861 L .33694 .50042 L .668 .746 .909 r
F
.33703 .49904 m .33268 .50172 L .33678 .50355 L .668 .747 .91 r
F
.33945 .50106 m .32443 .50827 L .33728 .50539 L .642 .738 .919 r
F
.33046 .50219 m .33268 .50172 L .3326 .50381 L .912 .65 .527 r
F
.34361 .49548 m .3434 .4954 L .34351 .49232 L .834 .575 .548 r
F
.34257 .49483 m .34251 .49775 L .3424 .49766 L .909 .647 .529 r
F
.34275 .49178 m .34262 .49487 L .34257 .49483 L F
.34297 .49538 m .34233 .49543 L .34239 .49574 L .668 .747 .91 r
F
.34262 .49487 m .34251 .49775 L .34257 .49483 L .909 .647 .529 r
F
.34269 .49492 m .34281 .49516 L .34312 .49529 L .668 .747 .91 r
F
.34254 .49479 m .34257 .49483 L .34269 .49492 L F
.34257 .49483 m .34281 .49516 L .34269 .49492 L F
.34323 .49221 m .34242 .49189 L .34256 .49263 L .668 .746 .909 r
F
.34277 .49179 m .34264 .49488 L .34275 .49178 L .909 .647 .529 r
F
.34264 .49488 m .34251 .49775 L .34262 .49487 L F
.34264 .49488 m .34262 .49487 L .34275 .49178 L F
.34221 .49434 m .34216 .49426 L .34231 .49117 L .981 .727 .472 r
F
.34233 .4912 m .34231 .49117 L .3424 .4894 L F
.34221 .49434 m .34231 .49117 L .34233 .4912 L F
.34285 .49002 m .34277 .49179 L .34275 .49178 L .909 .647 .529 r
F
.34252 .49479 m .34139 .49473 L .34113 .49528 L .668 .747 .91 r
F
.34181 .49428 m .34158 .49432 L .34252 .49479 L F
.34158 .49432 m .33962 .49463 L .34139 .49473 L F
.34158 .49432 m .34139 .49473 L .34252 .49479 L F
.3424 .4894 m .34216 .49426 L .34211 .4942 L .981 .727 .472 r
F
.34241 .4913 m .34225 .49439 L .34233 .4912 L F
.34225 .49439 m .34221 .49434 L .34233 .4912 L F
.34241 .4913 m .3424 .4946 L .34225 .49439 L F
.34256 .49478 m .34257 .49477 L .34257 .49483 L F
.34241 .4913 m .34257 .49477 L .34256 .49478 L F
.34269 .49169 m .34229 .49115 L .34241 .49179 L .668 .746 .909 r
F
.34241 .4913 m .34275 .49178 L .34257 .49477 L .981 .727 .472 r
F
.34241 .4913 m .34257 .49483 L .3424 .4946 L F
.34534 .49283 m .34615 .49294 L .34597 .49599 L .749 .499 .553 r
F
.34502 .49279 m .34453 .49272 L .34498 .4929 L .668 .746 .909 r
F
.34493 .49277 m .34483 .49584 L .34458 .49273 L .749 .499 .553 r
F
.34483 .49584 m .34451 .49579 L .34458 .49273 L F
.34458 .49273 m .34451 .49579 L .34453 .49272 L F
.34451 .49579 m .34443 .4987 L .34448 .49579 L F
.34451 .49579 m .34448 .49579 L .34453 .49272 L F
.34577 .49366 m .34398 .49563 L .34435 .49577 L .668 .747 .91 r
F
.34492 .49585 m .34435 .49577 L .34487 .49598 L F
.34577 .49366 m .34435 .49577 L .34492 .49585 L F
.3433 .49536 m .34329 .49828 L .34313 .49821 L .834 .575 .548 r
F
.34348 .4923 m .34338 .49539 L .3433 .49536 L F
.34338 .49539 m .34329 .49828 L .3433 .49536 L F
.34588 .49057 m .34229 .49114 L .34229 .49115 L .668 .746 .909 r
F
.34588 .49057 m .34229 .49115 L .34269 .49169 L F
.34588 .49057 m .34262 .48946 L .34235 .49 L F
.34588 .49057 m .34235 .49 L .34216 .49041 L F
.3227 .48369 m .3186 .47796 L .31578 .48227 L .643 .738 .918 r
F
.34678 .4726 m .34568 .47269 L .34485 .4869 L .663 .424 .548 r
F
.34692 .48866 m .34247 .48698 L .33925 .48709 L .643 .738 .918 r
F
.34219 .49059 m .34202 .49368 L .34218 .49049 L .923 .74 .252 r
F
.34229 .49114 m .34229 .49114 L .34229 .49115 L .668 .746 .909 r
F
.34223 .49078 m .34229 .49115 L .34211 .4942 L .923 .74 .252 r
F
.34351 .49232 m .34329 .49828 L .34348 .4923 L .834 .575 .548 r
F
.34185 .49375 m .34078 .49364 L .34057 .49378 L .668 .747 .91 r
F
.34577 .49366 m .3419 .49365 L .34185 .49375 L F
.3419 .49365 m .34078 .49364 L .34185 .49375 L F
.34047 .49247 m .33719 .49594 L .34153 .49326 L .668 .746 .909 r
F
.34577 .49366 m .34057 .49378 L .34094 .49442 L .668 .747 .91 r
F
.34057 .49378 m .33939 .49381 L .34011 .4941 L F
.34057 .49378 m .34011 .4941 L .34094 .49442 L F
.34577 .49366 m .34214 .49423 L .34254 .49479 L F
.34577 .49366 m .34318 .49456 L .34317 .49472 L F
.34318 .49456 m .34254 .49479 L .34317 .49472 L F
.34317 .49472 m .34254 .49479 L .34269 .49492 L F
.34577 .49366 m .34269 .49492 L .34317 .49526 L F
.34588 .49057 m .34242 .49189 L .34323 .49221 L .668 .746 .909 r
F
.34588 .49057 m .34323 .49221 L .34409 .49255 L F
.34047 .49247 m .33506 .49436 L .33719 .49594 L F
.33977 .49154 m .33506 .49436 L .34047 .49247 L F
.34078 .49364 m .3395 .49264 L .33934 .49364 L .668 .747 .91 r
F
.34201 .49362 m .34199 .49353 L .34217 .49044 L .923 .74 .252 r
F
.34201 .49362 m .34217 .49044 L .34217 .49047 L F
.34588 .49057 m .34216 .49041 L .34219 .49056 L .668 .746 .909 r
F
.34588 .49057 m .34221 .49067 L .34229 .49114 L F
.34588 .49057 m .34219 .49056 L .34221 .49067 L F
.34229 .49114 m .34178 .49123 L .34229 .49115 L F
.34216 .49041 m .34199 .49353 L .34198 .49346 L .923 .74 .252 r
F
.34217 .49044 m .34199 .49353 L .34216 .49041 L F
.34238 .48994 m .34216 .49041 L .34198 .49346 L 0 0 .29 r
F
.34249 .4897 m .34198 .49346 L .34229 .4928 L F
.3426 .488 m .34238 .48994 L .34249 .4897 L F
.34238 .48994 m .34198 .49346 L .34249 .4897 L F
.34588 .49057 m .34241 .49179 L .34242 .49189 L .668 .746 .909 r
F
.34233 .49272 m .34238 .49261 L .34259 .4895 L 0 0 .29 r
F
.34257 .48954 m .34259 .4895 L .3427 .4878 L F
.34233 .49272 m .34259 .4895 L .34257 .48954 L F
.3427 .4878 m .3424 .49257 L .34242 .49252 L F
.3426 .488 m .34249 .4897 L .3427 .4878 L F
.34249 .4897 m .34256 .48957 L .3427 .4878 L F
.34229 .4928 m .34233 .49272 L .3427 .4878 L F
.3426 .488 m .34216 .49041 L .34238 .48994 L F
.34568 .47269 m .34376 .48716 L .34461 .48696 L .57 .346 .536 r
F
.34459 .473 m .34353 .4873 L .34376 .48716 L .385 .194 .495 r
F
.34247 .48698 m .32338 .47437 L .3186 .47796 L .643 .738 .918 r
F
.34692 .48866 m .34406 .48693 L .34247 .48698 L F
.34406 .48693 m .32338 .47437 L .34247 .48698 L F
.34588 .49057 m .34393 .48867 L .34324 .48904 L .668 .746 .909 r
F
.34393 .48867 m .34367 .48874 L .34324 .48904 L F
.34678 .4726 m .34485 .4869 L .34571 .48687 L .663 .424 .548 r
F
.34568 .47269 m .34461 .48696 L .34485 .4869 L .57 .346 .536 r
F
.34692 .48866 m .32981 .47174 L .32338 .47437 L .643 .738 .918 r
F
.34461 .48696 m .34376 .48716 L .34367 .48874 L .57 .346 .536 r
F
.34353 .4873 m .3426 .48947 L .34341 .48892 L .385 .194 .495 r
F
.34262 .48946 m .3429 .48884 L .34261 .48946 L .668 .746 .909 r
F
.34588 .49057 m .34324 .48904 L .34262 .48946 L F
.34324 .48904 m .3429 .48884 L .34262 .48946 L F
.34327 .49195 m .34339 .49187 L .34364 .48877 L .385 .194 .495 r
F
.3436 .48879 m .34364 .48877 L .34376 .48716 L F
.34327 .49195 m .34364 .48877 L .3436 .48879 L F
.34577 .49366 m .34172 .493 L .34078 .49364 L .668 .747 .91 r
F
.34361 .49548 m .34349 .49836 L .3434 .4954 L .834 .575 .548 r
F
.34349 .49836 m .34329 .49828 L .3434 .4954 L F
.34254 .49479 m .34181 .49428 L .34252 .49479 L .668 .747 .91 r
F
.3424 .4946 m .3424 .49766 L .34225 .49439 L .981 .727 .472 r
F
.34225 .49439 m .3424 .49766 L .3421 .49726 L F
.34361 .49548 m .34418 .49866 L .34349 .49836 L .834 .575 .548 r
F
.34404 .49565 m .34418 .49866 L .34361 .49548 L F
.3424 .4946 m .34257 .49483 L .3424 .49766 L .981 .727 .472 r
F
.34317 .49526 m .34269 .49492 L .34312 .49529 L .668 .747 .91 r
F
.34281 .49516 m .34291 .49531 L .34312 .49529 L F
.34312 .49529 m .34291 .49531 L .34297 .49538 L F
.34278 .49498 m .3433 .49536 L .34313 .49821 L .909 .647 .529 r
F
.34278 .49498 m .34313 .49821 L .34265 .49785 L F
.34404 .49565 m .34435 .49577 L .34418 .49866 L .834 .575 .548 r
F
.34591 .49598 m .34591 .496 L .34597 .49599 L .668 .747 .91 r
F
.34486 .49948 m .34414 .50004 L .34445 .50047 L .642 .738 .919 r
F
.34504 .49902 m .34466 .49934 L .34486 .49948 L F
.34466 .49934 m .33728 .50539 L .34486 .49948 L F
.34513 .49882 m .34494 .49898 L .34504 .49902 L F
.34494 .49898 m .33728 .50539 L .34504 .49902 L F
.34399 .49862 m .33728 .50539 L .34513 .49882 L F
.34136 .50777 m .34243 .50722 L .34635 .50818 L .73 .486 .558 r
F
.34243 .50722 m .34636 .50771 L .34635 .50818 L F
.34483 .49584 m .34597 .49599 L .3458 .49894 L .749 .499 .553 r
F
.34623 .5013 m .35139 .50472 L .34953 .50105 L .668 .747 .91 r
F
.34624 .49902 m .34445 .50047 L .34652 .5033 L .642 .738 .919 r
F
.3458 .49894 m .34445 .50047 L .34624 .49902 L F
.34513 .49882 m .34506 .499 L .3458 .49894 L F
.34506 .499 m .34445 .50047 L .3458 .49894 L F
.34697 .49603 m .346 .49749 L .34765 .49736 L .668 .747 .91 r
F
.34689 .49587 m .34676 .49612 L .34697 .49603 L F
.34676 .49612 m .346 .49749 L .34697 .49603 L F
.34644 .50205 m .34681 .5077 L .34783 .49991 L .642 .738 .919 r
F
.34681 .5077 m .34727 .51474 L .34754 .50769 L F
.34705 .5077 m .35139 .50472 L .3513 .5076 L .669 .434 .556 r
F
.34681 .5077 m .34754 .50769 L .34783 .49991 L .642 .738 .919 r
F
.34814 .50767 m .34727 .51474 L .34843 .51472 L F
.34783 .49991 m .34754 .50769 L .34814 .50767 L F
.34754 .50769 m .34727 .51474 L .34814 .50767 L F
.35178 .50751 m .34843 .51472 L .35544 .51456 L F
.35157 .50755 m .35139 .50472 L .35595 .5036 L .595 .373 .549 r
F
.3513 .5076 m .35139 .50472 L .35157 .50755 L F
.34882 .50806 m .34843 .51472 L .35178 .50751 L .642 .738 .919 r
F
.35468 .50697 m .35595 .5036 L .35585 .50668 L .595 .373 .549 r
F
.35178 .50751 m .35544 .51456 L .35613 .50867 L .642 .738 .919 r
F
.35468 .50697 m .35613 .50867 L .35637 .50665 L F
.35178 .50751 m .35613 .50867 L .35468 .50697 L F
.35129 .5078 m .35157 .50755 L .35468 .50697 L .595 .373 .549 r
F
.35157 .50755 m .35595 .5036 L .35468 .50697 L F
.35371 .50583 m .35468 .50697 L .35585 .50668 L .667 .747 .91 r
F
.35139 .50472 m .3515 .50165 L .35605 .50053 L .595 .373 .549 r
F
.35139 .50472 m .35605 .50053 L .35595 .5036 L F
.34953 .50105 m .35139 .50472 L .35595 .5036 L .668 .747 .91 r
F
.34961 .49794 m .35147 .5016 L .356 .50048 L .668 .746 .909 r
F
.34953 .50105 m .35595 .5036 L .35257 .5003 L .668 .747 .91 r
F
.35177 .50356 m .35585 .50668 L .35247 .50338 L .667 .747 .91 r
F
.34972 .50116 m .35178 .50751 L .35468 .50697 L .642 .738 .919 r
F
.34765 .49736 m .34953 .50105 L .35257 .5003 L .668 .747 .91 r
F
.34924 .50092 m .35178 .50751 L .34972 .50116 L .642 .738 .919 r
F
.34775 .49426 m .34961 .49794 L .35264 .49719 L .668 .746 .909 r
F
.3536 .49527 m .35997 .50596 L .3637 .50526 L .643 .738 .918 r
F
.34927 .49389 m .35264 .49719 L .35521 .49599 L .668 .746 .909 r
F
.34775 .49426 m .35264 .49719 L .34927 .49389 L F
.34927 .49389 m .35521 .49599 L .35055 .49329 L F
.35264 .49719 m .356 .50048 L .35985 .49869 L F
.34961 .49794 m .356 .50048 L .35264 .49719 L F
.34947 .49685 m .35516 .4991 L .35047 .49638 L .668 .747 .91 r
F
.34918 .49699 m .34945 .49708 L .34947 .49685 L F
.34945 .49708 m .35516 .4991 L .34947 .49685 L F
.34872 .49294 m .34927 .49389 L .34965 .49371 L .668 .746 .909 r
F
.34958 .49023 m .34987 .48978 L .34979 .49117 L 0 0 .355 r
F
.34904 .49241 m .34965 .49371 L .3497 .49279 L .668 .746 .909 r
F
.34897 .49253 m .34965 .49371 L .34904 .49241 L F
.34835 .49263 m .34872 .49294 L .34875 .49232 L F
.34784 .49118 m .34778 .49272 L .34775 .49273 L .516 .302 .527 r
F
.34692 .48866 m .34583 .49133 L .34709 .49123 L .643 .738 .918 r
F
.34837 .49265 m .34856 .4932 L .34872 .49294 L .668 .746 .909 r
F
.34821 .49115 m .34821 .49128 L .34826 .49124 L .643 .738 .918 r
F
.34806 .4911 m .34883 .49083 L .34875 .49232 L .516 .302 .527 r
F
.34823 .49253 m .34804 .49269 L .34837 .49265 L .668 .746 .909 r
F
.34798 .49263 m .34804 .49269 L .34823 .49253 L F
.34804 .49269 m .34856 .4932 L .34837 .49265 L F
.34823 .49253 m .34835 .49263 L .34875 .49232 L F
.34856 .4932 m .34927 .49389 L .34872 .49294 L F
.34872 .49294 m .34965 .49371 L .34897 .49253 L F
.34611 .49439 m .34961 .49794 L .34775 .49426 L F
.34918 .49699 m .35257 .5003 L .35516 .4991 L .668 .747 .91 r
F
.34773 .49734 m .35257 .5003 L .34918 .49699 L F
.34765 .49736 m .3477 .49739 L .34773 .49734 L F
.3477 .49739 m .35257 .5003 L .34773 .49734 L F
.34904 .49076 m .34912 .49094 L .34916 .49088 L .643 .738 .918 r
F
.34898 .49073 m .3495 .49036 L .34942 .4918 L .335 .155 .483 r
F
.34904 .49241 m .3497 .49279 L .34942 .49179 L .668 .746 .909 r
F
.34904 .49241 m .34942 .49179 L .34942 .4918 L F
.34898 .49073 m .34942 .4918 L .34891 .49219 L .335 .155 .483 r
F
.34826 .49124 m .34824 .4923 L .34855 .49182 L .643 .738 .918 r
F
.34784 .49154 m .34821 .49128 L .34821 .49115 L F
.34806 .4911 m .34875 .49232 L .348 .49263 L .516 .302 .527 r
F
.34883 .49083 m .34877 .49231 L .34875 .49232 L .335 .155 .483 r
F
.34898 .49073 m .34891 .49219 L .34883 .49083 L F
.34891 .49219 m .34877 .49231 L .34883 .49083 L F
.34784 .49118 m .34784 .49154 L .34821 .49115 L .643 .738 .918 r
F
.34709 .49123 m .3471 .49143 L .34784 .49118 L F
.3484 .49843 m .34907 .50007 L .3485 .49839 L .667 .747 .91 r
F
.34769 .49872 m .34784 .49887 L .3484 .49843 L F
.34784 .49887 m .34907 .50007 L .3484 .49843 L F
.34875 .49232 m .34872 .49294 L .34883 .49229 L .668 .746 .909 r
F
.34872 .49294 m .34897 .49253 L .34883 .49229 L F
.34806 .4911 m .348 .49263 L .34784 .49118 L .516 .302 .527 r
F
.34798 .49263 m .34775 .49426 L .34927 .49389 L .668 .746 .909 r
F
.34711 .49299 m .34775 .49426 L .34797 .4927 L F
.34775 .49273 m .34797 .4927 L .34798 .49263 L F
.34711 .49299 m .34797 .4927 L .34775 .49273 L F
.34709 .49123 m .34699 .49143 L .3471 .49145 L .643 .738 .918 r
F
.3466 .49127 m .34784 .49118 L .34775 .49273 L .644 .409 .547 r
F
.34715 .49209 m .34672 .4929 L .34722 .49327 L .643 .738 .918 r
F
.3471 .49145 m .34685 .49197 L .34715 .49209 L F
.3466 .49127 m .34775 .49273 L .34655 .49289 L .644 .409 .547 r
F
.3466 .49127 m .34655 .49289 L .34624 .4913 L F
.34655 .49289 m .3462 .49293 L .34624 .4913 L F
.34624 .4913 m .3462 .49293 L .34615 .49294 L F
.34588 .49057 m .34611 .49439 L .34775 .49426 L .668 .746 .909 r
F
.34655 .49289 m .34775 .49273 L .34757 .49578 L .644 .409 .547 r
F
.34757 .49578 m .34765 .49736 L .3479 .49574 L .668 .747 .91 r
F
.34689 .49587 m .34697 .49603 L .34757 .49578 L F
.34697 .49603 m .34765 .49736 L .34757 .49578 L F
.348 .49263 m .34787 .49566 L .34778 .49272 L .516 .302 .527 r
F
.34787 .49566 m .34767 .49574 L .34778 .49272 L F
.34655 .49289 m .34757 .49578 L .34697 .49586 L .644 .409 .547 r
F
.34953 .49583 m .34947 .49685 L .35047 .49638 L .668 .747 .91 r
F
.34655 .49289 m .34697 .49586 L .34645 .49593 L .644 .409 .547 r
F
.34891 .49219 m .34877 .49522 L .34877 .49231 L .335 .155 .483 r
F
.34877 .49522 m .3487 .49527 L .34877 .49231 L F
.34973 .4922 m .35055 .49329 L .34975 .4919 L .668 .746 .909 r
F
.348 .49263 m .34778 .49272 L .34784 .49118 L .516 .302 .527 r
F
.34958 .49023 m .34951 .49164 L .3495 .49036 L 0 0 .355 r
F
.34951 .49164 m .34945 .49174 L .3495 .49036 L F
.34942 .49179 m .34975 .4919 L .34977 .49121 L .668 .746 .909 r
F
.34975 .4919 m .35152 .4925 L .34979 .49122 L F
.34975 .4919 m .34979 .49122 L .34977 .49121 L F
.35072 .47481 m .34936 .48815 L .34979 .48887 L .992 .745 .442 r
F
.35068 .47556 m .35072 .47481 L .34991 .48908 L 0 0 0 r
F
.35072 .47481 m .34979 .48887 L .34991 .48908 L .992 .745 .442 r
F
.35309 .48899 m .37789 .49502 L .37875 .49034 L .643 .738 .918 r
F
.34692 .48866 m .36076 .4915 L .35309 .48899 L F
.36076 .4915 m .37789 .49502 L .35309 .48899 L F
.34945 .49174 m .34944 .49176 L .3495 .49036 L 0 0 .355 r
F
.34887 .49546 m .34953 .49583 L .34924 .49485 L .668 .747 .91 r
F
.34953 .49583 m .35047 .49638 L .34956 .49525 L F
.34953 .49583 m .34956 .49525 L .34924 .49485 L F
.35015 .49059 m .35211 .49158 L .35227 .49059 L .668 .746 .909 r
F
.34944 .49176 m .34943 .49178 L .3495 .49036 L 0 0 .355 r
F
.34988 .48963 m .34984 .49043 L .34981 .4909 L 0 0 0 r
F
.34987 .48978 m .3498 .49115 L .34979 .49117 L F
.3498 .49113 m .3498 .49115 L .34987 .48978 L F
.3498 .49111 m .3498 .49113 L .34987 .48978 L F
.34958 .49023 m .34956 .49157 L .34951 .49164 L 0 0 .355 r
F
.34958 .49023 m .34979 .49117 L .34956 .49157 L F
.3495 .49036 m .34943 .49178 L .34942 .4918 L F
.34988 .48963 m .3498 .49099 L .34987 .48978 L 0 0 0 r
F
.3498 .49099 m .3498 .49111 L .34987 .48978 L F
.34692 .48866 m .34816 .49107 L .34904 .49076 L .643 .738 .918 r
F
.34692 .48866 m .34709 .49123 L .34821 .49115 L F
.34588 .49057 m .34977 .49121 L .34979 .49117 L .668 .746 .909 r
F
.34982 .49076 m .34979 .49117 L .35004 .49077 L F
.34588 .49057 m .34979 .49117 L .34982 .49076 L F
.34977 .49121 m .35211 .49158 L .35015 .49059 L F
.34924 .49485 m .34956 .49525 L .34925 .49484 L .668 .747 .91 r
F
.34956 .49525 m .35047 .49638 L .34956 .49524 L F
.34956 .49525 m .34956 .49524 L .34925 .49484 L F
.34962 .49428 m .35145 .49559 L .35203 .49467 L F
.34932 .49472 m .34928 .49479 L .34943 .49178 L 0 0 .355 r
F
.34932 .49472 m .34943 .49178 L .34944 .49176 L F
.34935 .49466 m .34932 .49472 L .34944 .49176 L F
.34935 .49466 m .34944 .49176 L .34945 .49174 L F
.3487 .49527 m .34864 .49532 L .34877 .49231 L .335 .155 .483 r
F
.34942 .4918 m .34927 .4948 L .34924 .49485 L 0 0 .355 r
F
.34881 .49228 m .34904 .49241 L .34942 .4918 L .668 .746 .909 r
F
.34883 .49229 m .34897 .49253 L .34904 .49241 L F
.34891 .49219 m .34942 .4918 L .34924 .49485 L .335 .155 .483 r
F
.34864 .49532 m .34887 .49546 L .34924 .49485 L .668 .747 .91 r
F
.3491 .49559 m .34918 .49699 L .34947 .49685 L F
.3491 .49559 m .34947 .49685 L .34953 .49583 L F
.34853 .49541 m .34815 .49571 L .3491 .49559 L F
.34815 .49571 m .34918 .49699 L .3491 .49559 L F
.3479 .49574 m .34799 .49583 L .34815 .49571 L F
.34799 .49583 m .34918 .49699 L .34815 .49571 L F
.34877 .49231 m .34864 .49532 L .34875 .49232 L .335 .155 .483 r
F
.34867 .49534 m .34853 .49541 L .3491 .49559 L .668 .747 .91 r
F
.3484 .49623 m .34773 .49734 L .34918 .49699 L F
.34591 .496 m .346 .49749 L .34689 .49587 L F
.34645 .49593 m .3474 .49882 L .34635 .4989 L .644 .409 .547 r
F
.34697 .49586 m .3474 .49882 L .34645 .49593 L F
.34799 .49583 m .34765 .49736 L .34773 .49734 L .668 .747 .91 r
F
.34799 .49583 m .34773 .49734 L .3484 .49623 L F
.34787 .49592 m .34765 .49736 L .34799 .49583 L F
.34655 .49289 m .34635 .4989 L .3462 .49293 L .644 .409 .547 r
F
.34623 .49891 m .3458 .49894 L .34624 .49902 L .642 .738 .919 r
F
.34635 .4989 m .34605 .49892 L .3462 .49293 L .644 .409 .547 r
F
.34784 .49567 m .34757 .49578 L .3479 .49574 L .668 .747 .91 r
F
.34941 .49802 m .35036 .49947 L .35134 .49868 L .667 .747 .91 r
F
.34787 .49566 m .34774 .4987 L .34767 .49574 L .516 .302 .527 r
F
.34774 .4987 m .34774 .4987 L .34767 .49574 L F
.34774 .4987 m .34755 .49877 L .34767 .49574 L F
.34774 .4987 m .34765 .49874 L .34774 .4987 L F
.34765 .49874 m .34755 .49877 L .34774 .4987 L F
.34873 .5 m .35178 .50751 L .34901 .50033 L .642 .738 .919 r
F
.34784 .49887 m .34783 .49894 L .34907 .50007 L .667 .747 .91 r
F
.34756 .49907 m .35178 .50751 L .34873 .5 L .642 .738 .919 r
F
.34729 .49886 m .34744 .49916 L .34756 .49907 L F
.34744 .49916 m .35178 .50751 L .34756 .49907 L F
.34907 .49791 m .3485 .49839 L .34941 .49802 L .667 .747 .91 r
F
.34862 .49534 m .34849 .49836 L .34858 .49537 L .335 .155 .483 r
F
.34849 .49836 m .34849 .49836 L .34858 .49537 L F
.34847 .49837 m .3484 .49843 L .3485 .49839 L .667 .747 .91 r
F
.34848 .49842 m .34845 .49845 L .34845 .49839 L .335 .155 .483 r
F
.34849 .49836 m .34845 .49839 L .34858 .49537 L F
.34848 .49842 m .34845 .49839 L .34849 .49836 L F
.34972 .4974 m .35134 .49868 L .35193 .49776 L .667 .747 .91 r
F
.34858 .49537 m .34845 .49839 L .3484 .49843 L .335 .155 .483 r
F
.34655 .49745 m .34625 .49922 L .34729 .49886 L .642 .738 .919 r
F
.34787 .49566 m .3484 .49843 L .34774 .4987 L .516 .302 .527 r
F
.34853 .49541 m .3479 .49574 L .34815 .49571 L .668 .747 .91 r
F
.34784 .49567 m .3479 .49574 L .34867 .49534 L F
.3479 .49574 m .34787 .49592 L .34799 .49583 L F
.3482 .49553 m .3484 .49843 L .34787 .49566 L .516 .302 .527 r
F
.34864 .49532 m .3485 .49835 L .34862 .49534 L .335 .155 .483 r
F
.3485 .49835 m .34849 .49836 L .34862 .49534 L F
.3482 .49553 m .34858 .49537 L .3484 .49843 L .516 .302 .527 r
F
.34847 .49837 m .3485 .49839 L .34907 .49791 L .667 .747 .91 r
F
.34877 .49522 m .34924 .49485 L .34906 .49801 L .335 .155 .483 r
F
.34756 .49907 m .34873 .5 L .34779 .49891 L .642 .738 .919 r
F
.34856 .4998 m .34854 .5002 L .34884 .50013 L .667 .747 .91 r
F
.34783 .49894 m .34854 .5002 L .34856 .4998 L F
.34783 .49991 m .34843 .51472 L .34915 .50244 L .642 .738 .919 r
F
.34783 .49894 m .34754 .50045 L .34854 .5002 L .667 .747 .91 r
F
.34783 .49894 m .34884 .50013 L .34907 .50007 L F
.34765 .49874 m .34873 .5 L .34815 .49857 L .642 .738 .919 r
F
.3485 .49839 m .35036 .49947 L .34941 .49802 L .667 .747 .91 r
F
.3487 .49851 m .34907 .50007 L .35036 .49947 L F
.3486 .49868 m .34907 .50007 L .3487 .49851 L F
.34836 .49909 m .34873 .5 L .34847 .49893 L .642 .738 .919 r
F
.34873 .5 m .34901 .50033 L .34847 .49893 L F
.34884 .50013 m .35247 .50338 L .34907 .50007 L .667 .747 .91 r
F
.34924 .50092 m .34972 .50116 L .34925 .50061 L .642 .738 .919 r
F
.34754 .50045 m .35074 .50235 L .34884 .50013 L .667 .747 .91 r
F
.35074 .50235 m .35247 .50338 L .34884 .50013 L F
.34754 .50045 m .34845 .50222 L .3485 .50115 L F
.34915 .50244 m .34882 .50806 L .35178 .50751 L .642 .738 .919 r
F
.34845 .50222 m .34942 .50413 L .3485 .50115 L .667 .747 .91 r
F
.3485 .50115 m .34942 .50413 L .35177 .50356 L F
.34754 .50045 m .35177 .50356 L .35074 .50235 L F
.34907 .50007 m .34927 .50027 L .34928 .50021 L F
.34907 .50007 m .35223 .50118 L .35036 .49947 L F
.35595 .5036 m .35605 .50053 L .35992 .49873 L .496 .292 .533 r
F
.35595 .5036 m .35992 .49873 L .35983 .5018 L F
.35257 .5003 m .35595 .5036 L .35983 .5018 L .668 .747 .91 r
F
.35223 .50118 m .35506 .50218 L .35166 .50021 L .667 .747 .91 r
F
.35223 .50118 m .35166 .50021 L .35036 .49947 L F
.348 .49263 m .3482 .49553 L .34787 .49566 L .516 .302 .527 r
F
.34864 .49532 m .34862 .49534 L .34875 .49232 L .335 .155 .483 r
F
.34875 .49232 m .34862 .49534 L .34858 .49537 L F
.348 .49263 m .34875 .49232 L .34858 .49537 L .516 .302 .527 r
F
.348 .49263 m .34858 .49537 L .3482 .49553 L F
.34891 .49219 m .34924 .49485 L .34877 .49522 L .335 .155 .483 r
F
.34951 .49164 m .34935 .49466 L .34945 .49174 L 0 0 .355 r
F
.34959 .49427 m .34925 .49484 L .34962 .49428 L .668 .747 .91 r
F
.34951 .49164 m .34948 .49447 L .34935 .49466 L 0 0 .355 r
F
.34925 .49484 m .34958 .49496 L .3496 .49457 L .668 .747 .91 r
F
.34925 .49484 m .3496 .49457 L .34962 .49428 L F
.35055 .49329 m .35521 .49599 L .35715 .49442 L .668 .746 .909 r
F
.34996 .49367 m .35203 .49467 L .3522 .49368 L .668 .747 .91 r
F
.34956 .49157 m .3495 .49443 L .34951 .49164 L 0 0 .355 r
F
.3495 .49443 m .34948 .49446 L .34951 .49164 L F
.34944 .49729 m .34944 .49729 L .34948 .49447 L F
.34948 .49446 m .34948 .49447 L .34951 .49164 L F
.34944 .49729 m .34948 .49447 L .34948 .49446 L F
.35055 .49329 m .35715 .49442 L .35152 .4925 L .668 .746 .909 r
F
.35041 .49292 m .3522 .49368 L .35192 .49268 L .668 .747 .91 r
F
.34988 .48963 m .34981 .4909 L .3498 .49099 L 0 0 0 r
F
.34588 .49057 m .35004 .49077 L .34993 .49059 L .668 .746 .909 r
F
.34588 .49057 m .34942 .49179 L .34977 .49121 L F
.34979 .48887 m .3497 .4902 L .34991 .48908 L .992 .745 .442 r
F
.3497 .4902 m .34979 .49035 L .34991 .48908 L F
.34588 .49057 m .34993 .49059 L .34957 .48999 L .668 .746 .909 r
F
.34981 .4909 m .34965 .49373 L .3498 .49099 L 0 0 0 r
F
.3497 .49279 m .34965 .49371 L .35055 .49329 L .668 .746 .909 r
F
.34965 .49373 m .34965 .49377 L .3498 .49099 L 0 0 0 r
F
.3498 .49099 m .34965 .49377 L .34963 .49401 L F
.3497 .49279 m .35055 .49329 L .34973 .4922 L .668 .746 .909 r
F
.34981 .4909 m .34966 .49349 L .34965 .49373 L 0 0 0 r
F
.34986 .49383 m .35203 .49467 L .34996 .49367 L .668 .747 .91 r
F
.34959 .49427 m .35018 .49437 L .34986 .49383 L F
.35018 .49437 m .35203 .49467 L .34986 .49383 L F
.35264 .49719 m .35985 .49869 L .35521 .49599 L .668 .746 .909 r
F
.35047 .49638 m .35516 .4991 L .35711 .49752 L .668 .747 .91 r
F
.34977 .49676 m .35193 .49776 L .35209 .49677 L .667 .747 .91 r
F
.34946 .49649 m .34949 .49654 L .34945 .49728 L 0 0 .355 r
F
.34946 .49649 m .34945 .49728 L .34944 .49729 L F
.34941 .49735 m .35193 .49776 L .34977 .49676 L .667 .747 .91 r
F
.34945 .49728 m .34945 .49732 L .34944 .49743 L 0 0 0 r
F
.34962 .49423 m .34945 .49717 L .34945 .49728 L F
.34948 .49676 m .34945 .49728 L .34977 .49676 L .667 .747 .91 r
F
.34945 .49717 m .34945 .49732 L .34945 .49728 L 0 0 0 r
F
.34935 .49466 m .34944 .49743 L .34919 .49781 L 0 0 .355 r
F
.34877 .49522 m .34906 .49801 L .34863 .49832 L .335 .155 .483 r
F
.34605 .49892 m .346 .49893 L .34615 .49294 L .644 .409 .547 r
F
.3461 .49692 m .3458 .49894 L .34623 .49891 L .642 .738 .919 r
F
.34925 .49484 m .34925 .49484 L .34959 .49427 L .668 .747 .91 r
F
.34925 .49484 m .34956 .49524 L .34958 .49496 L F
.34948 .49447 m .34944 .49743 L .34935 .49466 L 0 0 .355 r
F
.3492 .49769 m .34913 .49781 L .34928 .49479 L F
.3492 .49769 m .34928 .49479 L .34932 .49472 L F
.34863 .49825 m .3485 .49835 L .34864 .49532 L .335 .155 .483 r
F
.34863 .49825 m .34864 .49532 L .3487 .49527 L F
.34924 .49485 m .34912 .49792 L .34906 .49801 L 0 0 .355 r
F
.34927 .4948 m .34912 .49792 L .34924 .49485 L F
.34877 .49522 m .34863 .49825 L .3487 .49527 L .335 .155 .483 r
F
.34697 .49586 m .34757 .49578 L .3474 .49882 L .644 .409 .547 r
F
.34935 .49466 m .3492 .49769 L .34932 .49472 L 0 0 .355 r
F
.34942 .4918 m .34942 .49179 L .34942 .49179 L .668 .746 .909 r
F
.34943 .49178 m .34928 .49479 L .34942 .4918 L 0 0 .355 r
F
.34928 .49479 m .34912 .49792 L .34927 .4948 L F
.34928 .49479 m .34927 .4948 L .34942 .4918 L F
.3495 .49443 m .34949 .49654 L .34946 .49649 L F
.34956 .49157 m .34952 .4944 L .3495 .49443 L F
.34952 .4944 m .34949 .49654 L .3495 .49443 L F
.34979 .49121 m .35152 .4925 L .35211 .49158 L .668 .746 .909 r
F
.35152 .4925 m .35715 .49442 L .35833 .49259 L F
.35152 .4925 m .35833 .49259 L .35211 .49158 L F
.35109 .4918 m .35192 .49268 L .35123 .49175 L .668 .747 .91 r
F
.34977 .49121 m .34979 .49122 L .34979 .49121 L .668 .746 .909 r
F
.3497 .49279 m .34973 .4922 L .34942 .49179 L F
.34942 .49179 m .34973 .4922 L .34975 .4919 L F
.34956 .49157 m .34979 .49117 L .34949 .49654 L 0 0 .355 r
F
.34979 .49117 m .34962 .49417 L .34962 .49423 L 0 0 0 r
F
.34981 .4909 m .34984 .49043 L .34966 .49349 L F
.3498 .49115 m .34963 .49416 L .34979 .49117 L F
.34956 .49524 m .35047 .49638 L .34958 .49496 L .668 .747 .91 r
F
.34963 .49416 m .34945 .49732 L .34962 .49417 L 0 0 0 r
F
.34963 .49416 m .34962 .49417 L .34979 .49117 L F
.34979 .49122 m .35152 .4925 L .34979 .49121 L .668 .746 .909 r
F
.34975 .4919 m .35055 .49329 L .35152 .4925 L F
.34974 .49227 m .35041 .49292 L .35109 .4918 L .668 .747 .91 r
F
.34963 .49408 m .3498 .49115 L .3498 .49113 L 0 0 0 r
F
.34963 .49409 m .3498 .49115 L .34963 .49408 L F
.34963 .49409 m .34963 .49416 L .3498 .49115 L F
.34963 .49401 m .34963 .49408 L .3498 .49113 L F
.34963 .49401 m .3498 .49113 L .3498 .49111 L F
.3498 .49099 m .34963 .49401 L .3498 .49111 L F
.34984 .49043 m .34962 .49342 L .34966 .49349 L .992 .745 .442 r
F
.34775 .49273 m .34767 .49574 L .34757 .49578 L .516 .302 .527 r
F
.34778 .49272 m .34767 .49574 L .34775 .49273 L F
.3462 .49293 m .34605 .49892 L .34615 .49294 L .644 .409 .547 r
F
.34615 .49294 m .34608 .49597 L .34597 .49599 L F
.34577 .49366 m .34965 .49367 L .34942 .49308 L .668 .747 .91 r
F
.34577 .49366 m .34959 .49427 L .34986 .49383 L F
.34977 .49367 m .34986 .49383 L .34996 .49367 L F
.34577 .49366 m .34986 .49383 L .34977 .49367 L F
.34982 .49041 m .34962 .4934 L .34984 .49043 L .992 .745 .442 r
F
.34962 .4934 m .34941 .4964 L .34962 .49342 L F
.34962 .4934 m .34962 .49342 L .34984 .49043 L F
.3495 .49443 m .34944 .49729 L .34948 .49446 L 0 0 .355 r
F
.34577 .49366 m .34925 .49484 L .34959 .49427 L .668 .747 .91 r
F
.3493 .49622 m .34941 .4964 L .34962 .4934 L .992 .745 .442 r
F
.34577 .49366 m .34942 .49308 L .34911 .49255 L .668 .747 .91 r
F
.34577 .49366 m .34911 .49255 L .34906 .49251 L F
.34757 .49578 m .34747 .4988 L .3474 .49882 L .516 .302 .527 r
F
.34729 .49886 m .34756 .49907 L .34765 .49874 L .642 .738 .919 r
F
.34756 .49907 m .34779 .49891 L .34765 .49874 L F
.34729 .49886 m .34644 .50205 L .34783 .49991 L F
.34625 .49922 m .34644 .50205 L .34729 .49886 L F
.34684 .49907 m .34754 .50045 L .34768 .4988 L .667 .747 .91 r
F
.3474 .49884 m .34768 .4988 L .34769 .49872 L F
.34684 .49907 m .34768 .4988 L .3474 .49884 L F
.34727 .49883 m .34729 .49886 L .3474 .49882 L .642 .738 .919 r
F
.34635 .4989 m .3474 .49882 L .3474 .49884 L .644 .409 .547 r
F
.34635 .50818 m .34705 .5077 L .35129 .5078 L .669 .434 .556 r
F
.34689 .50781 m .34689 .5077 L .34705 .5077 L F
.34635 .50818 m .34689 .5077 L .34689 .50781 L F
.34635 .50818 m .34636 .50771 L .34689 .5077 L F
.35223 .50118 m .3533 .503 L .35506 .50218 L .667 .747 .91 r
F
.34907 .50007 m .3533 .503 L .35223 .50118 L F
.35585 .50668 m .35595 .5036 L .35983 .5018 L .496 .292 .533 r
F
.35585 .50668 m .35983 .5018 L .35973 .50488 L F
.35247 .50338 m .35585 .50668 L .35973 .50488 L .667 .747 .91 r
F
.35973 .50488 m .35983 .5018 L .36276 .49945 L .339 .168 .497 r
F
.35973 .50488 m .36276 .49945 L .36266 .50253 L F
.35506 .50218 m .35973 .50488 L .36266 .50253 L .667 .747 .91 r
F
.35247 .50338 m .35973 .50488 L .35506 .50218 L F
.35983 .5018 m .35992 .49873 L .36285 .49637 L .339 .168 .497 r
F
.35983 .5018 m .36285 .49637 L .36276 .49945 L F
.35516 .4991 m .35983 .5018 L .36276 .49945 L .668 .747 .91 r
F
.35257 .5003 m .35983 .5018 L .35516 .4991 L F
.35506 .50218 m .36266 .50253 L .35701 .50061 L .667 .747 .91 r
F
.35036 .49947 m .35506 .50218 L .35701 .50061 L F
.35036 .49947 m .35701 .50061 L .35134 .49868 L F
.34898 .49828 m .36298 .51316 L .36941 .51063 L .642 .738 .919 r
F
.34767 .49574 m .34755 .49877 L .34757 .49578 L .516 .302 .527 r
F
.34755 .49877 m .34749 .49879 L .34757 .49578 L F
.34705 .5077 m .3513 .5076 L .35129 .5078 L .669 .434 .556 r
F
.34612 .50438 m .34635 .50818 L .35129 .5078 L .667 .747 .91 r
F
.34612 .50438 m .35129 .5078 L .34942 .50413 L F
.34589 .50057 m .34612 .50438 L .34942 .50413 L F
.34589 .50057 m .34942 .50413 L .34754 .50045 L F
.34684 .49907 m .34589 .50057 L .34754 .50045 L F
.34635 .4989 m .3474 .49884 L .34635 .49897 L .644 .409 .547 r
F
.34597 .49599 m .346 .49893 L .3458 .49894 L F
.34604 .49684 m .3458 .49894 L .3461 .49692 L .642 .738 .919 r
F
.34483 .49584 m .3458 .49894 L .34474 .49875 L .749 .499 .553 r
F
.34608 .49597 m .346 .49893 L .34597 .49599 L .644 .409 .547 r
F
.34604 .49684 m .34513 .49882 L .3458 .49894 L .642 .738 .919 r
F
.34597 .49677 m .34513 .49882 L .34604 .49684 L F
.3461 .49692 m .34625 .49922 L .34655 .49745 L F
.34635 .4989 m .34635 .49897 L .34605 .49892 L .644 .409 .547 r
F
.34677 .49892 m .34582 .49948 L .34684 .49907 L .667 .747 .91 r
F
.3458 .49904 m .34582 .49948 L .34677 .49892 L F
.34582 .49948 m .34589 .50057 L .34684 .49907 L F
.33795 .50611 m .34147 .5047 L .34139 .50708 L .788 .536 .556 r
F
.34317 .50359 m .3374 .50595 L .3417 .50717 L .642 .738 .919 r
F
.34279 .50411 m .34635 .50818 L .34612 .50438 L .667 .747 .91 r
F
.34536 .50662 m .34539 .50704 L .34633 .50655 L .641 .739 .92 r
F
.34136 .50777 m .34162 .50711 L .34243 .50722 L .73 .486 .558 r
F
.34136 .50777 m .34139 .50708 L .34162 .50711 L F
.34279 .50411 m .34136 .50777 L .34635 .50818 L .667 .747 .91 r
F
.34539 .50704 m .34643 .52259 L .34633 .50672 L .641 .739 .92 r
F
.34539 .50704 m .34633 .50672 L .34633 .50655 L F
.34907 .49791 m .35134 .49868 L .34972 .4974 L .667 .747 .91 r
F
.34925 .49772 m .34898 .49828 L .3499 .49796 L .642 .738 .919 r
F
.34941 .49735 m .34907 .49791 L .34972 .4974 L .667 .747 .91 r
F
.34907 .49791 m .34907 .49791 L .34941 .49735 L F
.3492 .49769 m .34919 .49781 L .34913 .49781 L 0 0 .355 r
F
.34919 .49781 m .34912 .49792 L .34913 .49781 L F
.34749 .49879 m .34747 .4988 L .34757 .49578 L .516 .302 .527 r
F
.34595 .49675 m .34661 .49685 L .34644 .49675 L .667 .747 .91 r
F
.34661 .49685 m .34945 .49728 L .34644 .49675 L F
.34644 .49675 m .34945 .49728 L .34948 .49676 L F
.34599 .49679 m .34945 .49728 L .34595 .49675 L F
.34599 .49679 m .34941 .49735 L .34945 .49728 L F
.346 .4968 m .34941 .49735 L .34599 .49679 L F
.346 .4968 m .34907 .49791 L .34941 .49735 L F
.34958 .49496 m .35047 .49638 L .35145 .49559 L .668 .747 .91 r
F
.35047 .49638 m .35711 .49752 L .35145 .49559 L F
.34972 .4961 m .35209 .49677 L .35182 .49577 L .667 .747 .91 r
F
.34965 .49367 m .34966 .49349 L .34942 .49308 L .668 .747 .91 r
F
.3493 .49622 m .34962 .4934 L .34955 .4933 L .992 .745 .442 r
F
.34962 .49417 m .34945 .49732 L .34962 .49423 L 0 0 0 r
F
.34958 .49496 m .35145 .49559 L .34962 .49428 L .668 .747 .91 r
F
.34965 .49373 m .34949 .49656 L .34965 .49377 L 0 0 0 r
F
.34948 .49676 m .35076 .49676 L .34952 .49614 L .667 .747 .91 r
F
.34949 .49656 m .34948 .49673 L .34949 .49656 L 0 0 0 r
F
.34949 .49656 m .34949 .49656 L .34965 .49377 L F
.34952 .49614 m .35076 .49676 L .34972 .4961 L .667 .747 .91 r
F
.34946 .49703 m .34948 .49673 L .34945 .49719 L 0 0 0 r
F
.34963 .49401 m .34949 .49658 L .34946 .49703 L F
.34949 .49658 m .34948 .49673 L .34946 .49703 L F
.34577 .49366 m .34864 .49532 L .34925 .49484 L .668 .747 .91 r
F
.34911 .49255 m .34886 .49555 L .34894 .4956 L .892 .63 .535 r
F
.34588 .49057 m .34881 .49228 L .34942 .49179 L .668 .746 .909 r
F
.35017 .47384 m .3491 .48797 L .34936 .48815 L .892 .63 .535 r
F
.34969 .48787 m .37745 .48551 L .37405 .48088 L .643 .738 .918 r
F
.34692 .48866 m .35086 .48826 L .34969 .48787 L F
.35086 .48826 m .37745 .48551 L .34969 .48787 L F
.34902 .47307 m .3479 .47272 L .34708 .48701 L .802 .546 .551 r
F
.34692 .48866 m .37875 .49034 L .37745 .48551 L .643 .738 .918 r
F
.34588 .49057 m .34847 .48898 L .34813 .48876 L .668 .746 .909 r
F
.34588 .49057 m .34813 .48876 L .34765 .48862 L F
.34902 .47307 m .34795 .4873 L .34821 .48739 L .802 .546 .551 r
F
.35017 .47384 m .34821 .48739 L .3491 .48797 L .892 .63 .535 r
F
.34692 .48866 m .36876 .47675 L .36195 .47343 L .643 .738 .918 r
F
.34692 .48866 m .37405 .48088 L .36876 .47675 L F
.3491 .48797 m .34821 .48739 L .34813 .48876 L .892 .63 .535 r
F
.34588 .49057 m .34917 .48942 L .34874 .48914 L .668 .746 .909 r
F
.3491 .48797 m .34813 .48876 L .34875 .48915 L .892 .63 .535 r
F
.34847 .48898 m .349 .48901 L .3486 .48889 L .668 .746 .909 r
F
.34588 .49057 m .34874 .48914 L .34847 .48898 L F
.34874 .48914 m .349 .48901 L .34847 .48898 L F
.34588 .49057 m .34823 .49253 L .34883 .49229 L F
.34936 .48815 m .34925 .48947 L .34928 .48949 L .892 .63 .535 r
F
.34979 .48887 m .34936 .48815 L .34928 .48949 L .992 .745 .442 r
F
.34588 .49057 m .34957 .48999 L .34928 .48949 L .668 .746 .909 r
F
.349 .48931 m .34925 .48947 L .34936 .48815 L .892 .63 .535 r
F
.34917 .48942 m .34928 .48949 L .34923 .4894 L .668 .746 .909 r
F
.34588 .49057 m .34928 .48949 L .34917 .48942 L F
.3491 .48797 m .349 .48931 L .34936 .48815 L .892 .63 .535 r
F
.34877 .49233 m .34901 .49248 L .34925 .48947 L F
.34881 .49228 m .34942 .4918 L .34942 .49179 L .668 .746 .909 r
F
.34964 .49009 m .34928 .48949 L .34911 .49255 L .992 .745 .442 r
F
.34929 .49285 m .34911 .49255 L .34894 .4956 L F
.34929 .49285 m .34894 .4956 L .34895 .49562 L F
.34588 .49057 m .34711 .49299 L .34798 .49263 L .668 .746 .909 r
F
.34588 .49057 m .34798 .49263 L .34823 .49253 L F
.34577 .49366 m .34906 .49251 L .34835 .49207 L .668 .747 .91 r
F
.34577 .49366 m .34784 .49567 L .34867 .49534 L F
.34877 .49233 m .34854 .49535 L .34901 .49248 L .892 .63 .535 r
F
.34577 .49366 m .34689 .49587 L .34757 .49578 L .668 .747 .91 r
F
.34577 .49366 m .34757 .49578 L .34784 .49567 L F
.34585 .49663 m .34894 .4956 L .34824 .49516 L .667 .747 .91 r
F
.34487 .49598 m .34444 .49618 L .34471 .49638 L .668 .747 .91 r
F
.34445 .50047 m .3428 .5016 L .34317 .50359 L .642 .738 .919 r
F
.34414 .50004 m .33728 .50539 L .34445 .50047 L F
.32946 .49935 m .3328 .49865 L .33268 .50172 L .912 .65 .527 r
F
.32946 .49935 m .32959 .49627 L .3328 .49865 L F
.33506 .49436 m .33287 .49861 L .33719 .49594 L .668 .746 .909 r
F
.33506 .49436 m .32967 .49624 L .33287 .49861 L F
.33046 .50219 m .32946 .49935 L .33268 .50172 L .912 .65 .527 r
F
.32938 .50137 m .32946 .49935 L .33046 .50219 L F
.33489 .49745 m .33268 .50172 L .33703 .49904 L .668 .747 .91 r
F
.33489 .49745 m .32946 .49935 L .33268 .50172 L F
.33036 .50264 m .31907 .50423 L .32292 .50713 L .642 .738 .919 r
F
.33395 .50047 m .32954 .50158 L .33036 .50264 L F
.32954 .50158 m .31907 .50423 L .33036 .50264 L F
.3293 .50131 m .31551 .49965 L .31907 .50423 L F
.32798 .49956 m .32946 .49935 L .32938 .50137 L .977 .72 .474 r
F
.32735 .49658 m .32959 .49627 L .32946 .49935 L F
.34139 .49635 m .33703 .49904 L .33976 .50026 L .668 .747 .91 r
F
.32933 .5013 m .32621 .49897 L .3293 .50131 L .642 .738 .919 r
F
.32798 .49956 m .32735 .49658 L .32946 .49935 L .977 .72 .474 r
F
.32726 .49862 m .32735 .49658 L .32798 .49956 L F
.33348 .4956 m .32946 .49935 L .33489 .49745 L .668 .747 .91 r
F
.32735 .49658 m .32747 .4935 L .32959 .49627 L .977 .72 .474 r
F
.33366 .49251 m .32967 .49624 L .33506 .49436 L .668 .746 .909 r
F
.33366 .49251 m .32757 .49348 L .32967 .49624 L F
.33348 .4956 m .32735 .49658 L .32946 .49935 L .668 .747 .91 r
F
.34032 .49556 m .33703 .49904 L .34139 .49635 L F
.34032 .49556 m .33489 .49745 L .33703 .49904 L F
.34073 .49805 m .32747 .49889 L .32933 .5013 L .642 .738 .919 r
F
.32735 .4989 m .32621 .49897 L .32771 .50009 L F
.32667 .49665 m .32735 .49658 L .32726 .49862 L .965 .751 .309 r
F
.33722 .49743 m .31551 .49965 L .34073 .49805 L .642 .738 .919 r
F
.34483 .49584 m .34474 .49875 L .34451 .49579 L .749 .499 .553 r
F
.34474 .49875 m .3445 .49871 L .34451 .49579 L F
.32648 .4936 m .32747 .4935 L .32735 .49658 L .965 .751 .309 r
F
.33962 .49463 m .33489 .49745 L .34032 .49556 L .668 .747 .91 r
F
.33962 .49463 m .33348 .4956 L .33489 .49745 L F
.32667 .49665 m .32648 .4936 L .32735 .49658 L .965 .751 .309 r
F
.32654 .49624 m .32631 .49621 L .32721 .49845 L .642 .738 .919 r
F
.32631 .49621 m .31401 .49484 L .32602 .49813 L F
.32631 .49621 m .32602 .49813 L .32721 .49845 L F
.32639 .49573 m .32648 .4936 L .32667 .49665 L .965 .751 .309 r
F
.32671 .49368 m .32648 .4936 L .32639 .49573 L 0 0 .076 r
F
.3445 .49871 m .34443 .4987 L .34451 .49579 L .749 .499 .553 r
F
.34461 .48696 m .34367 .48874 L .34449 .4885 L .57 .346 .536 r
F
.34461 .48696 m .34449 .4885 L .34485 .4869 L F
.34449 .4885 m .34473 .48843 L .34485 .4869 L F
.34353 .4873 m .3427 .4878 L .3426 .48947 L .385 .194 .495 r
F
.34353 .4873 m .34341 .48892 L .34376 .48716 L F
.34341 .48892 m .34356 .48882 L .34376 .48716 L F
.34318 .49201 m .34327 .49195 L .34376 .48716 L F
.34376 .48716 m .34364 .48877 L .34367 .48874 L F
.34377 .48851 m .344 .48687 L .34248 .48725 L .668 .746 .909 r
F
.34588 .49057 m .34479 .48842 L .34377 .48851 L F
.33934 .49721 m .33773 .49611 L .33722 .49743 L .642 .738 .919 r
F
.34211 .4942 m .34202 .49714 L .34195 .49704 L .981 .727 .472 r
F
.34216 .49426 m .34202 .49714 L .34211 .4942 L F
.3421 .49726 m .34202 .49714 L .34216 .49426 L F
.34214 .49423 m .34181 .49428 L .34254 .49479 L .668 .747 .91 r
F
.3421 .49726 m .34216 .49426 L .34221 .49434 L .981 .727 .472 r
F
.34225 .49439 m .3421 .49726 L .34221 .49434 L F
.34186 .49657 m .34183 .49644 L .34199 .49353 L .923 .74 .252 r
F
.34186 .49657 m .34199 .49353 L .34201 .49362 L F
.34202 .49368 m .34186 .49657 L .34201 .49362 L F
.34198 .49346 m .34183 .49644 L .34181 .49633 L F
.34199 .49353 m .34183 .49644 L .34198 .49346 L F
.34207 .49399 m .34195 .49704 L .34202 .49368 L F
.34172 .493 m .34008 .49172 L .3395 .49264 L .668 .747 .91 r
F
.34577 .49366 m .34243 .49252 L .34172 .493 L F
.34262 .48946 m .3426 .48947 L .34235 .49 L .668 .746 .909 r
F
.34249 .4897 m .34229 .4928 L .34256 .48957 L 0 0 .29 r
F
.34243 .49252 m .34008 .49172 L .34172 .493 L .668 .747 .91 r
F
.34341 .48892 m .3426 .48947 L .34242 .49252 L .385 .194 .495 r
F
.34341 .48892 m .34242 .49252 L .34282 .49226 L F
.34178 .49123 m .33977 .49154 L .34155 .49171 L .668 .746 .909 r
F
.34243 .49252 m .34105 .49092 L .34008 .49172 L .668 .747 .91 r
F
.34577 .49366 m .34306 .49209 L .34243 .49252 L F
.34341 .48892 m .34282 .49226 L .34318 .49201 L .385 .194 .495 r
F
.3426 .48949 m .34238 .49261 L .3424 .49257 L 0 0 .29 r
F
.34259 .4895 m .34238 .49261 L .3426 .48949 L F
.34306 .49209 m .34105 .49092 L .34243 .49252 L .668 .747 .91 r
F
.34678 .4726 m .34571 .48687 L .34596 .48686 L .663 .424 .548 r
F
.3479 .47272 m .34678 .4726 L .34596 .48686 L .733 .485 .553 r
F
.3479 .47272 m .34596 .48686 L .34682 .48698 L F
.34692 .48866 m .33743 .47027 L .32981 .47174 L .643 .738 .918 r
F
.34571 .48687 m .34485 .4869 L .34477 .48842 L .663 .424 .548 r
F
.34485 .4869 m .34473 .48843 L .34477 .48842 L .57 .346 .536 r
F
.34479 .48842 m .34565 .48674 L .344 .48687 L .668 .746 .909 r
F
.34588 .49057 m .34575 .48834 L .34479 .48842 L F
.34571 .48687 m .34477 .48842 L .34534 .48837 L .663 .424 .548 r
F
.34588 .49057 m .34409 .49255 L .34453 .49272 L .668 .746 .909 r
F
.34571 .48687 m .34459 .49148 L .34537 .49141 L .663 .424 .548 r
F
.34341 .48892 m .34318 .49201 L .34356 .48882 L .385 .194 .495 r
F
.34364 .48877 m .34339 .49187 L .34367 .48874 L F
.34577 .49366 m .34349 .4918 L .34306 .49209 L .668 .747 .91 r
F
.34202 .49368 m .34195 .49704 L .34186 .49657 L .923 .74 .252 r
F
.34207 .49399 m .34211 .4942 L .34195 .49704 L F
.34579 .49655 m .34181 .49633 L .34148 .49699 L .642 .738 .919 r
F
.34229 .4928 m .34198 .49346 L .34181 .49633 L 0 0 .29 r
F
.34229 .4928 m .34181 .49633 L .3421 .49575 L F
.34575 .49651 m .34093 .49625 L .34579 .49655 L .642 .738 .919 r
F
.33291 .49362 m .32735 .49658 L .33348 .4956 L .668 .747 .91 r
F
.33291 .49362 m .32648 .4936 L .32735 .49658 L F
.34093 .49625 m .32613 .49547 L .34088 .49628 L .642 .738 .919 r
F
.34093 .49625 m .34088 .49628 L .34579 .49655 L F
.34339 .49187 m .34315 .49491 L .34342 .49184 L .385 .194 .495 r
F
.34577 .49366 m .34591 .49598 L .34689 .49587 L .668 .747 .91 r
F
.34581 .49658 m .34824 .49516 L .34778 .49487 L .667 .747 .91 r
F
.34581 .49658 m .34778 .49487 L .34745 .49478 L F
.34585 .49663 m .34824 .49516 L .34581 .49658 L F
.34306 .49816 m .34273 .49791 L .34304 .49817 L .642 .738 .919 r
F
.34234 .49759 m .34264 .498 L .34304 .49817 L F
.34304 .49817 m .33395 .50047 L .32443 .50827 L F
.34195 .4977 m .31907 .50423 L .34304 .49817 L F
.34009 .49977 m .33945 .50106 L .3435 .49911 L F
.34306 .49816 m .34304 .49817 L .34313 .49821 L F
.34317 .50359 m .33728 .50539 L .3374 .50595 L F
.3428 .5016 m .33728 .50539 L .34317 .50359 L F
.33795 .50611 m .34139 .50708 L .34136 .50777 L .788 .536 .556 r
F
.33965 .50334 m .34136 .50777 L .34279 .50411 L .667 .747 .91 r
F
.34265 .50005 m .34279 .50411 L .34422 .50044 L F
.34265 .50005 m .33965 .50334 L .34279 .50411 L F
.34459 .49948 m .34265 .50005 L .34422 .50044 L F
.34476 .49906 m .34374 .49886 L .34459 .49948 L F
.34481 .49891 m .34432 .49889 L .34476 .49906 L F
.34432 .49889 m .34374 .49886 L .34476 .49906 L F
.34402 .49859 m .34374 .49866 L .34386 .49875 L .642 .738 .919 r
F
.34349 .49836 m .34418 .49866 L .34417 .49883 L .834 .575 .548 r
F
.34381 .49878 m .34374 .49886 L .34481 .49891 L .667 .747 .91 r
F
.34374 .49886 m .34265 .50005 L .34459 .49948 L F
.34561 .51033 m .33816 .52154 L .34643 .52259 L .641 .739 .92 r
F
.34545 .50793 m .34477 .50919 L .34561 .51033 L F
.34477 .50919 m .33816 .52154 L .34561 .51033 L F
.34234 .49759 m .33722 .49743 L .34073 .49805 L .642 .738 .919 r
F
.34582 .49659 m .34188 .49695 L .34234 .49759 L F
.34579 .49655 m .34188 .49695 L .34582 .49659 L F
.34315 .49491 m .34318 .49489 L .34342 .49184 L .385 .194 .495 r
F
.34588 .49057 m .34453 .49272 L .34502 .49279 L .668 .746 .909 r
F
.34577 .49366 m .34378 .49171 L .34349 .4918 L .668 .747 .91 r
F
.34339 .49187 m .34342 .49184 L .34367 .48874 L .385 .194 .495 r
F
.34449 .4885 m .34367 .48874 L .34349 .4918 L .57 .346 .536 r
F
.34449 .4885 m .34349 .4918 L .3439 .49168 L F
.34571 .48687 m .3456 .48835 L .34596 .48686 L .663 .424 .548 r
F
.3456 .48835 m .34577 .48833 L .34596 .48686 L F
.34588 .49057 m .34672 .4884 L .34575 .48834 L .668 .746 .909 r
F
.34692 .48866 m .34572 .47007 L .33743 .47027 L .643 .738 .918 r
F
.34902 .47307 m .34708 .48701 L .34795 .4873 L .802 .546 .551 r
F
.3479 .47272 m .34682 .48698 L .34708 .48701 L .733 .485 .553 r
F
.34692 .48866 m .35409 .47115 L .34572 .47007 L .643 .738 .918 r
F
.34682 .48698 m .34587 .48833 L .34672 .4884 L .733 .485 .553 r
F
.34672 .4884 m .34587 .48833 L .34575 .48834 L .668 .746 .909 r
F
.34682 .48698 m .34672 .4884 L .34708 .48701 L .733 .485 .553 r
F
.34539 .50704 m .34508 .50766 L .34545 .50793 L .641 .739 .92 r
F
.34508 .50766 m .34288 .51208 L .34545 .50793 L F
.34288 .51208 m .33816 .52154 L .34297 .51256 L F
.34288 .51208 m .34297 .51256 L .34545 .50793 L F
.3452 .50696 m .34492 .50754 L .34539 .50704 L F
.34188 .49695 m .33722 .49743 L .34234 .49759 L .642 .738 .919 r
F
.34128 .49944 m .33965 .50334 L .34265 .50005 L .667 .747 .91 r
F
.34374 .49886 m .34128 .49944 L .34265 .50005 L F
.34349 .49836 m .34417 .49883 L .34348 .49856 L .834 .575 .548 r
F
.3459 .49669 m .34306 .49816 L .34402 .49859 L .642 .738 .919 r
F
.34306 .49816 m .34313 .49821 L .34402 .49859 L F
.34312 .49841 m .34128 .49944 L .34374 .49886 L .667 .747 .91 r
F
.34304 .49836 m .34302 .49837 L .34312 .49841 L F
.34302 .49837 m .34128 .49944 L .34312 .49841 L F
.34349 .49836 m .34348 .49856 L .34329 .49828 L .834 .575 .548 r
F
.34422 .50044 m .34279 .50411 L .34612 .50438 L .667 .747 .91 r
F
.34348 .49856 m .34317 .50609 L .34329 .49848 L .834 .575 .548 r
F
.34348 .49856 m .34329 .49848 L .34329 .49828 L F
.34284 .51186 m .33816 .52154 L .34288 .51208 L .641 .739 .92 r
F
.34492 .50754 m .34508 .50766 L .34539 .50704 L F
.34536 .50662 m .34497 .54128 L .34335 .54146 L .644 .409 .547 r
F
.34422 .50044 m .34612 .50438 L .34589 .50057 L .667 .747 .91 r
F
.3458 .49904 m .34422 .50044 L .34589 .50057 L F
.34597 .49677 m .34399 .49862 L .34513 .49882 L .642 .738 .919 r
F
.3459 .49669 m .34399 .49862 L .34597 .49677 L F
.34474 .49875 m .3458 .49894 L .3458 .49904 L .749 .499 .553 r
F
.3458 .49904 m .34471 .49918 L .3458 .49904 L .667 .747 .91 r
F
.34481 .49891 m .34471 .49918 L .3458 .49904 L F
.34471 .49918 m .34422 .50044 L .3458 .49904 L F
.34438 .50645 m .34432 .50659 L .34536 .50662 L .641 .739 .92 r
F
.34536 .50662 m .34536 .50662 L .34536 .50662 L F
.34438 .50645 m .34536 .50662 L .34536 .50662 L F
.34432 .50659 m .34262 .51072 L .3452 .50696 L F
.34262 .51072 m .33816 .52154 L .34284 .51186 L F
.34262 .51072 m .34284 .51186 L .3452 .50696 L F
.34222 .49886 m .34021 .49864 L .34128 .49944 L .667 .747 .91 r
F
.34265 .49785 m .34264 .49807 L .34251 .49775 L .909 .647 .529 r
F
.34234 .49759 m .34195 .4977 L .34264 .498 L .642 .738 .919 r
F
.34264 .49807 m .34251 .49797 L .34251 .49775 L .909 .647 .529 r
F
.34282 .49849 m .34206 .498 L .34222 .49886 L .667 .747 .91 r
F
.34304 .49836 m .34262 .4982 L .34282 .49849 L F
.34262 .4982 m .34206 .498 L .34282 .49849 L F
.3421 .49726 m .3424 .49766 L .34239 .49789 L .981 .727 .472 r
F
.34239 .49789 m .34206 .498 L .34304 .49836 L .667 .747 .91 r
F
.34206 .498 m .34021 .49864 L .34222 .49886 L F
.3421 .49726 m .34239 .49789 L .3421 .49749 L .981 .727 .472 r
F
.34206 .498 m .33951 .49772 L .34021 .49864 L .667 .747 .91 r
F
.34209 .49748 m .34195 .50535 L .3417 .50501 L .981 .727 .472 r
F
.3421 .49726 m .3421 .49749 L .34209 .49748 L F
.3421 .49749 m .34195 .50535 L .34209 .49748 L F
.34239 .49789 m .34195 .49733 L .34206 .498 L .667 .747 .91 r
F
.34584 .49662 m .34234 .49759 L .34273 .49791 L .642 .738 .919 r
F
.34607 .49652 m .34582 .49659 L .34584 .49662 L F
.34582 .49659 m .34234 .49759 L .34584 .49662 L F
.34588 .49057 m .34502 .49279 L .34602 .49292 L .668 .746 .909 r
F
.34577 .49366 m .34466 .49147 L .34459 .49148 L .668 .747 .91 r
F
.34449 .4885 m .3439 .49168 L .34426 .49157 L .57 .346 .536 r
F
.34577 .49366 m .34459 .49148 L .34378 .49171 L .668 .747 .91 r
F
.34318 .49201 m .34225 .49545 L .34295 .49503 L .385 .194 .495 r
F
.34282 .49226 m .34225 .49545 L .34318 .49201 L F
.34282 .49226 m .34242 .49252 L .34225 .49545 L F
.34172 .493 m .3395 .49264 L .34078 .49364 L .668 .747 .91 r
F
.34577 .49366 m .34492 .49585 L .34591 .49598 L F
.34564 .49638 m .34552 .49444 L .34523 .4959 L .667 .747 .91 r
F
.34577 .49366 m .34312 .49529 L .34398 .49563 L .668 .747 .91 r
F
.34577 .49366 m .34563 .49139 L .34466 .49147 L F
.3457 .49138 m .34538 .49445 L .34552 .49444 L .663 .424 .548 r
F
.34587 .48833 m .34563 .49139 L .3457 .49138 L F
.34563 .49139 m .34538 .49445 L .3457 .49138 L F
.34584 .48833 m .3456 .49139 L .34587 .48833 L F
.3456 .49139 m .34561 .49139 L .34587 .48833 L F
.34535 .49446 m .34538 .49445 L .34587 .48833 L F
.34672 .4884 m .34696 .48842 L .34708 .48701 L .733 .485 .553 r
F
.34565 .5066 m .34497 .54128 L .34536 .50662 L .644 .409 .547 r
F
.34594 .49673 m .34948 .49676 L .34949 .49655 L .667 .747 .91 r
F
.34595 .49675 m .34948 .49676 L .34594 .49673 L F
.34588 .49667 m .34894 .4956 L .34585 .49663 L F
.34813 .48876 m .34788 .49179 L .34795 .49181 L .802 .546 .551 r
F
.3481 .48875 m .34785 .49178 L .34813 .48876 L F
.34785 .49178 m .34788 .49179 L .34813 .48876 L F
.34964 .49009 m .34911 .49255 L .34929 .49285 L .992 .745 .442 r
F
.349 .48931 m .34877 .49233 L .34925 .48947 L .892 .63 .535 r
F
.349 .48931 m .34795 .49181 L .34877 .49233 L F
.34875 .48915 m .34795 .49181 L .349 .48931 L F
.34875 .48915 m .34813 .48876 L .34795 .49181 L F
.34928 .48949 m .34908 .49162 L .34917 .49156 L F
.34925 .48947 m .34908 .49162 L .34928 .48949 L F
.34955 .4933 m .34962 .4934 L .34982 .49041 L .992 .745 .442 r
F
.34955 .4933 m .34982 .49041 L .3498 .49038 L F
.3495 .49321 m .34955 .4933 L .3498 .49038 L F
.3495 .49321 m .3498 .49038 L .34979 .49035 L F
.3497 .4902 m .3495 .49321 L .34979 .49035 L F
.34577 .49366 m .3485 .49197 L .34755 .4917 L .668 .747 .91 r
F
.34692 .48866 m .36195 .47343 L .35409 .47115 L .643 .738 .918 r
F
.34795 .4873 m .34785 .48868 L .34821 .48739 L .802 .546 .551 r
F
.34566 .49675 m .34949 .49655 L .34927 .49617 L .667 .747 .91 r
F
.34956 .49539 m .35182 .49577 L .35112 .49484 L F
.34965 .49377 m .34949 .49656 L .34963 .49401 L 0 0 0 r
F
.34949 .49656 m .34948 .49673 L .34949 .49658 L F
.34949 .49656 m .34949 .49658 L .34963 .49401 L F
.34965 .49373 m .34966 .49349 L .34948 .49673 L F
.34946 .49703 m .34963 .49409 L .34963 .49408 L F
.34946 .49703 m .34946 .49717 L .34963 .49416 L F
.34946 .49703 m .34963 .49416 L .34963 .49409 L F
.34963 .49401 m .34946 .49703 L .34963 .49408 L F
.34966 .49349 m .34941 .4964 L .34949 .49655 L .992 .745 .442 r
F
.3495 .49321 m .3493 .49622 L .34955 .4933 L F
.3495 .49321 m .34892 .4958 L .34929 .49641 L F
.34979 .48887 m .34929 .49285 L .3495 .49321 L F
.34929 .49285 m .34892 .4958 L .3495 .49321 L F
.34819 .49099 m .35016 .49095 L .34879 .49034 L .668 .747 .91 r
F
.34785 .48868 m .34739 .49476 L .3481 .48875 L .802 .546 .551 r
F
.34739 .49476 m .3476 .49482 L .3481 .48875 L F
.34755 .4917 m .34846 .49144 L .34819 .49099 L .668 .747 .91 r
F
.34846 .49144 m .35016 .49095 L .34819 .49099 L F
.34894 .4956 m .34952 .49614 L .34956 .49539 L .667 .747 .91 r
F
.34877 .49233 m .34795 .49181 L .34778 .49487 L .892 .63 .535 r
F
.34566 .49675 m .34927 .49617 L .34894 .4956 L .667 .747 .91 r
F
.34607 .49652 m .34891 .49824 L .34925 .49772 L .642 .738 .919 r
F
.34854 .49535 m .34778 .49487 L .34777 .49504 L .892 .63 .535 r
F
.3471 .50803 m .34643 .52259 L .34798 .52256 L .641 .739 .92 r
F
.34866 .51101 m .34798 .52256 L .35461 .52241 L F
.3471 .50803 m .34798 .52256 L .34866 .51101 L F
.34898 .49828 m .36941 .51063 L .3499 .49796 L .642 .738 .919 r
F
.3485 .49839 m .3486 .49868 L .3487 .49851 L .667 .747 .91 r
F
.34928 .50021 m .35247 .50338 L .3533 .503 L F
.3484 .49848 m .36298 .51316 L .34898 .49828 L .642 .738 .919 r
F
.34815 .49857 m .3482 .49862 L .3484 .49848 L F
.3482 .49862 m .36298 .51316 L .3484 .49848 L F
.34815 .49857 m .34836 .49909 L .34847 .49893 L F
.35371 .50583 m .35585 .50668 L .35177 .50356 L .667 .747 .91 r
F
.34815 .49857 m .35552 .50681 L .35407 .50439 L .642 .738 .919 r
F
.34847 .49893 m .34902 .50035 L .34905 .49958 L F
.34902 .50035 m .34924 .50092 L .34905 .49958 L F
.34905 .49958 m .34924 .50092 L .3493 .49985 L F
.34919 .49781 m .3488 .50543 L .34912 .49792 L 0 0 .355 r
F
.34912 .49792 m .34875 .50551 L .34906 .49801 L F
.34882 .50833 m .35461 .52241 L .35935 .52154 L .641 .739 .92 r
F
.34777 .50701 m .34876 .50926 L .34882 .50833 L F
.34876 .50926 m .35461 .52241 L .34882 .50833 L F
.34767 .50716 m .34875 .50952 L .34777 .50701 L F
.34875 .50952 m .35461 .52241 L .34876 .50926 L F
.34875 .50952 m .34876 .50926 L .34777 .50701 L F
.34925 .50061 m .34972 .50116 L .3493 .49985 L .642 .738 .919 r
F
.34927 .50027 m .35247 .50338 L .34928 .50021 L .667 .747 .91 r
F
.35074 .50235 m .35177 .50356 L .35247 .50338 L F
.3493 .49985 m .34972 .50116 L .35552 .50681 L .642 .738 .919 r
F
.37009 .50274 m .40261 .50971 L .37493 .49925 L .643 .738 .918 r
F
.36266 .50253 m .36276 .49945 L .36454 .49669 L .042 0 .398 r
F
.35521 .49599 m .35985 .49869 L .36276 .49634 L .668 .746 .909 r
F
.35516 .4991 m .36276 .49945 L .35711 .49752 L .668 .747 .91 r
F
.36266 .50253 m .36454 .49669 L .36445 .49977 L .042 0 .398 r
F
.35701 .50061 m .36266 .50253 L .36445 .49977 L .667 .747 .91 r
F
.35701 .50061 m .36445 .49977 L .35819 .49877 L F
.35134 .49868 m .35701 .50061 L .35819 .49877 L F
.36276 .49945 m .36285 .49637 L .36463 .49361 L .042 0 .398 r
F
.36276 .49945 m .36463 .49361 L .36454 .49669 L F
.35711 .49752 m .36276 .49945 L .36454 .49669 L .668 .747 .91 r
F
.35521 .49599 m .36276 .49634 L .35715 .49442 L .668 .746 .909 r
F
.35711 .49752 m .36454 .49669 L .35829 .49568 L .668 .747 .91 r
F
.35145 .49559 m .35711 .49752 L .35829 .49568 L F
.35193 .49776 m .35819 .49877 L .35853 .49678 L .667 .747 .91 r
F
.35134 .49868 m .35819 .49877 L .35193 .49776 L F
.35193 .49776 m .35853 .49678 L .35209 .49677 L F
.34945 .49721 m .37428 .50714 L .37726 .5029 L .642 .738 .919 r
F
.34945 .49719 m .34945 .49732 L .34946 .49717 L 0 0 0 r
F
.34944 .49729 m .34945 .49728 L .34944 .49743 L 0 0 .355 r
F
.34944 .49729 m .34944 .49743 L .34944 .49729 L F
.34607 .49652 m .34942 .49778 L .34945 .49721 L .642 .738 .919 r
F
.34942 .49778 m .37428 .50714 L .34945 .49721 L F
.34946 .49703 m .34945 .49719 L .34946 .49717 L 0 0 0 r
F
.34607 .49652 m .34945 .49721 L .34947 .4967 L .642 .738 .919 r
F
.34945 .49721 m .34982 .49729 L .34948 .49673 L F
.34945 .49721 m .34948 .49673 L .34947 .4967 L F
.34902 .50479 m .34902 .5049 L .34945 .49732 L 0 0 0 r
F
.34945 .49732 m .34945 .49732 L .34946 .49717 L F
.34902 .50479 m .34945 .49732 L .34945 .49732 L F
.34945 .49719 m .34902 .50479 L .34945 .49732 L F
.34945 .49732 m .34902 .5049 L .34944 .49743 L F
.34945 .49719 m .34948 .49673 L .34905 .50441 L F
.34884 .50796 m .35935 .52154 L .35454 .51354 L .641 .739 .92 r
F
.34882 .50824 m .35935 .52154 L .34884 .50796 L F
.34777 .50701 m .35935 .52154 L .34781 .50695 L F
.34662 .5071 m .3471 .50803 L .3474 .50656 L F
.3471 .50803 m .35461 .52241 L .34767 .50716 L F
.3471 .50803 m .34767 .50716 L .3474 .50656 L F
.34919 .49781 m .34944 .49743 L .34901 .50512 L 0 0 .355 r
F
.34781 .50695 m .34882 .50824 L .34884 .50796 L .641 .739 .92 r
F
.3484 .49848 m .34808 .50608 L .34796 .50616 L .335 .155 .483 r
F
.34803 .50611 m .35454 .51354 L .35122 .50803 L .641 .739 .92 r
F
.34473 .4989 m .3458 .49904 L .34536 .50662 L .749 .499 .553 r
F
.34432 .50659 m .3452 .50696 L .34536 .50662 L .641 .739 .92 r
F
.34492 .50754 m .34284 .51186 L .34508 .50766 L F
.34284 .51186 m .34288 .51208 L .34508 .50766 L F
.34536 .50662 m .3452 .50696 L .34539 .50704 L F
.34449 .50647 m .34536 .50662 L .34335 .54146 L .749 .499 .553 r
F
.34473 .4989 m .34536 .50662 L .34449 .50647 L F
.3458 .49904 m .34565 .5066 L .34536 .50662 L .644 .409 .547 r
F
.3458 .49904 m .34565 .5066 L .3458 .49904 L F
.3474 .49882 m .34714 .50644 L .34696 .5065 L .516 .302 .527 r
F
.34635 .49897 m .3461 .50657 L .34605 .49901 L .644 .409 .547 r
F
.3461 .50657 m .34497 .54128 L .34586 .50659 L F
.3461 .50657 m .34586 .50659 L .34605 .49901 L F
.34732 .50648 m .34647 .50682 L .3474 .50656 L .641 .739 .92 r
F
.34727 .5064 m .3472 .50642 L .34747 .49881 L .516 .302 .527 r
F
.34635 .49897 m .3474 .49884 L .34696 .5065 L .644 .409 .547 r
F
.34635 .49897 m .34696 .5065 L .3461 .50657 L F
.34769 .49872 m .34766 .49901 L .34784 .49887 L .667 .747 .91 r
F
.34766 .49901 m .34754 .50045 L .34784 .49887 L F
.34774 .4987 m .34742 .50635 L .34755 .49877 L .516 .302 .527 r
F
.34696 .5065 m .34647 .50682 L .34732 .50648 L .641 .739 .92 r
F
.34633 .50655 m .3464 .50669 L .34696 .5065 L F
.3464 .50669 m .34647 .50682 L .34696 .5065 L F
.34747 .4988 m .3472 .50642 L .3474 .49882 L .516 .302 .527 r
F
.34725 .50641 m .34696 .5065 L .34732 .50648 L .641 .739 .92 r
F
.34647 .50682 m .34692 .5069 L .3474 .50656 L F
.34662 .5071 m .3466 .5088 L .3471 .50803 L F
.3466 .5088 m .34643 .52259 L .3471 .50803 L F
.3472 .50642 m .34599 .54088 L .34714 .50644 L .516 .302 .527 r
F
.3472 .50642 m .34714 .50644 L .3474 .49882 L F
.34742 .50635 m .34727 .5064 L .34755 .49877 L F
.34727 .5064 m .34747 .49881 L .34747 .49881 L F
.34727 .5064 m .34747 .4988 L .34749 .49879 L F
.34755 .49877 m .34727 .5064 L .34749 .49879 L F
.34774 .4987 m .3484 .49843 L .34796 .50616 L F
.34774 .4987 m .34796 .50616 L .34742 .50635 L F
.34605 .49892 m .34586 .50659 L .346 .49893 L .644 .409 .547 r
F
.34586 .50659 m .34497 .54128 L .34582 .50659 L F
.34586 .50659 m .34582 .50659 L .346 .49893 L F
.35129 .5078 m .3513 .5076 L .35157 .50755 L .595 .373 .549 r
F
.34942 .50413 m .35129 .5078 L .35468 .50697 L .667 .747 .91 r
F
.35637 .50665 m .35544 .51456 L .36298 .51316 L .642 .738 .919 r
F
.35015 .50627 m .36862 .5185 L .3735 .51501 L .641 .739 .92 r
F
.3484 .49848 m .34809 .50608 L .3484 .49848 L .335 .155 .483 r
F
.34809 .50608 m .34808 .50608 L .3484 .49848 L F
.34863 .49832 m .34863 .50569 L .34827 .50594 L F
.34848 .49842 m .34815 .50603 L .34845 .49845 L F
.3474 .50656 m .35454 .51354 L .34803 .50611 L .641 .739 .92 r
F
.34815 .50603 m .34666 .54036 L .34812 .50605 L .335 .155 .483 r
F
.34815 .50603 m .34812 .50605 L .34845 .49845 L F
.34863 .5057 m .34849 .50639 L .35015 .50627 L .641 .739 .92 r
F
.34803 .50611 m .34849 .50639 L .34863 .5057 L F
.34845 .49839 m .34845 .49845 L .3484 .49843 L .335 .155 .483 r
F
.3499 .49796 m .36941 .51063 L .37428 .50714 L .642 .738 .919 r
F
.34972 .50116 m .35468 .50697 L .35552 .50681 L F
.35407 .50439 m .35552 .50681 L .35637 .50665 L F
.34942 .50413 m .35468 .50697 L .35371 .50583 L .667 .747 .91 r
F
.36941 .51063 m .40218 .51763 L .37428 .50714 L .642 .738 .919 r
F
.34927 .50524 m .3735 .51501 L .37648 .51079 L .641 .739 .92 r
F
.34845 .49845 m .34812 .50605 L .3484 .49848 L .335 .155 .483 r
F
.34812 .50605 m .34809 .50608 L .3484 .49848 L F
.34919 .49781 m .34901 .50512 L .3488 .50543 L 0 0 .355 r
F
.34906 .49801 m .3487 .50559 L .34863 .50569 L F
.34875 .50551 m .3487 .50559 L .34906 .49801 L F
.3488 .50543 m .34875 .50551 L .34913 .49781 L F
.34882 .49818 m .3484 .49848 L .34898 .49828 L .642 .738 .919 r
F
.34891 .49824 m .34898 .49828 L .34925 .49772 L F
.34863 .49832 m .34906 .49801 L .34863 .50569 L .335 .155 .483 r
F
.3485 .49835 m .34817 .50602 L .34849 .49836 L F
.34817 .50602 m .34666 .54036 L .34815 .50603 L F
.34817 .50602 m .34815 .50603 L .34849 .49836 L F
.34942 .50413 m .35371 .50583 L .35177 .50356 L .667 .747 .91 r
F
.40261 .50971 m .43928 .50762 L .40867 .50134 L .643 .738 .918 r
F
.37493 .49925 m .40261 .50971 L .40867 .50134 L F
.37428 .50714 m .40218 .51763 L .40827 .50925 L .642 .738 .919 r
F
.37428 .50714 m .40827 .50925 L .37726 .5029 L F
.35008 .50467 m .37648 .51079 L .37735 .50611 L .641 .739 .92 r
F
.34945 .49719 m .34905 .50441 L .34902 .50479 L 0 0 0 r
F
.34902 .5049 m .34901 .50499 L .34944 .49743 L F
.34944 .49743 m .34901 .50499 L .34901 .50512 L F
.34863 .49825 m .34827 .50594 L .3485 .49835 L .335 .155 .483 r
F
.34827 .50594 m .34666 .54036 L .34817 .50602 L F
.34827 .50594 m .34817 .50602 L .3485 .49835 L F
.34948 .49673 m .34894 .50424 L .34905 .50441 L .992 .745 .442 r
F
.34949 .49655 m .34948 .49672 L .34948 .49673 L F
.34948 .49672 m .34894 .50424 L .34948 .49673 L F
.34927 .49617 m .34949 .49655 L .34952 .49614 L .667 .747 .91 r
F
.35076 .49676 m .35209 .49677 L .34972 .4961 L F
.34962 .49342 m .34941 .4964 L .34966 .49349 L .992 .745 .442 r
F
.37493 .49925 m .40867 .50134 L .37789 .49502 L .643 .738 .918 r
F
.35715 .49442 m .36276 .49634 L .36454 .4936 L .668 .746 .909 r
F
.36454 .49669 m .36463 .49361 L .36514 .49063 L 0 0 .116 r
F
.36454 .49669 m .36514 .49063 L .36505 .49372 L F
.36445 .49977 m .36454 .49669 L .36505 .49372 L F
.35829 .49568 m .36454 .49669 L .36505 .49372 L .668 .747 .91 r
F
.35715 .49442 m .36454 .4936 L .35833 .49259 L .668 .746 .909 r
F
.35829 .49568 m .36505 .49372 L .35862 .4937 L .668 .747 .91 r
F
.35203 .49467 m .35829 .49568 L .35862 .4937 L F
.35145 .49559 m .35829 .49568 L .35203 .49467 L F
.36445 .49977 m .36505 .49372 L .36496 .4968 L 0 0 .116 r
F
.35819 .49877 m .36445 .49977 L .36496 .4968 L .667 .747 .91 r
F
.35819 .49877 m .36496 .4968 L .35853 .49678 L F
.35833 .49259 m .36454 .4936 L .36504 .49063 L .668 .746 .909 r
F
.35833 .49259 m .36504 .49063 L .35866 .49061 L F
.35862 .4937 m .36505 .49372 L .36425 .49073 L .668 .747 .91 r
F
.36496 .4968 m .36505 .49372 L .36425 .49073 L .952 .739 .28 r
F
.36496 .4968 m .36425 .49073 L .36415 .49382 L F
.35853 .49678 m .36496 .4968 L .36415 .49382 L .667 .747 .91 r
F
.35853 .49678 m .36415 .49382 L .35798 .4948 L F
.35209 .49677 m .35853 .49678 L .35798 .4948 L F
.35209 .49677 m .35798 .4948 L .35182 .49577 L F
.34917 .49621 m .37814 .49821 L .37682 .49337 L .642 .738 .919 r
F
.34607 .49652 m .34947 .4967 L .34917 .49621 L F
.3493 .49622 m .34929 .49641 L .34941 .4964 L .992 .745 .442 r
F
.34929 .49641 m .34939 .49658 L .34941 .4964 L F
.34941 .4964 m .34887 .50413 L .34949 .49655 L F
.346 .49893 m .34582 .50659 L .3458 .49894 L .644 .409 .547 r
F
.34582 .50659 m .34497 .54128 L .34565 .5066 L F
.34582 .50659 m .34565 .5066 L .3458 .49894 L F
.34887 .50413 m .34894 .50424 L .34949 .49655 L .992 .745 .442 r
F
.34947 .4967 m .37726 .5029 L .37814 .49821 L .642 .738 .919 r
F
.34982 .49729 m .37726 .5029 L .34947 .4967 L F
.34879 .50398 m .34887 .50413 L .34941 .4964 L .992 .745 .442 r
F
.34607 .49689 m .34847 .49837 L .34907 .49791 L .667 .747 .91 r
F
.34607 .49689 m .34907 .49791 L .346 .4968 L F
.34586 .49664 m .34306 .49816 L .3459 .49669 L .642 .738 .919 r
F
.34566 .49675 m .3484 .49843 L .34847 .49837 L .667 .747 .91 r
F
.34607 .49652 m .34815 .49857 L .3484 .49848 L .642 .738 .919 r
F
.34845 .49845 m .3484 .49848 L .3484 .49843 L .335 .155 .483 r
F
.3484 .49843 m .3484 .49848 L .3484 .49848 L F
.34849 .49836 m .34848 .49842 L .34849 .49836 L F
.34607 .49652 m .3484 .49848 L .34882 .49818 L .642 .738 .919 r
F
.34624 .49708 m .34847 .49837 L .34607 .49689 L .667 .747 .91 r
F
.34607 .49652 m .34655 .49745 L .34815 .49857 L .642 .738 .919 r
F
.34655 .49745 m .34727 .49883 L .34764 .49872 L F
.34566 .49675 m .34769 .49872 L .3484 .49843 L .667 .747 .91 r
F
.34655 .49745 m .34764 .49872 L .34815 .49857 L .642 .738 .919 r
F
.34747 .49881 m .34747 .49881 L .34747 .4988 L .516 .302 .527 r
F
.34727 .49883 m .3474 .49882 L .34765 .49874 L .642 .738 .919 r
F
.34727 .49883 m .34765 .49874 L .34764 .49872 L F
.34566 .49675 m .34684 .49907 L .34765 .49874 L .667 .747 .91 r
F
.3474 .49844 m .34765 .49874 L .34769 .49872 L F
.34566 .49675 m .34765 .49874 L .3474 .49844 L F
.34774 .4987 m .34774 .4987 L .34774 .4987 L .516 .302 .527 r
F
.34764 .49872 m .34765 .49874 L .34815 .49857 L .642 .738 .919 r
F
.34854 .49535 m .34777 .49504 L .34852 .49553 L .892 .63 .535 r
F
.34877 .49233 m .34778 .49487 L .34854 .49535 L F
.34607 .49652 m .34842 .49525 L .3476 .49498 L .642 .738 .919 r
F
.34522 .50442 m .35033 .50469 L .34928 .504 L .641 .739 .92 r
F
.34522 .50442 m .34927 .50524 L .34946 .50511 L F
.34522 .50442 m .34946 .50511 L .34917 .50463 L F
.34785 .49178 m .3476 .49482 L .34788 .49179 L .802 .546 .551 r
F
.3476 .49482 m .34763 .49483 L .34788 .49179 L F
.34854 .49535 m .34876 .49549 L .34901 .49248 L .892 .63 .535 r
F
.34824 .49516 m .34894 .4956 L .34856 .49496 L .667 .747 .91 r
F
.34901 .49248 m .34876 .49549 L .34911 .49255 L .892 .63 .535 r
F
.34876 .49549 m .34886 .49555 L .34911 .49255 L F
.34856 .49496 m .35112 .49484 L .35005 .49404 L .667 .747 .91 r
F
.34894 .4956 m .35112 .49484 L .34856 .49496 L F
.34996 .49367 m .3522 .49368 L .35041 .49292 L .668 .747 .91 r
F
.35211 .49158 m .35833 .49259 L .35866 .49061 L .668 .746 .909 r
F
.35211 .49158 m .35866 .49061 L .35227 .49059 L F
.35866 .49061 m .36504 .49063 L .36425 .48766 L F
.36505 .49372 m .36514 .49063 L .36434 .48765 L .952 .739 .28 r
F
.35866 .49061 m .36425 .48766 L .35812 .48863 L .668 .746 .909 r
F
.35227 .49059 m .35866 .49061 L .35812 .48863 L F
.35203 .49467 m .35862 .4937 L .3522 .49368 L .668 .747 .91 r
F
.36505 .49372 m .36434 .48765 L .36425 .49073 L .952 .739 .28 r
F
.35862 .4937 m .36425 .49073 L .35808 .49171 L .668 .747 .91 r
F
.3522 .49368 m .35862 .4937 L .35808 .49171 L F
.3522 .49368 m .35808 .49171 L .35192 .49268 L F
.35812 .48863 m .36425 .48766 L .36219 .48487 L .668 .746 .909 r
F
.35192 .49268 m .35808 .49171 L .3567 .48984 L .668 .747 .91 r
F
.36425 .49073 m .36434 .48765 L .36227 .48485 L .98 .72 .461 r
F
.35808 .49171 m .36218 .48793 L .3567 .48984 L .668 .747 .91 r
F
.35808 .49171 m .36425 .49073 L .36218 .48793 L F
.35182 .49577 m .3566 .49294 L .35112 .49484 L .667 .747 .91 r
F
.35182 .49577 m .35798 .4948 L .3566 .49294 L F
.36425 .49073 m .36227 .48485 L .36218 .48793 L .98 .72 .461 r
F
.36415 .49382 m .36425 .49073 L .36218 .48793 L F
.35798 .4948 m .36208 .49102 L .3566 .49294 L .667 .747 .91 r
F
.35798 .4948 m .36415 .49382 L .36208 .49102 L F
.35112 .49484 m .35446 .49133 L .35005 .49404 L F
.35112 .49484 m .3566 .49294 L .35446 .49133 L F
.35227 .49059 m .35812 .48863 L .352 .4896 L .668 .746 .909 r
F
.352 .4896 m .35812 .48863 L .35674 .48678 L F
.35812 .48863 m .36219 .48487 L .35674 .48678 L F
.35674 .48678 m .36219 .48487 L .35901 .48247 L F
.3567 .48984 m .36218 .48793 L .35898 .48552 L .668 .747 .91 r
F
.36218 .48793 m .36227 .48485 L .35908 .48243 L .915 .65 .521 r
F
.36415 .49382 m .36218 .48793 L .36208 .49102 L .98 .72 .461 r
F
.3566 .49294 m .35888 .48861 L .35446 .49133 L .667 .747 .91 r
F
.3566 .49294 m .36208 .49102 L .35888 .48861 L F
.36218 .48793 m .35908 .48243 L .35898 .48552 L .915 .65 .521 r
F
.36208 .49102 m .36218 .48793 L .35898 .48552 L F
.36208 .49102 m .35898 .48552 L .35888 .48861 L F
.34842 .49525 m .37339 .48872 L .36807 .48459 L .642 .738 .919 r
F
.34854 .49535 m .34852 .49553 L .34876 .49549 L .892 .63 .535 r
F
.34607 .49652 m .34883 .49574 L .34824 .49535 L .642 .738 .919 r
F
.34522 .50442 m .34849 .50349 L .34849 .50349 L .641 .739 .92 r
F
.34522 .50442 m .34849 .50349 L .34795 .50313 L F
.34607 .49652 m .3495 .49617 L .34883 .49574 L .642 .738 .919 r
F
.34813 .50325 m .34821 .5033 L .34886 .49555 L .892 .63 .535 r
F
.34927 .49617 m .34952 .49614 L .34894 .4956 L .667 .747 .91 r
F
.34952 .49614 m .35122 .49587 L .34956 .49539 L F
.34952 .49614 m .34956 .49539 L .34956 .49539 L F
.35122 .49587 m .35182 .49577 L .34956 .49539 L F
.34522 .50442 m .34863 .5057 L .34927 .50524 L .641 .739 .92 r
F
.34812 .50605 m .34666 .54036 L .34809 .50608 L .335 .155 .483 r
F
.34522 .50442 m .34803 .50611 L .34863 .5057 L .641 .739 .92 r
F
.34725 .50641 m .3474 .50656 L .34796 .50616 L F
.3474 .50656 m .34777 .50701 L .34781 .50695 L F
.3474 .50656 m .34767 .50716 L .34777 .50701 L F
.34742 .50635 m .34796 .50616 L .34599 .54088 L .516 .302 .527 r
F
.34742 .50635 m .34599 .54088 L .34727 .5064 L F
.34809 .50608 m .34666 .54036 L .34808 .50608 L .335 .155 .483 r
F
.34796 .50616 m .34666 .54036 L .34599 .54088 L F
.34808 .50608 m .34666 .54036 L .34796 .50616 L F
.34863 .5057 m .3735 .51501 L .34927 .50524 L .641 .739 .92 r
F
.34849 .50639 m .36862 .5185 L .35015 .50627 L F
.34827 .50594 m .34863 .50569 L .34666 .54036 L .335 .155 .483 r
F
.34641 .50725 m .34643 .52259 L .34662 .5071 L .641 .739 .92 r
F
.34633 .50672 m .34643 .52259 L .3464 .50669 L F
.34696 .5065 m .34599 .54088 L .34497 .54128 L .516 .302 .527 r
F
.34714 .50644 m .34599 .54088 L .34696 .5065 L F
.34727 .5064 m .34599 .54088 L .3472 .50642 L F
.34947 .4967 m .37814 .49821 L .34917 .49621 L .642 .738 .919 r
F
.34912 .50331 m .37603 .50128 L .37259 .49665 L .641 .739 .92 r
F
.34929 .49641 m .34849 .50349 L .34879 .50398 L .992 .745 .442 r
F
.34929 .49641 m .34879 .50398 L .34939 .49658 L F
.34886 .49555 m .34821 .5033 L .34894 .4956 L .892 .63 .535 r
F
.34522 .50442 m .34928 .504 L .34849 .50349 L .641 .739 .92 r
F
.34522 .50442 m .34725 .50641 L .34803 .50611 L F
.34725 .50641 m .34796 .50616 L .34803 .50611 L F
.34821 .5033 m .34535 .5373 L .34827 .50334 L .892 .63 .535 r
F
.34821 .5033 m .34827 .50334 L .34894 .4956 L F
.34849 .50349 m .35078 .50385 L .34912 .50331 L .641 .739 .92 r
F
.34928 .504 m .35078 .50385 L .34849 .50349 L F
.35078 .50385 m .37603 .50128 L .34912 .50331 L F
.3476 .49482 m .34759 .49498 L .34763 .49483 L .802 .546 .551 r
F
.34759 .49498 m .34761 .49499 L .34763 .49483 L F
.34761 .49499 m .34762 .49499 L .34788 .49179 L F
.34795 .49181 m .34763 .49483 L .34778 .49487 L F
.34788 .49179 m .34763 .49483 L .34795 .49181 L F
.34762 .49171 m .34664 .49454 L .34739 .49476 L F
.34759 .49398 m .34868 .49343 L .34828 .49333 L .667 .747 .91 r
F
.34759 .49398 m .34828 .49333 L .3471 .49304 L F
.34577 .49366 m .34755 .4917 L .34682 .49148 L .668 .747 .91 r
F
.34577 .49366 m .34682 .49148 L .34662 .49146 L F
.34626 .49451 m .34647 .49453 L .34672 .49147 L .733 .485 .553 r
F
.34588 .49057 m .34765 .48862 L .34699 .48843 L .668 .746 .909 r
F
.34672 .4884 m .34699 .48843 L .34674 .48835 L F
.34588 .49057 m .34699 .48843 L .34672 .4884 L F
.34699 .48843 m .34673 .49147 L .34682 .49148 L .733 .485 .553 r
F
.34696 .48842 m .34647 .49453 L .34699 .48843 L F
.34661 .49146 m .34672 .49147 L .34696 .48842 L F
.34672 .4884 m .34649 .49145 L .34696 .48842 L F
.34649 .49145 m .34661 .49146 L .34696 .48842 L F
.34672 .4884 m .3457 .49138 L .34612 .49142 L F
.34649 .49145 m .34552 .49444 L .34626 .49451 L F
.34672 .4884 m .34612 .49142 L .34649 .49145 L F
.34577 .49366 m .34662 .49146 L .34563 .49139 L .668 .747 .91 r
F
.34612 .49142 m .34552 .49444 L .34649 .49145 L .733 .485 .553 r
F
.34662 .49146 m .34669 .4913 L .3457 .49138 L .668 .747 .91 r
F
.34662 .49146 m .3457 .49138 L .34563 .49139 L F
.3476 .4886 m .34699 .48843 L .34682 .49148 L .802 .546 .551 r
F
.34669 .4913 m .34721 .48995 L .34564 .49138 L .668 .747 .91 r
F
.3457 .49138 m .34564 .49138 L .34563 .49139 L F
.34669 .4913 m .34564 .49138 L .3457 .49138 L F
.34682 .49148 m .34647 .49453 L .34664 .49454 L .733 .485 .553 r
F
.34673 .49147 m .34647 .49453 L .34682 .49148 L F
.34708 .48701 m .34696 .48842 L .34699 .48843 L F
.34626 .49451 m .34672 .49147 L .34661 .49146 L F
.34785 .48868 m .34682 .49148 L .34762 .49171 L .802 .546 .551 r
F
.3476 .4886 m .34682 .49148 L .34785 .48868 L F
.34682 .49148 m .34879 .49034 L .34664 .49143 L .668 .747 .91 r
F
.34755 .4917 m .34768 .49156 L .34682 .49148 L F
.34768 .49156 m .34879 .49034 L .34682 .49148 L F
.34662 .49146 m .34682 .49148 L .34664 .49143 L F
.34649 .49145 m .34626 .49451 L .34661 .49146 L .733 .485 .553 r
F
.34591 .49598 m .34597 .49599 L .34689 .49587 L .668 .747 .91 r
F
.34575 .49651 m .34745 .49478 L .34664 .49454 L .667 .747 .91 r
F
.34575 .49651 m .34664 .49454 L .34652 .49453 L F
.34581 .49658 m .34745 .49478 L .34575 .49651 L F
.34739 .49476 m .34738 .49491 L .3476 .49482 L .802 .546 .551 r
F
.34738 .49491 m .34759 .49498 L .3476 .49482 L F
.34607 .49652 m .3476 .49498 L .34681 .49472 L .642 .738 .919 r
F
.34522 .50442 m .34795 .50313 L .34779 .50303 L .641 .739 .92 r
F
.34607 .49652 m .34681 .49472 L .34663 .49467 L .642 .738 .919 r
F
.34564 .49638 m .34653 .49436 L .34552 .49444 L .667 .747 .91 r
F
.34625 .49462 m .34646 .49464 L .34647 .49453 L .733 .485 .553 r
F
.34762 .49171 m .34682 .49148 L .34664 .49454 L .802 .546 .551 r
F
.34575 .49651 m .3471 .49304 L .34564 .49638 L .667 .747 .91 r
F
.34607 .49652 m .34663 .49467 L .34594 .49457 L .642 .738 .919 r
F
.34566 .49675 m .34581 .49658 L .34575 .49651 L .667 .747 .91 r
F
.34349 .4918 m .34325 .49485 L .34332 .49481 L .385 .194 .495 r
F
.34403 .49464 m .34424 .49459 L .34449 .4915 L .57 .346 .536 r
F
.34413 .49462 m .34424 .49459 L .34403 .49464 L F
.34403 .49464 m .34449 .4915 L .34438 .49154 L F
.34541 .49611 m .34413 .49462 L .34332 .49481 L .642 .738 .919 r
F
.34403 .49465 m .34403 .49464 L .34403 .49464 L .57 .346 .536 r
F
.34403 .49464 m .34449 .4915 L .34403 .49464 L F
.34426 .49157 m .34403 .49464 L .34438 .49154 L F
.34403 .49464 m .34403 .49465 L .34403 .49464 L F
.34403 .49464 m .34403 .49464 L .34438 .49154 L F
.34466 .49147 m .34562 .49117 L .34465 .49146 L .668 .747 .91 r
F
.34563 .49139 m .34562 .49117 L .34466 .49147 L F
.34438 .49154 m .34449 .4915 L .34473 .48843 L .57 .346 .536 r
F
.34449 .4885 m .34426 .49157 L .34473 .48843 L F
.34426 .49157 m .34438 .49154 L .34473 .48843 L F
.34534 .48837 m .34477 .48842 L .34459 .49148 L .663 .424 .548 r
F
.34523 .4959 m .34453 .49453 L .34413 .49462 L .667 .747 .91 r
F
.34537 .49141 m .34441 .49454 L .34514 .49447 L .663 .424 .548 r
F
.34453 .49453 m .34452 .4945 L .34441 .49454 L .667 .747 .91 r
F
.34453 .49453 m .34441 .49454 L .34413 .49462 L F
.34537 .49141 m .34459 .49148 L .34441 .49454 L .663 .424 .548 r
F
.34514 .49447 m .34535 .49446 L .3456 .49139 L F
.34532 .49446 m .34543 .4929 L .34453 .49453 L .667 .747 .91 r
F
.34504 .49453 m .34592 .4942 L .34498 .49442 L .642 .738 .919 r
F
.34626 .49451 m .34552 .49444 L .34552 .49452 L .733 .485 .553 r
F
.34552 .49444 m .34533 .49442 L .34523 .4959 L .667 .747 .91 r
F
.34607 .49652 m .34594 .49457 L .34504 .49453 L .642 .738 .919 r
F
.34523 .4959 m .34532 .49446 L .34453 .49453 L .667 .747 .91 r
F
.34514 .49447 m .34441 .49454 L .34441 .49455 L .663 .424 .548 r
F
.34514 .49447 m .34441 .49455 L .34513 .49453 L F
.34607 .49652 m .34504 .49453 L .34413 .49462 L .642 .738 .919 r
F
.34504 .49453 m .34498 .49442 L .34441 .49455 L F
.34504 .49453 m .34441 .49455 L .34413 .49462 L F
.34535 .49446 m .34534 .49452 L .34538 .49445 L .663 .424 .548 r
F
.34607 .49652 m .34527 .49574 L .34527 .49574 L .642 .738 .919 r
F
.34527 .49574 m .34413 .49462 L .34527 .49574 L F
.34527 .49574 m .34413 .49462 L .34413 .49462 L F
.34607 .49652 m .34413 .49462 L .34541 .49611 L F
.34543 .49613 m .34332 .49481 L .34328 .49483 L F
.34541 .49611 m .34332 .49481 L .34543 .49613 L F
.3151 .48699 m .28641 .49491 L .31658 .4918 L .643 .738 .918 r
F
.32648 .4936 m .32661 .49051 L .32747 .4935 L .965 .751 .309 r
F
.3331 .49053 m .32757 .49348 L .33366 .49251 L .668 .746 .909 r
F
.3331 .49053 m .3267 .49051 L .32757 .49348 L F
.33934 .49364 m .33348 .4956 L .33962 .49463 L .668 .747 .91 r
F
.33977 .49154 m .33366 .49251 L .33506 .49436 L .668 .746 .909 r
F
.33934 .49364 m .33291 .49362 L .33348 .4956 L .668 .747 .91 r
F
.32692 .49061 m .32661 .49051 L .32648 .4936 L 0 0 .076 r
F
.33321 .49163 m .32648 .4936 L .33291 .49362 L .668 .747 .91 r
F
.33321 .49163 m .32692 .49061 L .32648 .4936 L F
.32671 .49368 m .32692 .49061 L .32648 .4936 L 0 0 .076 r
F
.33783 .49609 m .32678 .49323 L .32643 .49549 L .642 .738 .919 r
F
.32683 .49289 m .32692 .49061 L .32671 .49368 L 0 0 .076 r
F
.34113 .49528 m .33962 .49463 L .34032 .49556 L .668 .747 .91 r
F
.34069 .49542 m .32701 .49262 L .33783 .49609 L .642 .738 .919 r
F
.32819 .49086 m .32692 .49061 L .32683 .49289 L .012 0 .379 r
F
.32701 .49262 m .3147 .4901 L .32663 .49319 L .642 .738 .919 r
F
.32701 .49262 m .32663 .49319 L .33783 .49609 L F
.33909 .48825 m .3227 .48369 L .3151 .48699 L .643 .738 .918 r
F
.3227 .48369 m .31571 .48274 L .3151 .48699 L F
.33949 .49055 m .33366 .49251 L .33977 .49154 L .668 .746 .909 r
F
.33949 .49055 m .3331 .49053 L .33366 .49251 L F
.3334 .48855 m .3267 .49051 L .3331 .49053 L F
.3334 .48855 m .32715 .48754 L .3267 .49051 L F
.32692 .49061 m .32705 .48753 L .32661 .49051 L 0 0 .076 r
F
.3395 .49264 m .33291 .49362 L .33934 .49364 L .668 .747 .91 r
F
.3395 .49264 m .33321 .49163 L .33291 .49362 L F
.32866 .48783 m .32705 .48753 L .32692 .49061 L .012 0 .379 r
F
.33964 .48957 m .3331 .49053 L .33949 .49055 L .668 .746 .909 r
F
.33964 .48957 m .3334 .48855 L .3331 .49053 L F
.33438 .48977 m .32692 .49061 L .33321 .49163 L .668 .747 .91 r
F
.33438 .48977 m .32866 .48783 L .32692 .49061 L F
.32819 .49086 m .32866 .48783 L .32692 .49061 L .012 0 .379 r
F
.34069 .49542 m .32852 .49036 L .32701 .49262 L .642 .738 .919 r
F
.32856 .49031 m .32866 .48783 L .32819 .49086 L .012 0 .379 r
F
.34094 .49442 m .33939 .49381 L .33962 .49463 L .668 .747 .91 r
F
.3421 .49575 m .34218 .49559 L .34238 .49261 L 0 0 .29 r
F
.3421 .49575 m .34238 .49261 L .34233 .49272 L F
.34229 .4928 m .3421 .49575 L .34233 .49272 L F
.34139 .49473 m .33962 .49463 L .34113 .49528 L .668 .747 .91 r
F
.3422 .49507 m .32889 .49006 L .34069 .49542 L .642 .738 .919 r
F
.34022 .48864 m .3334 .48855 L .33964 .48957 L .668 .746 .909 r
F
.34181 .48761 m .3227 .48369 L .33909 .48825 L .643 .738 .918 r
F
.34022 .48864 m .33455 .48671 L .3334 .48855 L .668 .746 .909 r
F
.33455 .48671 m .32715 .48754 L .3334 .48855 L F
.33632 .48818 m .32866 .48783 L .33438 .48977 L .668 .747 .91 r
F
.33109 .48844 m .32866 .48783 L .32856 .49031 L .325 .154 .488 r
F
.32889 .49006 m .31754 .48579 L .3285 .49035 L .642 .738 .919 r
F
.32889 .49006 m .3285 .49035 L .34069 .49542 L F
.33925 .48709 m .34001 .48605 L .3227 .48369 L .643 .738 .918 r
F
.34001 .48605 m .3186 .47796 L .3227 .48369 L F
.34057 .49378 m .33934 .49364 L .33939 .49381 L .668 .747 .91 r
F
.34078 .49364 m .33934 .49364 L .34057 .49378 L F
.3227 .48369 m .31578 .48227 L .31571 .48274 L .643 .738 .918 r
F
.34008 .49172 m .33321 .49163 L .3395 .49264 L .668 .747 .91 r
F
.33455 .48671 m .32887 .48477 L .32715 .48754 L .668 .746 .909 r
F
.32866 .48783 m .32879 .48474 L .32705 .48753 L .012 0 .379 r
F
.34008 .49172 m .33438 .48977 L .33321 .49163 L .668 .747 .91 r
F
.33649 .48512 m .32887 .48477 L .33455 .48671 L .668 .746 .909 r
F
.33157 .48543 m .32879 .48474 L .32866 .48783 L .325 .154 .488 r
F
.33632 .48818 m .33157 .48543 L .32866 .48783 L .668 .747 .91 r
F
.33109 .48844 m .33157 .48543 L .32866 .48783 L .325 .154 .488 r
F
.34113 .49466 m .33141 .4882 L .32889 .49006 L .642 .738 .919 r
F
.33146 .48816 m .33157 .48543 L .33109 .48844 L .325 .154 .488 r
F
.34242 .49252 m .34221 .49553 L .34225 .49545 L 0 0 .29 r
F
.3424 .49257 m .34221 .49553 L .34242 .49252 L F
.3424 .49257 m .34218 .49559 L .34221 .49553 L F
.34238 .49261 m .34218 .49559 L .3424 .49257 L F
.34105 .49134 m .33954 .49075 L .33977 .49154 L .668 .746 .909 r
F
.34105 .49092 m .33438 .48977 L .34008 .49172 L .668 .747 .91 r
F
.34105 .49092 m .33632 .48818 L .33438 .48977 L F
.3429 .4946 m .33193 .48797 L .34113 .49466 L .642 .738 .919 r
F
.34119 .48785 m .33455 .48671 L .34022 .48864 L .668 .746 .909 r
F
.34247 .48698 m .34001 .48605 L .33925 .48709 L .643 .738 .918 r
F
.34119 .48785 m .33649 .48512 L .33455 .48671 L .668 .746 .909 r
F
.33891 .48696 m .33157 .48543 L .33632 .48818 L .668 .747 .91 r
F
.33521 .48665 m .33157 .48543 L .33146 .48816 L .49 .285 .528 r
F
.33193 .48797 m .32235 .48218 L .33139 .48819 L .642 .738 .919 r
F
.33193 .48797 m .33139 .48819 L .34113 .49466 L F
.34342 .49184 m .34318 .49489 L .34349 .4918 L .385 .194 .495 r
F
.34607 .49652 m .34328 .49483 L .34262 .49523 L .642 .738 .919 r
F
.34113 .49528 m .34032 .49556 L .34103 .49549 L .668 .747 .91 r
F
.34607 .49652 m .3422 .49507 L .34069 .49542 L .642 .738 .919 r
F
.34097 .49561 m .34032 .49556 L .34082 .49593 L .668 .747 .91 r
F
.34097 .49561 m .34082 .49593 L .34139 .49635 L F
.34607 .49652 m .34069 .49542 L .33783 .49609 L .642 .738 .919 r
F
.34198 .49733 m .34195 .49733 L .34239 .49789 L .667 .747 .91 r
F
.34195 .49733 m .33951 .49772 L .34206 .498 L F
.34183 .49644 m .34182 .49664 L .34181 .49633 L .923 .74 .252 r
F
.34148 .49699 m .34088 .49628 L .33934 .49721 L .642 .738 .919 r
F
.34088 .49628 m .33773 .49611 L .33934 .49721 L F
.34195 .49733 m .33922 .49673 L .33951 .49772 L .667 .747 .91 r
F
.34194 .49732 m .33922 .49673 L .34195 .49733 L F
.3421 .49726 m .34209 .49748 L .34202 .49714 L .981 .727 .472 r
F
.3417 .50501 m .34163 .50492 L .34202 .49714 L F
.34186 .49657 m .34195 .49704 L .34193 .49726 L .923 .74 .252 r
F
.34186 .49657 m .34193 .49726 L .34185 .49679 L F
.34198 .49733 m .34194 .49732 L .34195 .49733 L .667 .747 .91 r
F
.34155 .49673 m .33922 .49673 L .34198 .49733 L F
.33728 .50539 m .33386 .51224 L .33902 .5137 L .642 .738 .919 r
F
.34262 .51072 m .33036 .51934 L .33816 .52154 L .641 .739 .92 r
F
.3438 .50786 m .34232 .50912 L .34262 .51072 L F
.34232 .50912 m .33036 .51934 L .34262 .51072 L F
.34186 .49657 m .34185 .49678 L .34183 .49644 L .923 .74 .252 r
F
.34185 .49678 m .34182 .49664 L .34183 .49644 L F
.34182 .49664 m .3418 .49653 L .34181 .49633 L F
.34186 .49657 m .34185 .49679 L .34185 .49678 L F
.3418 .49653 m .3418 .49653 L .34181 .49633 L F
.3421 .49575 m .34181 .49633 L .3418 .49652 L 0 0 .29 r
F
.34566 .49675 m .34173 .49611 L .34184 .49673 L .667 .747 .91 r
F
.34181 .49633 m .34088 .49628 L .34148 .49699 L .642 .738 .919 r
F
.34173 .49611 m .33938 .49573 L .34184 .49673 L .667 .747 .91 r
F
.3414 .50424 m .34138 .50415 L .3418 .49653 L .923 .74 .252 r
F
.3414 .50424 m .3418 .49653 L .3418 .49653 L F
.34185 .49678 m .34142 .50434 L .34182 .49664 L F
.34294 .5067 m .33703 .51264 L .3438 .50786 L .641 .739 .92 r
F
.33703 .51264 m .33036 .51934 L .33615 .5144 L F
.33703 .51264 m .33615 .5144 L .3438 .50786 L F
.34142 .50434 m .3414 .50424 L .34182 .49664 L .923 .74 .252 r
F
.34198 .49709 m .3419 .49803 L .34195 .49704 L .981 .727 .472 r
F
.34202 .49714 m .3419 .49803 L .34198 .49709 L F
.34202 .49714 m .34163 .50492 L .3419 .49803 L F
.34566 .49675 m .34184 .49673 L .34198 .49733 L .667 .747 .91 r
F
.34209 .49748 m .34201 .49736 L .34202 .49714 L .981 .727 .472 r
F
.33666 .50663 m .33795 .50611 L .34136 .50777 L .788 .536 .556 r
F
.33728 .50539 m .32443 .50827 L .33124 .51149 L .642 .738 .919 r
F
.33666 .50663 m .33669 .50575 L .33795 .50611 L .788 .536 .556 r
F
.33965 .50334 m .33666 .50663 L .34136 .50777 L .667 .747 .91 r
F
.34294 .5067 m .33907 .50858 L .33703 .51264 L .641 .739 .92 r
F
.34239 .50595 m .33965 .50742 L .34294 .5067 L F
.33965 .50742 m .32353 .51612 L .33907 .50858 L F
.33965 .50742 m .33907 .50858 L .34294 .5067 L F
.3424 .49766 m .34239 .49789 L .34239 .49789 L .909 .647 .529 r
F
.33965 .50742 m .3334 .50819 L .32353 .51612 L .641 .739 .92 r
F
.34239 .50595 m .34013 .50646 L .33965 .50742 L F
.34235 .50589 m .34013 .50646 L .34239 .50595 L F
.34195 .50535 m .34048 .50576 L .3426 .50583 L F
.34048 .50576 m .34021 .50631 L .3426 .50583 L F
.33472 .5074 m .3334 .50819 L .34013 .50646 L F
.34021 .50631 m .34013 .50646 L .3426 .50583 L F
.33472 .5074 m .34013 .50646 L .34021 .50631 L F
.34251 .49775 m .3425 .49797 L .3424 .49766 L .909 .647 .529 r
F
.3425 .49797 m .34217 .50551 L .34239 .49789 L F
.34217 .50551 m .34208 .50545 L .34239 .49789 L F
.3425 .49797 m .34239 .49789 L .3424 .49766 L F
.34566 .49675 m .34198 .49733 L .34239 .49789 L .667 .747 .91 r
F
.34239 .49789 m .34208 .50544 L .34195 .50535 L .909 .647 .529 r
F
.34239 .49789 m .34208 .50545 L .34239 .49789 L F
.34208 .50545 m .34064 .54079 L .34208 .50544 L F
.34208 .50545 m .34208 .50544 L .34239 .49789 L F
.33395 .50047 m .32292 .50713 L .32443 .50827 L .642 .738 .919 r
F
.32934 .50243 m .33046 .50219 L .33256 .5048 L .912 .65 .527 r
F
.33046 .50219 m .3326 .50381 L .33256 .5048 L F
.33256 .5048 m .3326 .50381 L .33387 .50441 L .847 .589 .548 r
F
.33256 .5048 m .33387 .50441 L .33666 .50663 L F
.33387 .50441 m .33669 .50575 L .33666 .50663 L F
.31551 .49965 m .29237 .51185 L .31907 .50423 L .642 .738 .919 r
F
.33263 .50382 m .33317 .50407 L .33945 .50106 L F
.33728 .50539 m .33687 .5058 L .33705 .50585 L F
.33691 .50213 m .33666 .50663 L .33965 .50334 L .667 .747 .91 r
F
.33691 .50213 m .33256 .5048 L .33666 .50663 L F
.34009 .49977 m .33263 .50382 L .33945 .50106 L .642 .738 .919 r
F
.33477 .50054 m .33256 .5048 L .33691 .50213 L .667 .747 .91 r
F
.32934 .50243 m .32938 .50137 L .33046 .50219 L .912 .65 .527 r
F
.33477 .50054 m .32934 .50243 L .33256 .5048 L .667 .747 .91 r
F
.34124 .50482 m .31308 .50273 L .31458 .50753 L .641 .739 .92 r
F
.34195 .49704 m .34158 .50484 L .34149 .50473 L .981 .727 .472 r
F
.34163 .50492 m .34158 .50484 L .3419 .49803 L F
.34182 .49664 m .3414 .50424 L .3418 .49653 L .923 .74 .252 r
F
.34209 .49748 m .3417 .50501 L .34201 .49736 L .981 .727 .472 r
F
.34185 .49678 m .34149 .50473 L .34142 .50434 L .923 .74 .252 r
F
.34185 .49679 m .34149 .50473 L .34185 .49678 L F
.3421 .49749 m .34239 .49789 L .34195 .50535 L .981 .727 .472 r
F
.34229 .5056 m .34217 .50551 L .3425 .49797 L .909 .647 .529 r
F
.34229 .5056 m .3425 .49797 L .34251 .49797 L F
.34185 .49679 m .34193 .49726 L .34149 .50473 L .923 .74 .252 r
F
.34312 .49841 m .34287 .50597 L .34268 .50589 L .834 .575 .548 r
F
.34312 .49842 m .34287 .50597 L .34312 .49841 L F
.34343 .50621 m .34239 .50595 L .34294 .5067 L .641 .739 .92 r
F
.34258 .50584 m .34239 .50595 L .34343 .50621 L F
.34287 .50597 m .3417 .54123 L .34287 .50597 L .834 .575 .548 r
F
.34287 .50597 m .34287 .50597 L .34312 .49841 L F
.34387 .49871 m .34312 .49841 L .34374 .49886 L .667 .747 .91 r
F
.34348 .49856 m .34417 .49883 L .34373 .50634 L .834 .575 .548 r
F
.34432 .50659 m .34294 .5067 L .3438 .50786 L .641 .739 .92 r
F
.34373 .50634 m .34294 .5067 L .34432 .50659 L F
.34343 .50621 m .34337 .50627 L .34373 .50634 L F
.34337 .50627 m .34294 .5067 L .34373 .50634 L F
.34373 .50634 m .34335 .54146 L .3417 .54123 L .749 .499 .553 r
F
.34418 .49866 m .34403 .50639 L .34373 .50634 L F
.34348 .49856 m .34373 .50634 L .34317 .50609 L .834 .575 .548 r
F
.34449 .50647 m .34424 .50642 L .34443 .49886 L .749 .499 .553 r
F
.34449 .50647 m .34443 .49886 L .34443 .49886 L F
.34449 .50647 m .34443 .4987 L .3445 .49871 L F
.34474 .49875 m .34449 .50647 L .3445 .49871 L F
.34443 .4987 m .34424 .50642 L .34418 .49866 L F
.34424 .50642 m .34403 .50639 L .34418 .49866 L F
.34522 .50442 m .34343 .50621 L .34373 .50634 L .641 .739 .92 r
F
.34438 .50645 m .34373 .50634 L .34432 .50659 L F
.34522 .50442 m .34373 .50634 L .34438 .50645 L F
.34424 .50642 m .34335 .54146 L .34403 .50639 L .749 .499 .553 r
F
.34403 .50639 m .34335 .54146 L .34373 .50634 L F
.34317 .50609 m .34373 .50634 L .3417 .54123 L .834 .575 .548 r
F
.34265 .49808 m .34312 .49841 L .34268 .50589 L .909 .647 .529 r
F
.34265 .49785 m .34268 .50589 L .34229 .5056 L F
.34317 .50609 m .34301 .50603 L .34329 .49828 L .834 .575 .548 r
F
.34329 .49828 m .34301 .50603 L .34313 .49821 L F
.34301 .50603 m .3417 .54123 L .34287 .50597 L F
.34301 .50603 m .34287 .50597 L .34313 .49821 L F
.32721 .49845 m .31401 .49484 L .31551 .49965 L .642 .738 .919 r
F
.32747 .49889 m .32735 .4989 L .32933 .5013 L F
.32735 .4989 m .32771 .50009 L .32933 .5013 L F
.32621 .49897 m .31551 .49965 L .3293 .50131 L F
.32722 .49966 m .32798 .49956 L .32934 .50243 L .977 .72 .474 r
F
.32798 .49956 m .32938 .50137 L .32934 .50243 L F
.31551 .49965 m .28513 .50277 L .29237 .51185 L .642 .738 .919 r
F
.31401 .49484 m .28513 .50277 L .31551 .49965 L F
.33336 .49869 m .32934 .50243 L .33477 .50054 L .667 .747 .91 r
F
.33336 .49869 m .32722 .49966 L .32934 .50243 L F
.33838 .50406 m .31376 .49801 L .31308 .50273 L .641 .739 .92 r
F
.34184 .49673 m .34193 .49726 L .34198 .49733 L .667 .747 .91 r
F
.34181 .49633 m .34138 .50415 L .34136 .50402 L .923 .74 .252 r
F
.34151 .49608 m .33996 .49481 L .33938 .49573 L .667 .747 .91 r
F
.34607 .49652 m .34273 .49791 L .34306 .49816 L .642 .738 .919 r
F
.34566 .49675 m .34224 .49558 L .34198 .49615 L .667 .747 .91 r
F
.34172 .50329 m .34175 .50323 L .34224 .49559 L 0 0 .29 r
F
.34224 .49559 m .34224 .49559 L .34225 .49545 L F
.34172 .50329 m .34224 .49559 L .34224 .49559 L F
.3421 .49575 m .34209 .49591 L .34218 .49559 L F
.34209 .49591 m .34217 .49573 L .34218 .49559 L F
.3421 .49575 m .3418 .49652 L .34209 .49591 L F
.34198 .49615 m .34224 .49558 L .34151 .49608 L .667 .747 .91 r
F
.34224 .49558 m .34224 .49558 L .34198 .49615 L F
.34218 .49559 m .34217 .49573 L .34221 .49553 L 0 0 .29 r
F
.34217 .49573 m .34166 .50341 L .3422 .49567 L F
.34217 .49573 m .3422 .49567 L .34221 .49553 L F
.34166 .50341 m .34169 .50336 L .34221 .49553 L F
.34221 .49553 m .34169 .50336 L .34172 .50329 L F
.34224 .49558 m .34094 .49402 L .33996 .49481 L .667 .747 .91 r
F
.34295 .49503 m .34225 .49545 L .34224 .49558 L .385 .194 .495 r
F
.34295 .49503 m .34224 .49558 L .34294 .49511 L F
.34566 .49675 m .34289 .49514 L .34224 .49558 L .667 .747 .91 r
F
.34251 .49797 m .3425 .49797 L .34251 .49775 L .909 .647 .529 r
F
.34265 .49785 m .34313 .49821 L .34312 .49841 L F
.34265 .49785 m .34312 .49841 L .34265 .49808 L F
.34566 .49675 m .34239 .49789 L .34304 .49836 L .667 .747 .91 r
F
.34264 .49807 m .34229 .5056 L .34251 .49797 L .909 .647 .529 r
F
.34295 .49503 m .34294 .49511 L .34294 .49511 L .385 .194 .495 r
F
.34326 .49482 m .34244 .49396 L .34262 .49444 L .642 .738 .919 r
F
.34208 .48996 m .33964 .48957 L .34216 .49041 L .668 .746 .909 r
F
.34235 .49032 m .33632 .48818 L .34105 .49092 L .668 .747 .91 r
F
.34261 .48946 m .34119 .48785 L .34022 .48864 L .668 .746 .909 r
F
.34195 .48923 m .34022 .48864 L .34208 .48996 L F
.34235 .49032 m .33891 .48696 L .33632 .48818 L .668 .747 .91 r
F
.33649 .48512 m .33177 .48238 L .32887 .48477 L .668 .746 .909 r
F
.33157 .48543 m .3317 .48234 L .32879 .48474 L .325 .154 .488 r
F
.34248 .48725 m .33649 .48512 L .34119 .48785 L .668 .746 .909 r
F
.34248 .48725 m .33907 .48391 L .33649 .48512 L F
.33907 .48391 m .33177 .48238 L .33649 .48512 L F
.33891 .48696 m .33547 .48359 L .33157 .48543 L .668 .747 .91 r
F
.33547 .48359 m .3317 .48234 L .33157 .48543 L .49 .285 .528 r
F
.33521 .48665 m .33547 .48359 L .33157 .48543 L F
.33535 .48659 m .33547 .48359 L .33521 .48665 L F
.33101 .48742 m .32882 .47955 L .32235 .48218 L .642 .738 .919 r
F
.34262 .49444 m .33535 .48659 L .33101 .48742 L F
.33535 .48659 m .32882 .47955 L .33101 .48742 L F
.344 .48687 m .33907 .48391 L .34248 .48725 L .668 .746 .909 r
F
.34198 .4862 m .33547 .48359 L .33891 .48696 L .668 .747 .91 r
F
.33996 .48554 m .33547 .48359 L .33535 .48659 L .592 .368 .545 r
F
.33996 .48554 m .33535 .48659 L .33701 .48627 L F
.34244 .49396 m .33544 .48655 L .34262 .49444 L .642 .738 .919 r
F
.33544 .48655 m .33535 .48659 L .34262 .49444 L F
.34318 .49489 m .34325 .49485 L .34349 .4918 L .385 .194 .495 r
F
.34426 .49157 m .34332 .49481 L .34403 .49464 L .57 .346 .536 r
F
.3439 .49168 m .34332 .49481 L .34426 .49157 L F
.34347 .49397 m .34337 .49387 L .34332 .49481 L F
.3439 .49168 m .34337 .49387 L .34347 .49397 L F
.3439 .49168 m .34349 .4918 L .34337 .49387 L F
.34295 .49503 m .34315 .49491 L .34339 .49187 L .385 .194 .495 r
F
.34295 .49503 m .34339 .49187 L .34327 .49195 L F
.34318 .49201 m .34295 .49503 L .34327 .49195 L F
.33907 .48391 m .33564 .48055 L .33177 .48238 L .668 .746 .909 r
F
.33547 .48359 m .33559 .4805 L .3317 .48234 L .49 .285 .528 r
F
.34413 .49461 m .33093 .47915 L .32882 .47955 L .642 .738 .919 r
F
.34413 .49462 m .32882 .47955 L .34326 .49482 L F
.34413 .49462 m .34377 .49303 L .34295 .49323 L .667 .747 .91 r
F
.34413 .49462 m .34413 .49461 L .34413 .49462 L .642 .738 .919 r
F
.34413 .49461 m .32882 .47955 L .34413 .49462 L F
.34295 .49323 m .3388 .49006 L .34223 .49341 L .667 .747 .91 r
F
.34377 .49303 m .34175 .49182 L .34295 .49323 L F
.34175 .49182 m .3388 .49006 L .34295 .49323 L F
.33701 .48627 m .33535 .48659 L .33534 .48669 L .592 .368 .545 r
F
.33534 .48669 m .33535 .48659 L .33521 .48665 L .49 .285 .528 r
F
.33544 .48655 m .32882 .47955 L .33535 .48659 L .642 .738 .919 r
F
.34289 .49514 m .34223 .49341 L .34094 .49402 L .667 .747 .91 r
F
.34403 .49464 m .34332 .49481 L .34331 .49486 L .57 .346 .536 r
F
.34566 .49675 m .34363 .49477 L .34289 .49514 L .667 .747 .91 r
F
.34363 .49477 m .34331 .49486 L .34289 .49514 L F
.34209 .49591 m .3418 .49652 L .34136 .50402 L 0 0 .29 r
F
.34126 .50421 m .33956 .50326 L .33838 .50406 L .641 .739 .92 r
F
.34522 .50442 m .34153 .50367 L .34126 .50421 L F
.34209 .49591 m .34136 .50402 L .34159 .50355 L 0 0 .29 r
F
.34153 .50367 m .33956 .50326 L .34126 .50421 L .641 .739 .92 r
F
.33956 .50326 m .33374 .50208 L .33759 .50372 L F
.33956 .50326 m .33759 .50372 L .33838 .50406 L F
.34313 .49821 m .34312 .49842 L .34312 .49841 L .834 .575 .548 r
F
.34566 .49675 m .34304 .49836 L .34312 .49841 L .667 .747 .91 r
F
.34566 .49675 m .34312 .49841 L .34387 .49871 L F
.34403 .49464 m .34331 .49486 L .34403 .49465 L .57 .346 .536 r
F
.34566 .49675 m .34523 .4959 L .3438 .49471 L .667 .747 .91 r
F
.34363 .49477 m .3438 .49471 L .34223 .49341 L F
.34566 .49675 m .3438 .49471 L .34363 .49477 L F
.34473 .48843 m .34424 .49459 L .34477 .48842 L .57 .346 .536 r
F
.34522 .50442 m .34258 .50584 L .34343 .50621 L .641 .739 .92 r
F
.34522 .50442 m .34034 .50416 L .34124 .50482 L F
.34522 .50442 m .34124 .50482 L .34195 .50535 L F
.34522 .50442 m .34195 .50535 L .3426 .50583 L F
.34268 .50589 m .3417 .54123 L .34064 .54079 L .834 .575 .548 r
F
.34287 .50597 m .3417 .54123 L .34268 .50589 L F
.34403 .49465 m .34413 .49462 L .34403 .49464 L .57 .346 .536 r
F
.34523 .4959 m .34295 .49323 L .34223 .49341 L .667 .747 .91 r
F
.34443 .49886 m .34443 .49886 L .34443 .4987 L .749 .499 .553 r
F
.34566 .49675 m .34381 .49878 L .34481 .49891 L .667 .747 .91 r
F
.3426 .50583 m .34235 .50589 L .34239 .50595 L .641 .739 .92 r
F
.34229 .5056 m .34268 .50589 L .34064 .54079 L .909 .647 .529 r
F
.34317 .50609 m .3417 .54123 L .34301 .50603 L .834 .575 .548 r
F
.32643 .49549 m .3147 .4901 L .31401 .49484 L .642 .738 .919 r
F
.33722 .49743 m .32654 .49624 L .32721 .49845 L F
.32613 .49547 m .31401 .49484 L .33722 .49743 L F
.32635 .49669 m .32667 .49665 L .32722 .49966 L .965 .751 .309 r
F
.32667 .49665 m .32726 .49862 L .32722 .49966 L F
.32722 .49966 m .32726 .49862 L .32798 .49956 L .977 .72 .474 r
F
.34128 .49944 m .33691 .50213 L .33965 .50334 L .667 .747 .91 r
F
.33279 .49671 m .32722 .49966 L .33336 .49869 L F
.33279 .49671 m .32635 .49669 L .32722 .49966 L F
.33956 .50326 m .31661 .4937 L .31376 .49801 L .641 .739 .92 r
F
.34221 .49566 m .34172 .50329 L .34224 .49559 L 0 0 .29 r
F
.34225 .49545 m .34175 .50323 L .3418 .50314 L F
.34209 .49591 m .34159 .50355 L .34217 .49573 L F
.34159 .50355 m .34166 .50341 L .34218 .49559 L F
.34325 .49485 m .34261 .50265 L .34332 .49481 L .385 .194 .495 r
F
.34522 .50442 m .3418 .50314 L .34108 .50357 L .641 .739 .92 r
F
.34217 .50551 m .34064 .54079 L .34208 .50545 L .909 .647 .529 r
F
.34195 .50535 m .33754 .5057 L .33472 .5074 L .641 .739 .92 r
F
.34124 .50482 m .31458 .50753 L .34195 .50535 L F
.34149 .50473 m .33989 .54025 L .33943 .53962 L .981 .727 .472 r
F
.34158 .50484 m .33989 .54025 L .34149 .50473 L F
.34195 .50535 m .34064 .54079 L .33989 .54025 L .909 .647 .529 r
F
.34208 .50544 m .34064 .54079 L .34195 .50535 L F
.34039 .53018 m .33989 .54025 L .34035 .53067 L .981 .727 .472 r
F
.34039 .53018 m .34035 .53067 L .34158 .50484 L F
.34163 .50492 m .34039 .53018 L .34158 .50484 L F
.3417 .50501 m .33989 .54025 L .34163 .50492 L F
.34229 .5056 m .34064 .54079 L .34217 .50551 L .909 .647 .529 r
F
.3417 .50501 m .34195 .50535 L .33989 .54025 L .981 .727 .472 r
F
.34294 .49511 m .3418 .50314 L .34237 .5028 L .385 .194 .495 r
F
.34294 .49511 m .3418 .50314 L .34294 .49511 L F
.34289 .49514 m .34224 .49558 L .34224 .49558 L .667 .747 .91 r
F
.34294 .49511 m .34224 .49558 L .3418 .50314 L .385 .194 .495 r
F
.32701 .49262 m .31754 .48579 L .3147 .4901 L .642 .738 .919 r
F
.32853 .49092 m .32819 .49086 L .3268 .4937 L .012 0 .379 r
F
.32819 .49086 m .32683 .49289 L .3268 .4937 L F
.3268 .4937 m .32683 .49289 L .32671 .49368 L 0 0 .076 r
F
.32678 .49323 m .3147 .4901 L .32643 .49549 L .642 .738 .919 r
F
.33773 .49611 m .32613 .49547 L .3343 .49691 L F
.3268 .4937 m .32671 .49368 L .32635 .49669 L 0 0 .076 r
F
.32671 .49368 m .32639 .49573 L .32635 .49669 L F
.32635 .49669 m .32639 .49573 L .32667 .49665 L .965 .751 .309 r
F
.34021 .49864 m .33691 .50213 L .34128 .49944 L .667 .747 .91 r
F
.34021 .49864 m .33477 .50054 L .33691 .50213 L F
.33951 .49772 m .33477 .50054 L .34021 .49864 L F
.33951 .49772 m .33336 .49869 L .33477 .50054 L F
.33773 .49611 m .3343 .49691 L .33722 .49743 L .642 .738 .919 r
F
.33922 .49673 m .33336 .49869 L .33951 .49772 L .667 .747 .91 r
F
.33922 .49673 m .33279 .49671 L .33336 .49869 L F
.33309 .49472 m .32635 .49669 L .33279 .49671 L F
.33309 .49472 m .3268 .4937 L .32635 .49669 L F
.33426 .49287 m .3268 .4937 L .33309 .49472 L F
.33426 .49287 m .32853 .49092 L .3268 .4937 L F
.33978 .50238 m .32143 .49011 L .31661 .4937 L .641 .739 .92 r
F
.34427 .49459 m .34365 .50232 L .34441 .49455 L .57 .346 .536 r
F
.3418 .50314 m .34226 .50264 L .34115 .5029 L .641 .739 .92 r
F
.34522 .50442 m .34245 .50275 L .3418 .50314 L F
.34295 .49503 m .34237 .5028 L .34315 .49491 L .385 .194 .495 r
F
.34522 .50442 m .34318 .50242 L .34245 .50275 L .641 .739 .92 r
F
.34403 .49465 m .34287 .5025 L .34345 .50236 L .57 .346 .536 r
F
.34318 .50242 m .34311 .50235 L .34287 .5025 L .641 .739 .92 r
F
.34318 .50242 m .34287 .5025 L .34245 .50275 L F
.34441 .49455 m .34376 .50229 L .34396 .50224 L .57 .346 .536 r
F
.34237 .5028 m .34254 .5027 L .34315 .49491 L .385 .194 .495 r
F
.34315 .49491 m .34254 .5027 L .34318 .49489 L F
.34254 .5027 m .34256 .50268 L .34318 .49489 L F
.34365 .50232 m .34376 .50229 L .34441 .49455 L .57 .346 .536 r
F
.34261 .50265 m .34267 .50261 L .34332 .49481 L .385 .194 .495 r
F
.34424 .49459 m .34362 .50232 L .34427 .49458 L .57 .346 .536 r
F
.34362 .50232 m .34365 .50232 L .34427 .49458 L F
.34403 .49465 m .34331 .49486 L .34287 .5025 L F
.34331 .49486 m .34267 .50261 L .34287 .5025 L .385 .194 .495 r
F
.34331 .49486 m .34267 .50261 L .34331 .49486 L F
.34224 .49558 m .33996 .49481 L .34151 .49608 L .667 .747 .91 r
F
.34318 .49489 m .34256 .50268 L .34325 .49485 L .385 .194 .495 r
F
.34256 .50268 m .34261 .50265 L .34325 .49485 L F
.3417 .49673 m .33938 .49573 L .33922 .49673 L .667 .747 .91 r
F
.34172 .49669 m .33938 .49573 L .3417 .49673 L F
.33534 .48669 m .33521 .48665 L .33145 .48853 L .49 .285 .528 r
F
.33521 .48665 m .33146 .48816 L .33145 .48853 L F
.33145 .48853 m .33146 .48816 L .33109 .48844 L .325 .154 .488 r
F
.33141 .4882 m .32235 .48218 L .32889 .49006 L .642 .738 .919 r
F
.33145 .48853 m .33109 .48844 L .32853 .49092 L .325 .154 .488 r
F
.33109 .48844 m .32856 .49031 L .32853 .49092 L F
.33938 .49573 m .33279 .49671 L .33922 .49673 L .667 .747 .91 r
F
.33938 .49573 m .33309 .49472 L .33279 .49671 L F
.33996 .49481 m .33309 .49472 L .33938 .49573 L F
.33996 .49481 m .33426 .49287 L .33309 .49472 L F
.34094 .49402 m .33426 .49287 L .33996 .49481 L F
.34094 .49402 m .3362 .49128 L .33426 .49287 L F
.34223 .49341 m .3362 .49128 L .34094 .49402 L F
.34223 .49341 m .3388 .49006 L .3362 .49128 L F
.3362 .49128 m .32853 .49092 L .33426 .49287 L F
.3362 .49128 m .33145 .48853 L .32853 .49092 L F
.3388 .49006 m .33145 .48853 L .3362 .49128 L F
.3388 .49006 m .33534 .48669 L .33145 .48853 L F
.3427 .4878 m .34259 .4895 L .3426 .48949 L 0 0 .29 r
F
.3429 .48884 m .34119 .48785 L .34261 .48946 L .668 .746 .909 r
F
.34367 .48874 m .34342 .49184 L .34349 .4918 L .385 .194 .495 r
F
.34262 .48946 m .34261 .48946 L .3426 .48947 L .668 .746 .909 r
F
.34261 .48946 m .34198 .48924 L .34235 .49 L F
.34198 .48924 m .34195 .48923 L .34195 .48925 L F
.34198 .48924 m .34195 .48925 L .34208 .48996 L F
.34235 .49 m .34208 .48996 L .34216 .49041 L F
.34388 .48994 m .33891 .48696 L .34235 .49032 L .668 .747 .91 r
F
.34186 .48929 m .33534 .48669 L .3388 .49006 L .667 .747 .91 r
F
.34324 .48904 m .34328 .48803 L .3429 .48884 L .668 .746 .909 r
F
.3429 .48884 m .34248 .48725 L .34119 .48785 L F
.34328 .48803 m .34248 .48725 L .3429 .48884 L F
.34388 .48994 m .34198 .4862 L .33891 .48696 L .668 .747 .91 r
F
.34186 .48929 m .33996 .48554 L .33534 .48669 L .667 .747 .91 r
F
.34318 .50242 m .33561 .48602 L .32792 .48748 L .641 .739 .92 r
F
.34474 .49875 m .3458 .49904 L .34473 .4989 L .749 .499 .553 r
F
.34566 .49675 m .34481 .49891 L .3458 .49904 L .667 .747 .91 r
F
.34534 .49452 m .34473 .50222 L .34537 .49452 L .663 .424 .548 r
F
.34522 .50442 m .34408 .50224 L .34318 .50242 L .641 .739 .92 r
F
.34449 .50647 m .34335 .54146 L .34424 .50642 L .749 .499 .553 r
F
.34522 .50442 m .34438 .50645 L .34536 .50662 L .641 .739 .92 r
F
.34473 .50222 m .34475 .50222 L .34537 .49452 L .663 .424 .548 r
F
.34441 .49455 m .34376 .50229 L .34441 .49455 L .57 .346 .536 r
F
.34376 .50229 m .34376 .50229 L .34441 .49455 L F
.34526 .49596 m .34526 .49593 L .34523 .4959 L .667 .747 .91 r
F
.34566 .49675 m .34526 .49593 L .34526 .49596 L F
.34566 .49675 m .34564 .49638 L .34526 .49593 L F
.34594 .49457 m .34552 .49452 L .34504 .49453 L .642 .738 .919 r
F
.34537 .49452 m .34475 .50222 L .34551 .49452 L .663 .424 .548 r
F
.34475 .50222 m .34487 .50221 L .34551 .49452 L F
.34424 .49459 m .34427 .49458 L .34477 .48842 L .57 .346 .536 r
F
.34363 .49477 m .34355 .49469 L .34331 .49486 L .667 .747 .91 r
F
.34332 .49481 m .34331 .49486 L .34331 .49486 L .385 .194 .495 r
F
.34328 .49483 m .3429 .4946 L .34262 .49523 L .642 .738 .919 r
F
.34328 .49483 m .34332 .49481 L .34326 .49482 L F
.34355 .49469 m .34223 .49341 L .34289 .49514 L .667 .747 .91 r
F
.34289 .49514 m .34254 .49494 L .34224 .49558 L F
.34221 .49553 m .34221 .49566 L .34225 .49545 L 0 0 .29 r
F
.34221 .49566 m .34224 .49559 L .34225 .49545 L F
.34262 .49523 m .3429 .4946 L .34113 .49466 L .642 .738 .919 r
F
.34254 .49494 m .34094 .49402 L .34224 .49558 L .667 .747 .91 r
F
.34184 .49673 m .34172 .49669 L .3417 .49673 L F
.34184 .49673 m .34155 .49673 L .34193 .49726 L F
.34427 .49458 m .34427 .49459 L .34441 .49454 L .57 .346 .536 r
F
.34427 .49459 m .34441 .49455 L .34441 .49454 L F
.34441 .49454 m .34441 .49455 L .34441 .49455 L F
.34513 .49453 m .34441 .49455 L .34396 .50224 L .663 .424 .548 r
F
.34522 .50442 m .34507 .50221 L .34408 .50224 L .641 .739 .92 r
F
.34455 .50222 m .34396 .50224 L .34194 .53691 L .663 .424 .548 r
F
.34513 .49453 m .34396 .50224 L .34455 .50222 L F
.34607 .49652 m .34541 .49611 L .34543 .49613 L .642 .738 .919 r
F
.34507 .50221 m .34194 .53691 L .34307 .53683 L .663 .424 .548 r
F
.34552 .49452 m .34487 .50221 L .34507 .50221 L F
.34487 .50221 m .34194 .53691 L .34507 .50221 L F
.34566 .49675 m .34575 .49651 L .34564 .49638 L .667 .747 .91 r
F
.34607 .49652 m .34579 .49655 L .34582 .49659 L .642 .738 .919 r
F
.34607 .49652 m .34575 .49651 L .34579 .49655 L F
.34566 .49675 m .34585 .49663 L .34581 .49658 L .667 .747 .91 r
F
.34566 .49675 m .34595 .49675 L .34594 .49673 L F
.34566 .49675 m .34588 .49667 L .34585 .49663 L F
.3458 .49894 m .3458 .49904 L .3458 .49904 L .644 .409 .547 r
F
.34635 .49897 m .34605 .49901 L .34605 .49892 L F
.34566 .49675 m .3458 .49904 L .34677 .49892 L .667 .747 .91 r
F
.34566 .49675 m .34599 .49679 L .34595 .49675 L F
.34566 .49675 m .346 .4968 L .34599 .49679 L F
.34566 .49675 m .34624 .49708 L .34607 .49689 L F
.34566 .49675 m .34607 .49689 L .346 .4968 L F
.34625 .49462 m .34552 .49452 L .34507 .50221 L .733 .485 .553 r
F
.34607 .49652 m .34586 .49664 L .3459 .49669 L .642 .738 .919 r
F
.34607 .49652 m .3459 .49669 L .34597 .49677 L F
.34607 .49652 m .34604 .49684 L .3461 .49692 L F
.34607 .49652 m .34597 .49677 L .34604 .49684 L F
.34625 .49462 m .34507 .50221 L .34567 .50229 L .733 .485 .553 r
F
.34538 .49445 m .34537 .49452 L .34552 .49444 L .663 .424 .548 r
F
.34537 .49452 m .34551 .49452 L .34552 .49444 L F
.34534 .49452 m .34537 .49452 L .34538 .49445 L F
.34626 .49451 m .34552 .49452 L .34625 .49462 L .733 .485 .553 r
F
.34594 .49457 m .34594 .4945 L .34552 .49452 L .642 .738 .919 r
F
.34653 .49436 m .3471 .49304 L .34552 .49444 L .667 .747 .91 r
F
.34552 .49444 m .34551 .49452 L .34552 .49452 L .663 .424 .548 r
F
.34514 .49447 m .34194 .53691 L .34535 .49446 L F
.34594 .4945 m .34592 .4942 L .34504 .49453 L .642 .738 .919 r
F
.34477 .48842 m .34427 .49458 L .34441 .49454 L .57 .346 .536 r
F
.34431 .49078 m .34425 .48991 L .34388 .48994 L .668 .747 .91 r
F
.34465 .49146 m .34425 .48991 L .34431 .49078 L F
.34465 .49146 m .34554 .48981 L .34425 .48991 L F
.34562 .49117 m .34554 .48981 L .34465 .49146 L F
.34459 .49148 m .34388 .48994 L .34362 .49156 L F
.34466 .49147 m .34465 .49146 L .34459 .49148 L F
.34465 .49146 m .34388 .48994 L .34459 .49148 L F
.34537 .49141 m .34514 .49447 L .3456 .49139 L .663 .424 .548 r
F
.34452 .4945 m .34543 .4929 L .34377 .49303 L .667 .747 .91 r
F
.34455 .4945 m .34543 .4929 L .34452 .4945 L F
.34378 .49171 m .34459 .49148 L .34362 .49156 L .668 .747 .91 r
F
.34362 .49156 m .34388 .48994 L .34235 .49032 L F
.34287 .49198 m .34362 .49156 L .34234 .49167 L F
.34378 .49171 m .34362 .49156 L .34287 .49198 L F
.34575 .48834 m .34565 .48674 L .34479 .48842 L .668 .746 .909 r
F
.34362 .49156 m .34235 .49032 L .34234 .49167 L .668 .747 .91 r
F
.34479 .48842 m .344 .48687 L .34377 .48851 L .668 .746 .909 r
F
.34387 .48861 m .34328 .48803 L .34324 .48887 L F
.34367 .48874 m .34324 .48887 L .34324 .48904 L F
.34387 .48861 m .34324 .48887 L .34367 .48874 L F
.34393 .48867 m .34387 .48861 L .34367 .48874 L F
.344 .48687 m .34211 .48315 L .33907 .48391 L F
.34565 .48674 m .34211 .48315 L .344 .48687 L F
.34565 .48674 m .34542 .48289 L .34211 .48315 L F
.3456 .48835 m .34537 .49141 L .34577 .48833 L .663 .424 .548 r
F
.34554 .48981 m .34198 .4862 L .34388 .48994 L .668 .747 .91 r
F
.34554 .48981 m .34531 .48594 L .34198 .4862 L F
.34211 .48315 m .33564 .48055 L .33907 .48391 L .668 .746 .909 r
F
.34306 .49209 m .34349 .4918 L .34287 .49198 L .668 .747 .91 r
F
.34543 .4929 m .34186 .48929 L .34377 .49303 L .667 .747 .91 r
F
.34543 .4929 m .34519 .48904 L .34186 .48929 L F
.34211 .48315 m .34022 .47941 L .33564 .48055 L .668 .746 .909 r
F
.34542 .48289 m .34022 .47941 L .34211 .48315 L F
.34542 .48289 m .34519 .47903 L .34022 .47941 L F
.34198 .4862 m .34007 .48244 L .33547 .48359 L .668 .747 .91 r
F
.34531 .48594 m .34007 .48244 L .34198 .4862 L F
.34531 .48594 m .34507 .48206 L .34007 .48244 L F
.34007 .48244 m .33559 .4805 L .33547 .48359 L .592 .368 .545 r
F
.34007 .48244 m .34019 .47935 L .33559 .4805 L F
.34519 .48904 m .33996 .48554 L .34186 .48929 L .667 .747 .91 r
F
.34519 .48904 m .34496 .48516 L .33996 .48554 L F
.34507 .48206 m .34019 .47935 L .34007 .48244 L .667 .431 .553 r
F
.34507 .48206 m .34518 .47897 L .34019 .47935 L F
.33996 .48554 m .34007 .48244 L .33547 .48359 L .592 .368 .545 r
F
.34496 .48516 m .34007 .48244 L .33996 .48554 L .667 .431 .553 r
F
.34496 .48516 m .34507 .48206 L .34007 .48244 L F
.34498 .49442 m .34485 .47788 L .3365 .47808 L .642 .738 .919 r
F
.34672 .4884 m .34587 .48833 L .3457 .49138 L .733 .485 .553 r
F
.34612 .49142 m .3457 .49138 L .34552 .49444 L F
.34558 .48981 m .34572 .48982 L .34596 .48686 L .663 .424 .548 r
F
.34537 .49141 m .34572 .48982 L .34558 .48981 L F
.34537 .49141 m .3456 .49139 L .34572 .48982 L F
.34563 .49137 m .34721 .48995 L .34554 .48981 L .668 .747 .91 r
F
.34563 .49139 m .34564 .49138 L .34563 .49137 L F
.34564 .49138 m .34721 .48995 L .34563 .49137 L F
.3456 .49139 m .34535 .49446 L .34561 .49139 L .663 .424 .548 r
F
.34552 .49444 m .3471 .49304 L .34543 .4929 L .667 .747 .91 r
F
.34552 .49444 m .34543 .4929 L .34533 .49442 L F
.34682 .48698 m .34596 .48686 L .34587 .48833 L .733 .485 .553 r
F
.34596 .48686 m .34584 .48833 L .34587 .48833 L .663 .424 .548 r
F
.34574 .48831 m .34731 .48688 L .34565 .48674 L .668 .746 .909 r
F
.34575 .48834 m .34577 .48832 L .34574 .48831 L F
.34577 .48832 m .34731 .48688 L .34574 .48831 L F
.34672 .4884 m .34678 .48825 L .34587 .48833 L F
.34678 .48825 m .34731 .48688 L .34575 .48834 L F
.34721 .48995 m .34531 .48594 L .34554 .48981 L .668 .747 .91 r
F
.34795 .4873 m .34708 .48701 L .34699 .48843 L .802 .546 .551 r
F
.34795 .4873 m .3476 .4886 L .34785 .48868 L F
.34674 .48835 m .34888 .48727 L .34731 .48688 L .668 .746 .909 r
F
.34795 .4873 m .34699 .48843 L .3476 .4886 L .802 .546 .551 r
F
.34765 .48862 m .34888 .48727 L .34674 .48835 L .668 .746 .909 r
F
.34888 .48727 m .34876 .48317 L .34731 .48688 L F
.34731 .48688 m .34542 .48289 L .34565 .48674 L F
.34731 .48688 m .34876 .48317 L .34542 .48289 L F
.34721 .48995 m .34866 .48622 L .34531 .48594 L .668 .747 .91 r
F
.3471 .49304 m .34519 .48904 L .34543 .4929 L .667 .747 .91 r
F
.3485 .49197 m .35016 .49095 L .34755 .4917 L .668 .747 .91 r
F
.34664 .49143 m .34879 .49034 L .34721 .48995 L F
.34785 .48868 m .3481 .48875 L .34821 .48739 L .802 .546 .551 r
F
.34821 .48739 m .3481 .48875 L .34813 .48876 L F
.3491 .48797 m .34875 .48915 L .349 .48931 L .892 .63 .535 r
F
.34813 .48876 m .35024 .48788 L .34775 .48852 L .668 .746 .909 r
F
.34847 .48898 m .3486 .48889 L .34813 .48876 L F
.3486 .48889 m .35024 .48788 L .34813 .48876 L F
.34765 .48862 m .34813 .48876 L .34775 .48852 L F
.34775 .48852 m .35024 .48788 L .34888 .48727 L F
.34879 .49034 m .34866 .48622 L .34721 .48995 L .668 .747 .91 r
F
.3471 .49304 m .34856 .48931 L .34519 .48904 L .667 .747 .91 r
F
.34876 .48317 m .34519 .47903 L .34542 .48289 L .668 .746 .909 r
F
.34866 .48622 m .34507 .48206 L .34531 .48594 L .668 .747 .91 r
F
.34888 .48727 m .3519 .48395 L .34876 .48317 L .668 .746 .909 r
F
.3519 .48395 m .3502 .47944 L .34876 .48317 L F
.34876 .48317 m .3502 .47944 L .34519 .47903 L F
.34866 .48622 m .35012 .48248 L .34507 .48206 L .668 .747 .91 r
F
.34856 .48931 m .34496 .48516 L .34519 .48904 L .667 .747 .91 r
F
.35024 .48788 m .3519 .48395 L .34888 .48727 L .668 .746 .909 r
F
.34979 .48887 m .34928 .48949 L .34964 .49009 L .992 .745 .442 r
F
.3498 .49038 m .34982 .49041 L .34991 .48908 L F
.34979 .49035 m .3498 .49038 L .34991 .48908 L F
.34988 .48963 m .34991 .48908 L .34984 .49043 L 0 0 0 r
F
.34991 .48908 m .34982 .49041 L .34984 .49043 L .992 .745 .442 r
F
.34923 .4894 m .352 .4896 L .3513 .48868 L .668 .746 .909 r
F
.34957 .48999 m .352 .4896 L .34923 .4894 L F
.34874 .48914 m .34923 .4894 L .349 .48901 L F
.34917 .48942 m .34923 .4894 L .34874 .48914 L F
.3486 .48889 m .349 .48901 L .34884 .48874 L F
.34884 .48874 m .3513 .48868 L .35024 .48788 L F
.34923 .4894 m .3513 .48868 L .34884 .48874 L F
.3513 .48868 m .35462 .48518 L .35024 .48788 L F
.35024 .48788 m .35462 .48518 L .3519 .48395 L F
.34879 .49034 m .35182 .487 L .34866 .48622 L .668 .747 .91 r
F
.35182 .487 m .35012 .48248 L .34866 .48622 L F
.34856 .48931 m .35001 .48557 L .34496 .48516 L .667 .747 .91 r
F
.35012 .48248 m .34518 .47897 L .34507 .48206 L .73 .484 .555 r
F
.35001 .48557 m .35012 .48248 L .34507 .48206 L F
.35001 .48557 m .34507 .48206 L .34496 .48516 L F
.34592 .4942 m .34485 .47788 L .34498 .49442 L .642 .738 .919 r
F
.34452 .4945 m .34377 .49303 L .34413 .49462 L .667 .747 .91 r
F
.34453 .49453 m .34455 .4945 L .34452 .4945 L F
.34219 .49056 m .34216 .49041 L .34209 .49056 L .668 .746 .909 r
F
.34234 .49167 m .34235 .49032 L .34105 .49092 L .668 .747 .91 r
F
.34377 .49303 m .34186 .48929 L .3388 .49006 L .667 .747 .91 r
F
.34498 .49442 m .3365 .47808 L .34413 .49462 L .642 .738 .919 r
F
.34594 .49457 m .34663 .49467 L .34593 .49444 L F
.34626 .49451 m .34625 .49462 L .34647 .49453 L .733 .485 .553 r
F
.34607 .49652 m .3461 .49692 L .34655 .49745 L .642 .738 .919 r
F
.34625 .49462 m .34567 .50229 L .34646 .49464 L .733 .485 .553 r
F
.34522 .50442 m .34607 .50234 L .34507 .50221 L .641 .739 .92 r
F
.34567 .50229 m .34584 .50231 L .34646 .49464 L .733 .485 .553 r
F
.34607 .50234 m .34507 .50221 L .34507 .50221 L .641 .739 .92 r
F
.34646 .49464 m .34584 .50231 L .34663 .49467 L .733 .485 .553 r
F
.34522 .50442 m .34633 .50655 L .34696 .5065 L .641 .739 .92 r
F
.34522 .50442 m .34696 .5065 L .34725 .50641 L F
.34522 .50442 m .34536 .50662 L .34633 .50655 L F
.34663 .49467 m .34599 .50233 L .34619 .50236 L .733 .485 .553 r
F
.34739 .49476 m .34664 .49454 L .34619 .50236 L .802 .546 .551 r
F
.34522 .50442 m .347 .50262 L .34608 .50232 L .641 .739 .92 r
F
.34647 .50682 m .34662 .5071 L .34692 .5069 L F
.3464 .50669 m .34641 .50725 L .34662 .5071 L F
.34633 .50655 m .34633 .50672 L .3464 .50669 L F
.3461 .50657 m .34696 .5065 L .34497 .54128 L .644 .409 .547 r
F
.347 .50262 m .34712 .50266 L .34776 .49504 L .802 .546 .551 r
F
.34894 .4956 m .34827 .50334 L .34849 .50349 L .892 .63 .535 r
F
.34883 .49574 m .37682 .49337 L .37339 .48872 L .642 .738 .919 r
F
.3495 .49617 m .37682 .49337 L .34883 .49574 L F
.34875 .49568 m .34813 .50325 L .34884 .49574 L .892 .63 .535 r
F
.34852 .49553 m .34795 .50313 L .34875 .49568 L F
.34795 .50313 m .34813 .50325 L .34875 .49568 L F
.3494 .49557 m .37339 .48872 L .34842 .49525 L .642 .738 .919 r
F
.34852 .49553 m .34777 .49504 L .34733 .50273 L .892 .63 .535 r
F
.34852 .49553 m .34733 .50273 L .34795 .50313 L F
.34929 .49641 m .34892 .4958 L .34849 .50349 L .992 .745 .442 r
F
.34522 .50442 m .34796 .50293 L .347 .50262 L .641 .739 .92 r
F
.34733 .50273 m .3442 .53695 L .34535 .5373 L .802 .546 .551 r
F
.34778 .49487 m .34712 .50266 L .34733 .50273 L F
.34712 .50266 m .3442 .53695 L .34733 .50273 L F
.34762 .49499 m .347 .50262 L .34776 .49504 L F
.34739 .49476 m .34619 .50236 L .3468 .50256 L F
.34584 .50231 m .34599 .50233 L .34663 .49467 L .733 .485 .553 r
F
.34664 .49454 m .34868 .49343 L .34653 .49451 L .667 .747 .91 r
F
.34745 .49478 m .34759 .49463 L .34664 .49454 L F
.34759 .49463 m .34868 .49343 L .34664 .49454 L F
.34653 .49451 m .34759 .49398 L .3471 .49304 L F
.34835 .49207 m .34888 .49216 L .3485 .49197 L .668 .747 .91 r
F
.34917 .49156 m .34901 .49248 L .34911 .49255 L .892 .63 .535 r
F
.34888 .49216 m .34965 .4923 L .34883 .49206 L .668 .747 .91 r
F
.34888 .49216 m .34883 .49206 L .3485 .49197 L F
.34906 .49251 m .34965 .4923 L .34835 .49207 L F
.34908 .49162 m .34901 .49248 L .34917 .49156 L .892 .63 .535 r
F
.3485 .49197 m .35109 .4918 L .35016 .49095 L .668 .747 .91 r
F
.34965 .4923 m .35109 .4918 L .3485 .49197 L F
.34908 .4925 m .3492 .4926 L .34974 .49227 L F
.34906 .49251 m .34911 .49255 L .34908 .4925 L F
.34942 .49308 m .34969 .49304 L .34908 .4925 L F
.35109 .4918 m .35116 .4917 L .35016 .49095 L F
.34957 .48999 m .35227 .49059 L .352 .4896 L .668 .746 .909 r
F
.34993 .49059 m .35227 .49059 L .34957 .48999 L F
.34993 .49059 m .35004 .49077 L .35015 .49059 L F
.352 .4896 m .35674 .48678 L .3513 .48868 L F
.3513 .48868 m .35674 .48678 L .35462 .48518 L F
.35123 .49175 m .35456 .48824 L .35016 .49095 L .668 .747 .91 r
F
.35674 .48678 m .35901 .48247 L .35462 .48518 L .668 .746 .909 r
F
.35016 .49095 m .35182 .487 L .34879 .49034 L .668 .747 .91 r
F
.35016 .49095 m .35456 .48824 L .35182 .487 L F
.35462 .48518 m .35492 .48062 L .3519 .48395 L .668 .746 .909 r
F
.35462 .48518 m .35901 .48247 L .35492 .48062 L F
.3492 .4926 m .34969 .49304 L .3497 .49292 L .668 .747 .91 r
F
.3492 .4926 m .3497 .49292 L .34974 .49227 L F
.34969 .49304 m .35041 .49292 L .34974 .49227 L F
.35041 .49292 m .35192 .49268 L .35109 .4918 L F
.34965 .49367 m .34977 .49367 L .34966 .49349 L F
.34942 .49308 m .34996 .49367 L .35041 .49292 L F
.34977 .49367 m .34996 .49367 L .34942 .49308 L F
.35005 .49404 m .35172 .4901 L .34868 .49343 L .667 .747 .91 r
F
.35109 .4918 m .35123 .49175 L .35116 .4917 L .668 .747 .91 r
F
.35192 .49268 m .3567 .48984 L .35123 .49175 L F
.35123 .49175 m .3567 .48984 L .35456 .48824 L F
.35005 .49404 m .35446 .49133 L .35172 .4901 L .667 .747 .91 r
F
.3519 .48395 m .35492 .48062 L .3502 .47944 L .668 .746 .909 r
F
.34868 .49343 m .34856 .48931 L .3471 .49304 L .667 .747 .91 r
F
.34868 .49343 m .35172 .4901 L .34856 .48931 L F
.35456 .48824 m .35486 .48366 L .35182 .487 L .668 .747 .91 r
F
.35456 .48824 m .35898 .48552 L .35486 .48366 L F
.35898 .48552 m .35908 .48243 L .35497 .48056 L .849 .588 .543 r
F
.35182 .487 m .35486 .48366 L .35012 .48248 L .668 .747 .91 r
F
.3567 .48984 m .35898 .48552 L .35456 .48824 L F
.35446 .49133 m .35476 .48675 L .35172 .4901 L .667 .747 .91 r
F
.35446 .49133 m .35888 .48861 L .35476 .48675 L F
.35898 .48552 m .35497 .48056 L .35486 .48366 L .849 .588 .543 r
F
.35888 .48861 m .35898 .48552 L .35486 .48366 L F
.35486 .48366 m .35497 .48056 L .35023 .47938 L .789 .534 .552 r
F
.35172 .4901 m .35001 .48557 L .34856 .48931 L .667 .747 .91 r
F
.35172 .4901 m .35476 .48675 L .35001 .48557 L F
.35486 .48366 m .35023 .47938 L .35012 .48248 L .789 .534 .552 r
F
.35888 .48861 m .35486 .48366 L .35476 .48675 L .849 .588 .543 r
F
.35476 .48675 m .35486 .48366 L .35012 .48248 L .789 .534 .552 r
F
.35476 .48675 m .35012 .48248 L .35001 .48557 L F
.34682 .49469 m .36121 .48125 L .35328 .47896 L .642 .738 .919 r
F
.34778 .49487 m .34962 .49431 L .34752 .49471 L .667 .747 .91 r
F
.34745 .49478 m .34778 .49487 L .34752 .49471 L F
.34752 .49471 m .34962 .49431 L .34868 .49343 L F
.34962 .49431 m .34965 .49386 L .34868 .49343 L F
.34776 .49482 m .36121 .48125 L .34682 .49469 L .642 .738 .919 r
F
.34738 .49491 m .3468 .50256 L .34759 .49498 L .802 .546 .551 r
F
.3468 .50256 m .34698 .50261 L .34759 .49498 L F
.34876 .49549 m .34875 .49568 L .34886 .49555 L .892 .63 .535 r
F
.34875 .49568 m .34884 .49574 L .34886 .49555 L F
.34852 .49553 m .34875 .49568 L .34876 .49549 L F
.34824 .49535 m .3494 .49557 L .34842 .49525 L .642 .738 .919 r
F
.34894 .4956 m .34894 .4956 L .34824 .49516 L .667 .747 .91 r
F
.34895 .49562 m .34894 .4956 L .34892 .4958 L .992 .745 .442 r
F
.34883 .49574 m .3494 .49557 L .34824 .49535 L .642 .738 .919 r
F
.34759 .49498 m .34698 .50261 L .34761 .49499 L .802 .546 .551 r
F
.34698 .50261 m .347 .50262 L .34762 .49499 L F
.34698 .50261 m .34762 .49499 L .34761 .49499 L F
.34962 .49431 m .35005 .49404 L .34965 .49386 L .667 .747 .91 r
F
.3476 .49498 m .36807 .48459 L .36121 .48125 L .642 .738 .919 r
F
.34762 .49499 m .34776 .49504 L .34778 .49487 L .802 .546 .551 r
F
.34824 .49516 m .34841 .49505 L .34778 .49487 L .667 .747 .91 r
F
.34841 .49505 m .34962 .49431 L .34778 .49487 L F
.34842 .49525 m .36807 .48459 L .3476 .49498 L .642 .738 .919 r
F
.34614 .50217 m .35243 .4869 L .34516 .50202 L .641 .739 .92 r
F
.34567 .50219 m .34516 .50202 L .34507 .50221 L F
.34614 .50217 m .34516 .50202 L .34567 .50219 L F
.347 .50262 m .36726 .49252 L .36038 .48919 L F
.34796 .50293 m .36726 .49252 L .347 .50262 L F
.347 .50262 m .3442 .53695 L .34712 .50266 L .802 .546 .551 r
F
.3468 .50256 m .34619 .50236 L .3442 .53695 L F
.34608 .50232 m .36038 .48919 L .35243 .4869 L .641 .739 .92 r
F
.347 .50262 m .36038 .48919 L .34608 .50232 L F
.34584 .50231 m .34307 .53683 L .34599 .50233 L .733 .485 .553 r
F
.34607 .50234 m .34614 .50217 L .34507 .50221 L .641 .739 .92 r
F
.34619 .50236 m .34307 .53683 L .3442 .53695 L .733 .485 .553 r
F
.34599 .50233 m .34307 .53683 L .34619 .50236 L F
.34567 .50229 m .34307 .53683 L .34584 .50231 L F
.34681 .49472 m .34776 .49482 L .34682 .49469 L .642 .738 .919 r
F
.34763 .49483 m .34762 .49499 L .34778 .49487 L .802 .546 .551 r
F
.3476 .49498 m .34776 .49482 L .34681 .49472 L .642 .738 .919 r
F
.34652 .49453 m .34664 .49454 L .34653 .49451 L .667 .747 .91 r
F
.34664 .49454 m .34646 .49464 L .34663 .49467 L .733 .485 .553 r
F
.34647 .49453 m .34646 .49464 L .34664 .49454 L F
.35012 .48248 m .35023 .47938 L .34518 .47897 L .73 .484 .555 r
F
.34593 .49444 m .35328 .47896 L .34485 .47788 L .642 .738 .919 r
F
.34681 .49472 m .35328 .47896 L .34593 .49444 L F
.34551 .49452 m .34194 .53691 L .34552 .49452 L .663 .424 .548 r
F
.34507 .50221 m .35243 .4869 L .34398 .48582 L .641 .739 .92 r
F
.34408 .50224 m .34507 .50221 L .34398 .50206 L F
.34507 .50221 m .34507 .50221 L .34408 .50224 L F
.34413 .49462 m .3365 .47808 L .33093 .47915 L .642 .738 .919 r
F
.34413 .49462 m .33093 .47915 L .34413 .49461 L F
.34403 .49465 m .34345 .50236 L .34424 .49459 L .57 .346 .536 r
F
.34345 .50236 m .34083 .53722 L .34362 .50232 L F
.34345 .50236 m .34362 .50232 L .34424 .49459 L F
.34447 .50213 m .34398 .48582 L .34398 .50206 L .641 .739 .92 r
F
.34507 .50221 m .34505 .50199 L .34447 .50213 L F
.34505 .50199 m .34398 .48582 L .34447 .50213 L F
.34398 .50206 m .34398 .48582 L .33561 .48602 L F
.34567 .50229 m .34507 .50221 L .34307 .53683 L .733 .485 .553 r
F
.34473 .50222 m .34194 .53691 L .34475 .50222 L .663 .424 .548 r
F
.34408 .50224 m .34407 .50222 L .34396 .50224 L .641 .739 .92 r
F
.34408 .50224 m .34396 .50224 L .34318 .50242 L F
.34407 .50222 m .33561 .48602 L .34318 .50242 L F
.34376 .50229 m .34083 .53722 L .34376 .50229 L .57 .346 .536 r
F
.34396 .50224 m .34083 .53722 L .34194 .53691 L F
.34376 .50229 m .34083 .53722 L .34396 .50224 L F
.34237 .5028 m .33975 .53794 L .34254 .5027 L .385 .194 .495 r
F
.32889 .49006 m .32235 .48218 L .31754 .48579 L .642 .738 .919 r
F
.32853 .49092 m .32856 .49031 L .32819 .49086 L .012 0 .379 r
F
.32852 .49036 m .31754 .48579 L .32701 .49262 L .642 .738 .919 r
F
.34245 .50275 m .32792 .48748 L .32143 .49011 L .641 .739 .92 r
F
.34311 .50235 m .32792 .48748 L .34245 .50275 L F
.34245 .50275 m .34226 .50264 L .3418 .50314 L F
.34254 .5027 m .33975 .53794 L .34256 .50268 L .385 .194 .495 r
F
.34365 .50232 m .34083 .53722 L .34376 .50229 L .57 .346 .536 r
F
.34115 .5029 m .34172 .50232 L .33978 .50238 L .641 .739 .92 r
F
.34226 .50264 m .34172 .50232 L .34115 .5029 L F
.34172 .50232 m .32143 .49011 L .33978 .50238 L F
.34475 .50222 m .34194 .53691 L .34487 .50221 L .663 .424 .548 r
F
.34261 .50265 m .33975 .53794 L .34267 .50261 L .385 .194 .495 r
F
.34108 .50357 m .34115 .5029 L .33956 .50326 L .641 .739 .92 r
F
.3418 .50314 m .34115 .5029 L .34108 .50357 L F
.34115 .5029 m .31661 .4937 L .33956 .50326 L F
.34362 .50232 m .34083 .53722 L .34365 .50232 L .57 .346 .536 r
F
.34345 .50236 m .34287 .5025 L .34083 .53722 L F
.33374 .50208 m .31376 .49801 L .33838 .50406 L .641 .739 .92 r
F
.34034 .50416 m .31308 .50273 L .34124 .50482 L F
.34237 .5028 m .3418 .50314 L .33975 .53794 L .385 .194 .495 r
F
.33472 .5074 m .31458 .50753 L .31815 .5121 L .641 .739 .92 r
F
.33754 .5057 m .31458 .50753 L .33472 .5074 L F
.34172 .50329 m .3395 .53845 L .34175 .50323 L 0 0 .29 r
F
.3418 .50314 m .3395 .53845 L .34133 .51113 L F
.34175 .50323 m .3395 .53845 L .3418 .50314 L F
.34048 .50576 m .33472 .5074 L .34021 .50631 L .641 .739 .92 r
F
.33472 .5074 m .31815 .5121 L .3334 .50819 L F
.34287 .5025 m .33975 .53794 L .34083 .53722 L .385 .194 .495 r
F
.34267 .50261 m .33975 .53794 L .34287 .5025 L F
.34013 .50646 m .3334 .50819 L .33965 .50742 L .641 .739 .92 r
F
.34038 .52275 m .33943 .53962 L .34031 .52384 L .923 .74 .252 r
F
.34038 .52275 m .34031 .52384 L .3414 .50424 L F
.34142 .50434 m .34038 .52275 L .3414 .50424 L F
.34142 .50434 m .34149 .50473 L .33943 .53962 L F
.3414 .50424 m .33943 .53962 L .34138 .50415 L F
.34136 .50402 m .33943 .53962 L .3393 .53888 L F
.34138 .50415 m .33943 .53962 L .34136 .50402 L F
.34166 .50341 m .3393 .53888 L .34169 .50336 L 0 0 .29 r
F
.34256 .50268 m .33975 .53794 L .34261 .50265 L .385 .194 .495 r
F
.3334 .50819 m .31815 .5121 L .32205 .51501 L .641 .739 .92 r
F
.3334 .50819 m .32205 .51501 L .32353 .51612 L F
.34172 .50329 m .3393 .53888 L .3395 .53845 L 0 0 .29 r
F
.34169 .50336 m .3393 .53888 L .34172 .50329 L F
.34159 .50355 m .3393 .53888 L .34166 .50341 L F
.33703 .51264 m .32353 .51612 L .33036 .51934 L .641 .739 .92 r
F
.33907 .50858 m .32353 .51612 L .33703 .51264 L F
.34159 .50355 m .34136 .50402 L .3393 .53888 L 0 0 .29 r
F
.3468 .50256 m .3442 .53695 L .34698 .50261 L .802 .546 .551 r
F
.34849 .50349 m .34535 .5373 L .34653 .53805 L .892 .63 .535 r
F
.34827 .50334 m .34535 .5373 L .34849 .50349 L F
.34849 .50349 m .354 .50192 L .34811 .50286 L .641 .739 .92 r
F
.34849 .50349 m .34849 .50349 L .34849 .50349 L F
.34849 .50349 m .354 .50192 L .34849 .50349 L F
.34813 .50325 m .34535 .5373 L .34821 .5033 L .892 .63 .535 r
F
.34779 .50303 m .3482 .50301 L .34796 .50293 L .641 .739 .92 r
F
.34795 .50313 m .3482 .50301 L .34779 .50303 L F
.34795 .50313 m .34849 .50349 L .3482 .50301 L F
.34795 .50313 m .34535 .5373 L .34813 .50325 L .892 .63 .535 r
F
.34698 .50261 m .3442 .53695 L .347 .50262 L .802 .546 .551 r
F
.34796 .50293 m .3482 .50301 L .34811 .50286 L .641 .739 .92 r
F
.34795 .50313 m .34733 .50273 L .34535 .5373 L .892 .63 .535 r
F
.34928 .504 m .36271 .50534 L .37603 .50128 L .641 .739 .92 r
F
.35033 .50469 m .36271 .50534 L .34928 .504 L F
.36271 .50534 m .37735 .50611 L .37686 .50429 L F
.36271 .50534 m .37686 .50429 L .37603 .50128 L F
.34917 .50463 m .34946 .50511 L .35008 .50467 L F
.34863 .50569 m .34705 .53974 L .34666 .54036 L 0 0 .355 r
F
.3487 .50559 m .34705 .53974 L .34863 .50569 L F
.34879 .50398 m .34849 .50349 L .34653 .53805 L .992 .745 .442 r
F
.3488 .50543 m .34901 .50512 L .34705 .53974 L 0 0 .355 r
F
.34875 .50551 m .34705 .53974 L .3487 .50559 L F
.3488 .50543 m .34705 .53974 L .34875 .50551 L F
.34887 .50413 m .34653 .53805 L .34894 .50424 L .992 .745 .442 r
F
.34811 .50286 m .354 .50192 L .36726 .49252 L .641 .739 .92 r
F
.354 .50192 m .37259 .49665 L .36733 .49257 L F
.354 .50192 m .36733 .49257 L .36726 .49252 L F
.34927 .50524 m .37648 .51079 L .35008 .50467 L F
.34902 .50479 m .34905 .50441 L .34709 .539 L 0 0 0 r
F
.34902 .5049 m .34709 .539 L .34901 .50499 L F
.34901 .50512 m .34709 .539 L .34705 .53974 L F
.34901 .50499 m .34709 .539 L .34901 .50512 L F
.34902 .50479 m .34709 .539 L .34902 .5049 L F
.34905 .50441 m .34653 .53805 L .34709 .539 L .992 .745 .442 r
F
.34894 .50424 m .34653 .53805 L .34905 .50441 L F
.35122 .50803 m .36218 .52102 L .36862 .5185 L .641 .739 .92 r
F
.35454 .51354 m .36218 .52102 L .35122 .50803 L F
.34879 .50398 m .34653 .53805 L .34887 .50413 L .992 .745 .442 r
F
.35454 .51354 m .35935 .52154 L .36218 .52102 L .641 .739 .92 r
F
.34133 .51113 m .3395 .53845 L .33975 .53794 L 0 0 .29 r
F
.417 .63738 m .40403 .62699 L .38846 .6333 L .654 .782 .942 r
F
.42915 .63462 m .40403 .62699 L .417 .63738 L F
.5368 .62754 m .54801 .62873 L .54837 .63497 L .922 .656 .516 r
F
.5368 .62754 m .53646 .62128 L .54801 .62873 L F
0 g
.54801 .62873 m
.5555 .63144 L
s
.45417 .75564 m .46755 .7606 L .47366 .75678 L .656 .809 .957 r
F
.45021 .75722 m .46755 .7606 L .45417 .75564 L F
.55927 .61437 m .54829 .6286 L .56688 .61937 L .654 .782 .942 r
F
.55927 .61437 m .5368 .62118 L .54829 .6286 L F
.60556 .61549 m .60298 .62567 L .61496 .6246 L F
.60618 .61303 m .61496 .6246 L .60991 .6127 L F
.60329 .61329 m .60556 .61549 L .60618 .61303 L F
.60556 .61549 m .61496 .6246 L .60618 .61303 L F
.60828 .57004 m .60844 .56932 L .60926 .6009 L 0 0 .235 r
F
.60329 .61329 m .60298 .62567 L .60556 .61549 L .654 .782 .942 r
F
.60373 .61962 m .60238 .63109 L .61547 .63095 L .654 .783 .943 r
F
.60238 .63109 m .60226 .63212 L .60241 .63211 L F
.60238 .63109 m .60241 .63211 L .61547 .63095 L F
.60281 .57147 m .60439 .5717 L .60517 .60311 L .749 .498 .552 r
F
.60118 .57053 m .60183 .57105 L .60258 .60265 L .925 .648 .496 r
F
.6042 .6055 m .60168 .60538 L .60329 .61329 L .654 .782 .942 r
F
.60439 .60383 m .60343 .60438 L .6042 .6055 L F
.60343 .60438 m .60168 .60538 L .6042 .6055 L F
.60083 .56992 m .60118 .57053 L .60193 .60222 L .988 .718 .377 r
F
.60403 .60359 m .60328 .60416 L .60439 .60383 L .654 .782 .942 r
F
.60328 .60416 m .60168 .60538 L .60343 .60438 L F
.60328 .60416 m .60343 .60438 L .60439 .60383 L F
.6043 .60321 m .60392 .60352 L .60446 .60326 L F
.60392 .60352 m .60168 .60538 L .60403 .60359 L F
.60392 .60352 m .60403 .60359 L .60446 .60326 L F
.60325 .60294 m .60168 .60538 L .6043 .60321 L F
.60357 .60297 m .6043 .60321 L .60449 .60305 L F
.60325 .60294 m .6043 .60321 L .60357 .60297 L F
.60168 .60538 m .6019 .61323 L .60329 .61329 L F
.60329 .61329 m .60218 .62284 L .60298 .62567 L F
.60218 .62284 m .60183 .62577 L .60226 .62573 L F
.60218 .62284 m .60226 .62573 L .60298 .62567 L F
.60168 .60538 m .59676 .61302 L .6019 .61323 L F
.59676 .61302 m .60183 .62577 L .60329 .61329 L F
.59676 .61302 m .5889 .62525 L .60183 .62577 L F
.59716 .61935 m .60226 .63212 L .60373 .61962 L .654 .783 .943 r
F
.59716 .61935 m .58924 .63161 L .60226 .63212 L F
.5976 .62564 m .6027 .63837 L .60418 .62591 L .653 .784 .944 r
F
.60183 .57105 m .60306 .6028 L .60258 .60265 L .84 .573 .536 r
F
.60118 .57053 m .60258 .60265 L .60225 .60243 L .925 .648 .496 r
F
.60183 .57105 m .60281 .57147 L .60357 .60297 L .84 .573 .536 r
F
.60183 .57105 m .60357 .60297 L .60306 .6028 L F
.60281 .57147 m .60517 .60311 L .60434 .60304 L .749 .498 .552 r
F
.60081 .5692 m .60157 .60161 L .60157 .60138 L .712 .567 0 r
F
.60081 .5692 m .60157 .60138 L .60156 .60108 L F
.60118 .57053 m .60225 .60243 L .60193 .60222 L .925 .648 .496 r
F
.60083 .56992 m .60175 .60195 L .60157 .6017 L .988 .718 .377 r
F
.60083 .56992 m .60193 .60222 L .60175 .60195 L F
.60081 .5692 m .60083 .56992 L .60157 .6017 L .712 .567 0 r
F
.60081 .5692 m .60157 .6017 L .60157 .60161 L F
.60139 .5683 m .60081 .5692 L .60156 .60108 L .07 0 .435 r
F
.60168 .60538 m .59586 .60886 L .59676 .61302 L .654 .782 .942 r
F
.60325 .60294 m .60162 .60313 L .60168 .60538 L F
.60281 .57147 m .60434 .60304 L .60357 .60297 L .749 .498 .552 r
F
.60478 .60057 m .60198 .60283 L .60325 .60294 L .654 .782 .942 r
F
.60198 .60283 m .60162 .60313 L .60325 .60294 L F
.60373 .61962 m .61547 .63095 L .6104 .61902 L .654 .783 .943 r
F
.60418 .62591 m .6027 .63837 L .61594 .6372 L .653 .784 .944 r
F
.60418 .62591 m .61594 .6372 L .61086 .62531 L F
.60645 .60451 m .60329 .61329 L .60991 .6127 L .654 .782 .942 r
F
.60601 .57152 m .60732 .60272 L .6068 .60289 L .539 .333 .549 r
F
.60439 .5717 m .60595 .60301 L .60517 .60311 L .648 .418 .556 r
F
.60707 .57113 m .60781 .57064 L .60862 .60206 L .402 .228 .528 r
F
.6076 .60322 m .60991 .6127 L .61486 .61158 L .654 .782 .942 r
F
.6076 .60322 m .61486 .61158 L .61326 .60853 L F
.6074 .60343 m .60991 .6127 L .6076 .60322 L F
.60722 .60292 m .60991 .6127 L .60726 .6029 L F
.6068 .60289 m .60991 .6127 L .6072 .60284 L F
.60582 .60302 m .6059 .60321 L .6068 .60289 L F
.6059 .60321 m .60991 .6127 L .6068 .60289 L F
.60601 .57152 m .60707 .57113 L .60787 .60252 L .539 .333 .549 r
F
.60726 .6029 m .6074 .60343 L .6076 .60322 L .654 .782 .942 r
F
.60601 .57152 m .60787 .60252 L .60732 .60272 L .539 .333 .549 r
F
.60439 .5717 m .60601 .57152 L .6068 .60289 L .648 .418 .556 r
F
.60439 .5717 m .6068 .60289 L .60595 .60301 L F
.60707 .57113 m .60823 .6023 L .60787 .60252 L .402 .228 .528 r
F
.61064 .60354 m .6162 .61128 L .62172 .60914 L .654 .782 .942 r
F
.60478 .60057 m .61326 .60853 L .61064 .60354 L F
.61326 .60853 m .6162 .61128 L .61064 .60354 L F
.60781 .57064 m .60828 .57004 L .6091 .60153 L .163 .05 .467 r
F
.60781 .57064 m .6091 .60153 L .60885 .60181 L F
.60828 .57004 m .60926 .6009 L .60918 .60123 L 0 0 .235 r
F
.60828 .57004 m .60918 .60123 L .6091 .60153 L F
.60844 .56932 m .60803 .5684 L .60885 .60012 L .978 .72 .315 r
F
.60707 .57113 m .60862 .60206 L .60823 .6023 L .402 .228 .528 r
F
.60781 .57064 m .60885 .60181 L .60862 .60206 L .163 .05 .467 r
F
.60478 .60057 m .62172 .60914 L .62322 .60822 L .654 .782 .942 r
F
.61425 .60316 m .62322 .60822 L .62611 .60642 L F
.60478 .60057 m .62322 .60822 L .61425 .60316 L F
.60885 .60181 m .60889 .60176 L .60903 .60711 L .163 .05 .467 r
F
.60823 .6023 m .60862 .60206 L .60878 .60806 L .402 .228 .528 r
F
.60672 .61037 m .60373 .61962 L .6104 .61902 L .654 .783 .943 r
F
.60636 .60954 m .60591 .61128 L .60672 .61037 L F
.60591 .61128 m .60373 .61962 L .60672 .61037 L F
.61084 .60124 m .62611 .60642 L .62908 .60328 L .654 .782 .942 r
F
.60478 .60057 m .61425 .60316 L .61084 .60124 L F
.61425 .60316 m .62611 .60642 L .61084 .60124 L F
.60803 .5684 m .60699 .56768 L .6078 .59953 L .906 .63 .507 r
F
.60823 .6023 m .60878 .60806 L .60845 .60826 L .402 .228 .528 r
F
.60991 .6127 m .61496 .6246 L .62743 .62182 L .654 .782 .942 r
F
.60991 .6127 m .62743 .62182 L .6162 .61128 L F
.60856 .61024 m .6104 .61902 L .61523 .61794 L .654 .783 .943 r
F
.60771 .60926 m .60828 .61134 L .60856 .61024 L F
.60828 .61134 m .6104 .61902 L .60856 .61024 L F
.60844 .56932 m .60885 .60012 L .60906 .60053 L .978 .72 .315 r
F
.60844 .56932 m .60906 .60053 L .60926 .6009 L F
.6116 .6004 m .62908 .60328 L .6304 .59994 L .654 .782 .942 r
F
.60478 .60057 m .61955 .60222 L .6116 .6004 L F
.61955 .60222 m .62908 .60328 L .6116 .6004 L F
.60756 .60943 m .60821 .61163 L .60771 .60926 L .654 .783 .943 r
F
.60821 .61163 m .6104 .61902 L .60828 .61134 L F
.60821 .61163 m .60828 .61134 L .60771 .60926 L F
.60918 .60123 m .60935 .60717 L .6091 .60153 L 0 0 .235 r
F
.60862 .61004 m .61523 .61794 L .61344 .61454 L .654 .783 .943 r
F
.60858 .61019 m .61523 .61794 L .60862 .61004 L F
.60771 .60926 m .61523 .61794 L .60774 .60922 L F
.60636 .60954 m .6104 .61902 L .6074 .6089 L F
.60787 .60252 m .60816 .60844 L .60803 .60852 L .402 .228 .528 r
F
.60831 .60842 m .6128 .61332 L .6109 .60973 L .654 .783 .943 r
F
.60823 .6023 m .60845 .60826 L .60787 .60252 L .402 .228 .528 r
F
.60803 .60852 m .61344 .61454 L .60831 .60842 L .654 .783 .943 r
F
.6074 .6089 m .61344 .61454 L .60803 .60852 L F
.61344 .61454 m .6128 .61332 L .60831 .60842 L F
.60774 .60922 m .60858 .61019 L .60862 .61004 L F
.60845 .60826 m .60816 .60844 L .60787 .60252 L .402 .228 .528 r
F
.60732 .60272 m .60787 .60252 L .60803 .60852 L .539 .333 .549 r
F
.60732 .60272 m .60803 .60852 L .60756 .60868 L F
.60905 .60776 m .60886 .60797 L .60862 .60206 L .163 .05 .467 r
F
.60862 .60206 m .60886 .60797 L .60878 .60806 L F
.61326 .60853 m .61486 .61158 L .6162 .61128 L .654 .782 .942 r
F
.60607 .60363 m .60551 .60556 L .60645 .60451 L F
.60551 .60556 m .60329 .61329 L .60645 .60451 L F
.60573 .60383 m .60329 .61329 L .60607 .60363 L F
.60595 .60301 m .6068 .60289 L .60696 .60889 L .648 .418 .556 r
F
.60665 .61547 m .60418 .62591 L .6063 .62572 L .653 .784 .944 r
F
.60807 .61879 m .6063 .62572 L .61086 .62531 L F
.60665 .61547 m .6063 .62572 L .60807 .61879 L F
.60576 .60326 m .60329 .61329 L .6059 .60321 L .654 .782 .942 r
F
.60447 .6032 m .60329 .61329 L .60582 .60302 L F
.60449 .60305 m .6043 .60321 L .60446 .60326 L F
.60434 .60304 m .60517 .60311 L .60532 .60911 L .749 .498 .552 r
F
.60595 .60301 m .60696 .60889 L .60625 .60899 L .648 .418 .556 r
F
.6068 .60289 m .60714 .60883 L .60696 .60889 L .539 .333 .549 r
F
.60727 .60878 m .60636 .60954 L .6074 .6089 L .654 .783 .943 r
F
.60756 .60868 m .60714 .60883 L .6068 .60289 L .539 .333 .549 r
F
.60655 .61522 m .60532 .61628 L .60665 .61547 L .653 .784 .944 r
F
.60628 .6152 m .60532 .61628 L .60655 .61522 L F
.60546 .61513 m .60532 .61628 L .60645 .615 L F
.60532 .61628 m .60418 .62591 L .60665 .61547 L F
.60517 .60311 m .6056 .60907 L .60532 .60911 L .648 .418 .556 r
F
.60434 .60304 m .60532 .60911 L .6049 .60907 L .749 .498 .552 r
F
.60621 .60919 m .60481 .61048 L .60636 .60954 L .654 .783 .943 r
F
.6059 .60321 m .60573 .60383 L .60607 .60363 L .654 .782 .942 r
F
.60582 .60302 m .60576 .60326 L .6059 .60321 L F
.60595 .60301 m .60625 .60899 L .60517 .60311 L .648 .418 .556 r
F
.60613 .609 m .60532 .60911 L .60621 .60919 L .654 .783 .943 r
F
.60497 .60908 m .60481 .61048 L .60621 .60919 L F
.60613 .609 m .6062 .60916 L .60696 .60889 L F
.6062 .60916 m .60636 .60954 L .60727 .60878 L F
.60645 .615 m .60628 .6152 L .60655 .61522 L .653 .784 .944 r
F
.60481 .61048 m .60373 .61962 L .60629 .60981 L .654 .783 .943 r
F
.60605 .60973 m .60629 .60981 L .60636 .60954 L F
.60481 .61048 m .60629 .60981 L .60605 .60973 L F
.60306 .6028 m .60357 .60297 L .60372 .60897 L .84 .573 .536 r
F
.60434 .60304 m .6049 .60907 L .60463 .60905 L .749 .498 .552 r
F
.60187 .61316 m .59716 .61935 L .60205 .61955 L .654 .783 .943 r
F
.60385 .60901 m .60368 .60927 L .60474 .6093 L F
.60326 .60992 m .60184 .61211 L .6036 .61041 L F
.60184 .61211 m .59716 .61935 L .60187 .61316 L F
.59779 .60622 m .58571 .61003 L .59077 .61191 L .654 .782 .942 r
F
.60478 .60057 m .60031 .60278 L .59779 .60622 L F
.60031 .60278 m .58571 .61003 L .59779 .60622 L F
.60225 .60243 m .60245 .60847 L .60193 .60222 L .925 .648 .496 r
F
.60184 .61211 m .60187 .61316 L .60377 .61066 L .654 .783 .943 r
F
.60365 .61049 m .60377 .61066 L .60445 .60977 L F
.60184 .61211 m .60377 .61066 L .60365 .61049 L F
.60478 .60057 m .59758 .60275 L .58571 .61003 L .654 .782 .942 r
F
.59758 .60275 m .58192 .6075 L .585 .60955 L F
.59758 .60275 m .585 .60955 L .58571 .61003 L F
.60256 .56761 m .60139 .5683 L .60215 .60028 L .438 .255 .533 r
F
.60361 .61043 m .60445 .60977 L .60437 .60972 L .654 .783 .943 r
F
.60184 .61211 m .60365 .61049 L .60361 .61043 L F
.60365 .61049 m .60445 .60977 L .60361 .61043 L F
.60175 .60195 m .60193 .60222 L .60207 .60822 L .988 .718 .377 r
F
.60433 .6097 m .60479 .60932 L .60474 .6093 L .654 .783 .943 r
F
.60184 .61211 m .60437 .60972 L .60433 .6097 L F
.60437 .60972 m .60479 .60932 L .60433 .6097 L F
.60225 .60243 m .60258 .60265 L .60273 .60865 L .925 .648 .496 r
F
.60497 .60908 m .60187 .61316 L .60373 .61962 L .654 .783 .943 r
F
.60187 .61316 m .60205 .61955 L .60373 .61962 L F
.60306 .6028 m .60329 .60883 L .60258 .60265 L .84 .573 .536 r
F
.60329 .60883 m .6029 .6087 L .60258 .60265 L F
.60357 .60297 m .604 .60899 L .60372 .60897 L .749 .498 .552 r
F
.60306 .6028 m .60372 .60897 L .60329 .60883 L .84 .573 .536 r
F
.60446 .60326 m .60403 .60359 L .60439 .60383 L .654 .782 .942 r
F
.60434 .60304 m .60463 .60905 L .60357 .60297 L .749 .498 .552 r
F
.60437 .60972 m .60445 .60977 L .60479 .60932 L .654 .783 .943 r
F
.60368 .60927 m .60326 .60992 L .60433 .6097 L F
.60326 .60992 m .6036 .61041 L .60433 .6097 L F
.60368 .60927 m .60433 .6097 L .60474 .6093 L F
.60387 .60898 m .60385 .60901 L .60497 .60908 L F
.60385 .60901 m .60474 .6093 L .60497 .60908 L F
.60387 .60898 m .59694 .61356 L .59716 .61935 L F
.60274 .60888 m .59694 .61356 L .60387 .60898 L F
.60463 .60905 m .604 .60899 L .60357 .60297 L .749 .498 .552 r
F
.60225 .60243 m .60273 .60865 L .60245 .60847 L .925 .648 .496 r
F
.59077 .61191 m .5889 .62525 L .59676 .61302 L .654 .782 .942 r
F
.59077 .61191 m .57699 .62307 L .5889 .62525 L F
.59694 .61356 m .58604 .61636 L .59113 .61824 L .654 .783 .943 r
F
.60245 .60847 m .60219 .6083 L .60193 .60222 L .925 .648 .496 r
F
.60258 .60265 m .6029 .6087 L .60273 .60865 L .84 .573 .536 r
F
.60523 .60687 m .59993 .60949 L .59694 .61356 L .654 .783 .943 r
F
.59586 .60886 m .59329 .61237 L .59676 .61302 L .654 .782 .942 r
F
.59993 .60949 m .58604 .61636 L .59694 .61356 L .654 .783 .943 r
F
.60193 .60222 m .60219 .6083 L .60207 .60822 L .925 .648 .496 r
F
.60139 .5683 m .60156 .60108 L .60186 .60067 L .07 0 .435 r
F
.59758 .60275 m .57968 .60448 L .58192 .6075 L .654 .782 .942 r
F
.60478 .60057 m .60033 .60126 L .59758 .60275 L F
.60033 .60126 m .57968 .60448 L .59758 .60275 L F
.60508 .61834 m .5976 .62564 L .60418 .62591 L .653 .784 .944 r
F
.60532 .61626 m .6044 .61738 L .60508 .61834 L F
.6044 .61738 m .5976 .62564 L .60508 .61834 L F
.60175 .60195 m .60207 .60822 L .60192 .608 L .988 .718 .377 r
F
.60175 .60195 m .60192 .608 L .60157 .6017 L F
.60192 .608 m .60178 .6078 L .60157 .6017 L F
.60162 .60313 m .59077 .61191 L .60168 .60538 L .654 .782 .942 r
F
.60157 .6017 m .60178 .6078 L .60172 .60771 L .988 .718 .377 r
F
.60157 .60138 m .60171 .60744 L .60156 .60108 L .712 .567 0 r
F
.60171 .60744 m .6017 .6072 L .60156 .60108 L F
.60156 .60108 m .6017 .6072 L .6017 .60709 L F
.60157 .60138 m .60172 .60771 L .60171 .60744 L F
.60157 .60161 m .60172 .60771 L .60157 .60138 L F
.60157 .60161 m .60157 .6017 L .60172 .60771 L F
.60139 .5683 m .60186 .60067 L .60215 .60028 L .07 0 .435 r
F
.59237 .6025 m .57913 .60119 L .57968 .60448 L .654 .782 .942 r
F
.60478 .60057 m .59926 .6007 L .59237 .6025 L F
.59926 .6007 m .57913 .60119 L .59237 .6025 L F
.6037 .56731 m .60256 .56761 L .60333 .59964 L .583 .366 .552 r
F
.60523 .60687 m .60089 .60818 L .59993 .60949 L .654 .783 .943 r
F
.60484 .61595 m .6041 .61694 L .60532 .61626 L .653 .784 .944 r
F
.6041 .61694 m .5976 .62564 L .6044 .61738 L F
.6041 .61694 m .6044 .61738 L .60532 .61626 L F
.60256 .56761 m .60215 .60028 L .60275 .59995 L .438 .255 .533 r
F
.59926 .6007 m .58033 .59784 L .57913 .60119 L .654 .782 .942 r
F
.60478 .60057 m .60127 .60018 L .59926 .6007 L F
.60127 .60018 m .58033 .59784 L .59926 .6007 L F
.60523 .60687 m .59956 .60776 L .59605 .60965 L .654 .783 .943 r
F
.60546 .61513 m .60484 .61595 L .60532 .61626 L .653 .784 .944 r
F
.60463 .60905 m .60492 .61508 L .604 .60899 L .749 .498 .552 r
F
.60492 .61508 m .60442 .61504 L .604 .60899 L F
.60463 .60905 m .60547 .61513 L .60492 .61508 L F
.60474 .6093 m .60479 .60932 L .60497 .60908 L .654 .783 .943 r
F
.6049 .60907 m .60547 .61513 L .60463 .60905 L .749 .498 .552 r
F
.60547 .61513 m .60768 .6378 L .60603 .63798 L .648 .418 .556 r
F
.60532 .60911 m .60581 .61509 L .60547 .61513 L F
.60581 .61509 m .60768 .6378 L .60547 .61513 L F
.60192 .608 m .6021 .61407 L .60178 .6078 L .988 .718 .377 r
F
.6021 .61407 m .60198 .61391 L .60178 .6078 L F
.59113 .61824 m .58924 .63161 L .59716 .61935 L .654 .783 .943 r
F
.60366 .61632 m .59552 .62167 L .5976 .62564 L .653 .784 .944 r
F
.60341 .61595 m .60195 .61701 L .60366 .61632 L F
.60195 .61701 m .59552 .62167 L .60196 .61743 L F
.60195 .61701 m .60196 .61743 L .60366 .61632 L F
.60171 .60744 m .60172 .60771 L .60186 .61373 L .712 .567 0 r
F
.60178 .6078 m .60198 .61391 L .60172 .60771 L .988 .718 .377 r
F
.60286 .61547 m .60193 .61622 L .60341 .61595 L .653 .784 .944 r
F
.60193 .61622 m .59156 .62454 L .60195 .61701 L F
.60193 .61622 m .60195 .61701 L .60341 .61595 L F
.58192 .6075 m .56688 .61937 L .58571 .61003 L .654 .782 .942 r
F
.58192 .6075 m .55927 .61437 L .56688 .61937 L F
.57968 .60448 m .55927 .61437 L .58192 .6075 L F
.58917 .60937 m .57941 .60751 L .57996 .61081 L .654 .783 .943 r
F
.60186 .60067 m .60156 .60108 L .6017 .60709 L .07 0 .435 r
F
.60186 .60067 m .6017 .60709 L .60195 .60675 L F
.59873 .59989 m .58321 .59466 L .58033 .59784 L .654 .782 .942 r
F
.60478 .60057 m .60138 .59964 L .59873 .59989 L F
.60138 .59964 m .58321 .59466 L .59873 .59989 L F
.60481 .56723 m .6037 .56731 L .60448 .59934 L .665 .431 .556 r
F
.60523 .60687 m .60101 .60698 L .59956 .60776 L .654 .783 .943 r
F
.60441 .61517 m .60286 .61547 L .60434 .61528 L .653 .784 .944 r
F
.60386 .61499 m .60286 .61547 L .60441 .61517 L F
.60357 .6149 m .6035 .61496 L .60386 .61499 L F
.6035 .61496 m .60286 .61547 L .60386 .61499 L F
.604 .60899 m .60442 .61504 L .60372 .60897 L .749 .498 .552 r
F
.60449 .61505 m .60386 .61499 L .60441 .61517 L .653 .784 .944 r
F
.60434 .61528 m .60341 .61595 L .60366 .61632 L F
.60449 .61505 m .60418 .61552 L .60546 .61513 L F
.6017 .6072 m .60185 .61333 L .6017 .60709 L .712 .567 0 r
F
.602 .61887 m .5976 .62564 L .60203 .61972 L .653 .784 .944 r
F
.60442 .61504 m .6042 .61502 L .60372 .60897 L .749 .498 .552 r
F
.60372 .60897 m .6042 .61502 L .60386 .61499 L F
.60523 .60687 m .60274 .60888 L .60387 .60898 L .654 .783 .943 r
F
.60329 .60883 m .60353 .61488 L .6029 .6087 L .84 .573 .536 r
F
.60353 .61488 m .60322 .61478 L .6029 .6087 L F
.59113 .61824 m .57725 .62943 L .58924 .63161 L .654 .783 .943 r
F
.59608 .62091 m .58646 .62266 L .59156 .62454 L .653 .784 .944 r
F
.60245 .60847 m .60273 .60865 L .60287 .61467 L .925 .648 .496 r
F
.60245 .60847 m .60287 .61467 L .60265 .61453 L F
.60234 .60839 m .60256 .61447 L .60219 .6083 L F
.60193 .61622 m .59954 .61622 L .59608 .62091 L .653 .784 .944 r
F
.60342 .61502 m .60191 .61549 L .60193 .61622 L F
.60191 .61549 m .59954 .61622 L .60193 .61622 L F
.60287 .61467 m .59954 .61622 L .60342 .61502 L F
.6028 .61462 m .60277 .61464 L .60287 .61467 L F
.60277 .61464 m .59954 .61622 L .60287 .61467 L F
.60418 .61552 m .602 .61887 L .60484 .61595 L F
.602 .61887 m .60203 .61972 L .60484 .61595 L F
.60286 .61547 m .60341 .61595 L .60307 .61547 L F
.60286 .61547 m .60409 .61546 L .60389 .61534 L F
.60287 .61467 m .60441 .63775 L .60341 .63735 L .84 .573 .536 r
F
.60273 .60865 m .60308 .61474 L .60287 .61467 L F
.60307 .61547 m .60341 .61595 L .60409 .61546 L .653 .784 .944 r
F
.60308 .61474 m .60441 .63775 L .60287 .61467 L .84 .573 .536 r
F
.60256 .61447 m .60244 .61439 L .60219 .6083 L .925 .648 .496 r
F
.60259 .61449 m .60256 .61447 L .60234 .60839 L F
.60245 .60847 m .60265 .61453 L .60234 .60839 L F
.60265 .61453 m .60259 .61449 L .60234 .60839 L F
.59694 .61356 m .59113 .61824 L .59321 .61862 L .654 .783 .943 r
F
.59694 .61356 m .59321 .61862 L .59716 .61935 L F
.6028 .61462 m .60066 .61471 L .59954 .61622 L .653 .784 .944 r
F
.60207 .60822 m .60236 .61434 L .60222 .61425 L .925 .648 .496 r
F
.60222 .61425 m .60066 .61471 L .6028 .61462 L .653 .784 .944 r
F
.60219 .6083 m .60244 .61439 L .60207 .60822 L .925 .648 .496 r
F
.60244 .61439 m .60341 .63735 L .60236 .61434 L F
.60244 .61439 m .60236 .61434 L .60207 .60822 L F
.58571 .61003 m .57699 .62307 L .59077 .61191 L .654 .782 .942 r
F
.58571 .61003 m .56688 .61937 L .57699 .62307 L F
.58604 .61636 m .57725 .62943 L .59113 .61824 L .654 .783 .943 r
F
.58604 .61636 m .56708 .62572 L .57725 .62943 L F
.58223 .61382 m .56708 .62572 L .58604 .61636 L F
.60222 .61425 m .58038 .61713 L .58264 .62014 L .653 .784 .944 r
F
.60198 .61391 m .60193 .61384 L .60172 .60771 L .988 .718 .377 r
F
.60172 .60771 m .60193 .61384 L .60186 .61373 L F
.60192 .608 m .60207 .60822 L .60222 .61425 L F
.60192 .608 m .60222 .61425 L .6021 .61407 L F
.6029 .6087 m .60322 .61478 L .60273 .60865 L .84 .573 .536 r
F
.60322 .61478 m .60441 .63775 L .60308 .61474 L F
.60322 .61478 m .60308 .61474 L .60273 .60865 L F
.60357 .6149 m .60287 .61467 L .60342 .61502 L .653 .784 .944 r
F
.60329 .60883 m .60372 .60897 L .60386 .61499 L .84 .573 .536 r
F
.60353 .61488 m .60386 .61499 L .60441 .63775 L F
.60329 .60883 m .60386 .61499 L .60353 .61488 L F
.59586 .60886 m .59077 .61191 L .59329 .61237 L .654 .782 .942 r
F
.59993 .60949 m .59605 .60965 L .58604 .61636 L .654 .783 .943 r
F
.59605 .60965 m .58223 .61382 L .58494 .61563 L F
.59605 .60965 m .58494 .61563 L .58604 .61636 L F
.58223 .61382 m .55942 .62071 L .56708 .62572 L F
.57996 .61081 m .55942 .62071 L .58223 .61382 L F
.60071 .61397 m .57983 .61384 L .58038 .61713 L .653 .784 .944 r
F
.60185 .61333 m .60184 .61325 L .6017 .60709 L .712 .567 0 r
F
.60171 .60744 m .60185 .61353 L .6017 .6072 L F
.60185 .61353 m .60185 .61333 L .6017 .6072 L F
.60171 .60744 m .60186 .61373 L .60185 .61353 L F
.5832 .60741 m .58062 .60415 L .57941 .60751 L .654 .783 .943 r
F
.60478 .60057 m .60325 .60294 L .60449 .60305 L .654 .782 .942 r
F
.60256 .56761 m .60275 .59995 L .60333 .59964 L .438 .255 .533 r
F
.60478 .60057 m .58759 .59187 L .58321 .59466 L .654 .782 .942 r
F
.6037 .56731 m .60333 .59964 L .60392 .59948 L .583 .366 .552 r
F
.60478 .60057 m .59316 .58967 L .58759 .59187 L .654 .782 .942 r
F
.6037 .56731 m .60392 .59948 L .60448 .59934 L .583 .366 .552 r
F
.60478 .60057 m .59954 .58821 L .59316 .58967 L .654 .782 .942 r
F
.60481 .56723 m .60448 .59934 L .60506 .59928 L .665 .431 .556 r
F
.60591 .56734 m .60618 .59926 L .60672 .59928 L .733 .485 .553 r
F
.60625 .60899 m .60655 .61499 L .6056 .60907 L .648 .418 .556 r
F
.60625 .60899 m .6056 .60907 L .60517 .60311 L F
.6072 .60284 m .60722 .60292 L .60726 .6029 L .654 .782 .942 r
F
.60732 .60272 m .60756 .60868 L .6068 .60289 L .539 .333 .549 r
F
.60523 .60687 m .6087 .60829 L .60946 .60803 L .654 .783 .943 r
F
.6087 .60829 m .61218 .60971 L .60946 .60803 L F
.60523 .60687 m .60877 .60866 L .6094 .60857 L F
.6162 .61128 m .62743 .62182 L .63843 .6176 L .654 .782 .942 r
F
.60877 .60866 m .62228 .61546 L .6094 .60857 L .654 .783 .943 r
F
.60935 .60717 m .60928 .60742 L .6091 .60153 L 0 0 .235 r
F
.60885 .60181 m .60905 .60776 L .60862 .60206 L .163 .05 .467 r
F
.6091 .60153 m .60928 .60742 L .60926 .60753 L 0 0 .235 r
F
.60903 .60711 m .6091 .60153 L .60926 .60753 L .163 .05 .467 r
F
.60903 .60711 m .60926 .60753 L .60905 .60776 L F
.60523 .60687 m .61517 .60958 L .61212 .60787 L .654 .783 .943 r
F
.62172 .60914 m .63843 .6176 L .64723 .61221 L .654 .782 .942 r
F
.6162 .61128 m .63843 .6176 L .62172 .60914 L F
.62172 .60914 m .64723 .61221 L .62611 .60642 L F
.61159 .60758 m .62899 .61032 L .62202 .60874 L .654 .783 .943 r
F
.60523 .60687 m .61212 .60787 L .61159 .60758 L F
.61212 .60787 m .62899 .61032 L .61159 .60758 L F
.60591 .56734 m .60481 .56723 L .60561 .59923 L .733 .485 .553 r
F
.60803 .5684 m .60834 .59984 L .60885 .60012 L .906 .63 .507 r
F
.60926 .59987 m .62307 .60012 L .61144 .59953 L .654 .782 .942 r
F
.60478 .60057 m .6116 .6004 L .60926 .59987 L F
.6116 .6004 m .62307 .60012 L .60926 .59987 L F
.60699 .56768 m .60591 .56734 L .60672 .59928 L .805 .544 .543 r
F
.60711 .61492 m .60742 .61578 L .60748 .61487 L .653 .784 .944 r
F
.60742 .61578 m .60825 .61809 L .60768 .61549 L F
.60825 .61809 m .61086 .62531 L .60837 .61762 L F
.60825 .61809 m .60837 .61762 L .60768 .61549 L F
.60651 .61512 m .60807 .61879 L .60711 .61492 L F
.60807 .61879 m .61086 .62531 L .60825 .61809 L F
.60807 .61879 m .60825 .61809 L .60711 .61492 L F
.60928 .60742 m .60947 .61334 L .60926 .60753 L 0 0 .235 r
F
.6094 .60857 m .62228 .61546 L .62389 .61447 L .654 .783 .943 r
F
.62611 .60642 m .64723 .61221 L .65323 .60598 L .654 .782 .942 r
F
.62611 .60642 m .65323 .60598 L .62908 .60328 L F
.61299 .60668 m .62969 .60959 L .63102 .60624 L .654 .783 .943 r
F
.60918 .60123 m .60926 .6009 L .60941 .60691 L 0 0 .235 r
F
.60926 .6009 m .60934 .60677 L .60941 .60691 L .978 .72 .315 r
F
.60918 .60123 m .60941 .60691 L .60935 .60717 L 0 0 .235 r
F
.60889 .60176 m .6091 .60153 L .60903 .60711 L .163 .05 .467 r
F
.60523 .60687 m .62202 .60874 L .61299 .60668 L .654 .783 .943 r
F
.62202 .60874 m .62969 .60959 L .61299 .60668 L F
.60478 .60057 m .60582 .60302 L .6072 .60284 L .654 .782 .942 r
F
.60699 .56768 m .60672 .59928 L .60727 .59941 L .805 .544 .543 r
F
.60699 .56768 m .60727 .59941 L .6078 .59953 L F
.60803 .5684 m .6078 .59953 L .60834 .59984 L .906 .63 .507 r
F
.60654 .59914 m .62408 .59099 L .619 .58904 L .654 .782 .942 r
F
.60478 .60057 m .60793 .599 L .60654 .59914 L F
.60793 .599 m .62408 .59099 L .60654 .59914 L F
.60655 .61499 m .60603 .61506 L .6056 .60907 L .648 .418 .556 r
F
.6056 .60907 m .60603 .61506 L .60532 .60911 L F
.60603 .61506 m .60768 .6378 L .60581 .61509 L F
.60603 .61506 m .60581 .61509 L .60532 .60911 L F
.6104 .61902 m .62802 .62816 L .61672 .61761 L .654 .783 .943 r
F
.60869 .61471 m .61295 .61931 L .61117 .61595 L .653 .784 .944 r
F
.60834 .61475 m .61362 .62058 L .60869 .61471 L F
.60789 .61525 m .61362 .62058 L .60834 .61475 L F
.61362 .62058 m .61295 .61931 L .60869 .61471 L F
.6104 .61902 m .61547 .63095 L .62802 .62816 L .654 .783 .943 r
F
.60871 .6163 m .61086 .62531 L .61557 .62426 L .653 .784 .944 r
F
.60837 .61762 m .61086 .62531 L .60871 .6163 L F
.60789 .61525 m .61557 .62426 L .61362 .62058 L F
.60748 .61487 m .60785 .6153 L .60789 .61525 L F
.60785 .6153 m .61557 .62426 L .60789 .61525 L F
.60886 .60797 m .6091 .6139 L .60878 .60806 L .163 .05 .467 r
F
.60878 .60806 m .60903 .61398 L .60893 .61409 L F
.6074 .6089 m .60756 .60943 L .60771 .60926 L .654 .783 .943 r
F
.60756 .60868 m .60781 .61467 L .60714 .60883 L .539 .333 .549 r
F
.60781 .61467 m .60748 .61479 L .60714 .60883 L F
.60711 .61492 m .60876 .63743 L .60768 .6378 L F
.60696 .60889 m .60733 .61484 L .60711 .61492 L F
.60733 .61484 m .60876 .63743 L .60711 .61492 L F
.6109 .60973 m .61672 .61761 L .62228 .61546 L .654 .783 .943 r
F
.6128 .61332 m .61672 .61761 L .6109 .60973 L F
.61344 .61454 m .61523 .61794 L .61672 .61761 L F
.60905 .60776 m .60926 .60753 L .60941 .61355 L .163 .05 .467 r
F
.60866 .61439 m .61099 .61561 L .61079 .61524 L .653 .784 .944 r
F
.60866 .61439 m .61099 .61561 L .60866 .61439 L F
.61672 .61761 m .62802 .62816 L .6391 .62393 L .654 .783 .943 r
F
.60829 .61451 m .62276 .62176 L .60865 .61438 L .653 .784 .944 r
F
.61344 .61454 m .61672 .61761 L .6128 .61332 L .654 .783 .943 r
F
.61672 .61761 m .6391 .62393 L .62228 .61546 L F
.60926 .61417 m .62448 .6207 L .61609 .61602 L .653 .784 .944 r
F
.60714 .60883 m .60748 .61479 L .60696 .60889 L .539 .333 .549 r
F
.60748 .61479 m .60733 .61484 L .60696 .60889 L F
.60625 .60899 m .60696 .60889 L .60711 .61492 L .648 .418 .556 r
F
.60625 .60899 m .60711 .61492 L .60655 .61499 L F
.60845 .60826 m .60868 .61424 L .60816 .60844 L .402 .228 .528 r
F
.60868 .61424 m .60844 .61439 L .60816 .60844 L F
.6077 .61484 m .60789 .61525 L .60834 .61475 L .653 .784 .944 r
F
.60748 .61487 m .60754 .61493 L .6077 .61484 L F
.60754 .61493 m .60789 .61525 L .6077 .61484 L F
.60803 .60852 m .60834 .61445 L .60818 .61454 L .402 .228 .528 r
F
.6074 .6089 m .60771 .60926 L .60774 .60922 L .654 .783 .943 r
F
.60756 .60868 m .60803 .60852 L .60818 .61454 L .539 .333 .549 r
F
.60829 .61451 m .60812 .61458 L .60869 .61471 L .653 .784 .944 r
F
.60812 .61458 m .60748 .61487 L .6077 .61484 L F
.60812 .61458 m .6077 .61484 L .60869 .61471 L F
.60816 .60844 m .60844 .61439 L .60803 .60852 L .402 .228 .528 r
F
.60748 .61487 m .60837 .61762 L .60871 .6163 L .653 .784 .944 r
F
.60844 .61439 m .60952 .63694 L .60834 .61445 L .402 .228 .528 r
F
.60844 .61439 m .60834 .61445 L .60803 .60852 L F
.60781 .61467 m .60818 .61454 L .60876 .63743 L .539 .333 .549 r
F
.60727 .60878 m .6074 .6089 L .60803 .60852 L .654 .783 .943 r
F
.60756 .60868 m .60818 .61454 L .60781 .61467 L .539 .333 .549 r
F
.60569 .6132 m .60741 .61481 L .60829 .61451 L .653 .784 .944 r
F
.60741 .61481 m .60748 .61487 L .60829 .61451 L F
.60818 .61454 m .60952 .63694 L .60876 .63743 L .402 .228 .528 r
F
.60834 .61445 m .60952 .63694 L .60818 .61454 L F
.60845 .60826 m .60878 .60806 L .60893 .61409 L F
.60894 .61408 m .60865 .61438 L .60926 .61417 L .653 .784 .944 r
F
.60852 .61434 m .60865 .61438 L .60894 .61408 L F
.60865 .61438 m .62448 .6207 L .60926 .61417 L F
.60868 .61424 m .60893 .61409 L .60952 .63694 L .402 .228 .528 r
F
.60845 .60826 m .60893 .61409 L .60868 .61424 L F
.60569 .6132 m .60852 .61434 L .60894 .61408 L .653 .784 .944 r
F
.60742 .61578 m .60768 .61549 L .60748 .61487 L F
.60748 .61479 m .60876 .63743 L .60733 .61484 L .539 .333 .549 r
F
.60905 .60776 m .60941 .61355 L .60925 .61374 L .163 .05 .467 r
F
.6091 .6139 m .60903 .61398 L .60878 .60806 L F
.60905 .60776 m .60925 .61374 L .60886 .60797 L F
.60925 .61374 m .6091 .6139 L .60886 .60797 L F
.60569 .6132 m .61609 .61602 L .61274 .61416 L .653 .784 .944 r
F
.63843 .6176 m .66814 .61794 L .64723 .61221 L .654 .782 .942 r
F
.62228 .61546 m .6391 .62393 L .64796 .61853 L .654 .783 .943 r
F
.62228 .61546 m .64796 .61853 L .62671 .61273 L F
.61235 .61394 m .62967 .61644 L .62449 .61527 L .653 .784 .944 r
F
.60569 .6132 m .61274 .61416 L .61235 .61394 L F
.61274 .61416 m .62967 .61644 L .61235 .61394 L F
.62908 .60328 m .65323 .60598 L .65599 .59932 L .654 .782 .942 r
F
.62908 .60328 m .65599 .59932 L .6304 .59994 L F
.61329 .60562 m .63102 .60624 L .6306 .60293 L .654 .783 .943 r
F
.60906 .60053 m .60918 .60646 L .60926 .6009 L .978 .72 .315 r
F
.60918 .60646 m .60934 .60677 L .60926 .6009 L F
.60478 .60057 m .62782 .59358 L .62408 .59099 L .654 .782 .942 r
F
.60478 .60057 m .62997 .59663 L .62782 .59358 L F
.60727 .59941 m .60733 .6054 L .6078 .59953 L .805 .544 .543 r
F
.60906 .60053 m .609 .60613 L .60918 .60646 L .978 .72 .315 r
F
.60523 .60687 m .61299 .60668 L .61033 .60608 L .654 .783 .943 r
F
.60569 .6132 m .60829 .61451 L .60865 .61438 L .653 .784 .944 r
F
.60569 .6132 m .60645 .615 L .60748 .61487 L F
.60523 .60687 m .60727 .60878 L .60831 .60842 L .654 .783 .943 r
F
.60733 .6054 m .60776 .6055 L .6078 .59953 L .805 .544 .543 r
F
.61144 .59953 m .6304 .59994 L .62997 .59663 L .654 .782 .942 r
F
.62307 .60012 m .6304 .59994 L .61144 .59953 L F
.60834 .59984 m .6084 .60579 L .60885 .60012 L .906 .63 .507 r
F
.6084 .60579 m .60882 .60603 L .60885 .60012 L F
.60885 .60012 m .60882 .60603 L .609 .60613 L F
.6078 .59953 m .60776 .6055 L .60796 .60554 L .805 .544 .543 r
F
.60834 .59984 m .6078 .59953 L .60796 .60554 L .906 .63 .507 r
F
.60834 .59984 m .60796 .60554 L .6084 .60579 L F
.60906 .60053 m .60885 .60012 L .609 .60613 L .978 .72 .315 r
F
.60747 .60507 m .62467 .59727 L .61956 .59533 L .654 .783 .943 r
F
.60727 .59941 m .60687 .60529 L .60733 .6054 L .805 .544 .543 r
F
.60523 .60687 m .60828 .60537 L .60717 .60531 L .654 .783 .943 r
F
.60645 .615 m .60651 .61512 L .60711 .61492 L .653 .784 .944 r
F
.60655 .61499 m .60768 .6378 L .60603 .61506 L .648 .418 .556 r
F
.60523 .60687 m .60613 .609 L .60727 .60878 L .654 .783 .943 r
F
.60613 .609 m .60696 .60889 L .60727 .60878 L F
.60655 .61499 m .60711 .61492 L .60768 .6378 L .648 .418 .556 r
F
.60935 .60717 m .60957 .61293 L .60952 .61314 L 0 0 .235 r
F
.60947 .61334 m .60945 .61342 L .60926 .60753 L F
.60926 .60753 m .60945 .61342 L .60941 .61355 L F
.61212 .60787 m .62671 .61273 L .62899 .61032 L .654 .783 .943 r
F
.61517 .60958 m .62671 .61273 L .61212 .60787 L F
.61218 .60971 m .62389 .61447 L .61597 .61004 L F
.61517 .60958 m .62389 .61447 L .62671 .61273 L F
.64723 .61221 m .66814 .61794 L .67725 .60866 L .654 .782 .942 r
F
.62671 .61273 m .64796 .61853 L .654 .61228 L .654 .783 .943 r
F
.64723 .61221 m .67725 .60866 L .65323 .60598 L .654 .782 .942 r
F
.62671 .61273 m .654 .61228 L .62969 .60959 L .654 .783 .943 r
F
.61438 .61299 m .63018 .6159 L .63152 .61257 L .653 .784 .944 r
F
.60922 .6049 m .62843 .59987 L .62467 .59727 L .654 .783 .943 r
F
.60591 .56734 m .60561 .59923 L .60618 .59926 L .733 .485 .553 r
F
.60478 .60057 m .619 .58904 L .61293 .58789 L .654 .782 .942 r
F
.60618 .59926 m .60623 .60526 L .60672 .59928 L .733 .485 .553 r
F
.60523 .60687 m .60995 .60545 L .60828 .60537 L .654 .783 .943 r
F
.60935 .60717 m .60952 .61314 L .60928 .60742 L 0 0 .235 r
F
.60952 .61314 m .60947 .61334 L .60928 .60742 L F
.60569 .6132 m .61235 .61394 L .61081 .61308 L .653 .784 .944 r
F
.60569 .6132 m .60546 .61513 L .60645 .615 L F
.60623 .60526 m .60667 .60528 L .60672 .59928 L .733 .485 .553 r
F
.60478 .60057 m .60447 .6032 L .60582 .60302 L .654 .782 .942 r
F
.60481 .56723 m .60506 .59928 L .60561 .59923 L .665 .431 .556 r
F
.60478 .60057 m .61293 .58789 L .60629 .5876 L .654 .782 .942 r
F
.6051 .6053 m .60556 .60526 L .60561 .59923 L .665 .431 .556 r
F
.60672 .59928 m .60667 .60528 L .60687 .60529 L .733 .485 .553 r
F
.60561 .59923 m .60556 .60526 L .60576 .60524 L .665 .431 .556 r
F
.60618 .59926 m .60561 .59923 L .60576 .60524 L .733 .485 .553 r
F
.60618 .59926 m .60576 .60524 L .60623 .60526 L F
.60727 .59941 m .60672 .59928 L .60687 .60529 L .805 .544 .543 r
F
.60523 .60687 m .61344 .59417 L .60676 .59389 L .654 .783 .943 r
F
.60523 .60687 m .61956 .59533 L .61344 .59417 L F
.60523 .60687 m .6306 .60293 L .62843 .59987 L F
.60776 .6055 m .60773 .61148 L .60796 .60554 L .805 .544 .543 r
F
.60569 .6132 m .61438 .61299 L .61437 .61299 L .653 .784 .944 r
F
.60934 .60677 m .60943 .61266 L .60941 .60691 L .978 .72 .315 r
F
.60943 .61266 m .60948 .61277 L .60941 .60691 L F
.60935 .60717 m .60941 .60691 L .60957 .61293 L 0 0 .235 r
F
.60941 .60691 m .60948 .61277 L .60957 .61293 L .978 .72 .315 r
F
.6093 .61242 m .60943 .61266 L .60934 .60677 L F
.60569 .6132 m .63152 .61256 L .61515 .61173 L .653 .784 .944 r
F
.60781 .61467 m .60876 .63743 L .60748 .61479 L .539 .333 .549 r
F
.60773 .61148 m .60788 .61152 L .60796 .60554 L .805 .544 .543 r
F
.60828 .60537 m .61295 .60454 L .60922 .6049 L .654 .783 .943 r
F
.60995 .60545 m .61295 .60454 L .60828 .60537 L F
.61295 .60454 m .62843 .59987 L .60922 .6049 L F
.6084 .60579 m .60796 .60554 L .60811 .61157 L .906 .63 .507 r
F
.6084 .60579 m .60811 .61157 L .60846 .61177 L F
.60796 .60554 m .60788 .61152 L .60811 .61157 L .805 .544 .543 r
F
.60687 .60529 m .60678 .61131 L .60702 .61132 L .733 .485 .553 r
F
.60922 .6049 m .62467 .59727 L .60747 .60507 L .654 .783 .943 r
F
.60733 .6054 m .60738 .61141 L .60776 .6055 L .805 .544 .543 r
F
.60738 .61141 m .60773 .61148 L .60776 .6055 L F
.61033 .60608 m .62735 .60633 L .61329 .60562 L .654 .783 .943 r
F
.61299 .60668 m .62735 .60633 L .61033 .60608 L F
.62735 .60633 m .63102 .60624 L .61329 .60562 L F
.60882 .60603 m .60879 .61195 L .609 .60613 L .906 .63 .507 r
F
.60879 .61195 m .60894 .61203 L .609 .60613 L F
.609 .60613 m .60894 .61203 L .60916 .61216 L F
.60733 .6054 m .60687 .60529 L .60702 .61132 L .805 .544 .543 r
F
.60733 .6054 m .60702 .61132 L .60738 .61141 L F
.60918 .60646 m .609 .60613 L .60916 .61216 L .978 .72 .315 r
F
.60918 .60646 m .60916 .61216 L .6093 .61242 L F
.6084 .60579 m .60846 .61177 L .60882 .60603 L .906 .63 .507 r
F
.60846 .61177 m .60879 .61195 L .60882 .60603 L F
.60918 .60646 m .6093 .61242 L .60934 .60677 L .978 .72 .315 r
F
.60946 .60803 m .61218 .60971 L .61517 .60958 L .654 .783 .943 r
F
.60691 .61132 m .62004 .60169 L .61392 .60053 L .653 .784 .944 r
F
.60569 .6132 m .60797 .61137 L .60691 .61132 L F
.60797 .61137 m .62004 .60169 L .60691 .61132 L F
.60797 .61137 m .62516 .60362 L .62004 .60169 L F
.60569 .6132 m .60927 .61144 L .60797 .61137 L F
.61218 .60971 m .61597 .61004 L .61517 .60958 L .654 .783 .943 r
F
.60927 .61144 m .62516 .60362 L .60797 .61137 L .653 .784 .944 r
F
.60667 .60528 m .60663 .61131 L .60687 .60529 L .733 .485 .553 r
F
.60663 .61131 m .60678 .61131 L .60687 .60529 L F
.60623 .60526 m .60628 .61129 L .60667 .60528 L F
.60628 .61129 m .60663 .61131 L .60667 .60528 L F
.60717 .60531 m .60922 .6049 L .60747 .60507 L .654 .783 .943 r
F
.60828 .60537 m .60922 .6049 L .60717 .60531 L F
.60523 .60687 m .60532 .60911 L .60613 .609 L F
.60623 .60526 m .60576 .60524 L .60591 .61127 L .733 .485 .553 r
F
.60569 .6132 m .60691 .61132 L .60591 .61127 L .653 .784 .944 r
F
.60623 .60526 m .60591 .61127 L .60628 .61129 L .733 .485 .553 r
F
.60576 .60524 m .60566 .61129 L .60591 .61127 L .665 .431 .556 r
F
.60506 .59928 m .6051 .6053 L .60561 .59923 L F
.60186 .60067 m .60195 .60675 L .60215 .60028 L .07 0 .435 r
F
.60195 .60675 m .60219 .60643 L .60215 .60028 L F
.60523 .60687 m .60069 .60637 L .59809 .60705 L .654 .783 .943 r
F
.60523 .60687 m .60387 .60898 L .60497 .60908 L F
.60523 .60687 m .60497 .60908 L .60532 .60911 L F
.6049 .60907 m .60532 .60911 L .60547 .61513 L .749 .498 .552 r
F
.60275 .59995 m .60215 .60028 L .60229 .60629 L .438 .255 .533 r
F
.60275 .59995 m .60229 .60629 L .60279 .60602 L F
.60215 .60028 m .60219 .60643 L .60229 .60629 L .07 0 .435 r
F
.60523 .60687 m .58353 .60096 L .58062 .60415 L .654 .783 .943 r
F
.60275 .59995 m .60279 .60602 L .60333 .59964 L .438 .255 .533 r
F
.60279 .60602 m .60327 .60576 L .60333 .59964 L F
.60523 .60687 m .58793 .59816 L .58353 .60096 L .654 .783 .943 r
F
.60392 .59948 m .60333 .59964 L .60348 .60565 L .583 .366 .552 r
F
.60392 .59948 m .60348 .60565 L .60396 .60552 L F
.60333 .59964 m .60327 .60576 L .60348 .60565 L .438 .255 .533 r
F
.60523 .60687 m .59354 .59596 L .58793 .59816 L .654 .783 .943 r
F
.60392 .59948 m .60396 .60552 L .60448 .59934 L .583 .366 .552 r
F
.60396 .60552 m .60442 .6054 L .60448 .59934 L F
.60448 .59934 m .60442 .6054 L .60463 .60535 L F
.60523 .60687 m .59996 .5945 L .59354 .59596 L .654 .783 .943 r
F
.60418 .59915 m .60629 .5876 L .59954 .58821 L .654 .782 .942 r
F
.60478 .60057 m .60494 .59919 L .60418 .59915 L F
.60494 .59919 m .60629 .5876 L .60418 .59915 L F
.60506 .59928 m .60448 .59934 L .60463 .60535 L .665 .431 .556 r
F
.60506 .59928 m .60463 .60535 L .6051 .6053 L F
.60523 .60687 m .60676 .59389 L .59996 .5945 L .654 .783 .943 r
F
.6051 .6053 m .60515 .61134 L .60556 .60526 L .665 .431 .556 r
F
.60515 .61134 m .60551 .61131 L .60556 .60526 L F
.60569 .6132 m .60592 .61127 L .6049 .61137 L .653 .784 .944 r
F
.60127 .61389 m .60055 .61333 L .60071 .61397 L F
.60569 .6132 m .60171 .6133 L .60127 .61389 L F
.60171 .6133 m .60055 .61333 L .60127 .61389 L F
.60219 .60643 m .60222 .6126 L .60229 .60629 L .07 0 .435 r
F
.60569 .6132 m .60159 .61384 L .60222 .61425 L .653 .784 .944 r
F
.60569 .6132 m .60222 .61425 L .6028 .61462 L F
.60222 .61425 m .60341 .63735 L .60275 .63684 L .925 .648 .496 r
F
.60236 .61434 m .60341 .63735 L .60222 .61425 L F
.60159 .61384 m .58038 .61713 L .60222 .61425 L .653 .784 .944 r
F
.60198 .61391 m .60275 .63684 L .60193 .61384 L .988 .718 .377 r
F
.60186 .61373 m .60275 .63684 L .60239 .63624 L F
.60193 .61384 m .60275 .63684 L .60186 .61373 L F
.6021 .61407 m .60275 .63684 L .60198 .61391 L F
.6021 .61407 m .60222 .61425 L .60275 .63684 L F
.60556 .60526 m .60551 .61131 L .60576 .60524 L .665 .431 .556 r
F
.59605 .60965 m .58917 .60937 L .58223 .61382 L .654 .783 .943 r
F
.58917 .60937 m .58057 .61161 L .58223 .61382 L F
.59692 .61342 m .59642 .61218 L .57983 .61384 L .653 .784 .944 r
F
.6017 .60709 m .60184 .61325 L .60184 .61312 L .712 .567 0 r
F
.60195 .60675 m .60204 .61285 L .60219 .60643 L .07 0 .435 r
F
.60204 .61285 m .60222 .6126 L .60219 .60643 L F
.60195 .60675 m .6017 .60709 L .60184 .61312 L F
.60195 .60675 m .60184 .61312 L .60204 .61285 L F
.60569 .6132 m .60162 .61275 L .60055 .61333 L .653 .784 .944 r
F
.60569 .6132 m .6028 .61462 L .60287 .61467 L F
.60569 .6132 m .60287 .61467 L .60357 .6149 L F
.60256 .61447 m .60341 .63735 L .60244 .61439 L .925 .648 .496 r
F
.60288 .62155 m .60341 .63735 L .60256 .61447 L F
.60569 .6132 m .60357 .6149 L .60386 .61499 L .653 .784 .944 r
F
.60353 .61488 m .60441 .63775 L .60322 .61478 L .84 .573 .536 r
F
.60331 .63445 m .60334 .63443 L .60341 .63735 L .925 .648 .496 r
F
.60265 .61453 m .60334 .63443 L .60331 .63445 L F
.60265 .61453 m .60287 .61467 L .60334 .63443 L F
.60222 .6126 m .60231 .61249 L .60229 .60629 L .07 0 .435 r
F
.59809 .60705 m .59758 .60603 L .5832 .60741 L .654 .783 .943 r
F
.59758 .60603 m .58062 .60415 L .5832 .60741 L F
.59956 .60776 m .59809 .60705 L .58917 .60937 L F
.59809 .60705 m .57941 .60751 L .58917 .60937 L F
.59956 .60776 m .58917 .60937 L .59605 .60965 L F
.58917 .60937 m .57996 .61081 L .58057 .61161 L F
.59642 .61218 m .58395 .60731 L .58104 .61049 L .653 .784 .944 r
F
.60229 .60629 m .60231 .61249 L .60243 .61232 L .07 0 .435 r
F
.60162 .61275 m .6018 .61215 L .60011 .61259 L .653 .784 .944 r
F
.60569 .6132 m .60243 .61232 L .60162 .61275 L F
.60243 .61232 m .6018 .61215 L .60162 .61275 L F
.60327 .60576 m .6032 .6119 L .60348 .60565 L .438 .255 .533 r
F
.60279 .60602 m .60283 .6121 L .60327 .60576 L F
.60283 .6121 m .6032 .6119 L .60327 .60576 L F
.60279 .60602 m .60229 .60629 L .60243 .61232 L F
.60279 .60602 m .60243 .61232 L .60283 .6121 L F
.60089 .60818 m .59605 .60965 L .59993 .60949 L .654 .783 .943 r
F
.6018 .61215 m .58836 .60452 L .58395 .60731 L .653 .784 .944 r
F
.60569 .6132 m .60298 .61184 L .6018 .61215 L F
.60298 .61184 m .58836 .60452 L .6018 .61215 L F
.60442 .6054 m .60437 .61148 L .60463 .60535 L .583 .366 .552 r
F
.60418 .61552 m .60484 .61595 L .60546 .61513 L .653 .784 .944 r
F
.60442 .61504 m .60603 .63798 L .6042 .61502 L .749 .498 .552 r
F
.60386 .61499 m .60603 .63798 L .60441 .63775 L F
.60389 .61534 m .60409 .61546 L .60434 .61528 L .653 .784 .944 r
F
.6042 .61502 m .60603 .63798 L .60386 .61499 L .749 .498 .552 r
F
.60569 .6132 m .60386 .61499 L .60449 .61505 L .653 .784 .944 r
F
.60492 .61508 m .60603 .63798 L .60442 .61504 L .749 .498 .552 r
F
.6032 .6119 m .60337 .61181 L .60348 .60565 L .438 .255 .533 r
F
.60348 .60565 m .60337 .61181 L .60362 .61168 L F
.60069 .60637 m .59758 .60603 L .59809 .60705 L .654 .783 .943 r
F
.60101 .60698 m .59809 .60705 L .59956 .60776 L F
.60298 .61184 m .59398 .60232 L .58836 .60452 L .653 .784 .944 r
F
.60569 .6132 m .60395 .61159 L .60298 .61184 L F
.60396 .60552 m .60348 .60565 L .60362 .61168 L .583 .366 .552 r
F
.60396 .60552 m .60362 .61168 L .604 .61158 L F
.60395 .61159 m .59398 .60232 L .60298 .61184 L .653 .784 .944 r
F
.60437 .61148 m .60453 .61144 L .60463 .60535 L .583 .366 .552 r
F
.60463 .60535 m .60453 .61144 L .60478 .61138 L F
.6051 .6053 m .60463 .60535 L .60478 .61138 L .665 .431 .556 r
F
.6051 .6053 m .60478 .61138 L .60515 .61134 L F
.60396 .60552 m .604 .61158 L .60442 .6054 L .583 .366 .552 r
F
.604 .61158 m .60437 .61148 L .60442 .6054 L F
.60569 .6132 m .60042 .60086 L .59398 .60232 L .653 .784 .944 r
F
.604 .61158 m .60362 .61168 L .60416 .63397 L .583 .366 .552 r
F
.60437 .61148 m .60416 .63397 L .60453 .61144 L F
.6032 .6119 m .60296 .63465 L .60337 .61181 L .438 .255 .533 r
F
.60468 .61474 m .60449 .61505 L .60468 .61506 L .653 .784 .944 r
F
.60468 .61474 m .60468 .61506 L .60546 .61513 L F
.60569 .6132 m .60468 .61474 L .60546 .61513 L F
.60478 .61138 m .60416 .63397 L .60532 .63368 L .583 .366 .552 r
F
.60453 .61144 m .60416 .63397 L .60478 .61138 L F
.60011 .61259 m .60048 .61179 L .59642 .61218 L .653 .784 .944 r
F
.6018 .61215 m .60048 .61179 L .60011 .61259 L F
.60048 .61179 m .58395 .60731 L .59642 .61218 L F
.60492 .61508 m .60547 .61513 L .60603 .63798 L .749 .498 .552 r
F
.60515 .61134 m .60478 .61138 L .60532 .63368 L .665 .431 .556 r
F
.60362 .61168 m .60296 .63465 L .60416 .63397 L .438 .255 .533 r
F
.60337 .61181 m .60296 .63465 L .60362 .61168 L F
.60055 .61333 m .60011 .61259 L .59692 .61342 L .653 .784 .944 r
F
.60162 .61275 m .60011 .61259 L .60055 .61333 L F
.60011 .61259 m .59642 .61218 L .59692 .61342 L F
.604 .61158 m .60416 .63397 L .60437 .61148 L .583 .366 .552 r
F
.60551 .61131 m .60532 .63368 L .60566 .61129 L .665 .431 .556 r
F
.60551 .61131 m .60566 .61129 L .60576 .60524 L F
.59642 .61218 m .58104 .61049 L .57985 .61378 L .653 .784 .944 r
F
.59642 .61218 m .57985 .61378 L .57983 .61384 L F
.60222 .6126 m .60237 .63553 L .60231 .61249 L .07 0 .435 r
F
.6049 .61137 m .60722 .60025 L .60042 .60086 L .653 .784 .944 r
F
.60592 .61127 m .60722 .60025 L .6049 .61137 L F
.60515 .61134 m .60532 .63368 L .60551 .61131 L .665 .431 .556 r
F
.60569 .6132 m .62893 .60621 L .62516 .60362 L .653 .784 .944 r
F
.62202 .60874 m .62899 .61032 L .62969 .60959 L .654 .783 .943 r
F
.65323 .60598 m .67725 .60866 L .68155 .5987 L .654 .782 .942 r
F
.65323 .60598 m .68155 .5987 L .65599 .59932 L F
.62969 .60959 m .65678 .60561 L .63102 .60624 L .654 .783 .943 r
F
.60569 .6132 m .63109 .60926 L .62893 .60621 L .653 .784 .944 r
F
.60628 .61129 m .60591 .61127 L .60646 .6336 L .733 .485 .553 r
F
.60591 .61127 m .60701 .61116 L .60592 .61127 L .653 .784 .944 r
F
.60691 .61132 m .60701 .61116 L .60591 .61127 L F
.60592 .61127 m .61392 .60053 L .60722 .60025 L F
.60701 .61116 m .61392 .60053 L .60592 .61127 L F
.60591 .61127 m .60532 .63368 L .60646 .6336 L .665 .431 .556 r
F
.60566 .61129 m .60532 .63368 L .60591 .61127 L F
.60663 .61131 m .60646 .6336 L .60678 .61131 L .733 .485 .553 r
F
.60702 .61132 m .60646 .6336 L .60758 .63371 L F
.60678 .61131 m .60646 .6336 L .60702 .61132 L F
.60773 .61148 m .60758 .63371 L .60788 .61152 L .805 .544 .543 r
F
.61437 .61299 m .63152 .61257 L .63152 .61256 L .653 .784 .944 r
F
.61438 .61299 m .63152 .61257 L .61437 .61299 L F
.62969 .60959 m .654 .61228 L .65678 .60561 L .654 .783 .943 r
F
.61515 .61173 m .63152 .61256 L .63109 .60926 L .653 .784 .944 r
F
.60628 .61129 m .60646 .6336 L .60663 .61131 L .733 .485 .553 r
F
.60865 .61438 m .60866 .61439 L .60866 .61439 L .653 .784 .944 r
F
.60868 .61424 m .60952 .63694 L .60844 .61439 L .402 .228 .528 r
F
.60846 .61177 m .60811 .61157 L .60868 .63404 L .906 .63 .507 r
F
.61081 .61308 m .62449 .61527 L .61438 .61299 L .653 .784 .944 r
F
.61235 .61394 m .62449 .61527 L .61081 .61308 L F
.62449 .61527 m .63018 .6159 L .61438 .61299 L F
.60811 .61157 m .60758 .63371 L .60868 .63404 L .805 .544 .543 r
F
.60788 .61152 m .60758 .63371 L .60811 .61157 L F
.60738 .61141 m .60758 .63371 L .60773 .61148 L F
.60879 .61195 m .60868 .63404 L .60894 .61203 L .906 .63 .507 r
F
.6091 .6139 m .61 .63635 L .60903 .61398 L .163 .05 .467 r
F
.60893 .61409 m .61 .63635 L .60952 .63694 L F
.60903 .61398 m .61 .63635 L .60893 .61409 L F
.60925 .61374 m .61 .63635 L .6091 .6139 L F
.60916 .61216 m .60868 .63404 L .60974 .63475 L .906 .63 .507 r
F
.60894 .61203 m .60868 .63404 L .60916 .61216 L F
.61274 .61416 m .6272 .61903 L .62967 .61644 L .653 .784 .944 r
F
.61609 .61602 m .6272 .61903 L .61274 .61416 L F
.62449 .61527 m .62967 .61644 L .63018 .6159 L F
.60738 .61141 m .60702 .61132 L .60758 .63371 L .805 .544 .543 r
F
.60925 .61374 m .60941 .61355 L .61 .63635 L .163 .05 .467 r
F
.6093 .61242 m .60916 .61216 L .60974 .63475 L .978 .72 .315 r
F
.61079 .61524 m .62276 .62176 L .62448 .6207 L .653 .784 .944 r
F
.61099 .61561 m .62276 .62176 L .61079 .61524 L F
.61609 .61602 m .62448 .6207 L .6272 .61903 L F
.60846 .61177 m .60868 .63404 L .60879 .61195 L .906 .63 .507 r
F
.61362 .62058 m .61719 .6239 L .61295 .61931 L .653 .784 .944 r
F
.60947 .61334 m .61016 .63565 L .60945 .61342 L 0 0 .235 r
F
.60941 .61355 m .61016 .63565 L .61 .63635 L F
.60945 .61342 m .61016 .63565 L .60941 .61355 L F
.60952 .61314 m .61016 .63565 L .60947 .61334 L F
.60943 .61266 m .60974 .63475 L .60948 .61277 L .978 .72 .315 r
F
.60952 .61314 m .60957 .61293 L .61016 .63565 L 0 0 .235 r
F
.60957 .61293 m .60974 .63475 L .61016 .63565 L .978 .72 .315 r
F
.60948 .61277 m .60974 .63475 L .60957 .61293 L F
.61117 .61595 m .61719 .6239 L .62276 .62176 L .653 .784 .944 r
F
.61295 .61931 m .61719 .6239 L .61117 .61595 L F
.61362 .62058 m .61557 .62426 L .61719 .6239 L F
.6093 .61242 m .60974 .63475 L .60943 .61266 L .978 .72 .315 r
F
.60283 .6121 m .60296 .63465 L .6032 .6119 L .438 .255 .533 r
F
.60055 .61333 m .59885 .61337 L .59986 .6137 L .653 .784 .944 r
F
.60055 .61333 m .59986 .6137 L .60071 .61397 L F
.59885 .61337 m .57983 .61384 L .60071 .61397 L F
.60243 .61232 m .60237 .63553 L .60296 .63465 L .07 0 .435 r
F
.60231 .61249 m .60237 .63553 L .60243 .61232 L F
.59954 .61622 m .59452 .61656 L .58646 .62266 L .653 .784 .944 r
F
.60066 .61471 m .59452 .61656 L .59954 .61622 L F
.59452 .61656 m .58264 .62014 L .58498 .62168 L F
.59452 .61656 m .58498 .62168 L .58646 .62266 L F
.60288 .62155 m .60256 .61447 L .60259 .61449 L .925 .648 .496 r
F
.60265 .61453 m .60288 .62155 L .60259 .61449 L F
.60283 .6121 m .60243 .61232 L .60296 .63465 L .438 .255 .533 r
F
.60184 .61312 m .60239 .63624 L .60237 .63553 L .712 .567 0 r
F
.60184 .61325 m .60239 .63624 L .60184 .61312 L F
.59954 .61622 m .58646 .62266 L .59608 .62091 L .653 .784 .944 r
F
.60204 .61285 m .60237 .63553 L .60222 .6126 L .07 0 .435 r
F
.60185 .61333 m .60239 .63624 L .60184 .61325 L .712 .567 0 r
F
.60185 .61353 m .60239 .63624 L .60185 .61333 L F
.60185 .61353 m .60186 .61373 L .60239 .63624 L F
.60204 .61285 m .60184 .61312 L .60237 .63553 L .07 0 .435 r
F
.59552 .62167 m .59156 .62454 L .59318 .62483 L .653 .784 .944 r
F
.59552 .62167 m .59318 .62483 L .5976 .62564 L F
.7456 .51043 m .72519 .526 L .74998 .51446 L .643 .738 .918 r
F
.7456 .51043 m .71637 .51804 L .72519 .526 L F
.79513 .51684 m .81476 .53072 L .8266 .52384 L F
.7879 .51936 m .81476 .53072 L .79513 .51684 L F
.47263 .74644 m .4947 .74313 L .47651 .74218 L .657 .808 .956 r
F
.38838 .64573 m .37651 .64739 L .37659 .65366 L .387 .234 .548 r
F
.38838 .64573 m .38828 .63944 L .37651 .64739 L F
0 g
.36941 .65637 m
.37651 .64739 L
s
.38526 .76078 m .39096 .7612 L .39129 .76636 L .977 .706 .449 r
F
.38526 .76078 m .38494 .75559 L .39096 .7612 L F
.40333 .75222 m .39096 .7612 L .40729 .75598 L .656 .808 .956 r
F
.40333 .75222 m .38494 .75559 L .39096 .7612 L F
0 g
.39096 .7612 m
.39752 .76438 L
s
.40673 .65394 m .38838 .64573 L .37659 .65366 L .653 .784 .944 r
F
0 g
.36948 .66261 m
.37659 .65366 L
s
.41716 .64979 m .38838 .64573 L .40673 .65394 L .653 .784 .944 r
F
.57711 .52466 m .54328 .52257 L .5736 .52881 L .642 .738 .919 r
F
.46781 .64225 m .46231 .62792 L .45559 .6401 L .654 .783 .943 r
F
.46781 .64225 m .48077 .63121 L .46231 .62792 L F
.6348 .53203 m .66083 .52001 L .63213 .52756 L .642 .738 .919 r
F
.6348 .53203 m .66603 .52903 L .66083 .52001 L F
.65621 .63852 m .669 .62426 L .66955 .63052 L .436 .285 .576 r
F
.6396 .6302 m .65621 .63852 L .66955 .63052 L .653 .784 .944 r
F
.62851 .63442 m .65621 .63852 L .6396 .6302 L F
0 g
.63964 .64476 m
.65621 .63852 L
s
.57743 .51682 m .55055 .50633 L .54367 .51472 L .643 .738 .918 r
F
.58277 .51335 m .55055 .50633 L .57743 .51682 L F
.58318 .5056 m .56177 .49158 L .5512 .4986 L .644 .737 .917 r
F
.58996 .50308 m .56177 .49158 L .58318 .5056 L F
.45531 .63397 m .44219 .62102 L .44223 .63346 L .654 .782 .942 r
F
.45531 .63397 m .46199 .62182 L .44219 .62102 L F
.63232 .51971 m .65177 .50405 L .62769 .51571 L .643 .738 .918 r
F
.63232 .51971 m .66096 .51213 L .65177 .50405 L F
.62777 .50795 m .63919 .48978 L .62155 .50474 L .644 .737 .917 r
F
.62777 .50795 m .65168 .4963 L .63919 .48978 L F
0 g
.59546 .51759 m
.59665 .51731 L
s
.55055 .50633 m .51325 .50843 L .54367 .51472 L .643 .738 .918 r
F
.49544 .7483 m .49498 .74315 L .4972 .73649 L 0 0 .373 r
F
0 g
.48938 .7492 m
.49498 .74315 L
s
.47651 .74218 m .4947 .74313 L .49691 .73651 L .657 .808 .956 r
F
.66614 .52117 m .68993 .50447 L .66096 .51213 L .643 .738 .918 r
F
.66614 .52117 m .69749 .51813 L .68993 .50447 L F
.47323 .75162 m .49544 .7483 L .47713 .74735 L .656 .808 .956 r
F
.42915 .63462 m .42238 .62279 L .40403 .62699 L .654 .782 .942 r
F
.44223 .63346 m .42238 .62279 L .42915 .63462 L F
.53714 .63382 m .54837 .63497 L .54872 .64122 L .922 .656 .516 r
F
.53714 .63382 m .5368 .62754 L .54837 .63497 L F
.55942 .62071 m .54837 .63497 L .56708 .62572 L .654 .783 .943 r
F
.55942 .62071 m .5368 .62754 L .54837 .63497 L F
0 g
.54837 .63497 m
.55592 .63768 L
s
.42409 .75591 m .4138 .76416 L .42716 .75743 L .656 .809 .957 r
F
.42409 .75591 m .40764 .76115 L .4138 .76416 L F
.41702 .64352 m .40396 .63312 L .38828 .63944 L .654 .783 .943 r
F
.42925 .64076 m .40396 .63312 L .41702 .64352 L F
.5512 .4986 m .52422 .48802 L .51416 .50071 L .644 .737 .917 r
F
.40218 .51763 m .4391 .51555 L .40827 .50925 L .642 .738 .919 r
F
.40368 .75741 m .39129 .76636 L .40764 .76115 L .656 .809 .957 r
F
.40368 .75741 m .38526 .76078 L .39129 .76636 L F
0 g
.39129 .76636 m
.40057 .77083 L
s
.52337 .49571 m .51371 .50062 L .51325 .50843 L .101 0 .414 r
F
.52337 .49571 m .52381 .48786 L .51371 .50062 L F
0 g
.50995 .51444 m
.51371 .50062 L
s
.2499 .49146 m .25598 .49805 L .25493 .50586 L .996 .804 .443 r
F
.2499 .49146 m .25097 .48362 L .25598 .49805 L F
0 g
.25598 .49805 m
.26176 .50516 L
s
.28327 .48532 m .25643 .49801 L .28641 .49491 L .643 .738 .918 r
F
.28327 .48532 m .25145 .48364 L .25643 .49801 L F
.44223 .63346 m .44219 .62102 L .42238 .62279 L .654 .782 .942 r
F
.4391 .51555 m .43974 .50772 L .4429 .49371 L 0 0 .083 r
F
0 g
.43458 .51463 m
.43974 .50772 L
s
.40867 .50134 m .43928 .50762 L .44242 .49369 L .643 .738 .918 r
F
.49642 .63674 m .49615 .63049 L .48052 .62494 L .848 .597 .559 r
F
0 g
.49615 .63049 m
.50789 .63785 L
s
.46804 .64851 m .46253 .63422 L .45579 .64637 L .653 .784 .944 r
F
.46804 .64851 m .48102 .6375 L .46253 .63422 L F
.42149 .74364 m .40317 .747 L .4071 .75076 L .657 .808 .956 r
F
.49544 .7483 m .4972 .73649 L .49766 .74166 L 0 0 .373 r
F
.4959 .75346 m .49544 .7483 L .49766 .74166 L F
.47713 .74735 m .49544 .7483 L .49766 .74166 L .656 .808 .956 r
F
0 g
.4898 .75437 m
.49544 .7483 L
s
.74315 .49797 m .71145 .50109 L .71637 .5102 L .644 .737 .917 r
F
.82634 .51598 m .86441 .51389 L .83479 .50758 L F
.45559 .6401 m .44238 .62713 L .44242 .63959 L .654 .783 .943 r
F
.45559 .6401 m .46231 .62792 L .44238 .62713 L F
.47366 .75678 m .4959 .75346 L .47757 .75252 L .656 .809 .957 r
F
.45722 .75372 m .47366 .75678 L .47757 .75252 L F
.45417 .75564 m .47366 .75678 L .45722 .75372 L F
.58996 .50308 m .57538 .48643 L .56177 .49158 L .644 .737 .917 r
F
.59774 .50167 m .57538 .48643 L .58996 .50308 L F
.62155 .50474 m .62419 .48528 L .61412 .50253 L F
.62155 .50474 m .63919 .48978 L .62419 .48528 L F
.86441 .51389 m .86407 .50606 L .87102 .49202 L 0 0 .411 r
F
0 g
.85754 .51243 m
.86407 .50606 L
s
.55979 .62701 m .54872 .64122 L .56747 .632 L .653 .784 .944 r
F
.55979 .62701 m .53714 .63382 L .54872 .64122 L F
0 g
.54872 .64122 m
.56397 .64667 L
s
.5976 .62564 m .58966 .63786 L .6027 .63837 L .653 .784 .944 r
F
.41716 .64979 m .40409 .63942 L .38838 .64573 L F
.42941 .64703 m .40409 .63942 L .41716 .64979 L F
.57711 .52466 m .55017 .51419 L .54328 .52257 L .642 .738 .919 r
F
.58247 .52121 m .55017 .51419 L .57711 .52466 L F
.42925 .64076 m .42244 .62891 L .40396 .63312 L .654 .783 .943 r
F
.44242 .63959 m .42244 .62891 L .42925 .64076 L F
.669 .62426 m .66845 .61802 L .67761 .6087 L .261 .157 .542 r
F
0 g
.65834 .62414 m
.66845 .61802 L
s
.58277 .51335 m .5612 .49929 L .55055 .50633 L .643 .738 .918 r
F
.5896 .51082 m .5612 .49929 L .58277 .51335 L F
.63213 .52756 m .65163 .51195 L .62749 .52358 L .642 .738 .919 r
F
.63213 .52756 m .66083 .52001 L .65163 .51195 L F
.62769 .51571 m .63919 .49751 L .62142 .5125 L .643 .738 .918 r
F
.62769 .51571 m .65177 .50405 L .63919 .49751 L F
.55017 .51419 m .51278 .51629 L .54328 .52257 L .642 .738 .919 r
F
.42176 .74883 m .40333 .75222 L .40729 .75598 L .656 .808 .956 r
F
.61086 .62531 m .61594 .6372 L .62851 .63442 L .653 .784 .944 r
F
.47651 .74218 m .49691 .73651 L .47791 .73776 L .657 .808 .956 r
F
.45823 .74122 m .47651 .74218 L .47791 .73776 L F
.66603 .52903 m .68987 .51238 L .66083 .52001 L .642 .738 .919 r
F
.66603 .52903 m .69745 .526 L .68987 .51238 L F
.44242 .63959 m .44238 .62713 L .42244 .62891 L .654 .783 .943 r
F
.49642 .63674 m .48052 .62494 L .48077 .63121 L .848 .597 .559 r
F
.49669 .64301 m .49642 .63674 L .48077 .63121 L F
0 g
.49642 .63674 m
.50818 .64408 L
s
.4959 .75346 m .49766 .74166 L .49813 .74684 L 0 0 .373 r
F
.47757 .75252 m .4959 .75346 L .49813 .74684 L .656 .809 .957 r
F
0 g
.48997 .75982 m
.4959 .75346 L
s
.31458 .50753 m .2914 .51969 L .31815 .5121 L .641 .739 .92 r
F
.31458 .50753 m .28413 .51063 L .2914 .51969 L F
.59774 .50167 m .59109 .48354 L .57538 .48643 L .644 .737 .917 r
F
.60599 .50148 m .59109 .48354 L .59774 .50167 L F
.61412 .50253 m .60777 .48315 L .60599 .50148 L F
.61412 .50253 m .62419 .48528 L .60777 .48315 L F
.40146 .52549 m .43847 .52342 L .40757 .51712 L .641 .739 .92 r
F
.3735 .51501 m .40146 .52549 L .40757 .51712 L F
.36862 .5185 m .40146 .52549 L .3735 .51501 L F
.55055 .50633 m .52337 .49571 L .51325 .50843 L .643 .738 .918 r
F
.52292 .5036 m .51325 .50843 L .51278 .51629 L .101 0 .414 r
F
.52292 .5036 m .52337 .49571 L .51325 .50843 L F
0 g
.50948 .52222 m
.51325 .50843 L
s
.24882 .49935 m .25493 .50586 L .25387 .51371 L .996 .804 .443 r
F
.24882 .49935 m .2499 .49146 L .25493 .50586 L F
.28195 .49315 m .25493 .50586 L .28513 .50277 L .642 .738 .919 r
F
.28195 .49315 m .2499 .49146 L .25493 .50586 L F
0 g
.25493 .50586 m
.26076 .51301 L
s
.59156 .62454 m .58966 .63786 L .5976 .62564 L .653 .784 .944 r
F
.59156 .62454 m .57766 .63569 L .58966 .63786 L F
.56177 .49158 m .52422 .48802 L .5512 .4986 L .644 .737 .917 r
F
.69745 .526 m .69749 .51813 L .68993 .50447 L .992 .738 .403 r
F
0 g
.69749 .51813 m
.69855 .53217 L
s
.40396 .63312 m .38818 .63317 L .38828 .63944 L .523 .339 .573 r
F
.40396 .63312 m .40383 .62684 L .38818 .63317 L F
0 g
.37643 .64114 m
.38818 .63317 L
s
.4391 .51555 m .4429 .49371 L .44227 .50158 L 0 0 .083 r
F
.43847 .52342 m .4391 .51555 L .44227 .50158 L F
.40827 .50925 m .4391 .51555 L .44227 .50158 L .642 .738 .919 r
F
0 g
.4339 .52249 m
.4391 .51555 L
s
.45579 .64637 m .44257 .63344 L .4426 .64586 L .653 .784 .944 r
F
.45579 .64637 m .46253 .63422 L .44257 .63344 L F
.60599 .50148 m .60777 .48315 L .59109 .48354 L .644 .737 .917 r
F
.66079 .50436 m .67597 .48447 L .65168 .4963 L F
.38263 .74923 m .38462 .75042 L .38494 .75559 L .921 .685 .192 r
F
.38263 .74923 m .38231 .74404 L .38462 .75042 L F
0 g
.38462 .75042 m
.3893 .75479 L
s
.40171 .74276 m .3849 .75037 L .40317 .747 L .657 .808 .956 r
F
.40171 .74276 m .3826 .74402 L .3849 .75037 L F
.42213 .75402 m .40764 .76115 L .42409 .75591 L .656 .809 .957 r
F
.42213 .75402 m .40368 .75741 L .40764 .76115 L F
.3151 .48699 m .28327 .48532 L .28641 .49491 L .643 .738 .918 r
F
.74321 .50585 m .71637 .51804 L .7456 .51043 L F
.74321 .50585 m .71144 .50896 L .71637 .51804 L F
.47713 .74735 m .49766 .74166 L .47854 .74292 L .656 .808 .956 r
F
.45873 .7464 m .47713 .74735 L .47854 .74292 L F
.42941 .64703 m .42259 .63522 L .40409 .63942 L .653 .784 .944 r
F
.4426 .64586 m .42259 .63522 L .42941 .64703 L F
.669 .62426 m .67761 .6087 L .67818 .61496 L .261 .157 .542 r
F
.66955 .63052 m .669 .62426 L .67818 .61496 L F
.64796 .61853 m .669 .62426 L .67818 .61496 L .654 .783 .943 r
F
.6391 .62393 m .669 .62426 L .64796 .61853 L F
0 g
.6588 .6304 m
.669 .62426 L
s
.40867 .50134 m .44242 .49369 L .41059 .49201 L .643 .738 .918 r
F
.37789 .49502 m .40867 .50134 L .41059 .49201 L F
.8266 .52384 m .86475 .52177 L .83507 .51546 L F
.80103 .51334 m .8266 .52384 L .83507 .51546 L F
.79513 .51684 m .8266 .52384 L .80103 .51334 L F
.5896 .51082 m .57491 .49413 L .5612 .49929 L F
.59744 .50941 m .57491 .49413 L .5896 .51082 L F
.61719 .6239 m .62851 .63442 L .6396 .6302 L .653 .784 .944 r
F
.61086 .62531 m .62851 .63442 L .61719 .6239 L F
.62142 .5125 m .62409 .49299 L .61393 .51028 L .643 .738 .918 r
F
.62142 .5125 m .63919 .49751 L .62409 .49299 L F
.4426 .64586 m .44257 .63344 L .42259 .63522 L .653 .784 .944 r
F
.49669 .64301 m .48077 .63121 L .48102 .6375 L .848 .597 .559 r
F
0 g
.49669 .64301 m
.50847 .65032 L
s
.86441 .51389 m .87102 .49202 L .87139 .4999 L 0 0 .411 r
F
.86475 .52177 m .86441 .51389 L .87139 .4999 L F
.83479 .50758 m .86441 .51389 L .87139 .4999 L .644 .737 .917 r
F
0 g
.85782 .52029 m
.86441 .51389 L
s
.58247 .52121 m .56084 .50717 L .55017 .51419 L .642 .738 .919 r
F
.58931 .51869 m .56084 .50717 L .58247 .52121 L F
.62749 .52358 m .63902 .50542 L .62121 .52037 L F
.62749 .52358 m .65163 .51195 L .63902 .50542 L F
.38296 .75444 m .38494 .75559 L .38526 .76078 L .921 .685 .192 r
F
.38296 .75444 m .38263 .74923 L .38494 .75559 L F
.40186 .74797 m .38494 .75559 L .40333 .75222 L .656 .808 .956 r
F
.40186 .74797 m .38263 .74923 L .38494 .75559 L F
0 g
.38494 .75559 m
.38965 .75998 L
s
.42079 .74151 m .40317 .747 L .42149 .74364 L .657 .808 .956 r
F
.42079 .74151 m .40171 .74276 L .40317 .747 L F
.40409 .63942 m .38828 .63944 L .38838 .64573 L .523 .339 .573 r
F
0 g
.37659 .65366 m
.38838 .64573 L
s
.40409 .63942 m .40396 .63312 L .38828 .63944 L .523 .339 .573 r
F
0 g
.37651 .64739 m
.38828 .63944 L
s
.45823 .74122 m .47791 .73776 L .4589 .73901 L .657 .808 .956 r
F
0 g
.35035 .47066 m
.35367 .41219 L
s
.52972 .61862 m .53646 .62128 L .5368 .62754 L .986 .716 .411 r
F
.52972 .61862 m .52939 .61233 L .53646 .62128 L F
0 g
.53646 .62128 m
.54318 .62562 L
s
.47757 .75252 m .49813 .74684 L .47899 .74811 L .656 .809 .957 r
F
.45915 .75158 m .47757 .75252 L .47899 .74811 L F
.45722 .75372 m .47757 .75252 L .45915 .75158 L F
0 g
.34374 .47012 m
.34716 .41208 L
s
.55467 .60839 m .5368 .62118 L .55927 .61437 L .654 .782 .942 r
F
.55467 .60839 m .52977 .61227 L .5368 .62118 L F
.58646 .62266 m .57766 .63569 L .59156 .62454 L .653 .784 .944 r
F
.58646 .62266 m .56747 .632 L .57766 .63569 L F
.59744 .50941 m .59074 .49124 L .57491 .49413 L .643 .738 .918 r
F
.60575 .50923 m .59074 .49124 L .59744 .50941 L F
.55017 .51419 m .52292 .5036 L .51278 .51629 L .642 .738 .919 r
F
0 g
.50901 .53003 m
.51278 .51629 L
s
.61393 .51028 m .60753 .49085 L .60575 .50923 L .643 .738 .918 r
F
.61393 .51028 m .62409 .49299 L .60753 .49085 L F
.28095 .50104 m .25387 .51371 L .28413 .51063 L .641 .739 .92 r
F
.28095 .50104 m .24882 .49935 L .25387 .51371 L F
0 g
.25387 .51371 m
.26495 .5272 L
s
.66955 .63052 m .67818 .61496 L .67875 .62125 L .261 .157 .542 r
F
.64848 .62481 m .66955 .63052 L .67875 .62125 L .653 .784 .944 r
F
.6396 .6302 m .66955 .63052 L .64848 .62481 L F
0 g
.65621 .63852 m
.66955 .63052 L
s
.69745 .526 m .68993 .50447 L .68987 .51238 L .992 .738 .403 r
F
0 g
.69745 .526 m
.69851 .54001 L
s
.47791 .73776 m .49691 .73651 L .49524 .73007 L .657 .808 .956 r
F
.49766 .74166 m .4972 .73649 L .49552 .73002 L .847 .621 .078 r
F
0 g
.49542 .74181 m
.49688 .73744 L
s
.43847 .52342 m .44227 .50158 L .44164 .50949 L 0 0 .083 r
F
.40757 .51712 m .43847 .52342 L .44164 .50949 L .641 .739 .92 r
F
0 g
.4291 .53584 m
.43847 .52342 L
s
.5612 .49929 m .52337 .49571 L .55055 .50633 L .643 .738 .918 r
F
.60575 .50923 m .60753 .49085 L .59074 .49124 L F
.66096 .51213 m .67625 .49219 L .65177 .50405 L F
.66096 .51213 m .68993 .50447 L .67625 .49219 L F
.48077 .63121 m .48052 .62494 L .46209 .62163 L .788 .548 .575 r
F
0 g
.48052 .62494 m
.49615 .63049 L
s
.40221 .75317 m .38526 .76078 L .40368 .75741 L .656 .809 .957 r
F
.40221 .75317 m .38296 .75444 L .38526 .76078 L F
0 g
.38526 .76078 m
.39129 .76636 L
s
.42107 .7467 m .40333 .75222 L .42176 .74883 L .656 .808 .956 r
F
.42107 .7467 m .40186 .74797 L .40333 .75222 L F
.31401 .49484 m .28195 .49315 L .28513 .50277 L .642 .738 .919 r
F
.47791 .73776 m .49524 .73007 L .47673 .73348 L .657 .808 .956 r
F
.4589 .73901 m .47791 .73776 L .47673 .73348 L F
.45873 .7464 m .47854 .74292 L .45941 .74418 L .656 .808 .956 r
F
.40827 .50925 m .44227 .50158 L .4102 .4999 L .642 .738 .919 r
F
.37726 .5029 m .40827 .50925 L .4102 .4999 L F
.58931 .51869 m .57459 .50203 L .56084 .50717 L F
.59717 .51729 m .57459 .50203 L .58931 .51869 L F
.62121 .52037 m .62388 .50091 L .6137 .51815 L F
.62121 .52037 m .63902 .50542 L .62388 .50091 L F
.86475 .52177 m .87139 .4999 L .87175 .50781 L 0 0 .411 r
F
.83507 .51546 m .86475 .52177 L .87175 .50781 L .643 .738 .918 r
F
0 g
.85187 .53421 m
.86475 .52177 L
s
.53005 .62493 m .5368 .62754 L .53714 .63382 L .986 .716 .411 r
F
.53005 .62493 m .52972 .61862 L .5368 .62754 L F
.55479 .61472 m .5368 .62754 L .55942 .62071 L .654 .783 .943 r
F
.55479 .61472 m .52972 .61862 L .5368 .62754 L F
0 g
.5368 .62754 m
.54357 .63189 L
s
.4589 .73901 m .47673 .73348 L .45827 .73687 L .657 .808 .956 r
F
.37789 .49502 m .41059 .49201 L .37875 .49034 L .643 .738 .918 r
F
.49766 .74166 m .49552 .73002 L .49598 .73521 L .847 .621 .078 r
F
.47854 .74292 m .49766 .74166 L .49598 .73521 L .656 .808 .956 r
F
.49813 .74684 m .49766 .74166 L .49598 .73521 L .847 .621 .078 r
F
0 g
.49587 .74699 m
.49734 .74261 L
s
.62276 .62176 m .6396 .6302 L .64848 .62481 L .653 .784 .944 r
F
.61719 .6239 m .6396 .6302 L .62276 .62176 L F
.74292 .49314 m .71145 .50109 L .74315 .49797 L .644 .737 .917 r
F
.83479 .50758 m .87139 .4999 L .83927 .49821 L F
.42143 .7519 m .40368 .75741 L .42213 .75402 L .656 .809 .957 r
F
.42143 .7519 m .40221 .75317 L .40368 .75741 L F
.34363 .61591 m .3436 .60966 L .36341 .60787 L .675 .458 .584 r
F
.32357 .61511 m .3436 .60966 L .34363 .61591 L .732 .505 .583 r
F
.32357 .61511 m .32357 .60884 L .3436 .60966 L F
.47854 .74292 m .49598 .73521 L .47735 .73863 L .656 .808 .956 r
F
.45941 .74418 m .47854 .74292 L .47735 .73863 L F
.42244 .62891 m .40383 .62684 L .40396 .63312 L .61 .407 .582 r
F
.42244 .62891 m .42228 .62261 L .40383 .62684 L F
0 g
.38818 .63317 m
.40383 .62684 L
s
.45915 .75158 m .47899 .74811 L .45982 .74937 L .656 .809 .957 r
F
.48077 .63121 m .46209 .62163 L .46231 .62792 L .788 .548 .575 r
F
.48102 .6375 m .48077 .63121 L .46231 .62792 L F
0 g
.48077 .63121 m
.49642 .63674 L
s
.34261 .59672 m .34359 .60947 L .3633 .60769 L .656 .781 .94 r
F
.32921 .59617 m .34359 .60947 L .34261 .59672 L F
.32921 .59617 m .32366 .60866 L .34359 .60947 L F
0 g
.60714 .53412 m
.60803 .5684 L
s
.59717 .51729 m .59045 .49916 L .57459 .50203 L .642 .738 .919 r
F
.6055 .5171 m .59045 .49916 L .59717 .51729 L F
.6137 .51815 m .60728 .49877 L .6055 .5171 L F
.6137 .51815 m .62388 .50091 L .60728 .49877 L F
0 g
.60057 .53378 m
.60139 .5683 L
s
.36348 .61413 m .36341 .60787 L .38177 .6036 L .608 .405 .58 r
F
.34363 .61591 m .36341 .60787 L .36348 .61413 L .675 .458 .584 r
F
0 g
.3436 .60966 m
.36341 .60787 L
s
.4214 .73929 m .40171 .74276 L .42079 .74151 L .657 .808 .956 r
F
.56084 .50717 m .52292 .5036 L .55017 .51419 L .642 .738 .919 r
F
.54621 .4783 m .53769 .47713 L .55485 .47544 L .67 .439 .562 r
F
.56177 .49158 m .54167 .47841 L .52422 .48802 L .644 .737 .917 r
F
.54167 .47841 m .53829 .47849 L .52422 .48802 L F
.534 .48597 m .53762 .47851 L .52381 .48786 L .362 .186 .503 r
F
.53726 .48537 m .53734 .48371 L .534 .48597 L F
.53734 .48371 m .53762 .47851 L .534 .48597 L F
.52934 .4839 m .52963 .4787 L .53539 .47856 L .67 .439 .562 r
F
.52963 .4787 m .52977 .47604 L .54621 .4783 L F
.57538 .48643 m .54792 .47936 L .56177 .49158 L .644 .737 .917 r
F
.54792 .47936 m .54401 .47836 L .54418 .48005 L F
.54401 .47836 m .54167 .47841 L .54418 .48005 L F
.54792 .47936 m .54418 .48005 L .56177 .49158 L F
.54621 .4783 m .55485 .47544 L .55472 .4781 L .67 .439 .562 r
F
.5704 .47519 m .55485 .47544 L .57857 .47103 L .598 .379 .554 r
F
.55472 .4781 m .55485 .47544 L .5704 .47519 L F
.53769 .47713 m .53776 .47585 L .55485 .47544 L .67 .439 .562 r
F
.5307 .45692 m .52979 .47576 L .55474 .47516 L .644 .737 .916 r
F
.54752 .45651 m .55474 .47516 L .57835 .47077 L F
.5307 .45692 m .55474 .47516 L .54752 .45651 L F
.54792 .47936 m .56052 .46945 L .54001 .47733 L .644 .737 .917 r
F
.57538 .48643 m .56623 .47597 L .54792 .47936 L F
.56623 .47597 m .56052 .46945 L .54792 .47936 L F
.5704 .47519 m .57857 .47103 L .57846 .4737 L .598 .379 .554 r
F
.59109 .48354 m .57369 .47552 L .57538 .48643 L .644 .737 .917 r
F
.57369 .47552 m .56052 .46945 L .5678 .47777 L F
.57369 .47552 m .5678 .47777 L .57538 .48643 L F
.59225 .46844 m .57857 .47103 L .59945 .46305 L .507 .304 .539 r
F
.57846 .4737 m .57857 .47103 L .59225 .46844 L F
.54752 .45651 m .57835 .47077 L .5634 .45351 L .644 .737 .916 r
F
.5634 .45351 m .57835 .47077 L .59912 .46283 L F
.57369 .47552 m .58429 .46501 L .56052 .46945 L .644 .737 .917 r
F
.59109 .48354 m .58637 .47068 L .57369 .47552 L F
.58637 .47068 m .58429 .46501 L .57369 .47552 L F
.60777 .48315 m .58429 .46501 L .59109 .48354 L F
.59225 .46844 m .59945 .46305 L .59936 .46573 L .507 .304 .539 r
F
.60777 .48315 m .60958 .46439 L .60106 .4646 L .644 .737 .917 r
F
.59936 .46573 m .59945 .46305 L .60157 .46215 L .372 .196 .509 r
F
.6015 .46431 m .60157 .46215 L .61036 .45842 L F
.59936 .46573 m .60157 .46215 L .6015 .46431 L F
.62419 .48528 m .60958 .46439 L .60777 .48315 L .644 .737 .917 r
F
.62419 .48528 m .6345 .46765 L .60958 .46439 L F
.60669 .46942 m .60961 .46411 L .6015 .46431 L .669 .437 .56 r
F
.60777 .48315 m .60106 .4646 L .59176 .47078 L .644 .737 .917 r
F
.60936 .47204 m .6015 .46431 L .60132 .46971 L .669 .437 .56 r
F
.59918 .47097 m .59936 .46573 L .6015 .46431 L .372 .196 .509 r
F
.60136 .46852 m .6015 .46431 L .61036 .45842 L F
.59918 .47097 m .6015 .46431 L .60136 .46852 L F
.59176 .47078 m .60106 .4646 L .58429 .46501 L .644 .737 .917 r
F
.57825 .47892 m .59225 .46844 L .59918 .47097 L .507 .304 .539 r
F
.59225 .46844 m .59936 .46573 L .59918 .47097 L F
.57825 .47892 m .57846 .4737 L .59225 .46844 L F
.59196 .47636 m .57825 .47892 L .59918 .47097 L F
.59074 .49124 m .57354 .48335 L .57491 .49413 L .643 .738 .918 r
F
.57814 .4816 m .57825 .47892 L .59196 .47636 L .507 .304 .539 r
F
.55448 .48331 m .5704 .47519 L .57825 .47892 L .598 .379 .554 r
F
.5704 .47519 m .57846 .4737 L .57825 .47892 L F
.55448 .48331 m .55472 .4781 L .5704 .47519 L F
.57006 .48309 m .55448 .48331 L .57825 .47892 L F
.54621 .4783 m .55472 .4781 L .55448 .48331 L .67 .439 .562 r
F
.56605 .4733 m .55448 .48331 L .57825 .47892 L .643 .737 .917 r
F
.5636 .47375 m .55448 .48331 L .56605 .4733 L F
.57585 .47148 m .56029 .46919 L .56005 .47441 L .598 .377 .553 r
F
.55219 .47742 m .55448 .48331 L .56465 .47265 L .643 .737 .917 r
F
.55303 .4771 m .56029 .46919 L .53968 .47711 L .504 .301 .537 r
F
.56005 .47441 m .56029 .46919 L .55303 .4771 L F
.57585 .47148 m .58419 .46473 L .56029 .46919 L .598 .377 .553 r
F
.58398 .46997 m .58419 .46473 L .57585 .47148 L F
.59436 .46971 m .57825 .47892 L .59918 .47097 L .643 .737 .917 r
F
.59544 .46969 m .58419 .46473 L .58398 .46997 L .669 .437 .56 r
F
.56319 .46161 m .57074 .47029 L .59436 .46971 L .643 .737 .917 r
F
.57074 .47029 m .57825 .47892 L .59436 .46971 L F
.59074 .49124 m .5866 .48004 L .57215 .48271 L .643 .738 .918 r
F
.60753 .49085 m .58977 .47719 L .59074 .49124 L F
.58977 .47719 m .58607 .47859 L .59074 .49124 L F
.59196 .47636 m .59918 .47097 L .59909 .47366 L .507 .304 .539 r
F
.60753 .49085 m .60936 .47204 L .60123 .47224 L .643 .738 .918 r
F
.60936 .47204 m .60132 .46971 L .60123 .47224 L .669 .437 .56 r
F
.60945 .46935 m .60961 .46411 L .60669 .46942 L F
.63919 .48978 m .6345 .46765 L .62419 .48528 L .644 .737 .917 r
F
.63447 .47531 m .60961 .46411 L .60936 .47204 L .732 .49 .562 r
F
.59909 .47366 m .59918 .47097 L .60131 .47007 L .372 .196 .509 r
F
.60123 .47224 m .60131 .47007 L .61012 .46637 L F
.59909 .47366 m .60131 .47007 L .60123 .47224 L F
.62409 .49299 m .60936 .47204 L .60753 .49085 L .643 .738 .918 r
F
.60644 .47737 m .60936 .47204 L .60123 .47224 L .669 .437 .56 r
F
.60753 .49085 m .60123 .47224 L .59161 .4786 L .643 .738 .918 r
F
.60911 .48001 m .60123 .47224 L .60105 .47766 L .669 .437 .56 r
F
.60936 .47204 m .60945 .46935 L .60669 .46942 L F
.59891 .47892 m .59909 .47366 L .60123 .47224 L .372 .196 .509 r
F
.60109 .47647 m .60123 .47224 L .61012 .46637 L F
.59891 .47892 m .60123 .47224 L .60109 .47647 L F
.59161 .4786 m .60123 .47224 L .58388 .47266 L .643 .738 .918 r
F
.57793 .48684 m .59196 .47636 L .59891 .47892 L .507 .304 .539 r
F
.59196 .47636 m .59909 .47366 L .59891 .47892 L F
.58977 .47719 m .58388 .47266 L .58607 .47859 L .643 .738 .918 r
F
.56605 .4733 m .57825 .47892 L .57234 .47213 L .643 .737 .917 r
F
.57354 .48335 m .57215 .48271 L .56746 .48565 L .643 .738 .918 r
F
.57215 .48271 m .56588 .48386 L .56746 .48565 L F
.57354 .48335 m .56746 .48565 L .57491 .49413 L F
.57491 .49413 m .54408 .48622 L .5612 .49929 L F
.54582 .48618 m .53728 .485 L .55448 .48331 L .67 .439 .562 r
F
.53728 .485 m .52934 .4839 L .53734 .48371 L F
.53728 .485 m .53734 .48371 L .55448 .48331 L F
.5372 .48639 m .52381 .48786 L .52337 .49571 L .362 .186 .503 r
F
.53726 .48537 m .52381 .48786 L .5372 .48639 L F
.5292 .48657 m .52934 .4839 L .53728 .485 L .67 .439 .562 r
F
.5372 .48639 m .53728 .485 L .54582 .48618 L F
.5292 .48657 m .53728 .485 L .5372 .48639 L F
.5612 .49929 m .54126 .48629 L .52337 .49571 L .643 .738 .918 r
F
.54126 .48629 m .53927 .48499 L .5372 .48639 L F
.54126 .48629 m .5372 .48639 L .52337 .49571 L F
.53358 .49387 m .5372 .48639 L .52337 .49571 L .362 .186 .503 r
F
.53693 .49161 m .5372 .48639 L .53358 .49387 L F
.52891 .4918 m .53706 .48909 L .53693 .49161 L .67 .439 .562 r
F
.52891 .4918 m .5292 .48657 L .53496 .48644 L F
.54408 .48622 m .54126 .48629 L .5612 .49929 L .643 .738 .918 r
F
.54582 .48618 m .55448 .48331 L .55435 .48598 L .67 .439 .562 r
F
.55435 .48598 m .55448 .48331 L .57006 .48309 L .598 .379 .554 r
F
.52934 .4839 m .54621 .4783 L .55448 .48331 L .67 .439 .562 r
F
.54401 .47836 m .54001 .47733 L .54167 .47841 L .644 .737 .917 r
F
.52934 .4839 m .53539 .47856 L .54621 .4783 L .67 .439 .562 r
F
.54167 .47841 m .54001 .47733 L .53829 .47849 L .644 .737 .917 r
F
.55303 .4771 m .53968 .47711 L .53941 .48232 L .504 .301 .537 r
F
.54667 .47742 m .53734 .48371 L .55448 .48331 L .643 .737 .917 r
F
.514 .45474 m .52979 .47576 L .5307 .45692 L .644 .737 .916 r
F
.53025 .46503 m .55448 .48331 L .5472 .46461 L .643 .737 .917 r
F
.57491 .49413 m .55993 .4771 L .53927 .48499 L .643 .738 .918 r
F
.52891 .4918 m .53496 .48644 L .54582 .48618 L .67 .439 .562 r
F
.53769 .47713 m .52977 .47604 L .53776 .47585 L F
.5044 .48068 m .52977 .47604 L .52934 .4839 L .731 .492 .565 r
F
.5044 .48068 m .50488 .47281 L .52977 .47604 L F
.514 .45474 m .50502 .47254 L .52979 .47576 L .644 .737 .916 r
F
.53025 .46503 m .52934 .4839 L .53734 .48371 L .643 .737 .917 r
F
.5039 .48858 m .52934 .4839 L .52891 .4918 L .731 .492 .565 r
F
.5039 .48858 m .5044 .48068 L .52934 .4839 L F
.51344 .46284 m .52934 .4839 L .53025 .46503 L .643 .737 .917 r
F
.51344 .46284 m .5044 .48068 L .52934 .4839 L F
.52982 .47297 m .52891 .4918 L .53693 .49161 L .642 .738 .918 r
F
.53693 .49161 m .54582 .48618 L .5541 .49122 L .67 .439 .562 r
F
.53706 .48909 m .54582 .48618 L .53693 .49161 L F
.54582 .48618 m .55435 .48598 L .5541 .49122 L F
.54814 .48674 m .53693 .49161 L .5541 .49122 L .642 .738 .918 r
F
.5541 .49122 m .55435 .48598 L .57006 .48309 L .598 .379 .554 r
F
.54408 .48622 m .53927 .48499 L .54126 .48629 L .643 .738 .918 r
F
.55265 .48502 m .53927 .48499 L .539 .49022 L .504 .301 .537 r
F
.5541 .49122 m .57006 .48309 L .57793 .48684 L .598 .379 .554 r
F
.57006 .48309 m .57825 .47892 L .57814 .4816 L F
.57215 .48271 m .55993 .4771 L .56588 .48386 L .643 .738 .918 r
F
.55993 .4771 m .56005 .47441 L .55303 .4771 L .504 .301 .537 r
F
.5472 .46461 m .55219 .47742 L .56465 .47265 L .643 .737 .917 r
F
.55993 .4771 m .55303 .4771 L .53927 .48499 L .504 .301 .537 r
F
.55303 .4771 m .53941 .48232 L .53927 .48499 L F
.5657 .48123 m .5541 .49122 L .57793 .48684 L .642 .738 .918 r
F
.56324 .48169 m .5541 .49122 L .5657 .48123 L F
.57215 .48271 m .58388 .47266 L .55993 .4771 L .643 .738 .918 r
F
.57552 .47942 m .55993 .4771 L .55969 .48234 L .598 .377 .553 r
F
.5518 .48535 m .5541 .49122 L .56429 .48059 L .642 .738 .918 r
F
.57006 .48309 m .57814 .4816 L .57793 .48684 L .598 .379 .554 r
F
.58352 .48061 m .57591 .47948 L .57215 .48271 L .643 .738 .918 r
F
.5866 .48004 m .57591 .47948 L .58352 .48061 L F
.5866 .48004 m .58388 .47266 L .57591 .47948 L F
.57793 .48684 m .57814 .4816 L .59196 .47636 L .507 .304 .539 r
F
.59408 .47767 m .57793 .48684 L .59891 .47892 L .642 .738 .918 r
F
.59516 .47764 m .58388 .47266 L .58367 .47792 L .669 .437 .56 r
F
.56465 .47265 m .56605 .4733 L .57076 .47031 L .643 .737 .917 r
F
.56605 .4733 m .57234 .47213 L .57076 .47031 L F
.5472 .46461 m .56465 .47265 L .56319 .46161 L F
.56465 .47265 m .57076 .47031 L .56319 .46161 L F
.58388 .47266 m .57585 .47148 L .55993 .4771 L .598 .377 .553 r
F
.57585 .47148 m .56005 .47441 L .55993 .4771 L F
.57552 .47942 m .58388 .47266 L .55993 .4771 L F
.58367 .47792 m .58388 .47266 L .57552 .47942 L F
.5704 .47823 m .57793 .48684 L .59408 .47767 L .642 .738 .918 r
F
.58357 .48062 m .58367 .47792 L .57552 .47942 L .598 .377 .553 r
F
.56283 .46958 m .5704 .47823 L .58367 .47792 L .642 .738 .918 r
F
.59031 .47669 m .58367 .47792 L .59408 .47767 L F
.56283 .46958 m .58367 .47792 L .59031 .47669 L F
.63919 .48978 m .65718 .47453 L .6345 .46765 L .644 .737 .917 r
F
.63447 .47531 m .63466 .46738 L .60961 .46411 L .732 .49 .562 r
F
.59891 .47892 m .61589 .4599 L .61566 .46788 L .372 .196 .509 r
F
.60054 .47751 m .58388 .47266 L .59516 .47764 L .669 .437 .56 r
F
.60054 .47751 m .60123 .47224 L .58388 .47266 L F
.59693 .4776 m .59891 .47892 L .60106 .4775 L .642 .738 .918 r
F
.60105 .47766 m .60106 .4775 L .60054 .47751 L .669 .437 .56 r
F
.60106 .4775 m .60123 .47224 L .60054 .47751 L F
.59918 .47097 m .61612 .45195 L .61589 .4599 L .372 .196 .509 r
F
.60081 .46956 m .58419 .46473 L .59544 .46969 L .669 .437 .56 r
F
.60081 .46956 m .6015 .46431 L .58419 .46473 L F
.61012 .46637 m .59918 .47097 L .61589 .4599 L .372 .196 .509 r
F
.59721 .46965 m .59918 .47097 L .60133 .46955 L .643 .737 .917 r
F
.60132 .46971 m .60133 .46955 L .60081 .46956 L .669 .437 .56 r
F
.60133 .46955 m .6015 .46431 L .60081 .46956 L F
.5634 .45351 m .59912 .46283 L .57731 .44811 L .644 .737 .916 r
F
.56319 .46161 m .59436 .46971 L .5772 .4562 L .643 .737 .917 r
F
.59436 .46971 m .59918 .47097 L .59721 .46965 L F
.59436 .46971 m .59721 .46965 L .5772 .4562 L F
.60132 .46971 m .60081 .46956 L .60123 .47224 L .669 .437 .56 r
F
.60081 .46956 m .59544 .46969 L .60123 .47224 L F
.60123 .47224 m .59544 .46969 L .58388 .47266 L F
.59544 .46969 m .58398 .46997 L .58388 .47266 L F
.58388 .47266 m .58398 .46997 L .57585 .47148 L .598 .377 .553 r
F
.56283 .46958 m .59408 .47767 L .57688 .46418 L .642 .738 .918 r
F
.59408 .47767 m .59891 .47892 L .59693 .4776 L F
.59408 .47767 m .59693 .4776 L .57688 .46418 L F
.60105 .47766 m .60054 .47751 L .60097 .48021 L .669 .437 .56 r
F
.60054 .47751 m .59516 .47764 L .60097 .48021 L F
.60097 .48021 m .59516 .47764 L .58357 .48062 L F
.59516 .47764 m .58367 .47792 L .58357 .48062 L F
.55265 .48502 m .55993 .4771 L .53927 .48499 L .504 .301 .537 r
F
.55969 .48234 m .55993 .4771 L .55265 .48502 L F
.56465 .47265 m .5636 .47375 L .56605 .4733 L .643 .737 .917 r
F
.5468 .47256 m .57793 .48684 L .56283 .46958 L .642 .738 .918 r
F
.58357 .48062 m .57552 .47942 L .55956 .48504 L .598 .377 .553 r
F
.57552 .47942 m .55969 .48234 L .55956 .48504 L F
.56429 .48059 m .56324 .48169 L .5657 .48123 L .642 .738 .918 r
F
.5468 .47256 m .5518 .48535 L .56429 .48059 L F
.55956 .48504 m .55969 .48234 L .55265 .48502 L .504 .301 .537 r
F
.53927 .48499 m .53968 .47711 L .53762 .47851 L .362 .186 .503 r
F
.53927 .48499 m .53762 .47851 L .53726 .48537 L F
.53025 .46503 m .53734 .48371 L .54667 .47742 L .643 .737 .917 r
F
.52982 .47297 m .5541 .49122 L .5468 .47256 L .642 .738 .918 r
F
.55956 .48504 m .55265 .48502 L .53886 .49291 L .504 .301 .537 r
F
.539 .49022 m .53693 .49161 L .54814 .48674 L .642 .738 .918 r
F
.55265 .48502 m .539 .49022 L .53886 .49291 L .504 .301 .537 r
F
.54628 .48534 m .539 .49022 L .54814 .48674 L .642 .738 .918 r
F
.53886 .49291 m .53927 .48499 L .5372 .48639 L .362 .186 .503 r
F
.53886 .49291 m .5372 .48639 L .53684 .49328 L F
.53927 .48499 m .53726 .48537 L .5372 .48639 L F
.52982 .47297 m .53693 .49161 L .54628 .48534 L .642 .738 .918 r
F
.53684 .49328 m .53693 .49161 L .53358 .49387 L .362 .186 .503 r
F
.60911 .48001 m .60105 .47766 L .60097 .48021 L .669 .437 .56 r
F
.61036 .45842 m .59945 .46305 L .61612 .45195 L .372 .196 .509 r
F
.57731 .44811 m .59912 .46283 L .61571 .45178 L .644 .737 .916 r
F
.5772 .4562 m .59721 .46965 L .61589 .4599 L .643 .737 .917 r
F
.59721 .46965 m .60133 .46955 L .61589 .4599 L F
.57688 .46418 m .59693 .4776 L .61566 .46788 L .642 .738 .918 r
F
.59693 .4776 m .60106 .4775 L .61566 .46788 L F
.60911 .48001 m .6092 .47731 L .60644 .47737 L .669 .437 .56 r
F
.6092 .47731 m .60936 .47204 L .60644 .47737 L F
.45941 .74418 m .47735 .73863 L .45878 .74204 L .656 .808 .956 r
F
.6055 .5171 m .60728 .49877 L .59045 .49916 L .642 .738 .919 r
F
.35588 .59552 m .3633 .60769 L .38157 .60344 L .656 .781 .94 r
F
.34261 .59672 m .3633 .60769 L .35588 .59552 L F
.66083 .52001 m .67616 .50013 L .65163 .51195 L .642 .738 .919 r
F
.66083 .52001 m .68987 .51238 L .67616 .50013 L F
.49813 .74684 m .49598 .73521 L .49645 .74041 L .847 .621 .078 r
F
.47899 .74811 m .49813 .74684 L .49645 .74041 L .656 .809 .957 r
F
0 g
.4959 .75346 m
.49813 .74684 L
s
.60803 .5684 m
.60853 .5877 L
s
.65168 .4963 m .65718 .47453 L .63919 .48978 L .644 .737 .917 r
F
.65168 .4963 m .67597 .48447 L .65718 .47453 L F
0 g
.60139 .5683 m
.60186 .588 L
s
.55517 .62104 m .53714 .63382 L .55979 .62701 L .653 .784 .944 r
F
.55517 .62104 m .53005 .62493 L .53714 .63382 L F
0 g
.53714 .63382 m
.54872 .64122 L
s
.77125 .61434 m .77054 .60808 L .79061 .6063 L .676 .461 .586 r
F
.75177 .61353 m .77054 .60808 L .77125 .61434 L .732 .502 .578 r
F
.75177 .61353 m .75108 .60727 L .77054 .60808 L F
.31308 .50273 m .28413 .51063 L .31458 .50753 L .641 .739 .92 r
F
.31308 .50273 m .28095 .50104 L .28413 .51063 L F
.77365 .59512 m .77058 .60789 L .79055 .60611 L .654 .782 .942 r
F
.76063 .59456 m .77058 .60789 L .77365 .59512 L F
.76063 .59456 m .75122 .60708 L .77058 .60789 L F
.58264 .62014 m .56747 .632 L .58646 .62266 L .653 .784 .944 r
F
.58264 .62014 m .55979 .62701 L .56747 .632 L F
.40285 .73832 m .3826 .74402 L .40171 .74276 L .657 .808 .956 r
F
.4214 .73929 m .40285 .73832 L .40171 .74276 L F
.40757 .51712 m .44164 .50949 L .4095 .5078 L .641 .739 .92 r
F
.37648 .51079 m .40757 .51712 L .4095 .5078 L F
.3735 .51501 m .40757 .51712 L .37648 .51079 L F
.45827 .73687 m .47301 .72963 L .45638 .73496 L .657 .808 .956 r
F
.45827 .73687 m .47673 .73348 L .47301 .72963 L F
.47899 .74811 m .49645 .74041 L .4778 .74383 L .656 .809 .957 r
F
.45982 .74937 m .47899 .74811 L .4778 .74383 L F
.30455 .61175 m .32357 .60884 L .32357 .61511 L .786 .55 .578 r
F
.30455 .61175 m .30459 .60548 L .32357 .60884 L F
0 g
.32357 .60884 m
.3436 .60966 L
s
.31652 .59389 m .32366 .60866 L .32921 .59617 L .656 .781 .94 r
F
.31652 .59389 m .30476 .6053 L .32366 .60866 L F
.79136 .61256 m .79061 .6063 L .81003 .60202 L .616 .418 .591 r
F
.77125 .61434 m .79061 .6063 L .79136 .61256 L .676 .461 .586 r
F
0 g
.77054 .60808 m
.79061 .6063 L
s
.34366 .62219 m .34363 .61591 L .36348 .61413 L .675 .458 .584 r
F
.32357 .62139 m .34363 .61591 L .34366 .62219 L .732 .505 .583 r
F
.32357 .62139 m .32357 .61511 L .34363 .61591 L F
.34265 .60315 m .34363 .61591 L .36348 .61413 L .655 .781 .941 r
F
.32915 .60259 m .34363 .61591 L .34265 .60315 L F
.32915 .60259 m .32357 .61511 L .34363 .61591 L F
.67818 .61496 m .67761 .6087 L .68194 .59869 L 0 0 .427 r
F
0 g
.67057 .61586 m
.67761 .6087 L
s
.78709 .59392 m .79055 .60611 L .80988 .60186 L .654 .782 .942 r
F
.77365 .59512 m .79055 .60611 L .78709 .59392 L F
0 g
.51371 .50062 m
.52145 .49084 L
s
.40285 .73832 m .38422 .73734 L .3826 .74402 L .657 .808 .956 r
F
.38426 .74254 m .38231 .74404 L .38263 .74923 L 0 0 .284 r
F
0 g
.38326 .74665 m
.38416 .74913 L
s
.38426 .74254 m .38393 .73733 L .38231 .74404 L 0 0 .284 r
F
.42259 .63522 m .40396 .63312 L .40409 .63942 L .61 .407 .582 r
F
0 g
.38838 .64573 m
.40409 .63942 L
s
.42259 .63522 m .42244 .62891 L .40396 .63312 L .61 .407 .582 r
F
0 g
.38828 .63944 m
.40396 .63312 L
s
.46231 .62792 m .46209 .62163 L .44219 .62083 L .732 .504 .582 r
F
0 g
.46209 .62163 m
.48052 .62494 L
s
.48102 .6375 m .46231 .62792 L .46253 .63422 L .788 .548 .575 r
F
0 g
.48102 .6375 m
.49669 .64301 L
s
.64796 .61853 m .67818 .61496 L .654 .61228 L .654 .783 .943 r
F
.37726 .5029 m .4102 .4999 L .37814 .49821 L .642 .738 .919 r
F
.42167 .74448 m .40186 .74797 L .42107 .7467 L .656 .808 .956 r
F
0 g
.67838 .48613 m
.6797 .48732 L
s
.45982 .74937 m .4778 .74383 L .45919 .74724 L .656 .809 .957 r
F
.74299 .50104 m .71144 .50896 L .74321 .50585 L .643 .738 .918 r
F
.74299 .50104 m .7108 .49935 L .71144 .50896 L F
.57968 .60448 m .55467 .60839 L .55927 .61437 L .654 .782 .942 r
F
.83507 .51546 m .87175 .50781 L .83956 .50612 L .643 .738 .918 r
F
.80521 .50911 m .83507 .51546 L .83956 .50612 L F
.80103 .51334 m .83507 .51546 L .80521 .50911 L F
.36348 .61413 m .38177 .6036 L .38186 .60987 L .608 .405 .58 r
F
.36354 .62041 m .36348 .61413 L .38186 .60987 L F
.34366 .62219 m .36348 .61413 L .36354 .62041 L .675 .458 .584 r
F
.356 .60194 m .36348 .61413 L .38186 .60987 L .655 .781 .941 r
F
.34265 .60315 m .36348 .61413 L .356 .60194 L F
0 g
.34363 .61591 m
.36348 .61413 L
s
.25139 .47716 m .25097 .48362 L .2499 .49146 L .739 .676 .127 r
F
.25139 .47716 m .25247 .46927 L .25097 .48362 L F
0 g
.25097 .48362 m
.25376 .49167 L
s
.28445 .47584 m .25145 .48364 L .28327 .48532 L .643 .738 .918 r
F
.28445 .47584 m .25294 .46937 L .25145 .48364 L F
.31578 .48227 m .28327 .48532 L .3151 .48699 L F
.31578 .48227 m .28445 .47584 L .28327 .48532 L F
.73411 .61017 m .75108 .60727 L .75177 .61353 L .792 .545 .564 r
F
.73411 .61017 m .73345 .60389 L .75108 .60727 L F
0 g
.75108 .60727 m
.77054 .60808 L
s
.42327 .73713 m .40285 .73832 L .4214 .73929 L .657 .808 .956 r
F
.40301 .74351 m .38263 .74923 L .40186 .74797 L .656 .808 .956 r
F
.42167 .74448 m .40301 .74351 L .40186 .74797 L F
.37875 .49034 m .40816 .48234 L .37745 .48551 L .643 .738 .918 r
F
.37875 .49034 m .41059 .49201 L .40816 .48234 L F
.74886 .59228 m .75122 .60708 L .76063 .59456 L .654 .782 .942 r
F
.74886 .59228 m .73368 .60372 L .75122 .60708 L F
.41059 .49201 m .43906 .47915 L .40816 .48234 L .643 .738 .918 r
F
.41059 .49201 m .44242 .49369 L .43906 .47915 L F
.45878 .74204 m .47361 .73478 L .45688 .74012 L .656 .808 .956 r
F
.45878 .74204 m .47735 .73863 L .47361 .73478 L F
.47673 .73348 m .48974 .72427 L .47301 .72963 L .657 .808 .956 r
F
.47673 .73348 m .49524 .73007 L .48974 .72427 L F
.44227 .50158 m .4429 .49371 L .43953 .47911 L .958 .771 .322 r
F
0 g
.44114 .50152 m
.44187 .49828 L
s
.44238 .62713 m .42228 .62261 L .42244 .62891 L .675 .459 .584 r
F
.44238 .62713 m .44219 .62083 L .42228 .62261 L F
0 g
.40383 .62684 m
.42228 .62261 L
s
.77197 .62062 m .77125 .61434 L .79136 .61256 L .676 .461 .586 r
F
.75245 .61982 m .77125 .61434 L .77197 .62062 L .732 .502 .578 r
F
.75245 .61982 m .75177 .61353 L .77125 .61434 L F
.77435 .60155 m .77125 .61434 L .79136 .61256 L .653 .783 .943 r
F
.76124 .60099 m .77125 .61434 L .77435 .60155 L F
.76124 .60099 m .75177 .61353 L .77125 .61434 L F
.40301 .74351 m .38426 .74254 L .38263 .74923 L .656 .808 .956 r
F
.38458 .74777 m .38263 .74923 L .38296 .75444 L 0 0 .284 r
F
0 g
.38359 .75185 m
.38449 .75434 L
s
.38458 .74777 m .38426 .74254 L .38263 .74923 L 0 0 .284 r
F
.30452 .61805 m .32357 .61511 L .32357 .62139 L .786 .55 .578 r
F
.30452 .61805 m .30455 .61175 L .32357 .61511 L F
.31639 .60031 m .32357 .61511 L .32915 .60259 L .655 .781 .941 r
F
.31639 .60031 m .30455 .61175 L .32357 .61511 L F
0 g
.32357 .61511 m
.34363 .61591 L
s
.38186 .60987 m .38177 .6036 L .39751 .5971 L .52 .335 .571 r
F
0 g
.3702 .60629 m
.38177 .6036 L
s
.45638 .73496 m .46698 .72649 L .45335 .7334 L .657 .808 .956 r
F
.45638 .73496 m .47301 .72963 L .46698 .72649 L F
.42204 .74969 m .40221 .75317 L .42143 .7519 L .656 .809 .957 r
F
.46231 .62792 m .44219 .62083 L .44238 .62713 L .732 .504 .582 r
F
0 g
.42228 .62261 m
.44219 .62083 L
s
.44219 .62083 m
.46209 .62163 L
s
.36815 .59265 m .38157 .60344 L .39723 .59697 L .656 .781 .94 r
F
.35588 .59552 m .38157 .60344 L .36815 .59265 L F
.79136 .61256 m .81003 .60202 L .81081 .60829 L .616 .418 .591 r
F
.79211 .61884 m .79136 .61256 L .81081 .60829 L F
.77197 .62062 m .79136 .61256 L .79211 .61884 L .676 .461 .586 r
F
.78788 .60034 m .79136 .61256 L .81081 .60829 L .653 .783 .943 r
F
.77435 .60155 m .79136 .61256 L .78788 .60034 L F
0 g
.77125 .61434 m
.79136 .61256 L
s
.65177 .50405 m .65732 .48221 L .63919 .49751 L .643 .738 .918 r
F
.65177 .50405 m .67625 .49219 L .65732 .48221 L F
.34268 .60946 m .34366 .62219 L .36354 .62041 L .654 .782 .942 r
F
.32916 .60891 m .34366 .62219 L .34268 .60946 L F
.32916 .60891 m .32357 .62139 L .34366 .62219 L F
.67818 .61496 m .68194 .59869 L .68252 .60499 L 0 0 .427 r
F
.67875 .62125 m .67818 .61496 L .68252 .60499 L F
.654 .61228 m .67818 .61496 L .68252 .60499 L .654 .783 .943 r
F
0 g
.67108 .62215 m
.67818 .61496 L
s
.68407 .47543 m .68414 .46754 L .67879 .48192 L 0 0 .293 r
F
.46253 .63422 m .46231 .62792 L .44238 .62713 L .732 .504 .582 r
F
0 g
.46231 .62792 m
.48077 .63121 L
s
.64848 .62481 m .67875 .62125 L .65454 .61858 L .653 .784 .944 r
F
.6272 .61903 m .64848 .62481 L .65454 .61858 L F
.62276 .62176 m .64848 .62481 L .6272 .61903 L F
.80677 .48865 m .83878 .48063 L .80674 .48381 L .644 .736 .916 r
F
.80677 .48865 m .83866 .49032 L .83878 .48063 L F
.83866 .49032 m .87101 .47743 L .83878 .48063 L F
.83866 .49032 m .87054 .492 L .87101 .47743 L F
.87139 .4999 m .87102 .49202 L .8715 .47739 L 0 0 .109 r
F
0 g
.86723 .49968 m
.87102 .49202 L
s
.57996 .61081 m .55479 .61472 L .55942 .62071 L .654 .783 .943 r
F
.42355 .74231 m .40301 .74351 L .42167 .74448 L .656 .808 .956 r
F
.40336 .74873 m .38296 .75444 L .40221 .75317 L .656 .809 .957 r
F
.42204 .74969 m .40336 .74873 L .40221 .75317 L F
.36354 .62041 m .38186 .60987 L .38195 .61615 L .608 .405 .58 r
F
.35605 .60826 m .36354 .62041 L .38195 .61615 L .654 .782 .942 r
F
.34268 .60946 m .36354 .62041 L .35605 .60826 L F
0 g
.34366 .62219 m
.36354 .62041 L
s
.45919 .74724 m .47405 .73999 L .45729 .74533 L .656 .809 .957 r
F
.45919 .74724 m .4778 .74383 L .47405 .73999 L F
.47735 .73863 m .49045 .72939 L .47361 .73478 L .656 .808 .956 r
F
.47735 .73863 m .49598 .73521 L .49045 .72939 L F
.49598 .73521 m .49552 .73002 L .48999 .72418 L .982 .702 .404 r
F
0 g
.49552 .73002 m
.4972 .73649 L
s
.73478 .61647 m .75177 .61353 L .75245 .61982 L .792 .545 .564 r
F
.73478 .61647 m .73411 .61017 L .75177 .61353 L F
.7494 .59871 m .75177 .61353 L .76124 .60099 L .653 .783 .943 r
F
.7494 .59871 m .73411 .61017 L .75177 .61353 L F
0 g
.75177 .61353 m
.77125 .61434 L
s
.43928 .83181 m .43934 .83724 L .44602 .83728 L .594 .768 .963 r
F
.43592 .83142 m .43934 .83724 L .43928 .83181 L F
.43928 .83181 m .44602 .83728 L .44263 .83182 L F
.44085 .82895 m .43928 .83181 L .44263 .83182 L F
.44052 .82841 m .44001 .82981 L .44085 .82895 L F
.44001 .82981 m .43928 .83181 L .44085 .82895 L F
.44041 .76201 m .44029 .82822 L .43874 .82828 L .651 .424 .562 r
F
.44375 .76106 m .44416 .76053 L .44255 .82721 L .095 0 .426 r
F
.44231 .82875 m .44263 .83182 L .44576 .83146 L .594 .768 .963 r
F
.4416 .82819 m .44211 .83 L .44231 .82875 L F
.44211 .83 m .44263 .83182 L .44231 .82875 L F
.44041 .76201 m .44202 .76185 L .44038 .82822 L .651 .424 .562 r
F
.44041 .76201 m .44038 .82822 L .44029 .82822 L F
.44305 .76151 m .44209 .82766 L .44142 .82798 L .387 .212 .518 r
F
.44416 .76053 m .44424 .75989 L .44263 .82668 L 0 0 .082 r
F
.44245 .82787 m .44576 .83146 L .44604 .83138 L .594 .768 .963 r
F
.44405 .82864 m .44604 .83138 L .44844 .83075 L F
.44245 .82787 m .44604 .83138 L .44405 .82864 L F
.44243 .82795 m .44576 .83146 L .44245 .82787 L F
.44142 .82798 m .44576 .83146 L .44228 .82779 L F
.44135 .828 m .44137 .82801 L .44142 .82798 L F
.44137 .82801 m .44576 .83146 L .44142 .82798 L F
.44305 .76151 m .44375 .76106 L .44213 .82764 L .387 .212 .518 r
F
.44202 .76185 m .44136 .82799 L .44038 .82822 L .539 .332 .549 r
F
.44202 .76185 m .44305 .76151 L .44142 .82798 L F
.4404 .82822 m .44263 .83182 L .44158 .82818 L .594 .768 .963 r
F
.44136 .82799 m .44142 .82798 L .44132 .83213 L .539 .332 .549 r
F
.44202 .76185 m .44142 .82798 L .44136 .82799 L F
.44135 .828 m .4404 .82822 L .44158 .82818 L .594 .768 .963 r
F
.43922 .82631 m .4404 .82821 L .44135 .828 L F
.4404 .82821 m .4404 .82822 L .44135 .828 L F
.43922 .82631 m .44135 .828 L .44228 .82779 L F
.44159 .8282 m .44263 .83182 L .4416 .82819 L F
.44305 .76151 m .44213 .82764 L .44209 .82766 L .387 .212 .518 r
F
.44375 .76106 m .44253 .82724 L .44213 .82764 L .095 0 .426 r
F
.44325 .82754 m .44844 .83075 L .4505 .82974 L .594 .768 .963 r
F
.43922 .82631 m .44405 .82864 L .44325 .82754 L F
.44405 .82864 m .44844 .83075 L .44325 .82754 L F
.44416 .76053 m .44263 .82668 L .44263 .82671 L 0 0 .082 r
F
.44416 .76053 m .44263 .82671 L .44255 .82721 L F
.44375 .76106 m .44255 .82721 L .44253 .82724 L .095 0 .426 r
F
.44424 .75989 m .44374 .75907 L .44212 .82597 L .993 .743 .421 r
F
.44454 .82724 m .4505 .82974 L .4518 .82849 L .594 .768 .963 r
F
.43922 .82631 m .44772 .8289 L .44454 .82724 L F
.44772 .8289 m .4505 .82974 L .44454 .82724 L F
.44031 .82852 m .43928 .83181 L .44052 .82841 L F
.44136 .82799 m .44132 .83213 L .44038 .82822 L .539 .332 .549 r
F
.44158 .82818 m .44159 .8282 L .4416 .82819 L .594 .768 .963 r
F
.44142 .82798 m .44203 .83169 L .44132 .83213 L .387 .212 .518 r
F
.44209 .82766 m .44203 .83169 L .44142 .82798 L F
.44424 .75989 m .44215 .82601 L .44263 .82668 L .993 .743 .421 r
F
.44323 .82655 m .4518 .82849 L .45224 .82709 L .594 .768 .963 r
F
.43922 .82631 m .44454 .82724 L .44323 .82655 L F
.44454 .82724 m .4518 .82849 L .44323 .82655 L F
.44374 .75907 m .44263 .75843 L .44098 .82538 L .889 .63 .539 r
F
.44374 .75907 m .44098 .82538 L .44104 .82541 L F
.44374 .75907 m .44104 .82541 L .44212 .82597 L F
.44424 .75989 m .44212 .82597 L .44215 .82601 L .993 .743 .421 r
F
.44263 .75843 m .4399 .82509 L .44098 .82538 L .799 .548 .56 r
F
.4407 .82531 m .44841 .82295 L .4457 .82191 L .594 .768 .963 r
F
.43922 .82631 m .44144 .8255 L .4407 .82531 L F
.44144 .8255 m .44841 .82295 L .4407 .82531 L F
.4404 .82822 m .44031 .82852 L .44052 .82841 L F
.44038 .82822 m .44132 .83213 L .44028 .83246 L .539 .332 .549 r
F
.43924 .82826 m .43928 .83181 L .4404 .82822 L .594 .768 .963 r
F
.44029 .82822 m .44038 .82822 L .44028 .83246 L .651 .424 .562 r
F
.43922 .82631 m .43924 .82826 L .4404 .82822 L .594 .768 .963 r
F
.43777 .76143 m .4388 .7618 L .4371 .82803 L .83 .576 .556 r
F
.43926 .82956 m .43592 .83142 L .43928 .83181 L .594 .768 .963 r
F
.43925 .82876 m .43868 .82922 L .43926 .82956 L F
.43868 .82922 m .43592 .83142 L .43926 .82956 L F
.43707 .76097 m .43777 .76143 L .43605 .82767 L .908 .647 .532 r
F
.43892 .82865 m .43845 .82908 L .43925 .82876 L .594 .768 .963 r
F
.43845 .82908 m .43592 .83142 L .43868 .82922 L F
.43845 .82908 m .43868 .82922 L .43925 .82876 L F
.43592 .83142 m .43266 .83648 L .43934 .83724 L F
.43279 .83068 m .43266 .83648 L .43592 .83142 L F
.43777 .76143 m .4371 .82803 L .43703 .828 L .83 .576 .556 r
F
.4388 .7618 m .44041 .76201 L .43874 .82828 L .747 .505 .564 r
F
.4388 .7618 m .43874 .82828 L .43864 .82826 L F
.43656 .75979 m .43665 .76042 L .4349 .82677 L .868 .695 .169 r
F
.43546 .8299 m .43279 .83068 L .43572 .83137 L .594 .768 .963 r
F
.43677 .82885 m .43538 .82949 L .43724 .82937 L F
.43538 .82949 m .43279 .83068 L .43546 .8299 L F
.43538 .82949 m .43546 .8299 L .43724 .82937 L F
.43781 .82827 m .43672 .82879 L .43793 .82831 L F
.43672 .82879 m .43279 .83068 L .43677 .82885 L F
.43672 .82879 m .43677 .82885 L .43793 .82831 L F
.43677 .82798 m .43279 .83068 L .43802 .82817 L F
.43777 .76143 m .43703 .828 L .43605 .82767 L .83 .576 .556 r
F
.4388 .7618 m .43864 .82826 L .4371 .82803 L .747 .505 .564 r
F
.43707 .76097 m .436 .82764 L .43533 .82725 L .908 .647 .532 r
F
.43707 .76097 m .43605 .82767 L .436 .82764 L F
.43922 .82631 m .433 .82859 L .43279 .83068 L .594 .768 .963 r
F
.433 .82859 m .43009 .82965 L .43171 .83027 L F
.433 .82859 m .43171 .83027 L .43279 .83068 L F
.43665 .76042 m .43531 .82722 L .4349 .82677 L .984 .727 .46 r
F
.43656 .75979 m .4349 .82674 L .43481 .82623 L .868 .695 .169 r
F
.43656 .75979 m .4349 .82677 L .4349 .82674 L F
.43665 .76042 m .43707 .76097 L .43533 .82725 L .984 .727 .46 r
F
.43665 .76042 m .43533 .82725 L .43531 .82722 L F
.43706 .75898 m .43656 .75979 L .43481 .82623 L 0 0 .377 r
F
.43922 .82631 m .434 .82728 L .433 .82859 L .594 .768 .963 r
F
.4288 .82824 m .42667 .82699 L .428 .82839 L F
.43922 .82631 m .43265 .82667 L .4288 .82824 L F
.43265 .82667 m .42667 .82699 L .4288 .82824 L F
.43724 .82937 m .43546 .8299 L .43592 .83142 L F
.43802 .82817 m .43592 .83142 L .43924 .82835 L F
.43605 .82767 m .43697 .83236 L .43594 .83201 L .83 .576 .556 r
F
.43279 .83068 m .42641 .83502 L .43266 .83648 L .594 .768 .963 r
F
.4367 .83227 m .42968 .83415 L .43239 .83518 L .593 .769 .963 r
F
.43793 .82831 m .43677 .82885 L .43724 .82937 L .594 .768 .963 r
F
.43703 .828 m .43699 .83237 L .43605 .82767 L .83 .576 .556 r
F
.43699 .83237 m .43697 .83236 L .43605 .82767 L F
.43777 .83248 m .43699 .83237 L .43769 .83261 L .593 .769 .963 r
F
.4371 .82803 m .43863 .83261 L .43699 .83237 L .747 .505 .564 r
F
.43888 .83265 m .43555 .83592 L .43893 .83631 L .593 .769 .963 r
F
.43802 .82817 m .43781 .82827 L .43793 .82831 L .594 .768 .963 r
F
.43864 .82826 m .43863 .83261 L .4371 .82803 L .747 .505 .564 r
F
.43864 .82826 m .43874 .82828 L .43863 .83261 L F
.43009 .82965 m .42641 .83502 L .43279 .83068 L .594 .768 .963 r
F
.43009 .82965 m .42102 .83297 L .42641 .83502 L F
.43528 .83211 m .42758 .83289 L .42968 .83415 L .593 .769 .963 r
F
.4349 .82677 m .43522 .83158 L .43479 .83107 L .984 .727 .46 r
F
.43513 .83149 m .43336 .83182 L .43559 .832 L .593 .769 .963 r
F
.43522 .83158 m .43522 .8316 L .43507 .83142 L .984 .727 .46 r
F
.43522 .83158 m .43507 .83142 L .43479 .83107 L F
.43559 .832 m .43336 .83182 L .43528 .83211 L .593 .769 .963 r
F
.43531 .82722 m .43522 .83158 L .4349 .82677 L .984 .727 .46 r
F
.43522 .83158 m .43522 .8316 L .43522 .83158 L F
.43522 .83158 m .43522 .83158 L .4349 .82677 L F
.43513 .83149 m .42624 .83148 L .42758 .83289 L .593 .769 .963 r
F
.43706 .75898 m .43484 .82619 L .43531 .82558 L 0 0 .377 r
F
.43706 .75898 m .43481 .82623 L .43484 .82619 L F
.43922 .82631 m .4315 .82585 L .42667 .82699 L .594 .768 .963 r
F
.4315 .82585 m .4262 .82554 L .42655 .82659 L F
.4315 .82585 m .42655 .82659 L .42667 .82699 L F
.43928 .7581 m .43817 .75836 L .43644 .82511 L .585 .37 .555 r
F
.4315 .82585 m .42661 .82413 L .4262 .82554 L .594 .768 .963 r
F
.43922 .82631 m .43421 .82545 L .4315 .82585 L F
.43421 .82545 m .42661 .82413 L .4315 .82585 L F
.43922 .82631 m .43677 .82798 L .43802 .82817 L F
.43703 .828 m .4371 .82803 L .43699 .83242 L .83 .576 .556 r
F
.43817 .75836 m .43537 .82555 L .43644 .82511 L .428 .243 .527 r
F
.43817 .75836 m .43706 .75898 L .43531 .82558 L F
.43817 .75836 m .43531 .82558 L .43537 .82555 L F
.44039 .75803 m .43928 .7581 L .43757 .82495 L .667 .437 .562 r
F
.43922 .82631 m .43475 .82496 L .43146 .82497 L .594 .768 .963 r
F
.43928 .7581 m .4365 .82511 L .43757 .82495 L .585 .37 .555 r
F
.43928 .7581 m .43644 .82511 L .4365 .82511 L F
.43204 .82413 m .42994 .82185 L .42788 .82287 L .594 .768 .963 r
F
.43922 .82631 m .43638 .82495 L .43475 .82496 L F
.43922 .82631 m .43802 .82817 L .43924 .82835 L F
.43922 .82631 m .43263 .82113 L .42994 .82185 L F
.44039 .75803 m .43763 .82494 L .4387 .82494 L .667 .437 .562 r
F
.44039 .75803 m .43757 .82495 L .43763 .82494 L F
.43922 .82631 m .43577 .82076 L .43263 .82113 L .594 .768 .963 r
F
.44151 .75813 m .44039 .75803 L .4387 .82494 L .733 .492 .564 r
F
.44151 .75813 m .4387 .82494 L .43876 .82495 L F
.44151 .75813 m .43876 .82495 L .43984 .82508 L F
.43922 .82631 m .43915 .82077 L .43577 .82076 L .594 .768 .963 r
F
.4387 .82494 m .43747 .82881 L .43861 .82875 L .667 .437 .562 r
F
.43763 .82494 m .43747 .82881 L .4387 .82494 L F
.43475 .82496 m .43558 .82456 L .43204 .82413 L .594 .768 .963 r
F
.43638 .82495 m .43558 .82456 L .43475 .82496 L F
.43558 .82456 m .42994 .82185 L .43204 .82413 L F
.43876 .82495 m .4387 .82494 L .43861 .82875 L .733 .492 .564 r
F
.43763 .82494 m .43757 .82495 L .43747 .82881 L .667 .437 .562 r
F
.43146 .82497 m .43204 .82413 L .42661 .82413 L .594 .768 .963 r
F
.43475 .82496 m .43204 .82413 L .43146 .82497 L F
.43204 .82413 m .42788 .82287 L .4272 .82355 L F
.43204 .82413 m .4272 .82355 L .42661 .82413 L F
.43924 .82835 m .43892 .82865 L .43925 .82876 L F
.44029 .82822 m .44028 .83246 L .43874 .82828 L .651 .424 .562 r
F
.43976 .82824 m .43892 .82877 L .43975 .82884 L .733 .492 .564 r
F
.44263 .75843 m .44151 .75813 L .43984 .82508 L .799 .548 .56 r
F
.44263 .75843 m .43984 .82508 L .4399 .82509 L F
.4392 .82491 m .44254 .82116 L .43915 .82077 L .594 .768 .963 r
F
.43922 .82631 m .43999 .82512 L .4392 .82491 L F
.43999 .82512 m .44254 .82116 L .4392 .82491 L F
.43922 .82631 m .4457 .82191 L .44254 .82116 L F
.43922 .82631 m .45049 .82423 L .44841 .82295 L F
.43922 .82631 m .45179 .82564 L .45049 .82423 L F
.43922 .82631 m .45224 .82709 L .45179 .82564 L F
.4399 .82509 m .43984 .82508 L .43975 .82884 L .799 .548 .56 r
F
.43984 .82508 m .43892 .82877 L .43976 .82824 L .733 .492 .564 r
F
.43984 .82508 m .43861 .82875 L .43892 .82877 L F
.43876 .82495 m .43861 .82875 L .43984 .82508 L F
.43757 .82495 m .43633 .82907 L .43747 .82881 L .585 .37 .555 r
F
.4365 .82511 m .43633 .82907 L .43757 .82495 L F
.4365 .82511 m .43644 .82511 L .43633 .82907 L F
.43481 .82623 m .43479 .83107 L .4347 .83045 L .868 .695 .169 r
F
.4349 .82674 m .43479 .83107 L .43481 .82623 L F
.43546 .8299 m .43572 .83137 L .43592 .83142 L .594 .768 .963 r
F
.43531 .82722 m .43533 .82725 L .43522 .83158 L .984 .727 .46 r
F
.43522 .83158 m .43522 .83158 L .43522 .8316 L F
.43531 .82722 m .43522 .83158 L .43522 .83158 L F
.428 .82839 m .42102 .83297 L .43009 .82965 L .594 .768 .963 r
F
.4352 .82967 m .4347 .83045 L .43469 .83057 L 0 0 .377 r
F
.43471 .83103 m .43437 .83099 L .43433 .83105 L .593 .769 .963 r
F
.4349 .82674 m .4349 .82677 L .43479 .83107 L .868 .695 .169 r
F
.43579 .83192 m .43522 .83158 L .43559 .832 L .593 .769 .963 r
F
.43522 .83158 m .43593 .83205 L .43522 .8316 L .908 .647 .532 r
F
.43533 .82725 m .43593 .832 L .43522 .83158 L F
.43593 .832 m .43593 .83205 L .43522 .83158 L F
.436 .82764 m .43594 .83201 L .43533 .82725 L F
.43574 .83194 m .42968 .83415 L .4367 .83227 L .593 .769 .963 r
F
.43594 .83201 m .43593 .83205 L .43593 .832 L .908 .647 .532 r
F
.43594 .83201 m .43593 .832 L .43533 .82725 L F
.436 .82764 m .43605 .82767 L .43593 .83205 L F
.43874 .82828 m .44028 .83246 L .43865 .83261 L .651 .424 .562 r
F
.43888 .8326 m .43863 .83261 L .43888 .83265 L .593 .769 .963 r
F
.43863 .83261 m .43865 .83261 L .43863 .83261 L .651 .424 .562 r
F
.43874 .82828 m .43865 .83261 L .43863 .83261 L F
.43886 .83081 m .43777 .83248 L .43863 .83261 L .593 .769 .963 r
F
.43886 .83081 m .43863 .83261 L .43888 .8326 L F
.43886 .83081 m .43579 .83192 L .4367 .83227 L F
.43579 .83192 m .43574 .83194 L .43594 .83201 L F
.43579 .83192 m .43594 .83201 L .4367 .83227 L F
.43886 .83081 m .43513 .83149 L .43522 .83158 L F
.43886 .83081 m .43522 .83158 L .43579 .83192 L F
.43477 .83102 m .43427 .83053 L .43471 .83103 L F
.4347 .83045 m .43479 .83107 L .43479 .83111 L .868 .695 .169 r
F
.4347 .83045 m .43479 .83111 L .43469 .83057 L F
.43469 .83056 m .43427 .83053 L .43477 .83102 L .593 .769 .963 r
F
.43427 .83053 m .42576 .83002 L .43471 .83103 L F
.43471 .83103 m .42624 .83148 L .43513 .83149 L F
.43336 .83182 m .42758 .83289 L .43528 .83211 L F
.43769 .83261 m .43239 .83518 L .43555 .83592 L F
.4367 .83227 m .43239 .83518 L .43769 .83261 L F
.42902 .84601 m .43941 .84271 L .43905 .84716 L .731 .508 .59 r
F
.42902 .84601 m .42938 .84156 L .43941 .84271 L F
.43266 .83648 m .43941 .84263 L .43934 .83724 L .594 .768 .963 r
F
.43266 .83648 m .42943 .84149 L .43941 .84263 L F
.42865 .85046 m .43905 .84716 L .4387 .85161 L .731 .508 .59 r
F
.42865 .85046 m .42902 .84601 L .43905 .84716 L F
.43227 .84099 m .43905 .84716 L .43899 .84176 L .593 .769 .963 r
F
.43227 .84099 m .42902 .84601 L .43905 .84716 L F
.43191 .84546 m .4387 .85161 L .43864 .84623 L .592 .769 .964 r
F
.43191 .84546 m .42865 .85046 L .4387 .85161 L F
.43555 .83592 m .43227 .84099 L .43899 .84176 L .593 .769 .963 r
F
.42641 .83502 m .42943 .84149 L .43266 .83648 L .594 .768 .963 r
F
.43239 .83518 m .43227 .84099 L .43555 .83592 L .593 .769 .963 r
F
.43519 .8404 m .43191 .84546 L .43864 .84623 L .592 .769 .964 r
F
.41962 .84383 m .42938 .84156 L .42902 .84601 L .784 .556 .591 r
F
.41962 .84383 m .42 .83938 L .42938 .84156 L F
.42641 .83502 m .42009 .83932 L .42943 .84149 L .594 .768 .963 r
F
.42598 .83953 m .42902 .84601 L .43227 .84099 L .593 .769 .963 r
F
.43239 .83518 m .42598 .83953 L .43227 .84099 L F
.43203 .83967 m .43191 .84546 L .43519 .8404 L .592 .769 .964 r
F
.43548 .83996 m .43203 .83967 L .43519 .8404 L F
.43506 .83763 m .43203 .83967 L .43548 .83996 L F
.43506 .83763 m .42931 .83864 L .43203 .83967 L F
.43555 .83592 m .43899 .84176 L .43893 .83631 L .593 .769 .963 r
F
.43863 .83261 m .43555 .83592 L .43888 .83265 L F
.43777 .83248 m .43767 .83265 L .43863 .83261 L F
.43767 .83265 m .43555 .83592 L .43863 .83261 L F
.43905 .84716 m .43941 .84271 L .44942 .84276 L .676 .46 .585 r
F
.43934 .83724 m .43941 .84263 L .44937 .84268 L .594 .768 .963 r
F
.43905 .84716 m .44942 .84276 L .44908 .84721 L .676 .46 .585 r
F
.43899 .84176 m .43905 .84716 L .44908 .84721 L .593 .769 .963 r
F
.43899 .84176 m .44908 .84721 L .4457 .84179 L F
.43934 .83724 m .44937 .84268 L .44602 .83728 L .594 .768 .963 r
F
.43893 .83631 m .43899 .84176 L .4457 .84179 L .593 .769 .963 r
F
.43857 .84079 m .43864 .84623 L .44536 .84626 L .592 .769 .964 r
F
.43519 .8404 m .43864 .84623 L .43857 .84079 L F
.43857 .84079 m .44536 .84626 L .44195 .84081 L F
.44022 .83805 m .43857 .84079 L .44195 .84081 L F
.4387 .85161 m .43905 .84716 L .44908 .84721 L .676 .46 .585 r
F
.4387 .85161 m .44908 .84721 L .44874 .85167 L F
.43864 .84623 m .4387 .85161 L .44874 .85167 L .592 .769 .964 r
F
.43864 .84623 m .44874 .85167 L .44536 .84626 L F
.43893 .83631 m .4457 .84179 L .4423 .83632 L .593 .769 .963 r
F
.43999 .83262 m .43893 .83631 L .4423 .83632 L F
.44028 .83246 m .44028 .83256 L .44027 .83256 L .539 .332 .549 r
F
.44263 .83182 m .44602 .83728 L .45224 .83656 L .594 .768 .963 r
F
.4413 .83272 m .4423 .83632 L .44544 .83596 L .593 .769 .963 r
F
.43865 .83261 m .44028 .83246 L .44027 .83256 L .651 .424 .562 r
F
.44028 .83246 m .44132 .83213 L .44132 .83232 L .539 .332 .549 r
F
.44091 .83241 m .44054 .8335 L .4413 .83272 L .593 .769 .963 r
F
.43999 .83262 m .44054 .8335 L .44091 .83241 L F
.44054 .8335 m .4423 .83632 L .4413 .83272 L F
.44602 .83728 m .44937 .84268 L .45867 .84163 L .594 .768 .963 r
F
.4423 .83632 m .4457 .84179 L .45196 .84108 L .593 .769 .963 r
F
.44167 .83215 m .44544 .83596 L .44814 .83525 L F
.44132 .83213 m .44203 .83198 L .44135 .83231 L .387 .212 .518 r
F
.43886 .83081 m .44099 .83248 L .44167 .83215 L .593 .769 .963 r
F
.44099 .83248 m .44544 .83596 L .44167 .83215 L F
.44132 .83213 m .44203 .83169 L .44203 .83198 L .387 .212 .518 r
F
.44203 .83169 m .44203 .83198 L .44203 .83198 L .095 0 .426 r
F
.44576 .83146 m .45224 .83656 L .4576 .83516 L .594 .768 .963 r
F
.44263 .83182 m .45224 .83656 L .44576 .83146 L F
.44219 .83181 m .44814 .83525 L .45021 .83424 L .593 .769 .963 r
F
.43886 .83081 m .4418 .83221 L .44219 .83181 L F
.4418 .83221 m .44814 .83525 L .44219 .83181 L F
.44203 .83169 m .44246 .83118 L .44245 .83156 L .095 0 .426 r
F
.442 .83804 m .44195 .84081 L .44509 .84045 L .592 .769 .964 r
F
.44602 .83728 m .45867 .84163 L .45224 .83656 L .594 .768 .963 r
F
.4423 .83632 m .45196 .84108 L .44544 .83596 L .593 .769 .963 r
F
.44908 .84721 m .44942 .84276 L .45877 .8417 L .611 .404 .576 r
F
.44908 .84721 m .45877 .8417 L .45844 .84616 L F
.4457 .84179 m .44908 .84721 L .45844 .84616 L .593 .769 .963 r
F
.44195 .84081 m .44536 .84626 L .45162 .84556 L .592 .769 .964 r
F
.4457 .84179 m .45844 .84616 L .45196 .84108 L .593 .769 .963 r
F
.44195 .84081 m .45162 .84556 L .44509 .84045 L .592 .769 .964 r
F
.44132 .83213 m .44192 .83633 L .44126 .83665 L .387 .212 .518 r
F
.44028 .83256 m .44132 .83232 L .44121 .83667 L .539 .332 .549 r
F
.44028 .83256 m .44121 .83667 L .44023 .83689 L F
.44027 .83256 m .44023 .83689 L .44017 .83691 L F
.44028 .83256 m .44023 .83689 L .44027 .83256 L F
.43889 .83287 m .43893 .83631 L .43999 .83262 L .593 .769 .963 r
F
.44132 .83213 m .44126 .83665 L .44121 .83667 L .387 .212 .518 r
F
.43863 .83261 m .43865 .83261 L .43863 .83696 L .651 .424 .562 r
F
.43863 .83261 m .43863 .83696 L .43862 .83696 L F
.44576 .83146 m .4576 .83516 L .44844 .83075 L .594 .768 .963 r
F
.44247 .83143 m .45021 .83424 L .45152 .83299 L .593 .769 .963 r
F
.44203 .83169 m .44245 .83156 L .44203 .83198 L .095 0 .426 r
F
.44209 .82766 m .44213 .82764 L .44203 .83169 L .387 .212 .518 r
F
.44213 .82764 m .44246 .83118 L .44203 .83169 L .095 0 .426 r
F
.43886 .83081 m .4424 .83187 L .44247 .83143 L .593 .769 .963 r
F
.4424 .83187 m .45021 .83424 L .44247 .83143 L F
.44246 .83118 m .44254 .83056 L .44253 .83103 L 0 0 .082 r
F
.44246 .83118 m .44253 .83103 L .44245 .83151 L F
.44844 .83075 m .4576 .83516 L .46173 .83315 L .594 .768 .963 r
F
.44253 .83102 m .45152 .83299 L .45196 .83159 L .593 .769 .963 r
F
.44246 .83118 m .44245 .83151 L .44245 .83155 L 0 0 .082 r
F
.44255 .82721 m .44254 .83056 L .44246 .83118 L F
.44253 .82724 m .44255 .82721 L .44246 .83118 L .095 0 .426 r
F
.44228 .82779 m .44243 .82795 L .44245 .82787 L .594 .768 .963 r
F
.44253 .82724 m .44246 .83118 L .44213 .82764 L .095 0 .426 r
F
.44253 .83103 m .45152 .83299 L .44253 .83102 L .593 .769 .963 r
F
.44247 .83143 m .44287 .8315 L .44253 .83103 L F
.44287 .8315 m .45152 .83299 L .44253 .83103 L F
.44254 .83056 m .44203 .82976 L .44201 .83032 L .993 .743 .421 r
F
.43886 .83081 m .44247 .83143 L .44253 .83103 L .593 .769 .963 r
F
.43886 .83081 m .44253 .83103 L .44253 .83102 L F
.44245 .83155 m .44242 .83538 L .44235 .83587 L 0 0 .082 r
F
.44245 .83151 m .44242 .83538 L .44245 .83155 L F
.44245 .83151 m .44253 .83103 L .44242 .83538 L F
.44216 .83705 m .44509 .84045 L .44779 .83974 L .592 .769 .964 r
F
.44213 .83727 m .44509 .84045 L .44216 .83705 L F
.44054 .83689 m .44509 .84045 L .44174 .83685 L F
.45224 .83656 m .45867 .84163 L .46669 .83954 L .594 .768 .963 r
F
.44544 .83596 m .45196 .84108 L .45735 .83967 L .593 .769 .963 r
F
.44346 .8368 m .44779 .83974 L .44987 .83873 L .592 .769 .964 r
F
.43865 .83261 m .44027 .83256 L .44017 .83691 L .651 .424 .562 r
F
.43865 .83261 m .44017 .83691 L .43863 .83696 L F
.43699 .83242 m .43863 .83261 L .43852 .83696 L .747 .505 .564 r
F
.43699 .83242 m .43852 .83696 L .43697 .83673 L F
.43593 .83205 m .43699 .83242 L .43687 .83671 L .83 .576 .556 r
F
.43854 .83794 m .43519 .8404 L .43857 .84079 L .592 .769 .964 r
F
.43853 .83728 m .43809 .83768 L .43854 .83794 L F
.43809 .83768 m .43519 .8404 L .43854 .83794 L F
.43522 .8316 m .43593 .83205 L .43582 .83636 L .908 .647 .532 r
F
.4383 .8372 m .43519 .8404 L .43853 .83728 L .592 .769 .964 r
F
.43752 .83681 m .43746 .83691 L .43852 .83696 L F
.43746 .83691 m .43519 .8404 L .4383 .8372 L F
.43746 .83691 m .4383 .8372 L .43852 .83696 L F
.43479 .83107 m .43522 .8316 L .4351 .83594 L .984 .727 .46 r
F
.43604 .83697 m .43488 .83662 L .43506 .83763 L .592 .769 .964 r
F
.43577 .83667 m .43488 .83662 L .43604 .83697 L F
.43633 .83665 m .43488 .83662 L .43642 .83671 L F
.43528 .83647 m .43488 .83662 L .4365 .83666 L F
.43488 .83662 m .42931 .83864 L .43506 .83763 L F
.43479 .83107 m .4351 .83594 L .4347 .83549 L .984 .727 .46 r
F
.43522 .8316 m .43515 .83596 L .4351 .83594 L .908 .647 .532 r
F
.43593 .83205 m .43589 .83638 L .43582 .83636 L .83 .576 .556 r
F
.43522 .8316 m .43582 .83636 L .43515 .83596 L .908 .647 .532 r
F
.43593 .83205 m .43687 .83671 L .43589 .83638 L .83 .576 .556 r
F
.43699 .83242 m .43697 .83673 L .43687 .83671 L .747 .505 .564 r
F
.42968 .83415 m .42598 .83953 L .43239 .83518 L .593 .769 .963 r
F
.42102 .83297 m .42009 .83932 L .42641 .83502 L .594 .768 .963 r
F
.42968 .83415 m .42055 .83747 L .42598 .83953 L .593 .769 .963 r
F
.43264 .83743 m .42721 .83738 L .42931 .83864 L .592 .769 .964 r
F
.43551 .83639 m .43359 .83621 L .43264 .83743 L F
.4351 .83593 m .43359 .83621 L .43551 .83639 L F
.42766 .8373 m .42587 .83597 L .42721 .83738 L F
.4385 .83531 m .4341 .83554 L .43359 .83621 L F
.43479 .83107 m .4347 .83549 L .43467 .83546 L .984 .727 .46 r
F
.43477 .83102 m .43471 .83103 L .43479 .83111 L .593 .769 .963 r
F
.43469 .83057 m .43479 .83111 L .43467 .83546 L .868 .695 .169 r
F
.43469 .83057 m .43467 .83546 L .43458 .83496 L F
.42758 .83289 m .42055 .83747 L .42968 .83415 L .593 .769 .963 r
F
.43166 .83567 m .42539 .83452 L .42587 .83597 L .592 .769 .964 r
F
.4385 .83531 m .43331 .83499 L .43166 .83567 L F
.43331 .83499 m .42539 .83452 L .43166 .83567 L F
.43169 .90449 m .43277 .90675 L .43362 .90527 L .657 .813 .959 r
F
.43352 .90468 m .43362 .90527 L .43394 .90473 L F
.43169 .90449 m .43362 .90527 L .43352 .90468 L F
.43469 .83057 m .43458 .83496 L .43458 .83492 L .868 .695 .169 r
F
.4347 .83045 m .43469 .83057 L .43469 .83057 L F
.43469 .83057 m .43458 .83496 L .43469 .83057 L F
.433 .82859 m .4288 .82824 L .43009 .82965 L .594 .768 .963 r
F
.4288 .82824 m .42818 .8285 L .43009 .82965 L F
.428 .82839 m .41684 .83046 L .42102 .83297 L F
.42667 .82699 m .41684 .83046 L .428 .82839 L F
.43469 .83056 m .42618 .82861 L .42576 .83002 L .593 .769 .963 r
F
.43531 .82558 m .4347 .83045 L .4352 .82967 L 0 0 .377 r
F
.43484 .82619 m .4347 .83045 L .43531 .82558 L F
.43484 .82619 m .43481 .82623 L .4347 .83045 L F
.43886 .83081 m .4346 .83007 L .43469 .83056 L .593 .769 .963 r
F
.4346 .83007 m .42618 .82861 L .43469 .83056 L F
.43886 .83081 m .43469 .83056 L .43477 .83102 L F
.43886 .83081 m .43477 .83102 L .43513 .83149 L F
.43477 .83102 m .43479 .83111 L .43513 .83149 L F
.434 .82728 m .4288 .82824 L .433 .82859 L .594 .768 .963 r
F
.4288 .82824 m .428 .82839 L .42818 .8285 L F
.43476 .8301 m .42746 .82735 L .42618 .82861 L .593 .769 .963 r
F
.43886 .83081 m .43519 .82992 L .43502 .83014 L F
.43519 .82992 m .43505 .83432 L .43508 .83428 L 0 0 .377 r
F
.4352 .82967 m .43519 .82992 L .43519 .82992 L F
.43519 .82992 m .43505 .83432 L .43519 .82992 L F
.43886 .83081 m .43551 .82979 L .43519 .82992 L .593 .769 .963 r
F
.4352 .82967 m .43469 .83057 L .43519 .82992 L 0 0 .377 r
F
.43502 .83014 m .43519 .82992 L .43476 .8301 L .593 .769 .963 r
F
.43633 .82907 m .4352 .82967 L .43519 .82992 L .428 .243 .527 r
F
.43886 .83081 m .43618 .82952 L .43551 .82979 L .593 .769 .963 r
F
.43633 .82907 m .43519 .82992 L .43623 .8295 L .428 .243 .527 r
F
.43633 .82907 m .43632 .82946 L .43632 .82946 L F
.43644 .82511 m .4352 .82967 L .43633 .82907 L F
.43537 .82555 m .4352 .82967 L .43644 .82511 L F
.43537 .82555 m .43531 .82558 L .4352 .82967 L F
.43618 .82952 m .43223 .8256 L .42952 .82633 L .593 .769 .963 r
F
.43747 .82881 m .43633 .82907 L .43632 .82946 L .585 .37 .555 r
F
.43886 .83081 m .43701 .82936 L .43618 .82952 L .593 .769 .963 r
F
.43701 .82936 m .43632 .82946 L .43618 .82952 L F
.42102 .83297 m .41201 .83626 L .42009 .83932 L .594 .768 .963 r
F
.42758 .83289 m .41635 .83496 L .42055 .83747 L .593 .769 .963 r
F
.42624 .83148 m .41635 .83496 L .42758 .83289 L F
.42971 .83478 m .4258 .83312 L .42539 .83452 L .592 .769 .964 r
F
.43519 .82992 m .43469 .83057 L .43458 .83492 L 0 0 .377 r
F
.43447 .83506 m .43279 .83432 L .42971 .83478 L .592 .769 .964 r
F
.4385 .83531 m .43478 .83466 L .43447 .83506 L F
.43519 .82992 m .43458 .83492 L .43505 .83432 L 0 0 .377 r
F
.43478 .83466 m .43279 .83432 L .43447 .83506 L .592 .769 .964 r
F
.43279 .83432 m .4258 .83312 L .42971 .83478 L F
.43594 .83201 m .43699 .83242 L .43593 .83205 L .83 .576 .556 r
F
.43697 .83236 m .43699 .83242 L .43594 .83201 L F
.43747 .82881 m .43632 .82946 L .43745 .82929 L .585 .37 .555 r
F
.43662 .82905 m .43539 .82524 L .43223 .8256 L .593 .769 .963 r
F
.43886 .83081 m .43792 .82929 L .43701 .82936 L F
.43861 .82875 m .43746 .82929 L .43859 .82929 L .667 .437 .562 r
F
.43792 .82929 m .43788 .82923 L .43746 .82929 L .593 .769 .963 r
F
.43792 .82929 m .43746 .82929 L .43701 .82936 L F
.43861 .82875 m .43747 .82881 L .43746 .82929 L .667 .437 .562 r
F
.4385 .83531 m .4351 .83593 L .43551 .83639 L .592 .769 .964 r
F
.4385 .83531 m .43752 .83681 L .43852 .83696 L F
.4385 .83531 m .43506 .83763 L .43548 .83996 L F
.43634 .90469 m .43637 .90669 L .43996 .90622 L .657 .813 .959 r
F
.43394 .90473 m .43637 .90669 L .43634 .90469 L F
.43394 .90473 m .43277 .90675 L .43637 .90669 L F
.43634 .90469 m .43996 .90622 L .43874 .90438 L F
.43661 .90289 m .43634 .90469 L .43874 .90438 L F
.43632 .90268 m .43632 .90299 L .43661 .90289 L F
.43632 .90299 m .43634 .90469 L .43661 .90289 L F
.44019 .9047 m .43996 .90622 L .44331 .90538 L F
.43874 .90438 m .43996 .90622 L .44019 .9047 L F
.43996 .90622 m .43996 .90622 L .44019 .9047 L F
.43863 .83261 m .43862 .83696 L .43852 .83696 L .651 .424 .562 r
F
.4385 .83531 m .44174 .83685 L .44344 .8368 L .592 .769 .964 r
F
.44174 .83685 m .44444 .83814 L .44344 .8368 L F
.44544 .83596 m .45735 .83967 L .44814 .83525 L .593 .769 .963 r
F
.44293 .83607 m .44987 .83873 L .45117 .83749 L .592 .769 .964 r
F
.44203 .83198 m .44234 .83591 L .44195 .83631 L .095 0 .426 r
F
.44135 .83231 m .44203 .83198 L .44192 .83633 L .387 .212 .518 r
F
.44203 .83198 m .44195 .83631 L .44192 .83633 L .095 0 .426 r
F
.44203 .83198 m .44195 .83631 L .44203 .83198 L F
.4385 .83531 m .44346 .8368 L .44293 .83607 L .592 .769 .964 r
F
.44346 .8368 m .44987 .83873 L .44293 .83607 L F
.45224 .83656 m .46669 .83954 L .4576 .83516 L .594 .768 .963 r
F
.44814 .83525 m .45735 .83967 L .46151 .83766 L .593 .769 .963 r
F
.44255 .83555 m .45117 .83749 L .45162 .83609 L .592 .769 .964 r
F
.44246 .83118 m .44235 .83587 L .44234 .83591 L 0 0 .082 r
F
.44203 .83198 m .44245 .83156 L .44234 .83591 L .095 0 .426 r
F
.4385 .83531 m .44293 .83607 L .44255 .83555 L .592 .769 .964 r
F
.44293 .83607 m .45117 .83749 L .44255 .83555 L F
.44253 .83102 m .44239 .83533 L .44253 .83103 L .993 .743 .421 r
F
.44235 .83587 m .44238 .83567 L .44228 .83898 L 0 0 .082 r
F
.44239 .83533 m .44239 .83534 L .44253 .83103 L .993 .743 .421 r
F
.44253 .83103 m .44239 .83534 L .44242 .83538 L F
.44253 .83102 m .44191 .83467 L .44239 .83533 L F
.44814 .83525 m .46151 .83766 L .45021 .83424 L .593 .769 .963 r
F
.4385 .83531 m .44373 .83562 L .44305 .83527 L .592 .769 .964 r
F
.4427 .83508 m .45134 .83519 L .44808 .8348 L F
.4385 .83531 m .44305 .83527 L .4427 .83508 L F
.44305 .83527 m .45134 .83519 L .4427 .83508 L F
.44028 .83246 m .44132 .83232 L .44028 .83256 L .539 .332 .549 r
F
.43886 .83081 m .43999 .83262 L .44091 .83241 L .593 .769 .963 r
F
.44098 .82538 m .43975 .82884 L .44089 .82913 L .799 .548 .56 r
F
.44104 .82541 m .44098 .82538 L .44089 .82913 L .889 .63 .539 r
F
.44212 .82597 m .44089 .82913 L .44203 .82976 L F
.44104 .82541 m .44089 .82913 L .44212 .82597 L F
.44215 .82601 m .44212 .82597 L .44203 .82976 L .993 .743 .421 r
F
.44263 .82671 m .44263 .82668 L .44254 .83056 L 0 0 .082 r
F
.44263 .82671 m .44254 .83056 L .44255 .82721 L F
.44263 .82668 m .44203 .82976 L .44254 .83056 L .993 .743 .421 r
F
.44215 .82601 m .44203 .82976 L .44263 .82668 L F
.44089 .82913 m .43975 .82884 L .43973 .82942 L .799 .548 .56 r
F
.43886 .83081 m .44057 .82965 L .43975 .82943 L .593 .769 .963 r
F
.43959 .83704 m .44195 .84081 L .44047 .83684 L .592 .769 .964 r
F
.43978 .83735 m .43915 .83914 L .44022 .83805 L F
.43915 .83914 m .43857 .84079 L .44022 .83805 L F
.44017 .83691 m .43956 .90182 L .43855 .90218 L .539 .332 .549 r
F
.44174 .83685 m .44213 .83727 L .44216 .83705 L .592 .769 .964 r
F
.4385 .83531 m .44054 .83689 L .44174 .83685 L F
.44101 .83726 m .44171 .83991 L .442 .83804 L F
.44171 .83991 m .44195 .84081 L .442 .83804 L F
.44079 .83748 m .44195 .84081 L .44101 .83726 L F
.44053 .837 m .44195 .84081 L .44061 .83695 L F
.44126 .83665 m .44192 .83633 L .44035 .90135 L .387 .212 .518 r
F
.4389 .90304 m .4403 .90399 L .44036 .90358 L .657 .813 .959 r
F
.44036 .90358 m .4403 .90399 L .44098 .90381 L F
.4403 .90399 m .44331 .90538 L .44098 .90381 L F
.44019 .9047 m .44331 .90538 L .4403 .90399 L F
.43945 .90239 m .44098 .90381 L .44289 .90304 L F
.43864 .90224 m .43924 .90265 L .43945 .90239 L F
.43924 .90265 m .44098 .90381 L .43945 .90239 L F
.44195 .83631 m .44234 .83591 L .44077 .90085 L .095 0 .426 r
F
.43752 .90253 m .4389 .90304 L .43864 .90224 L .657 .813 .959 r
F
.4389 .90304 m .44098 .90381 L .43924 .90265 L F
.4389 .90304 m .43924 .90265 L .43864 .90224 L F
.44195 .83631 m .44075 .90087 L .44192 .83633 L .095 0 .426 r
F
.4396 .90185 m .44289 .90304 L .44298 .90298 L .657 .813 .959 r
F
.4422 .90199 m .44298 .90298 L .44436 .9021 L F
.4396 .90185 m .44298 .90298 L .4422 .90199 L F
.44075 .90087 m .44075 .90088 L .44192 .83633 L .095 0 .426 r
F
.44195 .83631 m .44077 .90085 L .44075 .90087 L F
.44192 .83633 m .44075 .90088 L .44035 .90135 L F
.44126 .83665 m .44035 .90135 L .44031 .90137 L .387 .212 .518 r
F
.44235 .83587 m .44086 .90031 L .44234 .83591 L 0 0 .082 r
F
.44086 .90031 m .44086 .90031 L .44234 .83591 L F
.44228 .83898 m .44242 .83538 L .44086 .90028 L F
.44235 .83587 m .44086 .90028 L .44086 .90031 L F
.44234 .83591 m .44086 .90031 L .44077 .90085 L F
.44239 .83533 m .44036 .89964 L .44239 .83534 L .993 .743 .421 r
F
.4394 .90193 m .44289 .90304 L .4396 .90185 L .657 .813 .959 r
F
.43864 .90224 m .43884 .90228 L .4394 .90193 L F
.43884 .90228 m .44289 .90304 L .4394 .90193 L F
.43878 .90318 m .4403 .90399 L .4389 .90304 L F
.43756 .90254 m .43802 .90279 L .43756 .90254 L F
.43802 .90279 m .4403 .90399 L .43802 .90278 L F
.43802 .90279 m .43802 .90278 L .43756 .90254 L F
.44126 .83665 m .44031 .90137 L .44121 .83667 L .387 .212 .518 r
F
.44019 .90899 m .43998 .90625 L .44334 .9054 L .611 .406 .579 r
F
.44019 .90899 m .44334 .9054 L .44356 .90814 L F
.4394 .9051 m .44121 .90657 L .44314 .90579 L .657 .814 .959 r
F
.43886 .905 m .43926 .90526 L .4394 .9051 L F
.43926 .90526 m .44121 .90657 L .4394 .9051 L F
.44356 .90814 m .44334 .9054 L .44623 .90423 L .529 .345 .576 r
F
.44098 .90381 m .44331 .90538 L .44618 .90422 L .657 .813 .959 r
F
.43983 .90461 m .44314 .90579 L .44462 .90485 L .657 .814 .959 r
F
.43886 .905 m .44314 .90579 L .43983 .90461 L F
.44055 .90464 m .44215 .90472 L .44062 .90415 L F
.44071 .90356 m .44077 .90424 L .44068 .90484 L 0 0 .082 r
F
.44165 .9013 m .44436 .9021 L .44529 .90106 L .657 .813 .959 r
F
.44033 .90138 m .44195 .90167 L .44165 .9013 L F
.44195 .90167 m .44436 .9021 L .44165 .9013 L F
.4396 .90185 m .4422 .90199 L .44033 .90138 L F
.4422 .90199 m .44436 .9021 L .44195 .90167 L F
.4422 .90199 m .44195 .90167 L .44033 .90138 L F
.44238 .83567 m .44242 .83538 L .44228 .83898 L 0 0 .082 r
F
.44239 .83534 m .44036 .89964 L .44242 .83538 L .993 .743 .421 r
F
.44121 .83667 m .4403 .90137 L .43962 .9018 L .387 .212 .518 r
F
.44061 .83695 m .44079 .83748 L .44101 .83726 L .592 .769 .964 r
F
.44047 .83684 m .44053 .837 L .44061 .83695 L F
.44023 .83689 m .44121 .83667 L .43962 .9018 L .539 .332 .549 r
F
.44023 .83689 m .43962 .9018 L .43956 .90182 L F
.43632 .90268 m .43874 .90438 L .43752 .90253 L .657 .813 .959 r
F
.43658 .90946 m .43637 .90672 L .43998 .90625 L .674 .453 .578 r
F
.43653 .90544 m .43655 .90745 L .43897 .90714 L .657 .814 .959 r
F
.43658 .90946 m .43998 .90625 L .44019 .90899 L .674 .453 .578 r
F
.43774 .90528 m .43897 .90714 L .44121 .90657 L .657 .814 .959 r
F
.43653 .90544 m .43897 .90714 L .43774 .90528 L F
.43871 .90504 m .44121 .90657 L .43886 .905 L F
.43774 .90528 m .4381 .90541 L .43871 .90504 L F
.4381 .90541 m .44121 .90657 L .43871 .90504 L F
.43955 .90451 m .44025 .90534 L .43952 .90576 L .387 .212 .518 r
F
.43802 .90279 m .43874 .90438 L .4403 .90399 L .657 .813 .959 r
F
.43874 .90438 m .44019 .9047 L .4403 .90399 L F
.43962 .9018 m .44005 .90421 L .43955 .90451 L .387 .212 .518 r
F
.44005 .90421 m .44025 .90534 L .43955 .90451 L F
.43296 .90952 m .43637 .90672 L .43658 .90946 L .73 .495 .572 r
F
.43296 .90952 m .43275 .90678 L .43637 .90672 L F
.43532 .90546 m .43655 .90745 L .43653 .90544 L .657 .814 .959 r
F
.43532 .90546 m .43414 .90749 L .43655 .90745 L F
.43512 .90514 m .43678 .90623 L .43509 .90604 L .747 .505 .564 r
F
.43511 .9027 m .43634 .90469 L .43632 .90268 L .657 .813 .959 r
F
.43511 .9027 m .43394 .90473 L .43634 .90469 L F
.43749 .90248 m .43632 .90268 L .43752 .90253 L F
.43687 .83671 m .43678 .90246 L .43519 .90242 L .747 .505 .564 r
F
.43852 .83696 m .43846 .9022 L .43687 .90246 L .651 .424 .562 r
F
.43631 .90245 m .43632 .90268 L .43749 .90248 L .657 .813 .959 r
F
.43768 .9052 m .43653 .90544 L .43774 .90528 L .657 .814 .959 r
F
.43721 .90519 m .43653 .90544 L .43768 .9052 L F
.43697 .83673 m .43679 .90246 L .43687 .83671 L .747 .505 .564 r
F
.43679 .90246 m .43678 .90246 L .43687 .83671 L F
.43678 .90518 m .43678 .90518 L .43687 .83671 L F
.43946 .8375 m .43857 .84079 L .43978 .83735 L .592 .769 .964 r
F
.43949 .83706 m .43857 .84079 L .43959 .83704 L F
.43852 .83696 m .43857 .84079 L .43952 .83693 L F
.43862 .83696 m .43846 .9022 L .43852 .83696 L .651 .424 .562 r
F
.43756 .90254 m .43878 .90318 L .4389 .90304 L .657 .813 .959 r
F
.43779 .90293 m .43874 .90438 L .43802 .90279 L F
.43867 .90487 m .43774 .90528 L .43886 .905 L .657 .814 .959 r
F
.43846 .9022 m .43846 .90491 L .43846 .9022 L .651 .424 .562 r
F
.43846 .90491 m .43846 .90491 L .43846 .9022 L F
.43679 .90246 m .43678 .90518 L .43678 .90246 L .747 .505 .564 r
F
.43678 .90246 m .43678 .90518 L .43519 .90242 L F
.43687 .90246 m .43798 .90499 L .4368 .90518 L .651 .424 .562 r
F
.43848 .9049 m .43774 .90528 L .43867 .90487 L .657 .814 .959 r
F
.43758 .90505 m .43768 .90519 L .43848 .9049 L F
.43768 .90519 m .43774 .90528 L .43848 .9049 L F
.43848 .9049 m .43952 .90576 L .43846 .90608 L .539 .332 .549 r
F
.43855 .90218 m .43922 .90464 L .43848 .9049 L F
.43922 .90464 m .43952 .90576 L .43848 .9049 L F
.43855 .90218 m .43749 .90248 L .43864 .90224 L .657 .813 .959 r
F
.43742 .90237 m .43749 .90248 L .43855 .90218 L F
.43749 .90248 m .43752 .90253 L .43769 .90248 L F
.43749 .90248 m .43769 .90248 L .43864 .90224 L F
.43752 .90253 m .43756 .90254 L .43756 .90254 L F
.43752 .90253 m .43779 .90293 L .43802 .90279 L F
.43846 .9022 m .43846 .90491 L .43687 .90246 L .651 .424 .562 r
F
.43846 .90491 m .43846 .90608 L .43798 .90499 L F
.43846 .90491 m .43798 .90499 L .43687 .90246 L F
.43956 .90182 m .43962 .9018 L .43955 .90451 L .539 .332 .549 r
F
.43954 .90452 m .43955 .90451 L .43952 .90576 L F
.43956 .90182 m .43955 .90451 L .43954 .90452 L F
.43956 .90451 m .43867 .90487 L .43983 .90461 L .657 .814 .959 r
F
.43864 .90485 m .43867 .90487 L .43956 .90451 L F
.43867 .90487 m .43886 .905 L .43952 .90473 L F
.43867 .90487 m .43952 .90473 L .43983 .90461 L F
.43956 .90182 m .43953 .90452 L .43855 .90218 L .539 .332 .549 r
F
.43953 .90452 m .43952 .90576 L .43922 .90464 L F
.43953 .90452 m .43922 .90464 L .43855 .90218 L F
.44031 .90137 m .44027 .90407 L .4403 .90137 L .387 .212 .518 r
F
.43983 .90461 m .44055 .90464 L .44057 .90413 L .657 .814 .959 r
F
.44027 .90407 m .44025 .90534 L .44027 .90407 L .387 .212 .518 r
F
.44027 .90407 m .44027 .90407 L .4403 .90137 L F
.44026 .90408 m .43956 .90451 L .44057 .90413 L .657 .814 .959 r
F
.43956 .90451 m .43956 .90451 L .44026 .90408 L F
.43956 .90451 m .43983 .90461 L .44051 .90417 L F
.43956 .90451 m .44051 .90417 L .44057 .90413 L F
.4403 .90137 m .44027 .90407 L .43962 .9018 L .387 .212 .518 r
F
.44027 .90407 m .44025 .90534 L .44005 .90421 L F
.44027 .90407 m .44005 .90421 L .43962 .9018 L F
.44102 .90361 m .44057 .90413 L .44103 .90361 L .657 .814 .959 r
F
.44035 .90135 m .44057 .90372 L .44028 .90407 L .095 0 .426 r
F
.44033 .90138 m .44529 .90106 L .44079 .90086 L .657 .813 .959 r
F
.44075 .90087 m .4407 .90357 L .44075 .90088 L .095 0 .426 r
F
.44289 .90304 m .44618 .90422 L .44839 .90281 L .657 .813 .959 r
F
.44098 .90381 m .44618 .90422 L .44289 .90304 L F
.44063 .90406 m .44555 .90381 L .44103 .90361 L .657 .814 .959 r
F
.44057 .90413 m .44062 .90413 L .44063 .90406 L F
.44062 .90413 m .44555 .90381 L .44063 .90406 L F
.44079 .90086 m .44529 .90106 L .4456 .89999 L .657 .813 .959 r
F
.44079 .90086 m .4456 .89999 L .44095 .90033 L F
.44086 .90031 m .44079 .90301 L .44086 .90031 L 0 0 .082 r
F
.44062 .90413 m .44462 .90485 L .44555 .90381 L .657 .814 .959 r
F
.44057 .90413 m .44062 .90414 L .44062 .90413 L F
.44062 .90414 m .44462 .90485 L .44062 .90413 L F
.44086 .90031 m .44079 .90301 L .44077 .90085 L 0 0 .082 r
F
.44079 .90301 m .44077 .90318 L .44077 .90085 L F
.4407 .90357 m .4407 .90357 L .44075 .90088 L .095 0 .426 r
F
.44077 .90085 m .44077 .90318 L .44071 .90356 L 0 0 .082 r
F
.44074 .90339 m .44103 .90361 L .4411 .90338 L .657 .814 .959 r
F
.44075 .90087 m .44077 .90085 L .44071 .90356 L .095 0 .426 r
F
.4407 .90357 m .44071 .90356 L .44068 .90484 L F
.44075 .90087 m .44071 .90356 L .4407 .90357 L F
.44068 .9036 m .4407 .9036 L .44071 .90356 L .657 .814 .959 r
F
.44075 .90088 m .4407 .90357 L .44035 .90135 L .095 0 .426 r
F
.44068 .9036 m .44028 .90407 L .44102 .90361 L .657 .814 .959 r
F
.44026 .90408 m .44057 .90413 L .44102 .90361 L F
.4407 .90357 m .44068 .90484 L .44057 .90372 L .095 0 .426 r
F
.4407 .90357 m .44057 .90372 L .44035 .90135 L F
.44031 .90137 m .44035 .90135 L .44025 .90534 L .387 .212 .518 r
F
.43846 .9022 m .43846 .9022 L .43852 .83696 L .651 .424 .562 r
F
.44031 .90137 m .4403 .90137 L .44121 .83667 L .387 .212 .518 r
F
.43959 .83704 m .43946 .8375 L .43978 .83735 L .592 .769 .964 r
F
.43952 .83693 m .43949 .83706 L .43959 .83704 L F
.43863 .83696 m .44017 .83691 L .43855 .90218 L .651 .424 .562 r
F
.43847 .9022 m .43855 .90218 L .43846 .90608 L F
.43863 .83696 m .43855 .90218 L .43847 .9022 L F
.44023 .83689 m .43956 .90182 L .44017 .83691 L .539 .332 .549 r
F
.43956 .90182 m .43952 .90576 L .43956 .90182 L F
.43956 .90182 m .43956 .90182 L .44017 .83691 L F
.43862 .83696 m .43863 .83696 L .43846 .90608 L .651 .424 .562 r
F
.43652 .90517 m .43653 .90522 L .4368 .90518 L .657 .814 .959 r
F
.43852 .83696 m .4383 .8372 L .43853 .83728 L .592 .769 .964 r
F
.43697 .83673 m .43852 .83696 L .4368 .90518 L .747 .505 .564 r
F
.43678 .90518 m .4368 .90518 L .43678 .90623 L F
.43697 .83673 m .4368 .90518 L .43678 .90518 L F
.43653 .90522 m .43653 .90544 L .43721 .90519 L .657 .814 .959 r
F
.4368 .90518 m .43721 .90519 L .43758 .90505 L F
.43653 .90522 m .43721 .90519 L .4368 .90518 L F
.43629 .90067 m .43855 .90218 L .43856 .90218 L .657 .813 .959 r
F
.43953 .90183 m .43856 .90218 L .4396 .90185 L F
.43629 .90067 m .43856 .90218 L .43953 .90183 L F
.43855 .90218 m .43864 .90224 L .43894 .90212 L F
.43855 .90218 m .43894 .90212 L .4396 .90185 L F
.43629 .90067 m .44079 .90086 L .44093 .90038 L F
.4409 .90033 m .44093 .90038 L .44095 .90033 L F
.43629 .90067 m .44093 .90038 L .4409 .90033 L F
.44203 .82976 m .44188 .83025 L .442 .83031 L .889 .63 .539 r
F
.4505 .82974 m .46173 .83315 L .46434 .83066 L .594 .768 .963 r
F
.44844 .83075 m .46173 .83315 L .4505 .82974 L F
.4505 .82974 m .46434 .83066 L .4518 .82849 L F
.44188 .83025 m .45151 .83013 L .4502 .82871 L .593 .769 .963 r
F
.43886 .83081 m .44257 .83061 L .44188 .83025 L F
.44257 .83061 m .45151 .83013 L .44188 .83025 L F
.44254 .83056 m .44201 .83032 L .44253 .83102 L .993 .743 .421 r
F
.44254 .83056 m .44253 .83102 L .44253 .83103 L F
.44393 .83053 m .45196 .83159 L .45151 .83013 L .593 .769 .963 r
F
.43886 .83081 m .44674 .83128 L .44393 .83053 L F
.44674 .83128 m .45196 .83159 L .44393 .83053 L F
.43886 .83081 m .44188 .83025 L .44127 .82993 L F
.44201 .83032 m .44183 .83463 L .44191 .83467 L .889 .63 .539 r
F
.442 .83031 m .44183 .83463 L .44201 .83032 L F
.442 .83031 m .44076 .83408 L .44183 .83463 L F
.44253 .83102 m .44201 .83032 L .44191 .83467 L .993 .743 .421 r
F
.4385 .83531 m .44257 .83456 L .44141 .83425 L .592 .769 .964 r
F
.43629 .90067 m .43742 .90237 L .43855 .90218 L .657 .813 .959 r
F
.43629 .90067 m .4396 .90185 L .44033 .90138 L F
.44089 .82913 m .44086 .82972 L .44087 .82973 L .799 .548 .56 r
F
.44089 .82913 m .43973 .82942 L .44086 .82972 L F
.44203 .82976 m .44089 .82913 L .44087 .82973 L .889 .63 .539 r
F
.44203 .82976 m .44087 .82973 L .44188 .83025 L F
.44072 .82954 m .44811 .82744 L .44538 .82639 L .593 .769 .963 r
F
.43886 .83081 m .44193 .82969 L .44072 .82954 L F
.44193 .82969 m .44811 .82744 L .44072 .82954 L F
.43629 .90067 m .43631 .90245 L .43749 .90248 L .657 .813 .959 r
F
.4385 .83531 m .43959 .83704 L .44047 .83684 L .592 .769 .964 r
F
.43886 .83081 m .43889 .83287 L .43999 .83262 L .593 .769 .963 r
F
.4385 .83531 m .43852 .83696 L .43952 .83693 L .592 .769 .964 r
F
.43975 .82884 m .43972 .82942 L .43973 .82942 L .733 .492 .564 r
F
.43975 .82884 m .43861 .82875 L .43859 .82929 L F
.43975 .82884 m .43859 .82929 L .43972 .82942 L F
.4399 .82509 m .43975 .82884 L .44098 .82538 L .799 .548 .56 r
F
.43886 .83081 m .4422 .82564 L .4388 .82525 L .593 .769 .963 r
F
.43973 .82942 m .43955 .83377 L .43962 .83378 L .733 .492 .564 r
F
.43972 .82942 m .43955 .83377 L .43973 .82942 L F
.4385 .83531 m .44059 .8339 L .4395 .83377 L .592 .769 .964 r
F
.44087 .82973 m .4407 .83406 L .44076 .83408 L .799 .548 .56 r
F
.4385 .83531 m .44141 .83425 L .44044 .834 L .592 .769 .964 r
F
.44086 .82972 m .44069 .83406 L .44087 .82973 L .799 .548 .56 r
F
.4576 .83516 m .46669 .83954 L .4729 .83654 L .594 .768 .963 r
F
.4576 .83516 m .4729 .83654 L .46173 .83315 L F
.45021 .83424 m .46151 .83766 L .46414 .83517 L .593 .769 .963 r
F
.45021 .83424 m .46414 .83517 L .45152 .83299 L F
.4385 .83531 m .45117 .83464 L .44985 .83322 L .592 .769 .964 r
F
.43629 .90067 m .44033 .90138 L .44079 .90086 L .657 .813 .959 r
F
.43629 .90067 m .44095 .90033 L .44078 .89982 L F
.44069 .83406 m .43805 .89898 L .4407 .83406 L .799 .548 .56 r
F
.43805 .89898 m .43806 .89898 L .4407 .83406 L F
.43629 .90067 m .43828 .89902 L .438 .89898 L .657 .813 .959 r
F
.43629 .90067 m .438 .89898 L .43727 .89898 L F
.43629 .90067 m .43924 .89917 L .43828 .89902 L F
.44183 .83463 m .43916 .89914 L .43922 .89916 L .889 .63 .539 r
F
.43924 .89917 m .43916 .89914 L .43828 .89902 L .657 .813 .959 r
F
.4365 .90342 m .44074 .90339 L .44078 .90311 L .657 .814 .959 r
F
.4365 .90342 m .44068 .9036 L .44074 .90339 L F
.44191 .83467 m .43923 .89916 L .44033 .89961 L .889 .63 .539 r
F
.44239 .83533 m .44191 .83467 L .44033 .89961 L .993 .743 .421 r
F
.44239 .83533 m .44033 .89961 L .44036 .89964 L F
.44036 .89964 m .44036 .89965 L .44242 .83538 L F
.44242 .83538 m .44036 .89965 L .44086 .90028 L F
.44036 .89964 m .44036 .89964 L .44239 .83534 L F
.43629 .90067 m .44078 .89982 L .44073 .89977 L .657 .813 .959 r
F
.43999 .89947 m .44073 .89977 L .44031 .89937 L F
.43629 .90067 m .44073 .89977 L .43999 .89947 L F
.44183 .83463 m .43922 .89916 L .44191 .83467 L .889 .63 .539 r
F
.43629 .90067 m .44031 .89937 L .44013 .89928 L .657 .813 .959 r
F
.43927 .89915 m .44013 .89928 L .43957 .899 L F
.43629 .90067 m .44013 .89928 L .43927 .89915 L F
.4407 .83406 m .43806 .89898 L .44076 .83408 L .799 .548 .56 r
F
.4365 .90342 m .43848 .90177 L .43793 .9017 L .657 .814 .959 r
F
.438 .89898 m .43702 .9017 L .43793 .9017 L .733 .492 .564 r
F
.4375 .9017 m .43793 .9017 L .43753 .90164 L .657 .814 .959 r
F
.4365 .90342 m .43793 .9017 L .4375 .9017 L F
.43793 .9017 m .43675 .90249 L .43791 .90258 L .733 .492 .564 r
F
.43678 .90171 m .43702 .9017 L .438 .89898 L F
.4365 .90342 m .4375 .9017 L .43676 .90171 L .657 .814 .959 r
F
.4385 .83531 m .43528 .83647 L .4365 .83666 L .592 .769 .964 r
F
.42907 .83368 m .42709 .83186 L .4258 .83312 L F
.4385 .83531 m .43444 .83408 L .43279 .83432 L F
.43642 .83671 m .43577 .83667 L .43604 .83697 L F
.43399 .90258 m .43394 .90473 L .43511 .9027 L .657 .813 .959 r
F
.43419 .90534 m .43414 .90749 L .43532 .90546 L .657 .814 .959 r
F
.42957 .90916 m .43275 .90678 L .43296 .90952 L .784 .537 .562 r
F
.42957 .90916 m .42937 .90642 L .43275 .90678 L F
.43169 .90449 m .4294 .90639 L .43277 .90675 L .657 .813 .959 r
F
.43419 .90534 m .43188 .90725 L .43414 .90749 L .657 .814 .959 r
F
.43321 .90509 m .43188 .90725 L .43413 .90538 L F
.43404 .9053 m .43413 .90538 L .43419 .90534 L F
.43321 .90509 m .43413 .90538 L .43404 .9053 L F
.43399 .90258 m .43325 .90319 L .43394 .90473 L .657 .813 .959 r
F
.43325 .90319 m .43169 .90449 L .43352 .90468 L F
.43325 .90319 m .43352 .90468 L .43394 .90473 L F
.43302 .90233 m .43169 .90449 L .43325 .90319 L F
.43311 .90235 m .43325 .90319 L .43399 .90258 L F
.43302 .90233 m .43325 .90319 L .43311 .90235 L F
.43458 .83496 m .43293 .90138 L .43458 .83492 L .868 .695 .169 r
F
.43302 .90233 m .43118 .90327 L .43169 .90449 L .657 .813 .959 r
F
.43118 .90327 m .42976 .90399 L .43054 .90419 L F
.43118 .90327 m .43054 .90419 L .43169 .90449 L F
.43228 .90197 m .43182 .90233 L .43302 .90233 L F
.43182 .90233 m .42976 .90399 L .43118 .90327 L F
.43182 .90233 m .43118 .90327 L .43302 .90233 L F
.43467 .83546 m .43416 .86133 L .43332 .88696 L .984 .727 .46 r
F
.43406 .90252 m .43302 .90233 L .43399 .90258 L .657 .813 .959 r
F
.43582 .83636 m .43513 .90241 L .43411 .90219 L .83 .576 .556 r
F
.43513 .90267 m .43399 .90258 L .43511 .9027 L .657 .813 .959 r
F
.43589 .83638 m .43513 .90241 L .43582 .83636 L .83 .576 .556 r
F
.43546 .90521 m .43419 .90534 L .43532 .90546 L .657 .814 .959 r
F
.43513 .90241 m .4351 .90514 L .43513 .90241 L .83 .576 .556 r
F
.4351 .90514 m .4351 .90514 L .43513 .90241 L F
.43457 .90502 m .43419 .90534 L .43546 .90521 L .657 .814 .959 r
F
.43434 .90229 m .43399 .90258 L .43513 .90267 L .657 .813 .959 r
F
.43404 .9049 m .43509 .90604 L .43402 .90569 L .83 .576 .556 r
F
.43411 .90219 m .43485 .90508 L .43404 .9049 L F
.43485 .90508 m .43509 .90604 L .43404 .9049 L F
.43447 .9051 m .43384 .9051 L .43419 .90534 L .657 .814 .959 r
F
.43384 .9051 m .43321 .90509 L .43404 .9053 L F
.43384 .9051 m .43404 .9053 L .43419 .90534 L F
.43358 .90205 m .43302 .90233 L .43406 .90252 L .657 .813 .959 r
F
.43358 .90205 m .43228 .90197 L .43302 .90233 L F
.4347 .83549 m .43336 .90182 L .43467 .83546 L .984 .727 .46 r
F
.43336 .90182 m .43336 .90182 L .43467 .83546 L F
.4332 .90167 m .43228 .90197 L .43358 .90205 L .657 .813 .959 r
F
.4333 .90456 m .4333 .90456 L .43335 .90182 L .984 .727 .46 r
F
.43336 .90182 m .43335 .90182 L .43467 .83546 L F
.4333 .90456 m .43335 .90182 L .43336 .90182 L F
.43293 .90138 m .43293 .90137 L .43458 .83492 L .868 .695 .169 r
F
.43458 .83492 m .43293 .90137 L .43284 .90085 L F
.43458 .83496 m .43467 .83546 L .43294 .9014 L F
.43458 .83496 m .43294 .9014 L .43293 .90138 L F
.43285 .90132 m .43164 .901 L .4318 .90151 L .657 .813 .959 r
F
.4347 .83549 m .4351 .83594 L .43338 .90184 L .984 .727 .46 r
F
.4347 .83549 m .43338 .90184 L .43336 .90183 L F
.43336 .90182 m .4333 .90456 L .4333 .90456 L F
.4347 .83549 m .43336 .90183 L .43336 .90182 L F
.43336 .90183 m .4333 .90456 L .43336 .90182 L F
.43248 .90094 m .43179 .90047 L .43164 .901 L .657 .813 .959 r
F
.43505 .83432 m .43458 .83492 L .43284 .90085 L 0 0 .377 r
F
.43505 .83432 m .43284 .90085 L .43286 .90082 L F
.43513 .90241 m .43513 .90241 L .43582 .83636 L .83 .576 .556 r
F
.4351 .83594 m .43407 .90217 L .43338 .90184 L .908 .647 .532 r
F
.43416 .86133 m .43335 .90182 L .43332 .88696 L .984 .727 .46 r
F
.43335 .90182 m .4333 .90177 L .43332 .88696 L F
.4332 .90167 m .43234 .90157 L .43228 .90197 L .657 .813 .959 r
F
.43285 .90132 m .4318 .90151 L .4332 .90167 L F
.43294 .9014 m .4333 .90456 L .43287 .90412 L .984 .727 .46 r
F
.43332 .88696 m .4333 .90177 L .43294 .9014 L F
.4333 .90177 m .4333 .90456 L .43294 .9014 L F
.43505 .83432 m .43286 .90082 L .43508 .83428 L 0 0 .377 r
F
.43286 .90082 m .43286 .90081 L .43508 .83428 L F
.43508 .83428 m .43286 .90081 L .43335 .9001 L F
.43278 .90041 m .43259 .90001 L .43189 .90035 L .657 .813 .959 r
F
.43431 .90503 m .4338 .90506 L .43447 .9051 L .657 .814 .959 r
F
.4338 .90506 m .43384 .9051 L .43447 .9051 L F
.43515 .83596 m .43408 .90217 L .4351 .83594 L .908 .647 .532 r
F
.43408 .90217 m .43403 .9049 L .43407 .90217 L F
.43403 .9049 m .43403 .9049 L .43407 .90217 L F
.43338 .90184 m .43388 .90483 L .4333 .90456 L F
.43369 .90199 m .43338 .90184 L .43358 .90205 L .657 .813 .959 r
F
.43434 .90229 m .43361 .90208 L .43406 .90252 L F
.43439 .90225 m .43411 .90219 L .43434 .90229 L F
.43411 .90219 m .43361 .90208 L .43434 .90229 L F
.43515 .83596 m .43582 .83636 L .43411 .90219 L .908 .647 .532 r
F
.43371 .90483 m .43321 .90509 L .43431 .90503 L .657 .814 .959 r
F
.4338 .90479 m .43246 .90472 L .43321 .90509 L F
.43408 .90217 m .43411 .90219 L .43404 .9049 L .908 .647 .532 r
F
.43408 .90217 m .43404 .9049 L .43403 .9049 L F
.43407 .90217 m .43403 .9049 L .43338 .90184 L F
.43403 .9049 m .43388 .90483 L .43338 .90184 L F
.43336 .90183 m .43338 .90184 L .4333 .90456 L .984 .727 .46 r
F
.43336 .90182 m .4333 .90456 L .43336 .90182 L F
.43526 .90244 m .43434 .90229 L .43513 .90267 L .657 .813 .959 r
F
.43439 .90225 m .43434 .90229 L .43526 .90244 L F
.43513 .90241 m .43509 .90604 L .43411 .90219 L .83 .576 .556 r
F
.43335 .90182 m .4333 .90456 L .4333 .90177 L .984 .727 .46 r
F
.43519 .90242 m .43678 .90518 L .43512 .90514 L .747 .505 .564 r
F
.4365 .83666 m .43633 .83665 L .43642 .83671 L .592 .769 .964 r
F
.43589 .83638 m .43687 .83671 L .43519 .90242 L .83 .576 .556 r
F
.43513 .90241 m .43519 .90242 L .43509 .90604 L F
.43589 .83638 m .43519 .90242 L .43513 .90241 L F
.43632 .90267 m .43511 .9027 L .43632 .90268 L .657 .813 .959 r
F
.43629 .90067 m .43526 .90244 L .43632 .90267 L F
.43526 .90244 m .43511 .9027 L .43632 .90267 L F
.4365 .90342 m .43317 .90449 L .4338 .90479 L .657 .814 .959 r
F
.43317 .90449 m .43246 .90472 L .4338 .90479 L F
.43403 .9049 m .43404 .9049 L .43402 .90569 L .908 .647 .532 r
F
.43515 .83596 m .43411 .90219 L .43408 .90217 L F
.43371 .90483 m .43431 .90503 L .43404 .9049 L .657 .814 .959 r
F
.43403 .9049 m .43402 .90569 L .43388 .90483 L .908 .647 .532 r
F
.43404 .9049 m .43431 .90503 L .43457 .90502 L .657 .814 .959 r
F
.4365 .90342 m .4338 .90479 L .43457 .90502 L F
.4338 .90479 m .43371 .90483 L .43404 .9049 L F
.4338 .90479 m .43404 .9049 L .43457 .90502 L F
.43403 .9049 m .43402 .90569 L .43403 .9049 L .908 .647 .532 r
F
.43408 .90217 m .43407 .90217 L .4351 .83594 L F
.43629 .90067 m .4332 .90167 L .43338 .90184 L .657 .813 .959 r
F
.43629 .90067 m .43338 .90184 L .43369 .90199 L F
.43629 .90067 m .43329 .90014 L .43278 .90041 L F
.43329 .90014 m .43259 .90001 L .43278 .90041 L F
.43261 .90051 m .43189 .90035 L .43202 .90048 L F
.43629 .90067 m .43278 .90041 L .43261 .90051 L F
.43278 .90041 m .43189 .90035 L .43261 .90051 L F
.43433 .83105 m .42576 .83002 L .42624 .83148 L .593 .769 .963 r
F
.43444 .83408 m .42915 .83084 L .42709 .83186 L .592 .769 .964 r
F
.43632 .82946 m .43508 .83428 L .43614 .83385 L .428 .243 .527 r
F
.43623 .8295 m .43508 .83428 L .43632 .82946 L F
.43623 .8295 m .43519 .82992 L .43508 .83428 L F
.4385 .83531 m .43558 .83391 L .43444 .83408 L .592 .769 .964 r
F
.43558 .83391 m .42915 .83084 L .43444 .83408 L F
.43699 .83237 m .43863 .83261 L .43699 .83242 L .747 .505 .564 r
F
.43863 .83261 m .43863 .83261 L .43699 .83237 L F
.43886 .83081 m .4367 .83227 L .43699 .83237 L .593 .769 .963 r
F
.43886 .83081 m .43699 .83237 L .43777 .83248 L F
.43745 .82929 m .43727 .83366 L .43746 .82929 L .585 .37 .555 r
F
.43629 .90067 m .43261 .90051 L .43248 .90094 L .657 .813 .959 r
F
.43261 .90051 m .43202 .90048 L .43225 .90071 L F
.43261 .90051 m .43225 .90071 L .43248 .90094 L F
.43745 .82929 m .43632 .82946 L .43621 .83382 L .585 .37 .555 r
F
.43699 .83237 m .43699 .83242 L .43697 .83236 L .83 .576 .556 r
F
.43745 .82929 m .43621 .83382 L .43727 .83366 L .585 .37 .555 r
F
.43632 .82946 m .43614 .83385 L .43621 .83382 L .428 .243 .527 r
F
.43632 .82946 m .43614 .83385 L .43632 .82946 L F
.43437 .83099 m .42576 .83002 L .43433 .83105 L .593 .769 .963 r
F
.4385 .83531 m .43186 .83012 L .42915 .83084 L .592 .769 .964 r
F
.43614 .83385 m .43508 .83428 L .43335 .9001 L .428 .243 .527 r
F
.43629 .90067 m .43248 .90094 L .43285 .90132 L .657 .813 .959 r
F
.43629 .90067 m .43285 .90132 L .4332 .90167 L F
.43614 .83385 m .43335 .9001 L .4334 .90007 L .428 .243 .527 r
F
.43259 .90001 m .43298 .89948 L .43224 .89995 L .657 .813 .959 r
F
.43614 .83385 m .4334 .90007 L .43621 .83382 L .428 .243 .527 r
F
.4334 .90007 m .43341 .90007 L .43621 .83382 L F
.43621 .83382 m .43341 .90007 L .43451 .89947 L F
.43629 .90067 m .43364 .89971 L .43259 .90001 L .657 .813 .959 r
F
.43364 .89971 m .43298 .89948 L .43259 .90001 L F
.43727 .83366 m .43728 .83366 L .43746 .82929 L .585 .37 .555 r
F
.43746 .82929 m .43728 .83366 L .43735 .83365 L F
.43792 .82929 m .4388 .82525 L .43539 .82524 L .593 .769 .963 r
F
.43886 .83081 m .43884 .82929 L .43792 .82929 L F
.43861 .82875 m .43859 .82929 L .43859 .82929 L .667 .437 .562 r
F
.43884 .82929 m .4388 .82525 L .43792 .82929 L .593 .769 .963 r
F
.43859 .82929 m .43841 .83364 L .43848 .83364 L .667 .437 .562 r
F
.43859 .82929 m .43841 .83364 L .43859 .82929 L F
.43859 .82929 m .43746 .82929 L .43735 .83365 L F
.43859 .82929 m .43735 .83365 L .43841 .83364 L F
.43551 .82979 m .42746 .82735 L .43476 .8301 L .593 .769 .963 r
F
.4385 .83531 m .43503 .82975 L .43186 .83012 L .592 .769 .964 r
F
.43727 .83366 m .43456 .89945 L .43728 .83366 L .585 .37 .555 r
F
.43629 .90067 m .43358 .90205 L .43361 .90208 L .657 .813 .959 r
F
.43629 .90067 m .43361 .90208 L .43439 .90225 L F
.43364 .89971 m .43394 .89909 L .43298 .89948 L F
.43629 .90067 m .43451 .89947 L .43364 .89971 L F
.43451 .89947 m .43394 .89909 L .43364 .89971 L F
.43728 .83366 m .43456 .89945 L .43735 .83365 L .585 .37 .555 r
F
.43286 .9041 m .43199 .90427 L .43294 .90457 L .657 .814 .959 r
F
.43284 .90085 m .43285 .90402 L .43277 .90357 L .868 .695 .169 r
F
.43233 .9042 m .43182 .90376 L .43199 .90427 L .657 .814 .959 r
F
.43293 .90138 m .43286 .90412 L .43293 .90137 L .868 .695 .169 r
F
.43286 .90412 m .43285 .90474 L .43286 .90411 L F
.43286 .90412 m .43286 .90411 L .43293 .90137 L F
.43286 .9041 m .43268 .90369 L .43233 .9042 L .657 .814 .959 r
F
.43293 .90137 m .43285 .90474 L .43284 .90085 L .868 .695 .169 r
F
.43293 .90138 m .43294 .9014 L .43285 .90474 L F
.4365 .90342 m .43279 .90369 L .43286 .9041 L .657 .814 .959 r
F
.43279 .90369 m .43268 .90369 L .43286 .9041 L F
.43268 .90369 m .43182 .90376 L .43233 .9042 L F
.43286 .90082 m .43277 .90356 L .43286 .90081 L 0 0 .377 r
F
.43277 .90356 m .43277 .90356 L .43286 .90081 L F
.43286 .90082 m .43284 .90085 L .43277 .90357 L F
.43286 .90082 m .43277 .90357 L .43277 .90356 L F
.4365 .90342 m .43298 .90326 L .43268 .90369 L .657 .814 .959 r
F
.43335 .9001 m .43286 .90344 L .43328 .90282 L 0 0 .377 r
F
.43251 .90324 m .43243 .9027 L .43197 .90322 L .657 .814 .959 r
F
.43286 .90081 m .43277 .90356 L .43335 .9001 L 0 0 .377 r
F
.43277 .90356 m .43275 .90414 L .43286 .90344 L F
.43277 .90356 m .43286 .90344 L .43335 .9001 L F
.43298 .90326 m .43325 .90284 L .43251 .90324 L .657 .814 .959 r
F
.4365 .90342 m .43327 .90284 L .43298 .90326 L F
.43327 .90284 m .43325 .90284 L .43298 .90326 L F
.43325 .90284 m .43243 .9027 L .43251 .90324 L F
.4334 .90007 m .43329 .90282 L .43341 .90007 L .428 .243 .527 r
F
.43329 .90282 m .43327 .90338 L .43329 .90282 L F
.43329 .90282 m .43329 .90282 L .43341 .90007 L F
.43328 .90282 m .43275 .90414 L .43327 .90338 L 0 0 .377 r
F
.43286 .90344 m .43275 .90414 L .43328 .90282 L F
.43268 .90369 m .43251 .90324 L .43182 .90376 L .657 .814 .959 r
F
.43298 .90326 m .43251 .90324 L .43268 .90369 L F
.43251 .90324 m .43197 .90322 L .43187 .9036 L F
.43251 .90324 m .43187 .9036 L .43182 .90376 L F
.4334 .90007 m .43335 .9001 L .43328 .90282 L .428 .243 .527 r
F
.43329 .90282 m .43328 .90282 L .43327 .90338 L F
.4334 .90007 m .43328 .90282 L .43329 .90282 L F
.43277 .90357 m .43285 .90474 L .43275 .90414 L .868 .695 .169 r
F
.43277 .90356 m .43275 .90414 L .43277 .90356 L 0 0 .377 r
F
.43285 .90402 m .43285 .90474 L .43277 .90357 L .868 .695 .169 r
F
.43294 .90457 m .43199 .90427 L .43246 .90472 L .657 .814 .959 r
F
.4365 .90342 m .43286 .9041 L .43294 .90457 L F
.43277 .90356 m .43277 .90357 L .43275 .90414 L 0 0 .377 r
F
.43451 .89947 m .43337 .90083 L .43417 .90233 L .428 .243 .527 r
F
.43451 .89947 m .43417 .90233 L .43444 .90219 L F
.43456 .89945 m .43445 .90219 L .43456 .89945 L .585 .37 .555 r
F
.43445 .90219 m .43445 .90219 L .43456 .89945 L F
.4365 .90342 m .43354 .90244 L .43327 .90284 L .657 .814 .959 r
F
.43417 .90233 m .43332 .90335 L .43442 .9028 L .428 .243 .527 r
F
.43337 .90083 m .43334 .90279 L .43417 .90233 L F
.43334 .90279 m .43332 .90335 L .43417 .90233 L F
.4365 .90342 m .4346 .90214 L .43444 .90219 L .657 .814 .959 r
F
.4339 .90248 m .43444 .90219 L .43368 .9024 L F
.4365 .90342 m .43444 .90219 L .4339 .90248 L F
.43368 .9024 m .43414 .90183 L .43317 .90222 L F
.4365 .90342 m .4339 .90248 L .43381 .90253 L F
.43629 .90067 m .43439 .90225 L .43526 .90244 L .657 .813 .959 r
F
.43727 .83366 m .43621 .83382 L .43451 .89947 L .585 .37 .555 r
F
.4365 .90342 m .43549 .90189 L .4346 .90214 L .657 .814 .959 r
F
.43629 .90067 m .43534 .89923 L .43451 .89947 L .657 .813 .959 r
F
.43735 .83365 m .43456 .89945 L .43567 .89914 L .585 .37 .555 r
F
.43551 .82979 m .42952 .82633 L .42746 .82735 L .593 .769 .963 r
F
.43618 .82952 m .42952 .82633 L .43551 .82979 L F
.4385 .83531 m .43844 .82976 L .43503 .82975 L .592 .769 .964 r
F
.43841 .83364 m .43735 .83365 L .43567 .89914 L .667 .437 .562 r
F
.43841 .83364 m .43567 .89914 L .43572 .89913 L F
.43629 .90067 m .43627 .89906 L .43532 .89919 L .657 .813 .959 r
F
.43629 .90067 m .43727 .89898 L .43627 .89906 L F
.43962 .83378 m .43689 .89898 L .438 .89898 L .733 .492 .564 r
F
.43727 .89898 m .43683 .89898 L .43627 .89906 L .657 .813 .959 r
F
.4385 .83531 m .4395 .83377 L .43848 .83364 L .592 .769 .964 r
F
.43955 .83377 m .43848 .83364 L .43683 .89898 L .733 .492 .564 r
F
.43689 .89898 m .43683 .89898 L .43675 .90249 L F
.43955 .83377 m .43683 .89898 L .43689 .89898 L F
.43955 .83377 m .43689 .89898 L .43962 .83378 L F
.43689 .89898 m .43689 .89898 L .43962 .83378 L F
.43848 .83364 m .43573 .89913 L .43683 .89898 L .667 .437 .562 r
F
.43955 .83377 m .43689 .89898 L .43955 .83377 L .733 .492 .564 r
F
.43689 .89898 m .43689 .89898 L .43955 .83377 L F
.43627 .89899 m .43747 .89863 L .43627 .89865 L .657 .813 .959 r
F
.43627 .89906 m .43648 .89899 L .43627 .89899 L F
.43648 .89899 m .43747 .89863 L .43627 .89899 L F
.43727 .89898 m .4373 .89892 L .43683 .89898 L F
.43689 .89898 m .43675 .90249 L .43689 .89898 L .733 .492 .564 r
F
.43683 .89898 m .43561 .90186 L .43676 .90171 L .667 .437 .562 r
F
.43573 .89913 m .43561 .90186 L .43683 .89898 L F
.4373 .89892 m .43747 .89863 L .43627 .89906 L .657 .813 .959 r
F
.43841 .83364 m .43561 .90186 L .43848 .83364 L .667 .437 .562 r
F
.43532 .89919 m .43627 .89865 L .43506 .8988 L .657 .813 .959 r
F
.43627 .89906 m .43627 .89865 L .43532 .89919 L F
.4356 .90186 m .43442 .9028 L .43558 .90255 L .585 .37 .555 r
F
.43567 .89914 m .43465 .90213 L .4356 .90186 L F
.43465 .90213 m .43442 .9028 L .4356 .90186 L F
.43549 .90188 m .43648 .90139 L .43526 .90155 L .657 .814 .959 r
F
.4365 .90342 m .43648 .90174 L .43549 .90188 L F
.43648 .90174 m .43648 .90139 L .43549 .90188 L F
.43572 .89913 m .43567 .89914 L .4356 .90186 L .667 .437 .562 r
F
.43561 .90186 m .4356 .90186 L .43558 .90255 L F
.43572 .89913 m .4356 .90186 L .43561 .90186 L F
.43456 .89945 m .43442 .9028 L .43567 .89914 L .585 .37 .555 r
F
.4346 .90214 m .43526 .90155 L .43414 .90183 L .657 .814 .959 r
F
.43549 .90189 m .43526 .90155 L .4346 .90214 L F
.43456 .89945 m .43451 .89947 L .43444 .90219 L .585 .37 .555 r
F
.43445 .90219 m .43444 .90219 L .43442 .9028 L F
.43456 .89945 m .43444 .90219 L .43445 .90219 L F
.43727 .83366 m .43451 .89947 L .43456 .89945 L F
.43456 .89945 m .43456 .89945 L .43735 .83365 L F
.43456 .89945 m .43456 .89945 L .43728 .83366 L F
.43451 .89947 m .43506 .8988 L .43394 .89909 L .657 .813 .959 r
F
.43534 .89923 m .43506 .8988 L .43451 .89947 L F
.4346 .90214 m .43414 .90183 L .43368 .9024 L .657 .814 .959 r
F
.43456 .89945 m .43445 .90219 L .43456 .89945 L .585 .37 .555 r
F
.43445 .90219 m .43442 .9028 L .43445 .90219 L F
.43445 .90219 m .43445 .90219 L .43456 .89945 L F
.43444 .90219 m .43417 .90233 L .43442 .9028 L .428 .243 .527 r
F
.43381 .90253 m .43368 .9024 L .43354 .90244 L .657 .814 .959 r
F
.4339 .90248 m .43368 .9024 L .43381 .90253 L F
.43334 .90279 m .43327 .90338 L .43332 .90335 L .428 .243 .527 r
F
.43337 .90083 m .43329 .90282 L .43334 .90279 L F
.43329 .90282 m .43327 .90338 L .43334 .90279 L F
.43325 .90284 m .43354 .90244 L .43256 .90272 L .657 .814 .959 r
F
.43327 .90284 m .43328 .90282 L .43325 .90284 L F
.43328 .90282 m .43354 .90244 L .43325 .90284 L F
.43256 .90272 m .43317 .90222 L .43243 .9027 L F
.43368 .9024 m .43317 .90222 L .43256 .90272 L F
.43445 .90219 m .43442 .9028 L .43445 .90219 L .585 .37 .555 r
F
.43341 .90007 m .43337 .90083 L .43451 .89947 L .428 .243 .527 r
F
.43259 .90001 m .43224 .89995 L .43206 .90016 L .657 .813 .959 r
F
.43259 .90001 m .43206 .90016 L .43189 .90035 L F
.43202 .90048 m .43189 .90035 L .43179 .90047 L F
.43202 .90048 m .43179 .90047 L .43248 .90094 L F
.43248 .90094 m .43164 .901 L .43285 .90132 L F
.4333 .90456 m .4333 .90456 L .43329 .90525 L .984 .727 .46 r
F
.4338 .90506 m .43321 .90509 L .43384 .9051 L .657 .814 .959 r
F
.43234 .90157 m .4318 .90151 L .43215 .90185 L .657 .813 .959 r
F
.43234 .90157 m .43215 .90185 L .43228 .90197 L F
.4333 .90456 m .43329 .90525 L .4333 .90456 L .984 .727 .46 r
F
.4333 .90456 m .43402 .90569 L .43329 .90525 L .908 .647 .532 r
F
.43388 .90483 m .43402 .90569 L .4333 .90456 L F
.43457 .90502 m .43431 .90503 L .43447 .9051 L .657 .814 .959 r
F
.4365 .90342 m .43457 .90502 L .43546 .90521 L F
.4351 .90514 m .43509 .90604 L .4351 .90514 L .83 .576 .556 r
F
.43287 .90412 m .43329 .90525 L .43285 .90474 L .984 .727 .46 r
F
.4333 .90456 m .43329 .90525 L .43287 .90412 L F
.43279 .83432 m .43307 .83367 L .42907 .83368 L .592 .769 .964 r
F
.43444 .83408 m .43307 .83367 L .43279 .83432 L F
.43307 .83367 m .42709 .83186 L .42907 .83368 L F
.43648 .90174 m .43676 .90171 L .43648 .90171 L .657 .814 .959 r
F
.4365 .90342 m .43676 .90171 L .43648 .90174 L F
.43676 .90171 m .43558 .90255 L .43675 .90249 L .667 .437 .562 r
F
.43561 .90186 m .43558 .90255 L .43676 .90171 L F
.43689 .89898 m .43675 .90249 L .43689 .89898 L .733 .492 .564 r
F
.43648 .90171 m .43769 .90137 L .43648 .90139 L .657 .814 .959 r
F
.4375 .9017 m .43769 .90137 L .43648 .90171 L F
.43689 .89898 m .43678 .90171 L .438 .89898 L .733 .492 .564 r
F
.43678 .90171 m .43675 .90249 L .43702 .9017 L F
.43702 .9017 m .43675 .90249 L .43793 .9017 L F
.4365 .90342 m .44009 .90226 L .43936 .90197 L .657 .814 .959 r
F
.44052 .90266 m .44118 .90308 L .44102 .90256 L F
.4365 .90342 m .44087 .9031 L .44052 .90266 L F
.44087 .9031 m .44118 .90308 L .44052 .90266 L F
.44036 .89964 m .44033 .89961 L .44027 .90233 L .993 .743 .421 r
F
.44036 .89964 m .44027 .90233 L .44027 .90234 L F
.44033 .89961 m .43941 .90199 L .44027 .90233 L .889 .63 .539 r
F
.44086 .90031 m .44086 .90028 L .44079 .903 L 0 0 .082 r
F
.44086 .90031 m .44079 .903 L .44079 .90301 L F
.44079 .90301 m .44079 .90301 L .44086 .90031 L F
.44086 .90028 m .44028 .90234 L .44079 .903 L .993 .743 .421 r
F
.44036 .89964 m .44027 .90234 L .44036 .89964 L F
.4365 .90342 m .44091 .90259 L .44009 .90226 L .657 .814 .959 r
F
.44027 .90234 m .44024 .90347 L .44027 .90234 L .993 .743 .421 r
F
.44027 .90234 m .44027 .90234 L .44036 .89964 L F
.44019 .90223 m .44102 .90256 L .44055 .90211 L .657 .814 .959 r
F
.44009 .90226 m .44025 .90231 L .44019 .90223 L F
.44025 .90231 m .44102 .90256 L .44019 .90223 L F
.44091 .90259 m .44102 .90256 L .44009 .90226 L F
.43923 .89916 m .43911 .90187 L .44033 .89961 L .889 .63 .539 r
F
.43911 .90187 m .43907 .90286 L .43941 .90199 L F
.43911 .90187 m .43941 .90199 L .44033 .89961 L F
.44027 .90234 m .44027 .90233 L .44024 .90347 L .993 .743 .421 r
F
.44027 .90233 m .43907 .90286 L .44024 .90347 L .889 .63 .539 r
F
.43941 .90199 m .43907 .90286 L .44027 .90233 L F
.43916 .89914 m .43822 .90174 L .4391 .90186 L .799 .548 .56 r
F
.43922 .89916 m .43916 .89914 L .4391 .90186 L .889 .63 .539 r
F
.43911 .90187 m .4391 .90186 L .43907 .90286 L F
.43922 .89916 m .4391 .90186 L .43911 .90187 L F
.4365 .90342 m .43936 .90197 L .43848 .90177 L .657 .814 .959 r
F
.43936 .90197 m .43946 .90191 L .4391 .90186 L F
.43936 .90197 m .4391 .90186 L .43848 .90177 L F
.43861 .90167 m .4398 .90174 L .43883 .90149 L F
.43848 .90177 m .43886 .90177 L .43861 .90167 L F
.43886 .90177 m .4398 .90174 L .43861 .90167 L F
.43936 .90197 m .44055 .90211 L .4398 .90174 L F
.44009 .90226 m .44055 .90211 L .43936 .90197 L F
.43922 .89916 m .43911 .90187 L .43923 .89916 L .889 .63 .539 r
F
.43911 .90187 m .43907 .90286 L .43911 .90187 L F
.43911 .90187 m .43911 .90187 L .43923 .89916 L F
.4391 .90186 m .43791 .90258 L .43907 .90286 L .799 .548 .56 r
F
.43822 .90174 m .43791 .90258 L .4391 .90186 L F
.43946 .90191 m .4398 .90174 L .43848 .90177 L .657 .814 .959 r
F
.43806 .89898 m .43791 .90258 L .43916 .89914 L .799 .548 .56 r
F
.43805 .89898 m .43791 .90258 L .43806 .89898 L F
.44069 .83406 m .43962 .83378 L .43791 .90258 L F
.43753 .90164 m .43883 .90149 L .43769 .90137 L .657 .814 .959 r
F
.43848 .90177 m .43883 .90149 L .43753 .90164 L F
.43806 .89898 m .43794 .9017 L .43806 .89898 L .799 .548 .56 r
F
.43794 .9017 m .43791 .90258 L .43795 .9017 L F
.43794 .9017 m .43795 .9017 L .43806 .89898 L F
.43806 .89898 m .43806 .89898 L .44076 .83408 L F
.43922 .89916 m .43923 .89916 L .44191 .83467 L .889 .63 .539 r
F
.44183 .83463 m .44076 .83408 L .43916 .89914 L F
.44076 .83408 m .43806 .89898 L .43916 .89914 L .799 .548 .56 r
F
.43847 .89886 m .43957 .899 L .4386 .89875 L .657 .813 .959 r
F
.43828 .89902 m .43884 .89901 L .43847 .89886 L F
.43884 .89901 m .43957 .899 L .43847 .89886 L F
.43924 .89917 m .43927 .89915 L .43916 .89914 L F
.43927 .89915 m .43957 .899 L .43828 .89902 L F
.438 .89898 m .4386 .89875 L .43733 .89888 L F
.43828 .89902 m .43833 .89897 L .438 .89898 L F
.43833 .89897 m .4386 .89875 L .438 .89898 L F
.43727 .89898 m .438 .89898 L .43733 .89888 L F
.43733 .89888 m .4386 .89875 L .43747 .89863 L F
.44069 .83406 m .4407 .83406 L .44087 .82973 L .799 .548 .56 r
F
.43955 .83377 m .43955 .83377 L .43973 .82942 L .733 .492 .564 r
F
.44188 .83025 m .44076 .83408 L .442 .83031 L .889 .63 .539 r
F
.44203 .82976 m .442 .83031 L .44201 .83032 L F
.44188 .83025 m .4502 .82871 L .44127 .82993 L .593 .769 .963 r
F
.44086 .82972 m .43973 .82942 L .43962 .83378 L .799 .548 .56 r
F
.44086 .82972 m .43962 .83378 L .44069 .83406 L F
.44188 .83025 m .44087 .82973 L .44076 .83408 L .889 .63 .539 r
F
.43972 .82942 m .43848 .83364 L .43955 .83377 L .733 .492 .564 r
F
.44253 .83102 m .44253 .83103 L .44253 .83102 L .593 .769 .963 r
F
.43951 .83375 m .44503 .8309 L .44185 .83016 L .592 .769 .964 r
F
.4395 .83377 m .43953 .83376 L .43951 .83375 L F
.43953 .83376 m .44503 .8309 L .43951 .83375 L F
.44044 .834 m .44776 .83195 L .44503 .8309 L F
.44141 .83425 m .44776 .83195 L .44044 .834 L F
.44059 .8339 m .44503 .8309 L .4395 .83377 L F
.43972 .82942 m .43859 .82929 L .43848 .83364 L .733 .492 .564 r
F
.43848 .83364 m .44185 .83016 L .43844 .82976 L .592 .769 .964 r
F
.4395 .83377 m .44185 .83016 L .43848 .83364 L F
.44127 .82993 m .4502 .82871 L .44811 .82744 L .593 .769 .963 r
F
.44141 .83425 m .44985 .83322 L .44776 .83195 L .592 .769 .964 r
F
.44257 .83456 m .44985 .83322 L .44141 .83425 L F
.44079 .90301 m .44079 .903 L .44077 .90424 L 0 0 .082 r
F
.44078 .90311 m .44086 .90339 L .44087 .9031 L .657 .814 .959 r
F
.44074 .90339 m .44086 .90339 L .44078 .90311 L F
.44086 .90339 m .4411 .90338 L .44098 .90324 L F
.44086 .90339 m .44098 .90324 L .44087 .9031 L F
.44068 .9036 m .44071 .90356 L .44074 .90339 L F
.4407 .9036 m .44103 .90361 L .44074 .90339 L F
.44087 .9031 m .4411 .90338 L .44118 .90308 L F
.44036 .89964 m .44027 .90234 L .44036 .89965 L .993 .743 .421 r
F
.44027 .90234 m .44024 .90347 L .44028 .90234 L F
.44027 .90234 m .44028 .90234 L .44036 .89965 L F
.44079 .90301 m .44077 .90424 L .44077 .90318 L 0 0 .082 r
F
.44079 .90301 m .44077 .90424 L .44079 .90301 L F
.4407 .90357 m .44068 .90484 L .4407 .90357 L .095 0 .426 r
F
.4365 .90342 m .44026 .90408 L .44028 .90407 L .657 .814 .959 r
F
.4365 .90342 m .44028 .90407 L .44068 .9036 L F
.4365 .90342 m .43956 .90451 L .44026 .90408 L F
.4365 .90342 m .43864 .90485 L .43956 .90451 L F
.4365 .90342 m .43758 .90505 L .43867 .90487 L F
.43846 .90491 m .43846 .90608 L .43846 .90491 L .651 .424 .562 r
F
.43678 .90518 m .43678 .90623 L .43678 .90518 L .747 .505 .564 r
F
.4365 .90342 m .43652 .90517 L .43758 .90505 L .657 .814 .959 r
F
.43652 .90517 m .4368 .90518 L .43758 .90505 L F
.4365 .90342 m .43532 .90546 L .43653 .90544 L F
.43678 .90518 m .43678 .90623 L .43512 .90514 L .747 .505 .564 r
F
.43758 .90505 m .43721 .90519 L .43768 .9052 L .657 .814 .959 r
F
.4368 .90518 m .43846 .90608 L .43678 .90623 L .651 .424 .562 r
F
.43798 .90499 m .43846 .90608 L .4368 .90518 L F
.44036 .89965 m .44028 .90234 L .44086 .90028 L .993 .743 .421 r
F
.44077 .90318 m .44077 .90424 L .44071 .90356 L 0 0 .082 r
F
.44055 .90464 m .44062 .90415 L .44057 .90413 L .657 .814 .959 r
F
.44215 .90472 m .44462 .90485 L .44186 .90436 L F
.44215 .90472 m .44186 .90436 L .44057 .90413 L F
.44079 .903 m .44024 .90347 L .44077 .90424 L .993 .743 .421 r
F
.44028 .90234 m .44024 .90347 L .44079 .903 L F
.44028 .90407 m .44068 .90484 L .44025 .90534 L .095 0 .426 r
F
.44057 .90372 m .44068 .90484 L .44028 .90407 L F
.43975 .82943 m .44064 .8296 L .43989 .82921 L .593 .769 .963 r
F
.44057 .82965 m .44064 .8296 L .43975 .82943 L F
.43989 .82921 m .44307 .82758 L .4422 .82564 L F
.44307 .82758 m .44538 .82639 L .44334 .82591 L F
.44307 .82758 m .44334 .82591 L .4422 .82564 L F
.44064 .8296 m .44538 .82639 L .43989 .82921 L F
.44305 .83527 m .45162 .83609 L .45134 .83519 L .592 .769 .964 r
F
.44373 .83562 m .45162 .83609 L .44305 .83527 L F
.44808 .8348 m .45134 .83519 L .45117 .83464 L F
.43747 .82881 m .43745 .82929 L .43746 .82929 L .585 .37 .555 r
F
.43701 .82936 m .43786 .8292 L .43662 .82905 L .593 .769 .963 r
F
.43788 .82923 m .43786 .8292 L .43701 .82936 L F
.43786 .8292 m .43539 .82524 L .43662 .82905 L F
.43701 .82936 m .43686 .82924 L .43632 .82946 L F
.43633 .82907 m .43623 .8295 L .43632 .82946 L .428 .243 .527 r
F
.43686 .82924 m .43223 .8256 L .43618 .82952 L .593 .769 .963 r
F
.43359 .83621 m .43166 .83567 L .42766 .8373 L .592 .769 .964 r
F
.4341 .83554 m .43166 .83567 L .43359 .83621 L F
.43166 .83567 m .42587 .83597 L .42766 .8373 L F
.43359 .83621 m .42721 .83738 L .43264 .83743 L F
.44344 .8368 m .44444 .83814 L .44346 .8368 L F
.44444 .83814 m .44779 .83974 L .44346 .8368 L F
.81081 .60829 m .81003 .60202 L .82757 .5955 L .547 .369 .591 r
F
0 g
.79944 .60435 m
.81003 .60202 L
s
.53886 .49291 m .52337 .49571 L .52292 .5036 L .362 .186 .503 r
F
0 g
.51325 .50843 m
.52337 .49571 L
s
.42327 .73713 m .40654 .73398 L .40285 .73832 L .657 .808 .956 r
F
.42628 .73518 m .40654 .73398 L .42327 .73713 L F
.80008 .59104 m .80988 .60186 L .82734 .59537 L .654 .782 .942 r
F
.78709 .59392 m .80988 .60186 L .80008 .59104 L F
.37648 .51079 m .4095 .5078 L .37735 .50611 L .641 .739 .92 r
F
.44257 .63344 m .42244 .62891 L .42259 .63522 L .675 .459 .584 r
F
0 g
.40409 .63942 m
.42259 .63522 L
s
.44257 .63344 m .44238 .62713 L .42244 .62891 L .675 .459 .584 r
F
0 g
.40396 .63312 m
.42244 .62891 L
s
.77508 .60787 m .77197 .62062 L .79211 .61884 L .653 .784 .944 r
F
.76195 .60732 m .77197 .62062 L .77508 .60787 L F
.76195 .60732 m .75245 .61982 L .77197 .62062 L F
.68987 .51238 m .68993 .50447 L .67625 .49219 L .936 .671 .51 r
F
0 g
.68993 .50447 m
.69749 .51813 L
s
.40336 .74873 m .38458 .74777 L .38296 .75444 L .656 .809 .957 r
F
0 g
.38296 .75444 m
.38526 .76078 L
s
.45688 .74012 m .46755 .73163 L .45383 .73857 L .656 .808 .956 r
F
.45688 .74012 m .47361 .73478 L .46755 .73163 L F
.45335 .7334 m .45905 .72427 L .4494 .73231 L .657 .808 .956 r
F
.45335 .7334 m .46698 .72649 L .45905 .72427 L F
.2503 .48507 m .2499 .49146 L .24882 .49935 L .739 .676 .127 r
F
.2503 .48507 m .25139 .47716 L .2499 .49146 L F
.28313 .48365 m .2499 .49146 L .28195 .49315 L .642 .738 .919 r
F
.28313 .48365 m .25139 .47716 L .2499 .49146 L F
0 g
.2499 .49146 m
.25272 .49955 L
s
.28779 .60604 m .30459 .60548 L .30455 .61175 L .843 .598 .568 r
F
.28779 .60604 m .28785 .59974 L .30459 .60548 L F
0 g
.30459 .60548 m
.31004 .60644 L
s
.31637 .60664 m .32357 .62139 L .32916 .60891 L .654 .782 .942 r
F
.31637 .60664 m .30452 .61805 L .32357 .62139 L F
0 g
.32357 .62139 m
.34366 .62219 L
s
.38186 .60987 m .39751 .5971 L .39762 .60338 L .52 .335 .571 r
F
.38195 .61615 m .38186 .60987 L .39762 .60338 L F
.36836 .59906 m .38186 .60987 L .39762 .60338 L .655 .781 .941 r
F
.356 .60194 m .38186 .60987 L .36836 .59906 L F
0 g
.3702 .61257 m
.38186 .60987 L
s
.3147 .4901 m .28195 .49315 L .31401 .49484 L .642 .738 .919 r
F
.3147 .4901 m .28313 .48365 L .28195 .49315 L F
.52769 .60877 m .52939 .61233 L .52972 .61862 L .848 .641 .1 r
F
.52769 .60877 m .52736 .60245 L .52939 .61233 L F
0 g
.52939 .61233 m
.53385 .61798 L
s
.30539 .59002 m .30476 .6053 L .31652 .59389 L .656 .781 .94 r
F
.30539 .59002 m .28811 .5996 L .30476 .6053 L F
.46253 .63422 m .44238 .62713 L .44257 .63344 L .732 .504 .582 r
F
0 g
.42244 .62891 m
.44238 .62713 L
s
.44238 .62713 m
.46231 .62792 L
s
.46253 .63422 m
.48102 .6375 L
s
.55345 .60182 m .52977 .61227 L .55467 .60839 L .654 .782 .942 r
F
.55345 .60182 m .52775 .60244 L .52977 .61227 L F
.79211 .61884 m .81081 .60829 L .8116 .61458 L .616 .418 .591 r
F
.78863 .60666 m .79211 .61884 L .8116 .61458 L .653 .784 .944 r
F
.77508 .60787 m .79211 .61884 L .78863 .60666 L F
0 g
.77197 .62062 m
.79211 .61884 L
s
.40654 .73398 m .38422 .73734 L .40285 .73832 L .657 .808 .956 r
F
.37814 .49821 m .40776 .4902 L .37682 .49337 L .642 .738 .919 r
F
.37814 .49821 m .4102 .4999 L .40776 .4902 L F
.4102 .4999 m .43888 .48701 L .40776 .4902 L F
.4102 .4999 m .44227 .50158 L .43888 .48701 L F
.67875 .62125 m .68252 .60499 L .6831 .6113 L 0 0 .427 r
F
.65454 .61858 m .67875 .62125 L .6831 .6113 L .653 .784 .944 r
F
0 g
.66955 .63052 m
.67875 .62125 L
s
.44227 .50158 m .43953 .47911 L .43888 .48701 L .958 .771 .322 r
F
.44164 .50949 m .44227 .50158 L .43888 .48701 L F
0 g
.44049 .50943 m
.44123 .50617 L
s
.42393 .74753 m .40336 .74873 L .42204 .74969 L .656 .809 .957 r
F
0 g
.44257 .63344 m
.46253 .63422 L
s
.80521 .50911 m .83956 .50612 L .80736 .50442 L .643 .738 .918 r
F
.4778 .74383 m .49091 .73462 L .47405 .73999 L .656 .809 .957 r
F
.4778 .74383 m .49645 .74041 L .49091 .73462 L F
.49598 .73521 m .48999 .72418 L .49045 .72939 L .982 .702 .404 r
F
.49645 .74041 m .49598 .73521 L .49045 .72939 L F
0 g
.49598 .73521 m
.49766 .74166 L
s
.58038 .61713 m .55979 .62701 L .58264 .62014 L .653 .784 .944 r
F
.58038 .61713 m .55517 .62104 L .55979 .62701 L F
.42355 .74231 m .40673 .73916 L .40301 .74351 L .656 .808 .956 r
F
.42659 .74035 m .40673 .73916 L .42355 .74231 L F
.3186 .47796 m .28445 .47584 L .31578 .48227 L .643 .738 .918 r
F
.56084 .50717 m .53886 .49291 L .52292 .5036 L .642 .738 .919 r
F
0 g
.52337 .49571 m
.52918 .49179 L
s
.51278 .51629 m
.52292 .5036 L
s
.57459 .50203 m .53886 .49291 L .56084 .50717 L .642 .738 .919 r
F
0 g
.44374 .75907 m
.44397 .74958 L
s
.42628 .73518 m .41255 .73004 L .40654 .73398 L .657 .808 .956 r
F
.43023 .73357 m .41255 .73004 L .42628 .73518 L F
.37745 .48551 m .40149 .473 L .37405 .48088 L .643 .738 .918 r
F
.37745 .48551 m .40816 .48234 L .40149 .473 L F
0 g
.43706 .75898 m
.43729 .75 L
s
.65163 .51195 m .65719 .49017 L .63902 .50542 L .642 .738 .919 r
F
.65163 .51195 m .67616 .50013 L .65719 .49017 L F
0 g
.67964 .48727 m
.6797 .48711 L
s
.71943 .60445 m .73345 .60389 L .73411 .61017 L .86 .596 .538 r
F
.71943 .60445 m .71879 .59814 L .73345 .60389 L F
0 g
.73345 .60389 m
.74065 .60527 L
s
.75009 .60504 m .75245 .61982 L .76195 .60732 L .653 .784 .944 r
F
.75009 .60504 m .73478 .61647 L .75245 .61982 L F
0 g
.75245 .61982 m
.77197 .62062 L
s
.81081 .60829 m .82757 .5955 L .82839 .60178 L .547 .369 .591 r
F
.8116 .61458 m .81081 .60829 L .82839 .60178 L F
.80095 .59745 m .81081 .60829 L .82839 .60178 L .653 .783 .943 r
F
.78788 .60034 m .81081 .60829 L .80095 .59745 L F
0 g
.80014 .61063 m
.81081 .60829 L
s
.45729 .74533 m .46798 .73685 L .45425 .74378 L .656 .809 .957 r
F
.45729 .74533 m .47405 .73999 L .46798 .73685 L F
.73913 .5884 m .73368 .60372 L .74886 .59228 L .654 .782 .942 r
F
.73913 .5884 m .71909 .598 L .73368 .60372 L F
.80715 .49652 m .83939 .4885 L .80712 .49167 L .644 .737 .917 r
F
.80715 .49652 m .83927 .49821 L .83939 .4885 L F
0 g
.42259 .63522 m
.44257 .63344 L
s
.87139 .4999 m .8715 .47739 L .87186 .4853 L 0 0 .109 r
F
.83927 .49821 m .87186 .4853 L .83939 .4885 L .644 .737 .917 r
F
.83927 .49821 m .87139 .4999 L .87186 .4853 L F
.87175 .50781 m .87139 .4999 L .87186 .4853 L 0 0 .109 r
F
0 g
.86755 .50759 m
.87139 .4999 L
s
.4494 .73231 m .44976 .72316 L .44477 .73177 L .657 .808 .956 r
F
.4494 .73231 m .45905 .72427 L .44976 .72316 L F
.45383 .73857 m .45957 .72942 L .44985 .73748 L .656 .808 .956 r
F
.45383 .73857 m .46755 .73163 L .45957 .72942 L F
0 g
.44224 .82113 m
.44374 .75907 L
s
.43543 .8208 m
.43706 .75898 L
s
.40673 .73916 m .38426 .74254 L .40301 .74351 L .656 .808 .956 r
F
.47301 .72963 m .48073 .7195 L .46698 .72649 L .657 .808 .956 r
F
.47301 .72963 m .48974 .72427 L .48073 .7195 L F
.654 .61228 m .68252 .60499 L .65678 .60561 L .654 .783 .943 r
F
.28773 .61236 m .30455 .61175 L .30452 .61805 L .843 .598 .568 r
F
.28773 .61236 m .28779 .60604 L .30455 .61175 L F
.30518 .59644 m .30455 .61175 L .31639 .60031 L .655 .781 .941 r
F
.30518 .59644 m .28779 .60604 L .30455 .61175 L F
0 g
.30455 .61175 m
.31005 .61272 L
s
.38195 .61615 m .39762 .60338 L .39774 .60968 L .52 .335 .571 r
F
.36843 .60538 m .38195 .61615 L .39774 .60968 L .654 .782 .942 r
F
.35605 .60826 m .38195 .61615 L .36843 .60538 L F
0 g
.36354 .62041 m
.38195 .61615 L
s
.74899 .47625 m .71487 .47412 L .74497 .48056 L .644 .736 .916 r
F
.52802 .61511 m .52972 .61862 L .53005 .62493 L .848 .641 .1 r
F
.52802 .61511 m .52769 .60877 L .52972 .61862 L F
.55357 .60814 m .52972 .61862 L .55479 .61472 L .654 .783 .943 r
F
.55357 .60814 m .52769 .60877 L .52972 .61862 L F
0 g
.52972 .61862 m
.53422 .62429 L
s
.49645 .74041 m .49045 .72939 L .49091 .73462 L .982 .702 .404 r
F
0 g
.49645 .74041 m
.49813 .74684 L
s
.80674 .48381 m .8345 .47127 L .80452 .47916 L .644 .736 .916 r
F
.80674 .48381 m .83878 .48063 L .8345 .47127 L F
.43023 .73357 m .42047 .72679 L .41255 .73004 L .657 .808 .956 r
F
.43484 .73242 m .42047 .72679 L .43023 .73357 L F
.68987 .51238 m .67625 .49219 L .67616 .50013 L .936 .671 .51 r
F
0 g
.67962 .49522 m
.68993 .50447 L
s
.67829 .49403 m
.67962 .49522 L
s
.68987 .51238 m
.69745 .526 L
s
.67821 .50196 m
.68987 .51238 L
s
.42393 .74753 m .40708 .74439 L .40336 .74873 L .656 .809 .957 r
F
.42696 .74557 m .40708 .74439 L .42393 .74753 L F
.57913 .60119 m .55467 .60839 L .57968 .60448 L .654 .782 .942 r
F
.57913 .60119 m .55345 .60182 L .55467 .60839 L F
.44477 .73177 m .43976 .72322 L .43981 .7318 L .657 .808 .956 r
F
.44477 .73177 m .44976 .72316 L .43976 .72322 L F
.42659 .74035 m .41277 .73521 L .40673 .73916 L .656 .808 .956 r
F
.43056 .73874 m .41277 .73521 L .42659 .74035 L F
.63919 .49751 m .63447 .47531 L .62409 .49299 L .643 .738 .918 r
F
.63919 .49751 m .65732 .48221 L .63447 .47531 L F
.28213 .49156 m .24882 .49935 L .28095 .50104 L .641 .739 .92 r
F
.28213 .49156 m .2503 .48507 L .24882 .49935 L F
0 g
.24882 .49935 m
.25387 .51371 L
s
.31376 .49801 m .28095 .50104 L .31308 .50273 L .641 .739 .92 r
F
.31376 .49801 m .28213 .49156 L .28095 .50104 L F
.43484 .73242 m .42976 .72446 L .42047 .72679 L .657 .808 .956 r
F
.43981 .7318 m .42976 .72446 L .43484 .73242 L F
.43981 .7318 m .43976 .72322 L .42976 .72446 L F
.37735 .50611 m .40704 .49813 L .37603 .50128 L .641 .739 .92 r
F
.37735 .50611 m .4095 .5078 L .40704 .49813 L F
.4095 .5078 m .43824 .49496 L .40704 .49813 L F
.4095 .5078 m .44164 .50949 L .43824 .49496 L F
.44985 .73748 m .45022 .7283 L .4452 .73693 L .656 .808 .956 r
F
.44985 .73748 m .45957 .72942 L .45022 .7283 L F
.45425 .74378 m .45999 .73465 L .45026 .74269 L .656 .809 .957 r
F
.45425 .74378 m .46798 .73685 L .45999 .73465 L F
.40654 .73398 m .38968 .7308 L .38422 .73734 L .657 .808 .956 r
F
.39762 .60338 m .39751 .5971 L .40958 .58874 L .383 .229 .546 r
F
0 g
.38635 .60171 m
.39751 .5971 L
s
.44164 .50949 m .43888 .48701 L .43824 .49496 L .958 .771 .322 r
F
0 g
.43847 .52342 m
.44164 .50949 L
s
.72007 .61077 m .73411 .61017 L .73478 .61647 L .86 .596 .538 r
F
.72007 .61077 m .71943 .60445 L .73411 .61017 L F
.7396 .59483 m .73411 .61017 L .7494 .59871 L .653 .783 .943 r
F
.7396 .59483 m .71943 .60445 L .73411 .61017 L F
0 g
.73411 .61017 m
.74137 .61155 L
s
.8116 .61458 m .82839 .60178 L .82921 .60809 L .547 .369 .591 r
F
.80173 .60378 m .8116 .61458 L .82921 .60809 L .653 .784 .944 r
F
.78863 .60666 m .8116 .61458 L .80173 .60378 L F
0 g
.79211 .61884 m
.8116 .61458 L
s
.38976 .73598 m .38393 .73733 L .38426 .74254 L .162 .08 .508 r
F
.38976 .73598 m .38943 .73075 L .38393 .73733 L F
0 g
.38231 .74404 m
.38393 .73733 L
s
.37862 .58827 m .39723 .59697 L .40924 .58865 L .656 .781 .94 r
F
.36815 .59265 m .39723 .59697 L .37862 .58827 L F
.40708 .74439 m .38458 .74777 L .40336 .74873 L .656 .809 .957 r
F
.47361 .73478 m .48139 .72463 L .46755 .73163 L .656 .808 .956 r
F
.47361 .73478 m .49045 .72939 L .48139 .72463 L F
.31754 .48579 m .28313 .48365 L .3147 .4901 L .642 .738 .919 r
F
.43056 .73874 m .42075 .73195 L .41277 .73521 L .656 .808 .956 r
F
.43521 .73758 m .42075 .73195 L .43056 .73874 L F
.37682 .49337 m .40103 .48083 L .37339 .48872 L .642 .738 .919 r
F
.37682 .49337 m .40776 .4902 L .40103 .48083 L F
.65454 .61858 m .6831 .6113 L .65732 .61193 L .653 .784 .944 r
F
.63018 .6159 m .65454 .61858 L .65732 .61193 L F
.6272 .61903 m .65454 .61858 L .63018 .6159 L F
.30515 .60279 m .30452 .61805 L .31637 .60664 L .654 .782 .942 r
F
.30515 .60279 m .28773 .61236 L .30452 .61805 L F
0 g
.30452 .61805 m
.32357 .62139 L
s
.48117 .47382 m .50488 .47281 L .5044 .48068 L .791 .544 .565 r
F
.48117 .47382 m .48171 .46594 L .50488 .47281 L F
0 g
.50488 .47281 m
.50817 .47324 L
s
.74496 .49631 m .7108 .49935 L .74299 .50104 L .643 .738 .918 r
F
.74496 .49631 m .71457 .48985 L .7108 .49935 L F
.55394 .61447 m .53005 .62493 L .55517 .62104 L .653 .784 .944 r
F
.55394 .61447 m .52802 .61511 L .53005 .62493 L F
0 g
.53005 .62493 m
.53714 .63382 L
s
.42696 .74557 m .41314 .74045 L .40708 .74439 L .656 .809 .957 r
F
.43094 .74396 m .41314 .74045 L .42696 .74557 L F
.4452 .73693 m .44016 .72837 L .4402 .73697 L .656 .808 .956 r
F
.4452 .73693 m .45022 .7283 L .44016 .72837 L F
.80736 .50442 m .83968 .49643 L .80733 .49959 L .643 .738 .918 r
F
.80736 .50442 m .83956 .50612 L .83968 .49643 L F
.49849 .4501 m .50502 .47254 L .514 .45474 L .644 .737 .916 r
F
.49849 .4501 m .48196 .46571 L .50502 .47254 L F
.41255 .73004 m .38968 .7308 L .40654 .73398 L .657 .808 .956 r
F
.3186 .47796 m .28996 .46714 L .28445 .47584 L .643 .738 .918 r
F
.32338 .47437 m .28996 .46714 L .3186 .47796 L F
.87175 .50781 m .87186 .4853 L .87223 .49325 L 0 0 .109 r
F
.83956 .50612 m .87223 .49325 L .83968 .49643 L .643 .738 .918 r
F
.83956 .50612 m .87175 .50781 L .87223 .49325 L F
0 g
.86475 .52177 m
.87175 .50781 L
s
.82839 .60178 m .82757 .5955 L .8421 .58713 L .454 .303 .586 r
F
0 g
.81595 .59982 m
.82757 .5955 L
s
.37405 .48088 m .39096 .46464 L .36876 .47675 L .643 .738 .918 r
F
.37405 .48088 m .40149 .473 L .39096 .46464 L F
.81177 .58665 m .82734 .59537 L .84179 .58704 L .654 .782 .942 r
F
.80008 .59104 m .82734 .59537 L .81177 .58665 L F
.28996 .46714 m .25294 .46937 L .28445 .47584 L .643 .738 .918 r
F
.57941 .60751 m .55479 .61472 L .57996 .61081 L .654 .783 .943 r
F
.57941 .60751 m .55357 .60814 L .55479 .61472 L F
.43521 .73758 m .4301 .72962 L .42075 .73195 L .656 .808 .956 r
F
.4402 .73697 m .4301 .72962 L .43521 .73758 L F
.4402 .73697 m .44016 .72837 L .4301 .72962 L F
.45026 .74269 m .45063 .73355 L .4456 .74215 L .656 .809 .957 r
F
.45026 .74269 m .45999 .73465 L .45063 .73355 L F
.40816 .48234 m .42925 .46503 L .40149 .473 L .643 .738 .918 r
F
.40816 .48234 m .43906 .47915 L .42925 .46503 L F
.40673 .73916 m .38976 .73598 L .38426 .74254 L .656 .808 .956 r
F
.39009 .74123 m .38426 .74254 L .38458 .74777 L .162 .08 .508 r
F
.39009 .74123 m .38976 .73598 L .38426 .74254 L F
0 g
.38263 .74923 m
.38426 .74254 L
s
.74894 .48407 m .71457 .48194 L .74489 .4884 L .644 .737 .917 r
F
.47405 .73999 m .48184 .72987 L .46798 .73685 L .656 .809 .957 r
F
.47405 .73999 m .49091 .73462 L .48184 .72987 L F
.80712 .49167 m .83508 .47911 L .80488 .48701 L .644 .737 .917 r
F
.80712 .49167 m .83939 .4885 L .83508 .47911 L F
.39762 .60338 m .40958 .58874 L .40972 .59504 L .383 .229 .546 r
F
.39774 .60968 m .39762 .60338 L .40972 .59504 L F
.3789 .59467 m .39762 .60338 L .40972 .59504 L .655 .781 .941 r
F
.36836 .59906 m .39762 .60338 L .3789 .59467 L F
0 g
.38637 .60801 m
.39762 .60338 L
s
.74028 .60118 m .73478 .61647 L .75009 .60504 L .653 .784 .944 r
F
.74028 .60118 m .72007 .61077 L .73478 .61647 L F
0 g
.73478 .61647 m
.75245 .61982 L
s
.68252 .60499 m .68194 .59869 L .68104 .58866 L 0 0 .067 r
F
0 g
.67918 .60507 m
.68194 .59869 L
s
.65599 .59932 m .68155 .5987 L .68066 .58872 L .654 .782 .942 r
F
.43094 .74396 m .42112 .7372 L .41314 .74045 L .656 .809 .957 r
F
.4356 .74281 m .42112 .7372 L .43094 .74396 L F
.67625 .49219 m .67634 .48429 L .65746 .47429 L .86 .601 .545 r
F
0 g
.67634 .48429 m
.67838 .48613 L
s
.57459 .50203 m .55956 .48504 L .53886 .49291 L .642 .738 .919 r
F
0 g
.52292 .5036 m
.53886 .49291 L
s
.59045 .49916 m .55956 .48504 L .57459 .50203 L .642 .738 .919 r
F
.74899 .47625 m .72279 .4654 L .71487 .47412 L .644 .736 .916 r
F
.75481 .47264 m .72279 .4654 L .74899 .47625 L F
.62409 .49299 m .63447 .47531 L .60936 .47204 L .643 .738 .918 r
F
.80452 .47916 m .82604 .4629 L .80026 .47503 L .644 .736 .916 r
F
.80452 .47916 m .8345 .47127 L .82604 .4629 L F
.63902 .50542 m .63428 .48328 L .62388 .50091 L .642 .738 .919 r
F
.63902 .50542 m .65719 .49017 L .63428 .48328 L F
.49045 .72939 m .48999 .72418 L .48094 .7194 L .917 .647 .513 r
F
0 g
.48999 .72418 m
.49552 .73002 L
s
.46698 .72649 m .46882 .71614 L .45905 .72427 L .657 .808 .956 r
F
.46698 .72649 m .48073 .7195 L .46882 .71614 L F
.72279 .4654 m .6846 .46764 L .71487 .47412 L .644 .736 .916 r
F
.4456 .74215 m .44056 .73362 L .4406 .74219 L .656 .809 .957 r
F
.4456 .74215 m .45063 .73355 L .44056 .73362 L F
.41277 .73521 m .38976 .73598 L .40673 .73916 L .656 .808 .956 r
F
.83878 .48063 m .86482 .46328 L .8345 .47127 L .644 .736 .916 r
F
.83878 .48063 m .87101 .47743 L .86482 .46328 L F
.2744 .5983 m .28785 .59974 L .28779 .60604 L .906 .654 .546 r
F
.2744 .5983 m .27448 .59198 L .28785 .59974 L F
0 g
.28785 .59974 m
.29486 .60214 L
s
.65599 .59932 m .68066 .58872 L .65527 .59269 L .654 .782 .942 r
F
.6304 .59994 m .65599 .59932 L .65527 .59269 L F
.29655 .58481 m .28811 .5996 L .30539 .59002 L .656 .781 .94 r
F
.29655 .58481 m .27481 .59187 L .28811 .5996 L F
.34439 .58603 m .34377 .59662 L .35588 .59552 L F
.34455 .58347 m .35588 .59552 L .34832 .58313 L F
.34162 .58374 m .34439 .58603 L .34455 .58347 L F
.34439 .58603 m .35588 .59552 L .34455 .58347 L F
.34705 .53974 m .34709 .539 L .34529 .57085 L 0 0 0 r
F
.34162 .58374 m .34261 .59672 L .34377 .59662 L .656 .781 .94 r
F
.34162 .58374 m .34377 .59662 L .34439 .58603 L F
.33486 .58345 m .34261 .59672 L .34238 .59367 L F
.34018 .58367 m .34238 .59367 L .34162 .58374 L F
.33486 .58345 m .34238 .59367 L .34018 .58367 L F
.3393 .53888 m .33943 .53962 L .33754 .57168 L .923 .74 .252 r
F
.33486 .58345 m .32921 .59617 L .34261 .59672 L .656 .781 .94 r
F
.33484 .58985 m .34265 .60315 L .34257 .60207 L .655 .781 .941 r
F
.33991 .59006 m .34257 .60207 L .34165 .59014 L F
.33484 .58985 m .34257 .60207 L .33991 .59006 L F
.33484 .58985 m .32915 .60259 L .34265 .60315 L F
.33486 .59621 m .34268 .60946 L .34168 .59649 L .654 .782 .942 r
F
.33486 .59621 m .32916 .60891 L .34268 .60946 L F
.34064 .54079 m .3417 .54123 L .33985 .573 L .834 .575 .548 r
F
.33943 .53962 m .33989 .54025 L .33802 .57222 L .981 .727 .472 r
F
.341 .57563 m .33486 .58345 L .34162 .58374 L .656 .781 .94 r
F
.34029 .57482 m .33486 .58345 L .341 .57563 L F
.34058 .57372 m .34008 .57457 L .34087 .5739 L F
.34008 .57457 m .33486 .58345 L .34029 .57482 L F
.34008 .57457 m .34029 .57482 L .34087 .5739 L F
.34079 .57329 m .34055 .57371 L .34082 .5733 L F
.34055 .57371 m .33486 .58345 L .34058 .57372 L F
.34055 .57371 m .34058 .57372 L .34082 .5733 L F
.3393 .57345 m .33486 .58345 L .34079 .57329 L F
.34069 .57326 m .34079 .57329 L .34082 .57324 L F
.3393 .57345 m .34079 .57329 L .34069 .57326 L F
.34064 .54079 m .33929 .57282 L .33877 .57266 L .834 .575 .548 r
F
.33989 .54025 m .34064 .54079 L .33877 .57266 L .909 .647 .529 r
F
.33989 .54025 m .33877 .57266 L .33838 .57243 L F
.34064 .54079 m .33985 .573 L .33929 .57282 L .834 .575 .548 r
F
.3393 .53888 m .33747 .57135 L .3374 .57103 L .923 .74 .252 r
F
.33943 .53962 m .33777 .57194 L .33754 .57168 L .981 .727 .472 r
F
.33943 .53962 m .33802 .57222 L .33777 .57194 L F
.3393 .53888 m .33754 .57168 L .33747 .57135 L .923 .74 .252 r
F
.33975 .53794 m .3393 .53888 L .3374 .57103 L 0 0 .29 r
F
.33839 .5755 m .33309 .57913 L .33486 .58345 L .656 .781 .94 r
F
.33787 .57316 m .33456 .57638 L .33839 .5755 L F
.33456 .57638 m .32847 .58229 L .33309 .57913 L F
.33456 .57638 m .33309 .57913 L .33839 .5755 L F
.33989 .54025 m .33838 .57243 L .33802 .57222 L .909 .647 .529 r
F
.33819 .57285 m .32289 .58032 L .32847 .58229 L .656 .781 .94 r
F
.3417 .54123 m .34065 .57307 L .33985 .573 L .749 .499 .553 r
F
.34061 .5705 m .33662 .57271 L .33819 .57285 L .656 .781 .94 r
F
.33662 .57271 m .32289 .58032 L .33819 .57285 L F
.34081 .57308 m .3393 .57345 L .34082 .57324 L F
.3417 .54123 m .34152 .57315 L .34065 .57307 L .749 .499 .553 r
F
.34061 .5705 m .33951 .57297 L .34081 .57308 L .656 .781 .94 r
F
.33951 .57297 m .3393 .57345 L .34081 .57308 L F
.3417 .54123 m .34335 .54146 L .34152 .57315 L .749 .499 .553 r
F
.34087 .5739 m .34029 .57482 L .341 .57563 L .656 .781 .94 r
F
.34082 .5733 m .34058 .57372 L .34087 .5739 L F
.34082 .57324 m .34079 .57329 L .34082 .5733 L F
.34335 .54146 m .34231 .57304 L .34152 .57315 L .644 .409 .547 r
F
.34312 .57461 m .34162 .58374 L .34832 .58313 L .656 .781 .94 r
F
.34165 .59014 m .34265 .60315 L .356 .60194 L .655 .781 .941 r
F
.34165 .59014 m .356 .60194 L .34839 .58953 L F
.34168 .59649 m .34268 .60946 L .35605 .60826 L .654 .782 .942 r
F
.34168 .59649 m .35605 .60826 L .34843 .59588 L F
.34287 .58052 m .34165 .59014 L .34839 .58953 L .655 .781 .941 r
F
.34237 .5757 m .34162 .58374 L .34312 .57461 L .656 .781 .94 r
F
.34225 .5739 m .34162 .58374 L .34255 .57368 L F
.34216 .5733 m .34162 .58374 L .34229 .57325 L F
.34082 .57324 m .34162 .58374 L .34217 .57306 L F
.34209 .57925 m .34111 .58306 L .34287 .58052 L .655 .781 .941 r
F
.34111 .58306 m .34165 .59014 L .34287 .58052 L F
.34497 .54128 m .34365 .57274 L .34316 .57292 L .516 .302 .527 r
F
.34335 .54146 m .34497 .54128 L .34316 .57292 L .644 .409 .547 r
F
.34335 .54146 m .34316 .57292 L .34231 .57304 L F
.34599 .54088 m .34666 .54036 L .34487 .57206 L .335 .155 .483 r
F
.34404 .57326 m .34832 .58313 L .35319 .58198 L .656 .781 .94 r
F
.34404 .57326 m .35319 .58198 L .35093 .5788 L F
.34389 .57349 m .34832 .58313 L .34404 .57326 L F
.34666 .54036 m .34705 .53974 L .34525 .5715 L 0 0 .355 r
F
.34356 .57298 m .34832 .58313 L .34363 .57293 L .656 .781 .94 r
F
.34229 .57325 m .34832 .58313 L .34348 .5728 L F
.34832 .58313 m .35588 .59552 L .36815 .59265 L F
.34475 .58033 m .34839 .58953 L .35315 .58841 L .655 .781 .941 r
F
.34369 .57932 m .34468 .58146 L .34475 .58033 L F
.34468 .58146 m .34839 .58953 L .34475 .58033 L F
.34497 .54128 m .34599 .54088 L .34419 .57254 L .516 .302 .527 r
F
.34497 .54128 m .34419 .57254 L .34365 .57274 L F
.34599 .54088 m .34451 .57231 L .34419 .57254 L .335 .155 .483 r
F
.34724 .5736 m .3545 .58167 L .35975 .57945 L .656 .781 .94 r
F
.34061 .5705 m .35093 .5788 L .34724 .5736 L F
.35093 .5788 m .3545 .58167 L .34724 .5736 L F
.34666 .54036 m .34525 .5715 L .34505 .57179 L 0 0 .355 r
F
.34599 .54088 m .34487 .57206 L .34451 .57231 L .335 .155 .483 r
F
.34666 .54036 m .34505 .57179 L .34487 .57206 L 0 0 .355 r
F
.34709 .539 m .34653 .53805 L .34471 .57004 L .992 .745 .442 r
F
.34832 .58313 m .36815 .59265 L .3545 .58167 L .656 .781 .94 r
F
.34475 .58017 m .35315 .58841 L .35062 .58486 L .655 .781 .941 r
F
.34369 .57932 m .34475 .58033 L .34475 .58017 L F
.34475 .58033 m .35315 .58841 L .34475 .58017 L F
.34287 .58052 m .34457 .58329 L .34369 .57932 L F
.34457 .58329 m .34839 .58953 L .34468 .58146 L F
.34457 .58329 m .34468 .58146 L .34369 .57932 L F
.34061 .5705 m .35975 .57945 L .36111 .57848 L .656 .781 .94 r
F
.35087 .57321 m .36111 .57848 L .36373 .57661 L F
.34061 .5705 m .36111 .57848 L .35087 .57321 L F
.34451 .57231 m .34487 .57206 L .34453 .57811 L .335 .155 .483 r
F
.3545 .58167 m .36815 .59265 L .37862 .58827 L .656 .781 .94 r
F
.34705 .57985 m .35461 .58806 L .3599 .58583 L .655 .781 .941 r
F
.34404 .57845 m .34975 .58364 L .34705 .57985 L F
.34975 .58364 m .35461 .58806 L .34705 .57985 L F
.34451 .57231 m .34453 .57811 L .34423 .57832 L .335 .155 .483 r
F
.34705 .53974 m .34529 .57085 L .34527 .57119 L 0 0 0 r
F
.34705 .53974 m .34527 .57119 L .34525 .5715 L F
.34699 .57121 m .36373 .57661 L .36615 .57335 L .656 .781 .94 r
F
.34061 .5705 m .35087 .57321 L .34699 .57121 L F
.35087 .57321 m .36373 .57661 L .34699 .57121 L F
.34653 .53805 m .34535 .5373 L .34352 .56943 L .892 .63 .535 r
F
.34363 .57293 m .34389 .57349 L .34404 .57326 L .656 .781 .94 r
F
.34365 .57274 m .34419 .57254 L .34384 .57859 L .516 .302 .527 r
F
.34365 .57274 m .34384 .57859 L .3434 .57876 L F
.34316 .57292 m .34302 .57798 L .34288 .57791 L F
.34302 .57798 m .34299 .57891 L .34288 .57791 L F
.34288 .57791 m .34299 .57891 L .34282 .57898 L F
.34348 .5728 m .34356 .57298 L .34363 .57293 L .656 .781 .94 r
F
.34365 .57274 m .3434 .57876 L .34316 .57292 L .516 .302 .527 r
F
.34328 .57899 m .35062 .58486 L .34408 .5785 L .655 .781 .941 r
F
.34328 .57899 m .34408 .5785 L .34384 .57859 L F
.3434 .57876 m .34299 .57891 L .34316 .57292 L .516 .302 .527 r
F
.3432 .57892 m .34287 .58052 L .34369 .57932 L .655 .781 .941 r
F
.34061 .5705 m .34229 .57325 L .34348 .5728 L .656 .781 .94 r
F
.34255 .57368 m .34237 .5757 L .34312 .57461 L F
.34229 .57325 m .34225 .5739 L .34255 .57368 L F
.34231 .57304 m .34316 .57292 L .34282 .57898 L .644 .409 .547 r
F
.34231 .57304 m .34282 .57898 L .34211 .57907 L F
.34065 .57307 m .34152 .57315 L .34117 .5792 L .749 .499 .553 r
F
.34117 .5792 m .34085 .57971 L .34202 .57927 L .655 .781 .941 r
F
.34081 .57917 m .34082 .57925 L .34117 .5792 L F
.34082 .57925 m .34085 .57971 L .34117 .5792 L F
.34085 .57971 m .34111 .58306 L .34209 .57925 L F
.34065 .57307 m .34117 .5792 L .34045 .57913 L .749 .499 .553 r
F
.34104 .58211 m .33484 .58985 L .34165 .59014 L .655 .781 .941 r
F
.33989 .58081 m .33484 .58985 L .34104 .58211 L F
.33966 .57906 m .33964 .5791 L .34081 .57917 L F
.33952 .57936 m .33922 .58004 L .34041 .57988 L F
.34061 .5705 m .33364 .57276 L .32289 .58032 L .656 .781 .94 r
F
.33364 .57276 m .31849 .57769 L .32206 .57983 L F
.33364 .57276 m .32206 .57983 L .32289 .58032 L F
.34083 .53722 m .33975 .53794 L .33785 .5702 L .385 .194 .495 r
F
.3382 .58232 m .33484 .58985 L .33844 .58341 L .655 .781 .941 r
F
.33777 .57194 m .33746 .57804 L .33754 .57168 L .981 .727 .472 r
F
.33985 .573 m .33979 .57908 L .3395 .57905 L .749 .499 .553 r
F
.33746 .57804 m .33727 .57783 L .33754 .57168 L .981 .727 .472 r
F
.33975 .53794 m .3374 .57103 L .33763 .5706 L 0 0 .29 r
F
.33364 .57276 m .31557 .57455 L .31849 .57769 L .656 .781 .94 r
F
.34061 .5705 m .33618 .57122 L .33364 .57276 L F
.33618 .57122 m .31557 .57455 L .33364 .57276 L F
.33309 .57913 m .33115 .58277 L .33486 .58345 L F
.34061 .5705 m .33787 .57316 L .33839 .5755 L F
.33838 .57243 m .33809 .57852 L .33802 .57222 L .909 .647 .529 r
F
.32847 .58229 m .32921 .59617 L .33486 .58345 L .656 .781 .94 r
F
.33922 .58004 m .3329 .58485 L .33484 .58985 L .655 .781 .941 r
F
.33952 .57936 m .339 .5798 L .33922 .58004 L F
.339 .5798 m .3329 .58485 L .33922 .58004 L F
.33777 .57194 m .33802 .57222 L .33766 .57827 L .981 .727 .472 r
F
.33941 .5793 m .3329 .58485 L .33952 .57936 L .655 .781 .941 r
F
.33963 .57909 m .33939 .57929 L .33964 .5791 L F
.33939 .57929 m .3329 .58485 L .33941 .5793 L F
.33939 .57929 m .33941 .5793 L .33964 .5791 L F
.33838 .57243 m .33877 .57266 L .33842 .57871 L .909 .647 .529 r
F
.33929 .57282 m .33985 .573 L .3395 .57905 L .834 .575 .548 r
F
.33847 .57896 m .33345 .58382 L .33962 .57909 L .655 .781 .941 r
F
.33847 .57896 m .33962 .57909 L .3395 .57905 L F
.33345 .58382 m .3329 .58485 L .33966 .57906 L F
.33929 .57282 m .3395 .57905 L .33904 .57891 L .834 .575 .548 r
F
.33929 .57282 m .33904 .57891 L .33877 .57266 L F
.33904 .57891 m .3386 .57877 L .33877 .57266 L F
.34065 .57307 m .34045 .57913 L .33985 .573 L .749 .499 .553 r
F
.34045 .57913 m .33979 .57908 L .33985 .573 L F
.34063 .57687 m .33847 .57896 L .33966 .57906 L .655 .781 .941 r
F
.33922 .58004 m .3382 .58232 L .33989 .58081 L F
.3382 .58232 m .33844 .58341 L .33989 .58081 L F
.33922 .58004 m .33989 .58081 L .34041 .57988 L F
.33838 .57243 m .33842 .57871 L .33809 .57852 L .909 .647 .529 r
F
.33809 .57852 m .33779 .57835 L .33802 .57222 L F
.33877 .57266 m .3386 .57877 L .33842 .57871 L .834 .575 .548 r
F
.32847 .58229 m .31652 .59389 L .32921 .59617 L .656 .781 .94 r
F
.32289 .58032 m .31652 .59389 L .32847 .58229 L F
.33345 .58382 m .32279 .58672 L .32841 .58869 L .655 .781 .941 r
F
.34063 .57687 m .33571 .57959 L .33345 .58382 L F
.33309 .57913 m .32847 .58229 L .33115 .58277 L .656 .781 .94 r
F
.33571 .57959 m .32279 .58672 L .33345 .58382 L .655 .781 .941 r
F
.34107 .58862 m .33486 .59621 L .34168 .59649 L .654 .782 .942 r
F
.34091 .58645 m .34019 .58761 L .34107 .58862 L F
.34019 .58761 m .33486 .59621 L .34107 .58862 L F
.33777 .57194 m .33766 .57827 L .33746 .57804 L .981 .727 .472 r
F
.33802 .57222 m .33779 .57835 L .33766 .57827 L .909 .647 .529 r
F
.34063 .57687 m .33175 .57975 L .32279 .58672 L .655 .781 .941 r
F
.32289 .58032 m .30539 .59002 L .31652 .59389 L .656 .781 .94 r
F
.33175 .57975 m .31836 .58408 L .32153 .58596 L .655 .781 .941 r
F
.33175 .57975 m .32153 .58596 L .32279 .58672 L F
.31849 .57769 m .30539 .59002 L .32289 .58032 L .656 .781 .94 r
F
.33175 .57975 m .31543 .58093 L .31836 .58408 L .655 .781 .941 r
F
.33747 .57135 m .33754 .57168 L .33719 .57773 L .923 .74 .252 r
F
.33747 .57135 m .33719 .57773 L .33713 .57746 L F
.33754 .57168 m .33727 .57783 L .33719 .57773 L .981 .727 .472 r
F
.3374 .57103 m .33713 .57746 L .33705 .57709 L .923 .74 .252 r
F
.33747 .57135 m .33713 .57746 L .3374 .57103 L F
.34063 .57687 m .33498 .57778 L .33175 .57975 L .655 .781 .941 r
F
.33498 .57778 m .31543 .58093 L .33175 .57975 L F
.33975 .53794 m .33763 .5706 L .33785 .5702 L 0 0 .29 r
F
.32824 .5725 m .31435 .57112 L .31557 .57455 L .656 .781 .94 r
F
.34061 .5705 m .33497 .57063 L .32824 .5725 L F
.33497 .57063 m .31435 .57112 L .32824 .5725 L F
.34194 .53691 m .34083 .53722 L .33894 .56953 L .57 .346 .536 r
F
.33991 .5873 m .33486 .59621 L .34019 .58761 L .654 .782 .942 r
F
.33809 .57852 m .33842 .57871 L .33806 .58479 L .909 .647 .529 r
F
.33999 .58539 m .33958 .58568 L .34084 .58565 L .654 .782 .942 r
F
.33958 .58568 m .34052 .58623 L .34084 .58565 L F
.34052 .58623 m .33991 .5873 L .34091 .58645 L F
.33991 .5873 m .34019 .58761 L .34091 .58645 L F
.34084 .58565 m .34052 .58623 L .34091 .58645 L F
.34081 .58527 m .33974 .58531 L .34084 .58565 L F
.33964 .5791 m .33952 .57936 L .34067 .57941 L .655 .781 .941 r
F
.33952 .57936 m .34041 .57988 L .34067 .57941 L F
.33964 .5791 m .34067 .57941 L .34081 .57917 L F
.34081 .57917 m .33989 .58081 L .34104 .58211 L F
.34045 .57913 m .34025 .58522 L .33979 .57908 L .749 .499 .553 r
F
.34025 .58522 m .33973 .58518 L .33979 .57908 L F
.3398 .58518 m .33974 .58531 L .34081 .58527 L .654 .782 .942 r
F
.33958 .58568 m .33802 .58916 L .34052 .58623 L F
.33802 .58916 m .33486 .59621 L .33825 .59022 L F
.33802 .58916 m .33825 .59022 L .34052 .58623 L F
.33713 .57746 m .33719 .57773 L .33683 .58381 L .923 .74 .252 r
F
.34045 .57913 m .34117 .5792 L .34082 .58527 L .749 .499 .553 r
F
.34045 .57913 m .34082 .58527 L .34025 .58522 L F
.34117 .5792 m .34117 .58523 L .34082 .58527 L .644 .409 .547 r
F
.3434 .57876 m .34315 .5848 L .34299 .57891 L .516 .302 .527 r
F
.35062 .58486 m .34975 .58364 L .34404 .57845 L .655 .781 .941 r
F
.35093 .5788 m .35319 .58198 L .3545 .58167 L .656 .781 .94 r
F
.3545 .58167 m .37862 .58827 L .35975 .57945 L F
.34475 .57795 m .3599 .58583 L .36391 .58299 L .655 .781 .941 r
F
.34419 .57254 m .34396 .57851 L .34384 .57859 L .335 .155 .483 r
F
.34152 .57315 m .34146 .57916 L .34117 .5792 L .644 .409 .547 r
F
.34474 .5778 m .34459 .57802 L .34487 .57206 L 0 0 .355 r
F
.34487 .57206 m .34459 .57802 L .34453 .57811 L F
.34404 .57845 m .3599 .58583 L .34475 .57795 L .655 .781 .941 r
F
.34232 .58688 m .34168 .59649 L .34382 .5963 L .654 .782 .942 r
F
.34262 .58645 m .34382 .5963 L .34424 .58908 L F
.34212 .58563 m .34232 .58688 L .34262 .58645 L F
.34232 .58688 m .34382 .5963 L .34262 .58645 L F
.34451 .57231 m .34423 .57832 L .34419 .57254 L .335 .155 .483 r
F
.34384 .57859 m .34408 .5785 L .34404 .57845 L .655 .781 .941 r
F
.34423 .57832 m .34396 .57851 L .34419 .57254 L .335 .155 .483 r
F
.34063 .57687 m .34081 .57917 L .34122 .57919 L .655 .781 .941 r
F
.34199 .57909 m .34122 .57919 L .34209 .57925 L F
.34211 .57907 m .34172 .57912 L .34152 .57315 L .644 .409 .547 r
F
.34191 .58513 m .34139 .5852 L .34146 .57916 L F
.34172 .57912 m .34146 .57916 L .34152 .57315 L F
.34117 .5792 m .34202 .57927 L .34122 .57919 L .655 .781 .941 r
F
.34191 .58513 m .34146 .57916 L .34172 .57912 L .644 .409 .547 r
F
.34122 .57919 m .34202 .57927 L .34209 .57925 L .655 .781 .941 r
F
.34081 .57917 m .34117 .5792 L .34122 .57919 L F
.34063 .57687 m .34122 .57919 L .34199 .57909 L F
.34217 .57306 m .34216 .5733 L .34229 .57325 L .656 .781 .94 r
F
.34231 .57304 m .34211 .57907 L .34152 .57315 L .644 .409 .547 r
F
.34211 .57907 m .34191 .58513 L .34172 .57912 L F
.34181 .58514 m .34181 .5853 L .34189 .58527 L .654 .782 .942 r
F
.34181 .5853 m .34168 .59649 L .34189 .58527 L F
.34081 .58527 m .34168 .59649 L .34181 .58514 L F
.34191 .58513 m .34115 .60815 L .34139 .5852 L .644 .409 .547 r
F
.34284 .585 m .34212 .58563 L .34292 .58507 L .654 .782 .942 r
F
.34146 .57916 m .34139 .5852 L .34117 .5792 L .644 .409 .547 r
F
.34139 .5852 m .34117 .58523 L .34117 .5792 L F
.34247 .58505 m .34212 .58563 L .34284 .585 L .654 .782 .942 r
F
.34181 .58514 m .34189 .58527 L .34247 .58505 L F
.34189 .58527 m .34212 .58563 L .34247 .58505 L F
.34262 .58645 m .34424 .58908 L .34313 .58571 L F
.34424 .58908 m .34432 .58781 L .3432 .58561 L F
.34313 .58571 m .3432 .58561 L .34292 .58507 L F
.34424 .58908 m .3432 .58561 L .34313 .58571 L F
.34459 .57802 m .34431 .584 L .34453 .57811 L 0 0 .355 r
F
.34839 .58953 m .356 .60194 L .36836 .59906 L .655 .781 .941 r
F
.3444 .58648 m .34843 .59588 L .35306 .59479 L .654 .782 .942 r
F
.34292 .58507 m .34432 .58781 L .3444 .58648 L F
.34432 .58781 m .34843 .59588 L .3444 .58648 L F
.35975 .57945 m .37862 .58827 L .3866 .58266 L .656 .781 .94 r
F
.35975 .57945 m .3866 .58266 L .36373 .57661 L F
.34732 .57761 m .36391 .58299 L .36634 .57972 L .655 .781 .941 r
F
.34493 .57719 m .34492 .57745 L .34525 .5715 L 0 0 0 r
F
.34525 .5715 m .34492 .57745 L .34491 .57756 L F
.34505 .57179 m .34525 .5715 L .34491 .57756 L 0 0 .355 r
F
.34505 .57179 m .34491 .57756 L .34474 .5778 L F
.34505 .57179 m .34474 .5778 L .34487 .57206 L F
.34063 .57687 m .3514 .5797 L .34732 .57761 L .655 .781 .941 r
F
.3514 .5797 m .36391 .58299 L .34732 .57761 L F
.34709 .539 m .34471 .57004 L .34501 .57046 L .992 .745 .442 r
F
.34709 .539 m .34501 .57046 L .34529 .57085 L F
.3476 .57033 m .36615 .57335 L .36684 .56988 L .656 .781 .94 r
F
.34061 .5705 m .35614 .57223 L .3476 .57033 L F
.35614 .57223 m .36615 .57335 L .3476 .57033 L F
.34212 .58563 m .34262 .58645 L .34292 .58507 L .654 .782 .942 r
F
.34247 .58505 m .34218 .60776 L .34115 .60815 L .516 .302 .527 r
F
.34199 .57909 m .34287 .58052 L .3432 .57892 L .655 .781 .941 r
F
.34282 .57898 m .34268 .58497 L .34247 .58505 L .516 .302 .527 r
F
.34262 .58645 m .34313 .58571 L .34292 .58507 L .654 .782 .942 r
F
.34268 .58497 m .34218 .60776 L .34247 .58505 L .516 .302 .527 r
F
.34212 .58563 m .34205 .58727 L .34232 .58688 L .654 .782 .942 r
F
.34205 .58727 m .34168 .59649 L .34232 .58688 L F
.34447 .57788 m .34444 .57818 L .34475 .57795 L .655 .781 .941 r
F
.34063 .57687 m .34444 .57818 L .34447 .57788 L F
.34063 .57687 m .34404 .57845 L .34444 .57818 L F
.34839 .58953 m .36836 .59906 L .35461 .58806 L F
.34448 .58503 m .34936 .58963 L .34686 .58613 L .654 .782 .942 r
F
.34406 .58484 m .34447 .58521 L .34448 .58503 L F
.34447 .58521 m .34936 .58963 L .34448 .58503 L F
.36373 .57661 m .3866 .58266 L .39154 .57619 L .656 .781 .94 r
F
.36373 .57661 m .39154 .57619 L .36615 .57335 L F
.34858 .57668 m .36634 .57972 L .36704 .57625 L .655 .781 .941 r
F
.34527 .57119 m .34493 .57719 L .34525 .5715 L 0 0 0 r
F
.34527 .57119 m .34529 .57085 L .34495 .57691 L F
.34527 .57119 m .34495 .57691 L .34493 .57719 L F
.34529 .57085 m .34485 .57677 L .34495 .57691 L .992 .745 .442 r
F
.34063 .57687 m .34732 .57761 L .34564 .57675 L .655 .781 .941 r
F
.34423 .57832 m .34424 .57831 L .34418 .57938 L .335 .155 .483 r
F
.34424 .57831 m .34453 .57811 L .34418 .57938 L F
.34264 .579 m .34282 .57898 L .34247 .58505 L .644 .409 .547 r
F
.34264 .579 m .34247 .58505 L .34233 .58507 L F
.34233 .58507 m .34137 .6042 L .34115 .60815 L F
.34264 .579 m .34233 .58507 L .34233 .58507 L F
.34233 .58507 m .34137 .6042 L .34233 .58507 L F
.35062 .58486 m .35461 .58806 L .34975 .58364 L .655 .781 .941 r
F
.35062 .58486 m .35315 .58841 L .35461 .58806 L F
.35461 .58806 m .36836 .59906 L .3789 .59467 L F
.35461 .58806 m .3789 .59467 L .3599 .58583 L F
.34578 .5846 m .35996 .5922 L .36397 .58936 L .654 .782 .942 r
F
.34418 .57938 m .34418 .58419 L .34395 .58435 L .335 .155 .483 r
F
.34189 .58527 m .34188 .58579 L .34212 .58563 L .654 .782 .942 r
F
.34188 .58579 m .34168 .59649 L .34212 .58563 L F
.34211 .57907 m .34264 .579 L .34233 .58507 L .644 .409 .547 r
F
.34191 .58513 m .34233 .58507 L .34115 .60815 L F
.34211 .57907 m .34233 .58507 L .34191 .58513 L F
.37862 .58827 m .40924 .58865 L .3866 .58266 L .656 .781 .94 r
F
.3599 .58583 m .3789 .59467 L .38693 .58905 L .655 .781 .941 r
F
.3599 .58583 m .38693 .58905 L .36391 .58299 L F
.34894 .58418 m .36397 .58936 L .36641 .5861 L .654 .782 .942 r
F
.34418 .57938 m .34453 .57811 L .34418 .58419 L .335 .155 .483 r
F
.34431 .584 m .34426 .58407 L .34453 .57811 L 0 0 .355 r
F
.34453 .57811 m .34426 .58407 L .34418 .58419 L F
.34423 .57832 m .34395 .58435 L .34396 .57851 L .335 .155 .483 r
F
.34395 .58435 m .34373 .5845 L .34396 .57851 L F
.34474 .5778 m .34443 .58383 L .34459 .57802 L 0 0 .355 r
F
.34443 .58383 m .34431 .584 L .34459 .57802 L F
.34384 .57859 m .34373 .5845 L .3435 .58467 L .335 .155 .483 r
F
.34396 .57851 m .34373 .5845 L .34384 .57859 L F
.34474 .5778 m .34456 .58364 L .34443 .58383 L 0 0 .355 r
F
.34315 .5848 m .34283 .58492 L .34299 .57891 L .516 .302 .527 r
F
.34549 .58392 m .34578 .5846 L .34815 .58429 L .654 .782 .942 r
F
.34312 .57886 m .34328 .57899 L .34384 .57859 L .655 .781 .941 r
F
.3434 .57876 m .34384 .57859 L .3435 .58467 L .516 .302 .527 r
F
.3434 .57876 m .3435 .58467 L .34315 .5848 L F
.34299 .57891 m .34283 .58492 L .34282 .57898 L F
.34283 .58492 m .34268 .58497 L .34282 .57898 L F
.34066 .58327 m .34284 .585 L .34306 .58497 L .654 .782 .942 r
F
.34066 .58327 m .34181 .58514 L .34284 .585 L F
.34283 .58492 m .34218 .60776 L .34268 .58497 L .516 .302 .527 r
F
.34575 .58383 m .34815 .58429 L .34766 .58404 L .654 .782 .942 r
F
.34474 .5778 m .34491 .57756 L .34456 .58364 L 0 0 .355 r
F
.34572 .57605 m .36704 .57625 L .36594 .57279 L .655 .781 .941 r
F
.34501 .57046 m .34462 .57645 L .34529 .57085 L .992 .745 .442 r
F
.34462 .57645 m .34485 .57677 L .34529 .57085 L F
.34501 .57046 m .34437 .5761 L .34462 .57645 L F
.34653 .53805 m .34413 .56974 L .34471 .57004 L .892 .63 .535 r
F
.34509 .56977 m .36684 .56988 L .36575 .56643 L .656 .781 .94 r
F
.34061 .5705 m .3476 .57033 L .34509 .56977 L F
.3476 .57033 m .36684 .56988 L .34509 .56977 L F
.34535 .5373 m .3442 .53695 L .34235 .56917 L .802 .546 .551 r
F
.34063 .57687 m .34564 .57675 L .34462 .57623 L .655 .781 .941 r
F
.34066 .58327 m .34525 .58389 L .34516 .58376 L .654 .782 .942 r
F
.34066 .58327 m .34453 .58428 L .34532 .58399 L F
.34063 .57687 m .34199 .57909 L .3432 .57892 L .655 .781 .941 r
F
.34063 .57687 m .34312 .57886 L .34404 .57845 L F
.34061 .5705 m .34082 .57324 L .34217 .57306 L .656 .781 .94 r
F
.34535 .5373 m .34235 .56917 L .34295 .5693 L .802 .546 .551 r
F
.34535 .5373 m .34295 .5693 L .34352 .56943 L F
.34653 .53805 m .34352 .56943 L .34413 .56974 L .892 .63 .535 r
F
.3442 .53695 m .34179 .56914 L .34235 .56917 L .733 .485 .553 r
F
.342 .56915 m .35856 .56055 L .35295 .55852 L .656 .781 .94 r
F
.34061 .5705 m .34296 .5692 L .342 .56915 L F
.34296 .5692 m .35856 .56055 L .342 .56915 L F
.34066 .58327 m .34532 .58399 L .34525 .58389 L .654 .782 .942 r
F
.34066 .58327 m .34406 .58484 L .34578 .5846 L F
.34066 .58327 m .34306 .58497 L .34357 .58461 L F
.34066 .58327 m .34081 .58527 L .34181 .58514 L F
.34139 .5852 m .34115 .60815 L .34117 .58523 L .644 .409 .547 r
F
.34025 .58522 m .34082 .58527 L .33949 .60833 L .749 .499 .553 r
F
.33904 .57891 m .33878 .58501 L .3386 .57877 L .834 .575 .548 r
F
.3329 .58485 m .33063 .58909 L .33484 .58985 L .655 .781 .941 r
F
.32841 .58869 m .32915 .60259 L .33484 .58985 L F
.33921 .58651 m .33196 .59198 L .33486 .59621 L .654 .782 .942 r
F
.33894 .5862 m .33196 .59198 L .33921 .58651 L F
.33942 .58559 m .33884 .58609 L .33958 .58568 L F
.33884 .58609 m .33196 .59198 L .33894 .5862 L F
.33884 .58609 m .33894 .5862 L .33958 .58568 L F
.33727 .57783 m .33699 .584 L .33719 .57773 L .981 .727 .472 r
F
.33968 .58529 m .33937 .58556 L .33974 .58531 L .654 .782 .942 r
F
.33756 .58712 m .33196 .59198 L .33757 .58717 L F
.33876 .58509 m .3374 .5864 L .33967 .58529 L F
.3374 .5864 m .33234 .59128 L .33754 .58703 L F
.3374 .5864 m .33754 .58703 L .33967 .58529 L F
.31849 .57769 m .29655 .58481 L .30539 .59002 L .656 .781 .94 r
F
.31557 .57455 m .29655 .58481 L .31849 .57769 L F
.32462 .57945 m .3142 .5775 L .31543 .58093 L .655 .781 .941 r
F
.33763 .5706 m .3374 .57103 L .33705 .57709 L 0 0 .29 r
F
.33763 .5706 m .33705 .57709 L .33723 .57674 L F
.34083 .53722 m .33785 .5702 L .33841 .56985 L .385 .194 .495 r
F
.33497 .57063 m .31492 .56763 L .31435 .57112 L .656 .781 .94 r
F
.34061 .5705 m .33693 .57009 L .33497 .57063 L F
.33693 .57009 m .31492 .56763 L .33497 .57063 L F
.34063 .57687 m .33631 .57697 L .33498 .57778 L .655 .781 .941 r
F
.33234 .59128 m .33196 .59198 L .33968 .58529 L .654 .782 .942 r
F
.33967 .58529 m .33968 .58529 L .3398 .58518 L F
.33234 .59128 m .33968 .58529 L .33967 .58529 L F
.3386 .57877 m .33844 .58491 L .33842 .57871 L .834 .575 .548 r
F
.33937 .58556 m .33756 .58712 L .33942 .58559 L .654 .782 .942 r
F
.33756 .58712 m .33757 .58717 L .33942 .58559 L F
.33844 .58491 m .33829 .58486 L .33842 .57871 L .834 .575 .548 r
F
.33842 .57871 m .33829 .58486 L .33806 .58479 L F
.33878 .58501 m .33844 .58491 L .3386 .57877 L F
.32841 .58869 m .31639 .60031 L .32915 .60259 L .655 .781 .941 r
F
.32279 .58672 m .31639 .60031 L .32841 .58869 L F
.33234 .59128 m .32279 .59309 L .32842 .59505 L .654 .782 .942 r
F
.33809 .57852 m .33806 .58479 L .3378 .58464 L .909 .647 .529 r
F
.33904 .57891 m .3395 .57905 L .33915 .58513 L .834 .575 .548 r
F
.33904 .57891 m .33915 .58513 L .33878 .58501 L F
.33958 .58568 m .33894 .5862 L .33921 .58651 L .654 .782 .942 r
F
.33915 .58513 m .33949 .60833 L .33781 .6081 L .749 .499 .553 r
F
.3395 .57905 m .3395 .58516 L .33915 .58513 L F
.33876 .58509 m .33967 .58529 L .33915 .58513 L .654 .782 .942 r
F
.3395 .58516 m .33949 .60833 L .33915 .58513 L .749 .499 .553 r
F
.33876 .58509 m .33495 .5864 L .33234 .59128 L .654 .782 .942 r
F
.33915 .58513 m .33967 .58529 L .3398 .58518 L F
.33937 .58556 m .33942 .58559 L .33974 .58531 L F
.33974 .58531 m .33942 .58559 L .33958 .58568 L F
.3398 .58518 m .33968 .58529 L .33974 .58531 L F
.33974 .58531 m .33969 .58543 L .33999 .58539 L F
.33969 .58543 m .33958 .58568 L .33999 .58539 L F
.3395 .57905 m .33962 .57909 L .33966 .57906 L .655 .781 .941 r
F
.33964 .5791 m .33941 .5793 L .33952 .57936 L F
.33966 .57906 m .33963 .57909 L .33964 .5791 L F
.33979 .57908 m .33973 .58518 L .3395 .57905 L .749 .499 .553 r
F
.33973 .58518 m .33949 .60833 L .3395 .58516 L F
.33973 .58518 m .3395 .58516 L .3395 .57905 L F
.33746 .57804 m .33714 .58417 L .33727 .57783 L .981 .727 .472 r
F
.31557 .57455 m .29063 .57858 L .29655 .58481 L .656 .781 .94 r
F
.31435 .57112 m .29063 .57858 L .31557 .57455 L F
.33333 .57704 m .31477 .574 L .3142 .5775 L .655 .781 .941 r
F
.33763 .5706 m .33723 .57674 L .33785 .5702 L 0 0 .29 r
F
.33723 .57674 m .33741 .5764 L .33785 .5702 L F
.34063 .57687 m .33587 .57634 L .33333 .57704 L .655 .781 .941 r
F
.33587 .57634 m .31477 .574 L .33333 .57704 L F
.33779 .57835 m .33757 .5845 L .33766 .57827 L .909 .647 .529 r
F
.33757 .5845 m .33746 .58444 L .33766 .57827 L F
.33766 .57827 m .33746 .58444 L .3373 .58435 L F
.33809 .57852 m .3378 .58464 L .33779 .57835 L F
.3378 .58464 m .33757 .5845 L .33779 .57835 L F
.34066 .58327 m .33579 .58483 L .33753 .58499 L .654 .782 .942 r
F
.34066 .58327 m .33753 .58499 L .33876 .58509 L F
.33753 .58499 m .33495 .5864 L .33876 .58509 L F
.33844 .58491 m .33781 .6081 L .33829 .58486 L .834 .575 .548 r
F
.33806 .58479 m .33797 .59325 L .33695 .60382 L F
.33797 .59325 m .33781 .6081 L .33695 .60382 L F
.33695 .60382 m .33781 .6081 L .33672 .60767 L F
.33829 .58486 m .33781 .6081 L .33806 .58479 L F
.34066 .58327 m .33876 .58509 L .3398 .58518 L .654 .782 .942 r
F
.33878 .58501 m .33781 .6081 L .33844 .58491 L .834 .575 .548 r
F
.3378 .58464 m .33806 .58479 L .33672 .60767 L .909 .647 .529 r
F
.33695 .60382 m .33691 .60417 L .33692 .60417 L .57 .346 .536 r
F
.33878 .58501 m .33915 .58513 L .33781 .6081 L .834 .575 .548 r
F
.33695 .60382 m .33692 .60417 L .33804 .60387 L .57 .346 .536 r
F
.33746 .57804 m .33766 .57827 L .3373 .58435 L .981 .727 .472 r
F
.33746 .57804 m .3373 .58435 L .33714 .58417 L F
.33587 .57634 m .31711 .57068 L .31477 .574 L .655 .781 .941 r
F
.33426 .56979 m .31725 .56432 L .31492 .56763 L .656 .781 .94 r
F
.34061 .5705 m .33693 .56953 L .33426 .56979 L F
.33693 .56953 m .31725 .56432 L .33426 .56979 L F
.34307 .53683 m .34194 .53691 L .34006 .56922 L .663 .424 .548 r
F
.34083 .53722 m .33841 .56985 L .33894 .56953 L .385 .194 .495 r
F
.33693 .56953 m .32119 .56142 L .31725 .56432 L .656 .781 .94 r
F
.34061 .5705 m .33825 .5694 L .33693 .56953 L F
.33825 .5694 m .32119 .56142 L .33693 .56953 L F
.34063 .57687 m .33773 .57611 L .33712 .57648 L .655 .781 .941 r
F
.33699 .584 m .33693 .58393 L .33719 .57773 L .981 .727 .472 r
F
.33719 .57773 m .33693 .58393 L .33683 .58381 L F
.33714 .58417 m .33699 .584 L .33727 .57783 L F
.33345 .58382 m .32841 .58869 L .3329 .58485 L .655 .781 .941 r
F
.3329 .58485 m .32841 .58869 L .33063 .58909 L F
.34066 .58327 m .33378 .58437 L .32985 .58675 L .654 .782 .942 r
F
.34025 .58522 m .34024 .58574 L .33974 .58518 L .749 .499 .553 r
F
.34024 .58574 m .33949 .60833 L .33974 .58518 L F
.33974 .58518 m .33949 .60833 L .33973 .58518 L F
.34066 .58327 m .3398 .58518 L .34081 .58527 L .654 .782 .942 r
F
.34063 .57687 m .33966 .57906 L .34081 .57917 L .655 .781 .941 r
F
.34307 .53683 m .34064 .56916 L .3412 .56911 L .663 .424 .548 r
F
.34307 .53683 m .34006 .56922 L .34064 .56916 L F
.34194 .53691 m .33951 .56937 L .34006 .56922 L .57 .346 .536 r
F
.34194 .53691 m .33894 .56953 L .33951 .56937 L F
.3442 .53695 m .34307 .53683 L .3412 .56911 L .733 .485 .553 r
F
.3442 .53695 m .3412 .56911 L .34179 .56914 L F
.3405 .56907 m .34647 .55731 L .33958 .557 L .656 .781 .94 r
F
.34061 .5705 m .34123 .56911 L .3405 .56907 L F
.34123 .56911 m .34647 .55731 L .3405 .56907 L F
.34061 .5705 m .35295 .55852 L .34647 .55731 L F
.34061 .5705 m .36293 .56325 L .35856 .56055 L F
.34061 .5705 m .36575 .56643 L .36293 .56325 L F
.3866 .58266 m .40924 .58865 L .41677 .57901 L F
.3866 .58266 m .41677 .57901 L .39154 .57619 L F
.36391 .58299 m .38693 .58905 L .3919 .58256 L .655 .781 .941 r
F
.36391 .58299 m .3919 .58256 L .36634 .57972 L F
.3459 .58314 m .36641 .5861 L .36711 .58264 L .654 .782 .942 r
F
.34493 .57719 m .3446 .58299 L .34459 .58321 L 0 0 0 r
F
.34492 .57745 m .34458 .58341 L .34491 .57756 L F
.34458 .58341 m .34457 .5835 L .34491 .57756 L F
.34491 .57756 m .34457 .5835 L .34456 .58364 L F
.34493 .57719 m .34459 .58321 L .34492 .57745 L F
.34459 .58321 m .34458 .58341 L .34492 .57745 L F
.34066 .58327 m .34766 .58404 L .3459 .58314 L .654 .782 .942 r
F
.34766 .58404 m .36641 .5861 L .3459 .58314 L F
.34312 .57886 m .34384 .57859 L .34404 .57845 L .655 .781 .941 r
F
.34413 .56974 m .34368 .57575 L .34471 .57004 L .892 .63 .535 r
F
.34368 .57575 m .34416 .57599 L .34471 .57004 L F
.34471 .57004 m .34416 .57599 L .34437 .5761 L F
.34413 .56974 m .34317 .57549 L .34368 .57575 L F
.34501 .57046 m .34471 .57004 L .34437 .5761 L .992 .745 .442 r
F
.34347 .5753 m .3631 .5696 L .35871 .56689 L .655 .781 .941 r
F
.34295 .5693 m .34235 .56917 L .342 .57523 L .802 .546 .551 r
F
.34063 .57687 m .34421 .57572 L .34315 .57548 L .655 .781 .941 r
F
.34295 .5693 m .342 .57523 L .3423 .57529 L .802 .546 .551 r
F
.34063 .57687 m .34227 .57529 L .34138 .5752 L .655 .781 .941 r
F
.34227 .57529 m .34232 .57524 L .342 .57523 L F
.34227 .57529 m .342 .57523 L .34138 .5752 L F
.34295 .5693 m .3423 .57529 L .3425 .57534 L .802 .546 .551 r
F
.34295 .5693 m .3425 .57534 L .34352 .56943 L F
.3425 .57534 m .34297 .57544 L .34352 .56943 L F
.34352 .56943 m .34297 .57544 L .34317 .57549 L F
.34413 .56974 m .34352 .56943 L .34317 .57549 L .892 .63 .535 r
F
.34232 .57524 m .35871 .56689 L .35306 .56486 L .655 .781 .941 r
F
.34063 .57687 m .34347 .5753 L .34232 .57524 L F
.34347 .5753 m .35871 .56689 L .34232 .57524 L F
.34179 .56914 m .34134 .57519 L .34235 .56917 L .733 .485 .553 r
F
.34082 .58527 m .34115 .60815 L .33949 .60833 L .644 .409 .547 r
F
.34117 .58523 m .34115 .60815 L .34082 .58527 L F
.34134 .57519 m .3418 .57522 L .34235 .56917 L .733 .485 .553 r
F
.34235 .56917 m .3418 .57522 L .342 .57523 L F
.3412 .56911 m .34065 .57519 L .34085 .57517 L .663 .424 .548 r
F
.34179 .56914 m .3412 .56911 L .34085 .57517 L .733 .485 .553 r
F
.34179 .56914 m .34085 .57517 L .34134 .57519 L F
.34061 .5705 m .32648 .55914 L .32119 .56142 L .656 .781 .94 r
F
.34061 .5705 m .33276 .55763 L .32648 .55914 L F
.34061 .5705 m .33958 .557 L .33276 .55763 L F
.34064 .56916 m .34019 .57523 L .3412 .56911 L .663 .424 .548 r
F
.34019 .57523 m .34065 .57519 L .3412 .56911 L F
.31836 .58408 m .30518 .59644 L .32279 .58672 L .655 .781 .941 r
F
.31836 .58408 m .29629 .59122 L .30518 .59644 L F
.31543 .58093 m .29629 .59122 L .31836 .58408 L F
.32099 .58643 m .31418 .5839 L .31541 .58732 L .654 .782 .942 r
F
.33713 .57746 m .33678 .5836 L .33705 .57709 L .923 .74 .252 r
F
.33678 .5836 m .33672 .58331 L .33705 .57709 L F
.33713 .57746 m .33683 .58381 L .33678 .5836 L F
.34064 .56916 m .34006 .56922 L .33971 .57528 L .663 .424 .548 r
F
.33841 .56985 m .33785 .5702 L .33749 .57626 L .385 .194 .495 r
F
.33841 .56985 m .33749 .57626 L .33795 .57597 L F
.33841 .56985 m .33795 .57597 L .33894 .56953 L F
.33795 .57597 m .33839 .57571 L .33894 .56953 L F
.33785 .5702 m .33741 .5764 L .33749 .57626 L 0 0 .29 r
F
.34063 .57687 m .33765 .57548 L .33598 .57565 L .655 .781 .941 r
F
.34066 .58327 m .3354 .58339 L .33378 .58437 L .654 .782 .942 r
F
.33951 .56937 m .33894 .56953 L .33859 .57559 L .57 .346 .536 r
F
.33951 .56937 m .33859 .57559 L .33906 .57546 L F
.33894 .56953 m .33839 .57571 L .33859 .57559 L .385 .194 .495 r
F
.34063 .57687 m .32641 .56549 L .32108 .56778 L .655 .781 .941 r
F
.33951 .56937 m .33906 .57546 L .34006 .56922 L .57 .346 .536 r
F
.33906 .57546 m .33951 .57533 L .34006 .56922 L F
.34006 .56922 m .33951 .57533 L .33971 .57528 L F
.34063 .57687 m .33273 .56398 L .32641 .56549 L .655 .781 .941 r
F
.34064 .56916 m .33971 .57528 L .34019 .57523 L .663 .424 .548 r
F
.34063 .57687 m .3396 .56335 L .33273 .56398 L .655 .781 .941 r
F
.33951 .57533 m .33896 .58147 L .33971 .57528 L .57 .346 .536 r
F
.33723 .57674 m .33683 .58289 L .33741 .5764 L 0 0 .29 r
F
.33683 .58289 m .33698 .58263 L .33741 .5764 L F
.33705 .57709 m .33672 .58331 L .33669 .58317 L .923 .74 .252 r
F
.33723 .57674 m .33705 .57709 L .33669 .58317 L 0 0 .29 r
F
.33723 .57674 m .33669 .58317 L .33683 .58289 L F
.3354 .58339 m .3348 .58262 L .33168 .58348 L .654 .782 .942 r
F
.34066 .58327 m .33638 .58279 L .3354 .58339 L F
.33638 .58279 m .3348 .58262 L .3354 .58339 L F
.33753 .58499 m .33538 .5856 L .33495 .5864 L F
.32279 .58672 m .30518 .59644 L .31639 .60031 L .655 .781 .941 r
F
.33579 .58483 m .31835 .59046 L .33753 .58499 L .654 .782 .942 r
F
.33757 .5845 m .33672 .60767 L .33746 .58444 L .909 .647 .529 r
F
.33699 .584 m .33596 .60714 L .33693 .58393 L .981 .727 .472 r
F
.33683 .58381 m .33596 .60714 L .33549 .60652 L F
.33693 .58393 m .33596 .60714 L .33683 .58381 L F
.3373 .58435 m .33672 .60767 L .33596 .60714 L .909 .647 .529 r
F
.33746 .58444 m .33672 .60767 L .3373 .58435 L F
.3378 .58464 m .33672 .60767 L .33757 .5845 L F
.33714 .58417 m .33596 .60714 L .33699 .584 L .981 .727 .472 r
F
.33609 .60469 m .33611 .60468 L .33596 .60714 L F
.33714 .58417 m .33611 .60468 L .33609 .60469 L F
.33714 .58417 m .3373 .58435 L .33611 .60468 L F
.33333 .57704 m .3142 .5775 L .32462 .57945 L .655 .781 .941 r
F
.29063 .57858 m .27481 .59187 L .29655 .58481 L .656 .781 .94 r
F
.3142 .5775 m .29032 .58498 L .31543 .58093 L .655 .781 .941 r
F
.33092 .58219 m .3171 .5771 L .31475 .58041 L .654 .782 .942 r
F
.33741 .5764 m .33698 .58263 L .33749 .57626 L 0 0 .29 r
F
.33698 .58263 m .33704 .58252 L .33749 .57626 L F
.33749 .57626 m .33704 .58252 L .33713 .58234 L F
.33906 .57546 m .33859 .57559 L .33823 .58168 L .57 .346 .536 r
F
.33638 .58279 m .33645 .58217 L .3348 .58262 L .654 .782 .942 r
F
.34066 .58327 m .33713 .58234 L .33638 .58279 L F
.33713 .58234 m .33645 .58217 L .33638 .58279 L F
.33839 .57571 m .33784 .58191 L .33859 .57559 L .385 .194 .495 r
F
.33795 .57597 m .3375 .58212 L .33839 .57571 L F
.3375 .58212 m .33784 .58191 L .33839 .57571 L F
.33498 .57778 m .33333 .57704 L .32462 .57945 L .655 .781 .941 r
F
.33502 .58179 m .32108 .5742 L .3171 .5771 L .654 .782 .942 r
F
.33795 .57597 m .33749 .57626 L .33713 .58234 L .385 .194 .495 r
F
.33795 .57597 m .33713 .58234 L .3375 .58212 L F
.34066 .58327 m .33704 .58159 L .33502 .58179 L .654 .782 .942 r
F
.33704 .58159 m .32108 .5742 L .33502 .58179 L F
.33784 .58191 m .33799 .58182 L .33859 .57559 L .385 .194 .495 r
F
.33906 .57546 m .33823 .58168 L .3386 .58157 L .57 .346 .536 r
F
.33859 .57559 m .33799 .58182 L .33823 .58168 L .385 .194 .495 r
F
.33598 .57565 m .32108 .56778 L .31711 .57068 L .655 .781 .941 r
F
.33721 .57597 m .31711 .57068 L .33587 .57634 L F
.33704 .58159 m .32641 .57192 L .32108 .5742 L .654 .782 .942 r
F
.34066 .58327 m .33839 .58146 L .33704 .58159 L F
.33839 .58146 m .32641 .57192 L .33704 .58159 L F
.34063 .57687 m .36594 .57279 L .3631 .5696 L .655 .781 .941 r
F
.34065 .57519 m .34009 .58129 L .34085 .57517 L .663 .424 .548 r
F
.33896 .58147 m .33911 .58143 L .33971 .57528 L .57 .346 .536 r
F
.34019 .57523 m .33971 .57528 L .33935 .58136 L .663 .424 .548 r
F
.34019 .57523 m .33935 .58136 L .33973 .58133 L F
.33765 .57548 m .32108 .56778 L .33598 .57565 L .655 .781 .941 r
F
.33906 .57546 m .3386 .58157 L .33951 .57533 L .57 .346 .536 r
F
.3386 .58157 m .33896 .58147 L .33951 .57533 L F
.33631 .57697 m .33333 .57704 L .33498 .57778 L .655 .781 .941 r
F
.33797 .58112 m .33274 .57041 L .32641 .57192 L .654 .782 .942 r
F
.33971 .57528 m .33911 .58143 L .33935 .58136 L .57 .346 .536 r
F
.34066 .58327 m .33938 .5812 L .33797 .58112 L .654 .782 .942 r
F
.33712 .57648 m .33721 .57597 L .33587 .57634 L .655 .781 .941 r
F
.33938 .5812 m .33274 .57041 L .33797 .58112 L .654 .782 .942 r
F
.34063 .57687 m .34142 .57511 L .34051 .5752 L .655 .781 .941 r
F
.34134 .57519 m .34085 .57517 L .3405 .58125 L .733 .485 .553 r
F
.3425 .57534 m .34204 .5814 L .34297 .57544 L .802 .546 .551 r
F
.3459 .58314 m .34956 .58305 L .34955 .58305 L .654 .782 .942 r
F
.34066 .58327 m .3459 .58314 L .3459 .58314 L F
.3459 .58314 m .34956 .58305 L .3459 .58314 L F
.34416 .57599 m .3436 .58197 L .34437 .5761 L .892 .63 .535 r
F
.34485 .57677 m .3444 .58271 L .34495 .57691 L .992 .745 .442 r
F
.3444 .58271 m .34448 .58282 L .34495 .57691 L F
.34493 .57719 m .34495 .57691 L .3446 .58299 L 0 0 0 r
F
.34495 .57691 m .34448 .58282 L .3446 .58299 L .992 .745 .442 r
F
.34636 .58235 m .36711 .58263 L .3501 .58175 L .654 .782 .942 r
F
.34368 .57575 m .34317 .57549 L .34282 .58157 L .892 .63 .535 r
F
.34422 .58245 m .3444 .58271 L .34485 .57677 L .992 .745 .442 r
F
.34066 .58327 m .3459 .58314 L .34483 .5826 L .654 .782 .942 r
F
.34284 .585 m .35466 .59442 L .34406 .58484 L F
.34292 .58507 m .35306 .59479 L .35031 .59095 L F
.34357 .58461 m .34306 .58497 L .34406 .58484 L F
.34315 .5848 m .34218 .60776 L .34283 .58492 L .516 .302 .527 r
F
.34368 .57575 m .34282 .58157 L .34323 .58177 L .892 .63 .535 r
F
.34317 .57549 m .34257 .58152 L .34282 .58157 L .802 .546 .551 r
F
.3436 .58197 m .34377 .58205 L .34437 .5761 L .892 .63 .535 r
F
.3452 .57539 m .3631 .5696 L .34347 .5753 L .655 .781 .941 r
F
.34368 .57575 m .34323 .58177 L .34416 .57599 L .892 .63 .535 r
F
.34323 .58177 m .3436 .58197 L .34416 .57599 L F
.34462 .57623 m .34858 .57668 L .34572 .57605 L .655 .781 .941 r
F
.34564 .57675 m .34858 .57668 L .34462 .57623 L F
.34858 .57668 m .36704 .57625 L .34572 .57605 L F
.34437 .5761 m .34377 .58205 L .34402 .58218 L .892 .63 .535 r
F
.34564 .57675 m .35828 .57883 L .34858 .57668 L .655 .781 .941 r
F
.34732 .57761 m .35828 .57883 L .34564 .57675 L F
.35828 .57883 m .36634 .57972 L .34858 .57668 L F
.34462 .57645 m .34437 .5761 L .34402 .58218 L .992 .745 .442 r
F
.34462 .57645 m .34402 .58218 L .34422 .58245 L F
.34462 .57645 m .34422 .58245 L .34485 .57677 L F
.34264 .58136 m .35876 .57331 L .3531 .57129 L .654 .782 .942 r
F
.34297 .57544 m .34241 .58148 L .34317 .57549 L .802 .546 .551 r
F
.34066 .58327 m .34348 .58172 L .3425 .5815 L .654 .782 .942 r
F
.34241 .58148 m .34257 .58152 L .34317 .57549 L .802 .546 .551 r
F
.342 .57523 m .3414 .5813 L .34165 .58131 L .733 .485 .553 r
F
.34204 .5814 m .34241 .58148 L .34297 .57544 L .802 .546 .551 r
F
.3425 .57534 m .34165 .58131 L .34204 .5814 L F
.3423 .57529 m .34165 .58131 L .3425 .57534 L F
.34142 .57511 m .35306 .56486 L .34654 .56365 L .655 .781 .941 r
F
.34257 .575 m .35306 .56486 L .34142 .57511 L F
.3423 .57529 m .342 .57523 L .34165 .58131 L .802 .546 .551 r
F
.34315 .57548 m .3452 .57539 L .34347 .5753 L .655 .781 .941 r
F
.34421 .57572 m .3452 .57539 L .34315 .57548 L F
.34154 .58131 m .3531 .57129 L .34657 .57008 L .654 .782 .942 r
F
.34066 .58327 m .34264 .58136 L .34154 .58131 L F
.34264 .58136 m .3531 .57129 L .34154 .58131 L F
.3418 .57522 m .34124 .58129 L .342 .57523 L .733 .485 .553 r
F
.34124 .58129 m .3414 .5813 L .342 .57523 L F
.34134 .57519 m .34088 .58127 L .3418 .57522 L F
.34088 .58127 m .34124 .58129 L .3418 .57522 L F
.34134 .57519 m .3405 .58125 L .34088 .58127 L F
.34009 .58129 m .34025 .58128 L .34085 .57517 L .663 .424 .548 r
F
.34085 .57517 m .34025 .58128 L .3405 .58125 L F
.34019 .57523 m .33973 .58133 L .34065 .57519 L F
.33973 .58133 m .34009 .58129 L .34065 .57519 L F
.34051 .5752 m .34654 .56365 L .3396 .56335 L .655 .781 .941 r
F
.34142 .57511 m .34654 .56365 L .34051 .5752 L F
.34138 .5752 m .34257 .575 L .34142 .57511 L F
.34232 .57524 m .34257 .575 L .34138 .5752 L F
.34066 .58327 m .34657 .57008 L .33962 .56978 L .654 .782 .942 r
F
.34066 .58327 m .36316 .57601 L .35876 .57331 L F
.34066 .58327 m .36601 .57919 L .36316 .57601 L F
.34124 .58129 m .33919 .60379 L .3414 .5813 L .733 .485 .553 r
F
.34241 .58148 m .34035 .6039 L .34257 .58152 L .802 .546 .551 r
F
.3425 .5815 m .34399 .58143 L .34264 .58136 L .654 .782 .942 r
F
.34348 .58172 m .34399 .58143 L .3425 .5815 L F
.34399 .58143 m .35876 .57331 L .34264 .58136 L F
.34165 .58131 m .33919 .60379 L .34035 .6039 L .733 .485 .553 r
F
.3414 .5813 m .33919 .60379 L .34165 .58131 L F
.34323 .58177 m .34282 .58157 L .34153 .60424 L .892 .63 .535 r
F
.34483 .5826 m .34955 .58305 L .34636 .58235 L .654 .782 .942 r
F
.3459 .58314 m .34955 .58305 L .34483 .5826 L F
.34955 .58305 m .36711 .58263 L .34636 .58235 L F
.34233 .58507 m .34247 .58505 L .34137 .6042 L .644 .409 .547 r
F
.34282 .58157 m .34035 .6039 L .34153 .60424 L .802 .546 .551 r
F
.34257 .58152 m .34035 .6039 L .34282 .58157 L F
.34315 .5848 m .3435 .58467 L .34218 .60776 L .516 .302 .527 r
F
.3435 .58467 m .34287 .60725 L .34218 .60776 L .335 .155 .483 r
F
.34373 .5845 m .34287 .60725 L .3435 .58467 L F
.3436 .58197 m .34153 .60424 L .34377 .58205 L .892 .63 .535 r
F
.34204 .5814 m .34035 .6039 L .34241 .58148 L .802 .546 .551 r
F
.34955 .58305 m .36711 .58264 L .36711 .58263 L .654 .782 .942 r
F
.34956 .58305 m .36711 .58264 L .34955 .58305 L F
.3501 .58175 m .36711 .58263 L .36601 .57919 L F
.34088 .58127 m .33919 .60379 L .34124 .58129 L .733 .485 .553 r
F
.33773 .57611 m .33721 .57597 L .33712 .57648 L .655 .781 .941 r
F
.34066 .58327 m .33962 .56978 L .33274 .57041 L .654 .782 .942 r
F
.34088 .58127 m .3405 .58125 L .33919 .60379 L .733 .485 .553 r
F
.34009 .58129 m .33804 .60387 L .34025 .58128 L .663 .424 .548 r
F
.3405 .58125 m .33804 .60387 L .33919 .60379 L F
.34025 .58128 m .33804 .60387 L .3405 .58125 L F
.33784 .58191 m .33581 .60487 L .33799 .58182 L .385 .194 .495 r
F
.3386 .58157 m .33823 .58168 L .33691 .60417 L .57 .346 .536 r
F
.3348 .58262 m .33502 .58179 L .33092 .58219 L .654 .782 .942 r
F
.33645 .58217 m .33502 .58179 L .3348 .58262 L F
.33502 .58179 m .3171 .5771 L .33092 .58219 L F
.33973 .58133 m .33804 .60387 L .34009 .58129 L .663 .424 .548 r
F
.33823 .58168 m .33581 .60487 L .33691 .60417 L .385 .194 .495 r
F
.33799 .58182 m .33581 .60487 L .33823 .58168 L F
.33896 .58147 m .33691 .60417 L .33911 .58143 L .57 .346 .536 r
F
.33168 .58348 m .33092 .58219 L .31418 .5839 L .654 .782 .942 r
F
.3348 .58262 m .33092 .58219 L .33168 .58348 L F
.31543 .58093 m .29032 .58498 L .29629 .59122 L .655 .781 .941 r
F
.33092 .58219 m .31475 .58041 L .31419 .58383 L .654 .782 .942 r
F
.33092 .58219 m .31419 .58383 L .31418 .5839 L F
.33973 .58133 m .33935 .58136 L .33804 .60387 L .663 .424 .548 r
F
.3375 .58212 m .33581 .60487 L .33784 .58191 L .385 .194 .495 r
F
.33378 .58437 m .33168 .58348 L .32099 .58643 L .654 .782 .942 r
F
.3354 .58339 m .33168 .58348 L .33378 .58437 L F
.33168 .58348 m .31418 .5839 L .32099 .58643 L F
.3386 .58157 m .33691 .60417 L .33896 .58147 L .57 .346 .536 r
F
.34323 .58177 m .34153 .60424 L .3436 .58197 L .892 .63 .535 r
F
.3375 .58212 m .33713 .58234 L .33581 .60487 L .385 .194 .495 r
F
.32985 .58675 m .32099 .58643 L .31835 .59046 L .654 .782 .942 r
F
.33378 .58437 m .32099 .58643 L .32985 .58675 L F
.32099 .58643 m .31541 .58732 L .31589 .58783 L F
.32099 .58643 m .31589 .58783 L .31835 .59046 L F
.33935 .58136 m .33695 .60382 L .33804 .60387 L .57 .346 .536 r
F
.33911 .58143 m .33695 .60382 L .33935 .58136 L F
.33678 .5836 m .33549 .60652 L .33672 .58331 L .923 .74 .252 r
F
.33669 .58317 m .33549 .60652 L .33535 .60579 L F
.33672 .58331 m .33549 .60652 L .33669 .58317 L F
.33678 .5836 m .33683 .58381 L .33549 .60652 L F
.33698 .58263 m .33535 .60579 L .33704 .58252 L 0 0 .29 r
F
.33495 .5864 m .31835 .59046 L .32279 .59309 L .654 .782 .942 r
F
.33538 .5856 m .31835 .59046 L .33495 .5864 L F
.33495 .5864 m .32279 .59309 L .33234 .59128 L F
.33713 .58234 m .33535 .60579 L .33581 .60487 L 0 0 .29 r
F
.33704 .58252 m .33535 .60579 L .33713 .58234 L F
.33234 .59128 m .32842 .59505 L .33196 .59198 L .654 .782 .942 r
F
.33683 .58289 m .33535 .60579 L .33698 .58263 L 0 0 .29 r
F
.33196 .59198 m .32842 .59505 L .33015 .59536 L .654 .782 .942 r
F
.33196 .59198 m .33015 .59536 L .33486 .59621 L F
.33683 .58289 m .33669 .58317 L .33535 .60579 L 0 0 .29 r
F
.34204 .5814 m .34165 .58131 L .34035 .6039 L .802 .546 .551 r
F
.34406 .58484 m .35996 .5922 L .34578 .5846 L .654 .782 .942 r
F
.34395 .58435 m .34418 .58419 L .34287 .60725 L .335 .155 .483 r
F
.34431 .584 m .34326 .60664 L .34426 .58407 L 0 0 .355 r
F
.34418 .58419 m .34326 .60664 L .34287 .60725 L F
.34426 .58407 m .34326 .60664 L .34418 .58419 L F
.34395 .58435 m .34287 .60725 L .34373 .5845 L .335 .155 .483 r
F
.34443 .58383 m .34326 .60664 L .34431 .584 L 0 0 .355 r
F
.3444 .58271 m .34273 .60498 L .34448 .58282 L .992 .745 .442 r
F
.34516 .58376 m .34549 .58392 L .34575 .58383 L .654 .782 .942 r
F
.34525 .58389 m .34549 .58392 L .34516 .58376 L F
.34549 .58392 m .34815 .58429 L .34575 .58383 L F
.34424 .58908 m .34843 .59588 L .34432 .58781 L F
.34424 .58908 m .34382 .5963 L .34843 .59588 L F
.34459 .58321 m .3446 .58299 L .34331 .60591 L 0 0 0 r
F
.34458 .58341 m .34331 .60591 L .34457 .5835 L F
.34456 .58364 m .34331 .60591 L .34326 .60664 L F
.34457 .5835 m .34331 .60591 L .34456 .58364 L F
.34443 .58383 m .34456 .58364 L .34326 .60664 L 0 0 .355 r
F
.34459 .58321 m .34331 .60591 L .34458 .58341 L 0 0 0 r
F
.3446 .58299 m .34273 .60498 L .34331 .60591 L .992 .745 .442 r
F
.34448 .58282 m .34273 .60498 L .3446 .58299 L F
.34525 .58389 m .34532 .58399 L .34549 .58392 L .654 .782 .942 r
F
.34453 .58428 m .34578 .5846 L .34549 .58392 L F
.34402 .58218 m .34153 .60424 L .34273 .60498 L .892 .63 .535 r
F
.34377 .58205 m .34153 .60424 L .34402 .58218 L F
.34766 .58404 m .34815 .58429 L .34894 .58418 L .654 .782 .942 r
F
.34578 .5846 m .36397 .58936 L .34894 .58418 L F
.34422 .58245 m .34402 .58218 L .34273 .60498 L .992 .745 .442 r
F
.34686 .58613 m .35466 .59442 L .35996 .5922 L .654 .782 .942 r
F
.34936 .58963 m .35466 .59442 L .34686 .58613 L F
.34422 .58245 m .34273 .60498 L .3444 .58271 L .992 .745 .442 r
F
.35031 .59095 m .35306 .59479 L .35466 .59442 L .654 .782 .942 r
F
.4356 .74281 m .43048 .73486 L .42112 .7372 L .656 .809 .957 r
F
.4406 .74219 m .43048 .73486 L .4356 .74281 L F
.4406 .74219 m .44056 .73362 L .43048 .73486 L F
.40708 .74439 m .39009 .74123 L .38458 .74777 L F
0 g
.38296 .75444 m
.38458 .74777 L
s
.82839 .60178 m .8421 .58713 L .84294 .59343 L .454 .303 .586 r
F
.82921 .60809 m .82839 .60178 L .84294 .59343 L F
.81273 .59305 m .82839 .60178 L .84294 .59343 L .653 .783 .943 r
F
.80095 .59745 m .82839 .60178 L .81273 .59305 L F
0 g
.81667 .60612 m
.82839 .60178 L
s
.57983 .61384 m .55517 .62104 L .58038 .61713 L .653 .784 .944 r
F
.57983 .61384 m .55394 .61447 L .55517 .62104 L F
.6304 .59994 m .65527 .59269 L .62997 .59663 L .654 .782 .942 r
F
.31661 .4937 m .28213 .49156 L .31376 .49801 L .641 .739 .92 r
F
.37603 .50128 m .4003 .48878 L .37259 .49665 L F
.37603 .50128 m .40704 .49813 L .4003 .48878 L F
.48062 .48173 m .5044 .48068 L .5039 .48858 L .791 .544 .565 r
F
.48062 .48173 m .48117 .47382 L .5044 .48068 L F
.49781 .45818 m .5044 .48068 L .51344 .46284 L .643 .737 .917 r
F
.49781 .45818 m .48117 .47382 L .5044 .48068 L F
0 g
.5044 .48068 m
.52929 .48389 L
s
.70871 .59669 m .71879 .59814 L .71943 .60445 L .939 .657 .479 r
F
.70871 .59669 m .70808 .59036 L .71879 .59814 L F
0 g
.71879 .59814 m
.7264 .60113 L
s
.39774 .60968 m .40972 .59504 L .40986 .60137 L .383 .229 .546 r
F
.37899 .601 m .39774 .60968 L .40986 .60137 L .654 .782 .942 r
F
.36843 .60538 m .39774 .60968 L .37899 .601 L F
0 g
.38195 .61615 m
.39774 .60968 L
s
.31754 .48579 m .28867 .47492 L .28313 .48365 L .642 .738 .919 r
F
.32235 .48218 m .28867 .47492 L .31754 .48579 L F
.49045 .72939 m .48094 .7194 L .48139 .72463 L .917 .647 .513 r
F
.49091 .73462 m .49045 .72939 L .48139 .72463 L F
0 g
.49045 .72939 m
.49598 .73521 L
s
.32338 .47437 m .29946 .45983 L .28996 .46714 L .643 .738 .918 r
F
.32981 .47174 m .29946 .45983 L .32338 .47437 L F
.73208 .58318 m .71909 .598 L .73913 .5884 L .654 .782 .942 r
F
.73208 .58318 m .70844 .59026 L .71909 .598 L F
.46755 .73163 m .4694 .72126 L .45957 .72942 L .656 .808 .956 r
F
.46755 .73163 m .48139 .72463 L .4694 .72126 L F
.77879 .5844 m .77482 .59502 L .78709 .59392 L .654 .782 .942 r
F
.78356 .5815 m .78709 .59392 L .79337 .59253 L F
.79075 .58565 m .79337 .59253 L .80008 .59104 L F
.78356 .5815 m .79337 .59253 L .79075 .58565 L F
.78164 .53807 m .78188 .53733 L .78446 .5692 L 0 0 .362 r
F
.77936 .58287 m .78709 .59392 L .78437 .58434 L .654 .782 .942 r
F
.77879 .5844 m .78709 .59392 L .77936 .58287 L F
.77751 .58851 m .77461 .60047 L .78788 .60034 L .653 .783 .943 r
F
.77461 .60047 m .77435 .60155 L .77451 .60153 L F
.77461 .60047 m .77451 .60153 L .78788 .60034 L F
.77405 .53795 m .77435 .53858 L .77687 .57056 L .966 .687 .262 r
F
.77405 .53795 m .77687 .57056 L .77672 .57028 L F
.77678 .58211 m .77879 .5844 L .77936 .58287 L .654 .782 .942 r
F
.77678 .58211 m .78437 .58434 L .78286 .58156 L F
.77678 .58211 m .77482 .59502 L .77879 .5844 L F
.77751 .58851 m .78788 .60034 L .78523 .59105 L .653 .783 .943 r
F
.77751 .58851 m .78523 .59105 L .78355 .58797 L F
.77825 .59487 m .77508 .60787 L .78863 .60666 L .653 .784 .944 r
F
.77825 .59487 m .78863 .60666 L .78509 .59426 L F
.77592 .53956 m .7775 .5398 L .78003 .57149 L .75 .494 .544 r
F
.77496 .53912 m .77592 .53956 L .77843 .57134 L .848 .57 .516 r
F
.78141 .57392 m .77678 .58211 L .78356 .5815 L .654 .782 .942 r
F
.78093 .57223 m .7805 .57325 L .78141 .57392 L F
.7805 .57325 m .77678 .58211 L .78141 .57392 L F
.77435 .53858 m .77496 .53912 L .77747 .57101 L .941 .646 .452 r
F
.78056 .5721 m .78021 .57303 L .78093 .57223 L .654 .782 .942 r
F
.78021 .57303 m .77678 .58211 L .7805 .57325 L F
.78021 .57303 m .7805 .57325 L .78093 .57223 L F
.78072 .57161 m .78054 .57209 L .78075 .5716 L F
.78054 .57209 m .77678 .58211 L .78056 .5721 L F
.78054 .57209 m .78056 .5721 L .78075 .5716 L F
.78064 .57155 m .77678 .58211 L .78074 .57156 L F
.77931 .57159 m .77678 .58211 L .78064 .57155 L F
.78003 .57149 m .78064 .57155 L .7807 .5714 L F
.77931 .57159 m .78064 .57155 L .78003 .57149 L F
.77592 .53956 m .7792 .57142 L .77843 .57134 L .75 .494 .544 r
F
.77496 .53912 m .77843 .57134 L .77794 .57117 L .848 .57 .516 r
F
.77592 .53956 m .78003 .57149 L .7792 .57142 L .75 .494 .544 r
F
.7775 .5398 m .78084 .57139 L .78003 .57149 L .648 .416 .554 r
F
.77405 .53795 m .77672 .57028 L .77658 .57002 L .966 .687 .262 r
F
.77411 .5372 m .77405 .53795 L .77658 .57002 L 0 0 .196 r
F
.77873 .57398 m .77593 .57656 L .77678 .58211 L .654 .782 .942 r
F
.77763 .57195 m .7762 .57386 L .77873 .57398 L F
.7762 .57386 m .77021 .58182 L .77593 .57656 L F
.7762 .57386 m .77593 .57656 L .77873 .57398 L F
.77496 .53912 m .77794 .57117 L .77747 .57101 L .848 .57 .516 r
F
.77435 .53858 m .77747 .57101 L .77716 .57078 L .941 .646 .452 r
F
.7762 .57386 m .76429 .58065 L .77021 .58182 L .654 .782 .942 r
F
.77997 .56884 m .77643 .57151 L .7762 .57386 L F
.77643 .57151 m .76429 .58065 L .7762 .57386 L F
.77709 .57511 m .77722 .57639 L .77719 .57633 L .966 .687 .262 r
F
.77709 .57511 m .77719 .57633 L .77706 .57608 L F
.77435 .53858 m .77716 .57078 L .77687 .57056 L .941 .646 .452 r
F
.77215 .57473 m .75942 .57868 L .76429 .58065 L .654 .782 .942 r
F
.77997 .56884 m .77516 .57114 L .77215 .57473 L F
.77516 .57114 m .75942 .57868 L .77215 .57473 L F
.7748 .53626 m .77411 .5372 L .77664 .56937 L .159 .061 .485 r
F
.77411 .5372 m .77659 .56992 L .77661 .56969 L 0 0 .196 r
F
.77411 .5372 m .77658 .57002 L .77659 .56992 L F
.77997 .56884 m .77613 .56999 L .77516 .57114 L .654 .782 .942 r
F
.78212 .58014 m .77751 .58851 L .78433 .5879 L .653 .783 .943 r
F
.78162 .57835 m .78118 .57944 L .78212 .58014 L F
.78118 .57944 m .77751 .58851 L .78212 .58014 L F
.78009 .57782 m .77992 .57852 L .78162 .57835 L F
.77672 .57028 m .77687 .57056 L .77735 .57662 L .966 .687 .262 r
F
.77945 .58047 m .77751 .58851 L .7802 .58184 L .653 .783 .943 r
F
.77593 .57656 m .77538 .58204 L .77678 .58211 L .654 .782 .942 r
F
.77716 .57078 m .77747 .57101 L .77795 .57706 L .941 .646 .452 r
F
.77678 .58211 m .77365 .59512 L .77482 .59502 L .654 .782 .942 r
F
.77021 .58182 m .77365 .59512 L .77678 .58211 L F
.77992 .57852 m .77659 .58068 L .77751 .58851 L .653 .783 .943 r
F
.77956 .57825 m .77659 .58068 L .77992 .57852 L F
.7799 .57775 m .77659 .58068 L .78009 .57782 L F
.77906 .57741 m .77904 .57744 L .78017 .57752 L F
.77904 .57744 m .77659 .58068 L .7799 .57775 L F
.77904 .57744 m .7799 .57775 L .78017 .57752 L F
.77997 .56884 m .77763 .57195 L .77873 .57398 L .654 .782 .942 r
F
.77794 .57117 m .77843 .57134 L .77891 .5774 L .848 .57 .516 r
F
.77794 .57117 m .77891 .5774 L .7785 .57726 L F
.77794 .57117 m .7785 .57726 L .77747 .57101 L F
.7785 .57726 m .77812 .57712 L .77747 .57101 L F
.77843 .57134 m .77919 .57743 L .77891 .5774 L .75 .494 .544 r
F
.77665 .57015 m .77682 .57243 L .77658 .57002 L .966 .687 .262 r
F
.77672 .57028 m .77682 .57243 L .77665 .57015 L F
.77672 .57028 m .77722 .57639 L .77682 .57243 L F
.7748 .53626 m .77664 .56937 L .777 .56894 L .159 .061 .485 r
F
.77411 .5372 m .77661 .56969 L .77664 .56937 L 0 0 .196 r
F
.7724 .57111 m .75404 .5729 L .75592 .57604 L .654 .782 .942 r
F
.77997 .56884 m .77538 .56956 L .7724 .57111 L F
.77538 .56956 m .75404 .5729 L .7724 .57111 L F
.77906 .57741 m .77685 .57812 L .77659 .58068 L .653 .783 .943 r
F
.7792 .57142 m .77983 .57748 L .77843 .57134 L .75 .494 .544 r
F
.77983 .57748 m .77919 .57743 L .77843 .57134 L F
.78009 .57782 m .77956 .57825 L .77992 .57852 L .653 .783 .943 r
F
.78017 .57752 m .7799 .57775 L .78009 .57782 L F
.77992 .57852 m .77945 .58047 L .78118 .57944 L F
.77945 .58047 m .7802 .58184 L .78118 .57944 L F
.77992 .57852 m .78118 .57944 L .78162 .57835 L F
.7792 .57142 m .78003 .57149 L .78051 .57755 L .75 .494 .544 r
F
.78141 .57763 m .78009 .57782 L .78162 .57835 L .653 .783 .943 r
F
.78051 .57755 m .78009 .57782 L .78141 .57763 L F
.78017 .57752 m .78015 .5776 L .78051 .57755 L F
.78015 .5776 m .78009 .57782 L .78051 .57755 L F
.77983 .57748 m .78051 .57755 L .781 .58363 L .75 .494 .544 r
F
.78003 .57149 m .78081 .57751 L .78051 .57755 L .648 .416 .554 r
F
.7792 .57142 m .78051 .57755 L .77983 .57748 L .75 .494 .544 r
F
.78284 .58638 m .77825 .59487 L .78509 .59426 L .653 .784 .944 r
F
.7823 .5845 m .78185 .58565 L .78284 .58638 L F
.78185 .58565 m .77825 .59487 L .78284 .58638 L F
.78208 .58372 m .78187 .58434 L .7823 .5845 L F
.78187 .58434 m .78066 .58786 L .7823 .5845 L F
.78066 .58786 m .77825 .59487 L .78085 .58821 L F
.78066 .58786 m .78085 .58821 L .7823 .5845 L F
.77793 .57731 m .77685 .57812 L .77906 .57741 L .653 .783 .943 r
F
.78075 .5716 m .78056 .5721 L .78093 .57223 L .654 .782 .942 r
F
.78074 .57156 m .78072 .57161 L .78075 .5716 L F
.7807 .5714 m .78064 .57155 L .78074 .57156 L F
.77917 .53961 m .78226 .57109 L .78172 .57127 L .544 .339 .553 r
F
.78164 .53807 m .78446 .5692 L .78434 .56953 L 0 0 .362 r
F
.78164 .53807 m .78434 .56953 L .78422 .56985 L F
.78188 .53733 m .78156 .53637 L .78415 .56838 L .919 .662 .17 r
F
.78248 .57161 m .78356 .5815 L .78872 .58034 L .654 .782 .942 r
F
.78248 .57161 m .78872 .58034 L .7875 .57716 L F
.78433 .5879 m .78788 .60034 L .80095 .59745 L .653 .783 .943 r
F
.78356 .5815 m .80008 .59104 L .79011 .58003 L .654 .782 .942 r
F
.78509 .59426 m .78863 .60666 L .80173 .60378 L .653 .784 .944 r
F
.78433 .5879 m .80095 .59745 L .79093 .58643 L .653 .783 .943 r
F
.78509 .59426 m .80173 .60378 L .79169 .59279 L .653 .784 .944 r
F
.78029 .53921 m .78324 .57065 L .78285 .57088 L .424 .252 .542 r
F
.7775 .5398 m .77917 .53961 L .78172 .57127 L .648 .416 .554 r
F
.7775 .5398 m .78172 .57127 L .78084 .57139 L F
.7811 .53869 m .78164 .53807 L .78422 .56985 L .231 .113 .505 r
F
.78334 .57073 m .79011 .58003 L .79599 .57781 L .654 .782 .942 r
F
.78334 .57074 m .79011 .58003 L .78334 .57073 L F
.78285 .57088 m .79011 .58003 L .78333 .57072 L F
.78206 .57115 m .78217 .57127 L .78285 .57088 L F
.78217 .57127 m .79011 .58003 L .78285 .57088 L F
.78029 .53921 m .7811 .53869 L .78367 .57041 L .424 .252 .542 r
F
.78333 .57072 m .78334 .57074 L .78334 .57073 L .654 .782 .942 r
F
.77917 .53961 m .78029 .53921 L .78285 .57088 L .544 .339 .553 r
F
.77917 .53961 m .78285 .57088 L .78226 .57109 L F
.77997 .56884 m .78206 .57115 L .78333 .57072 L .654 .782 .942 r
F
.78355 .58797 m .78523 .59105 L .78433 .5879 L .653 .783 .943 r
F
.78029 .53921 m .78367 .57041 L .78324 .57065 L .424 .252 .542 r
F
.7811 .53869 m .78422 .56985 L .78393 .57014 L .231 .113 .505 r
F
.7811 .53869 m .78393 .57014 L .78367 .57041 L F
.77997 .56884 m .79599 .57781 L .79762 .57684 L .654 .782 .942 r
F
.78922 .57156 m .79762 .57684 L .80079 .57497 L F
.77997 .56884 m .79762 .57684 L .78922 .57156 L F
.78602 .56955 m .80079 .57497 L .80421 .5717 L F
.77997 .56884 m .78922 .57156 L .78602 .56955 L F
.78922 .57156 m .80079 .57497 L .78602 .56955 L F
.78156 .53637 m .78057 .53562 L .78317 .56776 L .921 .628 .471 r
F
.78188 .53733 m .78415 .56838 L .78431 .5688 L .919 .662 .17 r
F
.78188 .53733 m .78431 .5688 L .78446 .5692 L F
.7869 .56868 m .80421 .5717 L .80599 .56822 L .654 .782 .942 r
F
.77997 .56884 m .79471 .57058 L .7869 .56868 L F
.79471 .57058 m .80421 .5717 L .7869 .56868 L F
.78286 .58156 m .78437 .58434 L .78356 .5815 L F
.78373 .57852 m .78433 .5879 L .79093 .58643 L .653 .783 .943 r
F
.78225 .57184 m .78356 .5815 L .78248 .57161 L .654 .782 .942 r
F
.78213 .5713 m .78356 .5815 L .78217 .57127 L F
.7807 .5714 m .78356 .5815 L .78212 .57122 L F
.78296 .57767 m .78324 .57981 L .78373 .57852 L .653 .783 .943 r
F
.78324 .57981 m .78433 .5879 L .78373 .57852 L F
.78274 .57789 m .78433 .5879 L .78296 .57767 L F
.78151 .578 m .78433 .5879 L .78265 .57734 L F
.78324 .57065 m .78367 .57041 L .78416 .57646 L .424 .252 .542 r
F
.78434 .56953 m .78485 .57553 L .78422 .56985 L 0 0 .362 r
F
.78424 .57717 m .78752 .58196 L .78609 .57821 L .653 .783 .943 r
F
.78412 .57748 m .78752 .58196 L .78424 .57717 L F
.78333 .57694 m .78296 .57767 L .78363 .57684 L F
.78373 .57852 m .78801 .58323 L .78412 .57748 L F
.78801 .58323 m .79093 .58643 L .78752 .58196 L F
.78801 .58323 m .78752 .58196 L .78412 .57748 L F
.78422 .58461 m .78509 .59426 L .79 .59317 L .653 .784 .944 r
F
.78852 .58932 m .79 .59317 L .79169 .59279 L F
.78422 .58461 m .79 .59317 L .78852 .58932 L F
.7875 .57716 m .78872 .58034 L .79011 .58003 L .654 .782 .942 r
F
.79011 .58003 m .80008 .59104 L .81177 .58665 L F
.79011 .58003 m .81177 .58665 L .79599 .57781 L F
.78547 .57661 m .79684 .5842 L .80168 .58135 L .653 .783 .943 r
F
.78285 .57088 m .78348 .57686 L .78333 .57694 L .424 .252 .542 r
F
.78367 .57041 m .78425 .57637 L .78416 .57646 L .231 .113 .505 r
F
.78226 .57109 m .78285 .57088 L .78333 .57694 L .544 .339 .553 r
F
.78226 .57109 m .78333 .57694 L .78285 .57711 L F
.78324 .57065 m .78416 .57646 L .7838 .57667 L .424 .252 .542 r
F
.78393 .57014 m .78447 .57614 L .78367 .57041 L .231 .113 .505 r
F
.78434 .57628 m .78609 .57821 L .78547 .57661 L .653 .783 .943 r
F
.78373 .57689 m .78609 .57821 L .78439 .57633 L F
.78416 .57646 m .78439 .57633 L .78434 .57628 L F
.78373 .57689 m .78439 .57633 L .78416 .57646 L F
.78324 .57065 m .7838 .57667 L .78285 .57088 L .424 .252 .542 r
F
.7838 .57667 m .78348 .57686 L .78285 .57088 L F
.78447 .57614 m .78425 .57637 L .78367 .57041 L .231 .113 .505 r
F
.78259 .57727 m .78151 .578 L .78265 .57734 L .653 .783 .943 r
F
.78084 .57139 m .78172 .57127 L .7822 .57733 L .648 .416 .554 r
F
.78084 .57139 m .7822 .57733 L .78176 .57738 L F
.7822 .57733 m .78151 .578 L .78259 .57727 L .653 .783 .943 r
F
.78136 .57744 m .7814 .5776 L .7822 .57733 L F
.7814 .5776 m .78151 .578 L .7822 .57733 L F
.78313 .58342 m .78314 .58745 L .78422 .58461 L .653 .784 .944 r
F
.78307 .58335 m .78307 .58345 L .78313 .58342 L F
.78307 .58345 m .78314 .58745 L .78313 .58342 L F
.78314 .58745 m .78509 .59426 L .78422 .58461 L F
.78296 .57767 m .78373 .57852 L .7837 .57692 L .653 .783 .943 r
F
.78333 .57694 m .784 .58292 L .78382 .58302 L .424 .252 .542 r
F
.78172 .57127 m .7824 .57726 L .7822 .57733 L .544 .339 .553 r
F
.78147 .57742 m .78269 .5834 L .78211 .58348 L .648 .416 .554 r
F
.78084 .57139 m .78176 .57738 L .78147 .57742 L F
.78176 .57738 m .78269 .5834 L .78147 .57742 L F
.79599 .57781 m .81177 .58665 L .8214 .58103 L .654 .782 .942 r
F
.79599 .57781 m .8214 .58103 L .80079 .57497 L F
.78997 .5763 m .80168 .58135 L .80512 .57808 L .653 .783 .943 r
F
.78422 .56985 m .78475 .57579 L .78471 .57591 L 0 0 .362 r
F
.78485 .57553 m .78475 .57579 L .78422 .56985 L F
.78393 .57014 m .78422 .56985 L .78471 .57591 L .231 .113 .505 r
F
.78491 .57571 m .78547 .57661 L .78514 .57573 L .653 .783 .943 r
F
.78393 .57014 m .78471 .57591 L .78447 .57614 L .231 .113 .505 r
F
.78084 .57139 m .78147 .57742 L .78003 .57149 L .648 .416 .554 r
F
.78147 .57742 m .78081 .57751 L .78003 .57149 L F
.78217 .57127 m .78225 .57184 L .78248 .57161 L .654 .782 .942 r
F
.78212 .57122 m .78213 .5713 L .78217 .57127 L F
.78226 .57109 m .78285 .57711 L .78172 .57127 L .544 .339 .553 r
F
.78301 .58329 m .78313 .58342 L .78382 .58302 L .653 .784 .944 r
F
.78434 .57628 m .78547 .57661 L .78491 .57571 L .653 .783 .943 r
F
.78475 .57579 m .78529 .58176 L .78471 .57591 L 0 0 .362 r
F
.78422 .58461 m .78852 .58932 L .78448 .5839 L .653 .784 .944 r
F
.78285 .57711 m .7824 .57726 L .78172 .57127 L .544 .339 .553 r
F
.78072 .57522 m .78434 .57628 L .78491 .57571 L .653 .783 .943 r
F
.78434 .56953 m .78446 .5692 L .78495 .57526 L 0 0 .362 r
F
.78446 .5692 m .7849 .57511 L .78495 .57526 L .919 .662 .17 r
F
.80079 .57497 m .8214 .58103 L .8283 .57455 L .654 .782 .942 r
F
.80079 .57497 m .8283 .57455 L .80421 .5717 L F
.7886 .57503 m .80512 .57808 L .80692 .57459 L .653 .783 .943 r
F
.78434 .56953 m .78495 .57526 L .78485 .57553 L 0 0 .362 r
F
.78156 .53637 m .78368 .56808 L .78415 .56838 L .921 .628 .471 r
F
.78461 .56811 m .80599 .56822 L .806 .56477 L .654 .782 .942 r
F
.77997 .56884 m .7869 .56868 L .78461 .56811 L F
.7869 .56868 m .80599 .56822 L .78461 .56811 L F
.78057 .53562 m .77951 .53527 L .7821 .5675 L .811 .54 .528 r
F
.78072 .57522 m .78707 .57596 L .78569 .5751 L .653 .783 .943 r
F
.78313 .58342 m .78422 .58461 L .78382 .58302 L .653 .784 .944 r
F
.78072 .57522 m .78136 .57744 L .78259 .57727 L .653 .783 .943 r
F
.78254 .57721 m .78265 .57734 L .78333 .57694 L F
.78265 .57734 m .78296 .57767 L .78333 .57694 L F
.78265 .57734 m .78274 .57789 L .78296 .57767 L F
.78285 .57711 m .78344 .58315 L .7824 .57726 L .544 .339 .553 r
F
.78344 .58315 m .78569 .60612 L .78308 .58327 L F
.78344 .58315 m .78308 .58327 L .7824 .57726 L F
.78485 .57553 m .78495 .57526 L .78545 .58134 L 0 0 .362 r
F
.80421 .5717 m .8283 .57455 L .83198 .56761 L .654 .782 .942 r
F
.80421 .5717 m .83198 .56761 L .80599 .56822 L F
.78599 .57439 m .80692 .57459 L .80693 .57113 L .653 .783 .943 r
F
.78485 .57499 m .7849 .57511 L .78446 .5692 L .919 .662 .17 r
F
.78431 .5688 m .78478 .57479 L .78446 .5692 L F
.78478 .57479 m .78485 .57499 L .78446 .5692 L F
.78431 .5688 m .78464 .57444 L .78478 .57479 L F
.78072 .57522 m .78569 .5751 L .78485 .57457 L .653 .783 .943 r
F
.78497 .58263 m .78626 .58344 L .78607 .58295 L .653 .784 .944 r
F
.78529 .58176 m .78526 .58185 L .78471 .57591 L 0 0 .362 r
F
.78485 .57553 m .78537 .58156 L .78475 .57579 L F
.78415 .56838 m .78447 .57434 L .78464 .57444 L .921 .628 .471 r
F
.78431 .5688 m .78415 .56838 L .78464 .57444 L .919 .662 .17 r
F
.78461 .57406 m .80693 .57113 L .80515 .56793 L .653 .783 .943 r
F
.78156 .53637 m .78317 .56776 L .78368 .56808 L .921 .628 .471 r
F
.78407 .56761 m .806 .56477 L .80423 .56158 L .654 .782 .942 r
F
.77997 .56884 m .78686 .56776 L .78407 .56761 L F
.78686 .56776 m .806 .56477 L .78407 .56761 L F
.78072 .57522 m .78485 .57457 L .78422 .57418 L .653 .783 .943 r
F
.78373 .57852 m .78412 .57748 L .7837 .57692 L F
.7838 .57667 m .78437 .5827 L .78348 .57686 L .424 .252 .542 r
F
.78437 .5827 m .78411 .58285 L .78348 .57686 L F
.7822 .57733 m .78293 .58332 L .78269 .5834 L .544 .339 .553 r
F
.7824 .57726 m .78308 .58327 L .7822 .57733 L F
.78202 .58349 m .78314 .58745 L .78307 .58335 L .653 .784 .944 r
F
.78308 .58327 m .78569 .60612 L .78293 .58332 L .544 .339 .553 r
F
.78308 .58327 m .78293 .58332 L .7822 .57733 L F
.78202 .58349 m .78194 .58371 L .78208 .58372 L .653 .784 .944 r
F
.78194 .58371 m .78175 .5843 L .78208 .58372 L F
.77716 .57078 m .77795 .57706 L .77769 .57687 L .941 .646 .452 r
F
.77716 .57078 m .77769 .57687 L .77687 .57056 L F
.77769 .57687 m .77745 .5767 L .77687 .57056 L F
.77747 .57101 m .77812 .57712 L .77795 .57706 L .848 .57 .516 r
F
.77593 .57656 m .77021 .58182 L .77538 .58204 L .654 .782 .942 r
F
.78072 .57522 m .77501 .57794 L .777 .57801 L .653 .783 .943 r
F
.77501 .57794 m .77405 .5784 L .77469 .57831 L F
.77501 .57794 m .77469 .57831 L .777 .57801 L F
.7748 .53626 m .777 .56894 L .77735 .56854 L .159 .061 .485 r
F
.76716 .57084 m .75392 .56946 L .75404 .5729 L .654 .782 .942 r
F
.77997 .56884 m .77437 .56897 L .76716 .57084 L F
.77437 .56897 m .75392 .56946 L .76716 .57084 L F
.77726 .53524 m .77607 .53555 L .77863 .56787 L .585 .369 .554 r
F
.78141 .58533 m .77825 .59487 L .78151 .5854 L .653 .784 .944 r
F
.78072 .57522 m .77793 .57731 L .77906 .57741 L .653 .783 .943 r
F
.77607 .53555 m .7748 .53626 L .77735 .56854 L .454 .273 .545 r
F
.77607 .53555 m .77735 .56854 L .778 .56819 L F
.77437 .56897 m .75558 .56596 L .75392 .56946 L .654 .782 .942 r
F
.77997 .56884 m .77647 .56843 L .77437 .56897 L F
.77647 .56843 m .75558 .56596 L .77437 .56897 L F
.7807 .58481 m .78017 .58698 L .78141 .58533 L .653 .784 .944 r
F
.78017 .58698 m .77825 .59487 L .7806 .58776 L F
.78017 .58698 m .7806 .58776 L .78141 .58533 L F
.77672 .57028 m .77735 .57662 L .77722 .57639 L .966 .687 .262 r
F
.77687 .57056 m .77745 .5767 L .77735 .57662 L .941 .646 .452 r
F
.777 .56894 m .77664 .56937 L .77712 .57544 L .159 .061 .485 r
F
.78072 .57522 m .77616 .57658 L .77501 .57794 L .653 .783 .943 r
F
.77394 .56813 m .75892 .56265 L .75558 .56596 L .654 .782 .942 r
F
.77997 .56884 m .77665 .56786 L .77394 .56813 L F
.77665 .56786 m .75892 .56265 L .77394 .56813 L F
.7784 .53516 m .77726 .53524 L .77983 .56756 L .664 .428 .553 r
F
.77661 .56969 m .77708 .57581 L .77664 .56937 L 0 0 .196 r
F
.77708 .57581 m .77711 .57555 L .77664 .56937 L F
.77658 .57002 m .77709 .57511 L .77706 .57608 L .966 .687 .262 r
F
.77661 .56969 m .77706 .57608 L .77708 .57581 L 0 0 .196 r
F
.77659 .56992 m .77706 .57608 L .77661 .56969 L F
.77659 .56992 m .77658 .57002 L .77706 .57608 L F
.78072 .57522 m .77487 .57613 L .77106 .5781 L .653 .783 .943 r
F
.78099 .58363 m .7807 .58481 L .78194 .58371 L .653 .784 .944 r
F
.7807 .58481 m .78141 .58533 L .78194 .58371 L F
.781 .58363 m .78194 .58371 L .78202 .58349 L F
.78099 .58363 m .78194 .58371 L .781 .58363 L F
.78175 .5843 m .78141 .58533 L .78187 .58434 L F
.78141 .58533 m .78151 .5854 L .78187 .58434 L F
.78105 .57748 m .78129 .58123 L .78081 .57751 L .648 .416 .554 r
F
.78147 .57742 m .78129 .58123 L .78105 .57748 L F
.78175 .5843 m .78187 .58434 L .78208 .58372 L .653 .784 .944 r
F
.77711 .57618 m .77724 .57783 L .77706 .57608 L .966 .687 .262 r
F
.77722 .57639 m .77724 .57783 L .77711 .57618 L F
.77722 .57639 m .77773 .58252 L .77724 .57783 L F
.777 .56894 m .77712 .57544 L .77742 .57508 L .159 .061 .485 r
F
.77997 .56884 m .77931 .57159 L .7807 .5714 L .654 .782 .942 r
F
.77607 .53555 m .778 .56819 L .77863 .56787 L .454 .273 .545 r
F
.77997 .56884 m .76372 .55974 L .75892 .56265 L .654 .782 .942 r
F
.77726 .53524 m .77863 .56787 L .77925 .56771 L .585 .369 .554 r
F
.77997 .56884 m .76965 .55745 L .76372 .55974 L .654 .782 .942 r
F
.77726 .53524 m .77925 .56771 L .77983 .56756 L .585 .369 .554 r
F
.77997 .56884 m .77631 .55594 L .76965 .55745 L .654 .782 .942 r
F
.7784 .53516 m .77983 .56756 L .78043 .5675 L .664 .428 .553 r
F
.77951 .53527 m .78156 .56747 L .7821 .5675 L .734 .481 .546 r
F
.78057 .53562 m .7821 .5675 L .78265 .56764 L .811 .54 .528 r
F
.78057 .53562 m .78265 .56764 L .78317 .56776 L F
.77951 .53527 m .7784 .53516 L .78099 .56744 L .734 .481 .546 r
F
.77951 .53527 m .78099 .56744 L .78156 .56747 L F
.77983 .57748 m .78045 .58358 L .77919 .57743 L .75 .494 .544 r
F
.78045 .58358 m .77995 .58353 L .77919 .57743 L F
.77983 .57748 m .781 .58363 L .78045 .58358 L F
.78051 .57755 m .78135 .58358 L .781 .58363 L .648 .416 .554 r
F
.78072 .57522 m .78017 .57752 L .78141 .57763 L .653 .783 .943 r
F
.78081 .57751 m .78158 .58355 L .78051 .57755 L .648 .416 .554 r
F
.78158 .58355 m .78454 .60651 L .78135 .58358 L F
.78158 .58355 m .78135 .58358 L .78051 .57755 L F
.77664 .56937 m .77711 .57555 L .77712 .57544 L 0 0 .196 r
F
.77487 .57613 m .77347 .57539 L .76414 .5778 L .653 .783 .943 r
F
.78072 .57522 m .77643 .57532 L .77487 .57613 L F
.77643 .57532 m .77347 .57539 L .77487 .57613 L F
.778 .56819 m .77735 .56854 L .77783 .5746 L .454 .273 .545 r
F
.77021 .58182 m .76063 .59456 L .77365 .59512 L .654 .782 .942 r
F
.77659 .58068 m .77089 .58822 L .77582 .58844 L .653 .783 .943 r
F
.77659 .58068 m .77582 .58844 L .77751 .58851 L F
.77089 .58822 m .77435 .60155 L .77751 .58851 L F
.77089 .58822 m .76124 .60099 L .77435 .60155 L F
.77699 .58752 m .77006 .59043 L .77163 .59458 L .653 .784 .944 r
F
.77745 .5767 m .77804 .58285 L .77735 .57662 L .941 .646 .452 r
F
.77901 .58486 m .77719 .58558 L .77699 .58752 L .653 .784 .944 r
F
.77964 .58403 m .77884 .58454 L .77901 .58486 L F
.77884 .58454 m .77719 .58558 L .77901 .58486 L F
.77956 .58397 m .77719 .58558 L .77964 .58403 L F
.77831 .58398 m .77727 .58475 L .77984 .58378 L F
.76429 .58065 m .76063 .59456 L .77021 .58182 L .654 .782 .942 r
F
.76494 .58706 m .76124 .60099 L .77089 .58822 L .653 .783 .943 r
F
.77727 .58475 m .76566 .59342 L .77719 .58558 L .653 .784 .944 r
F
.77727 .58475 m .77719 .58558 L .77984 .58378 L F
.77711 .57555 m .77758 .58175 L .77712 .57544 L 0 0 .196 r
F
.7809 .584 m .7769 .58841 L .77825 .59487 L .653 .784 .944 r
F
.78099 .58363 m .78072 .58394 L .7809 .584 L F
.78072 .58394 m .7769 .58841 L .7809 .584 L F
.78211 .58348 m .78158 .58355 L .78129 .58123 L .648 .416 .554 r
F
.7785 .57726 m .77891 .5774 L .7794 .58348 L .848 .57 .516 r
F
.7785 .57726 m .7794 .58348 L .77907 .58337 L F
.77812 .57712 m .77877 .58326 L .77795 .57706 L F
.77992 .58366 m .77831 .58398 L .77984 .58378 L .653 .784 .944 r
F
.77975 .58361 m .77831 .58398 L .77992 .58366 L F
.77903 .58345 m .77831 .58398 L .78002 .58354 L F
.77984 .58378 m .77699 .58752 L .78099 .58363 L F
.77699 .58752 m .77163 .59458 L .7769 .58841 L F
.77699 .58752 m .7769 .58841 L .78099 .58363 L F
.77706 .57608 m .7776 .58228 L .77753 .58216 L .966 .687 .262 r
F
.77708 .57581 m .77706 .57608 L .77753 .58216 L 0 0 .196 r
F
.77781 .58521 m .77962 .60551 L .77932 .60488 L .966 .687 .262 r
F
.77877 .58326 m .77864 .58321 L .77795 .57706 L .848 .57 .516 r
F
.77891 .5774 m .77973 .58351 L .7794 .58348 L .75 .494 .544 r
F
.77795 .57706 m .77864 .58321 L .77843 .58314 L .848 .57 .516 r
F
.78147 .57742 m .78211 .58348 L .78129 .58123 L .648 .416 .554 r
F
.76429 .58065 m .74886 .59228 L .76063 .59456 L .654 .782 .942 r
F
.76494 .58706 m .7494 .59871 L .76124 .60099 L .653 .783 .943 r
F
.77072 .58964 m .76075 .59146 L .76566 .59342 L .653 .784 .944 r
F
.7785 .57726 m .77907 .58337 L .77812 .57712 L .848 .57 .516 r
F
.77907 .58337 m .77877 .58326 L .77812 .57712 L F
.77769 .57687 m .77795 .57706 L .77843 .58314 L .941 .646 .452 r
F
.77769 .57687 m .77843 .58314 L .77823 .58299 L F
.77919 .57743 m .77995 .58353 L .77891 .5774 L .75 .494 .544 r
F
.78002 .58354 m .77975 .58361 L .77992 .58366 L .653 .784 .944 r
F
.78099 .58363 m .77984 .58378 L .78099 .58363 L F
.78148 .58161 m .78002 .58354 L .78099 .58363 L F
.78002 .58354 m .77984 .58378 L .78099 .58363 L F
.77995 .58353 m .78284 .60669 L .77973 .58351 L .75 .494 .544 r
F
.77995 .58353 m .77973 .58351 L .77891 .5774 L F
.77903 .58345 m .77486 .58476 L .77072 .58964 L .653 .784 .944 r
F
.78148 .58161 m .77785 .58334 L .77903 .58345 L F
.77785 .58334 m .77486 .58476 L .77903 .58345 L F
.77659 .58068 m .77144 .58218 L .77089 .58822 L .653 .783 .943 r
F
.77144 .58218 m .76699 .58746 L .77089 .58822 L F
.77486 .58476 m .76075 .59146 L .77072 .58964 L .653 .784 .944 r
F
.77769 .57687 m .77823 .58299 L .77745 .5767 L .941 .646 .452 r
F
.77823 .58299 m .77804 .58285 L .77745 .5767 L F
.777 .56894 m .77742 .57508 L .77735 .56854 L .159 .061 .485 r
F
.77742 .57508 m .7777 .57475 L .77735 .56854 L F
.77516 .57114 m .7724 .57111 L .75942 .57868 L .654 .782 .942 r
F
.7724 .57111 m .75592 .57604 L .75876 .57819 L F
.7724 .57111 m .75876 .57819 L .75942 .57868 L F
.75404 .5729 m .73208 .58318 L .75592 .57604 L F
.78072 .57522 m .75617 .57234 L .7545 .57584 L .653 .783 .943 r
F
.778 .56819 m .77783 .5746 L .77837 .57432 L .454 .273 .545 r
F
.77735 .56854 m .7777 .57475 L .77783 .5746 L .159 .061 .485 r
F
.78072 .57522 m .75954 .56901 L .75617 .57234 L .653 .783 .943 r
F
.77742 .57508 m .77783 .58124 L .7777 .57475 L .159 .061 .485 r
F
.77914 .59999 m .77962 .60551 L .77916 .60037 L .966 .687 .262 r
F
.77804 .58285 m .77796 .58279 L .77735 .57662 L .941 .646 .452 r
F
.77735 .57662 m .77796 .58279 L .77783 .5827 L F
.77144 .58218 m .76494 .58706 L .76699 .58746 L .653 .783 .943 r
F
.78148 .58161 m .77619 .58319 L .77486 .58476 L .653 .784 .944 r
F
.77843 .58314 m .78122 .60646 L .78024 .60604 L .848 .57 .516 r
F
.77864 .58321 m .78122 .60646 L .77843 .58314 L F
.77804 .58285 m .78024 .60604 L .77796 .58279 L .941 .646 .452 r
F
.778 .56819 m .77837 .57432 L .77863 .56787 L .454 .273 .545 r
F
.77837 .57432 m .77889 .57405 L .77863 .56787 L F
.77613 .56999 m .7724 .57111 L .77516 .57114 L .654 .782 .942 r
F
.78072 .57522 m .76437 .5661 L .75954 .56901 L .653 .783 .943 r
F
.77863 .56787 m .77889 .57405 L .77911 .57393 L .454 .273 .545 r
F
.77925 .56771 m .77863 .56787 L .77911 .57393 L .585 .369 .554 r
F
.77925 .56771 m .77911 .57393 L .77962 .5738 L F
.78072 .57522 m .77034 .56381 L .76437 .5661 L .653 .783 .943 r
F
.77837 .57432 m .77873 .58046 L .77889 .57405 L .454 .273 .545 r
F
.77773 .58252 m .7776 .58228 L .77706 .57608 L .966 .687 .262 r
F
.77722 .57639 m .77735 .57662 L .77783 .5827 L F
.77722 .57639 m .77783 .5827 L .77773 .58252 L F
.77619 .58319 m .77435 .58272 L .76973 .58511 L .653 .784 .944 r
F
.78148 .58161 m .77692 .58232 L .77619 .58319 L F
.77692 .58232 m .77435 .58272 L .77619 .58319 L F
.7777 .57475 m .77806 .58098 L .77783 .5746 L .159 .061 .485 r
F
.77915 .59972 m .77962 .60551 L .77919 .60053 L .966 .687 .262 r
F
.77915 .59972 m .77919 .60053 L .7776 .58228 L F
.77773 .58252 m .77915 .59972 L .7776 .58228 L F
.77783 .5827 m .78024 .60604 L .77962 .60551 L .941 .646 .452 r
F
.77796 .58279 m .78024 .60604 L .77783 .5827 L F
.77823 .58299 m .78024 .60604 L .77804 .58285 L F
.77773 .58252 m .77783 .5827 L .77962 .60551 L .966 .687 .262 r
F
.77823 .58299 m .77843 .58314 L .78024 .60604 L .941 .646 .452 r
F
.77708 .57581 m .77753 .58216 L .77756 .58195 L 0 0 .196 r
F
.77758 .58175 m .77759 .58166 L .77712 .57544 L F
.77708 .57581 m .77756 .58195 L .77711 .57555 L F
.77756 .58195 m .77758 .58175 L .77711 .57555 L F
.75942 .57868 m .74886 .59228 L .76429 .58065 L .654 .782 .942 r
F
.77106 .5781 m .76414 .5778 L .75651 .58244 L .653 .783 .943 r
F
.75942 .57868 m .73913 .5884 L .74886 .59228 L .654 .782 .942 r
F
.75592 .57604 m .73913 .5884 L .75942 .57868 L F
.76414 .5778 m .75513 .58013 L .75651 .58244 L .653 .783 .943 r
F
.77501 .57794 m .77106 .5781 L .76003 .58509 L F
.77106 .5781 m .75651 .58244 L .75902 .58433 L F
.77106 .5781 m .75902 .58433 L .76003 .58509 L F
.777 .57801 m .76003 .58509 L .76494 .58706 L F
.77405 .5784 m .76003 .58509 L .777 .57801 L F
.75651 .58244 m .7396 .59483 L .76003 .58509 L F
.75592 .57604 m .73208 .58318 L .73913 .5884 L .654 .782 .942 r
F
.75651 .58244 m .73251 .5896 L .7396 .59483 L .653 .783 .943 r
F
.75462 .57929 m .73251 .5896 L .75651 .58244 L F
.76111 .58478 m .75522 .58225 L .75533 .58568 L .653 .784 .944 r
F
.78148 .58161 m .77626 .58174 L .77435 .58272 L F
.77877 .58326 m .78122 .60646 L .77864 .58321 L .848 .57 .516 r
F
.78148 .58161 m .77903 .58345 L .78002 .58354 L .653 .784 .944 r
F
.7794 .58348 m .78284 .60669 L .78122 .60646 L .75 .494 .544 r
F
.77984 .58378 m .77956 .58397 L .77964 .58403 L .653 .784 .944 r
F
.77973 .58351 m .78284 .60669 L .7794 .58348 L .75 .494 .544 r
F
.77907 .58337 m .78122 .60646 L .77877 .58326 L .848 .57 .516 r
F
.77907 .58337 m .7794 .58348 L .78122 .60646 L F
.77783 .58124 m .77806 .58098 L .7777 .57475 L .159 .061 .485 r
F
.77712 .57544 m .77759 .58166 L .7776 .58152 L 0 0 .196 r
F
.77742 .57508 m .77712 .57544 L .7776 .58152 L .159 .061 .485 r
F
.77742 .57508 m .7776 .58152 L .77783 .58124 L F
.78211 .58348 m .78454 .60651 L .78158 .58355 L .648 .416 .554 r
F
.78148 .58161 m .78202 .58349 L .78269 .5834 L .653 .784 .944 r
F
.78176 .57738 m .7822 .57733 L .78269 .5834 L .648 .416 .554 r
F
.78148 .58161 m .78269 .5834 L .78301 .58329 L .653 .784 .944 r
F
.78148 .58161 m .78203 .58192 L .78202 .58177 L F
.78296 .57767 m .7837 .57692 L .78363 .57684 L .653 .783 .943 r
F
.78285 .57711 m .78333 .57694 L .78382 .58302 L .544 .339 .553 r
F
.78344 .58315 m .78382 .58302 L .78569 .60612 L F
.78285 .57711 m .78382 .58302 L .78344 .58315 L F
.78609 .57821 m .79684 .5842 L .78547 .57661 L .653 .783 .943 r
F
.78609 .57821 m .79093 .58643 L .79684 .5842 L F
.78752 .58196 m .79093 .58643 L .78609 .57821 L F
.81177 .58665 m .84179 .58704 L .8214 .58103 L .654 .782 .942 r
F
.79684 .5842 m .81273 .59305 L .82242 .58742 L .653 .783 .943 r
F
.79093 .58643 m .81273 .59305 L .79684 .5842 L F
.79684 .5842 m .82242 .58742 L .80168 .58135 L F
.78631 .58218 m .80247 .58773 L .80592 .58446 L .653 .784 .944 r
F
.78425 .57637 m .78484 .58235 L .78416 .57646 L .231 .113 .505 r
F
.78484 .58235 m .78477 .58243 L .78416 .57646 L F
.78416 .57646 m .78477 .58243 L .78465 .58254 L F
.78447 .57614 m .78502 .58218 L .78425 .57637 L F
.78502 .58218 m .78484 .58235 L .78425 .57637 L F
.78348 .57686 m .78411 .58285 L .78333 .57694 L .424 .252 .542 r
F
.78411 .58285 m .784 .58292 L .78333 .57694 L F
.78363 .57684 m .78412 .57748 L .78424 .57717 L .653 .783 .943 r
F
.7838 .57667 m .78416 .57646 L .78465 .58254 L .424 .252 .542 r
F
.78465 .58254 m .78394 .58298 L .78497 .58263 L .653 .784 .944 r
F
.78435 .58284 m .78651 .5841 L .78497 .58263 L F
.79093 .58643 m .80095 .59745 L .81273 .59305 L .653 .783 .943 r
F
.78412 .58308 m .79762 .59057 L .78435 .58284 L .653 .784 .944 r
F
.78852 .58932 m .78817 .58842 L .7845 .58386 L F
.78449 .58389 m .7845 .58386 L .78398 .58321 L F
.78852 .58932 m .7845 .58386 L .78449 .58389 L F
.78852 .58932 m .78398 .58321 L .78397 .58322 L F
.78382 .58302 m .7845 .58386 L .78394 .58298 L F
.7845 .58386 m .79169 .59279 L .78454 .58374 L F
.7845 .58386 m .78454 .58374 L .78394 .58298 L F
.78412 .58308 m .79169 .59279 L .79762 .59057 L F
.78406 .58313 m .79169 .59279 L .78412 .58308 L F
.78437 .5827 m .78465 .58254 L .78652 .60561 L .424 .252 .542 r
F
.7838 .57667 m .78465 .58254 L .78437 .5827 L F
.78202 .58177 m .78392 .58296 L .78465 .58254 L .653 .784 .944 r
F
.78392 .58296 m .78394 .58298 L .78465 .58254 L F
.78422 .58461 m .78448 .5839 L .78382 .58302 L F
.78394 .58298 m .78406 .58313 L .78412 .58308 L F
.78411 .58285 m .78652 .60561 L .784 .58292 L .424 .252 .542 r
F
.78545 .58208 m .78497 .58263 L .78631 .58218 L .653 .784 .944 r
F
.78447 .57614 m .78471 .57591 L .7852 .58199 L .231 .113 .505 r
F
.78515 .58204 m .78465 .58254 L .78545 .58208 L .653 .784 .944 r
F
.78465 .58254 m .78497 .58263 L .78545 .58208 L F
.78497 .58263 m .79163 .58457 L .78631 .58218 L F
.79163 .58457 m .80247 .58773 L .7896 .58331 L F
.79163 .58457 m .7896 .58331 L .78631 .58218 L F
.78651 .5841 m .78626 .58344 L .78497 .58263 L F
.78447 .57614 m .7852 .58199 L .78502 .58218 L .231 .113 .505 r
F
.78615 .57681 m .80168 .58135 L .78997 .5763 L .653 .783 .943 r
F
.8214 .58103 m .84179 .58704 L .85225 .57737 L .654 .782 .942 r
F
.80168 .58135 m .82242 .58742 L .82937 .58092 L .653 .783 .943 r
F
.8214 .58103 m .85225 .57737 L .8283 .57455 L .654 .782 .942 r
F
.80168 .58135 m .82937 .58092 L .80512 .57808 L .653 .783 .943 r
F
.78668 .58149 m .80592 .58446 L .80772 .58098 L .653 .784 .944 r
F
.78485 .57553 m .78545 .58134 L .78537 .58156 L 0 0 .362 r
F
.78537 .58156 m .78529 .58176 L .78475 .57579 L F
.78471 .57591 m .78526 .58185 L .7852 .58199 L F
.78148 .58161 m .78813 .58239 L .78668 .58149 L .653 .784 .944 r
F
.78813 .58239 m .80592 .58446 L .78668 .58149 L F
.78422 .57624 m .78423 .57639 L .78434 .57628 L .653 .783 .943 r
F
.78072 .57522 m .78423 .57639 L .78422 .57624 L F
.78072 .57522 m .78373 .57689 L .78423 .57639 L F
.78503 .57316 m .80515 .56793 L .80169 .56522 L F
.77997 .56884 m .7807 .5714 L .78212 .57122 L .654 .782 .942 r
F
.7784 .53516 m .78043 .5675 L .78099 .56744 L .664 .428 .553 r
F
.78029 .56751 m .78991 .55562 L .78322 .55532 L .654 .782 .942 r
F
.77997 .56884 m .78102 .56744 L .78029 .56751 L F
.78102 .56744 m .78991 .55562 L .78029 .56751 L F
.77997 .56884 m .7959 .55683 L .78991 .55562 L F
.77997 .56884 m .80079 .55887 L .7959 .55683 L F
.77997 .56884 m .80423 .56158 L .80079 .55887 L F
.78099 .56744 m .78081 .57357 L .78148 .57351 L .664 .428 .553 r
F
.78043 .5675 m .78081 .57357 L .78099 .56744 L F
.78156 .56747 m .78099 .56744 L .78148 .57351 L .734 .481 .546 r
F
.78368 .56808 m .78408 .57409 L .78415 .56838 L .921 .628 .471 r
F
.78408 .57409 m .78447 .57434 L .78415 .56838 L F
.78368 .56808 m .78366 .57383 L .78408 .57409 L F
.78072 .57522 m .78569 .57374 L .78402 .57365 L .653 .783 .943 r
F
.78148 .58161 m .78465 .58254 L .78515 .58204 L .653 .784 .944 r
F
.78203 .58192 m .78394 .58298 L .78202 .58177 L F
.78148 .58161 m .78301 .58329 L .78394 .58298 L F
.78211 .58348 m .78269 .5834 L .78454 .60651 L .648 .416 .554 r
F
.78072 .57522 m .78254 .57721 L .78363 .57684 L .653 .783 .943 r
F
.781 .58363 m .78454 .60651 L .78284 .60669 L .648 .416 .554 r
F
.78135 .58358 m .78454 .60651 L .781 .58363 L F
.78156 .56747 m .78148 .57351 L .78195 .57353 L .734 .481 .546 r
F
.7821 .5675 m .78239 .57356 L .78259 .57357 L F
.78072 .57522 m .78199 .57354 L .78114 .57349 L .653 .783 .943 r
F
.78301 .58329 m .78269 .5834 L .78307 .58335 L .653 .784 .944 r
F
.78269 .5834 m .78569 .60612 L .78454 .60651 L .544 .339 .553 r
F
.78293 .58332 m .78569 .60612 L .78269 .5834 L F
.78156 .56747 m .78195 .57353 L .7821 .5675 L .734 .481 .546 r
F
.78195 .57353 m .78239 .57356 L .7821 .5675 L F
.78265 .56764 m .78304 .57368 L .78317 .56776 L .811 .54 .528 r
F
.78304 .57368 m .78347 .57378 L .78317 .56776 L F
.78265 .56764 m .7821 .5675 L .78259 .57357 L F
.78265 .56764 m .78259 .57357 L .78304 .57368 L F
.78368 .56808 m .78317 .56776 L .78366 .57383 L .921 .628 .471 r
F
.78317 .56776 m .78347 .57378 L .78366 .57383 L .811 .54 .528 r
F
.78072 .57522 m .79677 .56318 L .79074 .56197 L .653 .783 .943 r
F
.78072 .57522 m .80169 .56522 L .79677 .56318 L F
.78304 .57368 m .78344 .57974 L .78347 .57378 L .811 .54 .528 r
F
.78668 .58149 m .79031 .5814 L .7903 .5814 L .653 .784 .944 r
F
.78148 .58161 m .78668 .58149 L .78668 .58149 L F
.78668 .58149 m .79031 .5814 L .78668 .58149 L F
.78447 .57434 m .78479 .58031 L .78464 .57444 L .921 .628 .471 r
F
.78739 .5807 m .80772 .58097 L .79126 .58009 L .653 .784 .944 r
F
.7849 .57511 m .78534 .58106 L .78495 .57526 L .919 .662 .17 r
F
.78534 .58106 m .78538 .58117 L .78495 .57526 L F
.78408 .57409 m .78366 .57383 L .78415 .57992 L .921 .628 .471 r
F
.78495 .57526 m .78538 .58117 L .78545 .58134 L .919 .662 .17 r
F
.78524 .5808 m .78534 .58106 L .7849 .57511 L F
.78148 .58161 m .78668 .58149 L .7858 .58094 L .653 .784 .944 r
F
.78394 .58298 m .78412 .58308 L .78435 .58284 L F
.78437 .5827 m .78652 .60561 L .78411 .58285 L .424 .252 .542 r
F
.78382 .58302 m .78652 .60561 L .78569 .60612 L F
.78397 .58322 m .78398 .58321 L .78382 .58302 L .653 .784 .944 r
F
.784 .58292 m .78652 .60561 L .78382 .58302 L .424 .252 .542 r
F
.78408 .57409 m .78415 .57992 L .78448 .58012 L .921 .628 .471 r
F
.78479 .58031 m .78493 .5804 L .78464 .57444 L F
.78885 .57279 m .80515 .56793 L .78503 .57316 L .653 .783 .943 r
F
.78408 .57409 m .78448 .58012 L .78447 .57434 L .921 .628 .471 r
F
.78448 .58012 m .78479 .58031 L .78447 .57434 L F
.78464 .57444 m .78493 .5804 L .78514 .58053 L F
.78599 .57439 m .80693 .57113 L .78461 .57406 L .653 .783 .943 r
F
.78478 .57479 m .78464 .57444 L .78514 .58053 L .919 .662 .17 r
F
.78478 .57479 m .78514 .58053 L .78524 .5808 L F
.7886 .57503 m .80692 .57459 L .78599 .57439 L .653 .783 .943 r
F
.78569 .5751 m .79747 .57718 L .7886 .57503 L F
.78707 .57596 m .79747 .57718 L .78569 .5751 L F
.79747 .57718 m .80512 .57808 L .7886 .57503 L F
.78148 .58161 m .78475 .58006 L .78385 .57984 L .653 .784 .944 r
F
.78535 .57978 m .80595 .57435 L .80248 .57164 L F
.78347 .57378 m .78378 .57982 L .78366 .57383 L .811 .54 .528 r
F
.78524 .5808 m .7849 .57511 L .78485 .57499 L .919 .662 .17 r
F
.78478 .57479 m .78524 .5808 L .78485 .57499 L F
.78148 .58161 m .78583 .58032 L .78475 .58006 L .653 .784 .944 r
F
.78378 .57982 m .78392 .57986 L .78366 .57383 L .811 .54 .528 r
F
.78366 .57383 m .78392 .57986 L .78415 .57992 L F
.78259 .57357 m .78284 .57964 L .78308 .57966 L .734 .481 .546 r
F
.78304 .57368 m .78259 .57357 L .78308 .57966 L .811 .54 .528 r
F
.78304 .57368 m .78308 .57966 L .78344 .57974 L F
.78344 .57974 m .78378 .57982 L .78347 .57378 L F
.78402 .57365 m .78885 .57279 L .78503 .57316 L .653 .783 .943 r
F
.78569 .57374 m .78885 .57279 L .78402 .57365 L F
.78485 .57457 m .7886 .57503 L .78599 .57439 L F
.78569 .5751 m .7886 .57503 L .78485 .57457 L F
.78514 .57573 m .78615 .57681 L .78997 .5763 L F
.78547 .57661 m .78615 .57681 L .78514 .57573 L F
.78297 .57965 m .79756 .56961 L .79152 .5684 L .653 .784 .944 r
F
.78148 .58161 m .78403 .57971 L .78297 .57965 L F
.78403 .57971 m .79756 .56961 L .78297 .57965 L F
.78195 .57353 m .78148 .57351 L .78196 .5796 L .734 .481 .546 r
F
.78195 .57353 m .78196 .5796 L .78233 .57962 L F
.78239 .57356 m .78269 .57964 L .78259 .57357 L F
.78269 .57964 m .78284 .57964 L .78259 .57357 L F
.78195 .57353 m .78233 .57962 L .78239 .57356 L F
.78233 .57962 m .78269 .57964 L .78239 .57356 L F
.77955 .56737 m .78322 .55532 L .77631 .55594 L .654 .782 .942 r
F
.77997 .56884 m .78031 .56741 L .77955 .56737 L F
.78031 .56741 m .78322 .55532 L .77955 .56737 L F
.77925 .56771 m .77962 .5738 L .77983 .56756 L .585 .369 .554 r
F
.77962 .5738 m .7801 .57368 L .77983 .56756 L F
.78043 .5675 m .77983 .56756 L .78032 .57362 L .664 .428 .553 r
F
.78043 .5675 m .78032 .57362 L .78081 .57357 L F
.77983 .56756 m .7801 .57368 L .78032 .57362 L .585 .369 .554 r
F
.78022 .57344 m .784 .56166 L .77704 .56229 L .653 .783 .943 r
F
.78072 .57522 m .78114 .57349 L .78022 .57344 L F
.78114 .57349 m .784 .56166 L .78022 .57344 L F
.78114 .57349 m .79074 .56197 L .784 .56166 L F
.78199 .57354 m .79074 .56197 L .78114 .57349 L F
.78148 .57351 m .78119 .57967 L .78196 .5796 L .664 .428 .553 r
F
.78081 .57357 m .78119 .57967 L .78148 .57351 L F
.78072 .57522 m .77906 .57741 L .78017 .57752 L .653 .783 .943 r
F
.78072 .57522 m .77704 .56229 L .77034 .56381 L F
.78032 .57362 m .78054 .57978 L .7808 .57971 L .585 .369 .554 r
F
.77962 .5738 m .78 .57992 L .7801 .57368 L F
.78 .57992 m .78038 .57982 L .7801 .57368 L F
.78081 .57357 m .78032 .57362 L .7808 .57971 L .664 .428 .553 r
F
.78081 .57357 m .7808 .57971 L .78119 .57967 L F
.7801 .57368 m .78038 .57982 L .78032 .57362 L .585 .369 .554 r
F
.77685 .57812 m .77144 .58218 L .77659 .58068 L .653 .783 .943 r
F
.77626 .58174 m .77224 .58054 L .75522 .58225 L .653 .784 .944 r
F
.78148 .58161 m .77742 .58114 L .77626 .58174 L F
.77742 .58114 m .77224 .58054 L .77626 .58174 L F
.77889 .57405 m .77914 .58025 L .77911 .57393 L .454 .273 .545 r
F
.77806 .58098 m .77815 .58086 L .77783 .5746 L .159 .061 .485 r
F
.77783 .5746 m .77815 .58086 L .77831 .58069 L F
.76414 .5778 m .75834 .57575 L .75462 .57929 L .653 .783 .943 r
F
.77347 .57539 m .75834 .57575 L .76414 .5778 L F
.77487 .57613 m .76414 .5778 L .77106 .5781 L F
.76414 .5778 m .75462 .57929 L .75513 .58013 L F
.77592 .58097 m .76026 .57544 L .75689 .57875 L .653 .784 .944 r
F
.78148 .58161 m .77769 .58051 L .77592 .58097 L F
.77769 .58051 m .76026 .57544 L .77592 .58097 L F
.77962 .5738 m .77911 .57393 L .7796 .58002 L .585 .369 .554 r
F
.78045 .58358 m .78284 .60669 L .77995 .58353 L .75 .494 .544 r
F
.77873 .58046 m .77914 .58025 L .77889 .57405 L .454 .273 .545 r
F
.77837 .57432 m .77783 .5746 L .77831 .58069 L F
.77837 .57432 m .77831 .58069 L .77873 .58046 L F
.77616 .57658 m .77106 .5781 L .77501 .57794 L .653 .783 .943 r
F
.78148 .58161 m .7651 .57253 L .76026 .57544 L .653 .784 .944 r
F
.77962 .5738 m .7796 .58002 L .78 .57992 L .585 .369 .554 r
F
.77914 .58025 m .77932 .58016 L .77911 .57393 L .454 .273 .545 r
F
.77911 .57393 m .77932 .58016 L .7796 .58002 L F
.78148 .58161 m .77109 .57024 L .7651 .57253 L .653 .784 .944 r
F
.78038 .57982 m .78054 .57978 L .78032 .57362 L .585 .369 .554 r
F
.78148 .58161 m .7778 .56873 L .77109 .57024 L .653 .784 .944 r
F
.78 .57992 m .7796 .58002 L .78138 .60253 L .585 .369 .554 r
F
.77914 .58025 m .78009 .60323 L .77932 .58016 L .454 .273 .545 r
F
.78045 .58358 m .78054 .58358 L .78061 .5851 L .75 .494 .544 r
F
.78054 .58358 m .781 .58363 L .78061 .5851 L F
.78061 .5851 m .781 .58363 L .78284 .60669 L F
.78038 .57982 m .78138 .60253 L .78054 .57978 L .585 .369 .554 r
F
.78093 .57968 m .78477 .5681 L .7778 .56873 L .653 .784 .944 r
F
.78093 .5797 m .78094 .57967 L .78093 .57968 L F
.78094 .57967 m .78477 .5681 L .78093 .57968 L F
.78148 .58161 m .78197 .5796 L .78093 .5797 L F
.78197 .5796 m .78477 .5681 L .78093 .5797 L F
.78148 .58161 m .78099 .58363 L .78202 .58349 L F
.78119 .57967 m .7808 .57971 L .7826 .60222 L .664 .428 .553 r
F
.78422 .57418 m .78599 .57439 L .78461 .57406 L .653 .783 .943 r
F
.78485 .57457 m .78599 .57439 L .78422 .57418 L F
.78148 .58161 m .79152 .5684 L .78477 .5681 L .653 .784 .944 r
F
.8283 .57455 m .85225 .57737 L .85794 .56699 L .654 .782 .942 r
F
.8283 .57455 m .85794 .56699 L .83198 .56761 L F
.80512 .57808 m .83308 .57397 L .80692 .57459 L .653 .783 .943 r
F
.78148 .58161 m .80773 .57753 L .80595 .57435 L .653 .784 .944 r
F
.78233 .57962 m .78196 .5796 L .78377 .60214 L .734 .481 .546 r
F
.78378 .57982 m .7849 .60226 L .78392 .57986 L .811 .54 .528 r
F
.78475 .58006 m .78731 .57988 L .78535 .57978 L .653 .784 .944 r
F
.78583 .58032 m .78731 .57988 L .78475 .58006 L F
.78731 .57988 m .80595 .57435 L .78535 .57978 L F
.78269 .57964 m .78377 .60214 L .78284 .57964 L .734 .481 .546 r
F
.78415 .57992 m .7849 .60226 L .78599 .6026 L .811 .54 .528 r
F
.78392 .57986 m .7849 .60226 L .78415 .57992 L F
.78385 .57984 m .78535 .57978 L .78403 .57971 L .653 .784 .944 r
F
.78475 .58006 m .78535 .57978 L .78385 .57984 L F
.78403 .57971 m .80248 .57164 L .79756 .56961 L F
.78535 .57978 m .80248 .57164 L .78403 .57971 L F
.78308 .57966 m .78377 .60214 L .7849 .60226 L .734 .481 .546 r
F
.78284 .57964 m .78377 .60214 L .78308 .57966 L F
.78448 .58012 m .78415 .57992 L .78599 .6026 L .921 .628 .471 r
F
.7858 .58094 m .7903 .5814 L .78739 .5807 L .653 .784 .944 r
F
.78668 .58149 m .7903 .5814 L .7858 .58094 L F
.7903 .5814 m .80772 .58097 L .78739 .5807 L F
.78344 .57974 m .78308 .57966 L .7849 .60226 L .811 .54 .528 r
F
.78465 .58254 m .78465 .58254 L .78515 .58204 L .653 .784 .944 r
F
.78484 .58235 m .78707 .605 L .78477 .58243 L .231 .113 .505 r
F
.78465 .58254 m .78707 .605 L .78652 .60561 L F
.78477 .58243 m .78707 .605 L .78465 .58254 L F
.78502 .58218 m .78707 .605 L .78484 .58235 L F
.78479 .58031 m .78599 .6026 L .78493 .5804 L .921 .628 .471 r
F
.78344 .57974 m .7849 .60226 L .78378 .57982 L .811 .54 .528 r
F
.7903 .5814 m .80772 .58098 L .80772 .58097 L .653 .784 .944 r
F
.79031 .5814 m .80772 .58098 L .7903 .5814 L F
.80512 .57808 m .82937 .58092 L .83308 .57397 L .653 .783 .943 r
F
.79126 .58009 m .80772 .58097 L .80773 .57753 L .653 .784 .944 r
F
.78233 .57962 m .78377 .60214 L .78269 .57964 L .734 .481 .546 r
F
.78448 .58012 m .78599 .6026 L .78479 .58031 L .921 .628 .471 r
F
.78502 .58218 m .7852 .58199 L .78707 .605 L .231 .113 .505 r
F
.7852 .58199 m .78731 .60427 L .78707 .605 L 0 0 .362 r
F
.78526 .58185 m .78731 .60427 L .7852 .58199 L F
.78514 .58053 m .78599 .6026 L .78699 .60334 L .921 .628 .471 r
F
.78493 .5804 m .78599 .6026 L .78514 .58053 L F
.78196 .5796 m .7826 .60222 L .78377 .60214 L .664 .428 .553 r
F
.78119 .57967 m .7826 .60222 L .78196 .5796 L F
.77224 .58054 m .75689 .57875 L .75525 .58218 L .653 .784 .944 r
F
.77224 .58054 m .75525 .58218 L .75522 .58225 L F
.7796 .58002 m .78009 .60323 L .78138 .60253 L .454 .273 .545 r
F
.77932 .58016 m .78009 .60323 L .7796 .58002 L F
.77435 .58272 m .77257 .58183 L .76111 .58478 L .653 .784 .944 r
F
.77626 .58174 m .77257 .58183 L .77435 .58272 L F
.77257 .58183 m .75522 .58225 L .76111 .58478 L F
.7808 .57971 m .78138 .60253 L .7826 .60222 L .585 .369 .554 r
F
.78054 .57978 m .78138 .60253 L .7808 .57971 L F
.77806 .58098 m .77938 .60415 L .77815 .58086 L .159 .061 .485 r
F
.77873 .58046 m .78009 .60323 L .77914 .58025 L .454 .273 .545 r
F
.76003 .58509 m .7494 .59871 L .76494 .58706 L .653 .783 .943 r
F
.76973 .58511 m .76111 .58478 L .75722 .58882 L .653 .784 .944 r
F
.77435 .58272 m .76111 .58478 L .76973 .58511 L F
.76111 .58478 m .75533 .58568 L .75564 .58619 L F
.76003 .58509 m .7396 .59483 L .7494 .59871 L .653 .783 .943 r
F
.76111 .58478 m .75564 .58619 L .75722 .58882 L .653 .784 .944 r
F
.78 .57992 m .78138 .60253 L .78038 .57982 L .585 .369 .554 r
F
.77831 .58069 m .77938 .60415 L .78009 .60323 L .159 .061 .485 r
F
.77815 .58086 m .77938 .60415 L .77831 .58069 L F
.77486 .58476 m .76973 .58511 L .76075 .59146 L .653 .784 .944 r
F
.77619 .58319 m .76973 .58511 L .77486 .58476 L F
.76973 .58511 m .75722 .58882 L .75938 .59044 L F
.76973 .58511 m .75938 .59044 L .76075 .59146 L F
.77873 .58046 m .77831 .58069 L .78009 .60323 L .454 .273 .545 r
F
.77914 .59999 m .77916 .60037 L .77753 .58216 L .966 .687 .262 r
F
.7776 .58228 m .77914 .59999 L .77753 .58216 L F
.77783 .58124 m .77938 .60415 L .77806 .58098 L .159 .061 .485 r
F
.77756 .58195 m .77753 .58216 L .77932 .60488 L 0 0 .196 r
F
.77758 .58175 m .77932 .60488 L .77759 .58166 L F
.77719 .58558 m .77006 .59043 L .77699 .58752 L .653 .784 .944 r
F
.7776 .58152 m .77932 .60488 L .77938 .60415 L 0 0 .196 r
F
.77759 .58166 m .77932 .60488 L .7776 .58152 L F
.77783 .58124 m .7776 .58152 L .77938 .60415 L .159 .061 .485 r
F
.77006 .59043 m .76566 .59342 L .76726 .59373 L .653 .784 .944 r
F
.77006 .59043 m .76726 .59373 L .77163 .59458 L F
.75834 .57575 m .7545 .57584 L .75451 .57612 L .653 .783 .943 r
F
.75834 .57575 m .75451 .57612 L .75462 .57929 L F
.77756 .58195 m .77932 .60488 L .77758 .58175 L 0 0 .196 r
F
.7769 .58841 m .77163 .59458 L .77626 .59478 L .653 .784 .944 r
F
.7769 .58841 m .77626 .59478 L .77825 .59487 L F
.78529 .58176 m .78731 .60427 L .78526 .58185 L 0 0 .362 r
F
.78537 .58156 m .78731 .60427 L .78529 .58176 L F
.78524 .5808 m .78514 .58053 L .78699 .60334 L .919 .662 .17 r
F
.78651 .5841 m .79762 .59057 L .78626 .58344 L .653 .784 .944 r
F
.78537 .58156 m .78545 .58134 L .78731 .60427 L 0 0 .362 r
F
.78534 .58106 m .78699 .60334 L .78538 .58117 L .919 .662 .17 r
F
.78607 .58295 m .79762 .59057 L .80247 .58773 L .653 .784 .944 r
F
.78626 .58344 m .79762 .59057 L .78607 .58295 L F
.78852 .58932 m .79169 .59279 L .78817 .58842 L F
.78545 .58134 m .78699 .60334 L .78731 .60427 L .919 .662 .17 r
F
.78538 .58117 m .78699 .60334 L .78545 .58134 L F
.78524 .5808 m .78699 .60334 L .78534 .58106 L F
.37339 .48872 m .39043 .47245 L .36807 .48459 L .642 .738 .919 r
F
.37339 .48872 m .40103 .48083 L .39043 .47245 L F
.68252 .60499 m .68104 .58866 L .68163 .59499 L 0 0 .067 r
F
.6831 .6113 m .68252 .60499 L .68163 .59499 L F
.65678 .60561 m .68252 .60499 L .68163 .59499 L .654 .783 .943 r
F
0 g
.67973 .61138 m
.68252 .60499 L
s
.36876 .47675 m .37729 .45788 L .36195 .47343 L .643 .738 .918 r
F
.36876 .47675 m .39096 .46464 L .37729 .45788 L F
.28867 .47492 m .25139 .47716 L .28313 .48365 L .642 .738 .919 r
F
.41314 .74045 m .39009 .74123 L .40708 .74439 L .656 .809 .957 r
F
.40776 .4902 m .429 .47285 L .40103 .48083 L .642 .738 .919 r
F
.40776 .4902 m .43888 .48701 L .429 .47285 L F
.63018 .6159 m .65732 .61193 L .63152 .61257 L .653 .784 .944 r
F
.41255 .73004 m .39868 .72485 L .38968 .7308 L .657 .808 .956 r
F
.42047 .72679 m .39868 .72485 L .41255 .73004 L F
.74902 .49199 m .71457 .48985 L .74496 .49631 L .643 .738 .918 r
F
.80733 .49959 m .83536 .48706 L .80509 .49494 L F
.80733 .49959 m .83968 .49643 L .83536 .48706 L F
.58033 .59784 m .55345 .60182 L .57913 .60119 L .654 .782 .942 r
F
.65678 .60561 m .68163 .59499 L .65606 .59897 L .654 .783 .943 r
F
.63102 .60624 m .65678 .60561 L .65606 .59897 L F
.27432 .60465 m .28779 .60604 L .28773 .61236 L .906 .654 .546 r
F
.27432 .60465 m .2744 .5983 L .28779 .60604 L F
.29629 .59122 m .28779 .60604 L .30518 .59644 L .655 .781 .941 r
F
.29629 .59122 m .2744 .5983 L .28779 .60604 L F
0 g
.28779 .60604 m
.29485 .60845 L
s
.28996 .46714 m .26098 .45619 L .25294 .46937 L .643 .738 .918 r
F
.25947 .46394 m .25247 .46927 L .25139 .47716 L 0 0 .271 r
F
0 g
.25165 .47714 m
.2517 .47665 L
s
.25947 .46394 m .26054 .45602 L .25247 .46927 L 0 0 .271 r
F
.46112 .46371 m .48171 .46594 L .48117 .47382 L .853 .601 .558 r
F
.46112 .46371 m .46171 .45582 L .48171 .46594 L F
0 g
.48171 .46594 m
.48767 .46771 L
s
.67625 .49219 m .65746 .47429 L .65732 .48221 L .86 .601 .545 r
F
.67616 .50013 m .67625 .49219 L .65732 .48221 L F
0 g
.67625 .49219 m
.67829 .49403 L
s
.59045 .49916 m .58357 .48062 L .55956 .48504 L .642 .738 .919 r
F
.60728 .49877 m .58357 .48062 L .59045 .49916 L F
.82921 .60809 m .84294 .59343 L .84379 .59976 L .454 .303 .586 r
F
.81353 .59939 m .82921 .60809 L .84379 .59976 L .653 .784 .944 r
F
.80173 .60378 m .82921 .60809 L .81353 .59939 L F
0 g
.8116 .61458 m
.82921 .60809 L
s
.51296 .47079 m .52891 .4918 L .52982 .47297 L .642 .738 .918 r
F
.51296 .47079 m .5039 .48858 L .52891 .4918 L F
0 g
.52891 .4918 m
.53693 .49161 L
s
.74894 .48407 m .72254 .47319 L .71457 .48194 L .644 .737 .917 r
F
.7548 .48046 m .72254 .47319 L .74894 .48407 L F
.62388 .50091 m .60911 .48001 L .60728 .49877 L .642 .738 .919 r
F
.62388 .50091 m .63428 .48328 L .60911 .48001 L F
.75481 .47264 m .73439 .45808 L .72279 .4654 L .644 .736 .916 r
F
.76203 .47001 m .73439 .45808 L .75481 .47264 L F
.48518 .44327 m .48196 .46571 L .49849 .4501 L .644 .737 .916 r
F
.48518 .44327 m .46206 .45563 L .48196 .46571 L F
.43888 .48701 m .43953 .47911 L .42967 .46491 L .983 .743 .493 r
F
0 g
.43953 .47911 m
.4429 .49371 L
s
.80488 .48701 m .82656 .47071 L .80059 .48287 L .644 .737 .917 r
F
.80488 .48701 m .83508 .47911 L .82656 .47071 L F
.80026 .47503 m .81396 .45612 L .79423 .4717 L .644 .736 .916 r
F
.80026 .47503 m .82604 .4629 L .81396 .45612 L F
0 g
.76761 .48479 m
.76859 .48456 L
s
.72254 .47319 m .68407 .47543 L .71457 .48194 L .644 .737 .917 r
F
.55574 .59509 m .52775 .60244 L .55345 .60182 L .654 .782 .942 r
F
.58033 .59784 m .55574 .59509 L .55345 .60182 L F
.63102 .60624 m .65606 .59897 L .6306 .60293 L .654 .783 .943 r
F
.45905 .72427 m .45481 .71443 L .44976 .72316 L .657 .808 .956 r
F
.45905 .72427 m .46882 .71614 L .45481 .71443 L F
.49091 .73462 m .48139 .72463 L .48184 .72987 L .917 .647 .513 r
F
0 g
.49091 .73462 m
.49645 .74041 L
s
.83939 .4885 m .86563 .4711 L .83508 .47911 L .644 .737 .917 r
F
.83939 .4885 m .87186 .4853 L .86563 .4711 L F
.46798 .73685 m .46984 .72652 L .45999 .73465 L .656 .809 .957 r
F
.46798 .73685 m .48184 .72987 L .46984 .72652 L F
.70934 .60304 m .71943 .60445 L .72007 .61077 L .939 .657 .479 r
F
.70934 .60304 m .70871 .59669 L .71943 .60445 L F
.73251 .5896 m .71943 .60445 L .7396 .59483 L .653 .783 .943 r
F
.73251 .5896 m .70871 .59669 L .71943 .60445 L F
0 g
.71943 .60445 m
.7271 .60744 L
s
.55574 .59509 m .531 .59233 L .52775 .60244 L .654 .782 .942 r
F
.53097 .59864 m .52736 .60245 L .52769 .60877 L 0 0 .331 r
F
0 g
.52828 .60694 m
.52866 .60875 L
s
.53097 .59864 m .53063 .59229 L .52736 .60245 L 0 0 .331 r
F
.6831 .6113 m .68163 .59499 L .68221 .60133 L 0 0 .067 r
F
.65732 .61193 m .6831 .6113 L .68221 .60133 L .653 .784 .944 r
F
0 g
.67875 .62125 m
.6831 .6113 L
s
.72279 .4654 m .69628 .45443 L .6846 .46764 L .644 .736 .916 r
F
.41277 .73521 m .39881 .73002 L .38976 .73598 L .656 .808 .956 r
F
.42075 .73195 m .39881 .73002 L .41277 .73521 L F
.60728 .49877 m .60911 .48001 L .58357 .48062 L .642 .738 .919 r
F
.39881 .73002 m .38943 .73075 L .38976 .73598 L .402 .257 .568 r
F
.39881 .73002 m .39846 .72477 L .38943 .73075 L F
0 g
.38393 .73733 m
.38943 .73075 L
s
.69584 .46219 m .68414 .46754 L .68407 .47543 L .181 .055 .462 r
F
.69584 .46219 m .69588 .45426 L .68414 .46754 L F
0 g
.67879 .48192 m
.68414 .46754 L
s
.32981 .47174 m .31235 .45447 L .29946 .45983 L .643 .738 .918 r
F
.33743 .47027 m .31235 .45447 L .32981 .47174 L F
.41925 .84829 m .42902 .84601 L .42865 .85046 L .784 .556 .591 r
F
.41925 .84829 m .41962 .84383 L .42902 .84601 L F
.42598 .83953 m .41962 .84383 L .42902 .84601 L .593 .769 .963 r
F
0 g
.42902 .84601 m
.43137 .84628 L
s
.36195 .47343 m .36142 .45323 L .35409 .47115 L .643 .738 .918 r
F
.36195 .47343 m .37729 .45788 L .36142 .45323 L F
.44874 .85167 m .44908 .84721 L .45844 .84616 L .611 .404 .576 r
F
0 g
.44594 .84719 m
.44908 .84721 L
s
.62997 .59663 m .65107 .58653 L .62782 .59358 L .654 .782 .942 r
F
.62997 .59663 m .65527 .59269 L .65107 .58653 L F
.87186 .4853 m .8715 .47739 L .86528 .46316 L .973 .711 .293 r
F
0 g
.87128 .48398 m
.8713 .48341 L
s
.4973 .46613 m .5039 .48858 L .51296 .47079 L .642 .738 .918 r
F
.4973 .46613 m .48062 .48173 L .5039 .48858 L F
0 g
.5039 .48858 m
.52891 .4918 L
s
.41149 .84077 m .42 .83938 L .41962 .84383 L .84 .608 .587 r
F
.41149 .84077 m .41188 .83631 L .42 .83938 L F
0 g
.42 .83938 m
.42461 .84045 L
s
.58062 .60415 m .55357 .60814 L .57941 .60751 L .654 .783 .943 r
F
.65732 .61193 m .68221 .60133 L .6566 .60531 L .653 .784 .944 r
F
.63152 .61257 m .65732 .61193 L .6566 .60531 L F
.29624 .59758 m .28773 .61236 L .30515 .60279 L .654 .782 .942 r
F
.29624 .59758 m .27432 .60465 L .28773 .61236 L F
0 g
.28773 .61236 m
.30452 .61805 L
s
.45844 .84616 m .45877 .8417 L .46683 .8396 L .524 .33 .56 r
F
0 g
.45352 .8423 m
.45877 .8417 L
s
.31661 .4937 m .28767 .48286 L .28213 .49156 L .641 .739 .92 r
F
.32143 .49011 m .28767 .48286 L .31661 .4937 L F
.40972 .59504 m .40958 .58874 L .41715 .57905 L .129 .038 .474 r
F
0 g
.40063 .59493 m
.40958 .58874 L
s
.32235 .48218 m .29824 .4676 L .28867 .47492 L .642 .738 .919 r
F
.32882 .47955 m .29824 .4676 L .32235 .48218 L F
.37259 .49665 m .38966 .48042 L .36726 .49252 L .641 .739 .92 r
F
.37259 .49665 m .4003 .48878 L .38966 .48042 L F
.42047 .72679 m .41059 .71992 L .39868 .72485 L .657 .808 .956 r
F
.42976 .72446 m .41059 .71992 L .42047 .72679 L F
.36807 .48459 m .37665 .46567 L .36121 .48125 L .642 .738 .919 r
F
.36807 .48459 m .39043 .47245 L .37665 .46567 L F
.28767 .48286 m .2503 .48507 L .28213 .49156 L .641 .739 .92 r
F
.45957 .72942 m .45531 .71956 L .45022 .7283 L .656 .808 .956 r
F
.45957 .72942 m .4694 .72126 L .45531 .71956 L F
.34843 .59588 m .35605 .60826 L .36843 .60538 L .654 .782 .942 r
F
.40704 .49813 m .42832 .48083 L .4003 .48878 L .641 .739 .92 r
F
.40704 .49813 m .43824 .49496 L .42832 .48083 L F
.55587 .6014 m .52769 .60877 L .55357 .60814 L .654 .783 .943 r
F
.58062 .60415 m .55587 .6014 L .55357 .60814 L F
.63152 .61257 m .6566 .60531 L .63109 .60926 L .653 .784 .944 r
F
.76203 .47001 m .74891 .45271 L .73439 .45808 L .644 .736 .916 r
F
.77016 .46854 m .74891 .45271 L .76203 .47001 L F
.79423 .4717 m .79908 .45146 L .78685 .46941 L F
.79423 .4717 m .81396 .45612 L .79908 .45146 L F
.44976 .72316 m .43971 .71452 L .43976 .72322 L .657 .808 .956 r
F
.44976 .72316 m .45481 .71443 L .43971 .71452 L F
.42561 .844 m .42865 .85046 L .43191 .84546 L .592 .769 .964 r
F
.42561 .844 m .41925 .84829 L .42865 .85046 L F
0 g
.42865 .85046 m
.43415 .85109 L
s
.41314 .74045 m .39916 .73528 L .39009 .74123 L .656 .809 .957 r
F
.42112 .7372 m .39916 .73528 L .41314 .74045 L F
.39916 .73528 m .38976 .73598 L .39009 .74123 L .402 .257 .568 r
F
0 g
.38458 .74777 m
.39009 .74123 L
s
.39916 .73528 m .39881 .73002 L .38976 .73598 L .402 .257 .568 r
F
0 g
.38426 .74254 m
.38976 .73598 L
s
.44874 .85167 m .45844 .84616 L .4581 .85062 L .611 .404 .576 r
F
.44536 .84626 m .44874 .85167 L .4581 .85062 L .592 .769 .964 r
F
0 g
.44203 .85163 m
.44874 .85167 L
s
.58321 .59466 m .55574 .59509 L .58033 .59784 L .654 .782 .942 r
F
.33743 .47027 m .32772 .45146 L .31235 .45447 L .643 .738 .918 r
F
.34572 .47007 m .32772 .45146 L .33743 .47027 L F
.35409 .47115 m .34448 .45103 L .34572 .47007 L F
.35409 .47115 m .36142 .45323 L .34448 .45103 L F
0 g
.53886 .49291 m
.55956 .48504 L
s
.28867 .47492 m .25947 .46394 L .25139 .47716 L .642 .738 .919 r
F
.25839 .47189 m .25139 .47716 L .2503 .48507 L 0 0 .271 r
F
0 g
.25056 .48506 m
.25061 .48456 L
s
.25839 .47189 m .25947 .46394 L .25139 .47716 L 0 0 .271 r
F
.32842 .59505 m .32916 .60891 L .33486 .59621 L .654 .782 .942 r
F
.32842 .59505 m .31637 .60664 L .32916 .60891 L F
.46052 .47165 m .48117 .47382 L .48062 .48173 L .853 .601 .558 r
F
.46052 .47165 m .46112 .46371 L .48117 .47382 L F
.4844 .45133 m .48117 .47382 L .49781 .45818 L .643 .737 .917 r
F
.4844 .45133 m .46112 .46371 L .48117 .47382 L F
0 g
.48117 .47382 m
.48718 .47559 L
s
.73318 .59596 m .72007 .61077 L .74028 .60118 L .653 .784 .944 r
F
.73318 .59596 m .70934 .60304 L .72007 .61077 L F
0 g
.72007 .61077 m
.73478 .61647 L
s
.77163 .59458 m .77508 .60787 L .77825 .59487 L .653 .784 .944 r
F
.77163 .59458 m .76195 .60732 L .77508 .60787 L F
.67616 .50013 m .65732 .48221 L .65719 .49017 L .86 .601 .545 r
F
0 g
.67616 .50013 m
.67821 .50196 L
s
.41111 .84524 m .41962 .84383 L .41925 .84829 L .84 .608 .587 r
F
.41111 .84524 m .41149 .84077 L .41962 .84383 L F
.42055 .83747 m .41962 .84383 L .42598 .83953 L .593 .769 .963 r
F
.42055 .83747 m .41149 .84077 L .41962 .84383 L F
0 g
.41962 .84383 m
.42427 .84491 L
s
.55587 .6014 m .53097 .59864 L .52769 .60877 L .654 .783 .943 r
F
.5313 .60501 m .52769 .60877 L .52802 .61511 L 0 0 .331 r
F
0 g
.52862 .61327 m
.52899 .61509 L
s
.5313 .60501 m .53097 .59864 L .52769 .60877 L 0 0 .331 r
F
.74902 .49199 m .72256 .48113 L .71457 .48985 L .643 .738 .918 r
F
.75489 .48839 m .72256 .48113 L .74902 .49199 L F
.84294 .59343 m .8421 .58713 L .85261 .57741 L .31 .202 .566 r
F
0 g
.83141 .59329 m
.8421 .58713 L
s
.29946 .45983 m .26098 .45619 L .28996 .46714 L .643 .738 .918 r
F
.43888 .48701 m .42967 .46491 L .429 .47285 L .983 .743 .493 r
F
.43824 .49496 m .43888 .48701 L .429 .47285 L F
0 g
.43888 .48701 m
.44227 .50158 L
s
.45844 .84616 m .46683 .8396 L .46651 .84406 L .524 .33 .56 r
F
.4581 .85062 m .45844 .84616 L .46651 .84406 L F
.45196 .84108 m .45844 .84616 L .46651 .84406 L .593 .769 .963 r
F
0 g
.44908 .84721 m
.45844 .84616 L
s
.7548 .48046 m .73423 .46586 L .72254 .47319 L .644 .737 .917 r
F
.76208 .47783 m .73423 .46586 L .7548 .48046 L F
.80509 .49494 m .82683 .47868 L .80079 .49081 L .643 .738 .918 r
F
.80509 .49494 m .83536 .48706 L .82683 .47868 L F
.34572 .47007 m .34448 .45103 L .32772 .45146 L F
.80059 .48287 m .81439 .46392 L .79451 .47953 L .644 .737 .917 r
F
.80059 .48287 m .82656 .47071 L .81439 .46392 L F
.72256 .48113 m .684 .48335 L .71457 .48985 L .643 .738 .918 r
F
.48139 .72463 m .48094 .7194 L .46896 .71602 L .847 .593 .554 r
F
0 g
.48094 .7194 m
.48999 .72418 L
s
.40149 .473 m .41353 .45233 L .39096 .46464 L .643 .738 .918 r
F
.40149 .473 m .42925 .46503 L .41353 .45233 L F
.42976 .72446 m .42461 .71639 L .41059 .71992 L .657 .808 .956 r
F
.43976 .72322 m .42461 .71639 L .42976 .72446 L F
.83968 .49643 m .86599 .47909 L .83536 .48706 L .643 .738 .918 r
F
.83968 .49643 m .87223 .49325 L .86599 .47909 L F
.6306 .60293 m .65184 .5928 L .62843 .59987 L .654 .783 .943 r
F
.6306 .60293 m .65606 .59897 L .65184 .5928 L F
.43976 .72322 m .43971 .71452 L .42461 .71639 L .657 .808 .956 r
F
.42075 .73195 m .41081 .72508 L .39881 .73002 L .656 .808 .956 r
F
.4301 .72962 m .41081 .72508 L .42075 .73195 L F
.58104 .61049 m .55394 .61447 L .57983 .61384 L .653 .784 .944 r
F
.45999 .73465 m .45573 .72482 L .45063 .73355 L .656 .809 .957 r
F
.45999 .73465 m .46984 .72652 L .45573 .72482 L F
.65527 .59269 m .67452 .57942 L .65107 .58653 L .654 .782 .942 r
F
.65527 .59269 m .68066 .58872 L .67452 .57942 L F
.60362 .71686 m .60301 .71164 L .61814 .70976 L .677 .464 .591 r
F
.58869 .71694 m .60301 .71164 L .60362 .71686 L .732 .505 .583 r
F
.58869 .71694 m .5881 .71172 L .60301 .71164 L F
.40972 .59504 m .41715 .57905 L .4173 .58538 L .129 .038 .474 r
F
.40986 .60137 m .40972 .59504 L .4173 .58538 L F
.38693 .58905 m .40972 .59504 L .4173 .58538 L .655 .781 .941 r
F
.3789 .59467 m .40972 .59504 L .38693 .58905 L F
0 g
.4007 .60126 m
.40972 .59504 L
s
.77016 .46854 m .76533 .44969 L .74891 .45271 L .644 .736 .916 r
F
.77864 .46833 m .76533 .44969 L .77016 .46854 L F
.78685 .46941 m .78247 .44926 L .77864 .46833 L F
.78685 .46941 m .79908 .45146 L .78247 .44926 L F
.60237 .63553 m .60239 .63624 L .60356 .68586 L .712 .567 0 r
F
.60407 .70343 m .60303 .7115 L .60429 .71135 L .656 .808 .956 r
F
.5942 .70276 m .60303 .7115 L .60407 .70343 L F
.60404 .70271 m .60407 .70343 L .60416 .70271 L F
.5942 .70276 m .60407 .70343 L .60404 .70271 L F
.60029 .69382 m .60416 .70271 L .6053 .6938 L F
.60029 .69382 m .5942 .70276 L .60416 .70271 L F
.60416 .70271 m .60407 .70343 L .61808 .70964 L F
.60407 .70343 m .60429 .71135 L .61808 .70964 L F
.60659 .70241 m .61808 .70964 L .61427 .70146 L F
.60416 .70271 m .60622 .70374 L .60659 .70241 L F
.60622 .70374 m .61808 .70964 L .60659 .70241 L F
.6053 .6938 m .60416 .70271 L .60659 .70241 L F
.60826 .69633 m .60659 .70241 L .61427 .70146 L F
.6053 .6938 m .60659 .70241 L .60826 .69633 L F
.61 .63635 m .61016 .63565 L .61144 .68479 L 0 0 .235 r
F
.61039 .69316 m .61427 .70146 L .62027 .69997 L .656 .808 .956 r
F
.61834 .69665 m .62027 .69997 L .62386 .69908 L F
.61039 .69316 m .62027 .69997 L .61834 .69665 L F
.6053 .6938 m .61427 .70146 L .61039 .69316 L F
.60592 .69911 m .60476 .70805 L .61493 .70679 L .656 .809 .957 r
F
.61039 .69316 m .61834 .69665 L .61522 .69196 L .656 .808 .956 r
F
.61834 .69665 m .62386 .69908 L .61597 .69257 L F
.61834 .69665 m .61597 .69257 L .61522 .69196 L F
.61 .63635 m .61144 .68479 L .61139 .68496 L 0 0 .235 r
F
.61 .63635 m .61139 .68496 L .61127 .68538 L F
.61427 .70146 m .61808 .70964 L .63239 .70611 L .656 .808 .956 r
F
.61427 .70146 m .63239 .70611 L .62386 .69908 L F
.61104 .69848 m .61493 .70679 L .62459 .7044 L .656 .809 .957 r
F
.60592 .69911 m .61493 .70679 L .61104 .69848 L F
.61104 .69848 m .62459 .7044 L .6159 .69727 L F
.61877 .71498 m .61814 .70976 L .63252 .70621 L .617 .421 .595 r
F
.60362 .71686 m .61814 .70976 L .61877 .71498 L .677 .464 .591 r
F
.61877 .71498 m .63252 .70621 L .63316 .71144 L .617 .421 .595 r
F
.61493 .70679 m .61877 .71498 L .63316 .71144 L .656 .809 .957 r
F
.60476 .70805 m .61877 .71498 L .61493 .70679 L F
.61493 .70679 m .63316 .71144 L .62459 .7044 L F
.61167 .70377 m .61556 .71205 L .62523 .70966 L .655 .81 .957 r
F
.60654 .7044 m .61556 .71205 L .61167 .70377 L F
.61167 .70377 m .62523 .70966 L .61653 .70256 L F
.60952 .68726 m .61039 .69316 L .61522 .69196 L .656 .808 .956 r
F
.61058 .68649 m .61522 .69196 L .61947 .69027 L F
.60603 .63798 m .60844 .68684 L .60724 .68703 L .648 .418 .556 r
F
.61017 .68656 m .61522 .69196 L .61058 .68649 L .656 .808 .956 r
F
.60952 .68667 m .60982 .68694 L .61017 .68656 L F
.60982 .68694 m .61522 .69196 L .61017 .68656 L F
.60952 .63694 m .61 .63635 L .61127 .68538 L .163 .05 .467 r
F
.6091 .68692 m .61522 .69196 L .60952 .68667 L .656 .808 .956 r
F
.60827 .6886 m .61039 .69316 L .60952 .68726 L F
.6107 .69301 m .61104 .69848 L .6159 .69727 L .656 .809 .957 r
F
.60876 .63743 m .61056 .68604 L .61001 .68637 L .402 .228 .528 r
F
.60768 .6378 m .6097 .68648 L .60892 .68676 L .539 .333 .549 r
F
.60603 .63798 m .60768 .6378 L .60892 .68676 L .648 .418 .556 r
F
.60603 .63798 m .60892 .68676 L .60844 .68684 L F
.60935 .68712 m .60827 .6886 L .60952 .68726 L .656 .808 .956 r
F
.60441 .63775 m .60603 .63798 L .60724 .68703 L .749 .498 .552 r
F
.60441 .63775 m .60724 .68703 L .60677 .68701 L F
.60087 .69914 m .60476 .70805 L .60592 .69911 L .656 .809 .957 r
F
.60476 .70805 m .60362 .71686 L .61877 .71498 L F
.60654 .7044 m .60537 .71331 L .61556 .71205 L .655 .81 .957 r
F
.5942 .70276 m .58819 .71158 L .60303 .7115 L .656 .808 .956 r
F
.59474 .7081 m .60362 .71686 L .60476 .70805 L .656 .809 .957 r
F
.60087 .69914 m .59474 .7081 L .60476 .70805 L F
.60149 .70443 m .60537 .71331 L .60654 .7044 L .655 .81 .957 r
F
.60768 .6378 m .60876 .63743 L .61001 .68637 L .539 .333 .549 r
F
.60777 .68753 m .6053 .6938 L .61039 .69316 L .656 .808 .956 r
F
.60763 .68723 m .60754 .68747 L .60777 .68753 L F
.60754 .68747 m .6053 .6938 L .60777 .68753 L F
.60341 .63735 m .60441 .63775 L .6056 .68697 L .84 .573 .536 r
F
.60746 .68729 m .60741 .68744 L .60763 .68723 L .656 .808 .956 r
F
.60741 .68744 m .6053 .6938 L .60754 .68747 L F
.60741 .68744 m .60754 .68747 L .60763 .68723 L F
.60341 .63735 m .60532 .68689 L .60459 .6867 L .84 .573 .536 r
F
.60341 .63735 m .6056 .68697 L .60532 .68689 L F
.60441 .63775 m .60677 .68701 L .6056 .68697 L .749 .498 .552 r
F
.60239 .63624 m .60275 .63684 L .60392 .68633 L .988 .718 .377 r
F
.60593 .68892 m .60029 .69382 L .6053 .6938 L .656 .808 .956 r
F
.60543 .68828 m .60029 .69382 L .60593 .68892 L F
.60498 .68693 m .6047 .68734 L .60611 .68756 L F
.6047 .68734 m .60029 .69382 L .60543 .68828 L F
.6047 .68734 m .60543 .68828 L .60611 .68756 L F
.60275 .63684 m .60341 .63735 L .60459 .6867 L .925 .648 .496 r
F
.60275 .63684 m .60459 .6867 L .6044 .6866 L F
.60275 .63684 m .6044 .6866 L .60392 .68633 L F
.60239 .63624 m .60382 .6862 L .60356 .68586 L .988 .718 .377 r
F
.60239 .63624 m .60392 .68633 L .60382 .6862 L F
.60237 .63553 m .60355 .68569 L .60354 .68527 L .712 .567 0 r
F
.60237 .63553 m .60356 .68586 L .60355 .68569 L F
.60296 .63465 m .60237 .63553 L .60354 .68527 L .07 0 .435 r
F
.60498 .68693 m .59926 .6908 L .60029 .69382 L .656 .808 .956 r
F
.60423 .6865 m .60003 .68981 L .60498 .68693 L F
.60003 .68981 m .59569 .69322 L .59926 .6908 L F
.60003 .68981 m .59926 .6908 L .60498 .68693 L F
.60651 .69457 m .60087 .69914 L .60592 .69911 L .656 .809 .957 r
F
.60672 .6929 m .6059 .69378 L .60651 .69457 L F
.6059 .69378 m .60087 .69914 L .60651 .69457 L F
.60647 .68475 m .59181 .69205 L .59569 .69322 L .656 .808 .956 r
F
.60382 .6862 m .60392 .68633 L .60404 .6914 L .988 .718 .377 r
F
.60618 .68699 m .6053 .6938 L .60754 .68705 L .656 .808 .956 r
F
.60558 .69226 m .60517 .69285 L .60672 .6929 L .656 .809 .957 r
F
.60517 .69285 m .60087 .69914 L .6059 .69378 L F
.60517 .69285 m .6059 .69378 L .60672 .6929 L F
.6044 .6866 m .60457 .6917 L .60392 .68633 L .925 .648 .496 r
F
.60517 .69285 m .59892 .69645 L .60087 .69914 L .656 .809 .957 r
F
.60558 .69226 m .605 .69263 L .60517 .69285 L F
.60647 .68475 m .5995 .68698 L .59181 .69205 L .656 .808 .956 r
F
.5995 .68698 m .58891 .69038 L .59097 .69157 L F
.5995 .68698 m .59097 .69157 L .59181 .69205 L F
.60416 .63397 m .60296 .63465 L .60415 .68449 L .438 .255 .533 r
F
.605 .69263 m .60375 .69341 L .60517 .69285 L .656 .809 .957 r
F
.60375 .69341 m .60376 .69367 L .60517 .69285 L F
.60481 .69183 m .60373 .69268 L .60558 .69226 L F
.60373 .69268 m .59892 .69645 L .60375 .69341 L F
.60373 .69268 m .60375 .69341 L .60558 .69226 L F
.60375 .69341 m .59892 .69645 L .60376 .69367 L F
.60457 .6917 m .60422 .6915 L .60392 .68633 L .925 .648 .496 r
F
.60392 .68633 m .60422 .6915 L .60404 .6914 L F
.59569 .69322 m .5942 .70276 L .60029 .69382 L .656 .808 .956 r
F
.59569 .69322 m .58504 .70159 L .5942 .70276 L F
.59892 .69645 m .59234 .69737 L .59624 .69854 L .656 .809 .957 r
F
.6044 .6866 m .60459 .6867 L .60471 .69177 L .925 .648 .496 r
F
.60373 .69268 m .60188 .69263 L .59892 .69645 L .656 .809 .957 r
F
.60481 .69183 m .60371 .69213 L .60373 .69268 L F
.60371 .69213 m .60188 .69263 L .60373 .69268 L F
.5995 .68698 m .5872 .68832 L .58891 .69038 L .656 .808 .956 r
F
.60647 .68475 m .60219 .68554 L .5995 .68698 L F
.60219 .68554 m .5872 .68832 L .5995 .68698 L F
.60471 .69177 m .60188 .69263 L .60481 .69183 L .656 .809 .957 r
F
.6042 .69149 m .60399 .69159 L .60471 .69177 L F
.60399 .69159 m .60188 .69263 L .60471 .69177 L F
.60457 .6917 m .60471 .69177 L .60483 .69686 L .925 .648 .496 r
F
.60768 .6378 m .61001 .68637 L .6097 .68648 L .539 .333 .549 r
F
.60647 .68475 m .60892 .68676 L .60952 .68667 L .656 .808 .956 r
F
.61013 .6863 m .60952 .68667 L .61058 .68649 L F
.60647 .68475 m .60952 .68667 L .61013 .6863 L F
.60876 .63743 m .60952 .63694 L .61078 .68591 L .402 .228 .528 r
F
.60827 .69256 m .60592 .69911 L .61104 .69848 L .656 .809 .957 r
F
.60876 .63743 m .61078 .68591 L .61056 .68604 L .402 .228 .528 r
F
.60952 .63694 m .61113 .68553 L .61078 .68591 L .163 .05 .467 r
F
.60647 .68475 m .61058 .68649 L .61295 .68611 L .656 .808 .956 r
F
.61058 .68649 m .61947 .69027 L .61295 .68611 L F
.61045 .69147 m .61097 .69202 L .61105 .69172 L .656 .809 .957 r
F
.60952 .63694 m .61127 .68538 L .61113 .68553 L .163 .05 .467 r
F
.61331 .68516 m .62284 .6882 L .6251 .68588 L .656 .808 .956 r
F
.60647 .68475 m .61713 .68699 L .61331 .68516 L F
.61713 .68699 m .62284 .6882 L .61331 .68516 L F
.61039 .69153 m .61095 .69211 L .61045 .69147 L .656 .809 .957 r
F
.61095 .69211 m .6159 .69727 L .61097 .69202 L F
.61095 .69211 m .61097 .69202 L .61045 .69147 L F
.61113 .68553 m .6113 .69057 L .61078 .68591 L .163 .05 .467 r
F
.60975 .69222 m .6159 .69727 L .61039 .69153 L .656 .809 .957 r
F
.6159 .69727 m .6159 .69727 L .6159 .69727 L F
.6159 .69727 m .6159 .69727 L .61039 .69153 L F
.61113 .68553 m .61127 .68538 L .6114 .69045 L .163 .05 .467 r
F
.61016 .63565 m .61114 .68427 L .61144 .68479 L .978 .72 .315 r
F
.61173 .68441 m .6251 .68588 L .62611 .68348 L .656 .808 .956 r
F
.60647 .68475 m .61331 .68516 L .61173 .68441 L F
.61331 .68516 m .6251 .68588 L .61173 .68441 L F
.60974 .63475 m .60868 .63404 L .60995 .68355 L .906 .63 .507 r
F
.60936 .69191 m .60975 .69222 L .61026 .6914 L .656 .809 .957 r
F
.60975 .69222 m .61039 .69153 L .61026 .6914 L F
.61014 .69144 m .61026 .6914 L .61024 .69138 L F
.60936 .69191 m .61026 .6914 L .61014 .69144 L F
.61056 .68604 m .61075 .69108 L .61001 .68637 L .402 .228 .528 r
F
.61075 .69108 m .61034 .69132 L .61001 .68637 L F
.60647 .68475 m .60754 .68705 L .60935 .68712 L .656 .808 .956 r
F
.60754 .68705 m .60827 .6886 L .60935 .68712 L F
.60892 .68676 m .6091 .68692 L .60952 .68667 L F
.6097 .68648 m .60991 .69152 L .60892 .68676 L .539 .333 .549 r
F
.60991 .69152 m .60932 .69173 L .60892 .68676 L F
.6097 .68648 m .61001 .68637 L .61014 .69144 L F
.6097 .68648 m .61014 .69144 L .60991 .69152 L F
.6079 .69278 m .60592 .69911 L .60827 .69256 L .656 .809 .957 r
F
.60677 .68701 m .60724 .68703 L .60736 .6921 L .749 .498 .552 r
F
.60807 .69213 m .60676 .69265 L .60809 .69218 L .656 .809 .957 r
F
.60736 .6921 m .60676 .69265 L .60807 .69213 L F
.60683 .69208 m .60682 .69219 L .60736 .6921 L F
.60682 .69219 m .60676 .69265 L .60736 .6921 L F
.60676 .69265 m .60592 .69911 L .60809 .69218 L F
.60736 .6921 m .60806 .6971 L .60749 .69719 L .648 .418 .556 r
F
.60702 .69209 m .60736 .6921 L .60749 .69719 L .749 .498 .552 r
F
.60748 .69719 m .60663 .69733 L .60744 .69753 L .655 .81 .957 r
F
.60734 .69826 m .60731 .69829 L .60732 .69842 L F
.60731 .69829 m .60149 .70443 L .60732 .69842 L F
.60732 .69842 m .60149 .70443 L .60654 .7044 L F
.60698 .69806 m .60615 .69903 L .60734 .69826 L F
.60615 .69903 m .60149 .70443 L .60636 .6993 L F
.60615 .69903 m .60636 .6993 L .60734 .69826 L F
.60677 .68701 m .60736 .6921 L .60702 .69209 L .749 .498 .552 r
F
.60459 .6867 m .60497 .69184 L .60471 .69177 L .84 .573 .536 r
F
.6044 .6866 m .60471 .69177 L .60457 .6917 L .925 .648 .496 r
F
.60382 .6862 m .60397 .6913 L .60356 .68586 L .988 .718 .377 r
F
.60397 .6913 m .60377 .69105 L .60356 .68586 L F
.60382 .6862 m .60404 .6914 L .60397 .6913 L F
.60296 .63465 m .60371 .68506 L .60415 .68449 L .07 0 .435 r
F
.60296 .63465 m .60354 .68527 L .60371 .68506 L F
.59358 .68714 m .5868 .68601 L .5872 .68832 L .656 .808 .956 r
F
.60647 .68475 m .60082 .68511 L .59358 .68714 L F
.60082 .68511 m .5868 .68601 L .59358 .68714 L F
.60532 .63368 m .60416 .63397 L .60536 .68384 L .583 .366 .552 r
F
.60399 .69159 m .60284 .69141 L .60188 .69263 L .656 .809 .957 r
F
.60532 .68689 m .60551 .69198 L .60459 .6867 L .84 .573 .536 r
F
.60551 .69198 m .60497 .69184 L .60459 .6867 L F
.60457 .6917 m .60474 .69681 L .60422 .6915 L .925 .648 .496 r
F
.60617 .69761 m .60564 .69838 L .60692 .69803 L .655 .81 .957 r
F
.60564 .69838 m .60394 .70086 L .60603 .69887 L F
.60564 .69838 m .60603 .69887 L .60692 .69803 L F
.60611 .68756 m .60543 .68828 L .60593 .68892 L .656 .808 .956 r
F
.60647 .68475 m .60498 .68693 L .60611 .68756 L F
.60532 .68689 m .6056 .68697 L .60573 .69204 L .84 .573 .536 r
F
.60394 .70086 m .60396 .70156 L .60615 .69903 L .655 .81 .957 r
F
.60603 .69887 m .60615 .69903 L .60744 .69753 L F
.60394 .70086 m .60615 .69903 L .60603 .69887 L F
.60532 .68689 m .60573 .69204 L .60551 .69198 L .84 .573 .536 r
F
.6056 .68697 m .60702 .69209 L .60573 .69204 L .749 .498 .552 r
F
.60677 .68701 m .60702 .69209 L .6056 .68697 L F
.60709 .69005 m .60305 .69134 L .60399 .69159 L .656 .809 .957 r
F
.60305 .69134 m .60284 .69141 L .60399 .69159 L F
.60355 .68569 m .60367 .69081 L .60354 .68527 L .712 .567 0 r
F
.59926 .6908 m .59569 .69322 L .59723 .69342 L .656 .808 .956 r
F
.59926 .6908 m .59723 .69342 L .60029 .69382 L F
.59181 .69205 m .58504 .70159 L .59569 .69322 L F
.59181 .69205 m .57729 .69929 L .58504 .70159 L F
.60368 .69114 m .59032 .69315 L .58943 .6957 L .656 .809 .957 r
F
.60356 .68586 m .60377 .69105 L .60368 .69093 L .988 .718 .377 r
F
.60709 .69005 m .60367 .69068 L .60368 .69114 L .656 .809 .957 r
F
.60367 .69068 m .59032 .69315 L .60368 .69114 L F
.58891 .69038 m .57729 .69929 L .59181 .69205 L .656 .808 .956 r
F
.59032 .69315 m .58771 .69364 L .58787 .69384 L .656 .809 .957 r
F
.59032 .69315 m .58787 .69384 L .58943 .6957 L F
.60647 .68475 m .60423 .6865 L .60498 .68693 L .656 .808 .956 r
F
.60082 .68511 m .58774 .68361 L .5868 .68601 L F
.60647 .68475 m .60289 .68453 L .60082 .68511 L F
.60289 .68453 m .58774 .68361 L .60082 .68511 L F
.60709 .69005 m .60481 .69183 L .60558 .69226 L .656 .809 .957 r
F
.60709 .69005 m .60558 .69226 L .60672 .6929 L F
.60551 .69198 m .60573 .69204 L .60585 .69712 L .84 .573 .536 r
F
.59624 .69854 m .59474 .7081 L .60087 .69914 L .656 .809 .957 r
F
.60394 .70086 m .59685 .70384 L .60149 .70443 L .655 .81 .957 r
F
.60564 .69838 m .60388 .699 L .60394 .70086 L F
.60534 .698 m .60388 .699 L .60564 .69838 L F
.60388 .699 m .59685 .70384 L .60394 .70086 L F
.60387 .69837 m .59781 .70309 L .60388 .69898 L F
.59781 .70309 m .59766 .70328 L .60603 .69753 L F
.60603 .69753 m .60603 .69753 L .60641 .69727 L F
.59781 .70309 m .60603 .69753 L .60603 .69753 L F
.60539 .69718 m .60387 .69837 L .60593 .69747 L F
.60387 .69837 m .60388 .69898 L .60641 .69727 L F
.60641 .69727 m .60534 .698 L .60564 .69838 L F
.60923 .6918 m .60936 .69191 L .60965 .69174 L .656 .809 .957 r
F
.60923 .6918 m .60965 .69174 L .61014 .69144 L F
.60984 .69155 m .61014 .69144 L .61024 .69138 L F
.60923 .6918 m .61014 .69144 L .60984 .69155 L F
.61522 .69196 m .62386 .69908 L .63232 .69573 L .656 .808 .956 r
F
.61241 .6913 m .62017 .69557 L .62213 .69437 L .656 .809 .957 r
F
.61107 .69088 m .61263 .69169 L .61241 .6913 L F
.61263 .69169 m .62017 .69557 L .61241 .6913 L F
.60974 .63475 m .61025 .6837 L .61102 .68407 L .906 .63 .507 r
F
.61016 .63565 m .60974 .63475 L .61102 .68407 L .978 .72 .315 r
F
.61016 .63565 m .61102 .68407 L .61114 .68427 L F
.61148 .68382 m .62611 .68348 L .62578 .68116 L .656 .808 .956 r
F
.60647 .68475 m .61408 .68426 L .61148 .68382 L F
.61408 .68426 m .62611 .68348 L .61148 .68382 L F
.61056 .68604 m .61078 .68591 L .61091 .69098 L .402 .228 .528 r
F
.61056 .68604 m .61091 .69098 L .6108 .69104 L F
.61024 .69138 m .62017 .69557 L .61107 .69088 L .656 .809 .957 r
F
.61075 .69108 m .61105 .69606 L .61094 .69613 L .402 .228 .528 r
F
.61056 .68604 m .6108 .69104 L .61075 .69108 L F
.6108 .69104 m .61105 .69606 L .61075 .69108 L F
.61947 .69027 m .63232 .69573 L .63907 .69162 L .656 .808 .956 r
F
.61522 .69196 m .63232 .69573 L .61947 .69027 L F
.61197 .69034 m .62356 .6935 L .62585 .69118 L .656 .809 .957 r
F
.60892 .68676 m .60932 .69173 L .60904 .69183 L .539 .333 .549 r
F
.60724 .68703 m .60779 .69203 L .60736 .6921 L .648 .418 .556 r
F
.6113 .69057 m .61104 .69084 L .61078 .68591 L .163 .05 .467 r
F
.60887 .69042 m .60901 .69045 L .60904 .69183 L .648 .418 .556 r
F
.60844 .68684 m .60901 .69045 L .60887 .69042 L F
.60844 .68684 m .60892 .68676 L .60901 .69045 L F
.60844 .68684 m .60904 .69183 L .60868 .69189 L F
.61078 .68591 m .61104 .69084 L .61091 .69098 L .163 .05 .467 r
F
.61001 .68637 m .61034 .69132 L .61014 .69144 L .402 .228 .528 r
F
.61127 .68538 m .61145 .6903 L .6114 .69045 L 0 0 .235 r
F
.61113 .68553 m .6114 .69045 L .6113 .69057 L .163 .05 .467 r
F
.60905 .69819 m .60654 .7044 L .61167 .70377 L .655 .81 .957 r
F
.60871 .69746 m .6082 .69909 L .60905 .69819 L F
.6082 .69909 m .60654 .7044 L .60905 .69819 L F
.60809 .69218 m .6079 .69278 L .60827 .69256 L .656 .809 .957 r
F
.60754 .68705 m .60746 .68729 L .60763 .68723 L .656 .808 .956 r
F
.60923 .6918 m .60866 .69339 L .60975 .69222 L .656 .809 .957 r
F
.60844 .68684 m .60868 .69189 L .60724 .68703 L .648 .418 .556 r
F
.60868 .69189 m .60809 .69199 L .60724 .68703 L F
.60801 .692 m .60866 .69339 L .60923 .6918 L .656 .809 .957 r
F
.60893 .69696 m .60834 .69705 L .60779 .69203 L .648 .418 .556 r
F
.60809 .69199 m .60779 .69203 L .60724 .68703 L F
.60801 .692 m .60736 .6921 L .60807 .69213 L .656 .809 .957 r
F
.60893 .69696 m .60779 .69203 L .60809 .69199 L .648 .418 .556 r
F
.60709 .69005 m .60683 .69208 L .60736 .6921 L .656 .809 .957 r
F
.60709 .69005 m .60736 .6921 L .60801 .692 L F
.60709 .69005 m .60801 .692 L .60923 .6918 L F
.60866 .69339 m .61104 .69848 L .60975 .69222 L F
.60868 .69189 m .60893 .69696 L .60809 .69199 L .648 .418 .556 r
F
.61024 .69138 m .61039 .69153 L .61045 .69147 L .656 .809 .957 r
F
.60975 .69222 m .61025 .69464 L .6107 .69301 L F
.61025 .69464 m .61104 .69848 L .6107 .69301 L F
.61075 .69108 m .61094 .69613 L .61034 .69132 L .402 .228 .528 r
F
.60925 .69714 m .61167 .70377 L .60958 .69694 L .655 .81 .957 r
F
.60855 .69714 m .60871 .69746 L .60917 .69692 L F
.60871 .69746 m .61167 .70377 L .60925 .69714 L F
.60871 .69746 m .60925 .69714 L .60917 .69692 L F
.60709 .69005 m .61107 .69088 L .61197 .69034 L .656 .809 .957 r
F
.61107 .69088 m .62356 .6935 L .61197 .69034 L F
.61107 .69088 m .62213 .69437 L .61772 .69227 L F
.61105 .69172 m .6159 .69727 L .62017 .69557 L F
.61097 .69202 m .6159 .69727 L .61105 .69172 L F
.61295 .68611 m .61947 .69027 L .62284 .6882 L .656 .808 .956 r
F
.62284 .6882 m .63907 .69162 L .64365 .68701 L F
.61947 .69027 m .63907 .69162 L .62284 .6882 L F
.61531 .68952 m .62585 .69118 L .62686 .68877 L .656 .809 .957 r
F
.60868 .63404 m .60914 .68342 L .60995 .68355 L .805 .544 .543 r
F
.60974 .63475 m .60995 .68355 L .61025 .6837 L .906 .63 .507 r
F
.60868 .63404 m .60883 .68336 L .60914 .68342 L .805 .544 .543 r
F
.60914 .68342 m .62413 .67908 L .62127 .67737 L .656 .808 .956 r
F
.60647 .68475 m .6101 .68358 L .60914 .68342 L F
.6101 .68358 m .62413 .67908 L .60914 .68342 L F
.60868 .63404 m .60758 .63371 L .60883 .68336 L .805 .544 .543 r
F
.61139 .68496 m .61153 .68999 L .61127 .68538 L 0 0 .235 r
F
.61153 .68999 m .61145 .6903 L .61127 .68538 L F
.61139 .68496 m .61144 .68479 L .61157 .68986 L F
.61139 .68496 m .61157 .68986 L .61153 .68999 L F
.61144 .68479 m .61146 .68968 L .61157 .68986 L .978 .72 .315 r
F
.60709 .69005 m .61391 .69046 L .61234 .68971 L .656 .809 .957 r
F
.60917 .69692 m .60925 .69714 L .60955 .69686 L .655 .81 .957 r
F
.60925 .69714 m .60958 .69694 L .60955 .69686 L F
.60917 .69692 m .61053 .70654 L .60942 .7069 L .539 .333 .549 r
F
.60904 .69183 m .60954 .69679 L .60917 .69692 L F
.61014 .69144 m .61053 .69637 L .61027 .69653 L .402 .228 .528 r
F
.62386 .69908 m .63239 .70611 L .64503 .70113 L .656 .808 .956 r
F
.62386 .69908 m .64503 .70113 L .63232 .69573 L F
.6159 .69727 m .62459 .7044 L .6331 .70104 L .656 .809 .957 r
F
.61332 .69772 m .61653 .70256 L .62081 .70087 L .655 .81 .957 r
F
.60932 .69173 m .60973 .69672 L .60904 .69183 L .539 .333 .549 r
F
.61034 .69132 m .61066 .69629 L .61014 .69144 L .402 .228 .528 r
F
.61027 .69653 m .61087 .69794 L .61039 .69648 L .655 .81 .957 r
F
.60962 .69691 m .61087 .69794 L .61027 .69653 L F
.61087 .69794 m .61108 .69718 L .61039 .69648 L F
.61118 .69682 m .61583 .70198 L .61332 .69772 L F
.6111 .69711 m .61583 .70198 L .61118 .69682 L F
.61052 .69662 m .61108 .69718 L .61058 .69656 L F
.61108 .69718 m .61583 .70198 L .6111 .69711 L F
.61108 .69718 m .6111 .69711 L .61058 .69656 L F
.61145 .6903 m .61162 .69524 L .6114 .69045 L 0 0 .235 r
F
.61087 .69794 m .61583 .70198 L .61108 .69718 L .655 .81 .957 r
F
.61087 .69794 m .61167 .70377 L .61653 .70256 L F
.61066 .69629 m .61053 .69637 L .61014 .69144 L .402 .228 .528 r
F
.60973 .69672 m .60954 .69679 L .60904 .69183 L .539 .333 .549 r
F
.61094 .69613 m .61066 .69629 L .61034 .69132 L .402 .228 .528 r
F
.60991 .69152 m .61012 .69658 L .60932 .69173 L .539 .333 .549 r
F
.61012 .69658 m .60973 .69672 L .60932 .69173 L F
.60779 .69203 m .60834 .69705 L .60736 .6921 L .648 .418 .556 r
F
.60834 .69705 m .60806 .6971 L .60736 .6921 L F
.6113 .69057 m .6114 .69045 L .61154 .69554 L .163 .05 .467 r
F
.61086 .69626 m .61332 .69772 L .6128 .69682 L .655 .81 .957 r
F
.61058 .69656 m .61332 .69772 L .61086 .69626 L F
.61091 .69098 m .61121 .69589 L .61105 .69606 L .163 .05 .467 r
F
.6108 .69104 m .61091 .69098 L .61105 .69606 L .402 .228 .528 r
F
.6159 .69727 m .6331 .70104 L .62017 .69557 L .656 .809 .957 r
F
.61253 .69636 m .62276 .69967 L .61831 .69757 L .655 .81 .957 r
F
.60991 .69152 m .61014 .69144 L .61027 .69653 L .539 .333 .549 r
F
.60997 .6972 m .6105 .69926 L .61087 .69794 L .655 .81 .957 r
F
.60973 .69746 m .61167 .70377 L .60997 .6972 L F
.61012 .69658 m .61027 .69653 L .61053 .70654 L .539 .333 .549 r
F
.60991 .69152 m .61027 .69653 L .61012 .69658 L F
.61139 .69613 m .6128 .69682 L .61253 .69636 L .655 .81 .957 r
F
.6085 .69703 m .60855 .69714 L .60917 .69692 L F
.60868 .69189 m .60904 .69183 L .60917 .69692 L .648 .418 .556 r
F
.60893 .69696 m .60917 .69692 L .60942 .7069 L F
.60868 .69189 m .60917 .69692 L .60893 .69696 L F
.63232 .69573 m .64503 .70113 L .65517 .69501 L .656 .808 .956 r
F
.62017 .69557 m .6331 .70104 L .63989 .69692 L .656 .809 .957 r
F
.61585 .69585 m .62421 .69879 L .6265 .69648 L .655 .81 .957 r
F
.6113 .69057 m .61154 .69554 L .61147 .69561 L .163 .05 .467 r
F
.60709 .69005 m .61024 .69138 L .61091 .69098 L .656 .809 .957 r
F
.61101 .69087 m .61091 .69098 L .61107 .69088 L F
.60709 .69005 m .61091 .69098 L .61101 .69087 L F
.61104 .69084 m .61129 .6958 L .61091 .69098 L .163 .05 .467 r
F
.61129 .6958 m .61121 .69589 L .61091 .69098 L F
.6113 .69057 m .61147 .69561 L .61104 .69084 L F
.61147 .69561 m .61129 .6958 L .61104 .69084 L F
.61217 .69574 m .61257 .69637 L .61498 .69599 L .655 .81 .957 r
F
.60772 .69536 m .61253 .69636 L .61217 .69574 L F
.61253 .69636 m .61257 .69637 L .61217 .69574 L F
.61153 .68999 m .61168 .69503 L .61145 .6903 L 0 0 .235 r
F
.62284 .6882 m .64365 .68701 L .6251 .68588 L .656 .808 .956 r
F
.61251 .68904 m .62686 .68877 L .62653 .68645 L .656 .809 .957 r
F
.61114 .68427 m .61115 .68914 L .61124 .68929 L .978 .72 .315 r
F
.61114 .68427 m .61124 .68929 L .61144 .68479 L F
.61124 .68929 m .61146 .68968 L .61144 .68479 L F
.61073 .68338 m .62578 .68116 L .62413 .67908 L .656 .808 .956 r
F
.60647 .68475 m .61373 .6834 L .61073 .68338 L F
.61373 .6834 m .62578 .68116 L .61073 .68338 L F
.60709 .69005 m .61234 .68971 L .61138 .68925 L .656 .809 .957 r
F
.60772 .69536 m .61498 .69599 L .61451 .69577 L .655 .81 .957 r
F
.60772 .69536 m .61094 .69629 L .61139 .69613 L F
.60772 .69536 m .61058 .69656 L .61086 .69626 L F
.60772 .69536 m .60949 .69681 L .61039 .69648 L F
.60855 .69714 m .60842 .69763 L .60871 .69746 L F
.60842 .69763 m .60654 .7044 L .60871 .69746 L F
.6085 .69703 m .60846 .69717 L .60855 .69714 L F
.60846 .69717 m .60845 .69723 L .60855 .69714 L F
.60845 .69723 m .60654 .7044 L .60853 .69723 L F
.60845 .69723 m .60853 .69723 L .60855 .69714 L F
.60702 .69209 m .60726 .69718 L .60573 .69204 L .749 .498 .552 r
F
.60748 .69719 m .60654 .7044 L .6085 .69703 L .655 .81 .957 r
F
.60726 .69718 m .60641 .69715 L .60573 .69204 L .749 .498 .552 r
F
.60573 .69204 m .60641 .69715 L .60585 .69712 L F
.60551 .69198 m .60585 .69712 L .60571 .69709 L .84 .573 .536 r
F
.60585 .69712 m .60539 .69718 L .60641 .69727 L .655 .81 .957 r
F
.60556 .69705 m .60548 .69711 L .60585 .69712 L F
.60548 .69711 m .60539 .69718 L .60585 .69712 L F
.60539 .69718 m .60593 .69747 L .60641 .69727 L F
.60551 .69198 m .60571 .69709 L .60497 .69184 L .84 .573 .536 r
F
.58504 .70159 m .58819 .71158 L .5942 .70276 L .656 .808 .956 r
F
.58504 .70159 m .57452 .70987 L .58819 .71158 L F
.59624 .69854 m .58552 .70694 L .59474 .7081 L .656 .809 .957 r
F
.60387 .69837 m .59294 .70267 L .59685 .70384 L .655 .81 .957 r
F
.60556 .69705 m .60385 .69781 L .60387 .69837 L F
.60385 .69781 m .59294 .70267 L .60387 .69837 L F
.58891 .69038 m .57147 .69598 L .57729 .69929 L .656 .808 .956 r
F
.59032 .69315 m .5873 .69132 L .58771 .69364 L .656 .809 .957 r
F
.60367 .69081 m .60367 .6905 L .60354 .68527 L .712 .567 0 r
F
.60354 .68527 m .60367 .6905 L .60366 .69035 L F
.60355 .68569 m .60356 .68586 L .60368 .69093 L F
.60355 .68569 m .60368 .69093 L .60367 .69081 L F
.60371 .68506 m .60354 .68527 L .60366 .69035 L .07 0 .435 r
F
.60371 .68506 m .60366 .69035 L .60378 .69019 L F
.60416 .63397 m .60415 .68449 L .60448 .68431 L .438 .255 .533 r
F
.60647 .68475 m .58996 .68127 L .58774 .68361 L .656 .808 .956 r
F
.60416 .63397 m .60448 .68431 L .60536 .68384 L .438 .255 .533 r
F
.60647 .68475 m .59332 .67916 L .58996 .68127 L .656 .808 .956 r
F
.60647 .68475 m .5976 .67744 L .59332 .67916 L F
.60448 .68431 m .60451 .68943 L .60536 .68384 L .438 .255 .533 r
F
.60709 .69005 m .60286 .69032 L .6014 .6911 L .656 .809 .957 r
F
.60571 .69709 m .60535 .697 L .60497 .69184 L .84 .573 .536 r
F
.60702 .69209 m .60749 .69719 L .60726 .69718 L .749 .498 .552 r
F
.60457 .6917 m .60483 .69686 L .60474 .69681 L .925 .648 .496 r
F
.60471 .69177 m .60518 .69695 L .60483 .69686 L .84 .573 .536 r
F
.60474 .69684 m .6014 .69849 L .60556 .69705 L .655 .81 .957 r
F
.59892 .69645 m .5972 .69867 L .60087 .69914 L .656 .809 .957 r
F
.6014 .69849 m .59294 .70267 L .60091 .69912 L .655 .81 .957 r
F
.6014 .69849 m .60091 .69912 L .60556 .69705 L F
.60399 .69626 m .60393 .69618 L .60368 .69093 L .988 .718 .377 r
F
.60397 .6913 m .60411 .69643 L .60377 .69105 L F
.60411 .69643 m .60399 .69626 L .60377 .69105 L F
.5872 .68832 m .57147 .69598 L .58891 .69038 L .656 .808 .956 r
F
.59974 .69052 m .58825 .68891 L .5873 .69132 L .656 .809 .957 r
F
.60371 .68506 m .60378 .69019 L .60415 .68449 L .07 0 .435 r
F
.60378 .69019 m .60411 .68977 L .60415 .68449 L F
.60448 .68431 m .60415 .68449 L .60427 .68957 L .438 .255 .533 r
F
.60709 .69005 m .60375 .68985 L .60286 .69032 L .656 .809 .957 r
F
.60422 .6915 m .60451 .69668 L .60404 .6914 L .925 .648 .496 r
F
.60497 .69184 m .60535 .697 L .60471 .69177 L .84 .573 .536 r
F
.60535 .697 m .60609 .70685 L .60518 .69695 L F
.60535 .697 m .60518 .69695 L .60471 .69177 L F
.60474 .69684 m .59615 .69905 L .59294 .70267 L .655 .81 .957 r
F
.60451 .69668 m .6044 .69662 L .60404 .6914 L .925 .648 .496 r
F
.60404 .6914 m .6044 .69662 L .60416 .69649 L F
.60474 .69681 m .60451 .69668 L .60422 .6915 L F
.60772 .69536 m .60383 .6966 L .60474 .69684 L .655 .81 .957 r
F
.60448 .68431 m .60427 .68957 L .60451 .68943 L .438 .255 .533 r
F
.60415 .68449 m .60411 .68977 L .60427 .68957 L .07 0 .435 r
F
.59906 .68956 m .59049 .68657 L .58825 .68891 L .656 .809 .957 r
F
.60709 .69005 m .6026 .68911 L .59906 .68956 L F
.6026 .68911 m .59049 .68657 L .59906 .68956 L F
.60647 .68475 m .60618 .68699 L .60754 .68705 L .656 .808 .956 r
F
.60646 .6336 m .60532 .63368 L .60654 .68351 L .665 .431 .556 r
F
.60646 .6336 m .60654 .68351 L .60665 .68349 L F
.60647 .68475 m .60739 .6834 L .60663 .68349 L .656 .808 .956 r
F
.60758 .63371 m .60801 .68336 L .60883 .68336 L .733 .485 .553 r
F
.60758 .63371 m .60646 .6336 L .6077 .68336 L F
.60758 .63371 m .6077 .68336 L .60801 .68336 L F
.60647 .68475 m .60823 .68336 L .6077 .68336 L .656 .808 .956 r
F
.60772 .69536 m .60474 .69684 L .60556 .69705 L .655 .81 .957 r
F
.60772 .69536 m .60556 .69705 L .60585 .69712 L F
.60649 .69715 m .60585 .69712 L .60641 .69727 L F
.60772 .69536 m .60585 .69712 L .60649 .69715 L F
.60641 .69727 m .60617 .69761 L .60744 .69753 L F
.60617 .69761 m .60692 .69803 L .60744 .69753 L F
.60673 .69716 m .60641 .69727 L .60663 .69733 L F
.60649 .69715 m .60641 .69727 L .60673 .69716 L F
.60744 .69753 m .60698 .69806 L .60734 .69826 L F
.60726 .69718 m .60773 .70707 L .60641 .69715 L .749 .498 .552 r
F
.60772 .69536 m .6085 .69703 L .60955 .69686 L .655 .81 .957 r
F
.60772 .69536 m .60748 .69719 L .6085 .69703 L F
.60641 .69715 m .60773 .70707 L .60585 .69712 L .749 .498 .552 r
F
.60726 .69718 m .60749 .69719 L .60773 .70707 L F
.60749 .69719 m .60942 .7069 L .60773 .70707 L .648 .418 .556 r
F
.60806 .6971 m .60942 .7069 L .60749 .69719 L F
.63907 .69162 m .65517 .69501 L .6621 .68814 L .656 .808 .956 r
F
.63232 .69573 m .65517 .69501 L .63907 .69162 L F
.62356 .6935 m .63989 .69692 L .64451 .6923 L .656 .809 .957 r
F
.62017 .69557 m .63989 .69692 L .62356 .6935 L F
.61295 .69502 m .6265 .69648 L .62751 .69408 L .655 .81 .957 r
F
.61162 .69524 m .61159 .69534 L .6114 .69045 L 0 0 .235 r
F
.6114 .69045 m .61159 .69534 L .61154 .69554 L F
.61168 .69503 m .61162 .69524 L .61145 .6903 L F
.60772 .69536 m .61451 .69577 L .61295 .69502 L .655 .81 .957 r
F
.61451 .69577 m .6265 .69648 L .61295 .69502 L F
.61122 .688 m .62487 .68436 L .62199 .68265 L .656 .809 .957 r
F
.60647 .68475 m .62127 .67737 L .61738 .67617 L .656 .808 .956 r
F
.60801 .68336 m .6077 .68336 L .60782 .68844 L .733 .485 .553 r
F
.6103 .68874 m .61087 .68901 L .61102 .68407 L .906 .63 .507 r
F
.61025 .6837 m .60995 .68355 L .61008 .68863 L F
.61025 .6837 m .61008 .68863 L .6103 .68874 L F
.60995 .68355 m .60978 .68858 L .61008 .68863 L .805 .544 .543 r
F
.61025 .6837 m .6103 .68874 L .61102 .68407 L .906 .63 .507 r
F
.61114 .68427 m .61102 .68407 L .61115 .68914 L .978 .72 .315 r
F
.61102 .68407 m .61087 .68901 L .61115 .68914 L .906 .63 .507 r
F
.60998 .68862 m .61204 .68846 L .61031 .68845 L .656 .809 .957 r
F
.60709 .69005 m .61102 .68879 L .60998 .68862 L F
.61102 .68879 m .61204 .68846 L .60998 .68862 L F
.60914 .68342 m .60919 .68848 L .60995 .68355 L .805 .544 .543 r
F
.60949 .69681 m .60962 .69691 L .61027 .69653 L .655 .81 .957 r
F
.60927 .69688 m .60928 .69766 L .60917 .69692 L .539 .333 .549 r
F
.60954 .69679 m .60928 .69766 L .60927 .69688 L F
.60954 .69679 m .61053 .70654 L .60928 .69766 L F
.60922 .69179 m .60923 .6918 L .60969 .69161 L .656 .809 .957 r
F
.60922 .69179 m .60969 .69161 L .61024 .69138 L F
.60709 .69005 m .60922 .69179 L .61024 .69138 L F
.60919 .68848 m .60978 .68858 L .60995 .68355 L .805 .544 .543 r
F
.60941 .68823 m .62199 .68265 L .61808 .68145 L .656 .809 .957 r
F
.60709 .69005 m .61031 .68845 L .60914 .68844 L F
.60893 .69696 m .60923 .70289 L .60849 .69703 L .648 .418 .556 r
F
.60923 .70289 m .60942 .7069 L .60849 .69703 L F
.60849 .69703 m .60942 .7069 L .60834 .69705 L F
.60834 .69705 m .60942 .7069 L .60806 .6971 L F
.60883 .68336 m .60866 .68844 L .60896 .68844 L .733 .485 .553 r
F
.60806 .68844 m .60866 .68844 L .60883 .68336 L F
.60914 .68342 m .60883 .68336 L .60896 .68844 L .805 .544 .543 r
F
.60914 .68342 m .60896 .68844 L .60919 .68848 L F
.60819 .68844 m .61808 .68145 L .6134 .68083 L .656 .809 .957 r
F
.60709 .69005 m .60914 .68844 L .60819 .68844 L F
.60914 .68844 m .61808 .68145 L .60819 .68844 L F
.60801 .68336 m .60806 .68844 L .60883 .68336 L .733 .485 .553 r
F
.6069 .68855 m .60752 .68848 L .6077 .68336 L .665 .431 .556 r
F
.60801 .68336 m .60782 .68844 L .60806 .68844 L .733 .485 .553 r
F
.6077 .68336 m .60752 .68848 L .60782 .68844 L .665 .431 .556 r
F
.60646 .6336 m .60686 .68346 L .6077 .68336 L F
.60742 .68335 m .61738 .67617 L .61273 .67555 L .656 .808 .956 r
F
.60823 .68336 m .61738 .67617 L .60742 .68335 L F
.60646 .6336 m .60665 .68349 L .60686 .68346 L .665 .431 .556 r
F
.60663 .68349 m .61273 .67555 L .60765 .67556 L .656 .808 .956 r
F
.60739 .6834 m .61273 .67555 L .60663 .68349 L F
.60709 .69005 m .6134 .68083 L .60829 .68085 L .656 .809 .957 r
F
.6251 .68588 m .64365 .68701 L .64573 .68222 L .656 .808 .956 r
F
.6251 .68588 m .64573 .68222 L .62611 .68348 L F
.60709 .69005 m .62653 .68645 L .62487 .68436 L .656 .809 .957 r
F
.60919 .68848 m .60924 .69356 L .60978 .68858 L .805 .544 .543 r
F
.61153 .68999 m .6117 .69495 L .61168 .69503 L 0 0 .235 r
F
.61274 .69493 m .61655 .69479 L .61579 .69466 L .655 .81 .957 r
F
.60772 .69536 m .61295 .69502 L .61274 .69493 L F
.61295 .69502 m .61655 .69479 L .61274 .69493 L F
.61087 .68901 m .61072 .69397 L .61115 .68914 L .906 .63 .507 r
F
.61772 .69227 m .62213 .69437 L .62356 .6935 L .656 .809 .957 r
F
.61354 .69429 m .62745 .69365 L .61731 .69359 L .655 .81 .957 r
F
.61148 .69458 m .61155 .6947 L .61157 .68986 L .978 .72 .315 r
F
.61153 .68999 m .61157 .68986 L .6117 .69495 L 0 0 .235 r
F
.61157 .68986 m .61155 .6947 L .6117 .69495 L .978 .72 .315 r
F
.60772 .69536 m .61579 .69466 L .61354 .69429 L .655 .81 .957 r
F
.61579 .69466 m .62745 .69365 L .61354 .69429 L F
.60919 .68848 m .60896 .68844 L .60909 .69354 L .805 .544 .543 r
F
.60919 .68848 m .60909 .69354 L .60924 .69356 L F
.61072 .69397 m .6109 .69406 L .61115 .68914 L .906 .63 .507 r
F
.60924 .69356 m .60962 .69363 L .60978 .68858 L .805 .544 .543 r
F
.60896 .68844 m .60868 .69354 L .60909 .69354 L .733 .485 .553 r
F
.61122 .688 m .62199 .68265 L .60941 .68823 L .656 .809 .957 r
F
.61031 .68845 m .61503 .68751 L .61122 .688 L F
.61204 .68846 m .61503 .68751 L .61031 .68845 L F
.61503 .68751 m .62487 .68436 L .61122 .688 L F
.6103 .68874 m .61035 .69379 L .61087 .68901 L .906 .63 .507 r
F
.61035 .69379 m .61072 .69397 L .61087 .68901 L F
.61138 .68925 m .61531 .68952 L .61251 .68904 L .656 .809 .957 r
F
.61234 .68971 m .61531 .68952 L .61138 .68925 L F
.61531 .68952 m .62686 .68877 L .61251 .68904 L F
.61146 .68968 m .61148 .69458 L .61157 .68986 L .978 .72 .315 r
F
.61115 .68914 m .6109 .69406 L .61128 .69423 L .906 .63 .507 r
F
.61124 .68929 m .61134 .69433 L .61146 .68968 L .978 .72 .315 r
F
.61134 .69433 m .61148 .69458 L .61146 .68968 L F
.6103 .68874 m .61008 .68863 L .61021 .69373 L .906 .63 .507 r
F
.6103 .68874 m .61021 .69373 L .61035 .69379 L F
.61124 .68929 m .61115 .68914 L .61128 .69423 L .978 .72 .315 r
F
.61124 .68929 m .61128 .69423 L .61134 .69433 L F
.61234 .68971 m .62473 .69111 L .61531 .68952 L .656 .809 .957 r
F
.61391 .69046 m .62473 .69111 L .61234 .68971 L F
.60955 .69686 m .60973 .69746 L .60997 .6972 L .655 .81 .957 r
F
.60973 .69672 m .61053 .70654 L .60954 .69679 L .539 .333 .549 r
F
.61012 .69658 m .61053 .70654 L .60973 .69672 L F
.61008 .68863 m .60981 .69366 L .61021 .69373 L .805 .544 .543 r
F
.62473 .69111 m .62585 .69118 L .61531 .68952 L .656 .809 .957 r
F
.61005 .69354 m .62264 .68798 L .61872 .68678 L .655 .81 .957 r
F
.60978 .68858 m .60962 .69363 L .61008 .68863 L .805 .544 .543 r
F
.60772 .69536 m .61082 .69383 L .60989 .69367 L .655 .81 .957 r
F
.60772 .69536 m .61005 .69354 L .60897 .69354 L F
.61138 .69355 m .62552 .68968 L .62264 .68798 L F
.60772 .69536 m .61336 .69356 L .61138 .69355 L F
.61336 .69356 m .62552 .68968 L .61138 .69355 L F
.60806 .68844 m .60782 .68844 L .60795 .69353 L .733 .485 .553 r
F
.60806 .68844 m .60795 .69353 L .6081 .69353 L F
.60962 .69363 m .60981 .69366 L .61008 .68863 L .805 .544 .543 r
F
.60866 .68844 m .60849 .69353 L .60896 .68844 L .733 .485 .553 r
F
.60849 .69353 m .60868 .69354 L .60896 .68844 L F
.60806 .68844 m .6081 .69353 L .60866 .68844 L F
.6081 .69353 m .60849 .69353 L .60866 .68844 L F
.60914 .68844 m .61122 .688 L .60941 .68823 L .656 .809 .957 r
F
.61031 .68845 m .61122 .688 L .60914 .68844 L F
.60772 .69536 m .61404 .68617 L .60892 .68619 L .655 .81 .957 r
F
.63907 .69162 m .6621 .68814 L .64365 .68701 L .656 .808 .956 r
F
.62585 .69118 m .64451 .6923 L .64661 .6875 L .656 .809 .957 r
F
.62356 .6935 m .64451 .6923 L .62585 .69118 L F
.62585 .69118 m .64661 .6875 L .62686 .68877 L F
.60772 .69536 m .62718 .69176 L .62552 .68968 L .655 .81 .957 r
F
.6081 .69353 m .60795 .69353 L .60818 .7028 L .733 .485 .553 r
F
.60962 .69363 m .60933 .7029 L .60981 .69366 L .805 .544 .543 r
F
.60989 .69367 m .61138 .69355 L .61005 .69354 L .655 .81 .957 r
F
.61082 .69383 m .61138 .69355 L .60989 .69367 L F
.61138 .69355 m .62264 .68798 L .61005 .69354 L F
.60849 .69353 m .60818 .7028 L .60868 .69354 L .733 .485 .553 r
F
.61021 .69373 m .60933 .7029 L .61045 .70322 L .805 .544 .543 r
F
.60981 .69366 m .60933 .7029 L .61021 .69373 L F
.60899 .69352 m .61872 .68678 L .61404 .68617 L .655 .81 .957 r
F
.60897 .69354 m .609 .69352 L .60899 .69352 L F
.609 .69352 m .61872 .68678 L .60899 .69352 L F
.61005 .69354 m .61872 .68678 L .60897 .69354 L F
.60909 .69354 m .60818 .7028 L .60933 .7029 L .733 .485 .553 r
F
.60868 .69354 m .60818 .7028 L .60909 .69354 L F
.60924 .69356 m .60909 .69354 L .60933 .7029 L .805 .544 .543 r
F
.61058 .69656 m .6111 .69711 L .61118 .69682 L .655 .81 .957 r
F
.6105 .69926 m .61167 .70377 L .61087 .69794 L F
.61066 .69629 m .6113 .70606 L .61053 .69637 L .402 .228 .528 r
F
.61027 .69653 m .6113 .70606 L .61053 .70654 L F
.61039 .69648 m .61052 .69662 L .61058 .69656 L .655 .81 .957 r
F
.61053 .69637 m .6113 .70606 L .61027 .69653 L .402 .228 .528 r
F
.61094 .69613 m .6113 .70606 L .61066 .69629 L F
.61072 .69397 m .61045 .70322 L .6109 .69406 L .906 .63 .507 r
F
.60924 .69356 m .60933 .7029 L .60962 .69363 L .805 .544 .543 r
F
.61579 .69466 m .62751 .69408 L .62745 .69365 L .655 .81 .957 r
F
.61655 .69479 m .62751 .69408 L .61579 .69466 L F
.61731 .69359 m .62745 .69365 L .62718 .69176 L F
.6081 .69353 m .60818 .7028 L .60849 .69353 L .733 .485 .553 r
F
.60647 .68475 m .6077 .68336 L .60739 .6834 L .656 .808 .956 r
F
.60686 .68346 m .6069 .68855 L .6077 .68336 L .665 .431 .556 r
F
.60772 .69536 m .60649 .69715 L .60673 .69716 L .655 .81 .957 r
F
.60772 .69536 m .60663 .69733 L .60748 .69719 L F
.60709 .69005 m .6042 .69149 L .60481 .69183 L .656 .809 .957 r
F
.59234 .69737 m .58552 .70694 L .59624 .69854 L F
.57729 .69929 m .57452 .70987 L .58504 .70159 L .656 .808 .956 r
F
.59234 .69737 m .57773 .70463 L .58552 .70694 L .656 .809 .957 r
F
.58943 .6957 m .57773 .70463 L .59234 .69737 L F
.59615 .69905 m .58831 .69895 L .59003 .70101 L .655 .81 .957 r
F
.60368 .69093 m .60393 .69618 L .6038 .69602 L .988 .718 .377 r
F
.60377 .69105 m .60399 .69626 L .60368 .69093 L F
.60397 .6913 m .60404 .6914 L .60416 .69649 L F
.60397 .6913 m .60416 .69649 L .60411 .69643 L F
.59892 .69645 m .59624 .69854 L .5972 .69867 L .656 .809 .957 r
F
.60772 .69536 m .60319 .6962 L .60256 .69701 L .655 .81 .957 r
F
.60383 .6966 m .60256 .69701 L .60474 .69684 L F
.60256 .69701 m .60217 .6975 L .60474 .69684 L F
.60416 .69649 m .60506 .70646 L .60439 .70596 L .925 .648 .496 r
F
.6044 .69662 m .60506 .70646 L .60416 .69649 L F
.60394 .70086 m .60149 .70443 L .60396 .70156 L .655 .81 .957 r
F
.60367 .6905 m .60379 .69574 L .60366 .69035 L .712 .567 0 r
F
.60379 .69574 m .60379 .69564 L .60366 .69035 L F
.60366 .69035 m .60379 .69564 L .60378 .69544 L F
.60367 .69081 m .60368 .69093 L .6038 .69602 L F
.60367 .69081 m .6038 .69602 L .6038 .69594 L F
.60367 .69081 m .6038 .69594 L .60367 .6905 L F
.6038 .69594 m .60379 .69574 L .60367 .6905 L F
.60772 .69536 m .60243 .6957 L .60061 .69668 L .655 .81 .957 r
F
.6049 .70366 m .60506 .70646 L .60487 .70367 L .925 .648 .496 r
F
.6049 .70366 m .60487 .70367 L .6044 .69662 L F
.60451 .69668 m .6049 .70366 L .6044 .69662 L F
.60571 .69709 m .60609 .70685 L .60535 .697 L .84 .573 .536 r
F
.60474 .69681 m .60506 .70646 L .60451 .69668 L .925 .648 .496 r
F
.60474 .69681 m .60483 .69686 L .60506 .70646 L F
.60483 .69686 m .60609 .70685 L .60506 .70646 L .84 .573 .536 r
F
.60518 .69695 m .60609 .70685 L .60483 .69686 L F
.60378 .69019 m .60386 .69534 L .60411 .68977 L .07 0 .435 r
F
.60386 .69534 m .60407 .69507 L .60411 .68977 L F
.60378 .69019 m .60366 .69035 L .60378 .69544 L F
.60378 .69019 m .60378 .69544 L .60386 .69534 L F
.60188 .69263 m .59234 .69737 L .59892 .69645 L .656 .809 .957 r
F
.60243 .6957 m .60198 .69502 L .59866 .69595 L .655 .81 .957 r
F
.60772 .69536 m .60354 .69511 L .60243 .6957 L F
.60354 .69511 m .60198 .69502 L .60243 .6957 L F
.60451 .68943 m .60517 .68909 L .60536 .68384 L .438 .255 .533 r
F
.60709 .69005 m .59387 .68446 L .59049 .68657 L .656 .809 .957 r
F
.60532 .63368 m .60569 .68374 L .60654 .68351 L .583 .366 .552 r
F
.60532 .63368 m .60536 .68384 L .60569 .68374 L F
.60647 .68475 m .60248 .67621 L .5976 .67744 L .656 .808 .956 r
F
.60569 .68374 m .60536 .68384 L .60549 .68891 L .583 .366 .552 r
F
.60569 .68374 m .60549 .68891 L .60573 .68885 L F
.60536 .68384 m .60517 .68909 L .60549 .68891 L .438 .255 .533 r
F
.60709 .69005 m .59817 .68273 L .59387 .68446 L .656 .809 .957 r
F
.60517 .68909 m .60497 .69435 L .60549 .68891 L .438 .255 .533 r
F
.60427 .68957 m .60417 .69494 L .60439 .69466 L .07 0 .435 r
F
.6014 .6911 m .59974 .69052 L .59032 .69315 L .656 .809 .957 r
F
.59974 .69052 m .5873 .69132 L .59032 .69315 L F
.60188 .69263 m .59783 .69301 L .59234 .69737 L F
.59783 .69301 m .58943 .6957 L .59106 .69664 L F
.59783 .69301 m .59106 .69664 L .59234 .69737 L F
.59814 .69479 m .59109 .6919 L .58885 .69424 L .655 .81 .957 r
F
.60411 .68977 m .60407 .69507 L .60427 .68957 L .07 0 .435 r
F
.60407 .69507 m .60417 .69494 L .60427 .68957 L F
.60647 .68475 m .60663 .68349 L .60593 .68359 L .656 .808 .956 r
F
.60569 .68374 m .60573 .68885 L .60654 .68351 L .583 .366 .552 r
F
.60573 .68885 m .60635 .68867 L .60654 .68351 L F
.60654 .68351 m .60635 .68867 L .60667 .68858 L F
.60709 .69005 m .60309 .68149 L .59817 .68273 L .656 .809 .957 r
F
.60739 .6834 m .6077 .68336 L .60742 .68335 L .656 .808 .956 r
F
.60686 .68346 m .60667 .68858 L .6069 .68855 L .665 .431 .556 r
F
.60665 .68349 m .60667 .68858 L .60686 .68346 L F
.60593 .68359 m .60765 .67556 L .60248 .67621 L .656 .808 .956 r
F
.60663 .68349 m .60765 .67556 L .60593 .68359 L F
.60665 .68349 m .60654 .68351 L .60667 .68858 L .665 .431 .556 r
F
.60709 .69005 m .60829 .68085 L .60309 .68149 L .656 .809 .957 r
F
.60635 .68867 m .60617 .69385 L .60667 .68858 L .583 .366 .552 r
F
.60772 .69536 m .60373 .69453 L .60198 .69502 L .655 .81 .957 r
F
.60585 .69712 m .60773 .70707 L .60609 .70685 L .749 .498 .552 r
F
.60571 .69709 m .60585 .69712 L .60609 .70685 L .84 .573 .536 r
F
.60497 .69435 m .60517 .69424 L .60549 .68891 L .438 .255 .533 r
F
.60451 .68943 m .60455 .69458 L .60517 .68909 L F
.60455 .69458 m .60497 .69435 L .60517 .68909 L F
.60451 .68943 m .60427 .68957 L .60439 .69466 L F
.60451 .68943 m .60439 .69466 L .60455 .69458 L F
.60284 .69141 m .59783 .69301 L .60188 .69263 L .656 .809 .957 r
F
.60373 .69453 m .59448 .6898 L .59109 .6919 L .655 .81 .957 r
F
.60772 .69536 m .60494 .69419 L .60373 .69453 L F
.60494 .69419 m .59448 .6898 L .60373 .69453 L F
.60573 .68885 m .60549 .68891 L .60561 .69401 L .583 .366 .552 r
F
.60573 .68885 m .60561 .69401 L .60576 .69397 L F
.60549 .68891 m .60517 .69424 L .60561 .69401 L .438 .255 .533 r
F
.60573 .68885 m .60576 .69397 L .60635 .68867 L .583 .366 .552 r
F
.60576 .69397 m .60617 .69385 L .60635 .68867 L F
.60286 .69032 m .60244 .68977 L .59974 .69052 L .656 .809 .957 r
F
.60244 .68977 m .58825 .68891 L .59974 .69052 L F
.60286 .69032 m .59974 .69052 L .6014 .6911 L F
.60772 .69536 m .59879 .68807 L .59448 .6898 L .655 .81 .957 r
F
.60576 .69397 m .60561 .69401 L .60583 .70316 L .583 .366 .552 r
F
.60617 .69385 m .60637 .6938 L .60667 .68858 L F
.6069 .68855 m .60667 .68858 L .60679 .69368 L .665 .431 .556 r
F
.6069 .68855 m .60679 .69368 L .60694 .69366 L F
.60667 .68858 m .60637 .6938 L .60679 .69368 L .583 .366 .552 r
F
.60375 .68985 m .60244 .68977 L .60286 .69032 L .656 .809 .957 r
F
.60772 .69536 m .60371 .68684 L .59879 .68807 L .655 .81 .957 r
F
.60617 .69385 m .60583 .70316 L .60637 .6938 L .583 .366 .552 r
F
.60198 .69502 m .60237 .69425 L .59814 .69479 L .655 .81 .957 r
F
.60373 .69453 m .60237 .69425 L .60198 .69502 L F
.60237 .69425 m .59109 .6919 L .59814 .69479 L F
.6069 .68855 m .60694 .69366 L .60752 .68848 L .665 .431 .556 r
F
.60694 .69366 m .60734 .69361 L .60752 .68848 L F
.60782 .68844 m .60734 .69361 L .60795 .69353 L F
.60752 .68848 m .60734 .69361 L .60782 .68844 L F
.60772 .69536 m .60892 .68619 L .60371 .68684 L .655 .81 .957 r
F
.60694 .69366 m .60679 .69368 L .60702 .70287 L .665 .431 .556 r
F
.60497 .69435 m .60461 .70382 L .60517 .69424 L .438 .255 .533 r
F
.60679 .69368 m .60583 .70316 L .60702 .70287 L .583 .366 .552 r
F
.60637 .6938 m .60583 .70316 L .60679 .69368 L F
.57729 .69929 m .56291 .70645 L .57452 .70987 L .656 .808 .956 r
F
.57147 .69598 m .56291 .70645 L .57729 .69929 L F
.58943 .6957 m .57187 .70132 L .57773 .70463 L .656 .809 .957 r
F
.59866 .69595 m .59814 .69479 L .5879 .69664 L .655 .81 .957 r
F
.60198 .69502 m .59814 .69479 L .59866 .69595 L F
.58771 .69364 m .57187 .70132 L .58943 .6957 L .656 .809 .957 r
F
.59814 .69479 m .58885 .69424 L .58812 .69608 L .655 .81 .957 r
F
.59814 .69479 m .58812 .69608 L .5879 .69664 L F
.60694 .69366 m .60702 .70287 L .60734 .69361 L .665 .431 .556 r
F
.60561 .69401 m .60461 .70382 L .60583 .70316 L .438 .255 .533 r
F
.60517 .69424 m .60461 .70382 L .60561 .69401 L F
.60061 .69668 m .59866 .69595 L .58831 .69895 L .655 .81 .957 r
F
.60243 .6957 m .59866 .69595 L .60061 .69668 L F
.59866 .69595 m .5879 .69664 L .58829 .69884 L F
.59866 .69595 m .58829 .69884 L .58831 .69895 L F
.60576 .69397 m .60583 .70316 L .60617 .69385 L .583 .366 .552 r
F
.6038 .69602 m .60439 .70596 L .60402 .70537 L .988 .718 .377 r
F
.60393 .69618 m .60439 .70596 L .6038 .69602 L F
.60399 .69626 m .60439 .70596 L .60393 .69618 L F
.60411 .69643 m .60439 .70596 L .60399 .69626 L F
.60411 .69643 m .60416 .69649 L .60439 .70596 L F
.60439 .69466 m .604 .70468 L .60461 .70382 L .07 0 .435 r
F
.60417 .69494 m .604 .70468 L .60439 .69466 L F
.60256 .69701 m .60061 .69668 L .59615 .69905 L .655 .81 .957 r
F
.60319 .6962 m .60061 .69668 L .60256 .69701 L F
.60061 .69668 m .58831 .69895 L .59615 .69905 L F
.60455 .69458 m .60461 .70382 L .60497 .69435 L .438 .255 .533 r
F
.61035 .69379 m .61045 .70322 L .61072 .69397 L .906 .63 .507 r
F
.60795 .69353 m .60702 .70287 L .60818 .7028 L .665 .431 .556 r
F
.60734 .69361 m .60702 .70287 L .60795 .69353 L F
.60407 .69507 m .604 .70468 L .60417 .69494 L .07 0 .435 r
F
.60256 .69701 m .59615 .69905 L .60217 .6975 L .655 .81 .957 r
F
.59615 .69905 m .59003 .70101 L .59122 .70168 L F
.59615 .69905 m .59122 .70168 L .59294 .70267 L F
.60455 .69458 m .60439 .69466 L .60461 .70382 L .438 .255 .533 r
F
.60386 .69534 m .604 .70468 L .60407 .69507 L .07 0 .435 r
F
.60379 .69574 m .60402 .70537 L .60379 .69564 L .712 .567 0 r
F
.61094 .69629 m .6128 .69682 L .61139 .69613 L .655 .81 .957 r
F
.61147 .69561 m .61154 .69554 L .61179 .70548 L .163 .05 .467 r
F
.61129 .6958 m .61179 .70548 L .61121 .69589 L F
.61147 .69561 m .61179 .70548 L .61129 .6958 L F
.61105 .69606 m .61179 .70548 L .6113 .70606 L F
.61121 .69589 m .61179 .70548 L .61105 .69606 L F
.61148 .69458 m .61153 .70392 L .61155 .6947 L .978 .72 .315 r
F
.61094 .69613 m .61105 .69606 L .6113 .70606 L .402 .228 .528 r
F
.61128 .69423 m .61045 .70322 L .61153 .70392 L .906 .63 .507 r
F
.6109 .69406 m .61045 .70322 L .61128 .69423 L F
.61451 .69577 m .61498 .69599 L .61585 .69585 L .655 .81 .957 r
F
.61257 .69637 m .62421 .69879 L .61585 .69585 L F
.6128 .69682 m .62276 .69967 L .61253 .69636 L F
.61162 .69524 m .61196 .7048 L .61159 .69534 L 0 0 .235 r
F
.61154 .69554 m .61196 .7048 L .61179 .70548 L F
.61159 .69534 m .61196 .7048 L .61154 .69554 L F
.61168 .69503 m .6117 .69495 L .61196 .7048 L F
.61168 .69503 m .61196 .7048 L .61162 .69524 L F
.6117 .69495 m .61153 .70392 L .61196 .7048 L .978 .72 .315 r
F
.61155 .6947 m .61153 .70392 L .6117 .69495 L F
.61134 .69433 m .61153 .70392 L .61148 .69458 L F
.6128 .69682 m .62081 .70087 L .62276 .69967 L .655 .81 .957 r
F
.61332 .69772 m .62081 .70087 L .6128 .69682 L F
.61831 .69757 m .62276 .69967 L .62421 .69879 L F
.61035 .69379 m .61021 .69373 L .61045 .70322 L .906 .63 .507 r
F
.61583 .70198 m .61653 .70256 L .61332 .69772 L .655 .81 .957 r
F
.61134 .69433 m .61128 .69423 L .61153 .70392 L .978 .72 .315 r
F
.60378 .69544 m .60402 .70537 L .604 .70468 L .712 .567 0 r
F
.60379 .69564 m .60402 .70537 L .60378 .69544 L F
.59781 .70309 m .59685 .70384 L .59766 .70328 L .655 .81 .957 r
F
.6038 .69594 m .6038 .69602 L .60402 .70537 L .712 .567 0 r
F
.6038 .69594 m .60402 .70537 L .60379 .69574 L F
.60386 .69534 m .60378 .69544 L .604 .70468 L .07 0 .435 r
F
.65732 .48221 m .65746 .47429 L .63466 .46738 L .793 .542 .558 r
F
0 g
.65746 .47429 m
.67634 .48429 L
s
.72254 .47319 m .69584 .46219 L .68407 .47543 L .644 .737 .917 r
F
.69579 .47014 m .68407 .47543 L .684 .48335 L .181 .055 .462 r
F
.69579 .47014 m .69584 .46219 L .68407 .47543 L F
0 g
.6797 .48711 m
.68407 .47543 L
s
.76566 .59342 m .76195 .60732 L .77163 .59458 L .653 .784 .944 r
F
.76566 .59342 m .75009 .60504 L .76195 .60732 L F
.53141 .34401 m .5332 .40636 L .53153 .40656 L .641 .401 .54 r
F
.53141 .34401 m .53304 .3438 L .5332 .40636 L F
.52979 .34374 m .53141 .34401 L .53153 .40656 L .751 .491 .539 r
F
0 g
.53141 .34401 m
.53141 .34401 L
s
.32882 .47955 m .31122 .46223 L .29824 .4676 L .642 .738 .919 r
F
.3365 .47808 m .31122 .46223 L .32882 .47955 L F
.35466 .59442 m .36843 .60538 L .37899 .601 L .654 .782 .942 r
F
.34843 .59588 m .36843 .60538 L .35466 .59442 L F
.53304 .3438 m .53428 .40592 L .5332 .40636 L .517 .303 .528 r
F
.53304 .3438 m .5341 .34336 L .53428 .40592 L F
0 g
.53141 .34401 m
.53304 .3438 L
s
.36121 .48125 m .36065 .461 L .35328 .47896 L .642 .738 .919 r
F
.36121 .48125 m .37665 .46567 L .36065 .461 L F
.52979 .34374 m .53153 .40656 L .52988 .4063 L .751 .491 .539 r
F
.52877 .34326 m .52979 .34374 L .52988 .4063 L .845 .571 .524 r
F
0 g
.52979 .34374 m
.53141 .34401 L
s
.45022 .7283 m .44011 .71965 L .44016 .72837 L .656 .808 .956 r
F
.45022 .7283 m .45531 .71956 L .44011 .71965 L F
.73439 .45808 m .69628 .45443 L .72279 .4654 L .644 .736 .916 r
F
.62782 .59358 m .64364 .58128 L .62408 .59099 L .654 .782 .942 r
F
.62782 .59358 m .65107 .58653 L .64364 .58128 L F
.87186 .4853 m .86528 .46316 L .86563 .4711 L .973 .711 .293 r
F
.87223 .49325 m .87186 .4853 L .86563 .4711 L F
0 g
.87165 .49192 m
.87167 .49135 L
s
.42018 .84195 m .41925 .84829 L .42561 .844 L .592 .769 .964 r
F
.42018 .84195 m .41111 .84524 L .41925 .84829 L F
0 g
.41925 .84829 m
.42865 .85046 L
s
.55625 .60776 m .52802 .61511 L .55394 .61447 L .653 .784 .944 r
F
.58104 .61049 m .55625 .60776 L .55394 .61447 L F
.77864 .46833 m .78247 .44926 L .76533 .44969 L .644 .736 .916 r
F
.40517 .83702 m .41188 .83631 L .41149 .84077 L .905 .67 .573 r
F
.40517 .83702 m .40556 .83255 L .41188 .83631 L F
0 g
.41188 .83631 m
.41769 .83851 L
s
.4581 .85062 m .46651 .84406 L .46618 .84853 L .524 .33 .56 r
F
.45162 .84556 m .4581 .85062 L .46618 .84853 L .592 .769 .964 r
F
.44536 .84626 m .4581 .85062 L .45162 .84556 L F
0 g
.44874 .85167 m
.4581 .85062 L
s
.41684 .83046 m .41201 .83626 L .42102 .83297 L .594 .768 .963 r
F
.41684 .83046 m .40573 .83252 L .41201 .83626 L F
.8345 .47127 m .85225 .45056 L .82604 .4629 L .644 .736 .916 r
F
.8345 .47127 m .86482 .46328 L .85225 .45056 L F
.5341 .34336 m .53503 .40535 L .53428 .40592 L .358 .18 .498 r
F
.5341 .34336 m .53483 .34278 L .53503 .40535 L F
0 g
.53304 .3438 m
.5341 .34336 L
s
.46651 .84406 m .46683 .8396 L .47307 .83659 L .389 .218 .525 r
F
0 g
.45877 .8417 m
.46683 .8396 L
s
.52877 .34326 m .52988 .4063 L .52884 .40583 L .845 .571 .524 r
F
.52809 .34266 m .52877 .34326 L .52884 .40583 L .929 .648 .487 r
F
0 g
.52877 .34326 m
.52979 .34374 L
s
.58353 .60096 m .55587 .6014 L .58062 .60415 L .654 .783 .943 r
F
.32143 .49011 m .29726 .47556 L .28767 .48286 L .641 .739 .92 r
F
.32792 .48748 m .29726 .47556 L .32143 .49011 L F
.48139 .72463 m .46896 .71602 L .4694 .72126 L .847 .593 .554 r
F
.48184 .72987 m .48139 .72463 L .4694 .72126 L F
0 g
.48139 .72463 m
.49045 .72939 L
s
.36726 .49252 m .37585 .47365 L .36038 .48919 L .641 .739 .92 r
F
.36726 .49252 m .38966 .48042 L .37585 .47365 L F
.53483 .34278 m .53549 .40467 L .53503 .40535 L .08 0 .418 r
F
.53483 .34278 m .53529 .34209 L .53549 .40467 L F
0 g
.5341 .34336 m
.53483 .34278 L
s
.52809 .34266 m .52884 .40583 L .52814 .40523 L .929 .648 .487 r
F
.5277 .34195 m .52809 .34266 L .52814 .40523 L .988 .719 .384 r
F
0 g
.52809 .34266 m
.52877 .34326 L
s
.4301 .72962 m .42491 .72153 L .41081 .72508 L .656 .808 .956 r
F
.44016 .72837 m .42491 .72153 L .4301 .72962 L F
.55625 .60776 m .5313 .60501 L .52802 .61511 L .653 .784 .944 r
F
0 g
.52802 .61511 m
.53005 .62493 L
s
.84294 .59343 m .85261 .57741 L .85348 .58375 L .31 .202 .566 r
F
.84379 .59976 m .84294 .59343 L .85348 .58375 L F
.82242 .58742 m .84294 .59343 L .85348 .58375 L .653 .783 .943 r
F
.81273 .59305 m .84294 .59343 L .82242 .58742 L F
0 g
.83216 .59962 m
.84294 .59343 L
s
.42112 .7372 m .41117 .73035 L .39916 .73528 L .656 .809 .957 r
F
.43048 .73486 m .41117 .73035 L .42112 .7372 L F
.44016 .72837 m .44011 .71965 L .42491 .72153 L .656 .808 .956 r
F
.57493 .71523 m .5881 .71172 L .58869 .71694 L .789 .546 .569 r
F
.57493 .71523 m .57436 .70999 L .5881 .71172 L F
0 g
.5881 .71172 m
.59835 .71166 L
s
.26532 .58901 m .27448 .59198 L .2744 .5983 L .973 .719 .491 r
F
.26532 .58901 m .26541 .58266 L .27448 .59198 L F
0 g
.27448 .59198 m
.28145 .59602 L
s
.53529 .34209 m .53562 .40385 L .53549 .40467 L 0 0 .15 r
F
.53529 .34209 m .53541 .34127 L .53562 .40385 L F
0 g
.53483 .34278 m
.53529 .34209 L
s
.60423 .72209 m .60362 .71686 L .61877 .71498 L .677 .464 .591 r
F
.58928 .72218 m .60362 .71686 L .60423 .72209 L .732 .505 .583 r
F
.58928 .72218 m .58869 .71694 L .60362 .71686 L F
.59474 .7081 m .58869 .71694 L .60362 .71686 L .656 .809 .957 r
F
.76208 .47783 m .74886 .46047 L .73423 .46586 L .644 .737 .917 r
F
.77027 .47635 m .74886 .46047 L .76208 .47783 L F
.29063 .57858 m .26579 .5826 L .27481 .59187 L .656 .781 .94 r
F
.5277 .34195 m .52814 .40523 L .52775 .40453 L .988 .719 .384 r
F
.52765 .34113 m .5277 .34195 L .52775 .40453 L .781 .623 .061 r
F
0 g
.5277 .34195 m
.52809 .34266 L
s
.79169 .59279 m .80173 .60378 L .81353 .59939 L .653 .784 .944 r
F
.63109 .60926 m .65237 .59916 L .62893 .60621 L F
.63109 .60926 m .6566 .60531 L .65237 .59916 L F
.58321 .59466 m .56143 .58868 L .55574 .59509 L .654 .782 .942 r
F
.58759 .59187 m .56143 .58868 L .58321 .59466 L F
.79451 .47953 m .7994 .45924 L .78708 .47723 L .644 .737 .917 r
F
.79451 .47953 m .81439 .46392 L .7994 .45924 L F
.32279 .59309 m .31637 .60664 L .32842 .59505 L .654 .782 .942 r
F
.32279 .59309 m .30515 .60279 L .31637 .60664 L F
.3365 .47808 m .32671 .45922 L .31122 .46223 L .642 .738 .919 r
F
.34485 .47788 m .32671 .45922 L .3365 .47808 L F
.28767 .48286 m .25839 .47189 L .2503 .48507 L .641 .739 .92 r
F
0 g
.24882 .49935 m
.2503 .48507 L
s
.35328 .47896 m .34359 .45879 L .34485 .47788 L .642 .738 .919 r
F
.35328 .47896 m .36065 .461 L .34359 .45879 L F
.61939 .72021 m .61877 .71498 L .63316 .71144 L .617 .421 .595 r
F
.60423 .72209 m .61877 .71498 L .61939 .72021 L .677 .464 .591 r
F
0 g
.60362 .71686 m
.61877 .71498 L
s
.40478 .84149 m .41149 .84077 L .41111 .84524 L .905 .67 .573 r
F
.40478 .84149 m .40517 .83702 L .41149 .84077 L F
.41635 .83496 m .41149 .84077 L .42055 .83747 L .593 .769 .963 r
F
.41635 .83496 m .40517 .83702 L .41149 .84077 L F
0 g
.41149 .84077 m
.41735 .84297 L
s
.48385 .4593 m .48062 .48173 L .4973 .46613 L .642 .738 .918 r
F
.48385 .4593 m .46052 .47165 L .48062 .48173 L F
0 g
.48062 .48173 m
.5039 .48858 L
s
.65606 .59897 m .67545 .58566 L .65184 .5928 L .654 .783 .943 r
F
.65606 .59897 m .68163 .59499 L .67545 .58566 L F
.45063 .73355 m .44051 .72492 L .44056 .73362 L .656 .809 .957 r
F
.45063 .73355 m .45573 .72482 L .44051 .72492 L F
.53541 .34127 m .53515 .4028 L .53562 .40385 L .983 .725 .332 r
F
.53541 .34127 m .53495 .3402 L .53515 .4028 L F
.40986 .60137 m .4173 .58538 L .41745 .59173 L .129 .038 .474 r
F
.38703 .5954 m .40986 .60137 L .41745 .59173 L .654 .782 .942 r
F
.37899 .601 m .40986 .60137 L .38703 .5954 L F
0 g
.39774 .60968 m
.40986 .60137 L
s
.46651 .84406 m .47307 .83659 L .47275 .84106 L .389 .218 .525 r
F
.46618 .84853 m .46651 .84406 L .47275 .84106 L F
.45735 .83967 m .46651 .84406 L .47275 .84106 L .593 .769 .963 r
F
.45196 .84108 m .46651 .84406 L .45735 .83967 L F
0 g
.45844 .84616 m
.46651 .84406 L
s
.52765 .34113 m .52775 .40453 L .52769 .40372 L .781 .623 .061 r
F
.5282 .34008 m .52765 .34113 L .52769 .40372 L 0 0 .377 r
F
.43824 .49496 m .429 .47285 L .42832 .48083 L .983 .743 .493 r
F
0 g
.43824 .49496 m
.44164 .50949 L
s
.75489 .48839 m .73428 .47382 L .72256 .48113 L .643 .738 .918 r
F
.76219 .48576 m .73428 .47382 L .75489 .48839 L F
.29824 .4676 m .25947 .46394 L .28867 .47492 L .642 .738 .919 r
F
.80079 .49081 m .81463 .4719 L .7947 .48747 L .643 .738 .918 r
F
.80079 .49081 m .82683 .47868 L .81463 .4719 L F
.34485 .47788 m .34359 .45879 L .32671 .45922 L .642 .738 .919 r
F
.68163 .59499 m .68104 .58866 L .67487 .57931 L .982 .7 .33 r
F
0 g
.6816 .59494 m
.6816 .59496 L
s
.40103 .48083 m .41316 .46011 L .39043 .47245 L .642 .738 .919 r
F
.40103 .48083 m .429 .47285 L .41316 .46011 L F
.41081 .72508 m .39846 .72477 L .39881 .73002 L .529 .352 .586 r
F
.41081 .72508 m .41044 .71982 L .39846 .72477 L F
0 g
.38943 .73075 m
.39846 .72477 L
s
.63316 .71144 m .63252 .70621 L .64522 .70121 L .543 .369 .595 r
F
0 g
.62812 .7073 m
.63252 .70621 L
s
.62843 .59987 m .64436 .58754 L .62467 .59727 L .654 .783 .943 r
F
.62843 .59987 m .65184 .5928 L .64436 .58754 L F
.56143 .58868 m .531 .59233 L .55574 .59509 L .654 .782 .942 r
F
.48184 .72987 m .4694 .72126 L .46984 .72652 L .847 .593 .554 r
F
0 g
.48184 .72987 m
.49091 .73462 L
s
.70272 .58738 m .70808 .59036 L .70871 .59669 L .979 .696 .314 r
F
.70272 .58738 m .7021 .58102 L .70808 .59036 L F
0 g
.70808 .59036 m
.71444 .59498 L
s
.53495 .3402 m .53404 .40198 L .53515 .4028 L .911 .629 .497 r
F
.53495 .3402 m .53386 .33937 L .53404 .40198 L F
0 g
.53495 .3402 m
.53541 .34127 L
s
.53495 .3402 m
.53495 .3402 L
s
.43048 .73486 m .42529 .72681 L .41117 .73035 L .656 .809 .957 r
F
.44056 .73362 m .42529 .72681 L .43048 .73486 L F
.72821 .57694 m .70844 .59026 L .73208 .58318 L .654 .782 .942 r
F
.72821 .57694 m .70249 .58096 L .70844 .59026 L F
.5282 .34008 m .52769 .40372 L .52825 .40268 L 0 0 .377 r
F
.52936 .33929 m .5282 .34008 L .52825 .40268 L .4 .211 .506 r
F
0 g
.52765 .34113 m
.5282 .34008 L
s
.5282 .34008 m
.5282 .34008 L
s
.58395 .60731 m .55625 .60776 L .58104 .61049 L .653 .784 .944 r
F
.76075 .59146 m .75009 .60504 L .76566 .59342 L F
.76075 .59146 m .74028 .60118 L .75009 .60504 L F
.44557 .45095 m .46171 .45582 L .46112 .46371 L .92 .668 .54 r
F
.44557 .45095 m .4462 .44303 L .46171 .45582 L F
0 g
.46171 .45582 m
.46901 .45951 L
s
.44056 .73362 m .44051 .72492 L .42529 .72681 L .656 .809 .957 r
F
.62408 .59099 m .63346 .57734 L .619 .58904 L .654 .782 .942 r
F
.62408 .59099 m .64364 .58128 L .63346 .57734 L F
.77027 .47635 m .7654 .45745 L .74886 .46047 L .644 .737 .917 r
F
.77881 .47615 m .7654 .45745 L .77027 .47635 L F
.65732 .48221 m .63466 .46738 L .63447 .47531 L .793 .542 .558 r
F
0 g
.63466 .46738 m
.65746 .47429 L
s
.65719 .49017 m .65732 .48221 L .63447 .47531 L .793 .542 .558 r
F
0 g
.65732 .48221 m
.67625 .49219 L
s
.57551 .72048 m .58869 .71694 L .58928 .72218 L .789 .546 .569 r
F
.57551 .72048 m .57493 .71523 L .58869 .71694 L F
.58552 .70694 m .58869 .71694 L .59474 .7081 L .656 .809 .957 r
F
.58552 .70694 m .57493 .71523 L .58869 .71694 L F
0 g
.58869 .71694 m
.60362 .71686 L
s
.72256 .48113 m .69579 .47014 L .684 .48335 L .643 .738 .918 r
F
0 g
.67962 .49501 m
.684 .48335 L
s
.78708 .47723 m .78267 .45703 L .77881 .47615 L .644 .737 .917 r
F
.78708 .47723 m .7994 .45924 L .78267 .45703 L F
.47494 .43467 m .46206 .45563 L .48518 .44327 L .644 .737 .916 r
F
.47494 .43467 m .44663 .4429 L .46206 .45563 L F
.60537 .71331 m .60423 .72209 L .61939 .72021 L .655 .81 .957 r
F
.59534 .71337 m .60423 .72209 L .60537 .71331 L F
.59534 .71337 m .58928 .72218 L .60423 .72209 L F
.32792 .48748 m .31026 .47021 L .29726 .47556 L .641 .739 .92 r
F
.33561 .48602 m .31026 .47021 L .32792 .48748 L F
.53386 .33937 m .53291 .4016 L .53404 .40198 L .81 .54 .53 r
F
.53386 .33937 m .53276 .33898 L .53291 .4016 L F
0 g
.53386 .33937 m
.53495 .3402 L
s
.84379 .59976 m .85348 .58375 L .85435 .5901 L .31 .202 .566 r
F
.82324 .59377 m .84379 .59976 L .85435 .5901 L .653 .784 .944 r
F
.81353 .59939 m .84379 .59976 L .82324 .59377 L F
0 g
.82921 .60809 m
.84379 .59976 L
s
.36038 .48919 m .35981 .46899 L .35243 .4869 L .641 .739 .92 r
F
.36038 .48919 m .37585 .47365 L .35981 .46899 L F
.41597 .83944 m .41111 .84524 L .42018 .84195 L .592 .769 .964 r
F
.41597 .83944 m .40478 .84149 L .41111 .84524 L F
0 g
.41111 .84524 m
.41925 .84829 L
s
.52936 .33929 m .52825 .40268 L .52944 .4019 L .4 .211 .506 r
F
.5305 .33894 m .52936 .33929 L .52944 .4019 L .567 .342 .533 r
F
0 g
.5282 .34008 m
.52936 .33929 L
s
.87223 .49325 m .86563 .4711 L .86599 .47909 L .973 .711 .293 r
F
0 g
.87175 .50781 m
.87223 .49325 L
s
.73423 .46586 m .69584 .46219 L .72254 .47319 L .644 .737 .917 r
F
.46618 .84853 m .47275 .84106 L .47243 .84554 L .389 .218 .525 r
F
.45702 .84415 m .46618 .84853 L .47243 .84554 L .592 .769 .964 r
F
.45162 .84556 m .46618 .84853 L .45702 .84415 L F
0 g
.4581 .85062 m
.46618 .84853 L
s
.61939 .72021 m .63316 .71144 L .63381 .71667 L .617 .421 .595 r
F
.61556 .71205 m .61939 .72021 L .63381 .71667 L .655 .81 .957 r
F
.60537 .71331 m .61939 .72021 L .61556 .71205 L F
0 g
.60423 .72209 m
.61939 .72021 L
s
.26522 .59539 m .2744 .5983 L .27432 .60465 L .973 .719 .491 r
F
.26522 .59539 m .26532 .58901 L .2744 .5983 L F
.29032 .58498 m .2744 .5983 L .29629 .59122 L .655 .781 .941 r
F
.29032 .58498 m .26532 .58901 L .2744 .5983 L F
0 g
.2744 .5983 m
.28142 .60236 L
s
.53276 .33898 m .53176 .40147 L .53291 .4016 L .734 .477 .539 r
F
.53276 .33898 m .53163 .33885 L .53176 .40147 L F
0 g
.53276 .33898 m
.53386 .33937 L
s
.77881 .47615 m .78267 .45703 L .7654 .45745 L .644 .737 .917 r
F
.5305 .33894 m .52944 .4019 L .53061 .40156 L .567 .342 .533 r
F
.53163 .33885 m .5305 .33894 L .53061 .40156 L .66 .416 .54 r
F
0 g
.52936 .33929 m
.5305 .33894 L
s
.53163 .33885 m .53061 .40156 L .53176 .40147 L .66 .416 .54 r
F
0 g
.53163 .33885 m
.53276 .33898 L
s
.5305 .33894 m
.53163 .33885 L
s
.83508 .47911 m .85298 .45834 L .82656 .47071 L .644 .737 .917 r
F
.83508 .47911 m .86563 .4711 L .85298 .45834 L F
.58353 .60096 m .56159 .59498 L .55587 .6014 L .654 .783 .943 r
F
.58793 .59816 m .56159 .59498 L .58353 .60096 L F
.35996 .5922 m .37899 .601 L .38703 .5954 L .654 .782 .942 r
F
.35466 .59442 m .37899 .601 L .35996 .5922 L F
.58759 .59187 m .57015 .58304 L .56143 .58868 L F
.59316 .58967 m .57015 .58304 L .58759 .59187 L F
.6566 .60531 m .67602 .59204 L .65237 .59916 L .653 .784 .944 r
F
.6566 .60531 m .68221 .60133 L .67602 .59204 L F
.41117 .73035 m .39881 .73002 L .39916 .73528 L .529 .352 .586 r
F
0 g
.39009 .74123 m
.39916 .73528 L
s
.41117 .73035 m .41081 .72508 L .39881 .73002 L .529 .352 .586 r
F
0 g
.38976 .73598 m
.39881 .73002 L
s
.63316 .71144 m .64522 .70121 L .64588 .70644 L .543 .369 .595 r
F
.63381 .71667 m .63316 .71144 L .64588 .70644 L F
.62459 .7044 m .63316 .71144 L .64588 .70644 L .656 .809 .957 r
F
0 g
.62301 .71394 m
.63316 .71144 L
s
.4694 .72126 m .46896 .71602 L .45489 .7143 L .787 .547 .573 r
F
0 g
.46896 .71602 m
.48094 .7194 L
s
.4011 .83282 m .40556 .83255 L .40517 .83702 L .975 .747 .529 r
F
.4011 .83282 m .40149 .82834 L .40556 .83255 L F
0 g
.40556 .83255 m
.41119 .83591 L
s
.41416 .82766 m .40573 .83252 L .41684 .83046 L .594 .768 .963 r
F
.41416 .82766 m .40168 .82833 L .40573 .83252 L F
.47275 .84106 m .47307 .83659 L .47705 .83286 L .13 .009 .435 r
F
0 g
.46683 .8396 m
.47307 .83659 L
s
.61574 .46491 m
.63466 .46738 L
s
.68163 .59499 m .67487 .57931 L .67545 .58566 L .982 .7 .33 r
F
.68221 .60133 m .68163 .59499 L .67545 .58566 L F
0 g
.68219 .60128 m
.68219 .6013 L
s
.46173 .83315 m .4729 .83654 L .47686 .83283 L .594 .768 .963 r
F
.76219 .48576 m .74894 .46845 L .73428 .47382 L .643 .738 .918 r
F
.7704 .4843 m .74894 .46845 L .76219 .48576 L F
.43203 .83967 m .42561 .844 L .43191 .84546 L .592 .769 .964 r
F
.7947 .48747 m .7996 .46723 L .78725 .48518 L .643 .738 .918 r
F
.7947 .48747 m .81463 .4719 L .7996 .46723 L F
.62893 .60621 m .64489 .59392 L .62516 .60362 L .653 .784 .944 r
F
.62893 .60621 m .65237 .59916 L .64489 .59392 L F
.56159 .59498 m .53097 .59864 L .55587 .6014 L .654 .783 .943 r
F
.58612 .71221 m .58928 .72218 L .59534 .71337 L .655 .81 .957 r
F
.58612 .71221 m .57551 .72048 L .58928 .72218 L F
0 g
.58928 .72218 m
.60423 .72209 L
s
.56325 .71182 m .57436 .70999 L .57493 .71523 L .852 .592 .546 r
F
.56325 .71182 m .56269 .70656 L .57436 .70999 L F
0 g
.57436 .70999 m
.58062 .71078 L
s
.34653 .53805 m
.34849 .50349 L
s
.33561 .48602 m .32578 .4672 L .31026 .47021 L .641 .739 .92 r
F
.34398 .48582 m .32578 .4672 L .33561 .48602 L F
.70335 .59376 m .70871 .59669 L .70934 .60304 L .979 .696 .314 r
F
.70335 .59376 m .70272 .58738 L .70871 .59669 L F
.72862 .58334 m .70871 .59669 L .73251 .5896 L .653 .783 .943 r
F
.72862 .58334 m .70272 .58738 L .70871 .59669 L F
0 g
.70871 .59669 m
.71512 .60133 L
s
.35243 .4869 m .34271 .46679 L .34398 .48582 L .641 .739 .92 r
F
.35243 .4869 m .35981 .46899 L .34271 .46679 L F
0 g
.33975 .53794 m
.3418 .50314 L
s
.53163 .43765 m .5307 .45692 L .54752 .45651 L .644 .737 .916 r
F
.52319 .43654 m .5307 .45692 L .53163 .43765 L F
.52319 .43654 m .514 .45474 L .5307 .45692 L F
.619 .58904 m .62124 .57498 L .61293 .58789 L .654 .782 .942 r
F
.619 .58904 m .63346 .57734 L .62124 .57498 L F
.62467 .59727 m .63412 .58359 L .61956 .59533 L .654 .783 .943 r
F
.62467 .59727 m .64436 .58754 L .63412 .58359 L F
.79762 .59057 m .81353 .59939 L .82324 .59377 L .653 .784 .944 r
F
.79169 .59279 m .81353 .59939 L .79762 .59057 L F
.29726 .47556 m .25839 .47189 L .28767 .48286 L .641 .739 .92 r
F
.29946 .45983 m .27514 .44506 L .26098 .45619 L .643 .738 .918 r
F
.31235 .45447 m .27514 .44506 L .29946 .45983 L F
.34398 .48582 m .34271 .46679 L .32578 .4672 L .641 .739 .92 r
F
.4003 .48878 m .41244 .46812 L .38966 .48042 L F
.4003 .48878 m .42832 .48083 L .41244 .46812 L F
0 g
.34544 .55726 m
.34653 .53805 L
s
.39096 .46464 m .39294 .44202 L .37729 .45788 L .643 .738 .918 r
F
.39096 .46464 m .41353 .45233 L .39294 .44202 L F
0 g
.33862 .55709 m
.33975 .53794 L
s
.29026 .59136 m .27432 .60465 L .29624 .59758 L .654 .782 .942 r
F
.29026 .59136 m .26522 .59539 L .27432 .60465 L F
0 g
.27432 .60465 m
.28773 .61236 L
s
.4007 .8373 m .40517 .83702 L .40478 .84149 L .975 .747 .529 r
F
.4007 .8373 m .4011 .83282 L .40517 .83702 L F
.41365 .83215 m .40517 .83702 L .41635 .83496 L .593 .769 .963 r
F
.41365 .83215 m .4011 .83282 L .40517 .83702 L F
0 g
.40517 .83702 m
.41084 .84038 L
s
.42931 .83864 m .42561 .844 L .43203 .83967 L .592 .769 .964 r
F
.42931 .83864 m .42018 .84195 L .42561 .844 L F
.61556 .71205 m .63381 .71667 L .62523 .70966 L .655 .81 .957 r
F
.63381 .71667 m .64588 .70644 L .64655 .71169 L .543 .369 .595 r
F
.62523 .70966 m .63381 .71667 L .64655 .71169 L .655 .81 .957 r
F
0 g
.61939 .72021 m
.63381 .71667 L
s
.4694 .72126 m .45489 .7143 L .45531 .71956 L .787 .547 .573 r
F
.46984 .72652 m .4694 .72126 L .45531 .71956 L F
0 g
.4694 .72126 m
.48139 .72463 L
s
.59316 .58967 m .58134 .57858 L .57015 .58304 L .654 .782 .942 r
F
.59954 .58821 m .58134 .57858 L .59316 .58967 L F
.58395 .60731 m .56198 .60135 L .55625 .60776 L .653 .784 .944 r
F
.58836 .60452 m .56198 .60135 L .58395 .60731 L F
.44509 .84045 m .45162 .84556 L .45702 .84415 L .592 .769 .964 r
F
.31835 .59046 m .30515 .60279 L .32279 .59309 L .654 .782 .942 r
F
.31835 .59046 m .29624 .59758 L .30515 .60279 L F
0 g
.55956 .48504 m
.58357 .48062 L
s
.47275 .84106 m .47705 .83286 L .47673 .83735 L .13 .009 .435 r
F
.47243 .84554 m .47275 .84106 L .47673 .83735 L F
.46151 .83766 m .47275 .84106 L .47673 .83735 L .593 .769 .963 r
F
.45735 .83967 m .47275 .84106 L .46151 .83766 L F
0 g
.46651 .84406 m
.47275 .84106 L
s
.65107 .58653 m .66344 .57146 L .64364 .58128 L .654 .782 .942 r
F
.65107 .58653 m .67452 .57942 L .66344 .57146 L F
0 g
.77875 .5018 m
.78156 .53637 L
s
.44493 .45891 m .46112 .46371 L .46052 .47165 L .92 .668 .54 r
F
.44493 .45891 m .44557 .45095 L .46112 .46371 L F
.47408 .44271 m .46112 .46371 L .4844 .45133 L .643 .737 .917 r
F
.47408 .44271 m .44557 .45095 L .46112 .46371 L F
0 g
.46112 .46371 m
.46849 .46743 L
s
.7704 .4843 m .76552 .46544 L .74894 .46845 L .643 .738 .918 r
F
.77896 .4841 m .76552 .46544 L .7704 .4843 L F
.65719 .49017 m .63447 .47531 L .63428 .48328 L .793 .542 .558 r
F
0 g
.65719 .49017 m
.67616 .50013 L
s
.51536 .43417 m .514 .45474 L .52319 .43654 L .644 .737 .916 r
F
.51536 .43417 m .49849 .4501 L .514 .45474 L F
.78725 .48518 m .78283 .46502 L .77896 .4841 L .643 .738 .918 r
F
.78725 .48518 m .7996 .46723 L .78283 .46502 L F
0 g
.77205 .50145 m
.7748 .53626 L
s
.54014 .43743 m .54752 .45651 L .5634 .45351 L .644 .737 .916 r
F
.53163 .43765 m .54752 .45651 L .54014 .43743 L F
.58793 .59816 m .57038 .58932 L .56159 .59498 L .654 .783 .943 r
F
.59354 .59596 m .57038 .58932 L .58793 .59816 L F
.56143 .58868 m .53941 .58265 L .531 .59233 L .654 .782 .942 r
F
.56381 .71708 m .57493 .71523 L .57551 .72048 L .852 .592 .546 r
F
.56381 .71708 m .56325 .71182 L .57493 .71523 L F
.57773 .70463 m .57493 .71523 L .58552 .70694 L .656 .809 .957 r
F
.57773 .70463 m .56325 .71182 L .57493 .71523 L F
0 g
.57493 .71523 m
.58124 .71602 L
s
.42491 .72153 m .41044 .71982 L .41081 .72508 L .612 .415 .59 r
F
.42491 .72153 m .42453 .71627 L .41044 .71982 L F
0 g
.39846 .72477 m
.41044 .71982 L
s
.53943 .58893 m .53063 .59229 L .53097 .59864 L .19 .092 .506 r
F
.53943 .58893 m .53907 .58256 L .53063 .59229 L F
0 g
.52736 .60245 m
.53063 .59229 L
s
.64588 .70644 m .64522 .70121 L .65541 .69506 L .44 .296 .588 r
F
0 g
.63466 .70537 m
.64522 .70121 L
s
.73428 .47382 m .69579 .47014 L .72256 .48113 L .643 .738 .918 r
F
.61293 .58789 m .60783 .57439 L .60629 .5876 L .654 .782 .942 r
F
.61293 .58789 m .62124 .57498 L .60783 .57439 L F
.4173 .58538 m .41715 .57905 L .41962 .56864 L 0 0 .24 r
F
0 g
.41168 .58606 m
.41715 .57905 L
s
.73439 .45808 m .71364 .44328 L .69628 .45443 L .644 .736 .916 r
F
.74891 .45271 m .71364 .44328 L .73439 .45808 L F
.77896 .4841 m .78283 .46502 L .76552 .46544 L .643 .738 .918 r
F
.39154 .57619 m .41677 .57901 L .41922 .56865 L .656 .781 .94 r
F
.68221 .60133 m .67545 .58566 L .67602 .59204 L .982 .7 .33 r
F
0 g
.68221 .60133 m
.6831 .6113 L
s
.27373 .45279 m .26054 .45602 L .25947 .46394 L .277 .095 .445 r
F
.26903 .45394 m .27477 .44484 L .26054 .45602 L F
.2741 .44997 m .27477 .44484 L .26903 .45394 L F
.2803 .44357 m .27766 .44318 L .2896 .44053 L .667 .432 .555 r
F
.27766 .44318 m .27796 .44083 L .2896 .44053 L F
.28413 .44435 m .27856 .44362 L .27514 .44506 L .643 .738 .918 r
F
.30079 .44304 m .28924 .44334 L .28413 .44435 L F
.28924 .44334 m .27856 .44362 L .28413 .44435 L F
.30425 .44036 m .2896 .44053 L .31284 .43591 L .587 .36 .539 r
F
.31235 .45447 m .30079 .44304 L .27514 .44506 L .643 .738 .918 r
F
.28924 .44334 m .2896 .44053 L .30425 .44036 L .587 .36 .539 r
F
.26398 .44399 m .26436 .44119 L .2803 .44357 L .667 .432 .555 r
F
.26211 .42127 m .26432 .4409 L .28944 .44024 L .643 .737 .917 r
F
.27745 .4448 m .2776 .44364 L .27477 .44484 L .472 .26 .509 r
F
.27693 .44878 m .2896 .44053 L .28859 .44848 L .667 .432 .555 r
F
.27749 .44449 m .2896 .44053 L .27693 .44878 L F
.27905 .42082 m .28944 .44024 L .31258 .43565 L .643 .737 .917 r
F
.26211 .42127 m .28944 .44024 L .27905 .42082 L F
.28924 .44334 m .29453 .43685 L .27856 .44362 L .643 .738 .918 r
F
.30079 .44304 m .29911 .44138 L .28924 .44334 L F
.29911 .44138 m .29453 .43685 L .28924 .44334 L F
.32772 .45146 m .30305 .4406 L .31235 .45447 L F
.30305 .4406 m .29453 .43685 L .29911 .44138 L F
.30305 .4406 m .29911 .44138 L .31235 .45447 L F
.30425 .44036 m .31284 .43591 L .31251 .43873 L .587 .36 .539 r
F
.32527 .43336 m .31284 .43591 L .32973 .4288 L .475 .263 .511 r
F
.3296 .42996 m .32973 .4288 L .33263 .42758 L F
.32527 .43336 m .32973 .4288 L .3296 .42996 L F
.31251 .43873 m .31284 .43591 L .32527 .43336 L F
.27905 .42082 m .31258 .43565 L .2946 .41768 L .643 .737 .917 r
F
.2946 .41768 m .31258 .43565 L .33226 .42735 L F
.30549 .44168 m .31779 .43222 L .29453 .43685 L .643 .738 .918 r
F
.32772 .45146 m .31961 .43574 L .30549 .44168 L F
.31961 .43574 m .31779 .43222 L .30549 .44168 L F
.34448 .45103 m .3216 .4349 L .32772 .45146 L F
.3216 .4349 m .31779 .43222 L .31961 .43574 L F
.3216 .4349 m .31961 .43574 L .32772 .45146 L F
.32941 .43162 m .33263 .42758 L .3323 .4304 L .475 .263 .511 r
F
.32527 .43336 m .3296 .42996 L .32941 .43162 L F
.3296 .42996 m .33263 .42758 L .32941 .43162 L F
.34199 .42294 m .33263 .42758 L .34765 .41599 L .29 .108 .453 r
F
.34448 .45103 m .34322 .43155 L .33037 .43189 L .643 .738 .918 r
F
.34448 .45103 m .33037 .43189 L .32414 .43669 L F
.32414 .43669 m .33037 .43189 L .31779 .43222 L F
.34231 .43926 m .34317 .43155 L .32989 .4319 L .667 .43 .553 r
F
.34317 .43155 m .3432 .43125 L .32989 .4319 L F
.32989 .4319 m .3432 .43125 L .32941 .43162 L F
.33356 .43666 m .32941 .43162 L .32898 .4353 L F
.34231 .43926 m .33773 .43655 L .33356 .43666 L F
.33773 .43655 m .32941 .43162 L .33356 .43666 L F
.34231 .43926 m .32898 .4353 L .32848 .43962 L F
.31189 .44388 m .32527 .43336 L .32906 .43465 L .475 .263 .511 r
F
.32881 .43678 m .32906 .43465 L .33171 .43557 L F
.31189 .44388 m .32906 .43465 L .32881 .43678 L F
.32527 .43336 m .3323 .4304 L .33171 .43557 L F
.3245 .43397 m .3241 .43385 L .32527 .43336 L F
.31189 .44388 m .3241 .43385 L .3245 .43397 L F
.31189 .44388 m .31251 .43873 L .3241 .43385 L F
.32898 .4353 m .32941 .43162 L .31764 .43193 L .667 .43 .553 r
F
.30425 .44036 m .31251 .43873 L .31189 .44388 L .587 .36 .539 r
F
.31703 .43709 m .31189 .44388 L .32881 .43678 L .642 .738 .918 r
F
.30872 .43874 m .29426 .43659 L .29361 .44173 L .587 .359 .538 r
F
.30705 .43907 m .31189 .44388 L .31703 .43709 L .642 .738 .918 r
F
.30872 .43874 m .31764 .43193 L .29426 .43659 L .587 .359 .538 r
F
.31669 .43992 m .31703 .43709 L .30872 .43874 L F
.31703 .43709 m .31764 .43193 L .30872 .43874 L F
.32434 .44135 m .31189 .44388 L .32881 .43678 L .475 .263 .511 r
F
.32671 .45922 m .3194 .44515 L .30469 .44957 L .642 .738 .919 r
F
.3194 .44515 m .31866 .44372 L .31155 .4467 L F
.3194 .44515 m .31155 .4467 L .30469 .44957 L F
.30328 .44833 m .31189 .44388 L .31155 .4467 L .587 .36 .539 r
F
.28859 .44848 m .30425 .44036 L .31189 .44388 L F
.28859 .44848 m .28924 .44334 L .30425 .44036 L F
.30328 .44833 m .28859 .44848 L .31189 .44388 L F
.28823 .4513 m .28859 .44848 L .30328 .44833 L F
.28656 .44471 m .28859 .44848 L .30046 .43884 L .642 .738 .918 r
F
.26329 .44912 m .26398 .44399 L .2776 .44364 L .667 .432 .555 r
F
.27749 .44449 m .2776 .44364 L .2803 .44357 L F
.27693 .44878 m .27477 .44484 L .2741 .44997 L .472 .26 .509 r
F
.27745 .4448 m .27477 .44484 L .27693 .44878 L F
.26329 .44912 m .2776 .44364 L .27749 .44449 L .667 .432 .555 r
F
.28668 .44466 m .27745 .4448 L .27693 .44878 L .472 .26 .509 r
F
.26329 .44912 m .27749 .44449 L .27693 .44878 L .667 .432 .555 r
F
.28769 .44423 m .29426 .43659 L .2776 .44364 L .472 .26 .509 r
F
.28668 .44466 m .2776 .44364 L .27745 .4448 L F
.29326 .44456 m .28769 .44423 L .28668 .44466 L F
.28769 .44423 m .2776 .44364 L .28668 .44466 L F
.27766 .44318 m .26436 .44119 L .27796 .44083 L .667 .432 .555 r
F
.24487 .41902 m .26432 .4409 L .26211 .42127 L .643 .737 .917 r
F
.26105 .42946 m .28443 .44561 L .27811 .429 L .642 .738 .918 r
F
.28443 .44561 m .28859 .44848 L .28656 .44471 L F
.28443 .44561 m .28656 .44471 L .27811 .429 L F
.2819 .44386 m .27558 .44881 L .27693 .44878 L F
.28443 .44561 m .27693 .44878 L .28859 .44848 L F
.2819 .44386 m .27693 .44878 L .28443 .44561 L F
.29326 .44456 m .29361 .44173 L .28769 .44423 L .472 .26 .509 r
F
.29361 .44173 m .29426 .43659 L .28769 .44423 L F
.27926 .45152 m .27693 .44878 L .28859 .44848 L .667 .432 .555 r
F
.2998 .451 m .27656 .45159 L .27373 .45279 L .642 .738 .919 r
F
.27645 .45245 m .27656 .45159 L .27926 .45152 L .667 .432 .555 r
F
.27656 .45159 m .27693 .44878 L .27926 .45152 L F
.31122 .46223 m .2998 .451 L .27373 .45279 L .642 .738 .919 r
F
.30046 .43884 m .28859 .44848 L .31189 .44388 L .642 .738 .918 r
F
.29824 .4676 m .27373 .45279 L .25947 .46394 L .642 .738 .919 r
F
.31122 .46223 m .27373 .45279 L .29824 .4676 L F
.26798 .4619 m .27373 .45279 L .25947 .46394 L .277 .095 .445 r
F
.27268 .46077 m .27305 .45794 L .26798 .4619 L F
.27305 .45794 m .27373 .45279 L .26798 .4619 L F
.27488 .45717 m .27373 .45279 L .27305 .45794 L .472 .26 .509 r
F
.27589 .45675 m .28859 .44848 L .28757 .45646 L .667 .432 .555 r
F
.28341 .4536 m .27589 .45675 L .28757 .45646 L .642 .739 .919 r
F
.27645 .45245 m .28859 .44848 L .27589 .45675 L .667 .432 .555 r
F
.2998 .451 m .29326 .44456 L .27656 .45159 L .642 .738 .919 r
F
.30469 .44957 m .30719 .44756 L .3023 .44852 L F
.32671 .45922 m .29326 .44456 L .31122 .46223 L F
.28757 .45646 m .28823 .4513 L .30328 .44833 L .587 .36 .539 r
F
.27811 .429 m .31189 .44388 L .29377 .42586 L .642 .738 .918 r
F
.3023 .44852 m .31669 .43992 L .29326 .44456 L .642 .738 .919 r
F
.28554 .4527 m .28757 .45646 L .29696 .44887 L .642 .739 .919 r
F
.30719 .44756 m .31669 .43992 L .3023 .44852 L .642 .738 .919 r
F
.30775 .44675 m .29326 .44456 L .29261 .44973 L .587 .359 .538 r
F
.29261 .44973 m .29696 .44887 L .29947 .44685 L .642 .739 .919 r
F
.28554 .4527 m .29696 .44887 L .29261 .44973 L F
.31155 .4467 m .31189 .44388 L .32434 .44135 L .475 .263 .511 r
F
.31866 .44372 m .31669 .43992 L .30469 .44957 L .642 .738 .919 r
F
.28757 .45646 m .30328 .44833 L .31092 .45188 L .587 .36 .539 r
F
.29947 .44685 m .28757 .45646 L .31092 .45188 L .642 .739 .919 r
F
.30328 .44833 m .31155 .4467 L .31092 .45188 L .587 .36 .539 r
F
.34359 .45879 m .32082 .44282 L .32671 .45922 L .642 .738 .919 r
F
.32082 .44282 m .31669 .43992 L .31866 .44372 L F
.32082 .44282 m .31866 .44372 L .32671 .45922 L F
.32848 .43962 m .33171 .43557 L .33139 .4384 L .475 .263 .511 r
F
.32434 .44135 m .32868 .43795 L .32848 .43962 L F
.32868 .43795 m .33171 .43557 L .32848 .43962 L F
.32434 .44135 m .32881 .43678 L .32868 .43795 L F
.34109 .43096 m .33171 .43557 L .34676 .42401 L .29 .108 .453 r
F
.34359 .45879 m .34231 .43926 L .32985 .43958 L .642 .738 .919 r
F
.34359 .45879 m .32985 .43958 L .32333 .44458 L F
.32333 .44458 m .32985 .43958 L .31669 .43992 L F
.34141 .4473 m .34231 .43926 L .32848 .43962 L .667 .43 .553 r
F
.33264 .44468 m .32848 .43962 L .32806 .44331 L F
.34141 .4473 m .33683 .44457 L .33264 .44468 L F
.33683 .44457 m .32848 .43962 L .33264 .44468 L F
.34141 .4473 m .32806 .44331 L .32756 .44765 L F
.31092 .45188 m .32434 .44135 L .32813 .44267 L .475 .263 .511 r
F
.32788 .4448 m .32813 .44267 L .33079 .44359 L F
.31092 .45188 m .32813 .44267 L .32788 .4448 L F
.32434 .44135 m .33139 .4384 L .33079 .44359 L F
.31092 .45188 m .31155 .4467 L .32434 .44135 L F
.32806 .44331 m .32848 .43962 L .31669 .43992 L .667 .43 .553 r
F
.27811 .429 m .28656 .44471 L .30046 .43884 L .642 .738 .918 r
F
.31607 .44511 m .31092 .45188 L .32788 .4448 L .642 .739 .919 r
F
.30775 .44675 m .31669 .43992 L .29326 .44456 L .587 .359 .538 r
F
.31607 .44511 m .31669 .43992 L .30775 .44675 L F
.30439 .44541 m .30608 .44708 L .31607 .44511 L .642 .739 .919 r
F
.30608 .44708 m .31092 .45188 L .31607 .44511 L F
.31573 .44795 m .31607 .44511 L .30775 .44675 L .587 .359 .538 r
F
.32756 .44765 m .31669 .43992 L .31573 .44795 L .667 .43 .553 r
F
.32806 .44331 m .31669 .43992 L .32756 .44765 L F
.32464 .43689 m .31764 .43193 L .31703 .43709 L F
.29377 .42586 m .30537 .43739 L .32094 .43631 L .642 .738 .918 r
F
.30537 .43739 m .30705 .43907 L .31703 .43709 L F
.31669 .43992 m .30872 .43874 L .29326 .44456 L .587 .359 .538 r
F
.30872 .43874 m .29361 .44173 L .29326 .44456 L F
.32898 .4353 m .31764 .43193 L .32848 .43962 L .667 .43 .553 r
F
.30537 .43739 m .32881 .43678 L .33171 .43557 L .642 .738 .918 r
F
.29276 .4339 m .30439 .44541 L .33079 .44359 L .642 .739 .919 r
F
.30439 .44541 m .32788 .4448 L .33079 .44359 L F
.33079 .44359 m .33139 .4384 L .34109 .43096 L .29 .108 .453 r
F
.33139 .4384 m .33171 .43557 L .34109 .43096 L F
.31573 .44795 m .31147 .44731 L .31129 .44883 L .587 .359 .538 r
F
.31147 .44731 m .30775 .44675 L .31129 .44883 L F
.27706 .43703 m .31092 .45188 L .29276 .4339 L .642 .739 .919 r
F
.31129 .44883 m .30775 .44675 L .29225 .45257 L .587 .359 .538 r
F
.30775 .44675 m .29261 .44973 L .29225 .45257 L F
.28566 .45265 m .27641 .45276 L .27589 .45675 L .472 .26 .509 r
F
.28668 .44466 m .2741 .44997 L .27373 .45279 L F
.27373 .45279 m .2741 .44997 L .26903 .45394 L .277 .095 .445 r
F
.26222 .4571 m .26329 .44912 L .27693 .44878 L .667 .432 .555 r
F
.27641 .45276 m .27373 .45279 L .27552 .45959 L .472 .26 .509 r
F
.27656 .45159 m .27664 .45096 L .27373 .45279 L F
.29225 .45257 m .29326 .44456 L .27373 .45279 L F
.26222 .4571 m .27693 .44878 L .27645 .45245 L .667 .432 .555 r
F
.29326 .44456 m .28668 .44466 L .27664 .45096 L .472 .26 .509 r
F
.29326 .44456 m .27664 .45096 L .27656 .45159 L F
.23754 .44579 m .26436 .44119 L .26329 .44912 L .731 .491 .564 r
F
.23754 .44579 m .23867 .43786 L .26436 .44119 L F
.24487 .41902 m .23876 .43758 L .26432 .4409 L .643 .737 .917 r
F
.26105 .42946 m .26329 .44912 L .27558 .44881 L .642 .738 .918 r
F
.26105 .42946 m .27558 .44881 L .2819 .44386 L F
.24368 .4272 m .26329 .44912 L .26105 .42946 L F
.25996 .43748 m .28341 .4536 L .27706 .43703 L .642 .739 .919 r
F
.28341 .4536 m .28757 .45646 L .28554 .4527 L F
.28341 .4536 m .28554 .4527 L .27706 .43703 L F
.29225 .45257 m .28566 .45265 L .27552 .45959 L .472 .26 .509 r
F
.28566 .45265 m .27589 .45675 L .27552 .45959 L F
.27706 .43703 m .28554 .4527 L .29947 .44685 L .642 .739 .919 r
F
.26222 .4571 m .27645 .45245 L .27589 .45675 L .667 .432 .555 r
F
.28087 .45185 m .27453 .45679 L .27589 .45675 L .642 .739 .919 r
F
.28087 .45185 m .27589 .45675 L .28341 .4536 L F
.27552 .45959 m .27488 .45717 L .27268 .46077 L .472 .26 .509 r
F
.27488 .45717 m .27305 .45794 L .27268 .46077 L F
.2364 .45377 m .26329 .44912 L .26222 .4571 L .731 .491 .564 r
F
.2364 .45377 m .23754 .44579 L .26329 .44912 L F
.24368 .4272 m .23754 .44579 L .26329 .44912 L .642 .738 .918 r
F
.25996 .43748 m .26222 .4571 L .27453 .45679 L .642 .739 .919 r
F
.25996 .43748 m .27453 .45679 L .28087 .45185 L F
.32868 .43795 m .32881 .43678 L .33171 .43557 L .475 .263 .511 r
F
.32848 .43962 m .32464 .43689 L .31669 .43992 L .667 .43 .553 r
F
.32464 .43689 m .31703 .43709 L .31669 .43992 L F
.32865 .43478 m .32094 .43631 L .33171 .43557 L .642 .738 .918 r
F
.29377 .42586 m .32094 .43631 L .32865 .43478 L F
.33171 .43557 m .3323 .4304 L .34199 .42294 L .29 .108 .453 r
F
.3323 .4304 m .33263 .42758 L .34199 .42294 L F
0 g
.25247 .46927 m
.26005 .45682 L
s
.83536 .48706 m .85331 .46635 L .82683 .47868 L .643 .738 .918 r
F
.83536 .48706 m .86599 .47909 L .85331 .46635 L F
.38693 .58905 m .4173 .58538 L .3919 .58256 L .655 .781 .941 r
F
0 g
.78156 .53637 m
.78309 .55533 L
s
.82604 .4629 m .83409 .44023 L .81396 .45612 L .644 .736 .916 r
F
.82604 .4629 m .85225 .45056 L .83409 .44023 L F
.56198 .60135 m .5313 .60501 L .55625 .60776 L .653 .784 .944 r
F
0 g
.7748 .53626 m
.77635 .55594 L
s
.59954 .58821 m .59421 .57562 L .58134 .57858 L .654 .782 .942 r
F
.60629 .5876 m .59421 .57562 L .59954 .58821 L F
.72929 .58973 m .70934 .60304 L .73318 .59596 L .653 .784 .944 r
F
.72929 .58973 m .70335 .59376 L .70934 .60304 L F
0 g
.70934 .60304 m
.72007 .61077 L
s
.429 .47285 m .42967 .46491 L .41388 .45214 L .918 .667 .544 r
F
0 g
.42967 .46491 m
.43953 .47911 L
s
.60629 .5876 m .60783 .57439 L .59421 .57562 L .654 .782 .942 r
F
.41327 .83664 m .40478 .84149 L .41597 .83944 L .592 .769 .964 r
F
.41327 .83664 m .4007 .8373 L .40478 .84149 L F
0 g
.40478 .84149 m
.41111 .84524 L
s
.75722 .58882 m .74028 .60118 L .76075 .59146 L .653 .784 .944 r
F
.75722 .58882 m .73318 .59596 L .74028 .60118 L F
.61956 .59533 m .62181 .58123 L .61344 .59417 L .654 .783 .943 r
F
.61956 .59533 m .63412 .58359 L .62181 .58123 L F
.62516 .60362 m .63463 .58998 L .62004 .60169 L .653 .784 .944 r
F
.62516 .60362 m .64489 .59392 L .63463 .58998 L F
.47243 .84554 m .47673 .83735 L .47642 .84184 L .13 .009 .435 r
F
.46118 .84215 m .47243 .84554 L .47642 .84184 L .592 .769 .964 r
F
.45702 .84415 m .47243 .84554 L .46118 .84215 L F
0 g
.46618 .84853 m
.47243 .84554 L
s
.42667 .82699 m .41416 .82766 L .41684 .83046 L .594 .768 .963 r
F
.46984 .72652 m .45531 .71956 L .45573 .72482 L .787 .547 .573 r
F
0 g
.46984 .72652 m
.48184 .72987 L
s
.45531 .71956 m .45489 .7143 L .43971 .71439 L .732 .505 .584 r
F
0 g
.45489 .7143 m
.46896 .71602 L
s
.63428 .48328 m .63447 .47531 L .60936 .47204 L .732 .49 .562 r
F
0 g
.63447 .47531 m
.65732 .48221 L
s
.46173 .83315 m .47686 .83283 L .46434 .83066 L .594 .768 .963 r
F
.42721 .83738 m .42018 .84195 L .42931 .83864 L .592 .769 .964 r
F
.42721 .83738 m .41597 .83944 L .42018 .84195 L F
.85348 .58375 m .85261 .57741 L .85833 .56698 L .041 .016 .498 r
F
0 g
.84462 .5848 m
.85261 .57741 L
s
.44779 .83974 m .45702 .84415 L .46118 .84215 L .592 .769 .964 r
F
.44509 .84045 m .45702 .84415 L .44779 .83974 L F
.71332 .45101 m .69588 .45426 L .69584 .46219 L .389 .215 .52 r
F
.71332 .45101 m .71332 .44306 L .69588 .45426 L F
0 g
.68414 .46754 m
.69588 .45426 L
s
.53119 .44571 m .53025 .46503 L .5472 .46461 L .643 .737 .917 r
F
.52268 .44459 m .53025 .46503 L .53119 .44571 L F
.52268 .44459 m .51344 .46284 L .53025 .46503 L F
.82242 .58742 m .85348 .58375 L .82937 .58092 L .653 .783 .943 r
F
.59354 .59596 m .58165 .58485 L .57038 .58932 L .654 .783 .943 r
F
.59996 .5945 m .58165 .58485 L .59354 .59596 L F
.57831 .70991 m .57551 .72048 L .58612 .71221 L .655 .81 .957 r
F
.57831 .70991 m .56381 .71708 L .57551 .72048 L F
0 g
.57551 .72048 m
.58928 .72218 L
s
.42529 .72681 m .41081 .72508 L .41117 .73035 L .612 .415 .59 r
F
0 g
.39916 .73528 m
.41117 .73035 L
s
.42529 .72681 m .42491 .72153 L .41081 .72508 L .612 .415 .59 r
F
0 g
.39881 .73002 m
.41081 .72508 L
s
.65184 .5928 m .66431 .57769 L .64436 .58754 L .654 .783 .943 r
F
.65184 .5928 m .67545 .58566 L .66431 .57769 L F
.64588 .70644 m .65541 .69506 L .65609 .70031 L .44 .296 .588 r
F
.64655 .71169 m .64588 .70644 L .65609 .70031 L F
.6331 .70104 m .64588 .70644 L .65609 .70031 L .656 .809 .957 r
F
.62459 .7044 m .64588 .70644 L .6331 .70104 L F
0 g
.63525 .71062 m
.64588 .70644 L
s
.60916 .61216 m
.60974 .63475 L
s
.86563 .4711 m .86528 .46316 L .85265 .45037 L .953 .671 .466 r
F
0 g
.86528 .46316 m
.8715 .47739 L
s
.60243 .61232 m
.60296 .63465 L
s
.58836 .60452 m .57079 .59571 L .56198 .60135 L .653 .784 .944 r
F
.59398 .60232 m .57079 .59571 L .58836 .60452 L F
.57015 .58304 m .53941 .58265 L .56143 .58868 L .654 .782 .942 r
F
.75404 .5729 m .72821 .57694 L .73208 .58318 L F
.56159 .59498 m .53943 .58893 L .53097 .59864 L .654 .783 .943 r
F
.53978 .59533 m .53097 .59864 L .5313 .60501 L .19 .092 .506 r
F
.53978 .59533 m .53943 .58893 L .53097 .59864 L F
0 g
.52769 .60877 m
.53097 .59864 L
s
.39043 .47245 m .39241 .44977 L .37665 .46567 L .642 .738 .919 r
F
.39043 .47245 m .41316 .46011 L .39241 .44977 L F
.44011 .71965 m .42453 .71627 L .42491 .72153 L .676 .463 .589 r
F
.44011 .71965 m .43971 .71439 L .42453 .71627 L F
0 g
.41044 .71982 m
.42453 .71627 L
s
.4173 .58538 m .41962 .56864 L .41977 .575 L 0 0 .24 r
F
.41745 .59173 m .4173 .58538 L .41977 .575 L F
.3919 .58256 m .4173 .58538 L .41977 .575 L .655 .781 .941 r
F
0 g
.41178 .59241 m
.4173 .58538 L
s
.61344 .59417 m .60832 .58064 L .60676 .59389 L .654 .783 .943 r
F
.61344 .59417 m .62181 .58123 L .60832 .58064 L F
.39957 .82845 m .40149 .82834 L .4011 .83282 L .973 .789 .364 r
F
.39957 .82845 m .39997 .82397 L .40149 .82834 L F
0 g
.40149 .82834 m
.40556 .83255 L
s
.41318 .82476 m .40168 .82833 L .41416 .82766 L .594 .768 .963 r
F
.41318 .82476 m .40016 .82398 L .40168 .82833 L F
.38703 .5954 m .41745 .59173 L .39201 .58893 L .654 .782 .942 r
F
.36397 .58936 m .38703 .5954 L .39201 .58893 L F
.35996 .5922 m .38703 .5954 L .36397 .58936 L F
.42624 .83148 m .41365 .83215 L .41635 .83496 L .593 .769 .963 r
F
0 g
.60974 .63475 m
.6108 .67556 L
s
.47673 .83735 m .47705 .83286 L .47848 .82866 L 0 0 .157 r
F
0 g
.47307 .83659 m
.47705 .83286 L
s
.60296 .63465 m
.60395 .67603 L
s
.46151 .83766 m .47673 .83735 L .46414 .83517 L .593 .769 .963 r
F
.5148 .44222 m .51344 .46284 L .52268 .44459 L .643 .737 .917 r
F
.5148 .44222 m .49781 .45818 L .51344 .46284 L F
.46434 .83066 m .47686 .83283 L .47828 .82865 L .594 .768 .963 r
F
.63428 .48328 m .60936 .47204 L .60911 .48001 L .732 .49 .562 r
F
0 g
.60936 .47204 m
.63447 .47531 L
s
.63428 .48328 m
.65719 .49017 L
s
.60934 .47204 m
.60936 .47204 L
s
.53976 .44549 m .5472 .46461 L .56319 .46161 L .643 .737 .917 r
F
.53119 .44571 m .5472 .46461 L .53976 .44549 L F
.45531 .71956 m .43971 .71439 L .44011 .71965 L .732 .505 .584 r
F
0 g
.42453 .71627 m
.43971 .71439 L
s
.43971 .71439 m
.45489 .7143 L
s
.50868 .4307 m .49849 .4501 L .51536 .43417 L .644 .737 .916 r
F
.50868 .4307 m .48518 .44327 L .49849 .4501 L F
.47351 .45069 m .46052 .47165 L .48385 .4593 L .642 .738 .918 r
F
.47351 .45069 m .44493 .45891 L .46052 .47165 L F
0 g
.46052 .47165 m
.48062 .48173 L
s
.59996 .5945 m .5946 .58188 L .58165 .58485 L .654 .783 .943 r
F
.60676 .59389 m .5946 .58188 L .59996 .5945 L F
.45573 .72482 m .45531 .71956 L .44011 .71965 L .732 .505 .584 r
F
0 g
.45531 .71956 m
.4694 .72126 L
s
.54815 .43589 m .5634 .45351 L .57731 .44811 L .644 .737 .916 r
F
.54014 .43743 m .5634 .45351 L .54815 .43589 L F
.60676 .59389 m .60832 .58064 L .5946 .58188 L .654 .783 .943 r
F
0 g
.60106 .4775 m
.60265 .47645 L
s
.62004 .60169 m .6223 .58763 L .61392 .60053 L .653 .784 .944 r
F
.62004 .60169 m .63463 .58998 L .6223 .58763 L F
.55443 .7069 m .56269 .70656 L .56325 .71182 L .925 .647 .497 r
F
.55443 .7069 m .55388 .70163 L .56269 .70656 L F
0 g
.56269 .70656 m
.56969 .70862 L
s
.27268 .46077 m .25947 .46394 L .25839 .47189 L .277 .095 .445 r
F
0 g
.25139 .47716 m
.25947 .46394 L
s
.73423 .46586 m .71332 .45101 L .69584 .46219 L .644 .737 .917 r
F
.74886 .46047 m .71332 .45101 L .73423 .46586 L F
.57147 .69598 m .55414 .70154 L .56291 .70645 L .656 .808 .956 r
F
.64655 .71169 m .65609 .70031 L .65677 .70557 L .44 .296 .588 r
F
.63375 .70631 m .64655 .71169 L .65677 .70557 L .655 .81 .957 r
F
.62523 .70966 m .64655 .71169 L .63375 .70631 L F
0 g
.63381 .71667 m
.64655 .71169 L
s
.82656 .47071 m .83468 .44798 L .81439 .46392 L .644 .737 .917 r
F
.82656 .47071 m .85298 .45834 L .83468 .44798 L F
.85348 .58375 m .85833 .56698 L .85922 .57334 L .041 .016 .498 r
F
.85435 .5901 m .85348 .58375 L .85922 .57334 L F
.82937 .58092 m .85348 .58375 L .85922 .57334 L .653 .783 .943 r
F
0 g
.84542 .59116 m
.85348 .58375 L
s
.429 .47285 m .41388 .45214 L .41316 .46011 L .918 .667 .544 r
F
.42832 .48083 m .429 .47285 L .41316 .46011 L F
0 g
.429 .47285 m
.43888 .48701 L
s
.82324 .59377 m .85435 .5901 L .83021 .58729 L .653 .784 .944 r
F
.80247 .58773 m .82324 .59377 L .83021 .58729 L F
.79762 .59057 m .82324 .59377 L .80247 .58773 L F
.59398 .60232 m .58207 .59125 L .57079 .59571 L F
.60042 .60086 m .58207 .59125 L .59398 .60232 L F
.39916 .83295 m .4011 .83282 L .4007 .8373 L .973 .789 .364 r
F
.39916 .83295 m .39957 .82845 L .4011 .83282 L F
.41266 .82924 m .4011 .83282 L .41365 .83215 L .593 .769 .963 r
F
.41266 .82924 m .39957 .82845 L .4011 .83282 L F
0 g
.4011 .83282 m
.40517 .83702 L
s
.65237 .59916 m .66487 .58409 L .64489 .59392 L .653 .784 .944 r
F
.65237 .59916 m .67602 .59204 L .66487 .58409 L F
.37729 .45788 m .36891 .43491 L .36142 .45323 L .643 .738 .918 r
F
.37729 .45788 m .39294 .44202 L .36891 .43491 L F
.42587 .83597 m .41597 .83944 L .42721 .83738 L .592 .769 .964 r
F
.42587 .83597 m .41327 .83664 L .41597 .83944 L F
.44051 .72492 m .42491 .72153 L .42529 .72681 L .676 .463 .589 r
F
0 g
.41117 .73035 m
.42529 .72681 L
s
.44051 .72492 m .44011 .71965 L .42491 .72153 L .676 .463 .589 r
F
0 g
.41081 .72508 m
.42491 .72153 L
s
.47673 .83735 m .47848 .82866 L .47816 .83316 L 0 0 .157 r
F
.47642 .84184 m .47673 .83735 L .47816 .83316 L F
.46414 .83517 m .47673 .83735 L .47816 .83316 L .593 .769 .963 r
F
0 g
.47275 .84106 m
.47673 .83735 L
s
.4262 .82554 m .41416 .82766 L .42667 .82699 L .594 .768 .963 r
F
.4262 .82554 m .41318 .82476 L .41416 .82766 L F
.46118 .84215 m .47642 .84184 L .46381 .83967 L .592 .769 .964 r
F
.44987 .83873 m .46118 .84215 L .46381 .83967 L F
.44779 .83974 m .46118 .84215 L .44987 .83873 L F
.75462 .57929 m .72862 .58334 L .73251 .5896 L .653 .783 .943 r
F
0 g
.58357 .48062 m
.60911 .48001 L
s
.39154 .57619 m .41922 .56865 L .39305 .56926 L .656 .781 .94 r
F
.36615 .57335 m .39154 .57619 L .39305 .56926 L F
.57038 .58932 m .53943 .58893 L .56159 .59498 L .654 .783 .943 r
F
.46434 .83066 m .47828 .82865 L .46526 .82787 L .594 .768 .963 r
F
.4518 .82849 m .46434 .83066 L .46526 .82787 L F
0 g
.60911 .48001 m
.63428 .48328 L
s
.26124 .57875 m .26541 .58266 L .26532 .58901 L .973 .75 .324 r
F
.26124 .57875 m .26134 .57237 L .26541 .58266 L F
0 g
.26541 .58266 m
.27075 .58814 L
s
.28806 .57174 m .26579 .5826 L .29063 .57858 L .656 .781 .94 r
F
.28806 .57174 m .26174 .57236 L .26579 .5826 L F
.56198 .60135 m .53978 .59533 L .5313 .60501 L .653 .784 .944 r
F
0 g
.52802 .61511 m
.5313 .60501 L
s
.45573 .72482 m .44011 .71965 L .44051 .72492 L .732 .505 .584 r
F
0 g
.42491 .72153 m
.44011 .71965 L
s
.44011 .71965 m
.45531 .71956 L
s
.45573 .72482 m
.46984 .72652 L
s
.41745 .59173 m .41977 .575 L .41993 .58138 L 0 0 .24 r
F
.39201 .58893 m .41745 .59173 L .41993 .58138 L .654 .782 .942 r
F
0 g
.40986 .60137 m
.41745 .59173 L
s
.44051 .72492 m
.45573 .72482 L
s
.61392 .60053 m .60879 .58705 L .60722 .60025 L .653 .784 .944 r
F
.61392 .60053 m .6223 .58763 L .60879 .58705 L F
.71332 .459 m .69584 .46219 L .69579 .47014 L .389 .215 .52 r
F
.71332 .459 m .71332 .45101 L .69584 .46219 L F
0 g
.68407 .47543 m
.69584 .46219 L
s
.53075 .4537 m .52982 .47297 L .5468 .47256 L .642 .738 .918 r
F
.52222 .45259 m .52982 .47297 L .53075 .4537 L F
.52222 .45259 m .51296 .47079 L .52982 .47297 L F
.60042 .60086 m .59504 .58829 L .58207 .59125 L .653 .784 .944 r
F
.60722 .60025 m .59504 .58829 L .60042 .60086 L F
.86563 .4711 m .85265 .45037 L .85298 .45834 L .953 .671 .466 r
F
.86599 .47909 m .86563 .4711 L .85298 .45834 L F
0 g
.86563 .4711 m
.87186 .4853 L
s
.64364 .58128 m .64815 .56544 L .63346 .57734 L .654 .782 .942 r
F
.64364 .58128 m .66344 .57146 L .64815 .56544 L F
.31541 .58732 m .29624 .59758 L .31835 .59046 L F
.31541 .58732 m .29026 .59136 L .29624 .59758 L F
.55498 .71219 m .56325 .71182 L .56381 .71708 L .925 .647 .497 r
F
.55498 .71219 m .55443 .7069 L .56325 .71182 L F
.57187 .70132 m .56325 .71182 L .57773 .70463 L .656 .809 .957 r
F
.57187 .70132 m .55443 .7069 L .56325 .71182 L F
0 g
.56325 .71182 m
.5703 .71388 L
s
.74891 .45271 m .73552 .43506 L .71364 .44328 L .644 .736 .916 r
F
.76533 .44969 m .73552 .43506 L .74891 .45271 L F
.60722 .60025 m .60879 .58705 L .59504 .58829 L .653 .784 .944 r
F
.81396 .45612 m .81158 .4331 L .79908 .45146 L .644 .736 .916 r
F
.81396 .45612 m .83409 .44023 L .81158 .4331 L F
.29726 .47556 m .27268 .46077 L .25839 .47189 L .641 .739 .92 r
F
0 g
.25947 .46394 m
.26841 .45694 L
s
.2503 .48507 m
.25839 .47189 L
s
.31026 .47021 m .27268 .46077 L .29726 .47556 L .641 .739 .92 r
F
.67545 .58566 m .67487 .57931 L .66374 .57131 L .937 .657 .483 r
F
0 g
.67487 .57931 m
.68104 .58866 L
s
.41228 .83374 m .4007 .8373 L .41327 .83664 L .592 .769 .964 r
F
.41228 .83374 m .39916 .83295 L .4007 .8373 L F
0 g
.4007 .8373 m
.40478 .84149 L
s
.38966 .48042 m .39164 .4578 L .37585 .47365 L .641 .739 .92 r
F
.38966 .48042 m .41244 .46812 L .39164 .4578 L F
.42576 .83002 m .41365 .83215 L .42624 .83148 L .593 .769 .963 r
F
.42576 .83002 m .41266 .82924 L .41365 .83215 L F
.47642 .84184 m .47816 .83316 L .47785 .83766 L 0 0 .157 r
F
.46381 .83967 m .47642 .84184 L .47785 .83766 L .592 .769 .964 r
F
0 g
.47243 .84554 m
.47642 .84184 L
s
.70197 .5771 m .7021 .58102 L .70272 .58738 L 0 0 .091 r
F
0 g
.70228 .5813 m
.70586 .58689 L
s
.70197 .5771 m .70135 .57071 L .7021 .58102 L 0 0 .091 r
F
.65609 .70031 m .65541 .69506 L .66238 .68815 L .269 .176 .561 r
F
0 g
.64619 .70062 m
.65541 .69506 L
s
.72785 .57008 m .70249 .58096 L .72821 .57694 L .654 .782 .942 r
F
.72785 .57008 m .70174 .5707 L .70249 .58096 L F
.46414 .83517 m .47816 .83316 L .46506 .83237 L .593 .769 .963 r
F
.45152 .83299 m .46414 .83517 L .46506 .83237 L F
.50807 .43873 m .49781 .45818 L .5148 .44222 L .643 .737 .917 r
F
.50807 .43873 m .4844 .45133 L .49781 .45818 L F
0 g
.42529 .72681 m
.44051 .72492 L
s
.51432 .45022 m .51296 .47079 L .52222 .45259 L .642 .738 .918 r
F
.51432 .45022 m .4973 .46613 L .51296 .47079 L F
.85435 .5901 m .85922 .57334 L .8601 .57973 L .041 .016 .498 r
F
.83021 .58729 m .85435 .5901 L .8601 .57973 L .653 .784 .944 r
F
0 g
.84379 .59976 m
.85435 .5901 L
s
.53934 .45349 m .5468 .47256 L .56283 .46958 L .642 .738 .918 r
F
.53075 .4537 m .5468 .47256 L .53934 .45349 L F
.54783 .44395 m .56319 .46161 L .5772 .4562 L .643 .737 .917 r
F
.53976 .44549 m .56319 .46161 L .54783 .44395 L F
.4518 .82849 m .46526 .82787 L .45224 .82709 L .594 .768 .963 r
F
.43561 .43629 m .4462 .44303 L .44557 .45095 L .985 .743 .486 r
F
.43561 .43629 m .43628 .42834 L .4462 .44303 L F
0 g
.4462 .44303 m
.45315 .44876 L
s
.4685 .42485 m .44663 .4429 L .47494 .43467 L .644 .737 .916 r
F
.4685 .42485 m .43675 .42829 L .44663 .4429 L F
.60149 .70443 m .59534 .71337 L .60537 .71331 L .655 .81 .957 r
F
.75533 .58568 m .73318 .59596 L .75722 .58882 L .653 .784 .944 r
F
.75533 .58568 m .72929 .58973 L .73318 .59596 L F
.3919 .58256 m .41977 .575 L .39342 .57562 L .655 .781 .941 r
F
.36634 .57972 m .3919 .58256 L .39342 .57562 L F
.61589 .4599 m .61612 .45195 L .62742 .43837 L .138 .015 .437 r
F
0 g
.60566 .45892 m
.61612 .45195 L
s
.57079 .59571 m .53978 .59533 L .56198 .60135 L .653 .784 .944 r
F
.26113 .58516 m .26532 .58901 L .26522 .59539 L .973 .75 .324 r
F
.26113 .58516 m .26124 .57875 L .26532 .58901 L F
.28773 .57812 m .26532 .58901 L .29032 .58498 L .655 .781 .941 r
F
.28773 .57812 m .26124 .57875 L .26532 .58901 L F
0 g
.26532 .58901 m
.27069 .59451 L
s
.58833 .44063 m .61571 .45178 L .62695 .43827 L .644 .737 .916 r
F
.57731 .44811 m .61571 .45178 L .58833 .44063 L F
.73428 .47382 m .71332 .459 L .69579 .47014 L .643 .738 .918 r
F
0 g
.684 .48335 m
.69579 .47014 L
s
.74894 .46845 m .71332 .459 L .73428 .47382 L .643 .738 .918 r
F
.82683 .47868 m .83497 .45601 L .81463 .4719 L F
.82683 .47868 m .85331 .46635 L .83497 .45601 L F
.57245 .70661 m .56381 .71708 L .57831 .70991 L .655 .81 .957 r
F
.57245 .70661 m .55498 .71219 L .56381 .71708 L F
0 g
.56381 .71708 m
.57551 .72048 L
s
.42832 .48083 m .41316 .46011 L .41244 .46812 L .918 .667 .544 r
F
0 g
.42832 .48083 m
.43824 .49496 L
s
.43678 .90623 m
.4368 .90518 L
s
.31435 .57112 m .28806 .57174 L .29063 .57858 L .656 .781 .94 r
F
.36142 .45323 m .34322 .43155 L .34448 .45103 L .643 .738 .918 r
F
.36142 .45323 m .36891 .43491 L .34322 .43155 L F
.57015 .58304 m .55247 .57409 L .53941 .58265 L .654 .782 .942 r
F
.58134 .57858 m .55247 .57409 L .57015 .58304 L F
.42539 .83452 m .41327 .83664 L .42587 .83597 L .592 .769 .964 r
F
.42539 .83452 m .41228 .83374 L .41327 .83664 L F
.46381 .83967 m .47785 .83766 L .46473 .83688 L F
.45117 .83749 m .46381 .83967 L .46473 .83688 L F
.44987 .83873 m .46381 .83967 L .45117 .83749 L F
.37665 .46567 m .3682 .44263 L .36065 .461 L .642 .738 .919 r
F
.37665 .46567 m .39241 .44977 L .3682 .44263 L F
.64436 .58754 m .64891 .57166 L .63412 .58359 L .654 .783 .943 r
F
.64436 .58754 m .66431 .57769 L .64891 .57166 L F
.45152 .83299 m .46506 .83237 L .45196 .83159 L .593 .769 .963 r
F
.40071 .82422 m .39997 .82397 L .39957 .82845 L 0 0 .079 r
F
0 g
.40042 .82528 m
.40149 .82834 L
s
.41397 .82194 m .40016 .82398 L .41318 .82476 L .594 .768 .963 r
F
.41397 .82194 m .4013 .81975 L .40016 .82398 L F
.40071 .82422 m .40111 .81972 L .39997 .82397 L 0 0 .079 r
F
.59685 .70384 m .59534 .71337 L .60149 .70443 L .655 .81 .957 r
F
.59685 .70384 m .58612 .71221 L .59534 .71337 L F
.65609 .70031 m .66238 .68815 L .66307 .69342 L .269 .176 .561 r
F
.65677 .70557 m .65609 .70031 L .66307 .69342 L F
.63989 .69692 m .65609 .70031 L .66307 .69342 L .656 .809 .957 r
F
.6331 .70104 m .65609 .70031 L .63989 .69692 L F
0 g
.64681 .70589 m
.65609 .70031 L
s
.42661 .82413 m .41318 .82476 L .4262 .82554 L .594 .768 .963 r
F
.42661 .82413 m .41397 .82194 L .41318 .82476 L F
.45224 .82709 m .4644 .82496 L .45179 .82564 L F
.45224 .82709 m .46526 .82787 L .4644 .82496 L F
.67545 .58566 m .66374 .57131 L .66431 .57769 L .937 .657 .483 r
F
.67602 .59204 m .67545 .58566 L .66431 .57769 L F
0 g
.67545 .58566 m
.68163 .59499 L
s
.46526 .82787 m .47704 .82428 L .4644 .82496 L .594 .768 .963 r
F
.46526 .82787 m .47828 .82865 L .47704 .82428 L F
.47816 .83316 m .47848 .82866 L .47723 .82427 L .947 .768 .306 r
F
0 g
.47705 .83286 m
.47788 .83043 L
s
.50359 .42634 m .48518 .44327 L .50868 .4307 L .644 .737 .916 r
F
.50359 .42634 m .47494 .43467 L .48518 .44327 L F
.82937 .58092 m .85922 .57334 L .83308 .57397 L .653 .783 .943 r
F
.55513 .43314 m .57731 .44811 L .58833 .44063 L .644 .737 .916 r
F
.54815 .43589 m .57731 .44811 L .55513 .43314 L F
.75392 .56946 m .72821 .57694 L .75404 .5729 L .654 .782 .942 r
F
.75392 .56946 m .72785 .57008 L .72821 .57694 L F
.72825 .57647 m .70272 .58738 L .72862 .58334 L .653 .783 .943 r
F
.72825 .57647 m .70197 .5771 L .70272 .58738 L F
.7026 .58351 m .70272 .58738 L .70335 .59376 L 0 0 .091 r
F
0 g
.7029 .58766 m
.70651 .59327 L
s
.7026 .58351 m .70197 .5771 L .70272 .58738 L 0 0 .091 r
F
.61653 .70256 m .62523 .70966 L .63375 .70631 L .655 .81 .957 r
F
.86599 .47909 m .85298 .45834 L .85331 .46635 L .953 .671 .466 r
F
0 g
.86599 .47909 m
.87223 .49325 L
s
.36615 .57335 m .39305 .56926 L .36684 .56988 L .656 .781 .94 r
F
.76533 .44969 m .76038 .43041 L .73552 .43506 L .644 .736 .916 r
F
.78247 .44926 m .76038 .43041 L .76533 .44969 L F
.79908 .45146 m .78639 .42974 L .78247 .44926 L F
.79908 .45146 m .81158 .4331 L .78639 .42974 L F
.74886 .46047 m .73537 .44277 L .71332 .45101 L .644 .737 .917 r
F
.7654 .45745 m .73537 .44277 L .74886 .46047 L F
.81439 .46392 m .81201 .44082 L .7994 .45924 L F
.81439 .46392 m .83468 .44798 L .81201 .44082 L F
.39201 .58893 m .41993 .58138 L .39353 .58201 L .654 .782 .942 r
F
.36641 .5861 m .39201 .58893 L .39353 .58201 L F
.36397 .58936 m .39201 .58893 L .36641 .5861 L F
.28767 .58453 m .26522 .59539 L .29026 .59136 L F
.28767 .58453 m .26113 .58516 L .26522 .59539 L F
0 g
.26522 .59539 m
.27432 .60465 L
s
.45117 .83749 m .46473 .83688 L .45162 .83609 L .592 .769 .964 r
F
.40031 .82873 m .39957 .82845 L .39916 .83295 L 0 0 .079 r
F
0 g
.40003 .82977 m
.4011 .83282 L
s
.41346 .82642 m .39957 .82845 L .41266 .82924 L .593 .769 .963 r
F
.41346 .82642 m .40071 .82422 L .39957 .82845 L F
.40031 .82873 m .40071 .82422 L .39957 .82845 L 0 0 .079 r
F
.50757 .44674 m .4973 .46613 L .51432 .45022 L .642 .738 .918 r
F
.50757 .44674 m .48385 .4593 L .4973 .46613 L F
.42618 .82861 m .41266 .82924 L .42576 .83002 L .593 .769 .963 r
F
.42618 .82861 m .41346 .82642 L .41266 .82924 L F
.45196 .83159 m .4642 .82945 L .45151 .83013 L F
.45196 .83159 m .46506 .83237 L .4642 .82945 L F
.53934 .45349 m .56283 .46958 L .54743 .45195 L .642 .738 .918 r
F
.54743 .45195 m .56283 .46958 L .57688 .46418 L F
.46506 .83237 m .47692 .82878 L .4642 .82945 L .593 .769 .963 r
F
.46506 .83237 m .47816 .83316 L .47692 .82878 L F
.47816 .83316 m .47723 .82427 L .47692 .82878 L .947 .768 .306 r
F
.47785 .83766 m .47816 .83316 L .47692 .82878 L F
0 g
.47673 .83735 m
.47756 .83492 L
s
.42788 .82287 m .41397 .82194 L .42661 .82413 L .594 .768 .963 r
F
.55258 .58036 m .53907 .58256 L .53943 .58893 L .403 .25 .557 r
F
.55258 .58036 m .5522 .57395 L .53907 .58256 L F
0 g
.53063 .59229 m
.53907 .58256 L
s
.65677 .70557 m .66307 .69342 L .66377 .6987 L .269 .176 .561 r
F
.64056 .70219 m .65677 .70557 L .66377 .6987 L .655 .81 .957 r
F
.63375 .70631 m .65677 .70557 L .64056 .70219 L F
0 g
.64655 .71169 m
.65677 .70557 L
s
.3142 .5775 m .28773 .57812 L .29032 .58498 L .655 .781 .941 r
F
.45179 .82564 m .46181 .82213 L .45049 .82423 L .594 .768 .963 r
F
.45179 .82564 m .4644 .82496 L .46181 .82213 L F
.43494 .44429 m .44557 .45095 L .44493 .45891 L .985 .743 .486 r
F
.43494 .44429 m .43561 .43629 L .44557 .45095 L F
.46759 .43286 m .44557 .45095 L .47408 .44271 L .643 .737 .917 r
F
.46759 .43286 m .43561 .43629 L .44557 .45095 L F
0 g
.44557 .45095 m
.45258 .45671 L
s
.57038 .58932 m .55258 .58036 L .53943 .58893 L .654 .783 .943 r
F
.58165 .58485 m .55258 .58036 L .57038 .58932 L F
.78247 .44926 m .78639 .42974 L .76038 .43041 L .644 .736 .916 r
F
.63346 .57734 m .6297 .56183 L .62124 .57498 L .654 .782 .942 r
F
.63346 .57734 m .64815 .56544 L .6297 .56183 L F
.64489 .59392 m .64945 .57808 L .63463 .58998 L .653 .784 .944 r
F
.64489 .59392 m .66487 .58409 L .64945 .57808 L F
0 g
.44024 .90347 m
.44027 .90233 L
s
.61589 .4599 m .62742 .43837 L .62721 .44635 L .138 .015 .437 r
F
.61566 .46788 m .61589 .4599 L .62721 .44635 L F
.5883 .4487 m .61589 .4599 L .62721 .44635 L .643 .737 .917 r
F
.5772 .4562 m .61589 .4599 L .5883 .4487 L F
0 g
.60533 .4669 m
.61589 .4599 L
s
.43327 .90338 m
.43328 .90282 L
s
.4333 .90217 m
.43335 .9001 L
s
.43337 .89932 m
.43508 .83428 L
s
.59294 .70267 m .58612 .71221 L .59685 .70384 L .655 .81 .957 r
F
.59294 .70267 m .57831 .70991 L .58612 .71221 L F
.67602 .59204 m .66431 .57769 L .66487 .58409 L .937 .657 .483 r
F
0 g
.67602 .59204 m
.68221 .60133 L
s
.54909 .70079 m .55388 .70163 L .55443 .7069 L .983 .696 .368 r
F
.54909 .70079 m .54854 .6955 L .55388 .70163 L F
0 g
.55388 .70163 m
.56007 .7051 L
s
.56799 .69189 m .55414 .70154 L .57147 .69598 L .656 .808 .956 r
F
.56799 .69189 m .54883 .69544 L .55414 .70154 L F
.83021 .58729 m .8601 .57973 L .83392 .58036 L .653 .784 .944 r
F
.80592 .58446 m .83021 .58729 L .83392 .58036 L F
.80247 .58773 m .83021 .58729 L .80592 .58446 L F
.39305 .56926 m .41922 .56865 L .41632 .55826 L .656 .781 .94 r
F
.41977 .575 m .41962 .56864 L .4167 .5582 L .914 .697 .198 r
F
0 g
.4181 .57504 m
.41905 .57103 L
s
.7545 .57584 m .72862 .58334 L .75462 .57929 L .653 .783 .943 r
F
.7545 .57584 m .72825 .57647 L .72862 .58334 L F
.72892 .58288 m .70335 .59376 L .72929 .58973 L .653 .784 .944 r
F
.72892 .58288 m .7026 .58351 L .70335 .59376 L F
0 g
.70335 .59376 m
.70934 .60304 L
s
.41316 .46011 m .41388 .45214 L .39318 .44178 L .852 .601 .56 r
F
0 g
.41388 .45214 m
.42967 .46491 L
s
.31026 .47021 m .29225 .45257 L .27268 .46077 L .641 .739 .92 r
F
0 g
.25839 .47189 m
.27268 .46077 L
s
.32578 .4672 m .29225 .45257 L .31026 .47021 L .641 .739 .92 r
F
.36065 .461 m .34231 .43926 L .34359 .45879 L .642 .738 .919 r
F
.36065 .461 m .3682 .44263 L .34231 .43926 L F
.41307 .83092 m .39916 .83295 L .41228 .83374 L .592 .769 .964 r
F
.41307 .83092 m .40031 .82873 L .39916 .83295 L F
0 g
.39916 .83295 m
.4007 .8373 L
s
.37585 .47365 m .36736 .45067 L .35981 .46899 L .641 .739 .92 r
F
.37585 .47365 m .39164 .4578 L .36736 .45067 L F
.4258 .83312 m .41228 .83374 L .42539 .83452 L .592 .769 .964 r
F
.4258 .83312 m .41307 .83092 L .41228 .83374 L F
.36634 .57972 m .39342 .57562 L .36704 .57625 L .655 .781 .941 r
F
.45162 .83609 m .46387 .83396 L .45117 .83464 L .592 .769 .964 r
F
.45162 .83609 m .46473 .83688 L .46387 .83396 L F
.46473 .83688 m .4766 .83329 L .46387 .83396 L F
.46473 .83688 m .47785 .83766 L .4766 .83329 L F
.47785 .83766 m .47692 .82878 L .4766 .83329 L .947 .768 .306 r
F
0 g
.47642 .84184 m
.47785 .83766 L
s
.42746 .82735 m .41346 .82642 L .42618 .82861 L .593 .769 .963 r
F
.21291 .43868 m .23867 .43786 L .23754 .44579 L .789 .546 .569 r
F
.21291 .43868 m .2141 .43073 L .23867 .43786 L F
0 g
.23867 .43786 m
.2401 .43804 L
s
.42788 .82287 m .4165 .81942 L .41397 .82194 L .594 .768 .963 r
F
.42994 .82185 m .4165 .81942 L .42788 .82287 L F
.45151 .83013 m .4616 .82661 L .4502 .82871 L .593 .769 .963 r
F
.45151 .83013 m .4642 .82945 L .4616 .82661 L F
.50294 .43436 m .4844 .45133 L .50807 .43873 L .643 .737 .917 r
F
.50294 .43436 m .47408 .44271 L .4844 .45133 L F
.45049 .82423 m .45767 .81957 L .44841 .82295 L .594 .768 .963 r
F
.45049 .82423 m .46181 .82213 L .45767 .81957 L F
.4165 .81942 m .4013 .81975 L .41397 .82194 L F
.39305 .56926 m .41632 .55826 L .39098 .56235 L .656 .781 .94 r
F
.36684 .56988 m .39305 .56926 L .39098 .56235 L F
.58134 .57858 m .56932 .5673 L .55247 .57409 L .654 .782 .942 r
F
.59421 .57562 m .56932 .5673 L .58134 .57858 L F
.22842 .4142 m .23876 .43758 L .24487 .41902 L .643 .737 .917 r
F
.22842 .4142 m .21431 .43049 L .23876 .43758 L F
.4644 .82496 m .4732 .82002 L .46181 .82213 L .594 .768 .963 r
F
.4644 .82496 m .47704 .82428 L .4732 .82002 L F
.55486 .44119 m .5772 .4562 L .5883 .4487 L .643 .737 .917 r
F
.54783 .44395 m .5772 .4562 L .55486 .44119 L F
.62081 .70087 m .63375 .70631 L .64056 .70219 L .655 .81 .957 r
F
.61653 .70256 m .63375 .70631 L .62081 .70087 L F
.73537 .44277 m .71332 .44306 L .71332 .45101 L .512 .311 .544 r
F
.73537 .44277 m .73532 .43479 L .71332 .44306 L F
0 g
.69588 .45426 m
.71332 .44306 L
s
.55296 .58678 m .53943 .58893 L .53978 .59533 L .403 .25 .557 r
F
.55296 .58678 m .55258 .58036 L .53943 .58893 L F
0 g
.53097 .59864 m
.53943 .58893 L
s
.85922 .57334 m .85833 .56698 L .85877 .55652 L 0 0 .251 r
F
0 g
.85479 .57345 m
.85833 .56698 L
s
.31418 .5839 m .29026 .59136 L .31541 .58732 L .654 .782 .942 r
F
.31418 .5839 m .28767 .58453 L .29026 .59136 L F
.83198 .56761 m .85794 .56699 L .85837 .55658 L F
.54964 .7061 m .55443 .7069 L .55498 .71219 L .983 .696 .368 r
F
.54964 .7061 m .54909 .70079 L .55443 .7069 L F
.56837 .69722 m .55443 .7069 L .57187 .70132 L .656 .809 .957 r
F
.56837 .69722 m .54909 .70079 L .55443 .7069 L F
0 g
.55443 .7069 m
.56066 .71037 L
s
.36684 .56988 m .39098 .56235 L .36575 .56643 L .656 .781 .94 r
F
.57079 .59571 m .55296 .58678 L .53978 .59533 L .653 .784 .944 r
F
0 g
.5313 .60501 m
.53978 .59533 L
s
.58207 .59125 m .55296 .58678 L .57079 .59571 L .653 .784 .944 r
F
.85298 .45834 m .85265 .45037 L .83439 .43999 L .872 .6 .524 r
F
0 g
.85265 .45037 m
.86528 .46316 L
s
.74894 .46845 m .73542 .45078 L .71332 .459 L .643 .738 .918 r
F
.76552 .46544 m .73542 .45078 L .74894 .46845 L F
.7654 .45745 m .76042 .43812 L .73537 .44277 L .644 .737 .917 r
F
.78267 .45703 m .76042 .43812 L .7654 .45745 L F
.7994 .45924 m .78662 .43745 L .78267 .45703 L F
.7994 .45924 m .81201 .44082 L .78662 .43745 L F
.63412 .58359 m .63033 .56805 L .62181 .58123 L .654 .783 .943 r
F
.63412 .58359 m .64891 .57166 L .63033 .56805 L F
.81463 .4719 m .81224 .44887 L .7996 .46723 L .643 .738 .918 r
F
.81463 .4719 m .83497 .45601 L .81224 .44887 L F
.42994 .82185 m .42059 .81735 L .4165 .81942 L .594 .768 .963 r
F
.43263 .82113 m .42059 .81735 L .42994 .82185 L F
.44841 .82295 m .45224 .81746 L .4457 .82191 L F
.44841 .82295 m .45767 .81957 L .45224 .81746 L F
.42709 .83186 m .41307 .83092 L .4258 .83312 L .592 .769 .964 r
F
.83198 .56761 m .85837 .55658 L .83213 .56068 L .654 .782 .942 r
F
.80599 .56822 m .83198 .56761 L .83213 .56068 L F
.42746 .82735 m .416 .82388 L .41346 .82642 L .593 .769 .963 r
F
.42952 .82633 m .416 .82388 L .42746 .82735 L F
.45117 .83464 m .46126 .83113 L .44985 .83322 L .592 .769 .964 r
F
.45117 .83464 m .46387 .83396 L .46126 .83113 L F
.4502 .82871 m .45742 .82405 L .44811 .82744 L .593 .769 .963 r
F
.4502 .82871 m .4616 .82661 L .45742 .82405 L F
.416 .82388 m .40071 .82422 L .41346 .82642 L F
.41977 .575 m .4167 .5582 L .41686 .56459 L .914 .697 .198 r
F
.39342 .57562 m .41977 .575 L .41686 .56459 L .655 .781 .941 r
F
.41993 .58138 m .41977 .575 L .41686 .56459 L .914 .697 .198 r
F
0 g
.41824 .58142 m
.4192 .5774 L
s
.62124 .57498 m .6094 .56092 L .60783 .57439 L .654 .782 .942 r
F
.62124 .57498 m .6297 .56183 L .6094 .56092 L F
.4165 .81942 m .40505 .81594 L .4013 .81975 L .594 .768 .963 r
F
.40448 .8204 m .40111 .81972 L .40071 .82422 L .079 0 .403 r
F
.40448 .8204 m .40488 .81589 L .40111 .81972 L F
0 g
.39997 .82397 m
.40111 .81972 L
s
.4642 .82945 m .47305 .8245 L .4616 .82661 L .593 .769 .963 r
F
.4642 .82945 m .47692 .82878 L .47305 .8245 L F
.46699 .44087 m .44493 .45891 L .47351 .45069 L .642 .738 .918 r
F
.46699 .44087 m .43494 .44429 L .44493 .45891 L F
0 g
.44493 .45891 m
.46052 .47165 L
s
.66307 .69342 m .66238 .68815 L .66563 .68094 L 0 0 .458 r
F
0 g
.65598 .69449 m
.66238 .68815 L
s
.64365 .68701 m .6621 .68814 L .66533 .68096 L .656 .808 .956 r
F
.47692 .82878 m .47723 .82427 L .47337 .81999 L .982 .749 .508 r
F
0 g
.47723 .82427 m
.47848 .82866 L
s
.36641 .5861 m .39353 .58201 L .36711 .58264 L .654 .782 .942 r
F
.78267 .45703 m .78662 .43745 L .76042 .43812 L .644 .737 .917 r
F
.75522 .58225 m .72929 .58973 L .75533 .58568 L .653 .784 .944 r
F
.75522 .58225 m .72892 .58288 L .72929 .58973 L F
.61566 .46788 m .62721 .44635 L .627 .45437 L .138 .015 .437 r
F
.588 .45671 m .61566 .46788 L .627 .45437 L .642 .738 .918 r
F
.57688 .46418 m .61566 .46788 L .588 .45671 L F
0 g
.60265 .47645 m
.61566 .46788 L
s
.80599 .56822 m .83213 .56068 L .806 .56477 L .654 .782 .942 r
F
.63989 .69692 m .66307 .69342 L .64451 .6923 L .656 .809 .957 r
F
.31492 .56763 m .28806 .57174 L .31435 .57112 L .656 .781 .94 r
F
.39342 .57562 m .41686 .56459 L .39135 .5687 L .655 .781 .941 r
F
.36704 .57625 m .39342 .57562 L .39135 .5687 L F
.43263 .82113 m .42598 .81589 L .42059 .81735 L .594 .768 .963 r
F
.43577 .82076 m .42598 .81589 L .43263 .82113 L F
.4457 .82191 m .4459 .81596 L .44254 .82116 L F
.4457 .82191 m .45224 .81746 L .4459 .81596 L F
.59421 .57562 m .58877 .56279 L .56932 .5673 L .654 .782 .942 r
F
.60783 .57439 m .58877 .56279 L .59421 .57562 L F
.59003 .70101 m .57831 .70991 L .59294 .70267 L .655 .81 .957 r
F
.59003 .70101 m .57245 .70661 L .57831 .70991 L F
.58165 .58485 m .56954 .57354 L .55258 .58036 L .654 .783 .943 r
F
.5946 .58188 m .56954 .57354 L .58165 .58485 L F
.56895 .70253 m .55498 .71219 L .57245 .70661 L .655 .81 .957 r
F
.56895 .70253 m .54964 .7061 L .55498 .71219 L F
0 g
.55498 .71219 m
.56381 .71708 L
s
.41316 .46011 m .39318 .44178 L .39241 .44977 L .852 .601 .56 r
F
.41244 .46812 m .41316 .46011 L .39241 .44977 L F
0 g
.41316 .46011 m
.429 .47285 L
s
.32578 .4672 m .31573 .44795 L .29225 .45257 L .641 .739 .92 r
F
.34271 .46679 m .31573 .44795 L .32578 .4672 L F
.35981 .46899 m .34141 .4473 L .34271 .46679 L F
.35981 .46899 m .36736 .45067 L .34141 .4473 L F
.42952 .82633 m .42012 .82182 L .416 .82388 L .593 .769 .963 r
F
.43223 .8256 m .42012 .82182 L .42952 .82633 L F
.60783 .57439 m .6094 .56092 L .58877 .56279 L .654 .782 .942 r
F
.44811 .82744 m .45196 .82194 L .44538 .82639 L .593 .769 .963 r
F
.44811 .82744 m .45742 .82405 L .45196 .82194 L F
.85922 .57334 m .85877 .55652 L .85966 .56291 L 0 0 .251 r
F
.8601 .57973 m .85922 .57334 L .85966 .56291 L F
.83308 .57397 m .85922 .57334 L .85966 .56291 L .653 .783 .943 r
F
0 g
.85564 .57983 m
.85922 .57334 L
s
.43577 .82076 m .43229 .81515 L .42598 .81589 L .594 .768 .963 r
F
.43915 .82077 m .43229 .81515 L .43577 .82076 L F
.42709 .83186 m .41561 .8284 L .41307 .83092 L .592 .769 .964 r
F
.42915 .83084 m .41561 .8284 L .42709 .83186 L F
.44254 .82116 m .43909 .81517 L .43915 .82077 L .594 .768 .963 r
F
.44254 .82116 m .4459 .81596 L .43909 .81517 L F
.28907 .56474 m .26174 .57236 L .28806 .57174 L .656 .781 .94 r
F
.31492 .56763 m .28907 .56474 L .28806 .57174 L F
.66431 .57769 m .66374 .57131 L .64838 .56526 L .861 .596 .537 r
F
0 g
.66374 .57131 m
.67487 .57931 L
s
.44985 .83322 m .45708 .82857 L .44776 .83195 L .592 .769 .964 r
F
.44985 .83322 m .46126 .83113 L .45708 .82857 L F
.36704 .57625 m .39135 .5687 L .36594 .57279 L .655 .781 .941 r
F
.41561 .8284 m .40031 .82873 L .41307 .83092 L .592 .769 .964 r
F
.21171 .44666 m .23754 .44579 L .2364 .45377 L .789 .546 .569 r
F
.21171 .44666 m .21291 .43868 L .23754 .44579 L F
.22711 .42236 m .23754 .44579 L .24368 .4272 L .642 .738 .918 r
F
.22711 .42236 m .21291 .43868 L .23754 .44579 L F
0 g
.23754 .44579 m
.26127 .44886 L
s
.42059 .81735 m .40505 .81594 L .4165 .81942 L .594 .768 .963 r
F
.40408 .82492 m .40071 .82422 L .40031 .82873 L .079 0 .403 r
F
.416 .82388 m .40448 .8204 L .40071 .82422 L .593 .769 .963 r
F
.40408 .82492 m .40448 .8204 L .40071 .82422 L .079 0 .403 r
F
0 g
.39957 .82845 m
.40071 .82422 L
s
.50243 .44238 m .48385 .4593 L .50757 .44674 L .642 .738 .918 r
F
.50243 .44238 m .47351 .45069 L .48385 .4593 L F
.46387 .83396 m .47272 .82903 L .46126 .83113 L .592 .769 .964 r
F
.46387 .83396 m .4766 .83329 L .47272 .82903 L F
.43915 .82077 m .43909 .81517 L .43229 .81515 L .594 .768 .963 r
F
.63463 .58998 m .63085 .57449 L .6223 .58763 L .653 .784 .944 r
F
.63463 .58998 m .64945 .57808 L .63085 .57449 L F
.80592 .58446 m .83392 .58036 L .80772 .58098 L F
.46181 .82213 m .46699 .81616 L .45767 .81957 L .594 .768 .963 r
F
.46181 .82213 m .4732 .82002 L .46699 .81616 L F
.5872 .68832 m .56799 .69189 L .57147 .69598 L .656 .808 .956 r
F
.55448 .4492 m .57688 .46418 L .588 .45671 L .642 .738 .918 r
F
.54743 .45195 m .57688 .46418 L .55448 .4492 L F
.47692 .82878 m .47337 .81999 L .47305 .8245 L .982 .749 .508 r
F
.4766 .83329 m .47692 .82878 L .47305 .8245 L F
0 g
.47692 .82878 m
.47816 .83316 L
s
.50044 .42139 m .47494 .43467 L .50359 .42634 L .644 .737 .916 r
F
.50044 .42139 m .4685 .42485 L .47494 .43467 L F
.53391 .42134 m .53163 .43765 L .53244 .43763 L F
.53478 .42361 m .53244 .43763 L .54014 .43743 L F
.53391 .42134 m .53244 .43763 L .53478 .42361 L F
.53428 .40592 m .53449 .42015 L .53432 .42027 L .358 .18 .498 r
F
.53549 .40467 m .53562 .40385 L .53566 .41836 L 0 0 .15 r
F
.53523 .42097 m .54014 .43743 L .54415 .43666 L .644 .737 .916 r
F
.53878 .42507 m .54415 .43666 L .54815 .43589 L F
.53523 .42097 m .54415 .43666 L .53878 .42507 L F
.53514 .42149 m .54014 .43743 L .53523 .42097 L F
.53503 .40535 m .53549 .40467 L .53554 .41913 L .08 0 .418 r
F
.53449 .42054 m .54014 .43743 L .53483 .42052 L .644 .737 .916 r
F
.53405 .42115 m .54014 .43743 L .53449 .42054 L F
.53367 .42072 m .54014 .43743 L .53384 .4206 L F
.53483 .42052 m .53514 .42149 L .53523 .42097 L F
.53428 .40592 m .53503 .40535 L .53507 .41976 L .358 .18 .498 r
F
.53428 .40592 m .53507 .41976 L .53449 .42015 L F
.53153 .40656 m .5332 .40636 L .53324 .42065 L .641 .401 .54 r
F
.53153 .40656 m .53324 .42065 L .53193 .42075 L F
.53503 .40535 m .53518 .41961 L .53507 .41976 L .08 0 .418 r
F
.53503 .40535 m .53554 .41913 L .53518 .41961 L F
.53549 .40467 m .53566 .41836 L .53556 .41895 L 0 0 .15 r
F
.53549 .40467 m .53556 .41895 L .53554 .41913 L F
.53562 .40385 m .53515 .4028 L .5352 .41735 L .983 .725 .332 r
F
.53547 .41987 m .53763 .42259 L .53677 .42074 L .644 .737 .916 r
F
.5332 .40636 m .53348 .42056 L .53324 .42065 L .517 .303 .528 r
F
.53384 .4206 m .53405 .42115 L .53449 .42054 L .644 .737 .916 r
F
.53363 .42061 m .53367 .42072 L .53384 .4206 L F
.5332 .40636 m .53428 .40592 L .53432 .42027 L .517 .303 .528 r
F
.53455 .42019 m .53363 .42061 L .53483 .42052 L .644 .737 .916 r
F
.53359 .42052 m .53363 .42061 L .53455 .42019 L F
.53367 .42072 m .53353 .42186 L .53391 .42134 L F
.53353 .42186 m .53163 .43765 L .53391 .42134 L F
.53363 .42061 m .53361 .42075 L .53367 .42072 L F
.53361 .42075 m .53163 .43765 L .53367 .42072 L F
.5332 .40636 m .53432 .42027 L .53348 .42056 L .517 .303 .528 r
F
.53258 .41792 m .53245 .42071 L .53363 .42061 L .644 .737 .916 r
F
.53245 .42071 m .53163 .43765 L .53363 .42061 L F
.53258 .41792 m .53455 .42019 L .53483 .42009 L F
.53515 .41965 m .53483 .42009 L .53547 .41987 L F
.53258 .41792 m .53483 .42009 L .53515 .41965 L F
.53455 .42019 m .54815 .43589 L .53547 .41987 L F
.53258 .41792 m .55513 .43314 L .55589 .43261 L F
.54014 .421 m .55589 .43261 L .56062 .42934 L F
.53258 .41792 m .55589 .43261 L .54014 .421 L F
.53307 .42388 m .53459 .42787 L .53781 .42706 L .668 .747 .909 r
F
.53677 .42074 m .54815 .43589 L .55513 .43314 L .644 .737 .916 r
F
.53763 .42259 m .54815 .43589 L .53677 .42074 L F
.53468 .42348 m .53781 .42706 L .54062 .42576 L .668 .747 .909 r
F
.53307 .42388 m .53781 .42706 L .53468 .42348 L F
.53468 .42348 m .54062 .42576 L .53609 .42283 L F
.53737 .41895 m .56062 .42934 L .56423 .42474 L .644 .737 .916 r
F
.53258 .41792 m .54014 .421 L .53737 .41895 L F
.54014 .421 m .56062 .42934 L .53737 .41895 L F
.53515 .4028 m .53404 .40198 L .53408 .41652 L .911 .629 .497 r
F
.53478 .42663 m .53505 .42674 L .53509 .42648 L .667 .747 .91 r
F
.53153 .40656 m .53193 .42075 L .53155 .42078 L .641 .401 .54 r
F
.52884 .40583 m .52988 .4063 L .5299 .42047 L .845 .571 .524 r
F
.52775 .40453 m .52814 .40523 L .52815 .4194 L .988 .719 .384 r
F
.53218 .42621 m .52856 .43038 L .53163 .43765 L .644 .737 .916 r
F
.52856 .43038 m .52319 .43654 L .52903 .43731 L F
.52856 .43038 m .52903 .43731 L .53163 .43765 L F
.52769 .40372 m .52775 .40453 L .52776 .41872 L .781 .623 .061 r
F
.53122 .42459 m .52844 .42872 L .53218 .42621 L .644 .737 .916 r
F
.52844 .42872 m .52319 .43654 L .52856 .43038 L F
.52844 .42872 m .52856 .43038 L .53218 .42621 L F
.53186 .42252 m .53091 .42406 L .53234 .42292 L F
.53091 .42406 m .52319 .43654 L .53122 .42459 L F
.53091 .42406 m .53122 .42459 L .53234 .42292 L F
.5321 .4215 m .53162 .42232 L .5324 .42164 L F
.53162 .42232 m .52319 .43654 L .53186 .42252 L F
.53162 .42232 m .53186 .42252 L .5324 .42164 L F
.53117 .42071 m .53103 .421 L .53244 .42094 L F
.53103 .421 m .52319 .43654 L .5321 .4215 L F
.53103 .421 m .5321 .4215 L .53244 .42094 L F
.52884 .40583 m .5299 .42047 L .52908 .42009 L .845 .571 .524 r
F
.52988 .4063 m .53153 .40656 L .53155 .42078 L .751 .491 .539 r
F
.52988 .4063 m .53155 .42078 L .53026 .42054 L F
.52814 .40523 m .52831 .41953 L .52815 .4194 L .929 .648 .487 r
F
.52775 .40453 m .52784 .41887 L .52776 .41872 L .988 .719 .384 r
F
.52769 .40372 m .52771 .41812 L .5277 .41795 L .781 .623 .061 r
F
.52769 .40372 m .52776 .41872 L .52771 .41812 L F
.52775 .40453 m .52815 .4194 L .52784 .41887 L .988 .719 .384 r
F
.52814 .40523 m .52884 .40583 L .52885 .41999 L .929 .648 .487 r
F
.52814 .40523 m .52885 .41999 L .52831 .41953 L F
.52825 .40268 m .52769 .40372 L .5277 .41795 L 0 0 .377 r
F
.53117 .42071 m .52093 .42943 L .52319 .43654 L .644 .737 .916 r
F
.52988 .42047 m .52161 .42827 L .53117 .42071 L F
.52161 .42827 m .51536 .43417 L .52093 .42943 L F
.52161 .42827 m .52093 .42943 L .53117 .42071 L F
.52988 .4063 m .53026 .42054 L .5299 .42047 L .751 .491 .539 r
F
.52884 .40583 m .52908 .42009 L .52885 .41999 L .845 .571 .524 r
F
.53258 .41792 m .50868 .4307 L .51536 .43417 L .644 .737 .916 r
F
.53103 .43541 m .53096 .43229 L .53612 .43189 L .666 .426 .548 r
F
.53155 .43814 m .52268 .44459 L .53119 .44571 L .643 .737 .917 r
F
.53147 .43813 m .52268 .44459 L .53155 .43814 L F
.52703 .43755 m .53103 .43541 L .53109 .43808 L .731 .478 .545 r
F
.52591 .43497 m .53096 .43229 L .53103 .43541 L F
.53103 .43541 m .53612 .43189 L .5362 .43501 L .666 .426 .548 r
F
.53156 .43806 m .53147 .43813 L .53155 .43814 L .643 .737 .917 r
F
.52786 .43816 m .52268 .44459 L .53156 .43806 L F
.53181 .43806 m .53103 .43541 L .5362 .43501 L .666 .426 .548 r
F
.53109 .43808 m .53103 .43541 L .53181 .43806 L F
.53116 .42813 m .53097 .43223 L .5361 .43183 L .668 .747 .909 r
F
.53116 .42813 m .5361 .43183 L .53459 .42787 L F
.53123 .4313 m .53103 .43541 L .5362 .43501 L .667 .747 .91 r
F
.53156 .43806 m .53119 .44571 L .53205 .43805 L .643 .737 .917 r
F
.53296 .43803 m .53119 .44571 L .5324 .44567 L F
.53232 .43804 m .53119 .44571 L .53296 .43803 L F
.53181 .43806 m .5362 .43501 L .53627 .43794 L .666 .426 .548 r
F
.53678 .43784 m .5324 .44567 L .53976 .44549 L .643 .737 .917 r
F
.53656 .43789 m .5362 .43501 L .54106 .4338 L .592 .368 .545 r
F
.53627 .43794 m .5362 .43501 L .53656 .43789 L F
.53123 .4313 m .5362 .43501 L .53468 .43104 L .667 .747 .91 r
F
.53362 .43845 m .5324 .44567 L .53678 .43784 L .643 .737 .917 r
F
.53989 .43725 m .54106 .4338 L .54114 .43694 L .592 .368 .545 r
F
.53678 .43784 m .53976 .44549 L .5412 .43909 L .643 .737 .917 r
F
.53989 .43725 m .5412 .43909 L .5417 .4369 L F
.53678 .43784 m .5412 .43909 L .53989 .43725 L F
.53627 .43815 m .53656 .43789 L .53989 .43725 L .592 .368 .545 r
F
.53656 .43789 m .54106 .4338 L .53989 .43725 L F
.53901 .43602 m .53989 .43725 L .54114 .43694 L .667 .747 .91 r
F
.53234 .42292 m .53122 .42459 L .53218 .42621 L .644 .737 .916 r
F
.53518 .41961 m .5352 .41958 L .5352 .42013 L .08 0 .418 r
F
.5352 .41958 m .53554 .41913 L .5352 .42013 L F
.53781 .42706 m .54093 .43062 L .54513 .42869 L .668 .747 .909 r
F
.53459 .42787 m .54093 .43062 L .53781 .42706 L F
.53781 .42706 m .54513 .42869 L .54062 .42576 L F
.53509 .42648 m .54074 .42892 L .53619 .42598 L .667 .747 .91 r
F
.53505 .42674 m .54074 .42892 L .53509 .42648 L F
.53462 .42188 m .53468 .42348 L .53609 .42283 L .668 .747 .909 r
F
.53258 .41792 m .52988 .42047 L .53117 .42071 L .644 .737 .916 r
F
.53258 .41792 m .53117 .42071 L .53244 .42094 L F
.53348 .42056 m .53432 .42027 L .53433 .42178 L .517 .303 .528 r
F
.53433 .42178 m .53403 .42274 L .53441 .42174 L .668 .747 .909 r
F
.5335 .42212 m .53365 .42229 L .53433 .42178 L F
.53365 .42229 m .53403 .42274 L .53433 .42178 L F
.53441 .42174 m .53403 .42274 L .53462 .42188 L F
.53403 .42274 m .53468 .42348 L .53462 .42188 L F
.5362 .43501 m .53612 .43189 L .54097 .43068 L .592 .368 .545 r
F
.53459 .42787 m .5361 .43183 L .54093 .43062 L .668 .747 .909 r
F
.5362 .43501 m .54097 .43068 L .54106 .4338 L .592 .368 .545 r
F
.53468 .43104 m .5362 .43501 L .54106 .4338 L .667 .747 .91 r
F
.53468 .43104 m .54106 .4338 L .53792 .43022 L F
.53135 .42402 m .53116 .42813 L .53459 .42787 L .668 .747 .909 r
F
.53142 .42717 m .53123 .4313 L .53468 .43104 L .667 .747 .91 r
F
.53315 .42704 m .53468 .43104 L .53792 .43022 L F
.53142 .42717 m .53468 .43104 L .53315 .42704 L F
.53377 .42842 m .53485 .42977 L .53442 .42793 L F
.53434 .42799 m .53444 .42798 L .53434 .42804 L .358 .18 .498 r
F
.53135 .42402 m .53459 .42787 L .53307 .42388 L .668 .747 .909 r
F
.53323 .42702 m .53792 .43022 L .53478 .42663 L .667 .747 .91 r
F
.53315 .42704 m .5332 .42707 L .53323 .42702 L F
.5332 .42707 m .53792 .43022 L .53323 .42702 L F
.53478 .42663 m .53792 .43022 L .54074 .42892 L F
.53541 .42132 m .53609 .42283 L .53718 .42198 L .668 .747 .909 r
F
.53536 .42165 m .53609 .42283 L .53541 .42132 L F
.53556 .41895 m .53557 .42034 L .53554 .41913 L 0 0 .15 r
F
.53526 .42229 m .53609 .42283 L .53536 .42165 L .668 .747 .909 r
F
.53463 .42497 m .53478 .42663 L .53509 .42648 L .667 .747 .91 r
F
.53527 .42538 m .53509 .42648 L .53619 .42598 L F
.53463 .42497 m .53509 .42648 L .53527 .42538 L F
.53449 .42015 m .53507 .41976 L .53508 .42121 L .358 .18 .498 r
F
.53449 .42015 m .53508 .42121 L .53451 .42164 L F
.53507 .41976 m .53509 .42119 L .53508 .42121 L .08 0 .418 r
F
.53432 .42027 m .53435 .42176 L .53433 .42178 L .358 .18 .498 r
F
.53348 .42056 m .53433 .42178 L .53365 .42206 L .517 .303 .528 r
F
.5352 .42013 m .53554 .42054 L .53525 .42096 L .08 0 .418 r
F
.5361 .42067 m .53718 .42198 L .53789 .42098 L .668 .747 .909 r
F
.53562 .40385 m .5352 .41735 L .53556 .41813 L .983 .725 .332 r
F
.53562 .40385 m .53556 .41813 L .53566 .41836 L F
.539 .41825 m .56423 .42474 L .56571 .41965 L .644 .737 .916 r
F
.53258 .41792 m .54672 .42097 L .539 .41825 L F
.54672 .42097 m .56423 .42474 L .539 .41825 L F
.53552 .42057 m .53541 .42132 L .53553 .42058 L .668 .747 .909 r
F
.53518 .41961 m .53525 .42096 L .53519 .42105 L .08 0 .418 r
F
.5324 .42164 m .53186 .42252 L .53234 .42292 L .644 .737 .916 r
F
.53244 .42094 m .5321 .4215 L .5324 .42164 L F
.53193 .42075 m .53324 .42065 L .53324 .42222 L .641 .401 .54 r
F
.53365 .42229 m .53307 .42388 L .53468 .42348 L .668 .747 .909 r
F
.53355 .42218 m .53349 .42241 L .53365 .42229 L F
.53349 .42241 m .53307 .42388 L .53365 .42229 L F
.53449 .42015 m .53451 .42164 L .53432 .42027 L .358 .18 .498 r
F
.53441 .42483 m .53448 .4252 L .53463 .42497 L .667 .747 .91 r
F
.53448 .4252 m .53478 .42663 L .53463 .42497 L F
.53368 .42538 m .53478 .42663 L .53441 .42485 L F
.53433 .42488 m .53441 .42485 L .53441 .42483 L F
.53368 .42538 m .53441 .42485 L .53433 .42488 L F
.53365 .42206 m .53399 .42502 L .53351 .42211 L .517 .303 .528 r
F
.53368 .42538 m .53315 .42704 L .53478 .42663 L .667 .747 .91 r
F
.53254 .42251 m .53307 .42388 L .5335 .42212 L .668 .747 .909 r
F
.53193 .42075 m .53324 .42222 L .53197 .42239 L .641 .401 .54 r
F
.53257 .42259 m .53135 .42402 L .53307 .42388 L .668 .747 .909 r
F
.53156 .42244 m .53135 .42402 L .53257 .42259 L F
.53142 .42243 m .53142 .42246 L .53156 .42244 L F
.53142 .42246 m .53135 .42402 L .53156 .42244 L F
.53193 .42075 m .53197 .42239 L .53155 .42078 L .641 .401 .54 r
F
.53247 .42232 m .53156 .42244 L .53257 .42259 L .668 .747 .909 r
F
.53464 .43235 m .53362 .43845 L .53678 .43784 L .643 .737 .917 r
F
.53357 .4296 m .5324 .44567 L .53464 .43235 L F
.5329 .43051 m .53119 .44571 L .53357 .4296 L F
.5311 .43855 m .53181 .43806 L .53627 .43815 L .666 .426 .548 r
F
.53181 .43806 m .53627 .43794 L .53627 .43815 L F
.532 .42885 m .53156 .43806 L .53309 .42883 L .643 .737 .917 r
F
.53156 .43806 m .53205 .43805 L .53309 .42883 L F
.532 .42885 m .53309 .42883 L .53242 .42871 L F
.53357 .4296 m .53232 .43804 L .53296 .43803 L F
.52591 .43497 m .52584 .43185 L .53096 .43229 L .731 .478 .545 r
F
.52775 .42784 m .53097 .43223 L .53116 .42813 L .668 .747 .909 r
F
.52775 .42784 m .52587 .43179 L .53097 .43223 L F
.5278 .43101 m .53103 .43541 L .53123 .4313 L .667 .747 .91 r
F
.53193 .43033 m .53094 .43186 L .53179 .43328 L .643 .737 .917 r
F
.52964 .42387 m .53116 .42813 L .53135 .42402 L .668 .747 .909 r
F
.52964 .42387 m .52775 .42784 L .53116 .42813 L F
.5297 .42702 m .53123 .4313 L .53142 .42717 L .667 .747 .91 r
F
.53202 .42851 m .53051 .42914 L .53193 .43033 L .643 .737 .917 r
F
.53197 .42239 m .53206 .42548 L .53161 .42244 L .641 .401 .54 r
F
.53264 .4257 m .53142 .42717 L .53315 .42704 L .667 .747 .91 r
F
.53253 .42542 m .53238 .42566 L .53264 .4257 L F
.53238 .42566 m .53142 .42717 L .53264 .4257 L F
.53026 .42054 m .53155 .42078 L .53156 .42244 L .751 .491 .539 r
F
.53026 .42054 m .53156 .42244 L .53055 .4223 L F
.52908 .42009 m .5299 .42047 L .5299 .42221 L .845 .571 .524 r
F
.5314 .42286 m .52964 .42387 L .53135 .42402 L .668 .747 .909 r
F
.53107 .42272 m .52964 .42387 L .5314 .42286 L F
.5304 .42228 m .52964 .42387 L .53142 .42243 L F
.52703 .43755 m .52591 .43497 L .53103 .43541 L .731 .478 .545 r
F
.52596 .4374 m .52591 .43497 L .52703 .43755 L F
.5297 .42702 m .5278 .43101 L .53123 .4313 L .667 .747 .91 r
F
.53051 .42914 m .52997 .43022 L .53193 .43033 L .643 .737 .917 r
F
.53258 .41792 m .52101 .42128 L .50868 .4307 L .644 .737 .916 r
F
.52101 .42128 m .50359 .42634 L .50721 .42944 L F
.52101 .42128 m .50721 .42944 L .50868 .4307 L F
.52944 .4019 m .52825 .40268 L .52827 .41699 L .4 .211 .506 r
F
.5278 .43101 m .52591 .43497 L .53103 .43541 L .667 .747 .91 r
F
.52997 .43022 m .52825 .4336 L .53094 .43186 L .643 .737 .917 r
F
.52825 .4336 m .52628 .4375 L .5284 .43577 L F
.52628 .4375 m .52268 .44459 L .52712 .43775 L F
.52628 .4375 m .52712 .43775 L .5284 .43577 L F
.52093 .42943 m .51771 .43488 L .52319 .43654 L .644 .737 .916 r
F
.52248 .43635 m .52591 .43497 L .52596 .4374 L .794 .529 .538 r
F
.52807 .42345 m .52775 .42784 L .52964 .42387 L .668 .747 .909 r
F
.52908 .42009 m .5299 .42221 L .52911 .42187 L .845 .571 .524 r
F
.53026 .42054 m .53055 .4223 L .53031 .42227 L .751 .491 .539 r
F
.53015 .42282 m .52807 .42345 L .52964 .42387 L .668 .747 .909 r
F
.5304 .42228 m .52933 .42215 L .53015 .42282 L F
.52933 .42215 m .52895 .42254 L .53015 .42282 L F
.52895 .42254 m .52807 .42345 L .52927 .42308 L F
.52895 .42254 m .52927 .42308 L .53015 .42282 L F
.52101 .42128 m .50044 .42139 L .50359 .42634 L .644 .737 .916 r
F
.53258 .41792 m .52538 .4187 L .52101 .42128 L F
.52538 .4187 m .50044 .42139 L .52101 .42128 L F
.5299 .42047 m .52995 .42222 L .5299 .42221 L .751 .491 .539 r
F
.52935 .42213 m .52933 .42215 L .5304 .42228 L .668 .747 .909 r
F
.52807 .42345 m .5246 .427 L .52775 .42784 L F
.52673 .42279 m .5246 .427 L .52807 .42345 L F
.52812 .4266 m .5278 .43101 L .5297 .42702 L .667 .747 .91 r
F
.52831 .41953 m .52833 .42133 L .52815 .4194 L .929 .648 .487 r
F
.52933 .42215 m .52673 .42279 L .52807 .42345 L .668 .747 .909 r
F
.52932 .42214 m .52673 .42279 L .52933 .42215 L F
.53026 .42054 m .53031 .42227 L .5299 .42047 L .751 .491 .539 r
F
.53031 .42227 m .53002 .42223 L .5299 .42047 L F
.52935 .42213 m .52932 .42214 L .52933 .42215 L .668 .747 .909 r
F
.52811 .42196 m .52673 .42279 L .52932 .42214 L F
.5293 .42212 m .52932 .42214 L .52935 .42213 L F
.52811 .42196 m .52932 .42214 L .5293 .42212 L F
.52831 .41953 m .52885 .41999 L .52885 .42176 L .929 .648 .487 r
F
.52831 .41953 m .52885 .42176 L .52833 .42133 L F
.53002 .42223 m .52995 .42222 L .5299 .42047 L .751 .491 .539 r
F
.52833 .42133 m .52818 .4212 L .52815 .4194 L .929 .648 .487 r
F
.52784 .41887 m .52815 .4194 L .52816 .42118 L .988 .719 .384 r
F
.52784 .41887 m .52816 .42118 L .52786 .42067 L F
.52815 .4194 m .52818 .4212 L .52816 .42118 L .929 .648 .487 r
F
.52784 .41887 m .52786 .42067 L .52776 .41872 L .988 .719 .384 r
F
.5278 .4212 m .52635 .42171 L .52785 .42192 L .668 .747 .909 r
F
.52811 .42196 m .52571 .42193 L .52673 .42279 L F
.52635 .42171 m .52571 .42193 L .52811 .42196 L F
.5246 .427 m .52587 .43179 L .52775 .42784 L F
.5246 .427 m .52115 .43054 L .52587 .43179 L F
.52677 .42594 m .52463 .43017 L .52797 .42676 L .667 .747 .91 r
F
.52795 .42652 m .52797 .42676 L .52812 .4266 L F
.52677 .42594 m .52797 .42676 L .52795 .42652 L F
.52825 .40268 m .5277 .41795 L .52814 .4172 L 0 0 .377 r
F
.51446 .41988 m .49946 .41618 L .50044 .42139 L .644 .737 .916 r
F
.53258 .41792 m .52443 .41749 L .51446 .41988 L F
.52443 .41749 m .49946 .41618 L .51446 .41988 L F
.53061 .40156 m .52944 .4019 L .52946 .41629 L .567 .342 .533 r
F
.52885 .41999 m .52889 .42177 L .52885 .42176 L .845 .571 .524 r
F
.52946 .42202 m .52811 .42196 L .52935 .42213 L .668 .747 .909 r
F
.52908 .42009 m .52911 .42187 L .52885 .41999 L .845 .571 .524 r
F
.52911 .42187 m .52889 .42177 L .52885 .41999 L F
.53154 .41989 m .52861 .42165 L .52946 .42202 L .668 .747 .909 r
F
.52861 .42165 m .52811 .42196 L .52946 .42202 L F
.52116 .43372 m .52584 .43185 L .52591 .43497 L .794 .529 .538 r
F
.52628 .4375 m .5148 .44222 L .52268 .44459 L .643 .737 .917 r
F
.52248 .43635 m .52116 .43372 L .52591 .43497 L .794 .529 .538 r
F
.52121 .43597 m .52116 .43372 L .52248 .43635 L F
.52116 .43372 m .5211 .4306 L .52584 .43185 L F
.52463 .43017 m .52591 .43497 L .5278 .43101 L .667 .747 .91 r
F
.52463 .43017 m .52116 .43372 L .52591 .43497 L F
.52997 .43022 m .52228 .4363 L .52628 .4375 L .643 .737 .917 r
F
.52228 .4363 m .5148 .44222 L .52628 .4375 L F
.52806 .43084 m .52175 .43625 L .52811 .43159 L F
.52175 .43625 m .52118 .43675 L .5218 .43628 L F
.52175 .43625 m .5218 .43628 L .52811 .43159 L F
.52118 .43675 m .5148 .44222 L .5207 .43755 L F
.52861 .42165 m .52837 .42155 L .52848 .42173 L .668 .747 .909 r
F
.52848 .42173 m .5278 .4212 L .52811 .42196 L F
.5281 .42109 m .5278 .4212 L .52848 .42173 L F
.5278 .4212 m .52509 .42093 L .52571 .42193 L F
.52899 .42571 m .52677 .42594 L .52812 .4266 L .667 .747 .91 r
F
.52833 .42133 m .52885 .42176 L .52886 .42486 L .929 .648 .487 r
F
.52833 .42133 m .52886 .42486 L .5286 .42465 L F
.52851 .42489 m .52787 .42528 L .52899 .42571 L .667 .747 .91 r
F
.52787 .42528 m .52677 .42594 L .52791 .42582 L F
.52787 .42528 m .52791 .42582 L .52899 .42571 L F
.52833 .42133 m .5286 .42465 L .52837 .42446 L .929 .648 .487 r
F
.52851 .42489 m .52575 .42508 L .52677 .42594 L .667 .747 .91 r
F
.52911 .42187 m .52917 .42499 L .52889 .42177 L .845 .571 .524 r
F
.52973 .42696 m .52812 .4266 L .5297 .42702 L .667 .747 .91 r
F
.52931 .42624 m .52812 .4266 L .52973 .42696 L F
.52939 .4253 m .52899 .42571 L .53021 .42597 L F
.52899 .42571 m .52812 .4266 L .52931 .42624 L F
.52899 .42571 m .52931 .42624 L .53021 .42597 L F
.52781 .42435 m .52661 .42477 L .52784 .42485 L F
.52661 .42477 m .52647 .42503 L .52785 .42493 L F
.52784 .42485 m .52785 .42493 L .52851 .42489 L F
.52661 .42477 m .52785 .42493 L .52784 .42485 L F
.52776 .42051 m .52721 .42059 L .5278 .4212 L .668 .747 .909 r
F
.52776 .4205 m .52491 .41986 L .52509 .42093 L F
.52776 .41872 m .52777 .42053 L .52776 .42051 L .988 .719 .384 r
F
.52779 .42056 m .52777 .42053 L .52776 .41872 L F
.52771 .41987 m .52491 .41986 L .52776 .4205 L .668 .747 .909 r
F
.52776 .4205 m .52775 .4205 L .52776 .42051 L F
.52721 .42059 m .52692 .42111 L .5278 .4212 L F
.52771 .41812 m .52776 .41872 L .52776 .42051 L .781 .623 .061 r
F
.52773 .42011 m .52776 .42051 L .52776 .42361 L F
.52771 .41812 m .52776 .42051 L .52773 .42011 L F
.52771 .41987 m .52518 .41879 L .52491 .41986 L .668 .747 .909 r
F
.52771 .41977 m .5277 .41973 L .5277 .41795 L .781 .623 .061 r
F
.5277 .41795 m .5277 .41973 L .5277 .4197 L F
.52771 .41812 m .52772 .4199 L .5277 .41795 L F
.52772 .4199 m .52771 .41977 L .5277 .41795 L F
.52944 .4019 m .52827 .41699 L .52919 .41644 L .4 .211 .506 r
F
.52825 .40268 m .52814 .4172 L .52827 .41699 L 0 0 .377 r
F
.53258 .41792 m .52735 .41679 L .52443 .41749 L .644 .737 .916 r
F
.52814 .4172 m .5277 .41795 L .5277 .4197 L 0 0 .377 r
F
.52772 .4199 m .52776 .42361 L .52772 .42305 L .781 .623 .061 r
F
.52771 .41812 m .52773 .42011 L .52772 .4199 L F
.52773 .42011 m .52776 .42361 L .52772 .4199 L F
.52767 .41922 m .52589 .41779 L .52518 .41879 L .668 .747 .909 r
F
.52814 .4172 m .5277 .4197 L .52804 .41909 L 0 0 .377 r
F
.52795 .41926 m .52764 .41844 L .52767 .41922 L .668 .747 .909 r
F
.53154 .41989 m .52828 .41868 L .52795 .41926 L F
.52786 .42067 m .52779 .42056 L .52776 .41872 L .988 .719 .384 r
F
.53154 .41989 m .52795 .41926 L .52771 .41987 L .668 .747 .909 r
F
.53154 .41989 m .52771 .41987 L .52776 .4205 L F
.52917 .42499 m .52906 .42495 L .52889 .42177 L .845 .571 .524 r
F
.52939 .4253 m .52851 .42489 L .52899 .42571 L .667 .747 .91 r
F
.52922 .42792 m .52902 .42783 L .52896 .4249 L .845 .571 .524 r
F
.52906 .42495 m .52896 .4249 L .52889 .42177 L F
.52922 .42792 m .52896 .4249 L .52906 .42495 L F
.52953 .42515 m .52886 .42486 L .52939 .4253 L .667 .747 .91 r
F
.52886 .42486 m .52851 .42489 L .52939 .4253 L F
.52812 .4266 m .52463 .43017 L .5278 .43101 L F
.52956 .42835 m .52187 .43558 L .53027 .42894 L .643 .737 .917 r
F
.52187 .43558 m .5148 .44222 L .52118 .43675 L F
.52187 .43558 m .52118 .43675 L .53027 .42894 L F
.52781 .42435 m .52784 .42485 L .52851 .42489 L .667 .747 .91 r
F
.52118 .43675 m .5207 .43755 L .52997 .43022 L .643 .737 .917 r
F
.52823 .4377 m .52786 .43816 L .53109 .43808 L F
.53094 .43186 m .52268 .44459 L .53179 .43328 L F
.52597 .43811 m .52703 .43755 L .5311 .43855 L .731 .478 .545 r
F
.52703 .43755 m .53109 .43808 L .5311 .43855 L F
.51842 .43452 m .52116 .43372 L .52121 .43597 L .86 .586 .521 r
F
.52673 .42279 m .52192 .42569 L .5246 .427 L .668 .747 .909 r
F
.52661 .42477 m .52512 .42407 L .52575 .42508 L .667 .747 .91 r
F
.52885 .42176 m .52892 .42489 L .52886 .42486 L .845 .571 .524 r
F
.52786 .42067 m .52801 .42404 L .52788 .42381 L .988 .719 .384 r
F
.52777 .42053 m .5278 .42367 L .52776 .42051 L F
.5278 .42367 m .52779 .42366 L .52776 .42051 L F
.52781 .42435 m .52719 .42374 L .52661 .42477 L .667 .747 .91 r
F
.52813 .42424 m .52779 .42406 L .52781 .42435 L F
.52779 .42406 m .52719 .42374 L .52781 .42435 L F
.5277 .41973 m .52771 .42289 L .5277 .4197 L .781 .623 .061 r
F
.52778 .42364 m .52719 .42374 L .52813 .42424 L .667 .747 .91 r
F
.52784 .42374 m .5278 .42367 L .52777 .42053 L .988 .719 .384 r
F
.52571 .42193 m .52192 .42569 L .52673 .42279 L .668 .747 .909 r
F
.52719 .42374 m .52494 .423 L .52512 .42407 L .667 .747 .91 r
F
.52772 .4199 m .52772 .42305 L .52771 .41977 L .781 .623 .061 r
F
.52772 .42305 m .52772 .42298 L .52771 .41977 L F
.52776 .42051 m .52779 .42366 L .52776 .42361 L .988 .719 .384 r
F
.52784 .42375 m .52777 .42053 L .52779 .42056 L F
.5279 .42673 m .52784 .42374 L .52784 .42375 L F
.52784 .42374 m .52777 .42053 L .52784 .42375 L F
.5281 .42109 m .52776 .42051 L .5278 .4212 L .668 .747 .909 r
F
.52786 .42067 m .52816 .42118 L .52816 .42429 L .988 .719 .384 r
F
.5278 .4212 m .52785 .42192 L .52811 .42196 L .668 .747 .909 r
F
.52786 .42067 m .52816 .42429 L .52801 .42404 L .988 .719 .384 r
F
.52956 .42835 m .52794 .42905 L .52799 .42982 L .643 .737 .917 r
F
.52975 .42817 m .5295 .42829 L .52956 .42835 L F
.5295 .42829 m .52794 .42905 L .52956 .42835 L F
.52833 .42133 m .52837 .42446 L .52818 .4212 L .929 .648 .487 r
F
.52837 .42446 m .52829 .4244 L .52818 .4212 L F
.5284 .42737 m .52827 .42726 L .52823 .42434 L F
.52829 .4244 m .52823 .42434 L .52818 .4212 L F
.5284 .42737 m .52823 .42434 L .52829 .4244 L F
.52816 .42429 m .52781 .42435 L .52851 .42489 L .667 .747 .91 r
F
.52813 .42424 m .52811 .42425 L .52816 .42429 L F
.52811 .42425 m .52781 .42435 L .52816 .42429 L F
.52889 .42177 m .52896 .4249 L .52885 .42176 L .845 .571 .524 r
F
.52877 .42772 m .52549 .42946 L .52975 .42817 L .643 .737 .917 r
F
.52093 .42943 m .51536 .43417 L .51771 .43488 L .644 .737 .916 r
F
.51712 .43175 m .5211 .4306 L .52116 .43372 L .86 .586 .521 r
F
.51842 .43452 m .51712 .43175 L .52116 .43372 L F
.51718 .43388 m .51718 .43388 L .51759 .43409 L .643 .737 .917 r
F
.51718 .43388 m .50807 .43873 L .51748 .43415 L F
.51718 .43388 m .51748 .43415 L .51759 .43409 L F
.51716 .43387 m .51712 .43175 L .51842 .43452 L .86 .586 .521 r
F
.52192 .42569 m .52115 .43054 L .5246 .427 L .668 .747 .909 r
F
.52194 .42885 m .52116 .43372 L .52463 .43017 L .667 .747 .91 r
F
.51712 .43175 m .51706 .42862 L .5211 .4306 L .86 .586 .521 r
F
.52192 .42569 m .51713 .42857 L .52115 .43054 L .668 .747 .909 r
F
.52194 .42885 m .51712 .43175 L .52116 .43372 L .667 .747 .91 r
F
.52799 .42982 m .50807 .43873 L .5148 .44222 L .643 .737 .917 r
F
.52794 .42905 m .50807 .43873 L .52799 .42982 L F
.51512 .43212 m .51712 .43175 L .51716 .43387 L .932 .65 .484 r
F
.52896 .4249 m .52892 .42489 L .52885 .42176 L .845 .571 .524 r
F
.52911 .42187 m .5299 .42221 L .5299 .42531 L F
.52911 .42187 m .5299 .42531 L .52952 .42515 L F
.53022 .42536 m .53006 .42533 L .52995 .42222 L .751 .491 .539 r
F
.53025 .42536 m .52995 .42222 L .53002 .42223 L F
.53148 .42599 m .5297 .42702 L .53142 .42717 L .667 .747 .91 r
F
.53113 .42584 m .5297 .42702 L .53148 .42599 L F
.53048 .42539 m .53042 .42553 L .5315 .42554 L F
.53042 .42553 m .5297 .42702 L .53113 .42584 L F
.53042 .42553 m .53113 .42584 L .5315 .42554 L F
.52917 .42499 m .52991 .42824 L .52922 .42792 L .845 .571 .524 r
F
.52911 .42187 m .52952 .42515 L .52917 .42499 L F
.53021 .42597 m .52931 .42624 L .52973 .42696 L .667 .747 .91 r
F
.52952 .42515 m .52991 .42824 L .52917 .42499 L .845 .571 .524 r
F
.53047 .42835 m .53022 .42536 L .53025 .42536 L .751 .491 .539 r
F
.53022 .42536 m .52995 .42222 L .53025 .42536 L F
.53048 .42539 m .52939 .4253 L .53021 .42597 L .667 .747 .91 r
F
.52944 .42525 m .52939 .4253 L .53048 .42539 L F
.53031 .42227 m .53047 .42835 L .53002 .42223 L .751 .491 .539 r
F
.52971 .42821 m .52956 .42835 L .53067 .4286 L .643 .737 .917 r
F
.52956 .42835 m .53027 .42894 L .53067 .4286 L F
.52991 .42824 m .53067 .4286 L .53088 .42842 L F
.52971 .42821 m .53067 .4286 L .52991 .42824 L F
.52957 .42954 m .52806 .43084 L .52997 .43022 L F
.52806 .43084 m .52811 .43159 L .52997 .43022 L F
.53088 .42842 m .52957 .42954 L .52997 .43022 L F
.52825 .4336 m .5284 .43577 L .53094 .43186 L F
.52997 .43022 m .53094 .43186 L .53193 .43033 L F
.53179 .43328 m .52823 .4377 L .53156 .43806 L F
.52823 .4377 m .53109 .43808 L .53156 .43806 L F
.53442 .42793 m .53485 .42977 L .53509 .42966 L .667 .747 .91 r
F
.53528 .42848 m .53509 .42966 L .53626 .42912 L F
.53509 .4212 m .53541 .42132 L .53552 .42057 L .668 .747 .909 r
F
.53462 .42188 m .53526 .42229 L .53509 .4212 L F
.53542 .42443 m .53619 .42598 L .53687 .42544 L .667 .747 .91 r
F
.53661 .42487 m .53687 .42544 L .53729 .42512 L F
.53542 .42443 m .53687 .42544 L .53661 .42487 L F
.53537 .42474 m .53619 .42598 L .53542 .42443 L F
.53574 .4199 m .53789 .42098 L .53817 .41991 L .668 .747 .909 r
F
.53518 .41961 m .53519 .42105 L .53507 .41976 L .08 0 .418 r
F
.53519 .42105 m .53522 .42412 L .53512 .42115 L F
.53519 .42105 m .53512 .42115 L .53507 .41976 L F
.53522 .42412 m .53518 .42418 L .53511 .42117 L F
.53512 .42115 m .53511 .42117 L .53507 .41976 L F
.53522 .42412 m .53511 .42117 L .53512 .42115 L F
.53654 .41908 m .53817 .41991 L .538 .41884 L .668 .747 .909 r
F
.53556 .41813 m .5355 .41937 L .53555 .41949 L .983 .725 .332 r
F
.53463 .42497 m .53527 .42538 L .53509 .42431 L .667 .747 .91 r
F
.53526 .42719 m .53517 .42732 L .53513 .42425 L .08 0 .418 r
F
.53518 .42418 m .53513 .42425 L .53507 .41976 L F
.53509 .42431 m .53661 .42487 L .53551 .42369 L .667 .747 .91 r
F
.53661 .42487 m .53729 .42512 L .5364 .42441 L F
.53661 .42487 m .5364 .42441 L .53551 .42369 L F
.53556 .41895 m .53566 .41836 L .53567 .41974 L 0 0 .15 r
F
.53556 .41895 m .53567 .41974 L .5356 .42016 L F
.53556 .41813 m .5352 .41872 L .5355 .41937 L .983 .725 .332 r
F
.53557 .42034 m .53554 .42052 L .53554 .41913 L 0 0 .15 r
F
.53554 .41913 m .53554 .42052 L .53554 .42054 L F
.5352 .42013 m .53554 .41913 L .53554 .42054 L .08 0 .418 r
F
.53541 .42132 m .5366 .42176 L .53553 .42058 L .668 .747 .909 r
F
.53557 .42034 m .53568 .42284 L .53559 .42341 L 0 0 .15 r
F
.53556 .41895 m .5356 .42016 L .53557 .42034 L F
.5356 .42016 m .53568 .42284 L .53557 .42034 L F
.5357 .41953 m .53597 .4199 L .53627 .41948 L .668 .747 .909 r
F
.53258 .41792 m .53359 .42052 L .53455 .42019 L .644 .737 .916 r
F
.53612 .4238 m .53729 .42512 L .538 .42412 L .667 .747 .91 r
F
.53551 .42369 m .5364 .42441 L .53612 .4238 L F
.5364 .42441 m .53729 .42512 L .53612 .4238 L F
.53527 .42538 m .53619 .42598 L .53537 .42474 L F
.53465 .42808 m .53509 .42966 L .53528 .42848 L F
.5345 .44112 m .53238 .45366 L .53934 .45349 L .642 .738 .918 r
F
.53427 .42936 m .53464 .43235 L .53446 .42963 L .643 .737 .917 r
F
.53446 .42963 m .53464 .43235 L .53498 .43036 L F
.5315 .42556 m .53142 .42717 L .53253 .42542 L .667 .747 .91 r
F
.53325 .42533 m .53278 .42606 L .53359 .42528 L F
.53253 .42542 m .5326 .42559 L .53325 .42533 L F
.5326 .42559 m .53278 .42606 L .53325 .42533 L F
.53365 .42827 m .53377 .42842 L .53434 .42799 L F
.53313 .42846 m .53326 .42878 L .53364 .42848 L .643 .737 .917 r
F
.53353 .42832 m .53364 .42848 L .53407 .42814 L F
.53313 .42846 m .53364 .42848 L .53353 .42832 L F
.53326 .42842 m .53333 .4284 L .53326 .42843 L .517 .303 .528 r
F
.53325 .42533 m .53333 .42839 L .53326 .42842 L F
.53333 .42839 m .53333 .4284 L .53326 .42842 L F
.53407 .42814 m .53326 .42878 L .53412 .42819 L .643 .737 .917 r
F
.53278 .42606 m .53315 .42704 L .53368 .42538 L .667 .747 .91 r
F
.53485 .42977 m .538 .43336 L .53891 .43294 L F
.54106 .4338 m .54097 .43068 L .5452 .42873 L .499 .296 .536 r
F
.54106 .4338 m .5452 .42873 L .54528 .43186 L F
.53792 .43022 m .54106 .4338 L .54528 .43186 L .667 .747 .91 r
F
.538 .43098 m .53891 .43294 L .54082 .43206 L F
.53485 .42977 m .53891 .43294 L .538 .43098 L F
.53154 .41989 m .53564 .4199 L .53567 .41974 L .668 .747 .909 r
F
.53154 .41989 m .53567 .41974 L .53558 .41954 L F
.53324 .42222 m .53332 .4253 L .53325 .42533 L .517 .303 .528 r
F
.53554 .42052 m .53556 .42357 L .53554 .42054 L 0 0 .15 r
F
.53556 .42357 m .53556 .42358 L .53554 .42054 L F
.53441 .42174 m .53462 .42188 L .53483 .42157 L .668 .747 .909 r
F
.53441 .42174 m .53483 .42157 L .53509 .4212 L F
.53462 .42188 m .53509 .4212 L .53508 .42121 L F
.53451 .42164 m .53508 .42121 L .53509 .42432 L .358 .18 .498 r
F
.53451 .42164 m .53509 .42432 L .53456 .42472 L F
.53554 .42054 m .53556 .42358 L .53555 .42364 L 0 0 .15 r
F
.53206 .42548 m .53188 .4255 L .53161 .42244 L .641 .401 .54 r
F
.53215 .4285 m .53183 .42853 L .53161 .42244 L F
.53161 .42244 m .53183 .42853 L .53156 .42244 L F
.53183 .42853 m .53183 .42853 L .53156 .42244 L F
.53183 .42862 m .53179 .42863 L .53156 .42244 L F
.53206 .42548 m .53326 .42842 L .53215 .4285 L F
.52787 .43414 m .5311 .43855 L .5313 .43444 L .667 .747 .91 r
F
.52977 .43016 m .5313 .43444 L .53149 .43031 L F
.52977 .43016 m .52787 .43414 L .5313 .43444 L F
.53157 .42866 m .52977 .43016 L .53149 .43031 L F
.5299 .42221 m .53011 .42828 L .52991 .42824 L .751 .491 .539 r
F
.52896 .4249 m .52902 .42783 L .52892 .42489 L .845 .571 .524 r
F
.52902 .42783 m .52899 .42782 L .52892 .42489 L F
.52886 .42486 m .52893 .42779 L .52886 .42776 L F
.52892 .42489 m .52899 .42782 L .52886 .42486 L F
.52549 .42946 m .52484 .43056 L .52975 .42817 L .643 .737 .917 r
F
.51405 .42917 m .51706 .42862 L .51712 .43175 L .932 .65 .484 r
F
.51512 .43212 m .51405 .42917 L .51712 .43175 L F
.51989 .42713 m .51712 .43175 L .52194 .42885 L .667 .747 .91 r
F
.51405 .42917 m .51399 .42604 L .51706 .42862 L .932 .65 .484 r
F
.51989 .42397 m .51713 .42857 L .52192 .42569 L .668 .747 .909 r
F
.51989 .42397 m .51408 .42601 L .51713 .42857 L F
.51989 .42713 m .51405 .42917 L .51712 .43175 L .667 .747 .91 r
F
.52677 .42594 m .52194 .42885 L .52463 .43017 L F
.52877 .42772 m .51898 .43024 L .5158 .43271 L .643 .737 .917 r
F
.51718 .43388 m .5158 .43271 L .50807 .43873 L F
.52877 .42772 m .5158 .43271 L .51718 .43388 L F
.51408 .43123 m .51405 .42917 L .51512 .43212 L .932 .65 .484 r
F
.51495 .43261 m .50294 .43436 L .50663 .4375 L .643 .737 .917 r
F
.51898 .43024 m .51423 .43146 L .51495 .43261 L F
.51423 .43146 m .50294 .43436 L .51495 .43261 L F
.51284 .42926 m .51405 .42917 L .51408 .43123 L .987 .713 .388 r
F
.51984 .42948 m .50078 .43099 L .50294 .43436 L .643 .737 .917 r
F
.52899 .42782 m .52893 .42779 L .52886 .42486 L .845 .571 .524 r
F
.52851 .42458 m .52816 .42429 L .52837 .42465 L .667 .747 .91 r
F
.52837 .42446 m .5284 .42737 L .52829 .4244 L .929 .648 .487 r
F
.5279 .42673 m .52782 .4266 L .5278 .42367 L .988 .719 .384 r
F
.5279 .42673 m .5278 .42367 L .52784 .42374 L F
.52068 .42924 m .50078 .43099 L .51984 .42948 L .643 .737 .917 r
F
.52788 .42381 m .52816 .42717 L .5279 .42673 L .988 .719 .384 r
F
.52801 .42404 m .52816 .42717 L .52788 .42381 L F
.52917 .42499 m .52922 .42792 L .52906 .42495 L .845 .571 .524 r
F
.52837 .42446 m .52886 .42776 L .5284 .42737 L .929 .648 .487 r
F
.52869 .42479 m .52837 .42465 L .52851 .42489 L .667 .747 .91 r
F
.5286 .42465 m .52886 .42776 L .52837 .42446 L .929 .648 .487 r
F
.52801 .42404 m .52816 .42429 L .52816 .42717 L .988 .719 .384 r
F
.52873 .42476 m .52869 .42479 L .52886 .42486 L .667 .747 .91 r
F
.52869 .42479 m .52851 .42489 L .52886 .42486 L F
.5286 .42465 m .52886 .42486 L .52886 .42776 L .929 .648 .487 r
F
.52786 .42067 m .52788 .42381 L .52779 .42056 L .988 .719 .384 r
F
.52788 .42381 m .5279 .42673 L .52784 .42375 L F
.52788 .42381 m .52784 .42375 L .52779 .42056 L F
.52571 .42193 m .51989 .42397 L .52192 .42569 L .668 .747 .909 r
F
.52509 .42093 m .51989 .42397 L .52571 .42193 L F
.5274 .42301 m .52522 .42192 L .52494 .423 L .667 .747 .91 r
F
.5276 .42301 m .52748 .42231 L .5274 .42301 L F
.52995 .42222 m .53016 .42829 L .5299 .42221 L .751 .491 .539 r
F
.5311 .43855 m .53109 .43808 L .53181 .43806 L .666 .426 .548 r
F
.5313 .43444 m .5311 .43855 L .53627 .43815 L .667 .747 .91 r
F
.52597 .43811 m .52596 .4374 L .52703 .43755 L .731 .478 .545 r
F
.52787 .43414 m .52597 .43811 L .5311 .43855 L .667 .747 .91 r
F
.53152 .43778 m .52836 .44282 L .53075 .4537 L .642 .738 .918 r
F
.52836 .44282 m .52222 .45259 L .52909 .45349 L F
.52836 .44282 m .52909 .45349 L .53075 .4537 L F
.53016 .42829 m .53011 .42828 L .5299 .42221 L .751 .491 .539 r
F
.52952 .42515 m .5299 .42531 L .52991 .42824 L .845 .571 .524 r
F
.53047 .42835 m .53016 .42829 L .53006 .42533 L .751 .491 .539 r
F
.53047 .42835 m .53006 .42533 L .53022 .42536 L F
.52816 .42429 m .52827 .42726 L .52816 .42717 L .929 .648 .487 r
F
.52816 .42118 m .52821 .42433 L .52816 .42429 L F
.52821 .42433 m .52827 .42726 L .52816 .42429 L F
.52828 .41868 m .52827 .41869 L .52795 .41926 L .668 .747 .909 r
F
.53154 .41989 m .52776 .4205 L .52776 .42051 L F
.53154 .41989 m .52776 .42051 L .5281 .42109 L F
.53154 .41989 m .5281 .42109 L .52837 .42155 L F
.52814 .4172 m .52813 .41894 L .52827 .41699 L 0 0 .377 r
F
.52813 .41894 m .5281 .42209 L .52821 .41879 L F
.52813 .41894 m .52821 .41879 L .52827 .41699 L F
.5281 .42209 m .52815 .42201 L .52823 .41876 L F
.52821 .41879 m .52823 .41876 L .52827 .41699 L F
.5281 .42209 m .52823 .41876 L .52821 .41879 L F
.52473 .41622 m .50421 .40636 L .50074 .41105 L .644 .737 .916 r
F
.53258 .41792 m .52812 .4161 L .52473 .41622 L F
.52812 .4161 m .50421 .40636 L .52473 .41622 L F
.53176 .40147 m .53061 .40156 L .53063 .416 L .66 .416 .54 r
F
.53154 .41989 m .52974 .41782 L .52897 .41822 L .668 .747 .909 r
F
.52974 .41782 m .52946 .4179 L .52897 .41822 L F
.53061 .40156 m .52946 .41629 L .53037 .41607 L .567 .342 .533 r
F
.52944 .4019 m .52919 .41644 L .52946 .41629 L .4 .211 .506 r
F
.52812 .4161 m .50965 .40244 L .50421 .40636 L .644 .737 .916 r
F
.53258 .41792 m .5298 .41604 L .52812 .4161 L F
.5298 .41604 m .50965 .40244 L .52812 .4161 L F
.52818 .4212 m .52827 .42726 L .52816 .42118 L .929 .648 .487 r
F
.53031 .42227 m .53157 .42855 L .53047 .42835 L .751 .491 .539 r
F
.53055 .4223 m .53157 .42855 L .53031 .42227 L F
.5315 .42554 m .53113 .42584 L .53148 .42599 L .667 .747 .91 r
F
.53107 .42548 m .53156 .42555 L .53157 .42855 L .751 .491 .539 r
F
.53206 .42548 m .53215 .4285 L .53188 .4255 L .641 .401 .54 r
F
.53284 .43688 m .53075 .4537 L .53238 .45366 L .642 .738 .918 r
F
.53284 .43688 m .53238 .45366 L .5345 .44112 L F
.53267 .437 m .53075 .4537 L .53284 .43688 L F
.53159 .43636 m .53075 .4537 L .53272 .43657 L F
.53159 .43636 m .53336 .47161 L .53165 .47181 L .641 .401 .54 r
F
.53156 .42244 m .53179 .42863 L .53157 .42866 L F
.53195 .42611 m .52877 .42772 L .52975 .42817 L .643 .737 .917 r
F
.53574 .42373 m .53612 .4238 L .53601 .42357 L .667 .747 .91 r
F
.53574 .42373 m .53601 .42357 L .53577 .42304 L F
.53197 .42239 m .53324 .42222 L .53325 .42533 L .641 .401 .54 r
F
.53197 .42239 m .53325 .42533 L .53206 .42548 L F
.53451 .42164 m .53456 .42472 L .53435 .42176 L .358 .18 .498 r
F
.53456 .42472 m .5344 .42483 L .53435 .42176 L F
.53399 .42502 m .53392 .42505 L .53351 .42211 L .517 .303 .528 r
F
.53348 .42219 m .53307 .42388 L .53355 .42218 L .668 .747 .909 r
F
.53327 .42221 m .53335 .42528 L .53324 .42222 L .517 .303 .528 r
F
.53335 .42528 m .53333 .42529 L .53324 .42222 L F
.53359 .42528 m .53278 .42606 L .53368 .42538 L .667 .747 .91 r
F
.54114 .43694 m .54106 .4338 L .54528 .43186 L .499 .296 .536 r
F
.54528 .43186 m .5452 .42873 L .5485 .42618 L .362 .192 .512 r
F
.54114 .43694 m .54528 .43186 L .54537 .43499 L .499 .296 .536 r
F
.54528 .43186 m .5485 .42618 L .54859 .42931 L .362 .192 .512 r
F
.54537 .43499 m .54528 .43186 L .54859 .42931 L F
.54074 .42892 m .54528 .43186 L .54859 .42931 L .667 .747 .91 r
F
.53792 .43022 m .54528 .43186 L .54074 .42892 L F
.54537 .43499 m .54859 .42931 L .54868 .43245 L .362 .192 .512 r
F
.54082 .43206 m .54537 .43499 L .54868 .43245 L .667 .747 .91 r
F
.54868 .43245 m .54859 .42931 L .55076 .42632 L .129 .02 .45 r
F
.54868 .43245 m .55076 .42632 L .55085 .42946 L F
.54303 .43036 m .54868 .43245 L .55085 .42946 L .667 .747 .91 r
F
.54082 .43206 m .54868 .43245 L .54303 .43036 L F
.53626 .42912 m .54082 .43206 L .54303 .43036 L F
.54062 .42576 m .54513 .42869 L .54842 .42615 L .668 .747 .909 r
F
.54859 .42931 m .5485 .42618 L .55066 .42319 L .129 .02 .45 r
F
.54859 .42931 m .55066 .42319 L .55076 .42632 L F
.54295 .42722 m .54859 .42931 L .55076 .42632 L .667 .747 .91 r
F
.54074 .42892 m .54859 .42931 L .54295 .42722 L F
.54303 .43036 m .55085 .42946 L .54447 .42836 L F
.53619 .42598 m .54074 .42892 L .54295 .42722 L F
.53737 .42826 m .54303 .43036 L .54447 .42836 L F
.53626 .42912 m .54303 .43036 L .53737 .42826 L F
.53342 .42836 m .53339 .42837 L .53332 .4253 L .517 .303 .528 r
F
.53342 .42836 m .53332 .4253 L .53333 .42529 L F
.55513 .43314 m .58833 .44063 L .56062 .42934 L .644 .737 .916 r
F
.54281 .42406 m .54842 .42615 L .55057 .42317 L .668 .747 .909 r
F
.54062 .42576 m .54842 .42615 L .54281 .42406 L F
.54295 .42722 m .55076 .42632 L .54438 .42522 L .667 .747 .91 r
F
.53609 .42283 m .54062 .42576 L .54281 .42406 L .668 .747 .909 r
F
.53729 .42512 m .54295 .42722 L .54438 .42522 L .667 .747 .91 r
F
.53619 .42598 m .54295 .42722 L .53729 .42512 L F
.53808 .42727 m .54447 .42836 L .54504 .42622 L F
.53737 .42826 m .54447 .42836 L .53808 .42727 L F
.53335 .42528 m .53342 .42836 L .53333 .42529 L .517 .303 .528 r
F
.56062 .42934 m .58833 .44063 L .59569 .43153 L .644 .737 .916 r
F
.56062 .42934 m .59569 .43153 L .56423 .42474 L F
.55085 .42946 m .55076 .42632 L .55162 .4231 L 0 0 .272 r
F
.55085 .42946 m .55162 .4231 L .55172 .42625 L F
.54447 .42836 m .55085 .42946 L .55172 .42625 L .667 .747 .91 r
F
.55076 .42632 m .55066 .42319 L .55153 .41997 L 0 0 .272 r
F
.55076 .42632 m .55153 .41997 L .55162 .4231 L F
.54438 .42522 m .55076 .42632 L .55162 .4231 L .667 .747 .91 r
F
.54447 .42836 m .55172 .42625 L .54504 .42622 L F
.53808 .42727 m .54504 .42622 L .53836 .42619 L F
.53938 .4263 m .56403 .43277 L .56551 .42767 L .643 .737 .917 r
F
.53333 .42529 m .53332 .4253 L .53324 .42222 L .517 .303 .528 r
F
.53162 .42302 m .53253 .42542 L .53325 .42533 L .667 .747 .91 r
F
.53353 .42521 m .53325 .42533 L .53359 .42528 L F
.53671 .42703 m .53737 .42826 L .53808 .42727 L F
.5335 .42212 m .53348 .42219 L .53355 .42218 L .668 .747 .909 r
F
.53353 .42521 m .53368 .42538 L .53433 .42488 L .667 .747 .91 r
F
.53348 .42056 m .53363 .42828 L .53324 .42065 L .517 .303 .528 r
F
.53363 .42828 m .53342 .42837 L .53324 .42065 L F
.53191 .42605 m .52877 .42772 L .53195 .42611 L .643 .737 .917 r
F
.53332 .4253 m .53339 .42837 L .53325 .42533 L .517 .303 .528 r
F
.53339 .42837 m .53339 .42837 L .53325 .42533 L F
.53339 .42838 m .53333 .4284 L .53325 .42533 L F
.53243 .42638 m .53325 .4267 L .53326 .42842 L .641 .401 .54 r
F
.53206 .42548 m .53325 .4267 L .53243 .42638 L F
.53206 .42548 m .53325 .42533 L .53325 .4267 L F
.53351 .42211 m .53364 .42303 L .53353 .42303 L .517 .303 .528 r
F
.53364 .42303 m .53392 .42505 L .53353 .42303 L F
.53353 .42303 m .53392 .42505 L .53357 .42519 L F
.53539 .427 m .53543 .42755 L .53627 .42721 L .667 .747 .91 r
F
.53527 .42538 m .53537 .42474 L .53509 .42431 L F
.53522 .42412 m .53555 .42677 L .53526 .42719 L .08 0 .418 r
F
.53526 .42719 m .53513 .42425 L .53518 .42418 L F
.53443 .42484 m .53463 .42497 L .53484 .42468 L .667 .747 .91 r
F
.53443 .42484 m .53484 .42468 L .53509 .42431 L F
.53463 .42497 m .53509 .42431 L .53509 .42432 L F
.53456 .42472 m .53509 .42432 L .5351 .42743 L .358 .18 .498 r
F
.53519 .42105 m .53537 .4239 L .53522 .42412 L .08 0 .418 r
F
.53526 .42229 m .53536 .42165 L .53509 .4212 L .668 .747 .909 r
F
.53718 .42198 m .54281 .42406 L .54424 .42208 L F
.53609 .42283 m .54281 .42406 L .53718 .42198 L F
.53652 .42223 m .53829 .42305 L .53811 .42197 L .667 .747 .91 r
F
.53525 .42096 m .5354 .42386 L .53519 .42105 L .08 0 .418 r
F
.5354 .42386 m .53537 .4239 L .53519 .42105 L F
.53555 .42676 m .53555 .42676 L .53537 .4239 L F
.53537 .4239 m .53537 .4239 L .53519 .42105 L F
.53555 .42676 m .53537 .4239 L .53537 .4239 L F
.53451 .42164 m .53435 .42176 L .53432 .42027 L .358 .18 .498 r
F
.53154 .41989 m .53552 .42057 L .53574 .4199 L .668 .747 .909 r
F
.5356 .42016 m .53567 .41974 L .53568 .42284 L 0 0 .15 r
F
.53566 .41971 m .53564 .42275 L .53567 .41974 L .983 .725 .332 r
F
.53564 .42275 m .53564 .42276 L .53567 .41974 L F
.53553 .42058 m .5366 .42176 L .5361 .42067 L .668 .747 .909 r
F
.53558 .42263 m .53564 .42275 L .53566 .41971 L .983 .725 .332 r
F
.53564 .41967 m .53566 .41971 L .53566 .41836 L F
.53558 .42263 m .53566 .41971 L .53564 .41967 L F
.53515 .4028 m .53494 .41716 L .5352 .41735 L .911 .629 .497 r
F
.53557 .41705 m .56493 .41442 L .56192 .40939 L .644 .737 .916 r
F
.53258 .41792 m .53676 .41747 L .53557 .41705 L F
.53676 .41747 m .56493 .41442 L .53557 .41705 L F
.53404 .40198 m .53291 .4016 L .53294 .41612 L .81 .54 .53 r
F
.53515 .4028 m .53408 .41652 L .53494 .41716 L .911 .629 .497 r
F
.53531 .41646 m .56192 .40939 L .55689 .40492 L .644 .737 .916 r
F
.53258 .41792 m .53685 .41668 L .53531 .41646 L F
.53685 .41668 m .56192 .40939 L .53531 .41646 L F
.53154 .41989 m .53509 .41864 L .53467 .41834 L .668 .747 .909 r
F
.53154 .41989 m .53496 .41819 L .53456 .41807 L F
.53557 .42034 m .53559 .42341 L .53554 .42052 L 0 0 .15 r
F
.53559 .42341 m .53556 .42357 L .53554 .42052 L F
.53508 .42121 m .53513 .42425 L .53509 .42432 L .08 0 .418 r
F
.53508 .42121 m .53509 .4212 L .53509 .4212 L .668 .747 .909 r
F
.53509 .42119 m .53513 .42425 L .53508 .42121 L .08 0 .418 r
F
.53525 .42096 m .53554 .42054 L .53555 .42364 L F
.53509 .4212 m .53536 .42165 L .53541 .42132 L .668 .747 .909 r
F
.53525 .42096 m .53555 .42364 L .5354 .42386 L .08 0 .418 r
F
.53433 .42178 m .53438 .42485 L .53433 .42488 L .358 .18 .498 r
F
.53442 .42793 m .53626 .42912 L .5351 .42742 L .667 .747 .91 r
F
.53435 .42176 m .5344 .42483 L .53433 .42178 L .358 .18 .498 r
F
.5344 .42483 m .53439 .42484 L .53433 .42178 L F
.53446 .4279 m .53444 .42792 L .53433 .42178 L F
.53365 .42206 m .53433 .42178 L .53434 .42804 L .517 .303 .528 r
F
.53162 .42302 m .53441 .42483 L .53509 .42431 L .667 .747 .91 r
F
.53441 .42483 m .53443 .42484 L .53504 .42435 L F
.53441 .42483 m .53504 .42435 L .53509 .42431 L F
.5344 .42483 m .53446 .4279 L .53439 .42484 L .358 .18 .498 r
F
.53371 .42847 m .5346 .42983 L .53485 .42977 L .667 .747 .91 r
F
.5333 .42801 m .53366 .42851 L .53371 .42847 L F
.53366 .42851 m .5346 .42983 L .53371 .42847 L F
.53456 .42472 m .5346 .4278 L .5344 .42483 L .358 .18 .498 r
F
.53357 .42831 m .53371 .42847 L .53365 .42827 L .667 .747 .91 r
F
.53371 .42847 m .53485 .42977 L .53377 .42842 L F
.53371 .42847 m .53377 .42842 L .53365 .42827 L F
.53326 .42878 m .53464 .43235 L .53427 .42936 L .643 .737 .917 r
F
.5337 .42856 m .53427 .42936 L .53414 .42835 L F
.53326 .42878 m .53427 .42936 L .5337 .42856 L F
.5346 .42983 m .538 .43336 L .53485 .42977 L .667 .747 .91 r
F
.53632 .43224 m .538 .43336 L .5346 .42983 L F
.53632 .43224 m .53725 .43355 L .538 .43336 L F
.538 .43336 m .54114 .43694 L .54537 .43499 L F
.53725 .43355 m .54114 .43694 L .538 .43336 L F
.53901 .43602 m .54114 .43694 L .53725 .43355 L F
.538 .43336 m .54537 .43499 L .54082 .43206 L F
.53485 .42977 m .54082 .43206 L .53626 .42912 L F
.53514 .42937 m .53547 .43105 L .54079 .43708 L .643 .737 .917 r
F
.53547 .43105 m .53678 .43784 L .53989 .43725 L F
.53547 .43105 m .53989 .43725 L .54079 .43708 L F
.53464 .43235 m .53678 .43784 L .53514 .42937 L F
.53475 .43417 m .53901 .43602 L .53725 .43355 L .667 .747 .91 r
F
.53322 .43018 m .53632 .43224 L .5346 .42983 L F
.53347 .42841 m .53359 .42856 L .53358 .42839 L F
.53359 .42856 m .5346 .42983 L .53366 .42851 L F
.53359 .42856 m .53366 .42851 L .53358 .42839 L F
.53442 .42793 m .53454 .42823 L .53465 .42808 L F
.53454 .42823 m .53509 .42966 L .53465 .42808 L F
.53434 .42804 m .54783 .44395 L .53497 .42782 L .643 .737 .917 r
F
.53407 .42814 m .53412 .42819 L .53434 .42804 L F
.53412 .42819 m .54783 .44395 L .53434 .42804 L F
.53347 .42841 m .53322 .43018 L .5346 .42983 L .667 .747 .91 r
F
.53343 .42836 m .53343 .42841 L .53347 .42841 L F
.53343 .42841 m .53322 .43018 L .53347 .42841 L F
.53449 .42788 m .53446 .4279 L .5344 .42483 L .358 .18 .498 r
F
.5346 .4278 m .53449 .42788 L .5344 .42483 L F
.53456 .42472 m .5351 .42743 L .5346 .4278 L F
.53424 .42711 m .53434 .42799 L .53421 .4271 L .517 .303 .528 r
F
.53424 .42711 m .53421 .4271 L .53392 .42505 L F
.53399 .42502 m .53424 .42711 L .53392 .42505 L F
.53434 .42799 m .53434 .42799 L .53392 .42505 L F
.53357 .42519 m .53434 .42804 L .53363 .42829 L F
.53392 .42505 m .53434 .42804 L .53357 .42519 L F
.53433 .42488 m .53444 .42792 L .53434 .42799 L .358 .18 .498 r
F
.53438 .42485 m .53444 .42792 L .53433 .42488 L F
.5321 .42632 m .5351 .42742 L .53203 .42622 L .667 .747 .91 r
F
.5351 .42742 m .5351 .42742 L .53203 .42622 L F
.53522 .42412 m .53526 .42719 L .53518 .42418 L .08 0 .418 r
F
.5351 .42743 m .53517 .42743 L .5351 .42753 L F
.53509 .42432 m .53517 .42732 L .5351 .42743 L F
.5351 .42742 m .53543 .42755 L .53539 .427 L .667 .747 .91 r
F
.53517 .42732 m .53517 .42743 L .5351 .42743 L .08 0 .418 r
F
.53595 .42618 m .53808 .42727 L .53836 .42619 L .667 .747 .91 r
F
.53254 .42693 m .532 .42885 L .53313 .42846 L .643 .737 .917 r
F
.53212 .42635 m .532 .42885 L .53254 .42693 L F
.5321 .42632 m .53442 .42793 L .5351 .42742 L .667 .747 .91 r
F
.5354 .42386 m .53555 .42676 L .53537 .4239 L .08 0 .418 r
F
.53509 .42431 m .53537 .42474 L .53542 .42443 L .667 .747 .91 r
F
.53537 .4239 m .53556 .4269 L .53522 .42412 L .08 0 .418 r
F
.53551 .42682 m .53808 .42727 L .53595 .42618 L .667 .747 .91 r
F
.53559 .42675 m .53558 .42678 L .53558 .42663 L 0 0 .15 r
F
.53559 .42659 m .53558 .42663 L .53556 .42357 L F
.53565 .42618 m .53556 .42675 L .53595 .42618 L .667 .747 .91 r
F
.53559 .42675 m .53558 .42663 L .53559 .42659 L 0 0 .15 r
F
.53509 .42432 m .53509 .42431 L .53509 .42431 L .667 .747 .91 r
F
.53513 .42425 m .53517 .42743 L .53509 .42432 L .08 0 .418 r
F
.53199 .42617 m .53551 .42682 L .53556 .42675 L .667 .747 .91 r
F
.53556 .42357 m .53558 .42678 L .53556 .42358 L 0 0 .15 r
F
.53555 .42364 m .53558 .42678 L .53556 .4269 L F
.53556 .42358 m .53558 .42678 L .53555 .42364 L F
.53559 .42341 m .5356 .42648 L .53556 .42357 L F
.5356 .42648 m .53559 .42659 L .53556 .42357 L F
.5354 .42386 m .53555 .42364 L .53556 .4269 L .08 0 .418 r
F
.53612 .4238 m .538 .42412 L .53577 .42304 L .667 .747 .91 r
F
.53608 .42353 m .53757 .42411 L .53656 .42324 L F
.53559 .42341 m .53568 .42598 L .5356 .42648 L 0 0 .15 r
F
.53162 .42302 m .53577 .42304 L .53547 .4224 L .667 .747 .91 r
F
.53154 .41989 m .53254 .42251 L .5335 .42212 L .668 .747 .909 r
F
.53324 .42065 m .53327 .42221 L .53324 .42222 L .517 .303 .528 r
F
.53348 .42056 m .53365 .42206 L .53351 .42211 L F
.53154 .41989 m .53441 .42174 L .53509 .4212 L .668 .747 .909 r
F
.53154 .41989 m .5335 .42212 L .53441 .42174 L F
.53162 .42302 m .53516 .42178 L .53448 .4213 L .667 .747 .91 r
F
.5319 .42604 m .5352 .42492 L .53481 .42464 L F
.53162 .42302 m .53551 .42369 L .53577 .42304 L F
.53154 .41989 m .53558 .41954 L .53545 .41925 L .668 .747 .909 r
F
.53154 .41989 m .53509 .4212 L .53552 .42057 L F
.53258 .41792 m .56571 .41965 L .56493 .41442 L .644 .737 .916 r
F
.53494 .41716 m .53492 .41852 L .5352 .41735 L .911 .629 .497 r
F
.53404 .40198 m .53382 .41643 L .53408 .41652 L .81 .54 .53 r
F
.53258 .41792 m .55689 .40492 L .55016 .40132 L .644 .737 .916 r
F
.53494 .41716 m .53408 .41652 L .53408 .41792 L .911 .629 .497 r
F
.53494 .41716 m .53408 .41792 L .53492 .41852 L F
.53154 .41989 m .53456 .41807 L .53361 .41777 L .668 .747 .909 r
F
.53162 .42302 m .5332 .42526 L .53344 .42511 L .667 .747 .91 r
F
.5332 .42526 m .53325 .42533 L .53344 .42511 L F
.53344 .42511 m .53325 .42533 L .53353 .42521 L F
.53162 .42302 m .53353 .42521 L .53441 .42483 L F
.53353 .42521 m .53433 .42488 L .53441 .42483 L F
.5319 .42604 m .53481 .42464 L .53454 .42445 L F
.53199 .42617 m .53556 .42675 L .53565 .42618 L F
.53225 .42653 m .53442 .42793 L .5321 .42632 L F
.53203 .42622 m .53551 .42682 L .53199 .42617 L F
.53203 .42622 m .53539 .427 L .53551 .42682 L F
.53259 .42852 m .53265 .42868 L .53326 .42843 L F
.53242 .42871 m .53309 .42883 L .53313 .42846 L .643 .737 .917 r
F
.53313 .42846 m .5329 .43051 L .53357 .4296 L F
.53265 .42868 m .53322 .43018 L .53343 .42836 L .667 .747 .91 r
F
.53322 .43018 m .53326 .43027 L .53326 .43021 L F
.53326 .43027 m .53475 .43417 L .53326 .43021 L F
.53326 .43021 m .53475 .43417 L .53725 .43355 L F
.53272 .43657 m .53267 .437 L .53284 .43688 L .642 .738 .918 r
F
.53261 .43628 m .53159 .43636 L .53272 .43657 L F
.5313 .43444 m .53627 .43815 L .53475 .43417 L .667 .747 .91 r
F
.53149 .43031 m .5313 .43444 L .53475 .43417 L F
.53149 .43031 m .53475 .43417 L .53322 .43018 L F
.53212 .42635 m .53078 .42861 L .53202 .42851 L .643 .737 .917 r
F
.53195 .42611 m .52971 .42821 L .53201 .42619 L F
.53562 .4258 m .53563 .42582 L .53565 .42278 L .983 .725 .332 r
F
.53551 .42369 m .53574 .42373 L .53575 .42334 L .667 .747 .91 r
F
.53551 .42369 m .53575 .42334 L .53577 .42304 L F
.53559 .42341 m .53568 .42284 L .53569 .42595 L 0 0 .15 r
F
.53565 .42618 m .53836 .42619 L .53573 .42571 L .667 .747 .91 r
F
.53568 .42598 m .53569 .42595 L .53569 .42614 L 0 0 .15 r
F
.53559 .42341 m .53569 .42595 L .53568 .42598 L F
.53573 .42571 m .53836 .42619 L .53824 .42543 L .667 .747 .91 r
F
.53562 .4258 m .53565 .42278 L .53564 .42276 L .983 .725 .332 r
F
.53169 .42616 m .53565 .42618 L .53569 .42595 L .667 .747 .91 r
F
.53568 .42598 m .53569 .42614 L .5356 .42648 L 0 0 .15 r
F
.53569 .42595 m .53566 .42606 L .53569 .42614 L .983 .725 .332 r
F
.53568 .42284 m .53566 .42588 L .53569 .42595 L F
.53566 .42588 m .53566 .42606 L .53569 .42595 L F
.53564 .42275 m .53562 .4258 L .53564 .42276 L F
.53565 .42278 m .53563 .42582 L .53568 .42284 L F
.53563 .42582 m .53566 .42588 L .53568 .42284 L F
.53553 .4256 m .53562 .4258 L .53564 .42275 L F
.53552 .42057 m .5361 .42067 L .53584 .42011 L .668 .747 .909 r
F
.53555 .41949 m .53554 .42254 L .53564 .41967 L .983 .725 .332 r
F
.53554 .42254 m .53553 .4256 L .53558 .42263 L F
.53554 .42254 m .53558 .42263 L .53564 .41967 L F
.53556 .41813 m .53555 .41949 L .53566 .41836 L F
.53555 .41949 m .53564 .41967 L .53566 .41836 L F
.53566 .41836 m .53566 .41971 L .53567 .41974 L F
.53404 .40198 m .53294 .41612 L .53382 .41643 L .81 .54 .53 r
F
.53258 .41792 m .55016 .40132 L .5422 .39886 L .644 .737 .916 r
F
.53382 .41643 m .5338 .41783 L .53408 .41652 L .81 .54 .53 r
F
.53521 .41872 m .53735 .41895 L .53593 .4185 L .668 .747 .909 r
F
.53154 .41989 m .53586 .41919 L .53521 .41872 L F
.53586 .41919 m .53735 .41895 L .53521 .41872 L F
.5352 .41735 m .53517 .41869 L .5352 .41872 L .911 .629 .497 r
F
.53492 .41852 m .53517 .41869 L .5352 .41735 L F
.53556 .41813 m .5352 .41735 L .5352 .41872 L .983 .725 .332 r
F
.53516 .41862 m .53749 .418 L .53704 .41796 L .668 .747 .909 r
F
.53154 .41989 m .5352 .41873 L .53516 .41862 L F
.5352 .41873 m .53749 .418 L .53516 .41862 L F
.53169 .42616 m .53559 .42573 L .5355 .42555 L .667 .747 .91 r
F
.53169 .42616 m .53569 .42595 L .53559 .42573 L F
.53446 .4279 m .53446 .42796 L .53444 .42792 L .358 .18 .498 r
F
.53438 .4285 m .53446 .42963 L .53514 .42937 L .643 .737 .917 r
F
.53446 .42963 m .53498 .43036 L .53514 .42937 L F
.53322 .43018 m .53725 .43355 L .53632 .43224 L .667 .747 .91 r
F
.5351 .42742 m .53626 .42912 L .53691 .42861 L F
.5351 .42742 m .53691 .42861 L .53663 .42799 L F
.53543 .42755 m .53737 .42826 L .53671 .42703 L F
.53568 .42611 m .53728 .42703 L .53938 .4263 L .643 .737 .917 r
F
.5356 .42648 m .53569 .42614 L .53561 .42664 L 0 0 .15 r
F
.53193 .42608 m .53522 .42493 L .5319 .42604 L .667 .747 .91 r
F
.53553 .4256 m .53564 .42275 L .53558 .42263 L .983 .725 .332 r
F
.53162 .42302 m .53509 .42431 L .53551 .42369 L .667 .747 .91 r
F
.53554 .42254 m .53524 .42497 L .53553 .4256 L .983 .725 .332 r
F
.53522 .42493 m .53819 .42511 L .53757 .42411 L .667 .747 .91 r
F
.53169 .42616 m .53598 .42547 L .53522 .42493 L F
.53598 .42547 m .53819 .42511 L .53522 .42493 L F
.53564 .42276 m .53565 .42278 L .53567 .41974 L .983 .725 .332 r
F
.53567 .41974 m .53565 .42278 L .53568 .42284 L F
.53555 .41949 m .53536 .42216 L .53554 .42254 L F
.53162 .42302 m .53592 .42233 L .53516 .42178 L .667 .747 .91 r
F
.5352 .41872 m .53508 .42483 L .53522 .42493 L .911 .629 .497 r
F
.5355 .41937 m .53521 .42182 L .53536 .42216 L .983 .725 .332 r
F
.5355 .41937 m .53536 .42216 L .53555 .41949 L F
.5366 .42176 m .53718 .42198 L .5361 .42067 L .668 .747 .909 r
F
.53516 .42178 m .53811 .42197 L .5375 .42096 L .667 .747 .91 r
F
.53592 .42233 m .53811 .42197 L .53516 .42178 L F
.53517 .41869 m .53511 .42175 L .5352 .41872 L .911 .629 .497 r
F
.53511 .42175 m .53505 .42481 L .53512 .42176 L F
.53511 .42175 m .53512 .42176 L .5352 .41872 L F
.53522 .42493 m .5352 .42492 L .5319 .42604 L .667 .747 .91 r
F
.5356 .42648 m .53561 .42664 L .53559 .42659 L 0 0 .15 r
F
.53561 .42664 m .53559 .42675 L .53559 .42659 L F
.53214 .42592 m .5356 .42667 L .53568 .42611 L .643 .737 .917 r
F
.5356 .42667 m .53597 .42675 L .53569 .42614 L F
.5356 .42667 m .53569 .42614 L .53568 .42611 L F
.53555 .42676 m .53556 .4269 L .53555 .42676 L .08 0 .418 r
F
.53551 .42682 m .53559 .42705 L .53583 .42688 L .667 .747 .91 r
F
.53539 .427 m .53559 .42705 L .53551 .42682 L F
.53583 .42688 m .53627 .42721 L .53614 .42693 L F
.53559 .42705 m .53627 .42721 L .53583 .42688 L F
.53526 .42719 m .53556 .4269 L .53526 .42731 L .08 0 .418 r
F
.53555 .42677 m .53556 .4269 L .53526 .42719 L F
.53203 .42622 m .5351 .42742 L .53539 .427 L .667 .747 .91 r
F
.53214 .42592 m .53598 .42748 L .53627 .42738 L .643 .737 .917 r
F
.53614 .42693 m .53627 .42721 L .53671 .42703 L .667 .747 .91 r
F
.53597 .42675 m .53627 .42738 L .53728 .42703 L .643 .737 .917 r
F
.53214 .42592 m .53627 .42738 L .53597 .42675 L F
.53563 .42582 m .53563 .426 L .53566 .42588 L .983 .725 .332 r
F
.5351 .42742 m .53543 .42755 L .5351 .42742 L .667 .747 .91 r
F
.53548 .42727 m .53497 .42782 L .53598 .42748 L .643 .737 .917 r
F
.5346 .4278 m .5351 .42743 L .5351 .42753 L .358 .18 .498 r
F
.53526 .42719 m .53526 .42731 L .53517 .42732 L .08 0 .418 r
F
.53482 .42772 m .53497 .42782 L .53548 .42727 L .643 .737 .917 r
F
.53663 .42799 m .53691 .42861 L .53737 .42826 L .667 .747 .91 r
F
.53497 .42782 m .55486 .44119 L .53598 .42748 L .643 .737 .917 r
F
.53536 .42808 m .53859 .43236 L .53716 .42929 L F
.53533 .42827 m .53859 .43236 L .53536 .42808 L F
.53514 .42937 m .54079 .43708 L .53956 .43445 L F
.53561 .42664 m .53569 .42614 L .53572 .43395 L 0 0 .15 r
F
.5417 .4369 m .53976 .44549 L .54783 .44395 L .643 .737 .917 r
F
.535 .43821 m .53934 .45349 L .54441 .45253 L .642 .738 .918 r
F
.53483 .43921 m .53934 .45349 L .535 .43821 L F
.53394 .43694 m .53478 .4395 L .53406 .43678 L F
.53478 .4395 m .53934 .45349 L .53483 .43921 L F
.53478 .4395 m .53483 .43921 L .53406 .43678 L F
.53558 .42678 m .53563 .43448 L .53556 .4269 L 0 0 .15 r
F
.53506 .43781 m .54441 .45253 L .54035 .44386 L .642 .738 .918 r
F
.53501 .43811 m .54441 .45253 L .53506 .43781 L F
.53406 .43678 m .54441 .45253 L .53411 .43672 L F
.53284 .43688 m .53324 .43789 L .53373 .43628 L F
.53324 .43789 m .53934 .45349 L .53394 .43694 L F
.53324 .43789 m .53394 .43694 L .53373 .43628 L F
.53627 .43815 m .53627 .43794 L .53656 .43789 L .592 .368 .545 r
F
.53475 .43417 m .53627 .43815 L .53989 .43725 L .667 .747 .91 r
F
.53475 .43417 m .53989 .43725 L .53901 .43602 L F
.53517 .42743 m .53527 .43515 L .5351 .42753 L .08 0 .418 r
F
.53561 .42664 m .53572 .43395 L .53565 .43436 L 0 0 .15 r
F
.53562 .42951 m .53565 .43436 L .53561 .43018 L F
.53562 .42951 m .53561 .43018 L .53559 .42675 L F
.53561 .42664 m .53562 .42951 L .53559 .42675 L F
.53563 .426 m .53566 .42606 L .53566 .42588 L .983 .725 .332 r
F
.5355 .42555 m .53824 .42543 L .53756 .42522 L .667 .747 .91 r
F
.53559 .42573 m .53824 .42543 L .5355 .42555 L F
.53756 .42522 m .53824 .42543 L .53819 .42511 L F
.56423 .42474 m .59569 .43153 L .59883 .42139 L .644 .737 .916 r
F
.56423 .42474 m .59883 .42139 L .56571 .41965 L F
.54281 .42406 m .55057 .42317 L .54424 .42208 L .668 .747 .909 r
F
.54424 .42208 m .55057 .42317 L .55143 .41997 L F
.54438 .42522 m .55162 .4231 L .54496 .42308 L .667 .747 .91 r
F
.538 .42412 m .54438 .42522 L .54496 .42308 L F
.53729 .42512 m .54438 .42522 L .538 .42412 L F
.54424 .42208 m .55143 .41997 L .5448 .41994 L .668 .747 .909 r
F
.5448 .41994 m .55143 .41997 L .55094 .41674 L F
.54496 .42308 m .55162 .4231 L .55113 .41987 L .667 .747 .91 r
F
.55172 .42625 m .55162 .4231 L .55113 .41987 L .835 .641 .094 r
F
.55172 .42625 m .55113 .41987 L .55122 .42301 L F
.54504 .42622 m .55172 .42625 L .55122 .42301 L .667 .747 .91 r
F
.54504 .42622 m .55122 .42301 L .5447 .42406 L F
.53836 .42619 m .54504 .42622 L .5447 .42406 L F
.53836 .42619 m .5447 .42406 L .53819 .42511 L F
.53577 .42553 m .56551 .42767 L .56473 .42242 L .643 .737 .917 r
F
.53562 .4258 m .53562 .42598 L .53563 .42582 L .983 .725 .332 r
F
.53562 .42598 m .53563 .426 L .53563 .42582 L F
.53214 .42592 m .53568 .42611 L .53543 .42557 L .643 .737 .917 r
F
.53563 .43448 m .53561 .43458 L .53556 .4269 L 0 0 .15 r
F
.53556 .4269 m .53561 .43458 L .53559 .43472 L F
.53565 .43436 m .53558 .42678 L .53559 .42675 L F
.53533 .42721 m .5351 .42753 L .53548 .42727 L .643 .737 .917 r
F
.53526 .42731 m .53556 .4269 L .53559 .43472 L .08 0 .418 r
F
.53467 .43595 m .53955 .44216 L .53755 .43788 L .642 .738 .918 r
F
.53462 .43602 m .53955 .44216 L .53467 .43595 L F
.53553 .4256 m .5355 .43348 L .53562 .4258 L .983 .725 .332 r
F
.53373 .43628 m .54035 .44386 L .53446 .43582 L .642 .738 .918 r
F
.54035 .44386 m .53955 .44216 L .53446 .43582 L F
.53343 .42836 m .53347 .42841 L .53345 .42836 L .667 .747 .91 r
F
.53326 .42878 m .53414 .42835 L .53386 .42837 L .643 .737 .917 r
F
.53363 .42828 m .53378 .43606 L .53342 .42837 L .517 .303 .528 r
F
.53378 .43606 m .53361 .43611 L .53342 .42837 L F
.53446 .42796 m .5346 .4357 L .53444 .42798 L .358 .18 .498 r
F
.5346 .4357 m .53458 .43571 L .53444 .42798 L F
.53201 .42619 m .53078 .42861 L .53212 .42635 L .643 .737 .917 r
F
.53201 .42619 m .52971 .42821 L .53088 .42842 L F
.53215 .4285 m .53326 .42842 L .53326 .42843 L .641 .401 .54 r
F
.53215 .4285 m .53326 .42843 L .53215 .42858 L F
.53078 .42861 m .53051 .42914 L .53202 .42851 L .643 .737 .917 r
F
.53183 .42853 m .53183 .42862 L .53183 .42853 L .641 .401 .54 r
F
.53047 .42835 m .53157 .42855 L .53157 .42866 L .751 .491 .539 r
F
.5327 .42882 m .53149 .43031 L .53322 .43018 L .667 .747 .91 r
F
.53243 .42878 m .53149 .43031 L .5327 .42882 L F
.53157 .42866 m .53149 .43031 L .53259 .42852 L F
.53081 .43622 m .5305 .43633 L .53073 .43643 L .642 .738 .918 r
F
.53056 .42851 m .52977 .43016 L .53157 .42866 L .667 .747 .91 r
F
.53047 .42835 m .53157 .42866 L .53048 .4285 L .751 .491 .539 r
F
.53056 .42851 m .52819 .42974 L .52977 .43016 L .667 .747 .91 r
F
.53016 .42829 m .53017 .42846 L .53011 .42828 L .751 .491 .539 r
F
.53017 .42846 m .53012 .42845 L .53011 .42828 L F
.52991 .42824 m .52992 .42842 L .52991 .42842 L F
.52953 .42837 m .52819 .42974 L .53036 .42862 L .667 .747 .91 r
F
.52991 .42842 m .53036 .42862 L .53056 .42851 L F
.52953 .42837 m .53036 .42862 L .52991 .42842 L F
.52922 .42792 m .52991 .42824 L .52991 .42842 L .845 .571 .524 r
F
.52832 .4423 m .52222 .45259 L .52836 .44282 L .642 .738 .918 r
F
.5305 .43633 m .53028 .43675 L .53157 .43682 L F
.52575 .42508 m .52194 .42885 L .52677 .42594 L .667 .747 .91 r
F
.53187 .426 m .52424 .4272 L .52637 .42759 L .643 .737 .917 r
F
.53185 .42597 m .52424 .4272 L .53187 .426 L F
.53142 .42243 m .53107 .42272 L .5314 .42286 L .668 .747 .909 r
F
.53055 .4223 m .53156 .42244 L .53156 .42555 L .751 .491 .539 r
F
.53055 .4223 m .53156 .42555 L .53107 .42548 L F
.53162 .42302 m .5276 .42301 L .5275 .42317 L .667 .747 .91 r
F
.53162 .42302 m .5275 .42317 L .52778 .42364 L F
.52772 .42305 m .52776 .42361 L .52776 .4265 L .781 .623 .061 r
F
.52772 .42305 m .52776 .4265 L .52773 .42599 L F
.5278 .42367 m .52782 .4266 L .52779 .42366 L .988 .719 .384 r
F
.52776 .42361 m .52782 .4266 L .52776 .4265 L F
.52779 .42366 m .52782 .4266 L .52776 .42361 L F
.53185 .42597 m .52627 .42655 L .52677 .42679 L .643 .737 .917 r
F
.53505 .42481 m .53508 .42483 L .5352 .41872 L .911 .629 .497 r
F
.53197 .42239 m .53161 .42244 L .53155 .42078 L .641 .401 .54 r
F
.53155 .42078 m .53161 .42244 L .53156 .42244 L F
.53154 .41989 m .53156 .42244 L .53247 .42232 L .668 .747 .909 r
F
.53162 .42302 m .53448 .4213 L .53369 .4209 L .667 .747 .91 r
F
.53492 .41852 m .53409 .42102 L .53454 .42116 L .911 .629 .497 r
F
.53452 .42127 m .53448 .4213 L .53451 .42132 L F
.53448 .4213 m .53465 .4212 L .53409 .42102 L .667 .747 .91 r
F
.53448 .4213 m .53409 .42102 L .53369 .4209 L F
.53488 .42158 m .5341 .42414 L .53483 .42466 L .911 .629 .497 r
F
.53492 .41852 m .53451 .42132 L .53488 .42158 L F
.53451 .42132 m .5341 .42414 L .53488 .42158 L F
.53371 .42401 m .53393 .42408 L .53399 .42099 L .81 .54 .53 r
F
.53388 .42096 m .53399 .42099 L .53405 .41791 L F
.53371 .42401 m .53399 .42099 L .53388 .42096 L F
.5338 .41783 m .53375 .42092 L .53405 .41791 L F
.53375 .42092 m .53371 .42401 L .53388 .42096 L F
.53375 .42092 m .53388 .42096 L .53405 .41791 L F
.53291 .4016 m .53268 .41609 L .53294 .41612 L .734 .477 .539 r
F
.53291 .4016 m .53179 .41596 L .53268 .41609 L F
.53258 .41792 m .5422 .39886 L .53356 .39771 L .644 .737 .916 r
F
.5338 .41783 m .53405 .41791 L .53408 .41652 L .81 .54 .53 r
F
.53408 .41652 m .53405 .41791 L .53408 .41792 L F
.53294 .41612 m .53291 .41756 L .53294 .41756 L .734 .477 .539 r
F
.53382 .41643 m .53294 .41612 L .53294 .41756 L .81 .54 .53 r
F
.53382 .41643 m .53294 .41756 L .5338 .41783 L F
.53275 .41737 m .53503 .41631 L .53345 .41588 L .668 .747 .909 r
F
.53176 .40147 m .53063 .416 L .53153 .41597 L .66 .416 .54 r
F
.53061 .40156 m .53037 .41607 L .53063 .416 L .567 .342 .533 r
F
.53258 .41792 m .5167 .39957 L .50965 .40244 L .644 .737 .916 r
F
.53176 .40147 m .53153 .41597 L .53179 .41596 L .66 .416 .54 r
F
.53291 .4016 m .53176 .40147 L .53179 .41596 L .734 .477 .539 r
F
.53258 .41792 m .52485 .39795 L .5167 .39957 L .644 .737 .916 r
F
.53258 .41792 m .53356 .39771 L .52485 .39795 L F
.53268 .41609 m .53179 .41596 L .53179 .41745 L .734 .477 .539 r
F
.53154 .41989 m .53374 .41764 L .53266 .41753 L .668 .747 .909 r
F
.53162 .42302 m .53369 .4209 L .53295 .42067 L .667 .747 .91 r
F
.53162 .42302 m .53295 .42067 L .53275 .42065 L F
.53186 .42599 m .53473 .42433 L .53377 .42403 L F
.53187 .426 m .52768 .42721 L .53191 .42605 L .643 .737 .917 r
F
.53169 .42616 m .5319 .42604 L .53186 .42599 L .667 .747 .91 r
F
.5319 .42604 m .53473 .42433 L .53186 .42599 L F
.53191 .42605 m .52768 .42721 L .52877 .42772 L .643 .737 .917 r
F
.53214 .42592 m .53187 .426 L .53191 .42605 L F
.53214 .42592 m .53184 .42595 L .53185 .42597 L F
.53184 .42595 m .52627 .42655 L .53185 .42597 L F
.53259 .42852 m .53243 .42878 L .5327 .42882 L .667 .747 .91 r
F
.53215 .4285 m .53215 .42858 L .53183 .42853 L .641 .401 .54 r
F
.53215 .42858 m .53183 .42862 L .53183 .42853 L F
.53169 .42616 m .53157 .42866 L .53259 .42852 L .667 .747 .91 r
F
.53215 .42858 m .53237 .4363 L .53183 .42862 L .641 .401 .54 r
F
.53237 .4363 m .53336 .47161 L .53211 .43632 L F
.53237 .4363 m .53211 .43632 L .53183 .42862 L F
.53716 .42929 m .54783 .44395 L .55486 .44119 L .643 .737 .917 r
F
.53859 .43236 m .54783 .44395 L .53716 .42929 L F
.53665 .43596 m .55603 .44814 L .54273 .43842 L .642 .738 .918 r
F
.53215 .42858 m .53327 .43623 L .53237 .4363 L .641 .401 .54 r
F
.5346 .42787 m .53512 .43534 L .53472 .43562 L .358 .18 .498 r
F
.53215 .42858 m .53326 .42843 L .53327 .43623 L .641 .401 .54 r
F
.53472 .43562 m .5346 .4357 L .53446 .42796 L .358 .18 .498 r
F
.53472 .43562 m .53446 .42796 L .53446 .42796 L F
.53472 .43562 m .53446 .4279 L .53449 .42788 L F
.5346 .42787 m .53472 .43562 L .53449 .42794 L F
.53342 .42837 m .53361 .43611 L .53339 .42838 L .517 .303 .528 r
F
.53361 .43611 m .53359 .43612 L .53339 .42838 L F
.53157 .42866 m .53207 .43632 L .53159 .43636 L .641 .401 .54 r
F
.53179 .42863 m .53207 .43632 L .53157 .42866 L F
.53183 .42862 m .53211 .43632 L .53179 .42863 L F
.53211 .43632 m .53207 .43632 L .53179 .42863 L F
.53339 .42838 m .53359 .43612 L .53333 .4284 L .517 .303 .528 r
F
.53359 .43612 m .53354 .43614 L .53333 .4284 L F
.53359 .43612 m .53284 .43688 L .53373 .43628 L .642 .738 .918 r
F
.53326 .42843 m .53347 .43616 L .53327 .43623 L .517 .303 .528 r
F
.53267 .43644 m .53284 .43688 L .53359 .43612 L .642 .738 .918 r
F
.53333 .4284 m .53354 .43614 L .53326 .42843 L .517 .303 .528 r
F
.53354 .43614 m .53447 .47118 L .53347 .43616 L F
.53354 .43614 m .53347 .43616 L .53326 .42843 L F
.53473 .43573 m .5349 .4361 L .53531 .43607 L .642 .738 .918 r
F
.53411 .43672 m .53501 .43811 L .53506 .43781 L F
.53406 .43678 m .53483 .43921 L .535 .43821 L F
.53437 .43585 m .53523 .47062 L .53447 .47118 L .358 .18 .498 r
F
.53434 .42804 m .5345 .43576 L .53437 .43585 L F
.53437 .43585 m .53446 .43582 L .53445 .4358 L .642 .738 .918 r
F
.5345 .43576 m .53523 .47062 L .53437 .43585 L .358 .18 .498 r
F
.53463 .43567 m .53447 .43582 L .53473 .43573 L .642 .738 .918 r
F
.53445 .4358 m .53447 .43582 L .53463 .43567 L F
.53447 .43582 m .5349 .4361 L .53473 .43573 L F
.53444 .42798 m .53458 .43571 L .53434 .42804 L .358 .18 .498 r
F
.53445 .4358 m .53462 .43602 L .53467 .43595 L .642 .738 .918 r
F
.53458 .43571 m .53523 .47062 L .5345 .43576 L .358 .18 .498 r
F
.53427 .42936 m .53446 .42963 L .53438 .4285 L .643 .737 .917 r
F
.53458 .43571 m .5345 .43576 L .53434 .42804 L .358 .18 .498 r
F
.53512 .43535 m .53473 .43573 L .53545 .43548 L .642 .738 .918 r
F
.53359 .43612 m .53365 .4362 L .53428 .43588 L F
.53365 .4362 m .53373 .43628 L .53388 .43618 L F
.53386 .42837 m .53414 .42835 L .53412 .42819 L .643 .737 .917 r
F
.53419 .42876 m .53427 .42936 L .53438 .4285 L F
.53412 .42819 m .53419 .42876 L .53438 .4285 L F
.53363 .42829 m .53434 .42804 L .53437 .43585 L .517 .303 .528 r
F
.53365 .4362 m .53388 .43618 L .53437 .43585 L .642 .738 .918 r
F
.53365 .4362 m .53437 .43585 L .53428 .43588 L F
.53373 .43628 m .53446 .43582 L .53437 .43585 L F
.53373 .43628 m .53406 .43678 L .53411 .43672 L F
.53373 .43628 m .53394 .43694 L .53406 .43678 L F
.53378 .43606 m .53437 .43585 L .53447 .47118 L .517 .303 .528 r
F
.53363 .42829 m .53437 .43585 L .53378 .43606 L F
.53428 .43588 m .53437 .43585 L .53445 .4358 L .642 .738 .918 r
F
.5317 .43397 m .53463 .43567 L .53512 .43535 L F
.53463 .43567 m .53473 .43573 L .53512 .43535 L F
.5317 .43397 m .53445 .4358 L .53463 .43567 L F
.5317 .43397 m .53267 .43644 L .53359 .43612 L F
.53327 .43623 m .53447 .47118 L .53336 .47161 L .517 .303 .528 r
F
.53347 .43616 m .53447 .47118 L .53327 .43623 L F
.53359 .43612 m .53447 .47118 L .53354 .43614 L F
.5317 .43397 m .53359 .43612 L .53445 .4358 L .642 .738 .918 r
F
.53359 .43612 m .53428 .43588 L .53445 .4358 L F
.53211 .43632 m .53336 .47161 L .53207 .43632 L .641 .401 .54 r
F
.53361 .43611 m .53447 .47118 L .53359 .43612 L .517 .303 .528 r
F
.53545 .43548 m .53531 .43607 L .53665 .43596 L .642 .738 .918 r
F
.53473 .43573 m .53531 .43607 L .53545 .43548 L F
.53531 .43607 m .53723 .43719 L .53665 .43596 L F
.53723 .43719 m .55448 .4492 L .55603 .44814 L F
.53531 .43607 m .53736 .43748 L .53723 .43719 L F
.53736 .43748 m .55448 .4492 L .53723 .43719 L F
.53565 .43436 m .53563 .43448 L .53558 .42678 L 0 0 .15 r
F
.53566 .42606 m .5356 .43371 L .53569 .42614 L .983 .725 .332 r
F
.5349 .4361 m .53755 .43788 L .53531 .43607 L .642 .738 .918 r
F
.53755 .43788 m .55448 .4492 L .53736 .43748 L F
.53755 .43788 m .53736 .43748 L .53531 .43607 L F
.53526 .42731 m .53559 .43472 L .53534 .43505 L .08 0 .418 r
F
.53497 .42782 m .53533 .42827 L .53536 .42808 L .643 .737 .917 r
F
.53526 .42731 m .53534 .43505 L .53517 .42743 L .08 0 .418 r
F
.53534 .43505 m .53527 .43515 L .53517 .42743 L F
.53526 .42731 m .53517 .42743 L .53517 .42732 L F
.53214 .42592 m .5351 .42753 L .53533 .42721 L .643 .737 .917 r
F
.55162 .4231 m .55153 .41997 L .55104 .41673 L .835 .641 .094 r
F
.538 .42412 m .54496 .42308 L .53829 .42305 L .667 .747 .91 r
F
.55162 .4231 m .55104 .41673 L .55113 .41987 L .835 .641 .094 r
F
.54496 .42308 m .55113 .41987 L .54462 .42092 L .667 .747 .91 r
F
.53789 .42098 m .54424 .42208 L .5448 .41994 L .668 .747 .909 r
F
.53718 .42198 m .54424 .42208 L .53789 .42098 L F
.53829 .42305 m .54496 .42308 L .54462 .42092 L .667 .747 .91 r
F
.53577 .42304 m .538 .42412 L .53829 .42305 L F
.53819 .42511 m .54348 .42205 L .53757 .42411 L F
.53819 .42511 m .5447 .42406 L .54348 .42205 L F
.5448 .41994 m .55094 .41674 L .54447 .41779 L .668 .747 .909 r
F
.54447 .41779 m .55094 .41674 L .54912 .41372 L F
.54462 .42092 m .55113 .41987 L .5493 .41683 L .667 .747 .91 r
F
.55122 .42301 m .55113 .41987 L .5493 .41683 L .986 .709 .369 r
F
.5447 .42406 m .54939 .41998 L .54348 .42205 L .667 .747 .91 r
F
.5447 .42406 m .55122 .42301 L .54939 .41998 L F
.55122 .42301 m .5493 .41683 L .54939 .41998 L .986 .709 .369 r
F
.5371 .42449 m .56473 .42242 L .5617 .41738 L .643 .737 .917 r
F
.53371 .42401 m .5337 .42417 L .53393 .42408 L .81 .54 .53 r
F
.53553 .4256 m .53522 .42513 L .53553 .42579 L .983 .725 .332 r
F
.53524 .42497 m .53522 .42513 L .53553 .4256 L F
.53522 .42493 m .53521 .42512 L .53522 .42513 L .911 .629 .497 r
F
.53214 .42592 m .53577 .42553 L .53513 .42506 L .643 .737 .917 r
F
.53378 .43606 m .53447 .47118 L .53361 .43611 L .517 .303 .528 r
F
.53482 .42772 m .53434 .42804 L .53497 .42782 L .643 .737 .917 r
F
.5346 .42787 m .5351 .42753 L .53512 .43534 L .358 .18 .498 r
F
.53214 .42592 m .53482 .42772 L .5351 .42753 L .643 .737 .917 r
F
.5346 .4278 m .5351 .42753 L .5346 .42787 L .358 .18 .498 r
F
.53214 .42592 m .53513 .42506 L .53456 .42464 L .643 .737 .917 r
F
.53527 .43515 m .53521 .43523 L .5351 .42753 L .08 0 .418 r
F
.5351 .42753 m .53521 .43523 L .53512 .43534 L F
.53956 .43445 m .54079 .43708 L .5417 .4369 L .643 .737 .917 r
F
.5317 .43397 m .54273 .43842 L .53868 .43546 L .642 .738 .918 r
F
.5346 .4357 m .53523 .47062 L .53458 .43571 L .358 .18 .498 r
F
.53446 .42796 m .53444 .42798 L .53444 .42792 L F
.53225 .42653 m .53365 .42827 L .53442 .42793 L .667 .747 .91 r
F
.53365 .42827 m .53434 .42799 L .53442 .42793 L F
.53214 .42592 m .53407 .42814 L .53434 .42804 L .643 .737 .917 r
F
.53446 .42796 m .53446 .42796 L .53446 .4279 L .358 .18 .498 r
F
.5346 .4278 m .5346 .42787 L .53449 .42788 L F
.5346 .42787 m .53449 .42794 L .53449 .42788 L F
.53434 .42799 m .53434 .42804 L .53434 .42799 L .517 .303 .528 r
F
.53444 .42792 m .53444 .42798 L .53434 .42799 L .358 .18 .498 r
F
.53214 .42592 m .53434 .42804 L .53482 .42772 L .643 .737 .917 r
F
.53472 .43562 m .53523 .47062 L .5346 .4357 L .358 .18 .498 r
F
.53483 .42466 m .5341 .42414 L .5341 .4243 L .911 .629 .497 r
F
.53405 .41791 m .53393 .42408 L .53408 .41792 L .81 .54 .53 r
F
.53393 .42408 m .53395 .42409 L .53408 .41792 L F
.53408 .41792 m .53395 .42409 L .5341 .42414 L F
.53451 .42132 m .53409 .42102 L .5341 .42414 L .911 .629 .497 r
F
.53488 .42158 m .53483 .42466 L .535 .42167 L F
.53483 .42466 m .53505 .42481 L .53511 .42175 L F
.53483 .42466 m .53511 .42175 L .535 .42167 L F
.53536 .42216 m .53521 .42182 L .53522 .42493 L .983 .725 .332 r
F
.53523 .42495 m .53522 .42493 L .53522 .42513 L F
.53536 .42216 m .53522 .42493 L .53523 .42495 L F
.5352 .42492 m .53521 .42491 L .53481 .42464 L .667 .747 .91 r
F
.53521 .42491 m .53589 .42468 L .53509 .42465 L F
.53521 .42491 m .53509 .42465 L .53481 .42464 L F
.53536 .42216 m .53522 .42513 L .53554 .42254 L .983 .725 .332 r
F
.53377 .42403 m .53656 .42324 L .5352 .42257 L .667 .747 .91 r
F
.53473 .42433 m .53656 .42324 L .53377 .42403 L F
.53214 .42592 m .53456 .42464 L .5341 .4243 L .643 .737 .917 r
F
.5317 .43397 m .53868 .43546 L .53702 .43425 L .642 .738 .918 r
F
.53237 .4363 m .53327 .43623 L .53336 .47161 L .641 .401 .54 r
F
.53214 .42592 m .53254 .42693 L .53407 .42814 L .643 .737 .917 r
F
.5333 .42801 m .53357 .42831 L .53256 .42695 L .667 .747 .91 r
F
.5333 .42801 m .53256 .42695 L .53225 .42653 L F
.53357 .42831 m .53365 .42827 L .53225 .42653 L F
.53254 .42693 m .53353 .42832 L .53407 .42814 L .643 .737 .917 r
F
.53159 .43636 m .53159 .43636 L .53261 .43628 L .642 .738 .918 r
F
.53207 .43632 m .53336 .47161 L .53159 .43636 L .641 .401 .54 r
F
.5341 .4243 m .53391 .43205 L .53412 .43213 L .81 .54 .53 r
F
.5341 .42414 m .5341 .4243 L .5341 .4243 L F
.5341 .4243 m .53391 .43205 L .5341 .4243 L F
.53391 .43205 m .53391 .43205 L .5341 .4243 L F
.53482 .42483 m .5341 .4243 L .53412 .43213 L .911 .629 .497 r
F
.53483 .42466 m .53412 .43213 L .53472 .43256 L F
.53454 .42445 m .53599 .42407 L .53529 .424 L .667 .747 .91 r
F
.53481 .42464 m .53599 .42407 L .53454 .42445 L F
.53481 .42464 m .53589 .42468 L .53599 .42407 L F
.53529 .424 m .53599 .42407 L .53608 .42353 L F
.53589 .42468 m .53757 .42411 L .53608 .42353 L F
.53596 .42304 m .53829 .42305 L .53652 .42223 L F
.53789 .42098 m .5448 .41994 L .53817 .41991 L .668 .747 .909 r
F
.53817 .41991 m .5448 .41994 L .54447 .41779 L F
.53829 .42305 m .54462 .42092 L .53811 .42197 L .667 .747 .91 r
F
.53811 .42197 m .54462 .42092 L .54339 .4189 L F
.55113 .41987 m .55104 .41673 L .54921 .41369 L .986 .709 .369 r
F
.54462 .42092 m .5493 .41683 L .54339 .4189 L .667 .747 .91 r
F
.55113 .41987 m .54921 .41369 L .5493 .41683 L .986 .709 .369 r
F
.53757 .42411 m .54144 .42031 L .53656 .42324 L .667 .747 .91 r
F
.53757 .42411 m .54348 .42205 L .54144 .42031 L F
.53817 .41991 m .54447 .41779 L .538 .41884 L .668 .747 .909 r
F
.538 .41884 m .54447 .41779 L .54325 .41578 L F
.54447 .41779 m .54912 .41372 L .54325 .41578 L F
.54325 .41578 m .54912 .41372 L .54609 .41112 L F
.54339 .4189 m .5493 .41683 L .54625 .41421 L .667 .747 .91 r
F
.5493 .41683 m .54921 .41369 L .54616 .41107 L .936 .65 .474 r
F
.54348 .42205 m .54634 .41736 L .54144 .42031 L .667 .747 .91 r
F
.54348 .42205 m .54939 .41998 L .54634 .41736 L F
.5493 .41683 m .54616 .41107 L .54625 .41421 L .936 .65 .474 r
F
.54939 .41998 m .5493 .41683 L .54625 .41421 L F
.54939 .41998 m .54625 .41421 L .54634 .41736 L F
.53456 .42464 m .5617 .41738 L .55663 .41289 L .643 .737 .917 r
F
.53508 .42483 m .53507 .42502 L .53522 .42493 L .911 .629 .497 r
F
.53507 .42502 m .53521 .42512 L .53522 .42493 L F
.53492 .43271 m .53503 .43279 L .53522 .42493 L F
.53505 .42481 m .53505 .425 L .53508 .42483 L F
.53505 .425 m .53507 .42502 L .53508 .42483 L F
.53522 .42493 m .53522 .42493 L .5352 .42492 L .667 .747 .91 r
F
.53522 .42493 m .53757 .42411 L .53521 .42491 L F
.53522 .42493 m .53521 .42491 L .5352 .42492 L F
.53483 .42466 m .53472 .43256 L .53505 .42481 L .911 .629 .497 r
F
.53472 .43256 m .5349 .43269 L .53505 .42481 L F
.55378 .41967 m .5617 .41738 L .55356 .41955 L .643 .737 .917 r
F
.55378 .41967 m .55356 .41955 L .53456 .42464 L F
.53513 .42506 m .55378 .41967 L .53456 .42464 L F
.53507 .42502 m .53492 .43271 L .53521 .42512 L .911 .629 .497 r
F
.53519 .468 m .53522 .46802 L .53523 .47062 L .358 .18 .498 r
F
.53472 .43562 m .53522 .46802 L .53519 .468 L F
.53472 .43562 m .53512 .43534 L .53522 .46802 L F
.53527 .43515 m .5357 .46995 L .53521 .43523 L .08 0 .418 r
F
.53512 .43534 m .5357 .46995 L .53523 .47062 L F
.53521 .43523 m .5357 .46995 L .53512 .43534 L F
.53522 .42513 m .53504 .4328 L .53524 .43295 L .911 .629 .497 r
F
.53521 .42512 m .53503 .43279 L .53522 .42513 L F
.53503 .43279 m .53504 .4328 L .53522 .42513 L F
.54073 .425 m .56473 .42242 L .5371 .42449 L .643 .737 .917 r
F
.53553 .42579 m .53522 .42513 L .53524 .43295 L .983 .725 .332 r
F
.53553 .42579 m .53524 .43295 L .5355 .43348 L F
.5356 .43371 m .53563 .43377 L .53569 .42614 L F
.53569 .42614 m .53563 .43377 L .53572 .43395 L F
.53505 .425 m .5349 .43269 L .53507 .42502 L .911 .629 .497 r
F
.5349 .43269 m .53492 .43271 L .53507 .42502 L F
.5355 .43348 m .53557 .43364 L .53562 .4258 L .983 .725 .332 r
F
.53557 .43364 m .53558 .43366 L .53563 .426 L F
.53557 .43364 m .53563 .426 L .53563 .426 L F
.53662 .42616 m .56551 .42767 L .53577 .42553 L .643 .737 .917 r
F
.53563 .426 m .53558 .43366 L .53566 .42606 L .983 .725 .332 r
F
.53558 .43366 m .5356 .43371 L .53566 .42606 L F
.53562 .42598 m .53557 .43364 L .53563 .426 L F
.53728 .42703 m .56403 .43277 L .53938 .4263 L .643 .737 .917 r
F
.53728 .42703 m .56039 .43738 L .56403 .43277 L F
.53598 .42748 m .56039 .43738 L .53728 .42703 L F
.53598 .42748 m .55486 .44119 L .56039 .43738 L F
.53457 .43245 m .56133 .42545 L .55625 .42098 L .642 .738 .918 r
F
.5317 .43397 m .53525 .43295 L .53457 .43245 L F
.53525 .43295 m .56133 .42545 L .53457 .43245 L F
.53592 .43275 m .56436 .43048 L .56133 .42545 L F
.5317 .43397 m .5376 .43334 L .53592 .43275 L F
.5376 .43334 m .56436 .43048 L .53592 .43275 L F
.53214 .42592 m .5341 .4243 L .53393 .42425 L .643 .737 .917 r
F
.5337 .42417 m .53392 .42424 L .53393 .42408 L .81 .54 .53 r
F
.5338 .41783 m .53294 .41756 L .53295 .42067 L F
.53268 .41609 m .53179 .41745 L .53266 .41753 L .734 .477 .539 r
F
.53179 .41596 m .53176 .41745 L .53179 .41745 L .66 .416 .54 r
F
.53268 .41609 m .53266 .41753 L .53294 .41612 L .734 .477 .539 r
F
.53266 .41753 m .53291 .41756 L .53294 .41612 L F
.5315 .41747 m .53176 .41745 L .53179 .41596 L .66 .416 .54 r
F
.53166 .41746 m .53345 .41588 L .53174 .41573 L .668 .747 .909 r
F
.53154 .41989 m .53275 .41737 L .53166 .41746 L F
.53275 .41737 m .53345 .41588 L .53166 .41746 L F
.53153 .41597 m .5315 .41747 L .53179 .41596 L .66 .416 .54 r
F
.53162 .42302 m .53275 .42065 L .5318 .42055 L .667 .747 .91 r
F
.53162 .42302 m .5318 .42055 L .53173 .42056 L F
.5318 .42055 m .53163 .42368 L .5318 .42367 L .66 .416 .54 r
F
.53171 .42056 m .53162 .42375 L .5318 .42055 L F
.53162 .42302 m .52944 .42525 L .53048 .42539 L .667 .747 .91 r
F
.53162 .42302 m .52886 .42486 L .52953 .42515 L F
.53162 .42302 m .53048 .42539 L .5315 .42554 L F
.53134 .42524 m .53181 .42367 L .53077 .42376 L F
.51284 .42926 m .51216 .42617 L .51405 .42917 L .987 .713 .388 r
F
.5122 .42825 m .51216 .42617 L .51284 .42926 L F
.51216 .42617 m .51399 .42604 L .51405 .42917 L F
.51864 .42512 m .51405 .42917 L .51989 .42713 L .667 .747 .91 r
F
.51216 .42617 m .51211 .42303 L .51399 .42604 L .987 .713 .388 r
F
.51865 .42198 m .51408 .42601 L .51989 .42397 L .668 .747 .909 r
F
.51865 .42198 m .51221 .42302 L .51408 .42601 L F
.51864 .42512 m .51216 .42617 L .51405 .42917 L .667 .747 .91 r
F
.52575 .42508 m .51989 .42713 L .52194 .42885 L F
.5241 .42722 m .51235 .42912 L .52068 .42924 L .643 .737 .917 r
F
.51235 .42912 m .50078 .43099 L .5125 .42996 L F
.51235 .42912 m .5125 .42996 L .52068 .42924 L F
.51209 .42808 m .49878 .42417 L .49976 .4294 L F
.51307 .42797 m .51181 .42764 L .51209 .42808 L F
.51181 .42764 m .49878 .42417 L .51209 .42808 L F
.51181 .42611 m .51216 .42617 L .5122 .42825 L .865 .665 .134 r
F
.5116 .42294 m .51211 .42303 L .51216 .42617 L F
.52512 .42407 m .51989 .42713 L .52575 .42508 L .667 .747 .91 r
F
.52512 .42407 m .51864 .42512 L .51989 .42713 L F
.51181 .42611 m .5116 .42294 L .51216 .42617 L .865 .665 .134 r
F
.51163 .42511 m .5116 .42294 L .51181 .42611 L F
.51827 .42297 m .51216 .42617 L .51864 .42512 L .667 .747 .91 r
F
.5116 .42294 m .51154 .4198 L .51211 .42303 L .865 .665 .134 r
F
.51828 .41983 m .51221 .42302 L .51865 .42198 L .668 .747 .909 r
F
.51828 .41983 m .51164 .4198 L .51221 .42302 L F
.51827 .42297 m .5116 .42294 L .51216 .42617 L .667 .747 .91 r
F
.52344 .4255 m .51169 .42487 L .51307 .42797 L .643 .737 .917 r
F
.51169 .42487 m .51166 .42501 L .51307 .42797 L F
.51159 .42486 m .49878 .42417 L .5121 .42772 L F
.51159 .42486 m .5121 .42772 L .51307 .42797 L F
.52491 .41986 m .51828 .41983 L .51865 .42198 L .668 .747 .909 r
F
.51881 .42081 m .5116 .42294 L .51827 .42297 L .667 .747 .91 r
F
.51221 .42288 m .5116 .42294 L .51163 .42511 L 0 0 .24 r
F
.52601 .42203 m .52593 .42092 L .52524 .42189 L .667 .747 .91 r
F
.52919 .41644 m .52827 .41869 L .529 .4182 L .4 .211 .506 r
F
.52828 .41868 m .52864 .41801 L .52827 .41867 L .668 .747 .909 r
F
.53154 .41989 m .52897 .41822 L .52828 .41868 L F
.52897 .41822 m .52864 .41801 L .52828 .41868 L F
.53162 .42302 m .52828 .42179 L .52827 .42179 L .667 .747 .91 r
F
.52804 .41909 m .52787 .42251 L .52813 .41894 L 0 0 .377 r
F
.53162 .42302 m .52794 .42239 L .5276 .42301 L .667 .747 .91 r
F
.53162 .42302 m .52778 .42364 L .52813 .42424 L F
.52787 .42251 m .52771 .42572 L .52791 .42244 L 0 0 .377 r
F
.52787 .42251 m .52791 .42244 L .52813 .41894 L F
.52771 .42289 m .52771 .42287 L .5277 .4197 L .781 .623 .061 r
F
.52772 .42298 m .52771 .42289 L .5277 .41973 L F
.5277 .4197 m .52771 .42287 L .52771 .42281 L F
.52804 .41909 m .52771 .42281 L .52787 .42251 L 0 0 .377 r
F
.52827 .42179 m .52763 .42155 L .52751 .42229 L .667 .747 .91 r
F
.53154 .41989 m .52837 .42155 L .52861 .42165 L .668 .747 .909 r
F
.529 .4182 m .52827 .42179 L .52863 .42156 L .4 .211 .506 r
F
.52828 .42179 m .52827 .42178 L .52827 .42179 L .667 .747 .91 r
F
.52813 .41894 m .52791 .42244 L .5281 .42209 L 0 0 .377 r
F
.52827 .42178 m .52763 .42155 L .52827 .42179 L .667 .747 .91 r
F
.52795 .42237 m .52827 .42179 L .52751 .42229 L F
.53162 .42302 m .52827 .42179 L .52795 .42237 L F
.52748 .42231 m .52524 .42189 L .52528 .42193 L F
.52772 .42298 m .5277 .41973 L .52771 .41977 L .781 .623 .061 r
F
.52795 .41926 m .5277 .4197 L .52771 .41987 L .668 .747 .909 r
F
.52804 .41909 m .5277 .4197 L .52771 .42281 L 0 0 .377 r
F
.53162 .42302 m .52751 .42229 L .52748 .42231 L .667 .747 .91 r
F
.52751 .42229 m .52524 .42189 L .52748 .42231 L F
.53162 .42302 m .52906 .42392 L .52906 .42396 L F
.52906 .42392 m .52813 .42424 L .52906 .42396 L F
.52906 .42396 m .52813 .42424 L .52816 .42429 L F
.53162 .42302 m .52816 .42429 L .52851 .42458 L F
.52916 .41809 m .52871 .4215 L .52911 .42124 L .4 .211 .506 r
F
.52815 .42201 m .52822 .42189 L .52827 .41699 L 0 0 .377 r
F
.52827 .41699 m .52822 .42189 L .52827 .42179 L F
.52721 .42059 m .52509 .42093 L .52692 .42111 L .668 .747 .909 r
F
.52828 .42179 m .52703 .42006 L .52593 .42092 L .667 .747 .91 r
F
.53154 .41989 m .5297 .42178 L .53042 .42225 L .668 .747 .909 r
F
.5297 .42178 m .52935 .42213 L .53042 .42225 L F
.53042 .42225 m .52935 .42213 L .5304 .42228 L F
.53162 .42302 m .52898 .42132 L .52828 .42179 L .667 .747 .91 r
F
.529 .4182 m .52863 .42156 L .52916 .41809 L .4 .211 .506 r
F
.52863 .42156 m .52871 .4215 L .52916 .41809 L F
.529 .4182 m .52827 .41869 L .52827 .42179 L F
.52775 .4205 m .52721 .42059 L .52776 .42051 L .668 .747 .909 r
F
.52898 .42132 m .52703 .42006 L .52828 .42179 L .667 .747 .91 r
F
.52863 .42156 m .52827 .42477 L .52871 .4215 L .4 .211 .506 r
F
.5288 .4212 m .52844 .4194 L .52703 .42006 L .667 .747 .91 r
F
.52942 .41792 m .52935 .42108 L .52946 .4179 L .4 .211 .506 r
F
.53154 .41989 m .5304 .42228 L .53142 .42243 L .668 .747 .909 r
F
.53162 .42302 m .52946 .421 L .52898 .42132 L .667 .747 .91 r
F
.5281 .42209 m .52771 .42572 L .52808 .4251 L 0 0 .377 r
F
.53181 .4259 m .52773 .42569 L .53184 .42595 L .643 .737 .917 r
F
.52773 .42569 m .52679 .42564 L .52772 .4257 L F
.52773 .42569 m .52772 .4257 L .53184 .42595 L F
.52679 .42564 m .52356 .42547 L .52676 .42566 L F
.52791 .42244 m .52771 .42572 L .5281 .42209 L 0 0 .377 r
F
.52771 .42289 m .52772 .42584 L .52771 .42287 L .781 .623 .061 r
F
.52772 .42305 m .52773 .42599 L .52772 .42298 L F
.52771 .42281 m .52772 .42584 L .52771 .42572 L F
.52771 .42287 m .52772 .42584 L .52771 .42281 L F
.52773 .42599 m .52772 .42584 L .52771 .42289 L F
.52773 .42599 m .52771 .42289 L .52772 .42298 L F
.52787 .42251 m .52771 .42281 L .52771 .42572 L 0 0 .377 r
F
.52679 .42564 m .52676 .42566 L .53184 .42595 L .643 .737 .917 r
F
.52935 .42108 m .52928 .42417 L .52939 .42105 L .4 .211 .506 r
F
.52356 .42547 m .52344 .4255 L .52673 .42568 L .643 .737 .917 r
F
.52676 .42566 m .52673 .42568 L .53184 .42595 L F
.52356 .42547 m .52673 .42568 L .52676 .42566 L F
.52919 .41644 m .52916 .41809 L .52946 .41629 L .4 .211 .506 r
F
.52916 .41809 m .52911 .42124 L .52934 .41798 L F
.52916 .41809 m .52934 .41798 L .52946 .41629 L F
.52911 .42124 m .52921 .42117 L .52946 .41629 L F
.52906 .42431 m .52928 .42417 L .52935 .42108 L F
.52921 .42117 m .52935 .42108 L .52946 .41629 L F
.52906 .42431 m .52935 .42108 L .52921 .42117 L F
.52935 .42108 m .52939 .42105 L .52946 .4179 L F
.53154 .41989 m .53065 .41755 L .52968 .41775 L .668 .747 .909 r
F
.53037 .41607 m .53034 .41764 L .53063 .416 L .567 .342 .533 r
F
.53065 .41755 m .53052 .4172 L .52989 .41762 L .668 .747 .909 r
F
.53037 .41607 m .52946 .4179 L .53034 .41764 L .567 .342 .533 r
F
.53065 .41755 m .52989 .41762 L .52968 .41775 L .668 .747 .909 r
F
.53153 .41597 m .53063 .416 L .53063 .41755 L .66 .416 .54 r
F
.53162 .42302 m .53071 .42065 L .52977 .42091 L .667 .747 .91 r
F
.53153 .41597 m .53063 .41755 L .5315 .41747 L .66 .416 .54 r
F
.53037 .41607 m .52946 .41629 L .52946 .4179 L .567 .342 .533 r
F
.53034 .41764 m .5306 .41756 L .53063 .416 L F
.53063 .416 m .5306 .41756 L .53063 .41755 L F
.53154 .41989 m .53174 .41573 L .53001 .41587 L .668 .747 .909 r
F
.5315 .41747 m .53064 .42066 L .53145 .42059 L .66 .416 .54 r
F
.53071 .42065 m .5307 .42064 L .53064 .42066 L .667 .747 .91 r
F
.53071 .42065 m .53064 .42066 L .52977 .42091 L F
.5315 .41747 m .53063 .41755 L .53064 .42066 L .66 .416 .54 r
F
.53162 .42302 m .52977 .42091 L .52946 .421 L .667 .747 .91 r
F
.53184 .42595 m .52344 .4255 L .51307 .42797 L .643 .737 .917 r
F
.49946 .41618 m .4685 .42485 L .50044 .42139 L .644 .737 .916 r
F
.50758 .42463 m .50007 .41903 L .49878 .42417 L .643 .737 .917 r
F
.52808 .4251 m .52819 .42492 L .52822 .42189 L 0 0 .377 r
F
.52808 .4251 m .52822 .42189 L .52815 .42201 L F
.5281 .42209 m .52808 .4251 L .52815 .42201 L F
.52719 .42374 m .52512 .42407 L .52661 .42477 L .667 .747 .91 r
F
.52661 .42477 m .52575 .42508 L .52647 .42503 L F
.53181 .4259 m .52664 .42474 L .52356 .42547 L .643 .737 .917 r
F
.53339 .4208 m .53295 .42067 L .53296 .42378 L .81 .54 .53 r
F
.53339 .4208 m .53296 .42378 L .53298 .42378 L F
.53162 .42302 m .5315 .42556 L .53253 .42542 L .667 .747 .91 r
F
.53181 .42591 m .53377 .42403 L .53285 .42374 L F
.53169 .42616 m .53186 .42599 L .53181 .42591 L F
.53186 .42599 m .53377 .42403 L .53181 .42591 L F
.52911 .42124 m .52827 .42477 L .52906 .42431 L .4 .211 .506 r
F
.52871 .4215 m .52827 .42477 L .52911 .42124 L F
.52863 .42156 m .52827 .42179 L .52827 .42477 L F
.53162 .42302 m .52873 .42476 L .52886 .42486 L .667 .747 .91 r
F
.53162 .42302 m .52837 .42465 L .52869 .42479 L F
.53154 .41989 m .53142 .42243 L .53156 .42244 L .668 .747 .909 r
F
.53063 .41755 m .53056 .42068 L .53064 .42066 L .567 .342 .533 r
F
.53034 .41764 m .52946 .421 L .5299 .42087 L F
.53042 .42072 m .53053 .42069 L .5306 .41756 L F
.53034 .41764 m .53029 .42076 L .5306 .41756 L F
.53029 .42076 m .53042 .42072 L .5306 .41756 L F
.53034 .41764 m .52947 .42407 L .53024 .42388 L F
.5315 .41747 m .53145 .42059 L .53176 .41745 L .66 .416 .54 r
F
.53145 .42059 m .53169 .42056 L .53176 .41745 L F
.53176 .41745 m .53169 .42056 L .53179 .41745 L F
.53162 .42302 m .53173 .42056 L .53071 .42065 L .667 .747 .91 r
F
.53169 .42056 m .53162 .42375 L .53171 .42056 L .66 .416 .54 r
F
.53169 .42056 m .53171 .42056 L .53179 .41745 L F
.53071 .42065 m .53174 .42033 L .5307 .42064 L .667 .747 .91 r
F
.53173 .42056 m .53174 .42033 L .53071 .42065 L F
.5299 .42087 m .52946 .421 L .52947 .42407 L .567 .342 .533 r
F
.52946 .421 m .52932 .42415 L .52947 .42407 L .4 .211 .506 r
F
.53035 .42386 m .53014 .42213 L .52927 .42235 L .667 .747 .91 r
F
.53134 .42524 m .53076 .42373 L .53035 .42386 L F
.5306 .41756 m .53046 .42382 L .53063 .41755 L .567 .342 .533 r
F
.53046 .42383 m .53049 .42382 L .53063 .41755 L F
.53024 .42388 m .53035 .42386 L .53053 .42069 L F
.53035 .42386 m .53046 .42383 L .53046 .42382 L F
.53035 .42386 m .53046 .42382 L .53053 .42069 L F
.52911 .42124 m .52906 .42431 L .52921 .42117 L .4 .211 .506 r
F
.52928 .42417 m .52932 .42415 L .52939 .42105 L F
.52939 .42105 m .52932 .42415 L .52946 .421 L F
.53371 .42401 m .53296 .42391 L .5337 .42417 L .81 .54 .53 r
F
.5338 .41783 m .53298 .42378 L .53371 .42401 L F
.53298 .42378 m .53296 .42391 L .53371 .42401 L F
.53224 .4206 m .5318 .42055 L .53181 .42374 L .734 .477 .539 r
F
.53261 .42063 m .53256 .42385 L .53285 .42066 L F
.53171 .42577 m .53278 .42372 L .53182 .42342 L .667 .747 .91 r
F
.53256 .42385 m .53278 .42388 L .53278 .42376 L .734 .477 .539 r
F
.53257 .42374 m .53278 .42376 L .53285 .42066 L F
.53256 .42385 m .53278 .42376 L .53257 .42374 L F
.53181 .42591 m .53283 .42377 L .53171 .42577 L .667 .747 .91 r
F
.53295 .42067 m .53278 .42376 L .53296 .42378 L .734 .477 .539 r
F
.53294 .41756 m .53286 .42066 L .53295 .42067 L F
.53286 .42066 m .53278 .42376 L .53295 .42067 L F
.5338 .41783 m .53295 .42067 L .53339 .4208 L .81 .54 .53 r
F
.53261 .42063 m .53285 .42066 L .53291 .41756 L .734 .477 .539 r
F
.53291 .41756 m .53278 .42376 L .53294 .41756 L F
.53492 .41852 m .53408 .41792 L .53409 .42102 L .911 .629 .497 r
F
.53492 .41852 m .53488 .42158 L .53517 .41869 L F
.53295 .42067 m .53513 .41943 L .53277 .42061 L .667 .747 .91 r
F
.53369 .4209 m .53383 .42075 L .53295 .42067 L F
.53383 .42075 m .53513 .41943 L .53295 .42067 L F
.53283 .42377 m .53361 .42215 L .53276 .42376 L F
.53283 .42377 m .53276 .42376 L .53171 .42577 L F
.53266 .41753 m .53181 .42374 L .53256 .42385 L .734 .477 .539 r
F
.53182 .42342 m .53361 .42215 L .53188 .422 L .667 .747 .91 r
F
.53278 .42372 m .53361 .42215 L .53182 .42342 L F
.53024 .42388 m .53053 .42069 L .53042 .42072 L .567 .342 .533 r
F
.52751 .42229 m .52763 .42155 L .52601 .42203 L .667 .747 .91 r
F
.52763 .42155 m .52593 .42092 L .52601 .42203 L F
.53029 .42076 m .53024 .42388 L .53042 .42072 L .567 .342 .533 r
F
.53171 .42577 m .53181 .42367 L .53134 .42524 L .667 .747 .91 r
F
.52794 .42239 m .52748 .42231 L .5276 .42301 L F
.52748 .42231 m .52694 .42222 L .52713 .42254 L F
.52748 .42231 m .52713 .42254 L .5274 .42301 L F
.52694 .42222 m .52522 .42192 L .5274 .42301 L F
.52827 .42179 m .52819 .42492 L .52827 .42477 L 0 0 .377 r
F
.52822 .42189 m .52819 .42492 L .52827 .42179 L F
.52443 .41749 m .50782 .41258 L .49946 .41618 L .644 .737 .916 r
F
.52735 .41679 m .50782 .41258 L .52443 .41749 L F
.52767 .41922 m .52518 .41879 L .52771 .41987 L .668 .747 .909 r
F
.52509 .42093 m .51865 .42198 L .51989 .42397 L F
.52491 .41986 m .51865 .42198 L .52509 .42093 L F
.52518 .41879 m .51828 .41983 L .52491 .41986 L F
.52518 .41879 m .51882 .41769 L .51828 .41983 L F
.52589 .41779 m .51882 .41769 L .52518 .41879 L F
.52589 .41779 m .52022 .41569 L .51882 .41769 L F
.52698 .41693 m .52022 .41569 L .52589 .41779 L F
.52022 .41569 m .51244 .41658 L .51882 .41769 L F
.52593 .42092 m .51881 .42081 L .52522 .42192 L .667 .747 .91 r
F
.52698 .41693 m .52241 .41397 L .52022 .41569 L .668 .747 .909 r
F
.52022 .41569 m .51454 .41358 L .51244 .41658 L F
.51451 .41669 m .51446 .41355 L .51234 .41657 L .104 0 .436 r
F
.52593 .42092 m .52023 .41881 L .51881 .42081 L .667 .747 .91 r
F
.52703 .42006 m .52023 .41881 L .52593 .42092 L F
.52241 .41397 m .51454 .41358 L .52022 .41569 L .668 .747 .909 r
F
.52703 .42006 m .52243 .41708 L .52023 .41881 L .667 .747 .91 r
F
.52764 .41844 m .52762 .41845 L .52767 .41922 L .668 .747 .909 r
F
.52762 .41843 m .52589 .41779 L .52767 .41922 L F
.52795 .41926 m .52767 .41922 L .5277 .4197 L F
.52844 .4194 m .52243 .41708 L .52703 .42006 L .667 .747 .91 r
F
.52814 .4172 m .52804 .41909 L .52813 .41894 L 0 0 .377 r
F
.52827 .41867 m .52698 .41693 L .52589 .41779 L .668 .747 .909 r
F
.52839 .41628 m .52241 .41397 L .52698 .41693 L F
.52844 .4194 m .52526 .41576 L .52243 .41708 L .667 .747 .91 r
F
.52241 .41397 m .51782 .411 L .51454 .41358 L .668 .747 .909 r
F
.52522 .41265 m .51782 .411 L .52241 .41397 L F
.51882 .41769 m .51164 .4198 L .51828 .41983 L F
.51882 .41769 m .51244 .41658 L .51164 .4198 L F
.52243 .41708 m .51451 .41669 L .52023 .41881 L .667 .747 .91 r
F
.51781 .41409 m .51446 .41355 L .51451 .41669 L .35 .18 .504 r
F
.51781 .41409 m .51775 .41095 L .51446 .41355 L F
.52522 .41265 m .52204 .40902 L .51782 .411 L .668 .747 .909 r
F
.52243 .41708 m .51781 .41409 L .51451 .41669 L .667 .747 .91 r
F
.52526 .41576 m .51781 .41409 L .52243 .41708 L F
.51743 .41717 m .51781 .41409 L .51451 .41669 L .35 .18 .504 r
F
.51786 .41687 m .51781 .41409 L .51743 .41717 L F
.52528 .42193 m .52524 .42189 L .52522 .42192 L .667 .747 .91 r
F
.52778 .42364 m .5275 .42317 L .52719 .42374 L F
.5276 .42301 m .52494 .423 L .52719 .42374 L F
.50782 .41258 m .50074 .41105 L .50062 .41156 L .644 .737 .916 r
F
.50782 .41258 m .50062 .41156 L .49946 .41618 L F
.52494 .423 m .51864 .42512 L .52512 .42407 L .667 .747 .91 r
F
.52494 .423 m .51827 .42297 L .51864 .42512 L F
.5124 .41971 m .51234 .41657 L .51154 .4198 L 0 0 .24 r
F
.52522 .42192 m .51827 .42297 L .52494 .423 L .667 .747 .91 r
F
.52522 .42192 m .51881 .42081 L .51827 .42297 L F
.51451 .41669 m .51234 .41657 L .5124 .41971 L .104 0 .436 r
F
.52023 .41881 m .5124 .41971 L .51881 .42081 L .667 .747 .91 r
F
.52023 .41881 m .51451 .41669 L .5124 .41971 L F
.51411 .41981 m .51451 .41669 L .5124 .41971 L .104 0 .436 r
F
.51456 .41922 m .51451 .41669 L .51411 .41981 L F
.53214 .42592 m .51837 .41667 L .51494 .41894 L .643 .737 .917 r
F
.52197 .41522 m .51781 .41409 L .51786 .41687 L .493 .288 .531 r
F
.51837 .41667 m .51825 .41659 L .51786 .41687 L .643 .737 .917 r
F
.51837 .41667 m .51786 .41687 L .51494 .41894 L F
.52839 .41628 m .52522 .41265 L .52241 .41397 L .668 .747 .909 r
F
.52526 .41576 m .52206 .41211 L .51781 .41409 L .667 .747 .91 r
F
.52197 .41522 m .52206 .41211 L .51781 .41409 L .493 .288 .531 r
F
.51837 .41667 m .52176 .4141 L .51825 .41659 L .643 .737 .917 r
F
.53001 .41587 m .52522 .41265 L .52839 .41628 L .668 .747 .909 r
F
.52853 .41494 m .52206 .41211 L .52526 .41576 L .667 .747 .91 r
F
.53001 .41587 m .52847 .41183 L .52522 .41265 L .668 .747 .909 r
F
.52847 .41183 m .52204 .40902 L .52522 .41265 L F
.52847 .41183 m .52693 .40778 L .52204 .40902 L F
.52853 .41494 m .52697 .41086 L .52206 .41211 L .667 .747 .91 r
F
.52704 .41402 m .52206 .41211 L .52212 .41516 L .589 .363 .541 r
F
.53152 .4255 m .52259 .41506 L .51837 .41667 L .643 .737 .917 r
F
.52704 .41402 m .52212 .41516 L .5239 .41481 L .589 .363 .541 r
F
.52212 .41516 m .52206 .41211 L .52197 .41522 L .493 .288 .531 r
F
.52206 .41211 m .51775 .41095 L .51781 .41409 L F
.52206 .41211 m .52199 .40896 L .51775 .41095 L F
.53034 .42385 m .51613 .40752 L .53152 .4255 L .643 .737 .917 r
F
.53014 .42213 m .52818 .42082 L .52927 .42235 L .667 .747 .91 r
F
.53076 .42373 m .53014 .42213 L .53035 .42386 L F
.53064 .42377 m .53049 .42382 L .53064 .42379 L .567 .342 .533 r
F
.53064 .42066 m .53049 .42381 L .53064 .42377 L F
.53049 .42381 m .53049 .42382 L .53064 .42377 L F
.53056 .42068 m .53049 .42382 L .53064 .42066 L F
.53145 .42059 m .5314 .42376 L .53169 .42056 L .66 .416 .54 r
F
.5314 .42376 m .53162 .42375 L .53169 .42056 L F
.53145 .42059 m .53064 .42066 L .53064 .42379 L F
.53145 .42059 m .53064 .42379 L .5314 .42376 L F
.53076 .42373 m .53188 .422 L .53014 .42213 L .667 .747 .91 r
F
.53077 .42376 m .53079 .42373 L .53076 .42373 L F
.53079 .42373 m .53188 .422 L .53076 .42373 L F
.53034 .41764 m .52946 .4179 L .52946 .421 L .567 .342 .533 r
F
.52977 .42091 m .53057 .42028 L .52971 .42084 L .667 .747 .91 r
F
.5307 .42064 m .53057 .42028 L .52977 .42091 L F
.52946 .4179 m .52939 .42105 L .52946 .421 L .4 .211 .506 r
F
.52971 .42084 m .53007 .41899 L .52844 .4194 L .667 .747 .91 r
F
.53057 .42028 m .53007 .41899 L .52971 .42084 L F
.52946 .421 m .52844 .4194 L .5288 .4212 L F
.52977 .42091 m .52971 .42084 L .52946 .421 L F
.52971 .42084 m .52844 .4194 L .52946 .421 L F
.52898 .42132 m .52946 .421 L .5288 .4212 L F
.52919 .41644 m .529 .4182 L .52916 .41809 L .4 .211 .506 r
F
.53181 .42367 m .53188 .422 L .53077 .42376 L .667 .747 .91 r
F
.52968 .41775 m .52913 .41713 L .529 .41804 L .668 .747 .909 r
F
.52946 .4179 m .529 .41804 L .52897 .41822 L F
.52968 .41775 m .529 .41804 L .52946 .4179 L F
.52919 .41644 m .52827 .41699 L .52827 .41869 L .4 .211 .506 r
F
.52897 .41822 m .52913 .41713 L .52864 .41801 L .668 .747 .909 r
F
.52864 .41801 m .52839 .41628 L .52698 .41693 L F
.52913 .41713 m .52839 .41628 L .52864 .41801 L F
.52864 .41801 m .52698 .41693 L .52827 .41867 L F
.52828 .41868 m .52827 .41867 L .52827 .41869 L F
.52827 .41867 m .52764 .41844 L .52795 .41926 L F
.52764 .41844 m .52762 .41843 L .52762 .41845 L F
.53007 .41899 m .52526 .41576 L .52844 .4194 L .667 .747 .91 r
F
.52946 .41629 m .52942 .41792 L .52946 .4179 L .4 .211 .506 r
F
.52968 .41775 m .53001 .41587 L .52839 .41628 L .668 .747 .909 r
F
.52974 .41782 m .52968 .41775 L .52946 .4179 L F
.53007 .41899 m .52853 .41494 L .52526 .41576 L .667 .747 .91 r
F
.53014 .42213 m .52859 .41808 L .52659 .41859 L F
.53014 .42213 m .52659 .41859 L .52818 .42082 L F
.53188 .422 m .52859 .41808 L .53014 .42213 L F
.5307 .42064 m .53181 .41885 L .53007 .41899 L F
.53179 .41745 m .53171 .42056 L .5318 .42055 L .66 .416 .54 r
F
.53174 .42033 m .53181 .41885 L .5307 .42064 L .667 .747 .91 r
F
.53173 .42055 m .53182 .42055 L .53174 .42029 L F
.53182 .42055 m .53277 .42061 L .53242 .4205 L F
.53266 .41753 m .5318 .42055 L .53224 .4206 L .734 .477 .539 r
F
.53182 .42055 m .53242 .4205 L .53174 .42029 L .667 .747 .91 r
F
.53173 .42056 m .5318 .42055 L .53173 .42055 L F
.53266 .41753 m .53179 .41745 L .5318 .42055 L .734 .477 .539 r
F
.53275 .42065 m .53277 .42061 L .53173 .42055 L .667 .747 .91 r
F
.53266 .41753 m .53261 .42063 L .53291 .41756 L .734 .477 .539 r
F
.53174 .42029 m .53354 .419 L .53181 .41885 L .667 .747 .91 r
F
.53277 .42061 m .53354 .419 L .53174 .42029 L F
.53266 .41753 m .53412 .41725 L .53275 .41737 L .668 .747 .909 r
F
.53374 .41764 m .53412 .41725 L .53266 .41753 L F
.53412 .41725 m .53503 .41631 L .53275 .41737 L F
.53345 .41588 m .53193 .41156 L .53174 .41573 L F
.53354 .419 m .53201 .41466 L .53181 .41885 L .667 .747 .91 r
F
.53052 .4172 m .53001 .41587 L .52968 .41775 L .668 .747 .909 r
F
.53181 .41885 m .52853 .41494 L .53007 .41899 L .667 .747 .91 r
F
.53174 .41573 m .52847 .41183 L .53001 .41587 L .668 .747 .909 r
F
.53174 .41573 m .53193 .41156 L .52847 .41183 L F
.53181 .41885 m .53201 .41466 L .52853 .41494 L .667 .747 .91 r
F
.53188 .422 m .53208 .41781 L .52859 .41808 L F
.53034 .42385 m .51839 .40707 L .51613 .40752 L .643 .737 .917 r
F
.52859 .41808 m .52212 .41526 L .52532 .41891 L .667 .747 .91 r
F
.52697 .41086 m .52199 .40896 L .52206 .41211 L .589 .363 .541 r
F
.52697 .41086 m .5269 .40772 L .52199 .40896 L F
.52859 .41808 m .52704 .41402 L .52212 .41526 L .667 .747 .91 r
F
.53208 .41781 m .52704 .41402 L .52859 .41808 L F
.53361 .41777 m .53506 .41777 L .53374 .41764 L .668 .747 .909 r
F
.53456 .41807 m .53506 .41777 L .53361 .41777 L F
.53374 .41764 m .53638 .41697 L .53503 .41631 L F
.53506 .41777 m .53638 .41697 L .53374 .41764 L F
.53503 .41631 m .53537 .41186 L .53345 .41588 L F
.53503 .41631 m .53854 .41271 L .53537 .41186 L F
.53345 .41588 m .53537 .41186 L .53193 .41156 L F
.53354 .419 m .53546 .41496 L .53201 .41466 L .667 .747 .91 r
F
.53537 .41186 m .53213 .40737 L .53193 .41156 L .668 .747 .909 r
F
.53546 .41496 m .53221 .41045 L .53201 .41466 L .667 .747 .91 r
F
.53201 .41466 m .52697 .41086 L .52853 .41494 L F
.53193 .41156 m .52693 .40778 L .52847 .41183 L .668 .747 .909 r
F
.53193 .41156 m .53213 .40737 L .52693 .40778 L F
.53201 .41466 m .53221 .41045 L .52697 .41086 L .667 .747 .91 r
F
.53208 .41781 m .53228 .41361 L .52704 .41402 L F
.52704 .41402 m .52697 .41086 L .52206 .41211 L .589 .363 .541 r
F
.53228 .41361 m .52697 .41086 L .52704 .41402 L .665 .423 .544 r
F
.53214 .42592 m .52435 .4059 L .51839 .40707 L .643 .737 .917 r
F
.53214 .42592 m .51839 .40707 L .53034 .42385 L F
.52818 .42082 m .52659 .41859 L .52532 .41891 L .667 .747 .91 r
F
.5239 .41481 m .52212 .41516 L .52212 .41526 L .589 .363 .541 r
F
.52259 .41506 m .52253 .41499 L .52212 .41516 L .643 .737 .917 r
F
.52259 .41506 m .52212 .41516 L .51837 .41667 L F
.52253 .41499 m .52176 .4141 L .51837 .41667 L F
.52212 .41526 m .52212 .41516 L .52197 .41522 L .493 .288 .531 r
F
.52212 .41526 m .52197 .41522 L .51787 .41724 L F
.52197 .41522 m .51786 .41687 L .51787 .41724 L F
.5124 .41971 m .51154 .4198 L .5116 .42294 L 0 0 .24 r
F
.51881 .42081 m .5124 .41971 L .5116 .42294 L .667 .747 .91 r
F
.51221 .42288 m .5124 .41971 L .5116 .42294 L 0 0 .24 r
F
.51243 .42203 m .5124 .41971 L .51221 .42288 L F
.52344 .42405 m .51429 .41957 L .51265 .42173 L .643 .737 .917 r
F
.51411 .41981 m .5124 .41971 L .51243 .42203 L .104 0 .436 r
F
.52344 .42405 m .50007 .41903 L .50758 .42463 L .643 .737 .917 r
F
.51457 .41984 m .51411 .41981 L .51245 .42285 L .104 0 .436 r
F
.51411 .41981 m .51243 .42203 L .51245 .42285 L F
.51265 .42173 m .51321 .41905 L .51252 .4217 L .643 .737 .917 r
F
.51429 .41957 m .51321 .41905 L .51265 .42173 L F
.51252 .4217 m .50356 .41433 L .50007 .41903 L F
.51321 .41905 m .50356 .41433 L .51252 .4217 L F
.51245 .42285 m .51243 .42203 L .51221 .42288 L 0 0 .24 r
F
.51743 .41717 m .51451 .41669 L .51456 .41922 L .35 .18 .504 r
F
.52705 .42392 m .50356 .41433 L .52344 .42405 L .643 .737 .917 r
F
.53169 .42574 m .50356 .41433 L .53176 .42584 L F
.51787 .41724 m .51743 .41717 L .51457 .41984 L .35 .18 .504 r
F
.51743 .41717 m .51456 .41922 L .51457 .41984 L F
.51494 .41894 m .51712 .41582 L .5148 .41889 L .643 .737 .917 r
F
.51825 .41659 m .51712 .41582 L .51494 .41894 L F
.5148 .41889 m .50904 .4104 L .50356 .41433 L F
.51712 .41582 m .50904 .4104 L .5148 .41889 L F
.51457 .41984 m .51456 .41922 L .51411 .41981 L .104 0 .436 r
F
.51787 .41724 m .51786 .41687 L .51743 .41717 L .35 .18 .504 r
F
.51825 .41659 m .51613 .40752 L .50904 .4104 L .643 .737 .917 r
F
.52176 .4141 m .51613 .40752 L .51825 .41659 L F
.53214 .42592 m .53034 .42385 L .53152 .4255 L F
.52927 .42235 m .52532 .41891 L .52851 .42254 L .667 .747 .91 r
F
.52818 .42082 m .52532 .41891 L .52927 .42235 L F
.52999 .42396 m .52927 .42235 L .52851 .42254 L F
.53134 .42524 m .53035 .42386 L .52999 .42396 L F
.53035 .42386 m .52927 .42235 L .52999 .42396 L F
.53176 .42584 m .52817 .42437 L .52664 .42474 L .643 .737 .917 r
F
.53176 .42584 m .52664 .42474 L .53181 .4259 L F
.53169 .42616 m .53134 .42524 L .52999 .42396 L .667 .747 .91 r
F
.5298 .42402 m .52999 .42396 L .52851 .42254 L F
.53169 .42616 m .52999 .42396 L .5298 .42402 L F
.53028 .43675 m .52822 .44082 L .53117 .43749 L .642 .738 .918 r
F
.52822 .44082 m .52832 .4423 L .53117 .43749 L F
.53117 .43749 m .52832 .4423 L .53152 .43778 L F
.52832 .4423 m .52836 .44282 L .53152 .43778 L F
.52819 .42974 m .52787 .43414 L .52977 .43016 L .667 .747 .91 r
F
.52945 .42845 m .52683 .42908 L .52819 .42974 L F
.52922 .42792 m .52991 .42842 L .52922 .42812 L .845 .571 .524 r
F
.52899 .42782 m .52899 .42803 L .52893 .42779 L F
.52886 .42797 m .52683 .42908 L .52945 .42845 L .667 .747 .91 r
F
.52879 .42791 m .52876 .42792 L .52886 .42797 L F
.52876 .42792 m .52683 .42908 L .52886 .42797 L F
.52917 .43571 m .52911 .43568 L .52893 .428 L .845 .571 .524 r
F
.52893 .428 m .52893 .428 L .52893 .42779 L F
.52917 .43571 m .52893 .428 L .52893 .428 L F
.52899 .42803 m .52917 .43571 L .52893 .428 L F
.52899 .42803 m .52893 .428 L .52893 .42779 L F
.52961 .42829 m .52886 .42797 L .52945 .42845 L .667 .747 .91 r
F
.52768 .42721 m .50294 .43436 L .52877 .42772 L .643 .737 .917 r
F
.52819 .42974 m .5247 .43331 L .52787 .43414 L .667 .747 .91 r
F
.52683 .42908 m .5247 .43331 L .52819 .42974 L F
.52855 .42805 m .52581 .42822 L .52683 .42908 L F
.5284 .42737 m .52886 .42776 L .52886 .42797 L .929 .648 .487 r
F
.5284 .42737 m .52886 .42797 L .52841 .4276 L F
.5284 .42737 m .5284 .42759 L .52827 .42726 L F
.52816 .4274 m .52816 .4274 L .52879 .42791 L .667 .747 .91 r
F
.52816 .4274 m .52581 .42822 L .52855 .42805 L F
.5284 .42759 m .52849 .43526 L .52827 .42749 L .929 .648 .487 r
F
.5284 .42759 m .52827 .42749 L .52827 .42726 L F
.52879 .42791 m .52816 .4274 L .52855 .42805 L .667 .747 .91 r
F
.52849 .43526 m .52838 .43517 L .52827 .42749 L .929 .648 .487 r
F
.52827 .42749 m .52827 .42749 L .52827 .42726 L F
.52849 .43526 m .52827 .42749 L .52827 .42749 L F
.52637 .42759 m .5241 .42722 L .52068 .42924 L .643 .737 .917 r
F
.52816 .4274 m .52519 .42721 L .52581 .42822 L .667 .747 .91 r
F
.5279 .42673 m .52816 .42717 L .52816 .4274 L .988 .719 .384 r
F
.5279 .42673 m .52816 .4274 L .5279 .42696 L F
.52748 .42684 m .52519 .42721 L .5278 .42737 L .667 .747 .91 r
F
.52779 .42709 m .5278 .42737 L .52816 .4274 L F
.52748 .42684 m .5278 .42737 L .52779 .42709 L F
.52773 .42599 m .52776 .4265 L .52776 .42672 L .781 .623 .061 r
F
.5278 .42679 m .52748 .42684 L .52816 .4274 L .667 .747 .91 r
F
.52248 .43635 m .52596 .4374 L .52597 .43811 L .794 .529 .538 r
F
.5247 .43331 m .52597 .43811 L .52787 .43414 L .667 .747 .91 r
F
.52773 .42599 m .52776 .42672 L .52773 .42621 L .781 .623 .061 r
F
.52677 .42679 m .52277 .42693 L .52424 .4272 L .643 .737 .917 r
F
.52627 .42655 m .52277 .42693 L .52677 .42679 L F
.52777 .4268 m .52501 .42614 L .52519 .42721 L .667 .747 .91 r
F
.52776 .42672 m .52501 .42614 L .52777 .4268 L F
.52772 .42615 m .52742 .42615 L .52776 .42672 L F
.52742 .42615 m .52501 .42614 L .52776 .42672 L F
.52772 .42584 m .52772 .42605 L .52771 .42572 L .781 .623 .061 r
F
.52772 .42605 m .52771 .42593 L .52771 .42572 L F
.52808 .4251 m .52771 .42572 L .52771 .42592 L 0 0 .377 r
F
.52773 .42599 m .52773 .4262 L .52772 .42584 L .781 .623 .061 r
F
.52773 .4262 m .52772 .42605 L .52772 .42584 L F
.53169 .42616 m .52768 .42547 L .52772 .42615 L .667 .747 .91 r
F
.52768 .42547 m .52528 .42506 L .52772 .42615 L F
.52773 .4262 m .52774 .4339 L .52772 .42605 L .781 .623 .061 r
F
.52822 .44082 m .5214 .44414 L .52222 .45259 L .642 .738 .918 r
F
.52809 .43902 m .5214 .44414 L .52822 .44082 L F
.52949 .4372 m .5214 .44414 L .52979 .43771 L F
.52904 .43645 m .52213 .44292 L .52946 .43715 L F
.52213 .44292 m .5214 .44414 L .52949 .4372 L F
.52946 .43715 m .52949 .4372 L .5305 .43633 L F
.52213 .44292 m .52949 .4372 L .52946 .43715 L F
.52776 .42672 m .52784 .43444 L .52776 .42672 L .988 .719 .384 r
F
.52822 .44082 m .52222 .45259 L .52832 .4423 L .642 .738 .918 r
F
.52902 .42783 m .52919 .43572 L .52899 .42782 L .845 .571 .524 r
F
.52213 .44292 m .50757 .44674 L .51432 .45022 L .642 .738 .918 r
F
.52122 .43686 m .52248 .43635 L .52597 .43811 L .794 .529 .538 r
F
.52795 .43462 m .52789 .43452 L .52782 .4266 L .988 .719 .384 r
F
.52776 .4265 m .52776 .42672 L .52776 .42672 L F
.5278 .42679 m .52776 .42672 L .52777 .4268 L .667 .747 .91 r
F
.52122 .43686 m .52121 .43597 L .52248 .43635 L .794 .529 .538 r
F
.5247 .43331 m .52122 .43686 L .52597 .43811 L .667 .747 .91 r
F
.52904 .43645 m .52493 .43822 L .52213 .44292 L .642 .738 .918 r
F
.52893 .43626 m .52493 .43822 L .52904 .43645 L F
.52782 .4266 m .52789 .43452 L .52776 .4265 L .988 .719 .384 r
F
.52855 .43563 m .5255 .43725 L .52893 .43626 L .642 .738 .918 r
F
.5255 .43725 m .50757 .44674 L .52493 .43822 L F
.5255 .43725 m .52493 .43822 L .52893 .43626 L F
.53169 .42616 m .52772 .42615 L .52776 .42672 L .667 .747 .91 r
F
.5279 .42673 m .5279 .42695 L .52782 .4266 L .988 .719 .384 r
F
.53169 .42616 m .52776 .42672 L .5278 .42679 L .667 .747 .91 r
F
.5279 .42695 m .52783 .42683 L .52782 .4266 L .988 .719 .384 r
F
.5279 .42673 m .5279 .42696 L .5279 .42695 L F
.52979 .43771 m .52809 .43902 L .52822 .44082 L .642 .738 .918 r
F
.52879 .43551 m .51887 .43809 L .50757 .44674 L F
.51887 .43809 m .50243 .44238 L .50616 .44554 L F
.51887 .43809 m .50616 .44554 L .50757 .44674 L F
.52816 .43498 m .50243 .44238 L .52879 .43551 L F
.52827 .42726 m .52838 .43517 L .52816 .42717 L .929 .648 .487 r
F
.52838 .43517 m .52891 .47109 L .52829 .43509 L F
.52838 .43517 m .52829 .43509 L .52816 .42717 L F
.51898 .43024 m .50663 .4375 L .50807 .43873 L .643 .737 .917 r
F
.51718 .43488 m .51842 .43452 L .52122 .43686 L .86 .586 .521 r
F
.51842 .43452 m .52121 .43597 L .52122 .43686 L F
.522 .43199 m .52122 .43686 L .5247 .43331 L .667 .747 .91 r
F
.51718 .43488 m .51716 .43387 L .51842 .43452 L .86 .586 .521 r
F
.522 .43199 m .51718 .43488 L .52122 .43686 L .667 .747 .91 r
F
.52816 .43498 m .49925 .43743 L .50243 .44238 L .642 .738 .918 r
F
.52816 .42717 m .52829 .43509 L .52817 .43499 L .929 .648 .487 r
F
.52789 .43452 m .52784 .43444 L .52776 .4265 L .988 .719 .384 r
F
.5279 .42695 m .52795 .43462 L .52783 .42683 L F
.52919 .43572 m .52917 .43571 L .52899 .42782 L .845 .571 .524 r
F
.52784 .43444 m .52784 .43443 L .52776 .42672 L .988 .719 .384 r
F
.52776 .42672 m .52784 .43443 L .52777 .43431 L F
.5279 .42695 m .52817 .43499 L .52795 .43462 L F
.5279 .42696 m .52817 .43499 L .5279 .42695 L F
.5279 .42696 m .52816 .4274 L .52817 .43499 L F
.52841 .4276 m .52886 .42797 L .52887 .43557 L .929 .648 .487 r
F
.52922 .42812 m .52991 .42842 L .52992 .43606 L .845 .571 .524 r
F
.52922 .42812 m .52992 .43606 L .52935 .43579 L F
.5284 .42737 m .52887 .43557 L .52849 .43526 L .929 .648 .487 r
F
.53033 .43436 m .53039 .43614 L .53028 .43437 L .751 .491 .539 r
F
.53033 .43436 m .53028 .43437 L .52991 .42824 L F
.53011 .42828 m .53033 .43436 L .52991 .42824 L F
.53017 .42846 m .53043 .43615 L .53012 .42845 L F
.52992 .43606 m .52904 .43645 L .5305 .43633 L .642 .738 .918 r
F
.52904 .43645 m .52946 .43715 L .5305 .43633 L F
.5305 .43633 m .52949 .4372 L .52979 .43771 L F
.53043 .43615 m .53039 .43614 L .53012 .42845 L .751 .491 .539 r
F
.53048 .4285 m .53157 .42866 L .53159 .43636 L F
.53048 .4285 m .53159 .43636 L .53069 .4362 L F
.52991 .42842 m .53039 .43614 L .52992 .43606 L F
.52992 .42842 m .53039 .43614 L .52991 .42842 L F
.53058 .43618 m .52992 .43606 L .5305 .43633 L .642 .738 .918 r
F
.53028 .43675 m .53117 .43749 L .53157 .43682 L F
.53058 .43618 m .5305 .43633 L .53081 .43622 L F
.53047 .42835 m .53069 .4362 L .53016 .42829 L .751 .491 .539 r
F
.53069 .4362 m .53165 .47181 L .53043 .43615 L F
.53069 .4362 m .53043 .43615 L .53016 .42829 L F
.5141 .43231 m .51512 .43212 L .51718 .43488 L .932 .65 .484 r
F
.51512 .43212 m .51716 .43387 L .51718 .43488 L F
.49976 .4294 m .47408 .44271 L .50294 .43436 L .643 .737 .917 r
F
.52549 .42946 m .51718 .43388 L .52484 .43056 L F
.51718 .43388 m .51759 .43409 L .52484 .43056 L F
.51995 .43027 m .51718 .43488 L .522 .43199 L .667 .747 .91 r
F
.5141 .43231 m .51408 .43123 L .51512 .43212 L .932 .65 .484 r
F
.51995 .43027 m .5141 .43231 L .51718 .43488 L .667 .747 .91 r
F
.52338 .43485 m .49826 .43221 L .49925 .43743 L .642 .738 .918 r
F
.52774 .4339 m .52773 .43378 L .52772 .42584 L .781 .623 .061 r
F
.52772 .42605 m .52773 .43378 L .52771 .42593 L F
.52773 .42621 m .52776 .42672 L .52777 .43431 L F
.53169 .42616 m .5278 .42679 L .52816 .4274 L .667 .747 .91 r
F
.52876 .43552 m .52855 .43563 L .52962 .43592 L .642 .738 .918 r
F
.52855 .43563 m .52893 .43626 L .52962 .43592 L F
.52887 .43557 m .52997 .47156 L .52891 .47109 L .845 .571 .524 r
F
.52886 .42776 m .52906 .43566 L .52887 .43557 L F
.52954 .43599 m .52904 .43645 L .52992 .43606 L .642 .738 .918 r
F
.52962 .43592 m .52893 .43626 L .52904 .43645 L F
.52906 .43566 m .52997 .47156 L .52887 .43557 L .845 .571 .524 r
F
.52658 .43451 m .52269 .43349 L .52338 .43485 L .642 .738 .918 r
F
.52893 .42779 m .52911 .43568 L .52886 .42776 L .845 .571 .524 r
F
.52911 .43568 m .52997 .47156 L .52906 .43566 L F
.52911 .43568 m .52906 .43566 L .52886 .42776 L F
.51221 .42931 m .51284 .42926 L .5141 .43231 L .987 .713 .388 r
F
.51284 .42926 m .51408 .43123 L .5141 .43231 L F
.52424 .4272 m .49976 .4294 L .50078 .43099 L .643 .737 .917 r
F
.52277 .42693 m .49976 .4294 L .52424 .4272 L F
.49976 .4294 m .46759 .43286 L .47408 .44271 L F
.49878 .42417 m .46759 .43286 L .49976 .4294 L F
.5187 .42826 m .5141 .43231 L .51995 .43027 L .667 .747 .91 r
F
.51221 .42931 m .5122 .42825 L .51284 .42926 L .987 .713 .388 r
F
.5187 .42826 m .51221 .42931 L .5141 .43231 L .667 .747 .91 r
F
.52459 .43359 m .49955 .42708 L .49826 .43221 L .642 .738 .918 r
F
.5278 .42679 m .52816 .4274 L .52816 .4274 L .667 .747 .91 r
F
.52773 .43378 m .52772 .43368 L .52771 .42572 L .781 .623 .061 r
F
.52771 .42572 m .52772 .43368 L .52771 .43354 L F
.52773 .42599 m .52777 .43431 L .52774 .4339 L F
.52664 .42474 m .52705 .42392 L .52344 .42405 L .643 .737 .917 r
F
.52664 .42474 m .52344 .42405 L .52356 .42547 L F
.52746 .42544 m .52599 .42406 L .52528 .42506 L .667 .747 .91 r
F
.52819 .42492 m .52818 .42506 L .52827 .42477 L 0 0 .377 r
F
.53169 .42616 m .52827 .4249 L .52793 .42552 L .667 .747 .91 r
F
.53169 .42616 m .52816 .4274 L .52879 .42791 L F
.52818 .42506 m .5281 .43288 L .52827 .42491 L 0 0 .377 r
F
.52818 .42506 m .52827 .42491 L .52827 .42477 L F
.52808 .4251 m .52771 .42592 L .52808 .42525 L F
.52793 .42552 m .52827 .4249 L .52746 .42544 L .667 .747 .91 r
F
.52808 .4251 m .52802 .43303 L .52819 .42492 L 0 0 .377 r
F
.52827 .4249 m .52827 .4249 L .52793 .42552 L .667 .747 .91 r
F
.52827 .4249 m .52599 .42406 L .52746 .42544 L F
.52922 .42792 m .52935 .43579 L .52902 .42783 L .845 .571 .524 r
F
.52935 .43579 m .52997 .47156 L .52919 .43572 L F
.52935 .43579 m .52919 .43572 L .52902 .42783 L F
.52808 .42525 m .52771 .42592 L .52771 .43354 L 0 0 .377 r
F
.5281 .43288 m .52818 .43276 L .52827 .42491 L F
.52827 .42491 m .52827 .42491 L .52827 .42477 L F
.5281 .43288 m .52827 .42491 L .52827 .42491 L F
.52817 .42437 m .52705 .42392 L .52664 .42474 L .643 .737 .917 r
F
.52827 .4249 m .5271 .4232 L .52599 .42406 L .667 .747 .91 r
F
.52906 .42431 m .52827 .42477 L .52827 .4249 L .4 .211 .506 r
F
.52906 .42431 m .52827 .4249 L .52905 .42439 L F
.53169 .42616 m .52899 .42443 L .52827 .4249 L .667 .747 .91 r
F
.53169 .42616 m .529 .42778 L .529 .42788 L F
.529 .42778 m .52879 .42791 L .529 .42788 L F
.529 .42788 m .52879 .42791 L .52886 .42797 L F
.53169 .42616 m .52886 .42797 L .52961 .42829 L F
.52906 .42431 m .52905 .42439 L .52906 .42439 L .4 .211 .506 r
F
.52928 .42424 m .52928 .42424 L .52928 .42417 L F
.52906 .42431 m .52906 .42439 L .52928 .42417 L F
.52906 .42439 m .52928 .42424 L .52928 .42417 L F
.52899 .42443 m .52851 .42254 L .5271 .4232 L .667 .747 .91 r
F
.53024 .42388 m .52947 .42407 L .52947 .42412 L .567 .342 .533 r
F
.53169 .42616 m .5298 .42402 L .52899 .42443 L .667 .747 .91 r
F
.5298 .42402 m .52947 .42412 L .52899 .42443 L F
.5317 .43397 m .52828 .43258 L .52821 .4327 L .642 .738 .918 r
F
.52906 .42439 m .52828 .43259 L .52892 .43221 L .4 .211 .506 r
F
.52828 .43258 m .52828 .43258 L .52828 .43259 L .642 .738 .918 r
F
.52828 .43258 m .52828 .43259 L .52821 .4327 L F
.52928 .42424 m .52911 .4321 L .52931 .42422 L .4 .211 .506 r
F
.52356 .42547 m .49878 .42417 L .52344 .4255 L .643 .737 .917 r
F
.51165 .42608 m .51181 .42611 L .51221 .42931 L .865 .665 .134 r
F
.51181 .42611 m .5122 .42825 L .51221 .42931 L F
.52683 .42908 m .522 .43199 L .5247 .43331 L .667 .747 .91 r
F
.52581 .42822 m .522 .43199 L .52683 .42908 L F
.52581 .42822 m .51995 .43027 L .522 .43199 L F
.51833 .42611 m .51221 .42931 L .5187 .42826 L F
.51833 .42611 m .51165 .42608 L .51221 .42931 L F
.52592 .43273 m .50236 .42331 L .51997 .43145 L .642 .738 .918 r
F
.52827 .42477 m .52818 .43276 L .52828 .43259 L 0 0 .377 r
F
.52808 .42525 m .52771 .43354 L .52802 .43303 L F
.52802 .43303 m .5281 .43288 L .52819 .42492 L F
.5317 .43397 m .52814 .43267 L .52747 .43306 L .642 .738 .918 r
F
.52932 .42415 m .52913 .43209 L .52947 .42407 L .4 .211 .506 r
F
.5317 .43397 m .52747 .43306 L .5264 .43369 L .642 .738 .918 r
F
.5317 .43397 m .5264 .43369 L .52658 .43451 L F
.5317 .43397 m .52749 .43442 L .52816 .43498 L F
.52817 .43499 m .52891 .47109 L .5282 .4705 L .929 .648 .487 r
F
.52829 .43509 m .52891 .47109 L .52817 .43499 L F
.5317 .43397 m .52816 .43498 L .52879 .43551 L .642 .738 .918 r
F
.5317 .43397 m .52876 .43552 L .52962 .43592 L F
.52849 .43526 m .52887 .43557 L .52891 .47109 L .929 .648 .487 r
F
.52849 .43526 m .52891 .47109 L .52838 .43517 L F
.52917 .43571 m .52997 .47156 L .52911 .43568 L .845 .571 .524 r
F
.52905 .42439 m .52828 .43259 L .52906 .42439 L .4 .211 .506 r
F
.52892 .43221 m .52911 .4321 L .52928 .42424 L F
.52892 .43221 m .52928 .42424 L .52928 .42424 L F
.52906 .42439 m .52892 .43221 L .52928 .42424 L F
.52899 .42443 m .52827 .4249 L .52827 .4249 L .667 .747 .91 r
F
.52905 .42439 m .52827 .4249 L .52828 .43259 L .4 .211 .506 r
F
.52356 .42547 m .52344 .42405 L .50758 .42463 L .643 .737 .917 r
F
.51245 .42285 m .51221 .42288 L .51165 .42608 L 0 0 .24 r
F
.51165 .42608 m .51163 .42511 L .51181 .42611 L .865 .665 .134 r
F
.51221 .42288 m .51163 .42511 L .51165 .42608 L 0 0 .24 r
F
.51169 .42487 m .51159 .42486 L .51166 .42501 L .643 .737 .917 r
F
.52424 .4272 m .5241 .42722 L .52637 .42759 L F
.52519 .42721 m .51995 .43027 L .52581 .42822 L .667 .747 .91 r
F
.52519 .42721 m .5187 .42826 L .51995 .43027 L F
.52501 .42614 m .5187 .42826 L .52519 .42721 L F
.52501 .42614 m .51833 .42611 L .5187 .42826 L F
.52528 .42506 m .51833 .42611 L .52501 .42614 L F
.51887 .42396 m .51165 .42608 L .51833 .42611 L F
.52528 .42506 m .51887 .42396 L .51833 .42611 L F
.51887 .42396 m .51245 .42285 L .51165 .42608 L F
.52029 .42195 m .51245 .42285 L .51887 .42396 L F
.52029 .42195 m .51457 .41984 L .51245 .42285 L F
.52763 .43232 m .50854 .41847 L .50305 .42239 L .642 .738 .918 r
F
.5317 .43397 m .52882 .43204 L .52763 .43232 L F
.52882 .43204 m .50854 .41847 L .52763 .43232 L F
.53169 .42616 m .52953 .42837 L .53056 .42851 L .667 .747 .91 r
F
.53046 .42383 m .53029 .43169 L .53049 .42382 L .567 .342 .533 r
F
.5317 .43397 m .52962 .43592 L .52992 .43606 L .642 .738 .918 r
F
.5317 .43397 m .52992 .43606 L .53058 .43618 L F
.52919 .43572 m .52997 .47156 L .52917 .43571 L .845 .571 .524 r
F
.52962 .43592 m .52954 .43599 L .52992 .43606 L .642 .738 .918 r
F
.52935 .43579 m .52992 .43606 L .52997 .47156 L .845 .571 .524 r
F
.52992 .43606 m .53165 .47181 L .52997 .47156 L .751 .491 .539 r
F
.53039 .43614 m .53165 .47181 L .52992 .43606 L F
.52913 .43209 m .52926 .43201 L .52947 .42407 L .4 .211 .506 r
F
.52947 .42407 m .52926 .43201 L .52948 .43189 L F
.53024 .42389 m .52947 .42412 L .52948 .43189 L .567 .342 .533 r
F
.53024 .42389 m .52948 .43189 L .53011 .43174 L F
.52911 .4321 m .52913 .43209 L .52931 .42422 L .4 .211 .506 r
F
.52599 .42406 m .51887 .42396 L .52528 .42506 L .667 .747 .91 r
F
.52599 .42406 m .52029 .42195 L .51887 .42396 L F
.5271 .4232 m .52029 .42195 L .52599 .42406 L F
.5271 .4232 m .52249 .42023 L .52029 .42195 L F
.52249 .42023 m .51457 .41984 L .52029 .42195 L F
.52249 .42023 m .51787 .41724 L .51457 .41984 L F
.5283 .43169 m .51565 .4156 L .50854 .41847 L .642 .738 .918 r
F
.5317 .43397 m .52981 .43181 L .52882 .43204 L F
.53043 .43615 m .53165 .47181 L .53039 .43614 L .751 .491 .539 r
F
.5317 .43397 m .53058 .43618 L .53081 .43622 L .642 .738 .918 r
F
.53169 .42616 m .53056 .42851 L .53157 .42866 L .667 .747 .91 r
F
.53064 .42379 m .53044 .43166 L .53065 .43161 L .567 .342 .533 r
F
.53029 .43169 m .53032 .43169 L .53049 .42382 L F
.53024 .42389 m .53011 .43174 L .53035 .42386 L F
.53011 .43174 m .5302 .43172 L .53035 .42386 L F
.52866 .42421 m .5271 .4232 L .52827 .4249 L .667 .747 .91 r
F
.53035 .42386 m .5302 .43172 L .53046 .42383 L .567 .342 .533 r
F
.5302 .43172 m .53029 .43169 L .53046 .42383 L F
.52758 .42615 m .52528 .42506 L .52501 .42614 L .667 .747 .91 r
F
.52772 .42615 m .52761 .4261 L .52758 .42615 L F
.52761 .4261 m .52528 .42506 L .52758 .42615 L F
.52851 .42254 m .52249 .42023 L .5271 .4232 L F
.52851 .42254 m .52532 .41891 L .52249 .42023 L F
.52532 .41891 m .51787 .41724 L .52249 .42023 L F
.52532 .41891 m .52212 .41526 L .51787 .41724 L F
.52981 .43181 m .52389 .41399 L .51565 .4156 L .642 .738 .918 r
F
.5318 .42367 m .53162 .42375 L .53181 .42374 L .66 .416 .54 r
F
.53163 .42368 m .53162 .42375 L .5318 .42367 L F
.53275 .42065 m .53295 .42067 L .53277 .42061 L .667 .747 .91 r
F
.53277 .42061 m .53513 .41943 L .53354 .419 L F
.53361 .42215 m .53208 .41781 L .53188 .422 L F
.53417 .42097 m .53486 .42107 L .5345 .42028 L F
.53417 .42097 m .5345 .42028 L .53443 .42014 L F
.53369 .4209 m .53417 .42097 L .53443 .42014 L F
.53465 .4212 m .53486 .42107 L .53369 .4209 L F
.53488 .42158 m .535 .42167 L .53517 .41869 L .911 .629 .497 r
F
.535 .42167 m .53511 .42175 L .53517 .41869 L F
.53564 .4199 m .53597 .4199 L .5357 .41953 L .668 .747 .909 r
F
.5355 .41937 m .5352 .41872 L .53521 .42182 L .983 .725 .332 r
F
.53443 .42014 m .53648 .4201 L .53513 .41943 L .667 .747 .91 r
F
.53552 .42057 m .53584 .42011 L .53574 .4199 L .668 .747 .909 r
F
.53486 .42107 m .53648 .4201 L .53443 .42014 L .667 .747 .91 r
F
.53467 .41834 m .53516 .41862 L .53496 .41819 L .668 .747 .909 r
F
.53509 .41864 m .53516 .41862 L .53467 .41834 L F
.53456 .41807 m .53496 .41819 L .53483 .41791 L F
.53516 .41862 m .53739 .41784 L .53483 .41791 L F
.53483 .41791 m .53739 .41784 L .53638 .41697 L F
.53638 .41697 m .53854 .41271 L .53503 .41631 L F
.53513 .41943 m .53546 .41496 L .53354 .419 L .667 .747 .91 r
F
.53593 .4185 m .538 .41884 L .53749 .418 L .668 .747 .909 r
F
.53735 .41895 m .538 .41884 L .53593 .4185 L F
.53739 .41784 m .54123 .41405 L .53638 .41697 L F
.53638 .41697 m .54123 .41405 L .53854 .41271 L F
.53513 .41943 m .53865 .41582 L .53546 .41496 L .667 .747 .91 r
F
.53361 .42215 m .53554 .41811 L .53208 .41781 L F
.53537 .41186 m .53729 .40782 L .53213 .40737 L .668 .747 .909 r
F
.53854 .41271 m .53729 .40782 L .53537 .41186 L F
.53546 .41496 m .5374 .41091 L .53221 .41045 L .667 .747 .91 r
F
.53554 .41811 m .53228 .41361 L .53208 .41781 L F
.53865 .41582 m .5374 .41091 L .53546 .41496 L F
.53554 .41811 m .53748 .41406 L .53228 .41361 L F
.53854 .41271 m .54206 .4091 L .53729 .40782 L .668 .747 .909 r
F
.5374 .41091 m .53732 .40776 L .53213 .40731 L .731 .475 .542 r
F
.53221 .41045 m .5269 .40772 L .52697 .41086 L .665 .423 .544 r
F
.53221 .41045 m .53213 .40731 L .5269 .40772 L F
.5374 .41091 m .53213 .40731 L .53221 .41045 L .731 .475 .542 r
F
.53748 .41406 m .5374 .41091 L .53221 .41045 L F
.53228 .41361 m .53221 .41045 L .52697 .41086 L .665 .423 .544 r
F
.53748 .41406 m .53221 .41045 L .53228 .41361 L .731 .475 .542 r
F
.53214 .42592 m .53312 .40566 L .52435 .4059 L .643 .737 .917 r
F
.5314 .42376 m .53064 .42379 L .53065 .43161 L .66 .416 .54 r
F
.5317 .43397 m .53078 .4316 L .52981 .43181 L .642 .738 .918 r
F
.53159 .43636 m .53073 .43643 L .53157 .43682 L F
.53157 .43682 m .53117 .43749 L .53152 .43778 L F
.53069 .4362 m .53159 .43636 L .53165 .47181 L .751 .491 .539 r
F
.5317 .43397 m .53073 .43643 L .53159 .43636 L .642 .738 .918 r
F
.5314 .42376 m .53065 .43161 L .53128 .43158 L .66 .416 .54 r
F
.53049 .42382 m .53032 .43169 L .53064 .42379 L .567 .342 .533 r
F
.53032 .43169 m .53044 .43166 L .53064 .42379 L F
.53138 .42535 m .53138 .42531 L .53134 .42524 L .667 .747 .91 r
F
.53169 .42616 m .53138 .42531 L .53138 .42535 L F
.53169 .42616 m .53171 .42577 L .53138 .42531 L F
.5314 .42376 m .53128 .43158 L .53162 .42375 L .66 .416 .54 r
F
.53128 .43158 m .53146 .43158 L .53162 .42375 L F
.53024 .42388 m .52947 .42412 L .53024 .42389 L .567 .342 .533 r
F
.5298 .42402 m .52974 .42394 L .52947 .42412 L .667 .747 .91 r
F
.52928 .42417 m .52928 .42424 L .52932 .42415 L .4 .211 .506 r
F
.52928 .42424 m .52931 .42422 L .52932 .42415 L F
.52974 .42394 m .52851 .42254 L .52899 .42443 L .667 .747 .91 r
F
.52899 .42443 m .52866 .42421 L .52827 .4249 L F
.53024 .42388 m .53024 .42389 L .53035 .42386 L .567 .342 .533 r
F
.53214 .42592 m .53169 .42574 L .53176 .42584 L .643 .737 .917 r
F
.53214 .42592 m .53176 .42584 L .53181 .4259 L F
.53169 .42616 m .53181 .42591 L .53171 .42577 L .667 .747 .91 r
F
.53214 .42592 m .53181 .4259 L .53184 .42595 L .643 .737 .917 r
F
.5307 .43141 m .53268 .41375 L .52389 .41399 L .642 .738 .918 r
F
.5317 .43397 m .53457 .43245 L .53412 .43213 L F
.5317 .43397 m .53412 .43213 L .53379 .43201 L F
.53395 .42425 m .53409 .4243 L .5341 .42414 L .81 .54 .53 r
F
.53379 .43201 m .53391 .43205 L .5341 .42414 L F
.53547 .4224 m .53596 .42304 L .53652 .42223 L .667 .747 .91 r
F
.53577 .42304 m .53596 .42304 L .53547 .4224 L F
.5361 .42067 m .53789 .42098 L .53574 .4199 L .668 .747 .909 r
F
.53486 .42107 m .53735 .42101 L .53648 .4201 L .667 .747 .91 r
F
.53519 .42177 m .53735 .42101 L .53486 .42107 L F
.53735 .42101 m .5375 .42096 L .53743 .42091 L F
.53735 .42101 m .53743 .42091 L .53648 .4201 L F
.53597 .4199 m .53817 .41991 L .53654 .41908 L .668 .747 .909 r
F
.53811 .42197 m .54339 .4189 L .5375 .42096 L .667 .747 .91 r
F
.5375 .42096 m .54136 .41716 L .53648 .4201 L F
.5375 .42096 m .54339 .4189 L .54136 .41716 L F
.53656 .42324 m .53873 .41896 L .5352 .42257 L F
.53656 .42324 m .54144 .42031 L .53873 .41896 L F
.5341 .4243 m .55663 .41289 L .53397 .42421 L .643 .737 .917 r
F
.53483 .42466 m .5341 .4243 L .53482 .42483 L .911 .629 .497 r
F
.53456 .42464 m .53475 .42453 L .5341 .4243 L .643 .737 .917 r
F
.53475 .42453 m .55663 .41289 L .5341 .4243 L F
.53395 .42409 m .53395 .42425 L .5341 .42414 L .81 .54 .53 r
F
.53395 .42425 m .53379 .43201 L .53409 .4243 L F
.58833 .44063 m .62695 .43827 L .59569 .43153 L .644 .737 .916 r
F
.59569 .43153 m .62695 .43827 L .63196 .42313 L F
.59569 .43153 m .63196 .42313 L .59883 .42139 L F
.56403 .43277 m .59572 .43959 L .59889 .42943 L .643 .737 .917 r
F
.56039 .43738 m .59572 .43959 L .56403 .43277 L F
.56403 .43277 m .59889 .42943 L .56551 .42767 L F
.54149 .43292 m .56515 .43572 L .56436 .43048 L .642 .738 .918 r
F
.53393 .42408 m .53377 .432 L .53395 .42409 L .81 .54 .53 r
F
.5317 .43397 m .54077 .43444 L .5376 .43334 L .642 .738 .918 r
F
.5317 .43397 m .53379 .43201 L .53298 .43173 L F
.53214 .42592 m .53393 .42425 L .53313 .42397 L .643 .737 .917 r
F
.53254 .42693 m .53313 .42846 L .53353 .42832 L F
.53169 .42616 m .53343 .42836 L .5333 .42801 L .667 .747 .91 r
F
.53342 .42837 m .53339 .42837 L .53342 .42836 L .517 .303 .528 r
F
.53169 .42616 m .53259 .42852 L .53343 .42836 L .667 .747 .91 r
F
.53342 .42837 m .53339 .42838 L .53339 .42837 L .517 .303 .528 r
F
.53339 .42837 m .53339 .42838 L .53339 .42837 L F
.53259 .42852 m .53326 .42843 L .53343 .42836 L .667 .747 .91 r
F
.53169 .42616 m .5333 .42801 L .53225 .42653 L F
.53214 .42592 m .53315 .42393 L .53225 .42381 L .643 .737 .917 r
F
.53296 .42391 m .53276 .4317 L .53298 .43173 L .734 .477 .539 r
F
.53296 .42378 m .53296 .42391 L .53296 .42391 L F
.53296 .42391 m .53276 .4317 L .53296 .42391 L F
.54123 .41405 m .54206 .4091 L .53854 .41271 L .668 .747 .909 r
F
.54123 .41405 m .54609 .41112 L .54206 .4091 L F
.53865 .41582 m .54219 .41219 L .5374 .41091 L .667 .747 .91 r
F
.54219 .41219 m .54211 .40905 L .53732 .40776 L .795 .528 .533 r
F
.53704 .41796 m .53749 .418 L .53739 .41784 L .668 .747 .909 r
F
.538 .41884 m .54325 .41578 L .53739 .41784 L F
.53739 .41784 m .54325 .41578 L .54123 .41405 L F
.53545 .41925 m .53627 .41948 L .53586 .41919 L F
.53558 .41954 m .53627 .41948 L .53545 .41925 L F
.53558 .41954 m .53567 .41974 L .5357 .41953 L F
.53586 .41919 m .53627 .41948 L .53654 .41908 L F
.53648 .4201 m .53865 .41582 L .53513 .41943 L .667 .747 .91 r
F
.53648 .4201 m .54136 .41716 L .53865 .41582 L F
.53873 .41896 m .53748 .41406 L .53554 .41811 L F
.54325 .41578 m .54609 .41112 L .54123 .41405 L .668 .747 .909 r
F
.54136 .41716 m .54219 .41219 L .53865 .41582 L .667 .747 .91 r
F
.54136 .41716 m .54625 .41421 L .54219 .41219 L F
.53873 .41896 m .54228 .41534 L .53748 .41406 L F
.54219 .41219 m .53732 .40776 L .5374 .41091 L .795 .528 .533 r
F
.54228 .41534 m .54219 .41219 L .5374 .41091 L F
.54228 .41534 m .5374 .41091 L .53748 .41406 L F
.53225 .42381 m .54183 .40682 L .53312 .40566 L .643 .737 .917 r
F
.53285 .42374 m .5352 .42257 L .53361 .42215 L .667 .747 .91 r
F
.53377 .42403 m .5352 .42257 L .53285 .42374 L F
.53298 .42378 m .53296 .42378 L .53296 .42391 L .81 .54 .53 r
F
.53448 .4213 m .53519 .42177 L .53486 .42107 L .667 .747 .91 r
F
.53516 .42178 m .53519 .42177 L .53448 .4213 L F
.5317 .43397 m .53298 .43173 L .53285 .43171 L .642 .738 .918 r
F
.53278 .42376 m .53262 .43168 L .53296 .42378 L .734 .477 .539 r
F
.5317 .43397 m .53285 .43171 L .53182 .43156 L .642 .738 .918 r
F
.5317 .43397 m .53159 .43636 L .53261 .43628 L F
.53262 .43168 m .53189 .4668 L .53276 .4317 L .734 .477 .539 r
F
.53262 .43168 m .53276 .4317 L .53296 .42378 L F
.53214 .42592 m .53212 .42635 L .53254 .42693 L .643 .737 .917 r
F
.53256 .42385 m .53182 .43156 L .53244 .43165 L .734 .477 .539 r
F
.53182 .43156 m .53286 .43169 L .53183 .43133 L .642 .738 .918 r
F
.53244 .43165 m .53262 .43168 L .53278 .42388 L .734 .477 .539 r
F
.53285 .43171 m .53286 .43169 L .53182 .43156 L .642 .738 .918 r
F
.5352 .42257 m .53554 .41811 L .53361 .42215 L .667 .747 .91 r
F
.5352 .42257 m .53873 .41896 L .53554 .41811 L F
.53315 .42393 m .54183 .40682 L .53225 .42381 L .643 .737 .917 r
F
.53285 .43171 m .53298 .43173 L .53286 .43169 L .642 .738 .918 r
F
.53298 .43173 m .53189 .4668 L .53306 .46692 L .734 .477 .539 r
F
.53276 .4317 m .53189 .4668 L .53298 .43173 L F
.53377 .432 m .53306 .46692 L .53379 .43201 L .81 .54 .53 r
F
.53377 .432 m .53379 .43201 L .53395 .42409 L F
.5376 .43334 m .5592 .43541 L .54149 .43292 L .642 .738 .918 r
F
.54077 .43444 m .5592 .43541 L .5376 .43334 L F
.5592 .43541 m .56515 .43572 L .54149 .43292 L F
.53256 .42385 m .53244 .43165 L .53278 .42388 L .734 .477 .539 r
F
.53244 .43165 m .53189 .4668 L .53262 .43168 L F
.53379 .43201 m .53306 .46692 L .53391 .43205 L .81 .54 .53 r
F
.53412 .43213 m .55625 .42098 L .53387 .43194 L .642 .738 .918 r
F
.53457 .43245 m .53476 .43235 L .53412 .43213 L F
.53476 .43235 m .55625 .42098 L .53412 .43213 L F
.53379 .43201 m .53412 .43213 L .53387 .43194 L F
.5337 .42417 m .53296 .42391 L .53298 .43173 L .81 .54 .53 r
F
.53359 .43194 m .53298 .43173 L .53306 .46692 L F
.53343 .42836 m .53345 .42836 L .5333 .42801 L .667 .747 .91 r
F
.53347 .42841 m .53358 .42839 L .5333 .42801 L F
.5337 .42417 m .53298 .43173 L .53359 .43194 L .81 .54 .53 r
F
.53182 .43156 m .53071 .46688 L .53189 .4668 L .66 .416 .54 r
F
.53169 .42616 m .53225 .42653 L .5321 .42632 L .667 .747 .91 r
F
.53169 .42616 m .53203 .42622 L .53199 .42617 L F
.53169 .42616 m .5321 .42632 L .53203 .42622 L F
.53181 .42374 m .53161 .43157 L .53182 .43156 L .66 .416 .54 r
F
.5317 .43397 m .53182 .43156 L .53078 .4316 L .642 .738 .918 r
F
.53161 .43157 m .53071 .46688 L .53182 .43156 L .66 .416 .54 r
F
.53169 .42616 m .53193 .42608 L .5319 .42604 L .667 .747 .91 r
F
.53162 .42375 m .53071 .46688 L .53181 .42374 L .66 .416 .54 r
F
.53078 .4316 m .53182 .43156 L .5307 .43141 L .642 .738 .918 r
F
.53182 .43156 m .53182 .43156 L .53078 .4316 L F
.53214 .42592 m .53201 .42619 L .53212 .42635 L .643 .737 .917 r
F
.53214 .42592 m .53195 .42611 L .53201 .42619 L F
.53214 .42592 m .53185 .42597 L .53187 .426 L F
.53214 .42592 m .53191 .42605 L .53195 .42611 L F
.53256 .42385 m .53181 .42374 L .53182 .43156 L .734 .477 .539 r
F
.53182 .43156 m .53268 .41375 L .5307 .43141 L .642 .738 .918 r
F
.53244 .43165 m .53182 .43156 L .53189 .4668 L .734 .477 .539 r
F
.53128 .43158 m .53065 .43161 L .53071 .46688 L .66 .416 .54 r
F
.53078 .4316 m .53077 .43158 L .53065 .43161 L .642 .738 .918 r
F
.53078 .4316 m .53065 .43161 L .52981 .43181 L F
.53077 .43158 m .52389 .41399 L .52981 .43181 L F
.53032 .43169 m .52952 .46722 L .53044 .43166 L .567 .342 .533 r
F
.53065 .43161 m .52952 .46722 L .53071 .46688 L F
.53044 .43166 m .52952 .46722 L .53065 .43161 L F
.52882 .43204 m .52967 .43164 L .5283 .43169 L .642 .738 .918 r
F
.52981 .43181 m .52967 .43164 L .52882 .43204 L F
.52967 .43164 m .51565 .4156 L .5283 .43169 L F
.53128 .43158 m .53071 .46688 L .53146 .43158 L .66 .416 .54 r
F
.53029 .43169 m .52952 .46722 L .53032 .43169 L .567 .342 .533 r
F
.52913 .43209 m .52831 .46799 L .52926 .43201 L .4 .211 .506 r
F
.5264 .43369 m .52592 .43273 L .52459 .43359 L .642 .738 .918 r
F
.52747 .43306 m .52592 .43273 L .5264 .43369 L F
.52592 .43273 m .51997 .43145 L .52381 .43323 L F
.52592 .43273 m .52381 .43323 L .52459 .43359 L F
.53011 .43174 m .52952 .46722 L .5302 .43172 L .567 .342 .533 r
F
.52948 .43189 m .52831 .46799 L .52952 .46722 L .4 .211 .506 r
F
.52926 .43201 m .52831 .46799 L .52948 .43189 L F
.52747 .43306 m .52736 .43239 L .52592 .43273 L .642 .738 .918 r
F
.52814 .43267 m .52736 .43239 L .52747 .43306 L F
.52736 .43239 m .50236 .42331 L .52592 .43273 L F
.53011 .43174 m .52948 .43189 L .52952 .46722 L .567 .342 .533 r
F
.52911 .4321 m .52831 .46799 L .52913 .43209 L .4 .211 .506 r
F
.52821 .4327 m .50305 .42239 L .50236 .42331 L .642 .738 .918 r
F
.52828 .43258 m .50305 .42239 L .52821 .4327 L F
.51997 .43145 m .50236 .42331 L .49955 .42708 L F
.51997 .43145 m .49955 .42708 L .52459 .43359 L F
.52892 .43221 m .52831 .46799 L .52911 .4321 L .4 .211 .506 r
F
.5264 .43369 m .52459 .43359 L .52569 .4341 L .642 .738 .918 r
F
.5264 .43369 m .52569 .4341 L .52658 .43451 L F
.52459 .43359 m .52269 .43349 L .52658 .43451 L F
.5302 .43172 m .52952 .46722 L .53029 .43169 L .567 .342 .533 r
F
.52269 .43349 m .51327 .433 L .51975 .43419 L .642 .738 .918 r
F
.52269 .43349 m .51975 .43419 L .52338 .43485 L F
.51327 .433 m .49826 .43221 L .52338 .43485 L F
.52749 .43442 m .49925 .43743 L .52816 .43498 L F
.52892 .43221 m .52828 .43259 L .52831 .46799 L .4 .211 .506 r
F
.52789 .43452 m .5282 .4705 L .52784 .43444 L .988 .719 .384 r
F
.52795 .43462 m .5282 .4705 L .52789 .43452 L F
.52784 .43444 m .5282 .4705 L .52784 .43443 L F
.52777 .43431 m .5282 .4705 L .52779 .46982 L F
.52784 .43443 m .5282 .4705 L .52777 .43431 L F
.52778 .46512 m .52779 .46982 L .52778 .46519 L .781 .623 .061 r
F
.52778 .46512 m .52778 .46519 L .52773 .43378 L F
.52774 .4339 m .52778 .46512 L .52773 .43378 L F
.52795 .43462 m .52817 .43499 L .5282 .4705 L .988 .719 .384 r
F
.52773 .43378 m .52779 .46982 L .52772 .43368 L .781 .623 .061 r
F
.52771 .43354 m .52779 .46982 L .52774 .46901 L F
.52772 .43368 m .52779 .46982 L .52771 .43354 L F
.52774 .4339 m .52777 .43431 L .52779 .46982 L F
.5281 .43288 m .52774 .46901 L .52818 .43276 L 0 0 .377 r
F
.52493 .43822 m .50757 .44674 L .52213 .44292 L .642 .738 .918 r
F
.52828 .43259 m .52774 .46901 L .52831 .46799 L 0 0 .377 r
F
.52818 .43276 m .52774 .46901 L .52828 .43259 L F
.52213 .44292 m .51432 .45022 L .5214 .44414 L .642 .738 .918 r
F
.52802 .43303 m .52771 .43354 L .52774 .46901 L 0 0 .377 r
F
.5214 .44414 m .51432 .45022 L .51726 .4511 L .642 .738 .918 r
F
.5214 .44414 m .51726 .4511 L .52222 .45259 L F
.52802 .43303 m .52774 .46901 L .5281 .43288 L 0 0 .377 r
F
.53313 .42397 m .53412 .42407 L .53315 .42393 L .643 .737 .917 r
F
.53393 .42425 m .53412 .42407 L .53313 .42397 L F
.54625 .41421 m .54616 .41107 L .54211 .40905 L .863 .585 .515 r
F
.54339 .4189 m .54625 .41421 L .54136 .41716 L .667 .747 .91 r
F
.54144 .42031 m .54228 .41534 L .53873 .41896 L F
.54144 .42031 m .54634 .41736 L .54228 .41534 L F
.54625 .41421 m .54211 .40905 L .54219 .41219 L .863 .585 .515 r
F
.54634 .41736 m .54625 .41421 L .54219 .41219 L F
.54634 .41736 m .54219 .41219 L .54228 .41534 L F
.53315 .42393 m .54985 .40929 L .54183 .40682 L .643 .737 .917 r
F
.53412 .42407 m .54985 .40929 L .53315 .42393 L F
.5337 .42417 m .53359 .43194 L .53392 .42424 L .81 .54 .53 r
F
.53359 .43194 m .53306 .46692 L .53377 .432 L F
.53359 .43194 m .53377 .432 L .53392 .42424 L F
.53503 .43279 m .53422 .4673 L .53504 .4328 L .911 .629 .497 r
F
.53524 .43295 m .53422 .4673 L .53535 .46811 L F
.53504 .4328 m .53422 .4673 L .53524 .43295 L F
.53397 .42421 m .55663 .41289 L .54985 .40929 L .643 .737 .917 r
F
.53513 .42506 m .53718 .42538 L .53575 .42488 L F
.53577 .42553 m .53718 .42538 L .53513 .42506 L F
.53575 .42488 m .54073 .425 L .5371 .42449 L F
.53718 .42538 m .54073 .425 L .53575 .42488 L F
.53543 .42557 m .53662 .42616 L .53577 .42553 L F
.53563 .426 m .53563 .426 L .53563 .42582 L .983 .725 .332 r
F
.53559 .42573 m .53569 .42595 L .53573 .42571 L .667 .747 .91 r
F
.53568 .42611 m .53662 .42616 L .53543 .42557 L .643 .737 .917 r
F
.53597 .42675 m .53728 .42703 L .53568 .42611 L F
.53304 .43134 m .54945 .41738 L .5414 .41491 L .642 .738 .918 r
F
.53286 .43169 m .53317 .43143 L .53304 .43134 L F
.53317 .43143 m .54945 .41738 L .53304 .43134 L F
.53387 .43194 m .55625 .42098 L .54945 .41738 L F
.53472 .43256 m .53422 .4673 L .5349 .43269 L .911 .629 .497 r
F
.53391 .43205 m .53306 .46692 L .53391 .43205 L .81 .54 .53 r
F
.53379 .43201 m .54945 .41738 L .53286 .43169 L .642 .738 .918 r
F
.53393 .42425 m .5341 .4243 L .53397 .42421 L .643 .737 .917 r
F
.53183 .43133 m .5414 .41491 L .53268 .41375 L .642 .738 .918 r
F
.53286 .43169 m .5414 .41491 L .53183 .43133 L F
.53412 .43213 m .53306 .46692 L .53422 .4673 L .81 .54 .53 r
F
.53391 .43205 m .53306 .46692 L .53412 .43213 L F
.53472 .43256 m .53412 .43213 L .53422 .4673 L .911 .629 .497 r
F
.56039 .43738 m .5883 .4487 L .59572 .43959 L .643 .737 .917 r
F
.55486 .44119 m .5883 .4487 L .56039 .43738 L F
.53702 .43425 m .56366 .44081 L .56515 .43572 L .642 .738 .918 r
F
.53868 .43546 m .56366 .44081 L .53702 .43425 L F
.53492 .43271 m .53422 .4673 L .53503 .43279 L .911 .629 .497 r
F
.53868 .43546 m .56002 .4454 L .56366 .44081 L .642 .738 .918 r
F
.54273 .43842 m .56002 .4454 L .53868 .43546 L F
.53534 .43505 m .53549 .43485 L .53545 .44553 L .08 0 .418 r
F
.53549 .43485 m .53559 .43472 L .53545 .44553 L F
.53545 .44553 m .53559 .43472 L .5357 .46995 L F
.53534 .43505 m .5357 .46995 L .53527 .43515 L F
.5355 .43348 m .53524 .43295 L .53535 .46811 L .983 .725 .332 r
F
.53563 .43448 m .53583 .46915 L .53561 .43458 L 0 0 .15 r
F
.53559 .43472 m .53583 .46915 L .5357 .46995 L F
.53561 .43458 m .53583 .46915 L .53559 .43472 L F
.5356 .43371 m .53535 .46811 L .53563 .43377 L .983 .725 .332 r
F
.53565 .43436 m .53572 .43395 L .53583 .46915 L 0 0 .15 r
F
.53565 .43436 m .53583 .46915 L .53563 .43448 L F
.53572 .43395 m .53535 .46811 L .53583 .46915 L .983 .725 .332 r
F
.53563 .43377 m .53535 .46811 L .53572 .43395 L F
.53723 .43719 m .55603 .44814 L .53666 .43597 L .642 .738 .918 r
F
.53723 .43719 m .53666 .43597 L .53665 .43596 L F
.54273 .43842 m .55603 .44814 L .56002 .4454 L F
.5349 .43269 m .53422 .4673 L .53492 .43271 L .911 .629 .497 r
F
.5355 .43348 m .53535 .46811 L .53557 .43364 L .983 .725 .332 r
F
.54035 .44386 m .54743 .45195 L .53955 .44216 L .642 .738 .918 r
F
.53558 .43366 m .53535 .46811 L .5356 .43371 L .983 .725 .332 r
F
.53755 .43788 m .54743 .45195 L .55448 .4492 L .642 .738 .918 r
F
.53955 .44216 m .54743 .45195 L .53755 .43788 L F
.53557 .43364 m .53535 .46811 L .53558 .43366 L .983 .725 .332 r
F
.54035 .44386 m .54441 .45253 L .54743 .45195 L .642 .738 .918 r
F
.66307 .69342 m .66563 .68094 L .66633 .68623 L 0 0 .458 r
F
.66377 .6987 m .66307 .69342 L .66633 .68623 L F
.64451 .6923 m .66307 .69342 L .66633 .68623 L .656 .809 .957 r
F
0 g
.65663 .69977 m
.66307 .69342 L
s
.75558 .56596 m .72785 .57008 L .75392 .56946 L .654 .782 .942 r
F
.83308 .57397 m .85966 .56291 L .83324 .56703 L .653 .783 .943 r
F
.80692 .57459 m .83308 .57397 L .83324 .56703 L F
.28907 .56474 m .26306 .56183 L .26174 .57236 L .656 .781 .94 r
F
.26256 .56821 m .26134 .57237 L .26124 .57875 L 0 0 .087 r
F
0 g
.26187 .5737 m
.26385 .57869 L
s
.26256 .56821 m .26266 .56179 L .26134 .57237 L 0 0 .087 r
F
.73542 .45078 m .71332 .45101 L .71332 .459 L .512 .311 .544 r
F
0 g
.69579 .47014 m
.71332 .459 L
s
.73542 .45078 m .73537 .44277 L .71332 .45101 L .512 .311 .544 r
F
0 g
.69584 .46219 m
.71332 .45101 L
s
.41993 .58138 m .41686 .56459 L .41701 .571 L .914 .697 .198 r
F
.39353 .58201 m .41993 .58138 L .41701 .571 L .654 .782 .942 r
F
0 g
.41745 .59173 m
.41993 .58138 L
s
.43223 .8256 m .42554 .82036 L .42012 .82182 L .593 .769 .963 r
F
.43539 .82524 m .42554 .82036 L .43223 .8256 L F
.34271 .46679 m .34141 .4473 L .31573 .44795 L .641 .739 .92 r
F
.44538 .82639 m .44558 .82043 L .4422 .82564 L .593 .769 .963 r
F
.44538 .82639 m .45196 .82194 L .44558 .82043 L F
.62181 .58123 m .6099 .56714 L .60832 .58064 L .654 .783 .943 r
F
.62181 .58123 m .63033 .56805 L .6099 .56714 L F
.64056 .70219 m .66377 .6987 L .64518 .69759 L .655 .81 .957 r
F
.62421 .69879 m .64056 .70219 L .64518 .69759 L F
.62081 .70087 m .64056 .70219 L .62421 .69879 L F
.85298 .45834 m .83439 .43999 L .83468 .44798 L .872 .6 .524 r
F
.85331 .46635 m .85298 .45834 L .83468 .44798 L F
0 g
.85298 .45834 m
.86563 .4711 L
s
.76552 .46544 m .76053 .44615 L .73542 .45078 L .643 .738 .918 r
F
.78283 .46502 m .76053 .44615 L .76552 .46544 L F
.7996 .46723 m .78679 .44549 L .78283 .46502 L F
.7996 .46723 m .81224 .44887 L .78679 .44549 L F
.36575 .56643 m .38544 .55594 L .36293 .56325 L .656 .781 .94 r
F
.36575 .56643 m .39098 .56235 L .38544 .55594 L F
.42915 .83084 m .41973 .82634 L .41561 .8284 L .592 .769 .964 r
F
.43186 .83012 m .41973 .82634 L .42915 .83084 L F
.73105 .56307 m .70174 .5707 L .72785 .57008 L .654 .782 .942 r
F
.75558 .56596 m .73105 .56307 L .72785 .57008 L F
.80692 .57459 m .83324 .56703 L .80693 .57113 L .653 .783 .943 r
F
.44776 .83195 m .45161 .82647 L .44503 .8309 L .592 .769 .964 r
F
.44776 .83195 m .45708 .82857 L .45161 .82647 L F
.43539 .82524 m .43189 .81961 L .42554 .82036 L .593 .769 .963 r
F
.4388 .82525 m .43189 .81961 L .43539 .82524 L F
.31477 .574 m .28773 .57812 L .3142 .5775 L .655 .781 .941 r
F
.4422 .82564 m .43873 .81964 L .4388 .82525 L .593 .769 .963 r
F
.4422 .82564 m .44558 .82043 L .43873 .81964 L F
.39353 .58201 m .41701 .571 L .39146 .5751 L .654 .782 .942 r
F
.36711 .58264 m .39353 .58201 L .39146 .5751 L F
.19095 .42817 m .2141 .43073 L .21291 .43868 L .845 .602 .571 r
F
.19095 .42817 m .1922 .4202 L .2141 .43073 L F
0 g
.2141 .43073 m
.21867 .43205 L
s
.42012 .82182 m .40448 .8204 L .416 .82388 L .593 .769 .963 r
F
.41561 .8284 m .40408 .82492 L .40031 .82873 L .592 .769 .964 r
F
0 g
.39916 .83295 m
.40031 .82873 L
s
.58207 .59125 m .56995 .57998 L .55296 .58678 L .653 .784 .944 r
F
.59504 .58829 m .56995 .57998 L .58207 .59125 L F
.5946 .58188 m .58913 .56902 L .56954 .57354 L .654 .783 .943 r
F
.60832 .58064 m .58913 .56902 L .5946 .58188 L F
0 g
.27453 .45679 m
.27589 .45675 L
s
.24255 .43522 m .26222 .4571 L .25996 .43748 L .642 .739 .919 r
F
.24255 .43522 m .2364 .45377 L .26222 .4571 L F
0 g
.26222 .4571 m
.27453 .45679 L
s
.4388 .82525 m .43873 .81964 L .43189 .81961 L .593 .769 .963 r
F
0 g
.32973 .4288 m
.33263 .42758 L
s
.32261 .4318 m
.32973 .4288 L
s
.4616 .82661 m .4668 .82063 L .45742 .82405 L .593 .769 .963 r
F
.4616 .82661 m .47305 .8245 L .4668 .82063 L F
.21382 .4071 m .21431 .43049 L .22842 .4142 L .643 .737 .917 r
F
.21382 .4071 m .19252 .42001 L .21431 .43049 L F
.4766 .83329 m .47305 .8245 L .47272 .82903 L .982 .749 .508 r
F
0 g
.4766 .83329 m
.47785 .83766 L
s
.58771 .69364 m .56837 .69722 L .57187 .70132 L .656 .809 .957 r
F
.73105 .56307 m .70636 .56015 L .70174 .5707 L .654 .782 .942 r
F
.70663 .56653 m .70135 .57071 L .70197 .5771 L 0 0 .431 r
F
.70663 .56653 m .70599 .56011 L .70135 .57071 L F
0 g
.70135 .57071 m
.7021 .58102 L
s
.8601 .57973 m .85966 .56291 L .86055 .56932 L 0 0 .251 r
F
.83392 .58036 m .8601 .57973 L .86055 .56932 L .653 .784 .944 r
F
0 g
.85435 .5901 m
.8601 .57973 L
s
.64365 .68701 m .66533 .68096 L .64573 .68222 L .656 .808 .956 r
F
.78283 .46502 m .78679 .44549 L .76053 .44615 L .643 .738 .918 r
F
.60832 .58064 m .6099 .56714 L .58913 .56902 L .654 .783 .943 r
F
.66431 .57769 m .64838 .56526 L .64891 .57166 L .861 .596 .537 r
F
.66487 .58409 m .66431 .57769 L .64891 .57166 L F
0 g
.66431 .57769 m
.67545 .58566 L
s
.28874 .57111 m .26124 .57875 L .28773 .57812 L .655 .781 .941 r
F
.31477 .574 m .28874 .57111 L .28773 .57812 L F
.36711 .58264 m .39146 .5751 L .36601 .57919 L .654 .782 .942 r
F
.66377 .6987 m .66633 .68623 L .66703 .69153 L 0 0 .458 r
F
.64518 .69759 m .66377 .6987 L .66703 .69153 L .655 .81 .957 r
F
0 g
.65677 .70557 m
.66377 .6987 L
s
.43186 .83012 m .42516 .82488 L .41973 .82634 L .592 .769 .964 r
F
.43503 .82975 m .42516 .82488 L .43186 .83012 L F
.44503 .8309 m .44522 .82496 L .44185 .83016 L F
.44503 .8309 m .45161 .82647 L .44522 .82496 L F
.806 .56477 m .8287 .55425 L .80423 .56158 L .654 .782 .942 r
F
.806 .56477 m .83213 .56068 L .8287 .55425 L F
.31725 .56432 m .28907 .56474 L .31492 .56763 L .656 .781 .94 r
F
0 g
.27552 .45959 m
.29225 .45257 L
s
.27268 .46077 m
.27552 .45959 L
s
.42059 .81735 m .41118 .81282 L .40505 .81594 L .594 .768 .963 r
F
.42598 .81589 m .41118 .81282 L .42059 .81735 L F
.75617 .57234 m .72825 .57647 L .7545 .57584 L .653 .783 .943 r
F
.83392 .58036 m .86055 .56932 L .83409 .57344 L .653 .784 .944 r
F
.80772 .58098 m .83392 .58036 L .83409 .57344 L F
.41244 .46812 m .39241 .44977 L .39164 .4578 L .852 .601 .56 r
F
0 g
.41244 .46812 m
.42832 .48083 L
s
.45767 .81957 m .45883 .81298 L .45224 .81746 L .594 .768 .963 r
F
.45767 .81957 m .46699 .81616 L .45883 .81298 L F
.28874 .57111 m .26256 .56821 L .26124 .57875 L .655 .781 .941 r
F
.26245 .57465 m .26124 .57875 L .26113 .58516 L 0 0 .087 r
F
0 g
.26177 .58009 m
.26376 .5851 L
s
.26245 .57465 m .26256 .56821 L .26124 .57875 L 0 0 .087 r
F
.43503 .82975 m .43152 .82414 L .42516 .82488 L .592 .769 .964 r
F
.43844 .82976 m .43152 .82414 L .43503 .82975 L F
.44185 .83016 m .43837 .82417 L .43844 .82976 L F
.44185 .83016 m .44522 .82496 L .43837 .82417 L F
.56954 .57354 m .5522 .57395 L .55258 .58036 L .525 .341 .574 r
F
.56954 .57354 m .56914 .56713 L .5522 .57395 L F
0 g
.53907 .58256 m
.5522 .57395 L
s
.6223 .58763 m .61038 .57359 L .60879 .58705 L .653 .784 .944 r
F
.6223 .58763 m .63085 .57449 L .61038 .57359 L F
.41973 .82634 m .40408 .82492 L .41561 .8284 L .592 .769 .964 r
F
.43844 .82976 m .43837 .82417 L .43152 .82414 L F
.22593 .43039 m .2364 .45377 L .24255 .43522 L .642 .739 .919 r
F
.22593 .43039 m .21171 .44666 L .2364 .45377 L F
0 g
.2364 .45377 m
.26222 .4571 L
s
.46126 .83113 m .46647 .82517 L .45708 .82857 L .592 .769 .964 r
F
.46126 .83113 m .47272 .82903 L .46647 .82517 L F
.41065 .81728 m .40488 .81589 L .40448 .8204 L .368 .196 .511 r
F
.41065 .81728 m .41104 .81275 L .40488 .81589 L F
0 g
.40111 .81972 m
.40488 .81589 L
s
.54765 .69388 m .54854 .6955 L .54909 .70079 L .797 .578 .014 r
F
.54765 .69388 m .5471 .68856 L .54854 .6955 L F
0 g
.54854 .6955 m
.55258 .70014 L
s
.56711 .68728 m .54883 .69544 L .56799 .69189 L .656 .808 .956 r
F
.56711 .68728 m .5474 .68855 L .54883 .69544 L F
.36594 .57279 m .38577 .56227 L .3631 .5696 L .655 .781 .941 r
F
.36594 .57279 m .39135 .5687 L .38577 .56227 L F
.47305 .8245 m .47337 .81999 L .46713 .81611 L .912 .673 .564 r
F
0 g
.47337 .81999 m
.47723 .82427 L
s
.73148 .56944 m .70197 .5771 L .72825 .57647 L .653 .783 .943 r
F
.75617 .57234 m .73148 .56944 L .72825 .57647 L F
.80772 .58098 m .83409 .57344 L .80773 .57753 L .653 .784 .944 r
F
.31475 .58041 m .28767 .58453 L .31418 .5839 L .654 .782 .942 r
F
.5883 .4487 m .62721 .44635 L .59572 .43959 L .643 .737 .917 r
F
.58831 .69895 m .57245 .70661 L .59003 .70101 L .655 .81 .957 r
F
.58831 .69895 m .56895 .70253 L .57245 .70661 L F
.43205 .42067 m .43628 .42834 L .43561 .43629 L .956 .77 .318 r
F
.43205 .42067 m .43273 .41268 L .43628 .42834 L F
0 g
.43628 .42834 m
.44124 .43569 L
s
.64451 .6923 m .66633 .68623 L .64661 .6875 L .656 .809 .957 r
F
.39098 .56235 m .40815 .54856 L .38544 .55594 L .656 .781 .94 r
F
.39098 .56235 m .41632 .55826 L .40815 .54856 L F
0 g
.31756 .43194 m
.31764 .43193 L
s
.33804 .68877 m .33776 .68349 L .35309 .68157 L .675 .46 .586 r
F
.32251 .68882 m .33776 .68349 L .33804 .68877 L .732 .504 .582 r
F
.32251 .68882 m .32226 .68354 L .33776 .68349 L F
.46635 .41444 m .43675 .42829 L .4685 .42485 L .644 .737 .916 r
F
.46635 .41444 m .43323 .4127 L .43675 .42829 L F
.59504 .58829 m .58957 .57547 L .56995 .57998 L .653 .784 .944 r
F
.60879 .58705 m .58957 .57547 L .59504 .58829 L F
.75892 .56265 m .73105 .56307 L .75558 .56596 L .654 .782 .942 r
F
.33933 .67527 m .33886 .68321 L .35301 .68144 L .659 .805 .953 r
F
.33942 .67388 m .35301 .68144 L .3472 .67291 L F
.33695 .67419 m .33933 .67527 L .33942 .67388 L F
.33933 .67527 m .35301 .68144 L .33942 .67388 L F
.34326 .60664 m .34331 .60591 L .3405 .65552 L 0 0 0 r
F
.33614 .6649 m .33695 .67419 L .3472 .67291 L .659 .805 .953 r
F
.33614 .6649 m .3472 .67291 L .3413 .66425 L F
.33695 .67419 m .33775 .68335 L .33886 .68321 L F
.33695 .67419 m .33886 .68321 L .33933 .67527 L F
.32659 .67422 m .33775 .68335 L .33702 .67494 L F
.33683 .67419 m .33702 .67494 L .33695 .67419 L F
.32659 .67422 m .33702 .67494 L .33683 .67419 L F
.33535 .60579 m .33549 .60652 L .33254 .65661 L .923 .74 .252 r
F
.33456 .6649 m .33695 .67419 L .33614 .6649 L .659 .805 .953 r
F
.33092 .6649 m .33676 .6739 L .33456 .6649 L F
.33676 .6739 m .33695 .67419 L .33456 .6649 L F
.33092 .6649 m .32659 .67422 L .33695 .67419 L F
.33117 .67029 m .33723 .67959 L .33642 .67028 L .659 .806 .954 r
F
.32659 .67422 m .32232 .6834 L .33775 .68335 L .659 .805 .953 r
F
.33117 .67029 m .32681 .67962 L .33723 .67959 L .659 .806 .954 r
F
.32681 .67962 m .33804 .68877 L .33723 .67959 L F
.32681 .67962 m .32251 .68882 L .33804 .68877 L F
.33144 .67564 m .32707 .68495 L .33751 .68491 L .658 .806 .954 r
F
.3078 .68701 m .32226 .68354 L .32251 .68882 L .787 .547 .574 r
F
.3078 .68701 m .30756 .68171 L .32226 .68354 L F
.31679 .67298 m .32232 .6834 L .32659 .67422 L .659 .805 .953 r
F
.31679 .67298 m .3077 .68158 L .32232 .6834 L F
.31695 .67838 m .32251 .68882 L .32681 .67962 L .659 .806 .954 r
F
.326 .66427 m .32659 .67422 L .33092 .6649 L .659 .805 .953 r
F
.326 .66427 m .31679 .67298 L .32659 .67422 L F
.32621 .66966 m .32681 .67962 L .33117 .67029 L .659 .806 .954 r
F
.32621 .66966 m .31695 .67838 L .32681 .67962 L F
.32647 .67501 m .32707 .68495 L .33144 .67564 L .658 .806 .954 r
F
.33672 .60767 m .33781 .6081 L .33492 .65778 L .834 .575 .548 r
F
.33549 .60652 m .33596 .60714 L .33302 .6571 L .981 .727 .472 r
F
.3357 .65981 m .33092 .6649 L .33614 .6649 L .659 .805 .953 r
F
.33504 .65914 m .33092 .6649 L .3357 .65981 L F
.33531 .65826 m .33485 .65896 L .33557 .65839 L F
.33485 .65896 m .33092 .6649 L .33504 .65914 L F
.33485 .65896 m .33504 .65914 L .33557 .65839 L F
.33545 .65791 m .33525 .65823 L .33553 .65793 L F
.33525 .65823 m .33092 .6649 L .33531 .65826 L F
.33525 .65823 m .33531 .65826 L .33553 .65793 L F
.33425 .65775 m .33092 .6649 L .33545 .65791 L F
.33492 .65778 m .33545 .65791 L .33552 .6578 L F
.33425 .65775 m .33545 .65791 L .33492 .65778 L F
.33144 .67564 m .33751 .68491 L .33669 .67563 L .658 .806 .954 r
F
.33672 .60767 m .3346 .6577 L .3338 .6575 L .834 .575 .548 r
F
.33596 .60714 m .33358 .65739 L .33302 .6571 L .909 .647 .529 r
F
.33596 .60714 m .33672 .60767 L .3338 .6575 L F
.33596 .60714 m .3338 .6575 L .33358 .65739 L F
.33672 .60767 m .33492 .65778 L .3346 .6577 L .834 .575 .548 r
F
.33549 .60652 m .33289 .65697 L .33254 .65661 L .981 .727 .472 r
F
.33549 .60652 m .33302 .6571 L .33289 .65697 L F
.33535 .60579 m .33249 .65644 L .33239 .656 L .923 .74 .252 r
F
.33535 .60579 m .33254 .65661 L .33249 .65644 L F
.33581 .60487 m .33535 .60579 L .33239 .656 L 0 0 .29 r
F
.33425 .65775 m .32917 .66177 L .33092 .6649 L .659 .805 .953 r
F
.33296 .65769 m .32975 .66073 L .33425 .65775 L F
.32975 .66073 m .326 .66427 L .32917 .66177 L F
.32975 .66073 m .32917 .66177 L .33425 .65775 L F
.336 .66554 m .33117 .67029 L .33642 .67028 L .659 .806 .954 r
F
.33423 .66374 m .33117 .67029 L .336 .66554 L F
.33423 .66374 m .32853 .66748 L .33117 .67029 L F
.33452 .66313 m .33399 .66351 L .33423 .66374 L F
.33781 .6081 m .33615 .65783 L .33492 .65778 L .749 .499 .553 r
F
.33532 .65546 m .32169 .66304 L .326 .66427 L .659 .805 .953 r
F
.33532 .65546 m .32857 .65778 L .32169 .66304 L F
.32857 .65778 m .3183 .6613 L .32071 .66254 L F
.32857 .65778 m .32071 .66254 L .32169 .66304 L F
.33691 .60417 m .33581 .60487 L .33284 .65519 L .385 .194 .495 r
F
.33287 .66432 m .32853 .66748 L .33294 .66459 L .659 .806 .954 r
F
.33289 .65697 m .33262 .66212 L .33254 .65661 L .981 .727 .472 r
F
.3344 .66307 m .33391 .66343 L .33452 .66313 L .659 .806 .954 r
F
.33391 .66343 m .32853 .66748 L .33399 .66351 L F
.33391 .66343 m .33399 .66351 L .33452 .66313 L F
.33532 .65546 m .33296 .65769 L .33425 .65775 L .659 .805 .953 r
F
.33289 .65697 m .33302 .6571 L .33272 .66223 L .981 .727 .472 r
F
.33358 .65739 m .33334 .66254 L .33302 .6571 L .909 .647 .529 r
F
.33344 .66285 m .33268 .66356 L .3344 .66307 L .659 .806 .954 r
F
.33268 .66356 m .32853 .66748 L .33285 .66423 L F
.33268 .66356 m .33285 .66423 L .3344 .66307 L F
.33334 .66254 m .33292 .66233 L .33302 .6571 L .909 .647 .529 r
F
.3346 .6577 m .33438 .66284 L .3338 .6575 L .834 .575 .548 r
F
.33438 .66284 m .33379 .66269 L .3338 .6575 L F
.33302 .6571 m .33292 .66233 L .33272 .66223 L .909 .647 .529 r
F
.3338 .6575 m .33379 .66269 L .3335 .66262 L .834 .575 .548 r
F
.33492 .65778 m .33506 .66291 L .33462 .6629 L .749 .499 .553 r
F
.32853 .66748 m .32188 .66843 L .32621 .66966 L .659 .806 .954 r
F
.32917 .66177 m .32765 .66449 L .33092 .6649 L .659 .805 .953 r
F
.33557 .65839 m .33504 .65914 L .3357 .65981 L F
.33553 .65793 m .33531 .65826 L .33557 .65839 L F
.33552 .6578 m .33545 .65791 L .33553 .65793 L F
.33781 .6081 m .33949 .60833 L .33664 .65785 L .749 .499 .553 r
F
.33781 .6081 m .33664 .65785 L .33615 .65783 L F
.33806 .65949 m .33614 .6649 L .3413 .66425 L .659 .805 .953 r
F
.33642 .67028 m .33723 .67959 L .34754 .6783 L .659 .806 .954 r
F
.33642 .67028 m .34754 .6783 L .34161 .66963 L F
.33804 .68877 m .35309 .68157 L .35339 .68685 L .675 .46 .586 r
F
.33723 .67959 m .35339 .68685 L .34754 .6783 L .659 .806 .954 r
F
.33669 .67563 m .34783 .68362 L .34189 .67497 L .658 .806 .954 r
F
.33949 .60833 m .33784 .65765 L .33664 .65785 L .644 .409 .547 r
F
.34115 .60815 m .34218 .60776 L .33937 .65716 L .516 .302 .527 r
F
.34287 .60725 m .34326 .60664 L .34046 .65613 L 0 0 .355 r
F
.33906 .65809 m .3413 .66425 L .34606 .66301 L .659 .805 .953 r
F
.33883 .65841 m .3413 .66425 L .33906 .65809 L F
.33843 .65781 m .3413 .66425 L .33855 .65773 L F
.33691 .6578 m .3413 .66425 L .33832 .65757 L F
.34115 .60815 m .33937 .65716 L .33907 .65728 L .516 .302 .527 r
F
.33949 .60833 m .34115 .60815 L .33832 .65757 L .644 .409 .547 r
F
.33949 .60833 m .33832 .65757 L .33784 .65765 L F
.34218 .60776 m .33987 .65682 L .33937 .65716 L .335 .155 .483 r
F
.34115 .60815 m .33907 .65728 L .33832 .65757 L .516 .302 .527 r
F
.33532 .65546 m .34606 .66301 L .34636 .66288 L .659 .805 .953 r
F
.34279 .65839 m .34636 .66288 L .3501 .66125 L F
.33532 .65546 m .34636 .66288 L .34279 .65839 L F
.34218 .60776 m .34287 .60725 L .34007 .65668 L .335 .155 .483 r
F
.34218 .60776 m .34007 .65668 L .33987 .65682 L F
.34287 .60725 m .34035 .65629 L .34007 .65668 L 0 0 .355 r
F
.34145 .65671 m .3501 .66125 L .35314 .6591 L .659 .805 .953 r
F
.33532 .65546 m .34279 .65839 L .34145 .65671 L F
.34279 .65839 m .3501 .66125 L .34145 .65671 L F
.34287 .60725 m .34046 .65613 L .34035 .65629 L 0 0 .355 r
F
.34331 .60591 m .34273 .60498 L .3399 .65476 L .992 .745 .442 r
F
.33798 .66431 m .33642 .67028 L .34161 .66963 L .659 .806 .954 r
F
.33987 .65682 m .34007 .65668 L .33978 .6618 L .335 .155 .483 r
F
.34326 .60664 m .34049 .65569 L .34046 .65613 L 0 0 0 r
F
.34254 .65591 m .35314 .6591 L .35498 .65669 L .659 .805 .953 r
F
.33532 .65546 m .34693 .65783 L .34254 .65591 L F
.34693 .65783 m .35314 .6591 L .34254 .65591 L F
.3413 .66425 m .3472 .67291 L .35666 .67045 L F
.34002 .66392 m .34161 .66963 L .3464 .66838 L .659 .806 .954 r
F
.33885 .6631 m .33992 .66562 L .34002 .66392 L F
.33992 .66562 m .34161 .66963 L .34002 .66392 L F
.33866 .66337 m .3399 .66599 L .33885 .6631 L F
.3399 .66599 m .34161 .66963 L .33992 .66562 L F
.3399 .66599 m .33992 .66562 L .33885 .6631 L F
.34326 .60664 m .3405 .65552 L .34049 .65569 L 0 0 0 r
F
.34331 .60591 m .34007 .65498 L .3405 .65552 L .992 .745 .442 r
F
.34072 .65512 m .35498 .65669 L .35549 .65419 L .659 .805 .953 r
F
.33532 .65546 m .34254 .65591 L .34072 .65512 L F
.34254 .65591 m .35498 .65669 L .34072 .65512 L F
.34273 .60498 m .34153 .60424 L .33867 .65423 L .892 .63 .535 r
F
.33838 .66277 m .33866 .66337 L .33885 .6631 L .659 .806 .954 r
F
.34002 .66392 m .3464 .66838 L .3464 .66838 L F
.33838 .66277 m .34002 .66392 L .34002 .66392 L F
.34002 .66392 m .3464 .66838 L .34002 .66392 L F
.34049 .65569 m .3405 .65552 L .34021 .66064 L 0 0 0 r
F
.33739 .66345 m .34161 .66963 L .33838 .66277 L .659 .806 .954 r
F
.3413 .66425 m .35666 .67045 L .34606 .66301 L .659 .805 .953 r
F
.34252 .66352 m .3464 .66838 L .35046 .66662 L .659 .806 .954 r
F
.33907 .65728 m .33937 .65716 L .33908 .66228 L .516 .302 .527 r
F
.33908 .66228 m .3464 .66838 L .33921 .66223 L .659 .806 .954 r
F
.33818 .66263 m .33838 .66277 L .33908 .66228 L F
.33838 .66277 m .3464 .66838 L .33908 .66228 L F
.33723 .67959 m .33804 .68877 L .35339 .68685 L F
.33669 .67563 m .33751 .68491 L .34783 .68362 L .658 .806 .954 r
F
.33921 .66223 m .3464 .66838 L .34252 .66352 L .659 .806 .954 r
F
.33937 .65716 m .33926 .66216 L .33908 .66228 L .335 .155 .483 r
F
.33907 .65728 m .33908 .66228 L .33886 .66237 L .516 .302 .527 r
F
.34035 .65629 m .34009 .66137 L .34007 .65668 L 0 0 .355 r
F
.34009 .66137 m .33988 .66166 L .34007 .65668 L F
.34007 .65668 m .33988 .66166 L .33978 .6618 L F
.34273 .60498 m .33902 .65438 L .3399 .65476 L .892 .63 .535 r
F
.34331 .60591 m .3399 .65476 L .34007 .65498 L .992 .745 .442 r
F
.34033 .6545 m .35549 .65419 L .35463 .65177 L .659 .805 .953 r
F
.33532 .65546 m .34313 .65497 L .34033 .6545 L F
.34313 .65497 m .35549 .65419 L .34033 .6545 L F
.34077 .66224 m .34252 .66352 L .34169 .66249 L .659 .806 .954 r
F
.3374 .65852 m .33689 .66112 L .33806 .65949 L .659 .805 .953 r
F
.33689 .66112 m .33614 .6649 L .33806 .65949 L F
.33784 .65765 m .33832 .65757 L .33803 .66269 L .644 .409 .547 r
F
.33784 .65765 m .33803 .66269 L .33767 .66275 L F
.33698 .65882 m .33614 .6649 L .3374 .65852 L .659 .805 .953 r
F
.33987 .65682 m .33963 .6619 L .33937 .65716 L .335 .155 .483 r
F
.33918 .66222 m .33968 .66242 L .33961 .66192 L .659 .806 .954 r
F
.33963 .6619 m .33926 .66216 L .33937 .65716 L .335 .155 .483 r
F
.33987 .65682 m .33978 .6618 L .33963 .6619 L F
.34606 .66301 m .35666 .67045 L .36471 .66698 L .659 .805 .953 r
F
.34606 .66301 m .36471 .66698 L .3501 .66125 L F
.34036 .66179 m .35223 .66537 L .34717 .66317 L .659 .806 .954 r
F
.33832 .65757 m .3383 .66259 L .33803 .66269 L .516 .302 .527 r
F
.33768 .66945 m .33669 .67563 L .33936 .67529 L .658 .806 .954 r
F
.33737 .66839 m .33721 .67009 L .33768 .66945 L F
.33721 .67009 m .33669 .67563 L .33768 .66945 L F
.33789 .66915 m .33936 .67529 L .33958 .6716 L F
.33737 .66839 m .33768 .66945 L .33789 .66915 L F
.33768 .66945 m .33936 .67529 L .33789 .66915 L F
.33855 .65773 m .33883 .65841 L .33906 .65809 L .659 .805 .953 r
F
.33832 .65757 m .33843 .65781 L .33855 .65773 L F
.33907 .65728 m .33886 .66237 L .33832 .65757 L .516 .302 .527 r
F
.33688 .65813 m .33614 .6649 L .33708 .65805 L .659 .805 .953 r
F
.33554 .65803 m .33614 .6649 L .33691 .6578 L F
.33822 .66266 m .33739 .66345 L .33838 .66277 L .659 .806 .954 r
F
.33664 .65785 m .33677 .6629 L .33634 .66297 L .644 .409 .547 r
F
.33699 .66286 m .33739 .66345 L .33822 .66266 L .659 .806 .954 r
F
.33699 .66286 m .33612 .66689 L .33798 .66431 L F
.33579 .66306 m .33612 .66689 L .33696 .66299 L F
.33634 .66297 m .33696 .66299 L .33699 .66286 L F
.33579 .66306 m .33696 .66299 L .33634 .66297 L F
.33615 .65783 m .33664 .65785 L .33634 .66297 L .749 .499 .553 r
F
.33615 .65783 m .33634 .66297 L .33597 .66295 L F
.33612 .66689 m .33642 .67028 L .33798 .66431 L .659 .806 .954 r
F
.3375 .66786 m .3369 .66796 L .33677 .6629 L .644 .409 .547 r
F
.33706 .66285 m .33677 .6629 L .33664 .65785 L F
.3375 .66786 m .33677 .6629 L .33706 .66285 L F
.33615 .65783 m .33597 .66295 L .33492 .65778 L .749 .499 .553 r
F
.33559 .66082 m .33579 .66306 L .33699 .66286 L .659 .806 .954 r
F
.33597 .66295 m .33634 .66297 L .33604 .6681 L .749 .499 .553 r
F
.33597 .66295 m .33506 .66291 L .33492 .65778 L F
.3358 .66319 m .33423 .66374 L .336 .66554 L .659 .806 .954 r
F
.33559 .66082 m .33462 .6629 L .3358 .66319 L F
.33462 .6629 m .33423 .66374 L .3358 .66319 L F
.3346 .6577 m .33492 .65778 L .33462 .6629 L .834 .575 .548 r
F
.33344 .66285 m .3344 .66307 L .334 .66287 L .659 .806 .954 r
F
.33462 .6629 m .3344 .66307 L .33452 .66313 L F
.33268 .66356 m .33075 .66351 L .32853 .66748 L F
.33344 .66285 m .33256 .66306 L .33268 .66356 L F
.33256 .66306 m .33075 .66351 L .33268 .66356 L F
.32857 .65778 m .31606 .65914 L .3183 .6613 L .659 .805 .953 r
F
.33532 .65546 m .33104 .65628 L .32857 .65778 L F
.33104 .65628 m .31606 .65914 L .32857 .65778 L F
.3346 .6577 m .33462 .6629 L .33438 .66284 L .834 .575 .548 r
F
.33362 .66268 m .33205 .66279 L .33344 .66285 L .659 .806 .954 r
F
.33358 .65739 m .3338 .6575 L .3335 .66262 L .909 .647 .529 r
F
.33358 .65739 m .3335 .66262 L .33334 .66254 L F
.33559 .66082 m .3329 .66232 L .33362 .66268 L .659 .806 .954 r
F
.3329 .66232 m .33205 .66279 L .33362 .66268 L F
.33613 .66922 m .33144 .67564 L .33669 .67563 L .658 .806 .954 r
F
.33571 .66901 m .33506 .67002 L .33613 .66922 L F
.33506 .67002 m .33144 .67564 L .33534 .6703 L F
.33506 .67002 m .33534 .6703 L .33613 .66922 L F
.33205 .66279 m .33075 .66351 L .33344 .66285 L .659 .806 .954 r
F
.33289 .65697 m .33272 .66223 L .33262 .66212 L .981 .727 .472 r
F
.33262 .66212 m .33236 .66186 L .33254 .65661 L F
.33581 .60487 m .33251 .65578 L .33284 .65519 L 0 0 .29 r
F
.33581 .60487 m .33239 .656 L .33251 .65578 L F
.32243 .65792 m .31512 .65673 L .31606 .65914 L .659 .805 .953 r
F
.33532 .65546 m .32951 .65583 L .32243 .65792 L F
.32951 .65583 m .31512 .65673 L .32243 .65792 L F
.33804 .60387 m .33691 .60417 L .33396 .65451 L .57 .346 .536 r
F
.33559 .66082 m .33146 .66223 L .33075 .66351 L .659 .806 .954 r
F
.33518 .66824 m .33477 .66854 L .33607 .66846 L .658 .806 .954 r
F
.33477 .66854 m .33571 .66901 L .33607 .66846 L F
.33607 .66846 m .33571 .66901 L .33613 .66922 L F
.33603 .6681 m .33494 .66818 L .33607 .66846 L F
.33597 .66295 m .3358 .66809 L .33506 .66291 L .749 .499 .553 r
F
.3358 .66809 m .3352 .66807 L .33506 .66291 L F
.33499 .66806 m .33494 .66818 L .33603 .6681 L .658 .806 .954 r
F
.33494 .66818 m .33488 .66829 L .33518 .66824 L F
.33488 .66829 m .33477 .66854 L .33518 .66824 L F
.3322 .66161 m .33212 .66129 L .33239 .656 L .923 .74 .252 r
F
.32917 .66177 m .326 .66427 L .32765 .66449 L .659 .805 .953 r
F
.32169 .66304 m .31679 .67298 L .326 .66427 L F
.32169 .66304 m .3082 .67055 L .31679 .67298 L F
.3183 .6613 m .3082 .67055 L .32169 .66304 L F
.33229 .66195 m .31882 .66402 L .31847 .66668 L .659 .806 .954 r
F
.33249 .65644 m .3322 .66161 L .33239 .656 L .923 .74 .252 r
F
.33249 .65644 m .33254 .65661 L .33223 .66173 L F
.33249 .65644 m .33223 .66173 L .3322 .66161 L F
.33254 .65661 m .33236 .66186 L .33223 .66173 L .981 .727 .472 r
F
.33559 .66082 m .33217 .66148 L .33229 .66195 L .659 .806 .954 r
F
.33217 .66148 m .31882 .66402 L .33229 .66195 L F
.31882 .66402 m .31621 .66452 L .31643 .66473 L F
.31882 .66402 m .31643 .66473 L .31847 .66668 L F
.32951 .65583 m .31555 .65422 L .31512 .65673 L .659 .805 .953 r
F
.33532 .65546 m .33154 .65523 L .32951 .65583 L F
.33154 .65523 m .31555 .65422 L .32951 .65583 L F
.33439 .66934 m .33144 .67564 L .33506 .67002 L .658 .806 .954 r
F
.33462 .6629 m .33462 .6629 L .33462 .6629 L .659 .806 .954 r
F
.33506 .66291 m .3352 .66807 L .33462 .6629 L .749 .499 .553 r
F
.33318 .67193 m .32647 .67501 L .33144 .67564 L .658 .806 .954 r
F
.334 .66287 m .3344 .66307 L .33462 .6629 L .659 .806 .954 r
F
.33344 .66285 m .33462 .6629 L .33462 .6629 L F
.33399 .66351 m .33287 .66432 L .33423 .66374 L F
.33287 .66432 m .33294 .66459 L .33423 .66374 L F
.33438 .66284 m .33417 .66799 L .33379 .66269 L .834 .575 .548 r
F
.33477 .66854 m .33269 .66994 L .33318 .67193 L .658 .806 .954 r
F
.33494 .66818 m .33459 .66845 L .33477 .66854 L F
.33459 .66845 m .33269 .66994 L .33477 .66854 L F
.33292 .66233 m .33282 .66757 L .33272 .66223 L .909 .647 .529 r
F
.33486 .66817 m .33269 .66994 L .33494 .66818 L .658 .806 .954 r
F
.33269 .66994 m .32647 .67501 L .33318 .67193 L F
.33254 .66932 m .3273 .67423 L .33268 .66992 L F
.3273 .67423 m .3272 .67442 L .33269 .66994 L F
.33268 .66992 m .33269 .66994 L .33486 .66817 L F
.33268 .66992 m .33486 .66817 L .33486 .66817 L F
.33393 .66802 m .33386 .66808 L .33499 .66806 L F
.33386 .66808 m .33254 .66932 L .33441 .66836 L F
.33386 .66808 m .33441 .66836 L .33499 .66806 L F
.3273 .67423 m .33269 .66994 L .33268 .66992 L F
.33559 .66082 m .33344 .66285 L .33462 .6629 L .659 .806 .954 r
F
.3335 .66262 m .33359 .66785 L .3332 .66776 L .834 .575 .548 r
F
.33417 .66799 m .33377 .6679 L .33379 .66269 L F
.3352 .66807 m .33491 .66806 L .33462 .6629 L .749 .499 .553 r
F
.33334 .66254 m .3335 .66262 L .3332 .66776 L .909 .647 .529 r
F
.33334 .66254 m .3332 .66776 L .33309 .6677 L F
.33438 .66284 m .33462 .6629 L .33432 .66803 L .834 .575 .548 r
F
.33438 .66284 m .33432 .66803 L .33417 .66799 L F
.3273 .67423 m .32214 .67379 L .32647 .67501 L .658 .806 .954 r
F
.3322 .66161 m .33223 .66173 L .33193 .66687 L .923 .74 .252 r
F
.32853 .66748 m .32723 .66979 L .33117 .67029 L .659 .806 .954 r
F
.33254 .66932 m .33 .66944 L .3273 .67423 L .658 .806 .954 r
F
.33226 .66819 m .33 .66944 L .33254 .66932 L F
.33272 .66223 m .33269 .6675 L .33242 .66737 L .909 .647 .529 r
F
.33282 .66757 m .33269 .6675 L .33272 .66223 L F
.33334 .66254 m .33309 .6677 L .33292 .66233 L F
.32853 .66748 m .32621 .66966 L .32723 .66979 L .659 .806 .954 r
F
.32188 .66843 m .31695 .67838 L .32621 .66966 L F
.33289 .66784 m .32465 .67002 L .32214 .67379 L .658 .806 .954 r
F
.33284 .66779 m .32465 .67002 L .33289 .66784 L F
.33236 .66186 m .33218 .66713 L .33223 .66173 L .981 .727 .472 r
F
.33243 .66737 m .33086 .6679 L .3328 .66774 L .658 .806 .954 r
F
.33086 .6679 m .33058 .66841 L .33312 .66772 L F
.33218 .66713 m .3321 .66705 L .33223 .66173 L .981 .727 .472 r
F
.33223 .66173 m .3321 .66705 L .33193 .66687 L F
.33262 .66212 m .33235 .6673 L .33236 .66186 L F
.33235 .6673 m .33218 .66713 L .33236 .66186 L F
.3082 .67055 m .3077 .68158 L .31679 .67298 L .659 .805 .953 r
F
.32188 .66843 m .3083 .67596 L .31695 .67838 L .659 .806 .954 r
F
.31847 .66668 m .3083 .67596 L .32188 .66843 L F
.32465 .67002 m .31646 .66989 L .31872 .67204 L .658 .806 .954 r
F
.33262 .66212 m .33272 .66223 L .33242 .66737 L .981 .727 .472 r
F
.33262 .66212 m .33242 .66737 L .33235 .6673 L F
.33309 .6677 m .33282 .66757 L .33292 .66233 L .909 .647 .529 r
F
.33379 .66269 m .33377 .6679 L .3335 .66262 L .834 .575 .548 r
F
.33377 .6679 m .33359 .66785 L .3335 .66262 L F
.33393 .66802 m .33226 .66819 L .33254 .66932 L .658 .806 .954 r
F
.33462 .6629 m .33491 .66806 L .33432 .66803 L .749 .499 .553 r
F
.33587 .6662 m .33267 .66796 L .33393 .66802 L .658 .806 .954 r
F
.33267 .66796 m .33226 .66819 L .33393 .66802 L F
.33254 .66932 m .33268 .66992 L .33499 .66806 L F
.33477 .66854 m .33439 .66934 L .33571 .66901 L F
.33439 .66934 m .33506 .67002 L .33571 .66901 L F
.33432 .66803 m .33547 .67809 L .33375 .67786 L .749 .499 .553 r
F
.33486 .66817 m .33486 .66817 L .33499 .66806 L .658 .806 .954 r
F
.33491 .66806 m .33547 .67809 L .33432 .66803 L .749 .499 .553 r
F
.33377 .6679 m .33375 .67786 L .33359 .66785 L .834 .575 .548 r
F
.3183 .6613 m .3014 .66709 L .3082 .67055 L .659 .805 .953 r
F
.31606 .65914 m .3014 .66709 L .3183 .6613 L F
.31882 .66402 m .31526 .6621 L .31621 .66452 L .659 .806 .954 r
F
.33239 .656 m .33212 .66129 L .33208 .66113 L .923 .74 .252 r
F
.33251 .65578 m .33239 .656 L .33208 .66113 L 0 0 .29 r
F
.33251 .65578 m .33208 .66113 L .33218 .66096 L F
.33691 .60417 m .33284 .65519 L .33315 .655 L .385 .194 .495 r
F
.32847 .65503 m .31734 .65179 L .31555 .65422 L .659 .805 .953 r
F
.33532 .65546 m .33137 .65466 L .32847 .65503 L F
.33137 .65466 m .31734 .65179 L .32847 .65503 L F
.33919 .60379 m .33804 .60387 L .33512 .65417 L .663 .424 .548 r
F
.33559 .66082 m .33124 .6611 L .3299 .66191 L .659 .806 .954 r
F
.33587 .6662 m .3308 .66716 L .3321 .66748 L .658 .806 .954 r
F
.33587 .6662 m .33243 .66737 L .33312 .66772 L F
.33587 .6662 m .33393 .66802 L .33499 .66806 L F
.33532 .65546 m .33691 .6578 L .33832 .65757 L .659 .805 .953 r
F
.33532 .65546 m .33554 .65803 L .33691 .6578 L F
.33532 .65546 m .33425 .65775 L .33552 .6578 L F
.33691 .60417 m .33315 .655 L .33396 .65451 L .385 .194 .495 r
F
.33532 .65546 m .32037 .6496 L .31734 .65179 L .659 .805 .953 r
F
.33532 .65546 m .32443 .64781 L .32037 .6496 L F
.33804 .60387 m .33428 .65441 L .33512 .65417 L .57 .346 .536 r
F
.33804 .60387 m .33396 .65451 L .33428 .65441 L F
.33532 .65546 m .32925 .64654 L .32443 .64781 L .659 .805 .953 r
F
.33919 .60379 m .33512 .65417 L .33544 .65412 L .663 .424 .548 r
F
.33532 .65546 m .33448 .64588 L .32925 .64654 L .659 .805 .953 r
F
.34153 .60424 m .33781 .65408 L .33867 .65423 L .802 .546 .551 r
F
.34273 .60498 m .33867 .65423 L .33902 .65438 L .892 .63 .535 r
F
.34153 .60424 m .34035 .6039 L .33747 .65403 L .802 .546 .551 r
F
.34153 .60424 m .33747 .65403 L .33781 .65408 L F
.33499 .66806 m .33486 .66817 L .33494 .66818 L .658 .806 .954 r
F
.3352 .66807 m .33547 .67809 L .33491 .66806 L .749 .499 .553 r
F
.33587 .6662 m .33499 .66806 L .33603 .6681 L .658 .806 .954 r
F
.3358 .66809 m .33547 .67809 L .3352 .66807 L .749 .499 .553 r
F
.33706 .66794 m .33613 .66924 L .33737 .66839 L .658 .806 .954 r
F
.33603 .6681 m .33613 .66924 L .33706 .66794 L F
.33613 .66924 m .33669 .67563 L .33737 .66839 L F
.33604 .6681 m .33716 .67791 L .33547 .67809 L .644 .409 .547 r
F
.33634 .66297 m .33662 .66801 L .33604 .6681 L F
.33662 .66801 m .33716 .67791 L .33604 .6681 L F
.33597 .66295 m .33604 .6681 L .3358 .66809 L .749 .499 .553 r
F
.33677 .6629 m .3369 .66796 L .33634 .66297 L .644 .409 .547 r
F
.3369 .66796 m .33716 .67791 L .33662 .66801 L F
.3369 .66796 m .33662 .66801 L .33634 .66297 L F
.33708 .65805 m .33698 .65882 L .3374 .65852 L .659 .805 .953 r
F
.33691 .6578 m .33688 .65813 L .33708 .65805 L F
.33784 .65765 m .33767 .66275 L .33664 .65785 L .644 .409 .547 r
F
.33767 .66275 m .33706 .66285 L .33664 .65785 L F
.33886 .66237 m .3383 .66259 L .33832 .65757 L .516 .302 .527 r
F
.33559 .66082 m .33985 .66199 L .34036 .66179 L .659 .806 .954 r
F
.33963 .6619 m .33939 .66701 L .33926 .66216 L .335 .155 .483 r
F
.3472 .67291 m .35301 .68144 L .36711 .6778 L .659 .805 .953 r
F
.3472 .67291 m .36711 .6778 L .35666 .67045 L F
.34161 .66963 m .34754 .6783 L .35706 .67584 L .659 .806 .954 r
F
.33974 .66889 m .34189 .67497 L .34669 .67373 L .658 .806 .954 r
F
.33985 .66199 m .35223 .66537 L .34036 .66179 L .659 .806 .954 r
F
.33961 .66192 m .33968 .66242 L .34077 .66224 L F
.33968 .66242 m .34252 .66352 L .34077 .66224 L F
.34046 .65613 m .34018 .6611 L .34017 .66126 L 0 0 0 r
F
.34035 .65629 m .34046 .65613 L .34017 .66126 L 0 0 .355 r
F
.34035 .65629 m .34017 .66126 L .34009 .66137 L F
.33559 .66082 m .34717 .66317 L .3429 .66132 L .659 .806 .954 r
F
.3501 .66125 m .36471 .66698 L .37081 .66271 L .659 .805 .953 r
F
.34279 .66127 m .3553 .66216 L .35421 .66197 L .659 .806 .954 r
F
.33559 .66082 m .3429 .66132 L .34279 .66127 L F
.3429 .66132 m .3553 .66216 L .34279 .66127 L F
.33945 .65404 m .35463 .65177 L .35244 .64959 L .659 .805 .953 r
F
.33532 .65546 m .34257 .65407 L .33945 .65404 L F
.34257 .65407 m .35463 .65177 L .33945 .65404 L F
.33767 .66275 m .3375 .66786 L .33706 .66285 L .644 .409 .547 r
F
.33926 .66216 m .33915 .66718 L .33908 .66228 L .335 .155 .483 r
F
.33988 .66166 m .33969 .66666 L .33978 .6618 L 0 0 .355 r
F
.33823 .66868 m .33961 .67105 L .33842 .66842 L .658 .806 .954 r
F
.33961 .67105 m .33963 .67066 L .33816 .66785 L F
.33963 .6619 m .33978 .6618 L .33949 .66694 L .335 .155 .483 r
F
.33737 .66839 m .33958 .6716 L .33785 .66806 L .658 .806 .954 r
F
.33958 .6716 m .33961 .67105 L .33774 .66783 L F
.33863 .66812 m .33964 .6706 L .33974 .66889 L F
.33847 .66835 m .33964 .6706 L .33863 .66812 L F
.33816 .66785 m .34189 .67497 L .3382 .66782 L F
.33886 .66237 m .33864 .66748 L .3383 .66259 L .516 .302 .527 r
F
.33864 .66748 m .33827 .66762 L .3383 .66259 L F
.33767 .66275 m .33803 .66269 L .33774 .66783 L .644 .409 .547 r
F
.33737 .66839 m .33785 .66806 L .33774 .66783 L .658 .806 .954 r
F
.3375 .66786 m .33774 .66783 L .33716 .67791 L .644 .409 .547 r
F
.33767 .66275 m .33774 .66783 L .3375 .66786 L F
.35314 .6591 m .37081 .66271 L .37455 .65792 L .659 .805 .953 r
F
.3501 .66125 m .37081 .66271 L .35314 .6591 L F
.34404 .66029 m .35538 .66205 L .3559 .65954 L .659 .806 .954 r
F
.34049 .65569 m .34021 .66064 L .3402 .66077 L 0 0 0 r
F
.34049 .65569 m .3402 .66077 L .34046 .65613 L F
.3402 .66077 m .34018 .6611 L .34046 .65613 L F
.3405 .65552 m .34006 .66045 L .34021 .66064 L .992 .745 .442 r
F
.33559 .66082 m .35421 .66197 L .34404 .66029 L .659 .806 .954 r
F
.35421 .66197 m .35538 .66205 L .34404 .66029 L F
.33803 .66269 m .33809 .66769 L .33774 .66783 L .516 .302 .527 r
F
.3389 .66738 m .33812 .66776 L .33937 .66756 L .658 .806 .954 r
F
.3383 .66259 m .33827 .66762 L .33803 .66269 L .516 .302 .527 r
F
.33827 .66762 m .33809 .66769 L .33803 .66269 L F
.33908 .66228 m .33903 .66726 L .33879 .66742 L .335 .155 .483 r
F
.33804 .66771 m .33812 .66776 L .3389 .66738 L .658 .806 .954 r
F
.34161 .66963 m .35706 .67584 L .3464 .66838 L .659 .806 .954 r
F
.33812 .66776 m .34582 .67313 L .33937 .66756 L .658 .806 .954 r
F
.34582 .67313 m .34669 .67373 L .3455 .67273 L F
.34582 .67313 m .3455 .67273 L .33937 .66756 L F
.33937 .66756 m .3455 .67273 L .34224 .66867 L F
.33886 .66237 m .33908 .66228 L .33879 .66742 L .516 .302 .527 r
F
.33864 .66748 m .33879 .66742 L .33822 .67753 L F
.33886 .66237 m .33879 .66742 L .33864 .66748 L F
.3464 .66838 m .3464 .66838 L .34252 .66352 L .659 .806 .954 r
F
.3464 .66838 m .3464 .66838 L .3464 .66838 L F
.35666 .67045 m .36711 .6778 L .37916 .67264 L .659 .805 .953 r
F
.3464 .66838 m .35706 .67584 L .36516 .67235 L .659 .806 .954 r
F
.35666 .67045 m .37916 .67264 L .36471 .66698 L .659 .805 .953 r
F
.3464 .66838 m .36516 .67235 L .35046 .66662 L .659 .806 .954 r
F
.33987 .667 m .35076 .67197 L .35383 .66982 L .658 .806 .954 r
F
.33963 .6619 m .33949 .66694 L .33939 .66701 L .335 .155 .483 r
F
.33915 .66718 m .33903 .66726 L .33908 .66228 L F
.33939 .66701 m .33915 .66718 L .33926 .66216 L F
.33587 .6662 m .3389 .66738 L .33987 .667 L .658 .806 .954 r
F
.33559 .66082 m .33918 .66222 L .33961 .66192 L .659 .806 .954 r
F
.33789 .65403 m .35244 .64959 L .34907 .64781 L .659 .805 .953 r
F
.33532 .65546 m .33945 .65404 L .33789 .65403 L F
.33945 .65404 m .35244 .64959 L .33789 .65403 L F
.34035 .6039 m .33919 .60379 L .33629 .65401 L .733 .485 .553 r
F
.33559 .66082 m .34404 .66029 L .34365 .66023 L .659 .806 .954 r
F
.34007 .65498 m .33974 .66005 L .3405 .65552 L .992 .745 .442 r
F
.33974 .66005 m .34006 .66045 L .3405 .65552 L F
.34007 .65498 m .33961 .65989 L .33974 .66005 L F
.33559 .66082 m .35582 .65932 L .34401 .65922 L .659 .806 .954 r
F
.33559 .66082 m .33699 .66286 L .33822 .66266 L F
.33559 .66082 m .33818 .66263 L .33921 .66223 L F
.34035 .6039 m .33629 .65401 L .33661 .65402 L .733 .485 .553 r
F
.34035 .6039 m .33661 .65402 L .33747 .65403 L F
.33919 .60379 m .33544 .65412 L .33629 .65401 L .663 .424 .548 r
F
.33597 .65406 m .34475 .64654 L .33977 .64588 L .659 .805 .953 r
F
.33532 .65546 m .33694 .65393 L .33597 .65406 L F
.33694 .65393 m .34475 .64654 L .33597 .65406 L F
.33532 .65546 m .34907 .64781 L .34475 .64654 L F
.33075 .66351 m .32661 .66389 L .32188 .66843 L .659 .806 .954 r
F
.32661 .66389 m .31847 .66668 L .32038 .66766 L F
.32661 .66389 m .32038 .66766 L .32188 .66843 L F
.33075 .66351 m .32188 .66843 L .32853 .66748 L F
.3082 .67055 m .29484 .67799 L .3077 .68158 L .659 .805 .953 r
F
.3014 .66709 m .29484 .67799 L .3082 .67055 L F
.31847 .66668 m .30145 .67249 L .3083 .67596 L .659 .806 .954 r
F
.31621 .66452 m .30145 .67249 L .31847 .66668 L F
.32876 .66755 m .31551 .66749 L .31646 .66989 L .658 .806 .954 r
F
.3322 .66161 m .33193 .66687 L .33191 .66679 L .923 .74 .252 r
F
.33212 .66129 m .33186 .66659 L .33208 .66113 L F
.33186 .66659 m .33183 .66648 L .33208 .66113 L F
.33208 .66113 m .33183 .66648 L .33178 .66627 L F
.3322 .66161 m .33191 .66679 L .33212 .66129 L F
.33191 .66679 m .33186 .66659 L .33212 .66129 L F
.33587 .6662 m .33044 .66654 L .32876 .66755 L .658 .806 .954 r
F
.33044 .66654 m .31551 .66749 L .32876 .66755 L F
.33428 .65441 m .3339 .65957 L .33512 .65417 L .57 .346 .536 r
F
.33251 .65578 m .33218 .66096 L .33284 .65519 L 0 0 .29 r
F
.33218 .66096 m .33242 .66053 L .33284 .65519 L F
.33124 .6611 m .33068 .66052 L .32804 .6613 L .659 .806 .954 r
F
.33559 .66082 m .33206 .6606 L .33124 .6611 L F
.33206 .6606 m .33068 .66052 L .33124 .6611 L F
.33315 .655 m .33284 .65519 L .33254 .66031 L .385 .194 .495 r
F
.3308 .66716 m .32876 .66755 L .3321 .66748 L .658 .806 .954 r
F
.33218 .66713 m .33186 .67693 L .3321 .66705 L .981 .727 .472 r
F
.3321 .66748 m .33109 .6675 L .33086 .6679 L .658 .806 .954 r
F
.33193 .66687 m .33186 .67693 L .33137 .67632 L .981 .727 .472 r
F
.3321 .66705 m .33186 .67693 L .33193 .66687 L F
.33235 .6673 m .33186 .67693 L .33218 .66713 L F
.33315 .655 m .33254 .66031 L .33277 .66018 L .385 .194 .495 r
F
.31606 .65914 m .29685 .66282 L .3014 .66709 L .659 .805 .953 r
F
.31512 .65673 m .29685 .66282 L .31606 .65914 L F
.32712 .6603 m .3175 .65715 L .3157 .65959 L .659 .806 .954 r
F
.33284 .65519 m .33242 .66053 L .33254 .66031 L 0 0 .29 r
F
.33559 .66082 m .3307 .65983 L .32712 .6603 L .659 .806 .954 r
F
.3307 .65983 m .3175 .65715 L .32712 .6603 L F
.33532 .65546 m .33609 .6538 L .33516 .65364 L .659 .805 .953 r
F
.33544 .65412 m .33505 .65926 L .33629 .65401 L .663 .424 .548 r
F
.3307 .65983 m .32055 .65496 L .3175 .65715 L .659 .806 .954 r
F
.33315 .655 m .33277 .66018 L .33396 .65451 L .385 .194 .495 r
F
.33277 .66018 m .33337 .65982 L .33396 .65451 L F
.33559 .66082 m .33246 .6596 L .3307 .65983 L .659 .806 .954 r
F
.33246 .6596 m .32055 .65496 L .3307 .65983 L F
.33544 .65412 m .33512 .65417 L .33482 .6593 L .663 .424 .548 r
F
.33428 .65441 m .33396 .65451 L .33366 .65964 L .57 .346 .536 r
F
.33428 .65441 m .33366 .65964 L .3339 .65957 L F
.33396 .65451 m .33337 .65982 L .33366 .65964 L .385 .194 .495 r
F
.33559 .66082 m .32464 .65316 L .32055 .65496 L .659 .806 .954 r
F
.3339 .65957 m .33451 .65939 L .33512 .65417 L .57 .346 .536 r
F
.33512 .65417 m .33451 .65939 L .33482 .6593 L F
.33559 .66082 m .32948 .65189 L .32464 .65316 L .659 .806 .954 r
F
.33544 .65412 m .33482 .6593 L .33505 .65926 L .663 .424 .548 r
F
.33505 .65926 m .33568 .65918 L .33629 .65401 L F
.33559 .66082 m .33475 .65123 L .32948 .65189 L .659 .806 .954 r
F
.33277 .66018 m .33254 .66031 L .33224 .66546 L .385 .194 .495 r
F
.33218 .66096 m .33184 .66616 L .33242 .66053 L 0 0 .29 r
F
.33184 .66616 m .332 .66588 L .33242 .66053 L F
.33218 .66096 m .33208 .66113 L .33178 .66627 L F
.33218 .66096 m .33178 .66627 L .33184 .66616 L F
.33587 .6662 m .33145 .66593 L .33044 .66654 L .658 .806 .954 r
F
.3299 .66191 m .32804 .6613 L .31882 .66402 L .659 .806 .954 r
F
.32804 .6613 m .31526 .6621 L .31882 .66402 L F
.32576 .66558 m .31776 .66255 L .31595 .66498 L .658 .806 .954 r
F
.3339 .65957 m .33351 .66474 L .33451 .65939 L .57 .346 .536 r
F
.33242 .66053 m .332 .66588 L .33254 .66031 L 0 0 .29 r
F
.332 .66588 m .33207 .66575 L .33254 .66031 L F
.33254 .66031 m .33207 .66575 L .33224 .66546 L F
.33587 .6662 m .33152 .66532 L .32981 .66583 L .658 .806 .954 r
F
.3332 .66776 m .33375 .67786 L .33263 .67745 L .834 .575 .548 r
F
.33359 .66785 m .33375 .67786 L .3332 .66776 L F
.33277 .66018 m .33224 .66546 L .33238 .66537 L .385 .194 .495 r
F
.32804 .6613 m .32712 .6603 L .31526 .6621 L .659 .806 .954 r
F
.32712 .6603 m .3157 .65959 L .31531 .66183 L F
.32712 .6603 m .31531 .66183 L .31526 .6621 L F
.33146 .66223 m .32661 .66389 L .33075 .66351 L F
.33004 .66502 m .32081 .66036 L .31776 .66255 L .658 .806 .954 r
F
.33277 .66018 m .33238 .66537 L .33337 .65982 L .385 .194 .495 r
F
.33238 .66537 m .33277 .66514 L .33337 .65982 L F
.33337 .65982 m .33277 .66514 L .33366 .65964 L F
.33277 .66514 m .33296 .66502 L .33366 .65964 L F
.33587 .6662 m .33271 .66497 L .33152 .66532 L .658 .806 .954 r
F
.33417 .66799 m .33375 .67786 L .33377 .6679 L .834 .575 .548 r
F
.33309 .6677 m .3332 .66776 L .33263 .67745 L .909 .647 .529 r
F
.33284 .6739 m .33282 .67402 L .33283 .67401 L .57 .346 .536 r
F
.33417 .66799 m .33432 .66803 L .33375 .67786 L .834 .575 .548 r
F
.33284 .6739 m .33283 .67401 L .33398 .67372 L .57 .346 .536 r
F
.33351 .66474 m .33391 .66462 L .33451 .65939 L F
.33068 .66052 m .32712 .6603 L .32804 .6613 L .659 .806 .954 r
F
.33124 .6611 m .32804 .6613 L .3299 .66191 L F
.33213 .66475 m .3249 .65856 L .32081 .66036 L .658 .806 .954 r
F
.33451 .65939 m .33391 .66462 L .33482 .6593 L .57 .346 .536 r
F
.33587 .6662 m .33369 .66468 L .33271 .66497 L .658 .806 .954 r
F
.33391 .66462 m .3341 .66456 L .33482 .6593 L .57 .346 .536 r
F
.33482 .6593 m .3341 .66456 L .33452 .66444 L F
.33505 .65926 m .33482 .6593 L .33452 .66444 L .663 .424 .548 r
F
.33505 .65926 m .33452 .66444 L .33467 .66442 L F
.33366 .65964 m .33296 .66502 L .33336 .66478 L .385 .194 .495 r
F
.33309 .66427 m .32975 .65729 L .3249 .65856 L .658 .806 .954 r
F
.3339 .65957 m .33366 .65964 L .33336 .66478 L .57 .346 .536 r
F
.33351 .66474 m .33336 .66478 L .33282 .67402 L F
.3339 .65957 m .33336 .66478 L .33351 .66474 L F
.33369 .66468 m .33455 .66428 L .33309 .66427 L .658 .806 .954 r
F
.33587 .6662 m .33464 .66441 L .33369 .66468 L F
.33464 .66441 m .33455 .66428 L .33369 .66468 L F
.33455 .66428 m .32975 .65729 L .33309 .66427 L F
.33661 .65402 m .33629 .65401 L .33599 .65914 L .733 .485 .553 r
F
.33661 .65402 m .33599 .65914 L .33615 .65914 L F
.33559 .66082 m .33638 .65915 L .33545 .65914 L .659 .806 .954 r
F
.33559 .66082 m .33736 .65916 L .33638 .65915 L F
.33781 .65408 m .33742 .6592 L .33867 .65423 L .802 .546 .551 r
F
.33742 .6592 m .33807 .6593 L .33867 .65423 L F
.33867 .65423 m .33807 .6593 L .33838 .65935 L F
.33902 .65438 m .33864 .65946 L .3399 .65476 L .892 .63 .535 r
F
.33864 .65946 m .33929 .65975 L .3399 .65476 L F
.3399 .65476 m .33929 .65975 L .33961 .65989 L F
.33781 .65408 m .33718 .65915 L .33742 .6592 L .802 .546 .551 r
F
.33902 .65438 m .33867 .65423 L .33838 .65935 L .892 .63 .535 r
F
.33902 .65438 m .33838 .65935 L .33864 .65946 L F
.34007 .65498 m .3399 .65476 L .33961 .65989 L .992 .745 .442 r
F
.33736 .65916 m .34944 .65314 L .34509 .65188 L .659 .806 .954 r
F
.33559 .66082 m .33858 .65917 L .33736 .65916 L F
.33858 .65917 m .34944 .65314 L .33736 .65916 L F
.33661 .65402 m .33623 .65915 L .33747 .65403 L .733 .485 .553 r
F
.33587 .6662 m .33804 .66771 L .3389 .66738 L .658 .806 .954 r
F
.33587 .6662 m .33706 .66794 L .33774 .66783 L F
.33587 .6662 m .33774 .66783 L .33804 .66771 L F
.33587 .6662 m .33603 .6681 L .33706 .66794 L F
.33559 .66082 m .35283 .65493 L .34944 .65314 L .659 .806 .954 r
F
.35314 .6591 m .37455 .65792 L .35498 .65669 L .659 .805 .953 r
F
.33559 .66082 m .35503 .65711 L .35283 .65493 L .659 .806 .954 r
F
.33623 .65915 m .33585 .66429 L .33686 .65915 L .733 .485 .553 r
F
.33969 .66666 m .33963 .66675 L .33978 .6618 L 0 0 .355 r
F
.36471 .66698 m .37916 .67264 L .38834 .66628 L .659 .805 .953 r
F
.35046 .66662 m .36516 .67235 L .37131 .66807 L .659 .806 .954 r
F
.34304 .66664 m .35383 .66982 L .35568 .66741 L .658 .806 .954 r
F
.34009 .66137 m .33988 .66639 L .33983 .66647 L 0 0 .355 r
F
.34009 .66137 m .33983 .66647 L .33988 .66166 L F
.33983 .66647 m .33969 .66666 L .33988 .66166 L F
.33978 .6618 m .33963 .66675 L .33949 .66694 L F
.34006 .66045 m .33961 .66539 L .34021 .66064 L .992 .745 .442 r
F
.33587 .6662 m .34111 .66725 L .34049 .66648 L .658 .806 .954 r
F
.3389 .66738 m .34224 .66867 L .33987 .667 L F
.33947 .66695 m .33949 .66694 L .3394 .66864 L .335 .155 .483 r
F
.33947 .66695 m .3394 .66864 L .33892 .67703 L F
.33939 .66701 m .33947 .66695 L .33892 .67703 L F
.33915 .66718 m .33892 .67703 L .33903 .66726 L F
.33939 .66701 m .33892 .67703 L .33915 .66718 L F
.33949 .66694 m .33932 .67644 L .33892 .67703 L 0 0 .355 r
F
.33963 .66675 m .33932 .67644 L .33949 .66694 L F
.33879 .66742 m .33892 .67703 L .33822 .67753 L .335 .155 .483 r
F
.33903 .66726 m .33892 .67703 L .33879 .66742 L F
.33587 .6662 m .34304 .66664 L .34302 .66663 L .658 .806 .954 r
F
.34018 .6611 m .3399 .66608 L .34017 .66126 L 0 0 0 r
F
.3399 .66608 m .3399 .66618 L .34017 .66126 L F
.34017 .66126 m .3399 .66618 L .33988 .66639 L F
.34169 .66249 m .35046 .66662 L .35223 .66537 L .659 .806 .954 r
F
.34252 .66352 m .35046 .66662 L .34169 .66249 L F
.36471 .66698 m .38834 .66628 L .37081 .66271 L .659 .805 .953 r
F
.35046 .66662 m .37131 .66807 L .35353 .66446 L .659 .806 .954 r
F
.34124 .66586 m .35569 .66739 L .34494 .66562 L .658 .806 .954 r
F
.34009 .66137 m .34017 .66126 L .33988 .66639 L 0 0 .355 r
F
.33992 .66586 m .3399 .66608 L .34018 .6611 L 0 0 0 r
F
.33587 .6662 m .34302 .66663 L .34124 .66586 L .658 .806 .954 r
F
.34302 .66663 m .35569 .66739 L .34124 .66586 L F
.33929 .65975 m .33868 .66475 L .33961 .65989 L .892 .63 .535 r
F
.33812 .66776 m .33816 .66785 L .3382 .66782 L .658 .806 .954 r
F
.33827 .66762 m .33822 .67753 L .33809 .66769 L .516 .302 .527 r
F
.33823 .66868 m .33842 .66842 L .33816 .66785 L .658 .806 .954 r
F
.3382 .66782 m .33847 .66835 L .33863 .66812 L F
.33864 .66748 m .33822 .67753 L .33827 .66762 L .516 .302 .527 r
F
.33774 .66783 m .33822 .67753 L .33716 .67791 L F
.33787 .66805 m .33823 .66868 L .33816 .66785 L .658 .806 .954 r
F
.33774 .66783 m .33787 .66805 L .33812 .66776 L F
.33787 .66805 m .33816 .66785 L .33812 .66776 L F
.33804 .66771 m .33774 .66783 L .33812 .66776 L F
.33809 .66769 m .33822 .67753 L .33774 .66783 L .516 .302 .527 r
F
.33961 .66539 m .33971 .66552 L .34021 .66064 L .992 .745 .442 r
F
.3402 .66077 m .33992 .66578 L .33992 .66586 L 0 0 0 r
F
.341 .66576 m .34494 .66562 L .34412 .66549 L .658 .806 .954 r
F
.3402 .66077 m .33992 .66586 L .34018 .6611 L 0 0 0 r
F
.33587 .6662 m .34124 .66586 L .341 .66576 L .658 .806 .954 r
F
.34124 .66586 m .34494 .66562 L .341 .66576 L F
.33864 .65946 m .33838 .65935 L .33809 .6645 L .892 .63 .535 r
F
.3402 .66077 m .34021 .66064 L .33992 .66578 L 0 0 0 r
F
.34021 .66064 m .33971 .66552 L .33992 .66578 L .992 .745 .442 r
F
.3429 .66132 m .35353 .66446 L .3553 .66216 L .659 .806 .954 r
F
.34717 .66317 m .35353 .66446 L .3429 .66132 L F
.34717 .66317 m .35223 .66537 L .35353 .66446 L F
.37081 .66271 m .38834 .66628 L .39402 .65913 L .659 .805 .953 r
F
.35353 .66446 m .37131 .66807 L .37507 .66327 L .659 .806 .954 r
F
.35353 .66446 m .37507 .66327 L .35538 .66205 L F
.34169 .66509 m .35604 .66446 L .34546 .66437 L .658 .806 .954 r
F
.33587 .6662 m .34412 .66549 L .34169 .66509 L F
.34412 .66549 m .35604 .66446 L .34169 .66509 L F
.33807 .6593 m .33746 .66439 L .33838 .65935 L .802 .546 .551 r
F
.33706 .66794 m .33714 .66805 L .33774 .66783 L .658 .806 .954 r
F
.33603 .6681 m .33604 .6681 L .33706 .66794 L F
.33714 .66805 m .33737 .66839 L .33774 .66783 L F
.3375 .66786 m .33716 .67791 L .3369 .66796 L .644 .409 .547 r
F
.33746 .66439 m .33766 .66443 L .33838 .65935 L .802 .546 .551 r
F
.33864 .65946 m .33809 .6645 L .33825 .66457 L .892 .63 .535 r
F
.33838 .65935 m .33766 .66443 L .33809 .6645 L .802 .546 .551 r
F
.33718 .65915 m .33646 .66429 L .33688 .6643 L .733 .485 .553 r
F
.33868 .66475 m .33889 .66484 L .33961 .65989 L .892 .63 .535 r
F
.33961 .65989 m .33889 .66484 L .33932 .66503 L F
.33742 .6592 m .33704 .66432 L .33807 .6593 L .802 .546 .551 r
F
.33704 .66432 m .33746 .66439 L .33807 .6593 L F
.33864 .65946 m .33825 .66457 L .33929 .65975 L .892 .63 .535 r
F
.33825 .66457 m .33868 .66475 L .33929 .65975 L F
.33974 .66005 m .33961 .65989 L .33932 .66503 L .992 .745 .442 r
F
.33974 .66005 m .33932 .66503 L .3394 .66513 L F
.33974 .66005 m .3394 .66513 L .34006 .66045 L F
.3394 .66513 m .33961 .66539 L .34006 .66045 L F
.33742 .6592 m .33718 .65915 L .33688 .6643 L .802 .546 .551 r
F
.33587 .6662 m .33788 .66431 L .33676 .6643 L .658 .806 .954 r
F
.34365 .66023 m .3559 .65954 L .35582 .65932 L .659 .806 .954 r
F
.34404 .66029 m .3559 .65954 L .34365 .66023 L F
.34401 .65922 m .35582 .65932 L .35503 .65711 L F
.33587 .6662 m .34973 .65854 L .34538 .65727 L .658 .806 .954 r
F
.33587 .6662 m .35313 .66032 L .34973 .65854 L F
.33587 .6662 m .35533 .66249 L .35313 .66032 L F
.33704 .66432 m .33688 .6643 L .33634 .67376 L .802 .546 .551 r
F
.33742 .6592 m .33688 .6643 L .33704 .66432 L F
.33677 .66428 m .34538 .65727 L .34036 .65662 L .658 .806 .954 r
F
.33676 .6643 m .33678 .66428 L .33677 .66428 L F
.33678 .66428 m .34538 .65727 L .33677 .66428 L F
.33788 .66431 m .34538 .65727 L .33676 .6643 L F
.33686 .65915 m .33626 .66429 L .33718 .65915 L .733 .485 .553 r
F
.33603 .6681 m .33603 .6681 L .33604 .6681 L .658 .806 .954 r
F
.3358 .66809 m .33604 .6681 L .33547 .67809 L .749 .499 .553 r
F
.33626 .66429 m .33646 .66429 L .33718 .65915 L .733 .485 .553 r
F
.33585 .66429 m .33626 .66429 L .33686 .65915 L F
.33623 .65915 m .33686 .65915 L .33747 .65403 L F
.33623 .65915 m .33569 .66429 L .33585 .66429 L F
.33661 .65402 m .33615 .65914 L .33623 .65915 L F
.33615 .65914 m .33569 .66429 L .33623 .65915 L F
.33747 .65403 m .33686 .65915 L .33718 .65915 L F
.33781 .65408 m .33747 .65403 L .33718 .65915 L .802 .546 .551 r
F
.33638 .65915 m .34509 .65188 L .34008 .65122 L .659 .806 .954 r
F
.33736 .65916 m .34509 .65188 L .33638 .65915 L F
.33629 .65401 m .33568 .65918 L .33599 .65914 L .663 .424 .548 r
F
.33516 .65364 m .33977 .64588 L .33448 .64588 L .659 .805 .953 r
F
.33609 .6538 m .33977 .64588 L .33516 .65364 L F
.33545 .65914 m .34008 .65122 L .33475 .65123 L .659 .806 .954 r
F
.33638 .65915 m .34008 .65122 L .33545 .65914 L F
.33615 .65914 m .33599 .65914 L .33569 .66429 L .733 .485 .553 r
F
.33568 .65918 m .33507 .66437 L .33599 .65914 L .663 .424 .548 r
F
.33507 .66437 m .33527 .66434 L .33599 .65914 L F
.33599 .65914 m .33527 .66434 L .33569 .66429 L F
.33505 .65926 m .33467 .66442 L .33568 .65918 L F
.33467 .66442 m .33507 .66437 L .33568 .65918 L F
.33587 .6662 m .34036 .65662 L .33503 .65663 L .658 .806 .954 r
F
.33626 .66429 m .33515 .67364 L .33646 .66429 L .733 .485 .553 r
F
.33746 .66439 m .33634 .67376 L .33766 .66443 L .802 .546 .551 r
F
.33825 .66457 m .33809 .6645 L .33754 .67409 L .892 .63 .535 r
F
.33809 .6645 m .33634 .67376 L .33754 .67409 L .802 .546 .551 r
F
.33766 .66443 m .33634 .67376 L .33809 .6645 L F
.34412 .66549 m .3562 .66491 L .35604 .66446 L .658 .806 .954 r
F
.34494 .66562 m .3562 .66491 L .34412 .66549 L F
.34546 .66437 m .35604 .66446 L .35533 .66249 L F
.33688 .6643 m .33515 .67364 L .33634 .67376 L .733 .485 .553 r
F
.33646 .66429 m .33515 .67364 L .33688 .6643 L F
.33868 .66475 m .33754 .67409 L .33889 .66484 L .892 .63 .535 r
F
.33932 .66503 m .33754 .67409 L .33877 .67481 L F
.33889 .66484 m .33754 .67409 L .33932 .66503 L F
.34302 .66663 m .35568 .66741 L .35569 .66739 L .658 .806 .954 r
F
.34304 .66664 m .35568 .66741 L .34302 .66663 L F
.34494 .66562 m .35569 .66739 L .3562 .66491 L F
.33704 .66432 m .33634 .67376 L .33746 .66439 L .802 .546 .551 r
F
.33961 .66539 m .33877 .67481 L .33971 .66552 L .992 .745 .442 r
F
.34049 .66648 m .3474 .66852 L .34304 .66664 L .658 .806 .954 r
F
.34111 .66725 m .3474 .66852 L .34049 .66648 L F
.3474 .66852 m .35383 .66982 L .34304 .66664 L F
.33825 .66457 m .33754 .67409 L .33868 .66475 L .892 .63 .535 r
F
.33587 .6662 m .33503 .65663 L .32975 .65729 L .658 .806 .954 r
F
.33585 .66429 m .33515 .67364 L .33626 .66429 L .733 .485 .553 r
F
.33585 .66429 m .33569 .66429 L .33515 .67364 L F
.33391 .66462 m .33282 .67402 L .3341 .66456 L .57 .346 .536 r
F
.33271 .66497 m .33353 .66457 L .33213 .66475 L .658 .806 .954 r
F
.33369 .66468 m .33353 .66457 L .33271 .66497 L F
.33353 .66457 m .3249 .65856 L .33213 .66475 L F
.33507 .66437 m .33398 .67372 L .33527 .66434 L .663 .424 .548 r
F
.33452 .66444 m .33284 .6739 L .33398 .67372 L .57 .346 .536 r
F
.3341 .66456 m .33282 .67402 L .33452 .66444 L F
.33152 .66532 m .33213 .66475 L .33004 .66502 L .658 .806 .954 r
F
.33271 .66497 m .33213 .66475 L .33152 .66532 L F
.33213 .66475 m .32081 .66036 L .33004 .66502 L F
.33569 .66429 m .33398 .67372 L .33515 .67364 L .663 .424 .548 r
F
.33527 .66434 m .33398 .67372 L .33569 .66429 L F
.33351 .66474 m .33282 .67402 L .33391 .66462 L .57 .346 .536 r
F
.32981 .66583 m .33004 .66502 L .32576 .66558 L .658 .806 .954 r
F
.33152 .66532 m .33004 .66502 L .32981 .66583 L F
.33004 .66502 m .31776 .66255 L .32576 .66558 L F
.33467 .66442 m .33398 .67372 L .33507 .66437 L .663 .424 .548 r
F
.33238 .66537 m .33224 .66546 L .33169 .67471 L .385 .194 .495 r
F
.33044 .66654 m .32576 .66558 L .31551 .66749 L .658 .806 .954 r
F
.33145 .66593 m .32576 .66558 L .33044 .66654 L F
.32576 .66558 m .31595 .66498 L .31561 .6669 L F
.32576 .66558 m .31561 .6669 L .31551 .66749 L F
.33467 .66442 m .33452 .66444 L .33398 .67372 L .663 .424 .548 r
F
.33243 .66737 m .33243 .66737 L .33312 .66772 L .658 .806 .954 r
F
.33243 .66737 m .3328 .66774 L .33312 .66772 L F
.33242 .66737 m .33263 .67745 L .33186 .67693 L .909 .647 .529 r
F
.33269 .6675 m .33263 .67745 L .33242 .66737 L F
.33235 .6673 m .33242 .66737 L .33186 .67693 L .981 .727 .472 r
F
.33238 .66537 m .33169 .67471 L .33277 .66514 L .385 .194 .495 r
F
.3394 .66513 m .33932 .66503 L .33877 .67481 L .992 .745 .442 r
F
.34224 .66867 m .35076 .67197 L .34151 .66775 L .658 .806 .954 r
F
.34224 .66867 m .34151 .66775 L .33987 .667 L F
.33958 .6716 m .34189 .67497 L .33961 .67105 L F
.33961 .67105 m .34189 .67497 L .33963 .67066 L F
.33964 .6706 m .34189 .67497 L .33974 .66889 L F
.33958 .6716 m .33936 .67529 L .34189 .67497 L F
.3399 .66608 m .33936 .67573 L .3399 .66618 L 0 0 0 r
F
.33969 .66666 m .33932 .67644 L .33963 .66675 L 0 0 .355 r
F
.33988 .66639 m .33936 .67573 L .33932 .67644 L 0 0 0 r
F
.3399 .66618 m .33936 .67573 L .33988 .66639 L F
.33983 .66647 m .33988 .66639 L .33932 .67644 L 0 0 .355 r
F
.33992 .66586 m .33992 .66578 L .33936 .67573 L 0 0 0 r
F
.33983 .66647 m .33932 .67644 L .33969 .66666 L 0 0 .355 r
F
.33992 .66586 m .33936 .67573 L .3399 .66608 L 0 0 0 r
F
.33992 .66578 m .33877 .67481 L .33936 .67573 L .992 .745 .442 r
F
.33971 .66552 m .33877 .67481 L .33992 .66578 L F
.3394 .66513 m .33877 .67481 L .33961 .66539 L F
.34224 .66867 m .34669 .67373 L .35076 .67197 L .658 .806 .954 r
F
.3455 .67273 m .34669 .67373 L .34224 .66867 L F
.35421 .66197 m .3553 .66216 L .35538 .66205 L .659 .806 .954 r
F
.33191 .66679 m .33193 .66687 L .33137 .67632 L .923 .74 .252 r
F
.33186 .66659 m .33137 .67632 L .33183 .66648 L F
.33178 .66627 m .33137 .67632 L .33123 .67561 L F
.33183 .66648 m .33137 .67632 L .33178 .66627 L F
.33191 .66679 m .33137 .67632 L .33186 .66659 L F
.332 .66588 m .33123 .67561 L .33207 .66575 L 0 0 .29 r
F
.33086 .6679 m .32876 .66755 L .32465 .67002 L .658 .806 .954 r
F
.33109 .6675 m .32876 .66755 L .33086 .6679 L F
.32876 .66755 m .31646 .66989 L .32465 .67002 L F
.33277 .66514 m .33169 .67471 L .33296 .66502 L .385 .194 .495 r
F
.33086 .6679 m .32465 .67002 L .33058 .66841 L .658 .806 .954 r
F
.33224 .66546 m .33123 .67561 L .33169 .67471 L 0 0 .29 r
F
.33207 .66575 m .33123 .67561 L .33224 .66546 L F
.33312 .66772 m .33284 .66779 L .33289 .66784 L .658 .806 .954 r
F
.32465 .67002 m .31872 .67204 L .32011 .67275 L F
.32465 .67002 m .32011 .67275 L .32214 .67379 L F
.33282 .66757 m .33263 .67745 L .33269 .6675 L .909 .647 .529 r
F
.33309 .6677 m .33263 .67745 L .33282 .66757 L F
.33336 .66478 m .33169 .67471 L .33282 .67402 L .385 .194 .495 r
F
.33296 .66502 m .33169 .67471 L .33336 .66478 L F
.33 .66944 m .32214 .67379 L .3273 .67423 L .658 .806 .954 r
F
.33184 .66616 m .33123 .67561 L .332 .66588 L 0 0 .29 r
F
.3273 .67423 m .32647 .67501 L .3272 .67442 L .658 .806 .954 r
F
.33184 .66616 m .33178 .66627 L .33123 .67561 L 0 0 .29 r
F
.39241 .44977 m .39318 .44178 L .36903 .43463 L .791 .544 .563 r
F
0 g
.39318 .44178 m
.41388 .45214 L
s
.62721 .44635 m .62742 .43837 L .63246 .42316 L 0 0 .241 r
F
0 g
.62176 .44518 m
.62742 .43837 L
s
.85331 .46635 m .83468 .44798 L .83497 .45601 L .872 .6 .524 r
F
0 g
.85331 .46635 m
.86599 .47909 L
s
.35339 .68685 m .35309 .68157 L .36727 .67791 L .609 .409 .586 r
F
0 g
.35004 .68195 m
.35309 .68157 L
s
.73148 .56944 m .70663 .56653 L .70197 .5771 L .653 .783 .943 r
F
.70727 .57297 m .70197 .5771 L .7026 .58351 L 0 0 .431 r
F
.70727 .57297 m .70663 .56653 L .70197 .5771 L F
0 g
.70197 .5771 m
.70272 .58738 L
s
.42012 .82182 m .41065 .81728 L .40448 .8204 L .593 .769 .963 r
F
.42554 .82036 m .41065 .81728 L .42012 .82182 L F
.36293 .56325 m .37675 .55047 L .35856 .56055 L .656 .781 .94 r
F
.36293 .56325 m .38544 .55594 L .37675 .55047 L F
.60879 .58705 m .61038 .57359 L .58957 .57547 L .653 .784 .944 r
F
.66487 .58409 m .64891 .57166 L .64945 .57808 L .861 .596 .537 r
F
0 g
.66487 .58409 m
.67602 .59204 L
s
.28868 .57754 m .26113 .58516 L .28767 .58453 L .654 .782 .942 r
F
.31475 .58041 m .28868 .57754 L .28767 .58453 L F
.45742 .82405 m .45859 .81745 L .45196 .82194 L .593 .769 .963 r
F
.45742 .82405 m .4668 .82063 L .45859 .81745 L F
.80693 .57113 m .82979 .56058 L .80515 .56793 L .653 .783 .943 r
F
.80693 .57113 m .83324 .56703 L .82979 .56058 L F
.18969 .43618 m .21291 .43868 L .21171 .44666 L .845 .602 .571 r
F
.18969 .43618 m .19095 .42817 L .21291 .43868 L F
.21239 .41523 m .21291 .43868 L .22711 .42236 L .642 .738 .918 r
F
.21239 .41523 m .19095 .42817 L .21291 .43868 L F
0 g
.21291 .43868 m
.21752 .44001 L
s
.31711 .57068 m .28874 .57111 L .31477 .574 L .655 .781 .941 r
F
.41025 .82181 m .40448 .8204 L .40408 .82492 L .368 .196 .511 r
F
.41025 .82181 m .41065 .81728 L .40448 .8204 L F
0 g
.40071 .82422 m
.40448 .8204 L
s
.42598 .81589 m .41928 .81062 L .41118 .81282 L .594 .768 .963 r
F
.43229 .81515 m .41928 .81062 L .42598 .81589 L F
.45224 .81746 m .44928 .81072 L .4459 .81596 L F
.45224 .81746 m .45883 .81298 L .44928 .81072 L F
.75689 .57875 m .72892 .58288 L .75522 .58225 L .653 .784 .944 r
F
.47305 .8245 m .46713 .81611 L .4668 .82063 L .912 .673 .564 r
F
.47272 .82903 m .47305 .8245 L .4668 .82063 L F
0 g
.47305 .8245 m
.47692 .82878 L
s
.5482 .69921 m .54909 .70079 L .54964 .7061 L .797 .578 .014 r
F
.5482 .69921 m .54765 .69388 L .54909 .70079 L F
.56749 .6926 m .54909 .70079 L .56837 .69722 L .656 .809 .957 r
F
.56749 .6926 m .54765 .69388 L .54909 .70079 L F
0 g
.54909 .70079 m
.55316 .70545 L
s
.83213 .56068 m .85339 .54686 L .8287 .55425 L .654 .782 .942 r
F
.83213 .56068 m .85837 .55658 L .85339 .54686 L F
.76042 .43812 m .73532 .43479 L .73537 .44277 L .598 .379 .554 r
F
.76042 .43812 m .76031 .43012 L .73532 .43479 L F
0 g
.71332 .44306 m
.73532 .43479 L
s
.77971 .68722 m .77887 .68194 L .79434 .68002 L .676 .462 .588 r
F
.76471 .68727 m .77887 .68194 L .77971 .68722 L .733 .501 .577 r
F
.76471 .68727 m .76388 .68198 L .77887 .68194 L F
.5868 .68601 m .56799 .69189 L .5872 .68832 L .656 .808 .956 r
F
.5868 .68601 m .56711 .68728 L .56799 .69189 L F
.28868 .57754 m .26245 .57465 L .26113 .58516 L .654 .782 .942 r
F
0 g
.26113 .58516 m
.26522 .59539 L
s
.78135 .67262 m .78115 .67337 L .7943 .67989 L .655 .809 .957 r
F
.78384 .67231 m .7943 .67989 L .79169 .67133 L F
.78135 .67262 m .78327 .6737 L .78384 .67231 L F
.78327 .6737 m .7943 .67989 L .78384 .67231 L F
.79169 .67133 m .7943 .67989 L .80141 .67815 L F
.79949 .67352 m .80141 .67815 L .8092 .67624 L F
.79169 .67133 m .80141 .67815 L .79949 .67352 L F
.79794 .66979 m .8092 .67624 L .80168 .66887 L F
.79169 .67133 m .79949 .67352 L .79794 .66979 L F
.79949 .67352 m .8092 .67624 L .79794 .66979 L F
.78707 .605 m .79127 .65408 L .79109 .65452 L 0 0 .362 r
F
.78904 .66265 m .79169 .67133 L .80168 .66887 L .655 .809 .957 r
F
.78904 .66265 m .80168 .66887 L .79407 .66141 L F
.78383 .6633 m .78135 .67262 L .79169 .67133 L F
.77932 .60488 m .77962 .60551 L .78356 .65549 L .966 .687 .262 r
F
.78383 .6633 m .79169 .67133 L .79027 .66667 L .655 .809 .957 r
F
.78383 .6633 m .79027 .66667 L .78794 .66279 L F
.78115 .67337 m .7802 .68164 L .7943 .67989 L F
.78469 .66869 m .78218 .67802 L .79259 .67673 L .655 .81 .958 r
F
.78115 .67337 m .7789 .6818 L .7802 .68164 L .655 .809 .957 r
F
.77134 .67264 m .7789 .6818 L .78135 .67262 L F
.78268 .66869 m .78218 .67802 L .78469 .66869 L .655 .81 .958 r
F
.77879 .66331 m .78135 .67262 L .78383 .6633 L .655 .809 .957 r
F
.77879 .66331 m .77134 .67264 L .78135 .67262 L F
.77962 .6687 m .78177 .67651 L .78268 .66869 L .655 .81 .958 r
F
.78177 .67651 m .78218 .67802 L .78268 .66869 L F
.77971 .68722 m .79434 .68002 L .79521 .6853 L .676 .462 .588 r
F
.78218 .67802 m .77971 .68722 L .79521 .6853 L .655 .81 .958 r
F
.77134 .67264 m .76399 .68185 L .7789 .6818 L .655 .809 .957 r
F
.77211 .67805 m .77971 .68722 L .78218 .67802 L .655 .81 .958 r
F
.78218 .67802 m .79521 .6853 L .79259 .67673 L F
.77962 .6687 m .77211 .67805 L .78218 .67802 L F
.78048 .67405 m .78304 .68335 L .78556 .67404 L .654 .811 .959 r
F
.78519 .65821 m .78383 .6633 L .78794 .66279 L .655 .809 .957 r
F
.78122 .60646 m .78284 .60669 L .78679 .65624 L .75 .494 .544 r
F
.78122 .60646 m .78679 .65624 L .78632 .65622 L F
.78724 .65676 m .78519 .65821 L .78904 .66265 L .655 .809 .957 r
F
.78709 .65625 m .78674 .65661 L .78724 .65676 L F
.78674 .65661 m .78519 .65821 L .78724 .65676 L F
.78024 .60604 m .78122 .60646 L .78515 .65616 L .848 .57 .516 r
F
.78702 .65625 m .78519 .65821 L .78709 .65625 L .655 .809 .957 r
F
.78567 .65642 m .78519 .65821 L .78707 .65619 L F
.77962 .60551 m .78024 .60604 L .78417 .65589 L .941 .646 .452 r
F
.78557 .65678 m .7829 .65817 L .78383 .6633 L .655 .809 .957 r
F
.78528 .65659 m .7829 .65817 L .78557 .65678 L F
.78559 .65629 m .78521 .65655 L .78569 .65632 L F
.78521 .65655 m .7829 .65817 L .78528 .65659 L F
.78521 .65655 m .78528 .65659 L .78569 .65632 L F
.78452 .65614 m .7829 .65817 L .78573 .65619 L F
.78469 .66869 m .79259 .67673 L .78993 .66803 L .655 .81 .958 r
F
.78556 .67404 m .78304 .68335 L .79346 .68205 L .654 .811 .959 r
F
.77962 .60551 m .784 .65577 L .78356 .65549 L .941 .646 .452 r
F
.77962 .60551 m .78417 .65589 L .784 .65577 L F
.78024 .60604 m .78488 .65609 L .78417 .65589 L .848 .57 .516 r
F
.78024 .60604 m .78515 .65616 L .78488 .65609 L F
.78122 .60646 m .78632 .65622 L .78515 .65616 L .75 .494 .544 r
F
.78635 .65385 m .77913 .65912 L .77879 .66331 L .655 .809 .957 r
F
.77913 .65912 m .77426 .66268 L .77578 .66289 L F
.77913 .65912 m .77578 .66289 L .77879 .66331 L F
.77932 .60488 m .78348 .65535 L .78326 .655 L .966 .687 .262 r
F
.77932 .60488 m .78356 .65549 L .78348 .65535 L F
.78009 .60323 m .77938 .60415 L .78334 .65439 L .159 .061 .485 r
F
.78794 .66279 m .79027 .66667 L .78904 .66265 L .655 .809 .957 r
F
.78856 .66356 m .78469 .66869 L .78993 .66803 L .655 .81 .958 r
F
.78643 .66219 m .78469 .66869 L .78856 .66356 L F
.77913 .65912 m .77054 .66144 L .77426 .66268 L .655 .809 .957 r
F
.78635 .65385 m .78193 .65597 L .77913 .65912 L F
.78193 .65597 m .77054 .66144 L .77913 .65912 L F
.78596 .66394 m .77962 .6687 L .78469 .66869 L .655 .81 .958 r
F
.78547 .66311 m .77962 .6687 L .78596 .66394 L F
.78538 .66152 m .78488 .66214 L .78643 .66219 L F
.78488 .66214 m .77962 .6687 L .78547 .66311 L F
.78488 .66214 m .78547 .66311 L .78643 .66219 L F
.784 .65577 m .78417 .65589 L .78458 .66101 L .941 .646 .452 r
F
.7829 .65817 m .78231 .6633 L .78383 .6633 L .655 .809 .957 r
F
.78488 .66214 m .77806 .66588 L .77962 .6687 L .655 .81 .958 r
F
.78538 .66152 m .78474 .6619 L .78488 .66214 L F
.77938 .60415 m .78328 .65483 L .78334 .65439 L 0 0 .196 r
F
.77938 .60415 m .77932 .60488 L .78326 .655 L F
.77938 .60415 m .78326 .655 L .78328 .65483 L F
.78635 .65385 m .77902 .65616 L .77054 .66144 L .655 .809 .957 r
F
.77902 .65616 m .76788 .65969 L .76976 .66093 L F
.77902 .65616 m .76976 .66093 L .77054 .66144 L F
.78138 .60253 m .78009 .60323 L .78406 .65357 L .454 .273 .545 r
F
.78474 .6619 m .78337 .66272 L .78488 .66214 L .655 .81 .958 r
F
.78337 .66272 m .78334 .66299 L .78488 .66214 L F
.78556 .66129 m .78467 .66107 L .78538 .66152 L F
.78417 .65589 m .78483 .66108 L .78458 .66101 L .848 .57 .516 r
F
.78471 .66105 m .78467 .66107 L .78556 .66129 L .655 .81 .958 r
F
.7829 .65817 m .77879 .66331 L .78231 .6633 L .655 .809 .957 r
F
.78467 .66107 m .77806 .66588 L .78538 .66152 L .655 .81 .958 r
F
.78643 .66219 m .78547 .66311 L .78596 .66394 L F
.78488 .65609 m .78535 .66123 L .78417 .65589 L .848 .57 .516 r
F
.78556 .67404 m .79346 .68205 L .79081 .67339 L .654 .811 .959 r
F
.78535 .66123 m .78483 .66108 L .78417 .65589 L .848 .57 .516 r
F
.784 .65577 m .78458 .66101 L .78445 .66093 L .941 .646 .452 r
F
.77426 .66268 m .77134 .67264 L .77879 .66331 L .655 .809 .957 r
F
.77426 .66268 m .76232 .6714 L .77134 .67264 L F
.77806 .66588 m .77131 .66683 L .77506 .66806 L .655 .81 .958 r
F
.784 .65577 m .78445 .66093 L .78356 .65549 L .941 .646 .452 r
F
.78445 .66093 m .78412 .66072 L .78356 .65549 L F
.78356 .65549 m .78412 .66072 L .78396 .66062 L F
.78519 .65821 m .78794 .66279 L .78904 .66265 L .655 .809 .957 r
F
.78488 .65609 m .78515 .65616 L .78556 .66129 L .848 .57 .516 r
F
.78946 .669 m .78556 .67404 L .79081 .67339 L .654 .811 .959 r
F
.7884 .66833 m .78556 .67404 L .78946 .669 L F
.7875 .66686 m .78729 .66762 L .78893 .66726 L F
.78729 .66762 m .78556 .67404 L .7884 .66833 L F
.78729 .66762 m .7884 .66833 L .78893 .66726 L F
.78471 .66105 m .78161 .6619 L .77806 .66588 L .655 .81 .958 r
F
.78388 .66081 m .78161 .6619 L .78471 .66105 L F
.78445 .66093 m .7849 .6661 L .78412 .66072 L .941 .646 .452 r
F
.78488 .65609 m .78556 .66129 L .78535 .66123 L .848 .57 .516 r
F
.78674 .66968 m .78048 .67405 L .78556 .67404 L .654 .811 .959 r
F
.7875 .66686 m .78598 .66842 L .78674 .66968 L F
.78598 .66842 m .78048 .67405 L .78674 .66968 L F
.78557 .66774 m .78348 .67033 L .78588 .66826 L F
.78348 .67033 m .7834 .67106 L .78598 .66842 L F
.78588 .66826 m .78598 .66842 L .7875 .66686 L F
.78348 .67033 m .78598 .66842 L .78588 .66826 L F
.77054 .66144 m .76232 .6714 L .77426 .66268 L .655 .809 .957 r
F
.78312 .66118 m .76864 .66507 L .77131 .66683 L .655 .81 .958 r
F
.78515 .65616 m .78598 .66131 L .78556 .66129 L .75 .494 .544 r
F
.78348 .65535 m .7839 .66051 L .78326 .655 L .966 .687 .262 r
F
.7839 .66051 m .78375 .66025 L .78326 .655 L F
.78348 .65535 m .78356 .65549 L .78396 .66062 L F
.78348 .65535 m .78396 .66062 L .7839 .66051 L F
.77902 .65616 m .76647 .65753 L .76788 .65969 L .655 .809 .957 r
F
.78635 .65385 m .78194 .65466 L .77902 .65616 L F
.78194 .65466 m .76647 .65753 L .77902 .65616 L F
.78651 .66658 m .78557 .66774 L .7875 .66686 L .654 .811 .959 r
F
.78557 .66774 m .78588 .66826 L .7875 .66686 L F
.7876 .6665 m .78651 .66658 L .7875 .66686 L F
.78661 .66645 m .78651 .66658 L .7876 .6665 L F
.7866 .66158 m .78538 .66152 L .78643 .66219 L .655 .81 .958 r
F
.78569 .65632 m .78528 .65659 L .78557 .65678 L .655 .809 .957 r
F
.78573 .65619 m .78559 .65629 L .78569 .65632 L F
.78632 .65622 m .78685 .66134 L .78515 .65616 L .75 .494 .544 r
F
.78666 .66134 m .78556 .66129 L .7866 .66158 L .655 .81 .958 r
F
.78556 .66129 m .78538 .66152 L .7866 .66158 L F
.78685 .66134 m .78598 .66131 L .78515 .65616 L .75 .494 .544 r
F
.78632 .65622 m .78679 .65624 L .7872 .66136 L F
.7879 .66139 m .78643 .66219 L .78856 .66356 L .655 .81 .958 r
F
.78766 .66138 m .78643 .66219 L .7879 .66139 L F
.78632 .65622 m .7872 .66136 L .78685 .66134 L .75 .494 .544 r
F
.78679 .65624 m .78763 .66129 L .7872 .66136 L .648 .416 .554 r
F
.78786 .66125 m .78766 .66138 L .7879 .66139 L .655 .81 .958 r
F
.78663 .66145 m .78643 .66219 L .78786 .66125 L F
.78893 .66726 m .7884 .66833 L .78946 .669 L .654 .811 .959 r
F
.78707 .65619 m .78702 .65625 L .78709 .65625 L .655 .809 .957 r
F
.78284 .60669 m .78802 .65604 L .78679 .65624 L .648 .416 .554 r
F
.78707 .605 m .78731 .60427 L .79134 .6539 L 0 0 .362 r
F
.78993 .65735 m .78904 .66265 L .79407 .66141 L .655 .809 .957 r
F
.78993 .66803 m .79259 .67673 L .80265 .67426 L .655 .81 .958 r
F
.79023 .65568 m .79407 .66141 L .79859 .65965 L .655 .809 .957 r
F
.78284 .60669 m .78454 .60651 L .78851 .65596 L .648 .416 .554 r
F
.78284 .60669 m .78851 .65596 L .78802 .65604 L F
.78868 .65612 m .7885 .66087 L .78993 .65735 L .655 .809 .957 r
F
.78983 .6555 m .78851 .65596 L .79023 .65568 L F
.7898 .65575 m .79407 .66141 L .79023 .65568 L F
.78939 .65615 m .79407 .66141 L .7898 .65575 L F
.78868 .65612 m .78904 .65648 L .78913 .65586 L F
.78904 .65648 m .79407 .66141 L .78939 .65615 L F
.78904 .65648 m .78939 .65615 L .78913 .65586 L F
.78652 .60561 m .78707 .605 L .79109 .65452 L .231 .113 .505 r
F
.78993 .66803 m .80265 .67426 L .79499 .66679 L .655 .81 .958 r
F
.79521 .6853 m .79434 .68002 L .80931 .67635 L .617 .422 .596 r
F
.79521 .6853 m .80931 .67635 L .8102 .68163 L F
.79259 .67673 m .79521 .6853 L .8102 .68163 L .655 .81 .958 r
F
.79259 .67673 m .8102 .68163 L .80265 .67426 L F
.79081 .67339 m .79346 .68205 L .80354 .67959 L .654 .811 .959 r
F
.79081 .67339 m .80354 .67959 L .79588 .67214 L F
.79041 .66231 m .78993 .66803 L .79499 .66679 L .655 .81 .958 r
F
.79096 .66097 m .79499 .66678 L .79296 .66192 L F
.79039 .6607 m .79083 .66128 L .79096 .66097 L F
.79083 .66128 m .79499 .66678 L .79096 .66097 L F
.78652 .60561 m .79092 .65468 L .79052 .65507 L .231 .113 .505 r
F
.78569 .60612 m .78652 .60561 L .79052 .65507 L .424 .252 .542 r
F
.78569 .60612 m .79052 .65507 L .79027 .65521 L F
.78569 .60612 m .79027 .65521 L .78967 .65555 L F
.78454 .60651 m .78569 .60612 L .78967 .65555 L .544 .339 .553 r
F
.78454 .60651 m .78967 .65555 L .78934 .65567 L F
.78454 .60651 m .78934 .65567 L .78851 .65596 L F
.78635 .65385 m .79859 .65965 L .80075 .65839 L .655 .809 .957 r
F
.79673 .65622 m .80075 .65839 L .80228 .65749 L F
.78635 .65385 m .80075 .65839 L .79673 .65622 L F
.78652 .60561 m .79109 .65452 L .79092 .65468 L .231 .113 .505 r
F
.79316 .6543 m .80228 .65749 L .80491 .65508 L .655 .809 .957 r
F
.78635 .65385 m .79673 .65622 L .79316 .6543 L F
.79673 .65622 m .80228 .65749 L .79316 .6543 L F
.78707 .605 m .79134 .6539 L .79127 .65408 L 0 0 .362 r
F
.78699 .60334 m .78599 .6026 L .79003 .65261 L .921 .628 .471 r
F
.78957 .66149 m .79499 .66678 L .79039 .6607 L .655 .81 .958 r
F
.79499 .66678 m .79499 .66679 L .79499 .66678 L F
.79499 .66678 m .79499 .66678 L .79039 .6607 L F
.78731 .60427 m .79111 .65336 L .79134 .6539 L .919 .662 .17 r
F
.79407 .65335 m .80491 .65508 L .80628 .65258 L .655 .809 .957 r
F
.78635 .65385 m .80261 .65493 L .79407 .65335 L F
.80261 .65493 m .80491 .65508 L .79407 .65335 L F
.78913 .65586 m .78939 .65615 L .7898 .65575 L F
.7885 .66087 m .78904 .66265 L .78993 .65735 L F
.78934 .65567 m .78967 .65555 L .79009 .66067 L .544 .339 .553 r
F
.79023 .66062 m .78957 .66149 L .79039 .6607 L .655 .81 .958 r
F
.79017 .66064 m .78957 .66149 L .79023 .66062 L F
.78923 .66116 m .78957 .66149 L .79017 .66064 L F
.79009 .66067 m .79017 .66064 L .7902 .66061 L F
.78923 .66116 m .79017 .66064 L .79009 .66067 L F
.78971 .66402 m .78993 .66803 L .79041 .66231 L F
.78851 .65622 m .7885 .66087 L .78868 .65612 L .655 .809 .957 r
F
.78851 .65596 m .78922 .66098 L .78892 .66108 L .544 .339 .553 r
F
.78715 .65644 m .7885 .66087 L .78851 .65596 L .655 .809 .957 r
F
.78802 .65604 m .78851 .65596 L .78892 .66108 L .648 .416 .554 r
F
.78912 .66105 m .7883 .66271 L .78957 .66149 L .655 .81 .958 r
F
.78907 .66106 m .7883 .66271 L .78912 .66105 L F
.78802 .65604 m .78892 .66108 L .78855 .66114 L .648 .416 .554 r
F
.78802 .65604 m .78855 .66114 L .78679 .65624 L F
.78855 .66114 m .78794 .66124 L .78679 .65624 L F
.78786 .66125 m .78791 .66144 L .78892 .66108 L .655 .81 .958 r
F
.78909 .66626 m .78848 .66636 L .78763 .66129 L .648 .416 .554 r
F
.78794 .66124 m .78763 .66129 L .78679 .65624 L F
.78909 .66626 m .78763 .66129 L .78794 .66124 L F
.78791 .66144 m .7883 .66271 L .78907 .66106 L .655 .81 .958 r
F
.78892 .66108 m .78907 .66106 L .78909 .66102 L F
.78791 .66144 m .78907 .66106 L .78892 .66108 L F
.78723 .65921 m .78786 .66125 L .78909 .66102 L F
.78786 .66125 m .78892 .66108 L .78909 .66102 L F
.7883 .66271 m .78993 .66803 L .78957 .66149 L F
.78855 .66114 m .78909 .66626 L .78794 .66124 L .648 .416 .554 r
F
.79119 .65428 m .7917 .65916 L .79109 .65452 L 0 0 .362 r
F
.7917 .65916 m .79157 .65949 L .79109 .65452 L F
.79089 .66729 m .79081 .67339 L .79554 .67222 L .654 .811 .959 r
F
.79089 .66729 m .79554 .67222 L .79525 .67153 L F
.79407 .66141 m .80168 .66887 L .81068 .66539 L .655 .809 .957 r
F
.79407 .66141 m .81068 .66539 L .79859 .65965 L F
.79231 .66037 m .79954 .66502 L .80326 .66286 L .655 .81 .958 r
F
.78851 .65596 m .78868 .65612 L .78913 .65586 L .655 .809 .957 r
F
.78851 .65596 m .78851 .65622 L .78868 .65612 L F
.78934 .65567 m .78984 .66076 L .78851 .65596 L .544 .339 .553 r
F
.78984 .66076 m .78922 .66098 L .78851 .65596 L F
.78934 .65567 m .79009 .66067 L .78984 .66076 L F
.78967 .65555 m .7903 .66055 L .79009 .66067 L .424 .252 .542 r
F
.79052 .65507 m .79108 .66005 L .79093 .66019 L .231 .113 .505 r
F
.79092 .65468 m .79138 .65976 L .79052 .65507 L F
.79105 .66008 m .79296 .66192 L .79231 .66037 L .655 .81 .958 r
F
.79039 .6607 m .79296 .66192 L .79108 .66011 L F
.79093 .66019 m .79108 .66011 L .79105 .66008 L F
.79039 .6607 m .79108 .66011 L .79093 .66019 L F
.79027 .65521 m .79052 .65507 L .79093 .66019 L .424 .252 .542 r
F
.79027 .65521 m .79093 .66019 L .79075 .66029 L F
.79138 .65976 m .79108 .66005 L .79052 .65507 L .231 .113 .505 r
F
.79859 .65965 m .81068 .66539 L .81807 .66111 L .655 .809 .957 r
F
.79196 .65952 m .80326 .66286 L .8059 .66044 L .655 .81 .958 r
F
.79109 .65452 m .79157 .65949 L .7915 .65965 L 0 0 .362 r
F
.79092 .65468 m .79109 .65452 L .7915 .65965 L .231 .113 .505 r
F
.79092 .65468 m .7915 .65965 L .79138 .65976 L F
.79027 .65521 m .79075 .66029 L .78967 .65555 L .424 .252 .542 r
F
.80168 .66887 m .8092 .67624 L .82264 .67106 L .655 .809 .957 r
F
.80168 .66887 m .82264 .67106 L .81068 .66539 L F
.79499 .66679 m .80265 .67426 L .8117 .67077 L .655 .81 .958 r
F
.79339 .66707 m .79588 .67214 L .80043 .67038 L .654 .811 .959 r
F
.79137 .66612 m .79504 .67102 L .79339 .66707 L F
.79504 .67102 m .79588 .67214 L .79339 .66707 L F
.79125 .66641 m .79511 .67119 L .79137 .66612 L F
.79511 .67119 m .79588 .67214 L .79504 .67102 L F
.79511 .67119 m .79504 .67102 L .79137 .66612 L F
.79075 .66029 m .7903 .66055 L .78967 .65555 L .424 .252 .542 r
F
.78723 .65921 m .79111 .66009 L .79196 .65952 L .655 .81 .958 r
F
.79111 .66009 m .79231 .66037 L .79199 .65959 L F
.79111 .66009 m .79199 .65959 L .79196 .65952 L F
.80228 .65749 m .81807 .66111 L .82337 .65631 L .655 .809 .957 r
F
.79859 .65965 m .81807 .66111 L .80228 .65749 L F
.79557 .65868 m .8059 .66044 L .80728 .65793 L .655 .81 .958 r
F
.79141 .65571 m .7917 .65916 L .79119 .65428 L 0 0 .362 r
F
.78699 .60334 m .79031 .65276 L .79103 .65315 L .921 .628 .471 r
F
.78731 .60427 m .78699 .60334 L .79103 .65315 L .919 .662 .17 r
F
.78731 .60427 m .79103 .65315 L .79111 .65336 L F
.79153 .65289 m .80628 .65258 L .80629 .65015 L .655 .809 .957 r
F
.78635 .65385 m .79407 .65335 L .79153 .65289 L F
.79407 .65335 m .80628 .65258 L .79153 .65289 L F
.78599 .6026 m .7849 .60226 L .78894 .65241 L .811 .54 .528 r
F
.79127 .65408 m .79134 .6539 L .79176 .65903 L 0 0 .362 r
F
.79134 .6539 m .79167 .65883 L .79176 .65903 L .919 .662 .17 r
F
.79127 .65408 m .79176 .65903 L .7917 .65916 L 0 0 .362 r
F
.78723 .65921 m .79402 .65966 L .79255 .65887 L .655 .81 .958 r
F
.78957 .66149 m .78971 .66402 L .79041 .66231 L F
.79009 .66067 m .79079 .66565 L .7905 .66581 L .424 .252 .542 r
F
.78855 .66114 m .78892 .66108 L .78934 .66622 L .648 .416 .554 r
F
.78855 .66114 m .78934 .66622 L .78909 .66626 L F
.78984 .66076 m .79033 .66587 L .78922 .66098 L .544 .339 .553 r
F
.79033 .66587 m .78992 .66601 L .78922 .66098 L F
.78967 .6661 m .78979 .66622 L .7905 .66581 L .654 .811 .959 r
F
.78979 .66622 m .79018 .669 L .79089 .66729 L F
.79018 .669 m .79081 .67339 L .79089 .66729 L F
.78974 .66624 m .79081 .67339 L .78979 .66622 L F
.78865 .66633 m .79081 .67339 L .78973 .66616 L F
.78934 .66622 m .79132 .67593 L .79015 .67631 L .544 .339 .553 r
F
.78892 .66108 m .78973 .66608 L .78934 .66622 L F
.78967 .6661 m .78934 .66622 L .78973 .66616 L .654 .811 .959 r
F
.78973 .66608 m .79132 .67593 L .78934 .66622 L .544 .339 .553 r
F
.78871 .66655 m .7875 .66686 L .78893 .66726 L .654 .811 .959 r
F
.78865 .66633 m .78822 .66652 L .78871 .66655 L F
.78822 .66652 m .7875 .66686 L .78871 .66655 L F
.78685 .66134 m .7872 .66136 L .78761 .6665 L .75 .494 .544 r
F
.7876 .6665 m .7875 .66686 L .78865 .66633 L .654 .811 .959 r
F
.78738 .66649 m .78761 .6665 L .7884 .67649 L .75 .494 .544 r
F
.78685 .66134 m .78761 .6665 L .78738 .66649 L F
.78763 .66129 m .78848 .66636 L .7872 .66136 L .648 .416 .554 r
F
.78848 .66636 m .79015 .67631 L .78819 .6664 L F
.78848 .66636 m .78819 .6664 L .7872 .66136 L F
.78404 .66074 m .78275 .66062 L .78312 .66118 L .655 .81 .958 r
F
.78723 .65921 m .78377 .6603 L .78404 .66074 L F
.78377 .6603 m .78275 .66062 L .78404 .66074 L F
.78723 .65921 m .78404 .66074 L .78471 .66105 L F
.78404 .66074 m .78388 .66081 L .78412 .66088 L F
.78404 .66074 m .78412 .66088 L .78471 .66105 L F
.7839 .66051 m .78396 .66062 L .78437 .66576 L .966 .687 .262 r
F
.78557 .66774 m .77592 .67342 L .78048 .67405 L .654 .811 .959 r
F
.78535 .66738 m .77592 .67342 L .78557 .66774 L F
.77054 .66144 m .75487 .66897 L .76232 .6714 L .655 .809 .957 r
F
.76788 .65969 m .75487 .66897 L .77054 .66144 L F
.77748 .66229 m .76722 .66291 L .76864 .66507 L .655 .81 .958 r
F
.78326 .655 m .78375 .66025 L .78367 .66012 L .966 .687 .262 r
F
.78377 .6603 m .78135 .6603 L .77748 .66229 L .655 .81 .958 r
F
.78328 .65483 m .78326 .655 L .78367 .66012 L 0 0 .196 r
F
.78328 .65483 m .78367 .66012 L .78368 .66 L F
.78009 .60323 m .78354 .65416 L .78406 .65357 L .159 .061 .485 r
F
.78009 .60323 m .78334 .65439 L .78354 .65416 L F
.77305 .65631 m .76641 .65512 L .76647 .65753 L .655 .809 .957 r
F
.78635 .65385 m .78062 .65421 L .77305 .65631 L F
.78062 .65421 m .76641 .65512 L .77305 .65631 L F
.7826 .60222 m .78138 .60253 L .78538 .65289 L .585 .369 .554 r
F
.78334 .65439 m .78368 .66 L .78374 .65951 L 0 0 .196 r
F
.78723 .65921 m .7837 .65986 L .78377 .6603 L .655 .81 .958 r
F
.7837 .65986 m .78353 .65989 L .78367 .66012 L F
.7837 .65986 m .78367 .66012 L .78377 .6603 L F
.78761 .6665 m .79015 .67631 L .7884 .67649 L .648 .416 .554 r
F
.7872 .66136 m .78819 .6664 L .78761 .6665 L F
.78819 .6664 m .79015 .67631 L .78761 .6665 L F
.77506 .66806 m .77211 .67805 L .77962 .6687 L .655 .81 .958 r
F
.76232 .6714 m .76399 .68185 L .77134 .67264 L .655 .809 .957 r
F
.76232 .6714 m .75051 .68002 L .76399 .68185 L F
.77506 .66806 m .76303 .67681 L .77211 .67805 L .655 .81 .958 r
F
.78487 .66694 m .77217 .67219 L .77592 .67342 L .654 .811 .959 r
F
.78685 .66134 m .78738 .66649 L .78598 .66131 L .75 .494 .544 r
F
.78738 .66649 m .7884 .67649 L .7868 .66646 L F
.78738 .66649 m .7868 .66646 L .78598 .66131 L F
.78412 .66072 m .78469 .66596 L .78396 .66062 L .941 .646 .452 r
F
.7855 .66648 m .78233 .66734 L .78487 .66694 L .654 .811 .959 r
F
.78546 .66645 m .78388 .6669 L .7855 .66648 L F
.78388 .6669 m .78233 .66734 L .78388 .66692 L F
.78388 .6669 m .78388 .66692 L .7855 .66648 L F
.7844 .66636 m .78233 .66734 L .7856 .66641 L F
.77806 .66588 m .776 .66819 L .77962 .6687 L .655 .81 .958 r
F
.78233 .66734 m .77217 .67219 L .78487 .66694 L .654 .811 .959 r
F
.78487 .66694 m .78379 .66772 L .78613 .66688 L F
.78379 .66772 m .7837 .66843 L .78613 .66688 L F
.78469 .66596 m .78458 .66589 L .78396 .66062 L .941 .646 .452 r
F
.78396 .66062 m .78458 .66589 L .78437 .66576 L F
.78353 .65989 m .78135 .6603 L .78377 .6603 L .655 .81 .958 r
F
.7839 .66051 m .78433 .66569 L .78375 .66025 L .966 .687 .262 r
F
.78433 .66569 m .78423 .66552 L .78375 .66025 L F
.76992 .66241 m .76716 .66049 L .76722 .66291 L .655 .81 .958 r
F
.78635 .65385 m .78452 .65614 L .78573 .65619 L .655 .809 .957 r
F
.78062 .65421 m .76771 .6526 L .76641 .65512 L F
.78635 .65385 m .78279 .65361 L .78062 .65421 L F
.78279 .65361 m .76771 .6526 L .78062 .65421 L F
.78354 .65416 m .78334 .65439 L .78374 .65951 L .159 .061 .485 r
F
.78354 .65416 m .78374 .65951 L .78389 .65935 L F
.78328 .65483 m .78368 .66 L .78334 .65439 L 0 0 .196 r
F
.78723 .65921 m .78294 .65948 L .78135 .6603 L .655 .81 .958 r
F
.78556 .66129 m .7868 .66646 L .78597 .66643 L .75 .494 .544 r
F
.78556 .66129 m .78556 .66129 L .78666 .66134 L .655 .81 .958 r
F
.78598 .66131 m .7868 .66646 L .78556 .66129 L .75 .494 .544 r
F
.78535 .66123 m .78556 .66129 L .78597 .66643 L .848 .57 .516 r
F
.78535 .66123 m .78597 .66643 L .78583 .66639 L F
.7849 .6661 m .78469 .66596 L .78412 .66072 L .941 .646 .452 r
F
.78445 .66093 m .78458 .66101 L .78498 .66615 L F
.78445 .66093 m .78498 .66615 L .7849 .6661 L F
.78535 .66123 m .78583 .66639 L .78483 .66108 L .848 .57 .516 r
F
.78583 .66639 m .78549 .66629 L .78483 .66108 L F
.78489 .66612 m .78268 .6663 L .78129 .66784 L .654 .811 .959 r
F
.78458 .66101 m .78532 .66624 L .78498 .66615 L .848 .57 .516 r
F
.78483 .66108 m .78549 .66629 L .78458 .66101 L F
.78569 .66635 m .7844 .66636 L .7856 .66641 L .654 .811 .959 r
F
.78489 .66612 m .7844 .66636 L .78569 .66635 L F
.78651 .66658 m .78487 .66694 L .78642 .66669 L F
.78811 .66459 m .78569 .66635 L .78651 .66658 L F
.78569 .66635 m .78487 .66694 L .78651 .66658 L F
.78487 .66694 m .78613 .66688 L .78595 .66676 L F
.78642 .66669 m .78535 .66738 L .78557 .66774 L F
.78549 .66629 m .78675 .67626 L .78532 .66624 L .848 .57 .516 r
F
.78549 .66629 m .78532 .66624 L .78458 .66101 L F
.78811 .66459 m .78489 .66612 L .78569 .66635 L .654 .811 .959 r
F
.78811 .66459 m .78402 .66588 L .78489 .66612 L F
.78402 .66588 m .78268 .6663 L .78489 .66612 L F
.78498 .66615 m .78675 .67626 L .78575 .67584 L .848 .57 .516 r
F
.78532 .66624 m .78675 .67626 L .78498 .66615 L F
.78635 .65385 m .78715 .65644 L .78851 .65596 L .655 .809 .957 r
F
.78635 .65385 m .78851 .65596 L .78851 .65596 L F
.78635 .65385 m .78851 .65596 L .78983 .6555 L F
.78811 .66459 m .7876 .6665 L .78865 .66633 L .654 .811 .959 r
F
.78723 .65921 m .78663 .66145 L .78786 .66125 L .655 .81 .958 r
F
.78723 .65921 m .78556 .66129 L .78666 .66134 L F
.78597 .66643 m .7884 .67649 L .78675 .67626 L .75 .494 .544 r
F
.78595 .66676 m .78613 .66688 L .78642 .66669 L .654 .811 .959 r
F
.7868 .66646 m .7884 .67649 L .78597 .66643 L .75 .494 .544 r
F
.78811 .66459 m .78661 .66645 L .7876 .6665 L .654 .811 .959 r
F
.78723 .65921 m .78471 .66105 L .78556 .66129 L .655 .81 .958 r
F
.77131 .66683 m .76303 .67681 L .77506 .66806 L F
.75487 .66897 m .75051 .68002 L .76232 .6714 L .655 .809 .957 r
F
.77131 .66683 m .75554 .67438 L .76303 .67681 L .655 .81 .958 r
F
.76864 .66507 m .75554 .67438 L .77131 .66683 L F
.77593 .66842 m .76807 .66829 L .76949 .67044 L .654 .811 .959 r
F
.78375 .66025 m .78423 .66552 L .78367 .66012 L .966 .687 .262 r
F
.7839 .66051 m .78437 .66576 L .78433 .66569 L F
.76788 .65969 m .74952 .6655 L .75487 .66897 L .655 .809 .957 r
F
.76647 .65753 m .74952 .6655 L .76788 .65969 L F
.77977 .65969 m .76847 .65797 L .76716 .66049 L .655 .81 .958 r
F
.78138 .60253 m .78406 .65357 L .78442 .65338 L .454 .273 .545 r
F
.78635 .65385 m .77029 .65017 L .76771 .6526 L .655 .809 .957 r
F
.78354 .65416 m .78389 .65935 L .78406 .65357 L .159 .061 .485 r
F
.78389 .65935 m .78427 .65891 L .78406 .65357 L F
.78138 .60253 m .78442 .65338 L .78538 .65289 L .454 .273 .545 r
F
.78635 .65385 m .77398 .64797 L .77029 .65017 L .655 .809 .957 r
F
.78442 .65338 m .78406 .65357 L .78447 .6587 L .454 .273 .545 r
F
.78723 .65921 m .7839 .65899 L .78294 .65948 L .655 .81 .958 r
F
.78423 .66552 m .78418 .66544 L .78367 .66012 L .966 .687 .262 r
F
.78367 .66012 m .78418 .66544 L .78407 .66527 L F
.78811 .66459 m .78411 .66533 L .78437 .66576 L .654 .811 .959 r
F
.78161 .6619 m .77131 .66683 L .77806 .66588 L .655 .81 .958 r
F
.77806 .66588 m .77506 .66806 L .776 .66819 L F
.78077 .66595 m .76801 .66588 L .76807 .66829 L .654 .811 .959 r
F
.78374 .65951 m .78412 .66487 L .78414 .66466 L 0 0 .196 r
F
.78368 .66 m .78408 .66519 L .78374 .65951 L F
.78408 .66519 m .78412 .66487 L .78374 .65951 L F
.78368 .66 m .78367 .66012 L .78407 .66527 L F
.78368 .66 m .78407 .66527 L .78408 .66519 L F
.78811 .66459 m .78397 .66485 L .78343 .66545 L .654 .811 .959 r
F
.78437 .66576 m .7831 .66583 L .78268 .6663 L F
.78411 .66533 m .78077 .66595 L .78437 .66576 L F
.78407 .66527 m .78512 .67533 L .78482 .67472 L .966 .687 .262 r
F
.78488 .67298 m .78488 .674 L .78497 .67388 L .159 .061 .485 r
F
.78469 .66596 m .78575 .67584 L .78458 .66589 L .941 .646 .452 r
F
.78437 .66576 m .78575 .67584 L .78512 .67533 L F
.78458 .66589 m .78575 .67584 L .78437 .66576 L F
.78433 .66569 m .78437 .66576 L .78512 .67533 L .966 .687 .262 r
F
.78423 .66552 m .78512 .67533 L .78418 .66544 L F
.78433 .66569 m .78512 .67533 L .78423 .66552 L F
.7849 .6661 m .78575 .67584 L .78469 .66596 L .941 .646 .452 r
F
.7849 .6661 m .78498 .66615 L .78575 .67584 L F
.78488 .67298 m .78497 .67388 L .7856 .6731 L .159 .061 .485 r
F
.78418 .66544 m .78512 .67533 L .78407 .66527 L .966 .687 .262 r
F
.78125 .6611 m .76864 .66507 L .78312 .66118 L .655 .81 .958 r
F
.75487 .66897 m .73936 .67642 L .75051 .68002 L .655 .809 .957 r
F
.74952 .6655 m .73936 .67642 L .75487 .66897 L F
.76864 .66507 m .75016 .6709 L .75554 .67438 L .655 .81 .958 r
F
.76722 .66291 m .75016 .6709 L .76864 .66507 L F
.77892 .66518 m .76933 .66336 L .76801 .66588 L .654 .811 .959 r
F
.78442 .65338 m .78447 .6587 L .78473 .65856 L .454 .273 .545 r
F
.78406 .65357 m .78427 .65891 L .78447 .6587 L .159 .061 .485 r
F
.77924 .65868 m .77107 .65553 L .76847 .65797 L .655 .81 .958 r
F
.78723 .65921 m .78286 .65822 L .77924 .65868 L F
.78286 .65822 m .77107 .65553 L .77924 .65868 L F
.78635 .65385 m .78567 .65642 L .78707 .65619 L .655 .809 .957 r
F
.78377 .60214 m .7826 .60222 L .78661 .65255 L .664 .428 .553 r
F
.78377 .60214 m .78661 .65255 L .78672 .65253 L F
.78635 .65385 m .78748 .65244 L .7867 .65254 L .655 .809 .957 r
F
.78599 .6026 m .78894 .65241 L .78924 .65246 L .811 .54 .528 r
F
.78599 .6026 m .78924 .65246 L .79003 .65261 L F
.78699 .60334 m .79003 .65261 L .79031 .65276 L .921 .628 .471 r
F
.7849 .60226 m .78811 .6524 L .78894 .65241 L .734 .481 .546 r
F
.78635 .65385 m .78833 .6524 L .7878 .6524 L .655 .809 .957 r
F
.78377 .60214 m .78694 .65251 L .7878 .6524 L .664 .428 .553 r
F
.78748 .65244 m .7878 .6524 L .78751 .65239 L .655 .809 .957 r
F
.78635 .65385 m .7878 .6524 L .78748 .65244 L F
.78389 .65935 m .78424 .66455 L .78427 .65891 L .159 .061 .485 r
F
.78337 .66272 m .77806 .66588 L .78334 .66299 L .655 .81 .958 r
F
.78397 .66485 m .7824 .66422 L .77892 .66518 L .654 .811 .959 r
F
.78811 .66459 m .78442 .66435 L .78397 .66485 L F
.78424 .66455 m .78449 .66427 L .78427 .65891 L .159 .061 .485 r
F
.78389 .65935 m .78374 .65951 L .78414 .66466 L F
.78389 .65935 m .78414 .66466 L .78424 .66455 L F
.78442 .66435 m .7824 .66422 L .78397 .66485 L .654 .811 .959 r
F
.78811 .66459 m .78865 .66633 L .78934 .66622 L F
.78811 .66459 m .78934 .66622 L .78967 .6661 L F
.78909 .66102 m .78907 .66106 L .78912 .66105 L .655 .81 .958 r
F
.78922 .66098 m .78992 .66601 L .78892 .66108 L .544 .339 .553 r
F
.7901 .66652 m .79089 .66729 L .79073 .66592 L .654 .811 .959 r
F
.79089 .66729 m .79525 .67153 L .79121 .66651 L F
.79089 .66729 m .79121 .66651 L .79073 .66592 L F
.79157 .65949 m .79205 .66447 L .7915 .65965 L 0 0 .362 r
F
.7917 .65916 m .79176 .65903 L .79217 .66417 L F
.79525 .67153 m .79513 .67124 L .79121 .6665 L .654 .811 .959 r
F
.79525 .67153 m .79121 .6665 L .79121 .66651 L F
.79525 .67153 m .79073 .66592 L .79073 .66592 L F
.79073 .66592 m .79588 .67214 L .7908 .66585 L F
.79093 .66019 m .79154 .66515 L .79135 .66533 L .231 .113 .505 r
F
.78992 .66601 m .78973 .66608 L .78892 .66108 L .544 .339 .553 r
F
.78723 .65921 m .79039 .6607 L .79105 .66008 L .655 .81 .958 r
F
.79075 .66029 m .79123 .6654 L .7903 .66055 L .424 .252 .542 r
F
.79296 .66192 m .79499 .66679 L .79954 .66502 L .655 .81 .958 r
F
.79499 .66678 m .79499 .66679 L .79296 .66192 L F
.79499 .66679 m .8117 .67077 L .79954 .66502 L F
.79113 .66554 m .80043 .67038 L .80257 .66914 L .654 .811 .959 r
F
.79103 .66551 m .79112 .66555 L .79113 .66554 L F
.79112 .66555 m .80043 .67038 L .79113 .66554 L F
.79138 .65976 m .7915 .65965 L .79192 .66479 L .231 .113 .505 r
F
.7906 .66576 m .80043 .67038 L .79103 .66551 L .654 .811 .959 r
F
.79123 .6654 m .79093 .66557 L .7903 .66055 L .424 .252 .542 r
F
.79075 .66029 m .79093 .66019 L .79135 .66533 L F
.79075 .66029 m .79135 .66533 L .79123 .6654 L F
.79168 .6654 m .80257 .66914 L .79842 .66692 L .654 .811 .959 r
F
.78984 .66076 m .79009 .66067 L .7905 .66581 L .544 .339 .553 r
F
.78984 .66076 m .7905 .66581 L .79033 .66587 L F
.7902 .66061 m .79017 .66064 L .79023 .66062 L .655 .81 .958 r
F
.7903 .66055 m .79093 .66557 L .79009 .66067 L .424 .252 .542 r
F
.79093 .66557 m .79216 .67543 L .79079 .66565 L F
.79093 .66557 m .79079 .66565 L .79009 .66067 L F
.79136 .66532 m .79121 .66556 L .79168 .6654 L .654 .811 .959 r
F
.78811 .66459 m .79103 .66551 L .79136 .66532 L F
.79103 .66551 m .79121 .66556 L .79136 .66532 L F
.79121 .66556 m .80257 .66914 L .79168 .6654 L F
.7901 .66652 m .79073 .66592 L .79061 .66577 L F
.79033 .66587 m .7905 .66581 L .79132 .67593 L .544 .339 .553 r
F
.79138 .65976 m .79192 .66479 L .79184 .66486 L .231 .113 .505 r
F
.79108 .66005 m .79164 .66505 L .79093 .66019 L F
.79164 .66505 m .79154 .66515 L .79093 .66019 L F
.79138 .65976 m .79184 .66486 L .79108 .66005 L F
.79184 .66486 m .79164 .66505 L .79108 .66005 L F
.81068 .66539 m .82264 .67106 L .83374 .6647 L .655 .809 .957 r
F
.79954 .66502 m .8117 .67077 L .81915 .66647 L .655 .81 .958 r
F
.79488 .66503 m .80415 .66822 L .8068 .66581 L .654 .811 .959 r
F
.78811 .66459 m .79842 .66692 L .79488 .66503 L F
.79842 .66692 m .80415 .66822 L .79488 .66503 L F
.79205 .66447 m .79201 .66458 L .7915 .65965 L 0 0 .362 r
F
.7849 .60226 m .78377 .60214 L .7878 .6524 L .734 .481 .546 r
F
.78635 .65385 m .79385 .65246 L .79084 .65243 L .655 .809 .957 r
F
.78811 .66459 m .79488 .66503 L .79486 .66502 L .654 .811 .959 r
F
.7915 .65965 m .79201 .66458 L .79192 .66479 L 0 0 .362 r
F
.79296 .66192 m .79954 .66502 L .79231 .66037 L .655 .81 .958 r
F
.79214 .66425 m .79205 .66447 L .79157 .65949 L 0 0 .362 r
F
.81068 .66539 m .83374 .6647 L .81807 .66111 L .655 .809 .957 r
F
.79954 .66502 m .81915 .66647 L .80326 .66286 L .655 .81 .958 r
F
.78811 .66459 m .80681 .66579 L .79707 .66402 L .654 .811 .959 r
F
.78811 .66459 m .7906 .66576 L .79103 .66551 L F
.78811 .66459 m .78967 .6661 L .7906 .66576 L F
.78723 .65921 m .78923 .66116 L .7902 .66061 L .655 .81 .958 r
F
.78635 .65385 m .80232 .64617 L .7986 .6449 L .655 .809 .957 r
F
.78635 .65385 m .80495 .64796 L .80232 .64617 L F
.79031 .65276 m .79065 .65785 L .79103 .65315 L .921 .628 .471 r
F
.78723 .65921 m .79255 .65887 L .79246 .65882 L .655 .81 .958 r
F
.79166 .65839 m .80728 .65771 L .79593 .6576 L F
.79111 .65336 m .79149 .65838 L .79151 .65843 L .919 .662 .17 r
F
.79127 .65408 m .79141 .65571 L .79119 .65428 L 0 0 .362 r
F
.79111 .65336 m .79151 .65843 L .79134 .6539 L .919 .662 .17 r
F
.79151 .65843 m .79167 .65883 L .79134 .6539 L F
.78723 .65921 m .79246 .65882 L .79166 .65839 L .655 .81 .958 r
F
.79246 .65882 m .80728 .65771 L .79166 .65839 L F
.79101 .65804 m .79118 .65814 L .79103 .65315 L .921 .628 .471 r
F
.79065 .65785 m .79101 .65804 L .79103 .65315 L F
.80491 .65508 m .82337 .65631 L .82618 .65131 L .655 .809 .957 r
F
.80228 .65749 m .82337 .65631 L .80491 .65508 L F
.80491 .65508 m .82618 .65131 L .80628 .65258 L F
.79244 .65757 m .8073 .6555 L .80595 .65331 L .655 .81 .958 r
F
.78924 .65246 m .78894 .65241 L .78935 .65754 L .811 .54 .528 r
F
.79103 .65315 m .79118 .65814 L .79144 .65827 L .921 .628 .471 r
F
.79111 .65336 m .79103 .65315 L .79144 .65827 L .919 .662 .17 r
F
.79111 .65336 m .79144 .65827 L .79149 .65838 L F
.79098 .65803 m .79283 .65817 L .79136 .65791 L .655 .81 .958 r
F
.78723 .65921 m .79166 .65839 L .79098 .65803 L F
.79166 .65839 m .79283 .65817 L .79098 .65803 L F
.79144 .65827 m .79134 .66314 L .79186 .66342 L .921 .628 .471 r
F
.79118 .65814 m .79134 .66314 L .79144 .65827 L F
.78924 .65246 m .78935 .65754 L .7895 .65757 L .811 .54 .528 r
F
.79084 .65243 m .80629 .65015 L .80495 .64796 L .655 .809 .957 r
F
.79385 .65246 m .80629 .65015 L .79084 .65243 L F
.78924 .65246 m .7895 .65757 L .78957 .65758 L .811 .54 .528 r
F
.78723 .65921 m .78949 .65756 L .78935 .65754 L .655 .81 .958 r
F
.78979 .66622 m .7901 .66652 L .79061 .66577 L .654 .811 .959 r
F
.78973 .66616 m .78974 .66624 L .78979 .66622 L F
.78992 .66601 m .79132 .67593 L .78973 .66608 L .544 .339 .553 r
F
.78979 .66622 m .79061 .66577 L .7905 .66581 L .654 .811 .959 r
F
.78967 .6661 m .7905 .66581 L .7906 .66576 L F
.79033 .66587 m .79132 .67593 L .78992 .66601 L .544 .339 .553 r
F
.78909 .66626 m .78934 .66622 L .79015 .67631 L .648 .416 .554 r
F
.78909 .66626 m .79015 .67631 L .78848 .66636 L F
.79031 .65276 m .79003 .65261 L .79044 .65774 L .921 .628 .471 r
F
.79031 .65276 m .79044 .65774 L .79065 .65785 L F
.79003 .65261 m .79016 .65769 L .79044 .65774 L .811 .54 .528 r
F
.78924 .65246 m .78957 .65758 L .79003 .65261 L F
.78723 .65921 m .79034 .65772 L .78949 .65756 L .655 .81 .958 r
F
.79168 .65708 m .80595 .65331 L .80331 .65152 L F
.78811 .6524 m .78844 .65753 L .78894 .65241 L .734 .481 .546 r
F
.78723 .65921 m .79244 .65757 L .7907 .65755 L .655 .81 .958 r
F
.78723 .65921 m .78935 .65754 L .78858 .65753 L F
.78844 .65753 m .78905 .65753 L .78894 .65241 L .734 .481 .546 r
F
.78726 .65765 m .7879 .65757 L .7878 .6524 L .664 .428 .553 r
F
.78957 .65758 m .79016 .65769 L .79003 .65261 L .811 .54 .528 r
F
.7878 .6524 m .7879 .65757 L .78821 .65753 L .664 .428 .553 r
F
.78894 .65241 m .78905 .65753 L .78935 .65754 L .734 .481 .546 r
F
.78811 .6524 m .78837 .65753 L .78844 .65753 L F
.78811 .6524 m .7878 .6524 L .78821 .65753 L F
.78811 .6524 m .78821 .65753 L .78837 .65753 L F
.7849 .60226 m .7878 .6524 L .78811 .6524 L F
.78751 .65239 m .7986 .6449 L .79402 .64425 L .655 .809 .957 r
F
.78833 .6524 m .7986 .6449 L .78751 .65239 L F
.78723 .65921 m .79495 .64959 L .78981 .64959 L .655 .81 .958 r
F
.78957 .65758 m .78991 .66271 L .79016 .65769 L .811 .54 .528 r
F
.7917 .65916 m .79217 .66417 L .79214 .66425 L 0 0 .362 r
F
.7917 .65916 m .79214 .66425 L .79157 .65949 L F
.79214 .66424 m .79707 .66402 L .79632 .66388 L .654 .811 .959 r
F
.78811 .66459 m .7921 .66433 L .79214 .66424 L F
.7921 .66433 m .79707 .66402 L .79214 .66424 L F
.79231 .66037 m .80326 .66286 L .79196 .65952 L .655 .81 .958 r
F
.81807 .66111 m .83374 .6647 L .84173 .65753 L .655 .809 .957 r
F
.80326 .66286 m .81915 .66647 L .82448 .66166 L .655 .81 .958 r
F
.80326 .66286 m .82448 .66166 L .8059 .66044 L F
.79412 .66348 m .80819 .66285 L .79802 .66276 L .654 .811 .959 r
F
.79201 .66378 m .79206 .66391 L .79176 .65903 L .919 .662 .17 r
F
.79176 .65903 m .79206 .66391 L .79217 .66417 L F
.78811 .66459 m .79632 .66388 L .79412 .66348 L .654 .811 .959 r
F
.79632 .66388 m .80819 .66285 L .79412 .66348 L F
.79121 .66651 m .79121 .6665 L .79073 .66592 L F
.7908 .66585 m .79125 .66641 L .79137 .66612 L F
.79123 .6654 m .79216 .67543 L .79093 .66557 L .424 .252 .542 r
F
.7905 .66581 m .79216 .67543 L .79132 .67593 L F
.79073 .66592 m .79073 .66592 L .79061 .66577 L .654 .811 .959 r
F
.7905 .66581 m .79061 .66577 L .7906 .66576 L F
.7906 .66576 m .79073 .66592 L .7908 .66585 L F
.79079 .66565 m .79216 .67543 L .7905 .66581 L .424 .252 .542 r
F
.79044 .65774 m .79047 .66281 L .79086 .66288 L .811 .54 .528 r
F
.79593 .6576 m .8073 .6555 L .79244 .65757 L .655 .81 .958 r
F
.79099 .66296 m .79134 .66314 L .79118 .65814 L .921 .628 .471 r
F
.79246 .65882 m .80728 .65793 L .80728 .65771 L .655 .81 .958 r
F
.79255 .65887 m .80728 .65793 L .79246 .65882 L F
.79593 .6576 m .80728 .65771 L .8073 .6555 L F
.79151 .65843 m .7919 .66352 L .79167 .65883 L .919 .662 .17 r
F
.7919 .66352 m .79201 .66378 L .79167 .65883 L F
.79255 .65887 m .80479 .66037 L .79557 .65868 L .655 .81 .958 r
F
.79402 .65966 m .80479 .66037 L .79255 .65887 L F
.80479 .66037 m .8059 .66044 L .79557 .65868 L F
.79167 .65883 m .79201 .66378 L .79176 .65903 L .919 .662 .17 r
F
.79151 .65843 m .79186 .66342 L .7919 .66352 L F
.79149 .65838 m .79186 .66342 L .79151 .65843 L F
.79149 .65838 m .79144 .65827 L .79186 .66342 L F
.79122 .66234 m .80421 .65691 L .80046 .65565 L .654 .811 .959 r
F
.79099 .66296 m .79118 .65814 L .79101 .65804 L .921 .628 .471 r
F
.79065 .65785 m .79099 .66296 L .79101 .65804 L F
.79065 .65785 m .79044 .65774 L .79086 .66288 L F
.79065 .65785 m .79086 .66288 L .79099 .66296 L F
.79055 .66283 m .79206 .66271 L .79073 .66269 L .654 .811 .959 r
F
.78811 .66459 m .79146 .66299 L .79055 .66283 L F
.79146 .66299 m .79206 .66271 L .79055 .66283 L F
.79016 .65769 m .79029 .66278 L .79044 .65774 L .811 .54 .528 r
F
.79029 .66278 m .79047 .66281 L .79044 .65774 L F
.78935 .65754 m .78936 .66268 L .78976 .66268 L .734 .481 .546 r
F
.78991 .66271 m .79029 .66278 L .79016 .65769 L .811 .54 .528 r
F
.7907 .65755 m .79558 .65658 L .79168 .65708 L .655 .81 .958 r
F
.79244 .65757 m .79558 .65658 L .7907 .65755 L F
.79558 .65658 m .80595 .65331 L .79168 .65708 L F
.79168 .65708 m .80331 .65152 L .78983 .65732 L F
.78957 .65758 m .78976 .66268 L .78991 .66271 L .811 .54 .528 r
F
.79136 .65791 m .79593 .6576 L .79244 .65757 L .655 .81 .958 r
F
.79283 .65817 m .79593 .6576 L .79136 .65791 L F
.78978 .66253 m .80046 .65565 L .79585 .65499 L .654 .811 .959 r
F
.78905 .65753 m .78916 .66268 L .78935 .65754 L .734 .481 .546 r
F
.78811 .66459 m .79073 .66269 L .78965 .66268 L .654 .811 .959 r
F
.78916 .66268 m .78936 .66268 L .78935 .65754 L .734 .481 .546 r
F
.78844 .65753 m .78877 .66268 L .78905 .65753 L F
.78877 .66268 m .78916 .66268 L .78905 .65753 L F
.78949 .65756 m .79168 .65708 L .78983 .65732 L .655 .81 .958 r
F
.79034 .65772 m .79168 .65708 L .78949 .65756 L F
.78983 .65732 m .80331 .65152 L .79956 .65025 L F
.78867 .65741 m .79956 .65025 L .79495 .64959 L F
.78949 .65756 m .79956 .65025 L .78867 .65741 L F
.7895 .65757 m .78976 .66268 L .78957 .65758 L .811 .54 .528 r
F
.7895 .65757 m .78935 .65754 L .78976 .66268 L F
.78844 .65753 m .78862 .66267 L .78877 .66268 L .734 .481 .546 r
F
.78811 .66459 m .79585 .65499 L .7907 .655 L .654 .811 .959 r
F
.78811 .66459 m .80686 .6587 L .80421 .65691 L F
.81807 .66111 m .84173 .65753 L .82337 .65631 L .655 .809 .957 r
F
.8059 .66044 m .82448 .66166 L .82731 .65665 L .655 .81 .958 r
F
.8059 .66044 m .82731 .65665 L .80728 .65793 L F
.78811 .66459 m .80821 .66088 L .80686 .6587 L .654 .811 .959 r
F
.78916 .66268 m .78937 .67204 L .78936 .66268 L .734 .481 .546 r
F
.78965 .66268 m .79122 .66234 L .78978 .66253 L .654 .811 .959 r
F
.79073 .66269 m .79122 .66234 L .78965 .66268 L F
.79122 .66234 m .80046 .65565 L .78978 .66253 L F
.7879 .65757 m .78799 .66275 L .78821 .65753 L .664 .428 .553 r
F
.78135 .6603 m .77977 .65969 L .76992 .66241 L .655 .81 .958 r
F
.77977 .65969 m .76716 .66049 L .76992 .66241 L F
.78135 .6603 m .76722 .66291 L .77748 .66229 L F
.77858 .66397 m .77193 .66093 L .76933 .66336 L .654 .811 .959 r
F
.78447 .6587 m .78461 .66414 L .78487 .66385 L .159 .061 .485 r
F
.78395 .66432 m .78423 .66371 L .7824 .66422 L .654 .811 .959 r
F
.78427 .65891 m .78449 .66427 L .78447 .6587 L .159 .061 .485 r
F
.78811 .66459 m .78486 .66385 L .78442 .66435 L .654 .811 .959 r
F
.78449 .66427 m .78488 .674 L .78461 .66414 L .159 .061 .485 r
F
.78449 .66427 m .78461 .66414 L .78447 .6587 L F
.78442 .66435 m .78486 .66385 L .78395 .66432 L .654 .811 .959 r
F
.78486 .66385 m .78486 .66385 L .78442 .66435 L F
.78486 .66385 m .78423 .66371 L .78395 .66432 L F
.78635 .65385 m .77853 .64618 L .77398 .64797 L .655 .809 .957 r
F
.78442 .65338 m .78473 .65856 L .78538 .65289 L .454 .273 .545 r
F
.78473 .65856 m .78544 .6582 L .78538 .65289 L F
.78723 .65921 m .77479 .65333 L .77107 .65553 L .655 .81 .958 r
F
.7826 .60222 m .78572 .6528 L .78661 .65255 L .585 .369 .554 r
F
.7826 .60222 m .78538 .65289 L .78572 .6528 L F
.78635 .65385 m .78363 .64491 L .77853 .64618 L .655 .809 .957 r
F
.78572 .6528 m .78538 .65289 L .78579 .65802 L .585 .369 .554 r
F
.78572 .6528 m .78579 .65802 L .78604 .65795 L F
.78538 .65289 m .78544 .6582 L .78579 .65802 L .454 .273 .545 r
F
.78723 .65921 m .77937 .65153 L .77479 .65333 L .655 .81 .958 r
F
.78544 .6582 m .7855 .66353 L .78579 .65802 L .454 .273 .545 r
F
.7856 .66641 m .78546 .66645 L .7855 .66648 L .654 .811 .959 r
F
.78583 .66639 m .78675 .67626 L .78549 .66629 L .848 .57 .516 r
F
.7855 .66353 m .78572 .66341 L .78579 .65802 L .454 .273 .545 r
F
.7826 .6589 m .76847 .65797 L .77977 .65969 L .655 .81 .958 r
F
.7829 .66341 m .77565 .65873 L .77193 .66093 L .654 .811 .959 r
F
.78473 .65856 m .78447 .6587 L .78487 .66385 L .454 .273 .545 r
F
.78473 .65856 m .78487 .66385 L .78504 .66376 L F
.78473 .65856 m .78504 .66376 L .78544 .6582 L F
.78504 .66376 m .7855 .66353 L .78544 .6582 L F
.78635 .65385 m .7867 .65254 L .78598 .65263 L .655 .809 .957 r
F
.78572 .6528 m .78604 .65795 L .78661 .65255 L .585 .369 .554 r
F
.78604 .65795 m .7867 .65777 L .78661 .65255 L F
.78661 .65255 m .7867 .65777 L .78702 .65768 L F
.78723 .65921 m .78449 .65025 L .77937 .65153 L .655 .81 .958 r
F
.78694 .65251 m .78726 .65765 L .7878 .6524 L .664 .428 .553 r
F
.78694 .65251 m .78702 .65768 L .78726 .65765 L F
.78377 .60214 m .78672 .65253 L .78694 .65251 L F
.78672 .65253 m .78702 .65768 L .78694 .65251 L F
.7867 .65254 m .79402 .64425 L .78891 .64425 L .655 .809 .957 r
F
.78748 .65244 m .79402 .64425 L .7867 .65254 L F
.78598 .65263 m .78891 .64425 L .78363 .64491 L F
.7867 .65254 m .78891 .64425 L .78598 .65263 L F
.78672 .65253 m .78661 .65255 L .78702 .65768 L .664 .428 .553 r
F
.78723 .65921 m .78981 .64959 L .78449 .65025 L .655 .81 .958 r
F
.7867 .65777 m .78678 .66301 L .78702 .65768 L .585 .369 .554 r
F
.78811 .66459 m .7855 .66336 L .78423 .66371 L .654 .811 .959 r
F
.78604 .65795 m .78636 .66312 L .7867 .65777 L .585 .369 .554 r
F
.78636 .66312 m .78678 .66301 L .7867 .65777 L F
.78294 .65948 m .7826 .6589 L .77977 .65969 L .655 .81 .958 r
F
.78294 .65948 m .77977 .65969 L .78135 .6603 L F
.78275 .66062 m .78125 .6611 L .78229 .66114 L F
.78275 .66062 m .78229 .66114 L .78312 .66118 L F
.7855 .66336 m .78024 .65694 L .77565 .65873 L .654 .811 .959 r
F
.78811 .66459 m .78655 .66307 L .7855 .66336 L F
.78604 .65795 m .78579 .65802 L .7862 .66317 L .585 .369 .554 r
F
.78604 .65795 m .7862 .66317 L .78636 .66312 L F
.78579 .65802 m .78572 .66341 L .7862 .66317 L .454 .273 .545 r
F
.78655 .66307 m .78024 .65694 L .7855 .66336 L .654 .811 .959 r
F
.78636 .66312 m .7862 .66317 L .78693 .67241 L .585 .369 .554 r
F
.78678 .66301 m .78699 .66295 L .78702 .65768 L F
.78726 .65765 m .78702 .65768 L .78743 .66283 L .664 .428 .553 r
F
.78726 .65765 m .78743 .66283 L .78759 .66281 L F
.78702 .65768 m .78699 .66295 L .78743 .66283 L .585 .369 .554 r
F
.7839 .65899 m .7826 .6589 L .78294 .65948 L .655 .81 .958 r
F
.78811 .66459 m .78538 .65566 L .78024 .65694 L .654 .811 .959 r
F
.78678 .66301 m .78693 .67241 L .78699 .66295 L .585 .369 .554 r
F
.78423 .66371 m .78502 .66314 L .7829 .66341 L .654 .811 .959 r
F
.7855 .66336 m .78502 .66314 L .78423 .66371 L F
.78502 .66314 m .77565 .65873 L .7829 .66341 L F
.78726 .65765 m .78759 .66281 L .7879 .65757 L .664 .428 .553 r
F
.78759 .66281 m .78799 .66275 L .7879 .65757 L F
.78799 .66275 m .7882 .66273 L .78821 .65753 L F
.78821 .65753 m .7882 .66273 L .78862 .66267 L F
.78858 .65753 m .78935 .65754 L .78867 .65741 L .655 .81 .958 r
F
.78837 .65753 m .78862 .66267 L .78844 .65753 L .734 .481 .546 r
F
.78837 .65753 m .78821 .65753 L .78862 .66267 L F
.78811 .66459 m .7907 .655 L .78538 .65566 L .654 .811 .959 r
F
.78759 .66281 m .78743 .66283 L .78817 .67211 L .664 .428 .553 r
F
.7855 .66353 m .7856 .6731 L .78572 .66341 L .454 .273 .545 r
F
.78743 .66283 m .78693 .67241 L .78817 .67211 L .585 .369 .554 r
F
.78699 .66295 m .78693 .67241 L .78743 .66283 L F
.7824 .66422 m .7829 .66341 L .77858 .66397 L .654 .811 .959 r
F
.78423 .66371 m .7829 .66341 L .7824 .66422 L F
.7829 .66341 m .77193 .66093 L .77858 .66397 L F
.78759 .66281 m .78817 .67211 L .78799 .66275 L .664 .428 .553 r
F
.78799 .66275 m .78817 .67211 L .7882 .66273 L F
.79029 .66278 m .79053 .67215 L .79047 .66281 L .811 .54 .528 r
F
.78976 .66268 m .78937 .67204 L .79053 .67215 L .734 .481 .546 r
F
.78936 .66268 m .78937 .67204 L .78976 .66268 L F
.79073 .66269 m .79342 .66206 L .79122 .66234 L .654 .811 .959 r
F
.79206 .66271 m .79342 .66206 L .79073 .66269 L F
.79342 .66206 m .80421 .65691 L .79122 .66234 L F
.78862 .66267 m .78817 .67211 L .78937 .67204 L .664 .428 .553 r
F
.7882 .66273 m .78817 .67211 L .78862 .66267 L F
.79086 .66288 m .79053 .67215 L .79163 .67248 L .811 .54 .528 r
F
.79047 .66281 m .79053 .67215 L .79086 .66288 L F
.78991 .66271 m .79053 .67215 L .79029 .66278 L F
.79632 .66388 m .80819 .6633 L .80819 .66285 L .654 .811 .959 r
F
.79707 .66402 m .80819 .6633 L .79632 .66388 L F
.79802 .66276 m .80819 .66285 L .80821 .66088 L F
.78877 .66268 m .78937 .67204 L .78916 .66268 L .734 .481 .546 r
F
.78877 .66268 m .78862 .66267 L .78937 .67204 L F
.79135 .66533 m .79273 .67483 L .79216 .67543 L .231 .113 .505 r
F
.79154 .66515 m .79273 .67483 L .79135 .66533 L F
.79123 .6654 m .79135 .66533 L .79216 .67543 L .424 .252 .542 r
F
.79099 .66296 m .79163 .67248 L .79134 .66314 L .921 .628 .471 r
F
.79486 .66502 m .8068 .66581 L .80681 .66579 L .654 .811 .959 r
F
.79488 .66503 m .8068 .66581 L .79486 .66502 L F
.79707 .66402 m .80681 .66579 L .80819 .6633 L F
.78991 .66271 m .78976 .66268 L .79053 .67215 L .811 .54 .528 r
F
.79184 .66486 m .79192 .66479 L .79273 .67483 L .231 .113 .505 r
F
.79164 .66505 m .79273 .67483 L .79154 .66515 L F
.79192 .66479 m .7921 .66637 L .7926 .67316 L 0 0 .362 r
F
.7921 .66637 m .79298 .67412 L .7926 .67316 L F
.7926 .67316 m .79298 .67412 L .79273 .67483 L F
.79184 .66486 m .79273 .67483 L .79164 .66505 L .231 .113 .505 r
F
.79186 .66342 m .79163 .67248 L .79265 .6732 L .921 .628 .471 r
F
.79134 .66314 m .79163 .67248 L .79186 .66342 L F
.79842 .66692 m .80257 .66914 L .80415 .66822 L .654 .811 .959 r
F
.79099 .66296 m .79086 .66288 L .79163 .67248 L .921 .628 .471 r
F
.79214 .66425 m .79217 .66417 L .79298 .67412 L 0 0 .362 r
F
.79205 .66447 m .79298 .67412 L .79201 .66458 L F
.79525 .67153 m .79588 .67214 L .79513 .67124 L .654 .811 .959 r
F
.79201 .66458 m .79298 .67412 L .79192 .66479 L 0 0 .362 r
F
.7919 .66352 m .79265 .6732 L .79201 .66378 L .919 .662 .17 r
F
.7824 .66422 m .76933 .66336 L .77892 .66518 L .654 .811 .959 r
F
.78636 .66312 m .78693 .67241 L .78678 .66301 L .585 .369 .554 r
F
.78487 .66385 m .78488 .67298 L .7856 .6731 L .159 .061 .485 r
F
.78461 .66414 m .78488 .674 L .78487 .66385 L F
.78343 .66545 m .78275 .66493 L .78077 .66595 L .654 .811 .959 r
F
.78397 .66485 m .78275 .66493 L .78343 .66545 L F
.78275 .66493 m .76801 .66588 L .78077 .66595 L F
.78504 .66376 m .78487 .66385 L .7856 .6731 L .454 .273 .545 r
F
.78424 .66455 m .78488 .674 L .78449 .66427 L .159 .061 .485 r
F
.78268 .6663 m .78077 .66595 L .77593 .66842 L .654 .811 .959 r
F
.7831 .66583 m .78077 .66595 L .78268 .6663 L F
.78077 .66595 m .76807 .66829 L .77593 .66842 L F
.78504 .66376 m .7856 .6731 L .7855 .66353 L .454 .273 .545 r
F
.78424 .66455 m .78414 .66466 L .78488 .674 L .159 .061 .485 r
F
.78129 .66784 m .77593 .66842 L .77217 .67219 L .654 .811 .959 r
F
.78268 .6663 m .77593 .66842 L .78129 .66784 L F
.77593 .66842 m .76949 .67044 L .77058 .67116 L F
.77593 .66842 m .77058 .67116 L .77217 .67219 L F
.78583 .66639 m .78597 .66643 L .78675 .67626 L .848 .57 .516 r
F
.7862 .66317 m .7856 .6731 L .78693 .67241 L .454 .273 .545 r
F
.78572 .66341 m .7856 .6731 L .7862 .66317 L F
.78414 .66466 m .78482 .67472 L .78488 .674 L 0 0 .196 r
F
.78412 .66487 m .78482 .67472 L .78414 .66466 L F
.78408 .66519 m .78482 .67472 L .78412 .66487 L F
.78379 .66772 m .77592 .67342 L .7837 .66843 L .654 .811 .959 r
F
.79201 .66378 m .79265 .6732 L .79206 .66391 L .919 .662 .17 r
F
.79214 .66425 m .79298 .67412 L .79205 .66447 L 0 0 .362 r
F
.79217 .66417 m .79265 .6732 L .79298 .67412 L .919 .662 .17 r
F
.79206 .66391 m .79265 .6732 L .79217 .66417 L F
.7919 .66352 m .79186 .66342 L .79265 .6732 L F
.79525 .67153 m .79554 .67222 L .79588 .67214 L .654 .811 .959 r
F
.78348 .67033 m .78048 .67405 L .7834 .67106 L F
.78408 .66519 m .78407 .66527 L .78482 .67472 L 0 0 .196 r
F
.56995 .57998 m .55258 .58036 L .55296 .58678 L .525 .341 .574 r
F
0 g
.53978 .59533 m
.55296 .58678 L
s
.56995 .57998 m .56954 .57354 L .55258 .58036 L .525 .341 .574 r
F
0 g
.53943 .58893 m
.55258 .58036 L
s
.83468 .44798 m .83439 .43999 L .81177 .43282 L .798 .539 .546 r
F
0 g
.83439 .43999 m
.85265 .45037 L
s
.64518 .69759 m .66703 .69153 L .64728 .69281 L .655 .81 .957 r
F
.6265 .69648 m .64518 .69759 L .64728 .69281 L F
.62421 .69879 m .64518 .69759 L .6265 .69648 L F
.33831 .69406 m .33804 .68877 L .35339 .68685 L .675 .46 .586 r
F
.32276 .69412 m .33804 .68877 L .33831 .69406 L .732 .504 .582 r
F
.32276 .69412 m .32251 .68882 L .33804 .68877 L F
.36601 .57919 m .38587 .56869 L .36316 .57601 L .654 .782 .942 r
F
.36601 .57919 m .39146 .5751 L .38587 .56869 L F
.31725 .56432 m .29363 .55807 L .28907 .56474 L .656 .781 .94 r
F
.32119 .56142 m .29363 .55807 L .31725 .56432 L F
.80423 .56158 m .82188 .54877 L .80079 .55887 L .654 .782 .942 r
F
.80423 .56158 m .8287 .55425 L .82188 .54877 L F
.73216 .57587 m .7026 .58351 L .72892 .58288 L .653 .784 .944 r
F
.75689 .57875 m .73216 .57587 L .72892 .58288 L F
.41973 .82634 m .41025 .82181 L .40408 .82492 L .592 .769 .964 r
F
0 g
.40031 .82873 m
.40408 .82492 L
s
.42516 .82488 m .41025 .82181 L .41973 .82634 L .592 .769 .964 r
F
.45708 .82857 m .45825 .82199 L .45161 .82647 L F
.45708 .82857 m .46647 .82517 L .45825 .82199 L F
.35339 .68685 m .36727 .67791 L .36758 .68319 L .609 .409 .586 r
F
.35368 .69214 m .35339 .68685 L .36758 .68319 L F
.33831 .69406 m .35339 .68685 L .35368 .69214 L .675 .46 .586 r
F
.34754 .6783 m .35339 .68685 L .36758 .68319 L .659 .806 .954 r
F
0 g
.33804 .68877 m
.35339 .68685 L
s
.39135 .5687 m .40863 .55487 L .38577 .56227 L .655 .781 .941 r
F
.39135 .5687 m .41686 .56459 L .40863 .55487 L F
.26388 .30625 m .25992 .36905 L .25824 .36926 L .636 .39 .528 r
F
.26388 .30625 m .26552 .30604 L .25992 .36905 L F
.2622 .30598 m .26388 .30625 L .25824 .36926 L .751 .492 .54 r
F
0 g
.26388 .30625 m
.26388 .30625 L
s
.75954 .56901 m .73148 .56944 L .75617 .57234 L .653 .783 .943 r
F
.43229 .81515 m .42878 .80949 L .41928 .81062 L .594 .768 .963 r
F
.43909 .81517 m .42878 .80949 L .43229 .81515 L F
.4459 .81596 m .43903 .80952 L .43909 .81517 L F
.4459 .81596 m .44928 .81072 L .43903 .80952 L F
.26552 .30604 m .26095 .3686 L .25992 .36905 L .487 .263 .5 r
F
.26552 .30604 m .26654 .30558 L .26095 .3686 L F
0 g
.26388 .30625 m
.26552 .30604 L
s
.2622 .30598 m .25824 .36926 L .25652 .36899 L .751 .492 .54 r
F
.26109 .30548 m .2622 .30598 L .25652 .36899 L .839 .573 .538 r
F
0 g
.2622 .30598 m
.26388 .30625 L
s
.66633 .68623 m .66563 .68094 L .66486 .67391 L 0 0 .113 r
F
0 g
.66315 .68643 m
.66563 .68094 L
s
.64573 .68222 m .66533 .68096 L .66457 .67396 L .656 .808 .956 r
F
.42554 .82036 m .41879 .81507 L .41065 .81728 L .593 .769 .963 r
F
.43189 .81961 m .41879 .81507 L .42554 .82036 L F
.45196 .82194 m .44898 .81517 L .44558 .82043 L F
.45196 .82194 m .45859 .81745 L .44898 .81517 L F
.41686 .56459 m .4167 .5582 L .40849 .54845 L .984 .718 .44 r
F
0 g
.4167 .5582 m
.41962 .56864 L
s
.73216 .57587 m .70727 .57297 L .7026 .58351 L .653 .784 .944 r
F
0 g
.7026 .58351 m
.70335 .59376 L
s
.47272 .82903 m .4668 .82063 L .46647 .82517 L .912 .673 .564 r
F
0 g
.47272 .82903 m
.4766 .83329 L
s
.26654 .30558 m .26163 .368 L .26095 .3686 L .269 .086 .437 r
F
.26654 .30558 m .2672 .30498 L .26163 .368 L F
0 g
.26552 .30604 m
.26654 .30558 L
s
.36758 .68319 m .36727 .67791 L .37937 .67272 L .522 .343 .58 r
F
0 g
.35691 .68059 m
.36727 .67791 L
s
.3631 .5696 m .37702 .55679 L .35871 .56689 L .655 .781 .941 r
F
.3631 .5696 m .38577 .56227 L .37702 .55679 L F
.43909 .81517 m .43903 .80952 L .42878 .80949 L .594 .768 .963 r
F
.26109 .30548 m .25652 .36899 L .25539 .3685 L .839 .573 .538 r
F
.26031 .30485 m .26109 .30548 L .25539 .3685 L .913 .647 .523 r
F
0 g
.26109 .30548 m
.2622 .30598 L
s
.29363 .55807 m .26306 .56183 L .28907 .56474 L .656 .781 .94 r
F
.64891 .57166 m .64838 .56526 L .62982 .56163 L .793 .545 .561 r
F
0 g
.64838 .56526 m
.66374 .57131 L
s
.49925 .43743 m .47351 .45069 L .50243 .44238 L .642 .738 .918 r
F
.49925 .43743 m .46699 .44087 L .47351 .45069 L F
.75115 .68545 m .76388 .68198 L .76471 .68727 L .793 .543 .559 r
F
.75115 .68545 m .75034 .68015 L .76388 .68198 L F
0 g
.76388 .68198 m
.77534 .68195 L
s
.56806 .69793 m .54964 .7061 L .56895 .70253 L .655 .81 .957 r
F
.56806 .69793 m .5482 .69921 L .54964 .7061 L F
0 g
.54964 .7061 m
.55498 .71219 L
s
.5873 .69132 m .56837 .69722 L .58771 .69364 L .656 .809 .957 r
F
.5873 .69132 m .56749 .6926 L .56837 .69722 L F
.588 .45671 m .627 .45437 L .59543 .44761 L .642 .738 .918 r
F
.56002 .4454 m .588 .45671 L .59543 .44761 L F
.55448 .4492 m .588 .45671 L .56002 .4454 L F
.78057 .69252 m .77971 .68722 L .79521 .6853 L .676 .462 .588 r
F
.76554 .69258 m .77971 .68722 L .78057 .69252 L .733 .501 .577 r
F
.76554 .69258 m .76471 .68727 L .77971 .68722 L F
.77211 .67805 m .76471 .68727 L .77971 .68722 L .655 .81 .958 r
F
.80773 .57753 m .83064 .56701 L .80595 .57435 L .653 .784 .944 r
F
.80773 .57753 m .83409 .57344 L .83064 .56701 L F
.75892 .56265 m .73765 .55638 L .73105 .56307 L .654 .782 .942 r
F
.76372 .55974 m .73765 .55638 L .75892 .56265 L F
.43137 .4287 m .43561 .43629 L .43494 .44429 L .956 .77 .318 r
F
.43137 .4287 m .43205 .42067 L .43561 .43629 L F
.46541 .42242 m .43561 .43629 L .46759 .43286 L .643 .737 .917 r
F
.46541 .42242 m .43205 .42067 L .43561 .43629 L F
0 g
.43561 .43629 m
.44063 .44368 L
s
.2672 .30498 m .262 .36729 L .26163 .368 L 0 0 .268 r
F
.2672 .30498 m .26756 .30426 L .262 .36729 L F
0 g
.26654 .30558 m
.2672 .30498 L
s
.31652 .43995 m
.31669 .43992 L
s
.3171 .5771 m .28868 .57754 L .31475 .58041 L .654 .782 .942 r
F
.26031 .30485 m .25539 .3685 L .25459 .36788 L .913 .647 .523 r
F
.25981 .30412 m .26031 .30485 L .25459 .36788 L .98 .727 .476 r
F
0 g
.26031 .30485 m
.26109 .30548 L
s
.64573 .68222 m .66457 .67396 L .64515 .67757 L .656 .808 .956 r
F
.62611 .68348 m .64573 .68222 L .64515 .67757 L F
.35856 .56055 m .36549 .54634 L .35295 .55852 L .656 .781 .94 r
F
.35856 .56055 m .37675 .55047 L .36549 .54634 L F
.39241 .44977 m .36903 .43463 L .3682 .44263 L .791 .544 .563 r
F
.39164 .4578 m .39241 .44977 L .3682 .44263 L F
0 g
.39241 .44977 m
.41316 .46011 L
s
.30803 .69232 m .32251 .68882 L .32276 .69412 L .787 .547 .574 r
F
.30803 .69232 m .3078 .68701 L .32251 .68882 L F
.31695 .67838 m .3078 .68701 L .32251 .68882 L .659 .806 .954 r
F
0 g
.32251 .68882 m
.33804 .68877 L
s
.79608 .6906 m .79521 .6853 L .8102 .68163 L .617 .422 .596 r
F
.78057 .69252 m .79521 .6853 L .79608 .6906 L .676 .462 .588 r
F
0 g
.77971 .68722 m
.79521 .6853 L
s
.62721 .44635 m .63246 .42316 L .63226 .43118 L 0 0 .241 r
F
.627 .45437 m .62721 .44635 L .63226 .43118 L F
.59572 .43959 m .62721 .44635 L .63226 .43118 L .643 .737 .917 r
F
0 g
.62149 .45319 m
.62721 .44635 L
s
.33751 .68491 m .33831 .69406 L .35368 .69214 L .658 .806 .954 r
F
.32707 .68495 m .33831 .69406 L .33751 .68491 L F
.32707 .68495 m .32276 .69412 L .33831 .69406 L F
.41879 .81507 m .41104 .81275 L .41065 .81728 L .515 .318 .552 r
F
.41879 .81507 m .41918 .81054 L .41104 .81275 L F
0 g
.40488 .81589 m
.41104 .81275 L
s
.83324 .56703 m .85466 .55317 L .82979 .56058 L .653 .783 .943 r
F
.83324 .56703 m .85966 .56291 L .85466 .55317 L F
.26756 .30426 m .262 .36644 L .262 .36729 L .796 .683 .137 r
F
.26756 .30426 m .26757 .3034 L .262 .36644 L F
0 g
.2672 .30498 m
.26748 .30442 L
s
.4668 .82063 m .46713 .81611 L .45893 .81292 L .845 .608 .581 r
F
0 g
.46713 .81611 m
.47337 .81999 L
s
.25981 .30412 m .25459 .36788 L .25408 .36715 L .98 .727 .476 r
F
.25964 .30326 m .25981 .30412 L .25408 .36715 L .952 .765 .308 r
F
0 g
.25981 .30412 m
.26031 .30485 L
s
.35368 .69214 m .36758 .68319 L .36789 .68849 L .609 .409 .586 r
F
.34783 .68362 m .35368 .69214 L .36789 .68849 L .658 .806 .954 r
F
.33751 .68491 m .35368 .69214 L .34783 .68362 L F
0 g
.33831 .69406 m
.35368 .69214 L
s
.43189 .81961 m .42835 .81394 L .41879 .81507 L .593 .769 .963 r
F
.43873 .81964 m .42835 .81394 L .43189 .81961 L F
.44558 .82043 m .43866 .81397 L .43873 .81964 L F
.44558 .82043 m .44898 .81517 L .43866 .81397 L F
.85966 .56291 m .85877 .55652 L .85377 .54674 L .943 .654 .198 r
F
0 g
.85859 .56083 m
.85862 .56006 L
s
.31711 .57068 m .29334 .56443 L .28874 .57111 L .655 .781 .941 r
F
.32108 .56778 m .29334 .56443 L .31711 .57068 L F
.62611 .68348 m .64515 .67757 L .62578 .68116 L .656 .808 .956 r
F
.8102 .68163 m .80931 .67635 L .82282 .67115 L .548 .375 .599 r
F
0 g
.80569 .67723 m
.80931 .67635 L
s
.42516 .82488 m .41841 .81961 L .41025 .82181 L .592 .769 .964 r
F
.43152 .82414 m .41841 .81961 L .42516 .82488 L F
.80515 .56793 m .82293 .55509 L .80169 .56522 L .653 .783 .943 r
F
.80515 .56793 m .82979 .56058 L .82293 .55509 L F
.21117 .42328 m .21171 .44666 L .22593 .43039 L .642 .739 .919 r
F
.21117 .42328 m .18969 .43618 L .21171 .44666 L F
0 g
.21171 .44666 m
.2364 .45377 L
s
.73765 .55638 m .70636 .56015 L .73105 .56307 L .654 .782 .942 r
F
.49946 .41618 m .46635 .41444 L .4685 .42485 L .644 .737 .916 r
F
.45161 .82647 m .44863 .81972 L .44522 .82496 L .592 .769 .964 r
F
.45161 .82647 m .45825 .82199 L .44863 .81972 L F
.66633 .68623 m .66486 .67391 L .66556 .67922 L 0 0 .113 r
F
.66703 .69153 m .66633 .68623 L .66556 .67922 L F
.64661 .6875 m .66633 .68623 L .66556 .67922 L .656 .809 .957 r
F
0 g
.66384 .69174 m
.66633 .68623 L
s
.26757 .3034 m .26137 .36535 L .262 .36644 L .991 .745 .452 r
F
.26757 .3034 m .26695 .3023 L .26137 .36535 L F
0 g
.26756 .30426 m
.26757 .3034 L
s
.25964 .30326 m .25408 .36715 L .2539 .3663 L .952 .765 .308 r
F
.26005 .30217 m .25964 .30326 L .2539 .3663 L 0 0 .188 r
F
.43873 .81964 m .43866 .81397 L .42835 .81394 L .593 .769 .963 r
F
.32119 .56142 m .30148 .55221 L .29363 .55807 L .656 .781 .94 r
F
.32648 .55914 m .30148 .55221 L .32119 .56142 L F
.39146 .5751 m .40877 .56131 L .38587 .56869 L .654 .782 .942 r
F
.39146 .5751 m .41701 .571 L .40877 .56131 L F
.36758 .68319 m .37937 .67272 L .3797 .67801 L .522 .343 .58 r
F
.36789 .68849 m .36758 .68319 L .3797 .67801 L F
.35706 .67584 m .36758 .68319 L .3797 .67801 L .659 .806 .954 r
F
.34754 .6783 m .36758 .68319 L .35706 .67584 L F
0 g
.35714 .68588 m
.36758 .68319 L
s
.76053 .44615 m .73537 .44277 L .73542 .45078 L .598 .379 .554 r
F
0 g
.71332 .459 m
.73542 .45078 L
s
.76053 .44615 m .76042 .43812 L .73537 .44277 L .598 .379 .554 r
F
0 g
.71332 .45101 m
.73537 .44277 L
s
.76026 .57544 m .73216 .57587 L .75689 .57875 L .653 .784 .944 r
F
.80079 .55887 m .8121 .54463 L .7959 .55683 L .654 .782 .942 r
F
.80079 .55887 m .82188 .54877 L .8121 .54463 L F
.83468 .44798 m .81177 .43282 L .81201 .44082 L .798 .539 .546 r
F
.83497 .45601 m .83468 .44798 L .81201 .44082 L F
0 g
.83468 .44798 m
.85298 .45834 L
s
.75197 .69076 m .76471 .68727 L .76554 .69258 L .793 .543 .559 r
F
.75197 .69076 m .75115 .68545 L .76471 .68727 L F
.76303 .67681 m .76471 .68727 L .77211 .67805 L .655 .81 .958 r
F
.76303 .67681 m .75115 .68545 L .76471 .68727 L F
0 g
.76471 .68727 m
.77971 .68722 L
s
.31764 .43193 m
.32941 .43162 L
s
.33505 .43147 m
.33712 .43142 L
s
.5879 .69664 m .56895 .70253 L .58831 .69895 L .655 .81 .957 r
F
.5879 .69664 m .56806 .69793 L .56895 .70253 L F
.78304 .68335 m .78057 .69252 L .79608 .6906 L .654 .811 .959 r
F
.77296 .68338 m .78057 .69252 L .78304 .68335 L F
.77296 .68338 m .76554 .69258 L .78057 .69252 L F
.3682 .44263 m .36903 .43463 L .3432 .43125 L .732 .489 .561 r
F
0 g
.36903 .43463 m
.39318 .44178 L
s
.41686 .56459 m .40849 .54845 L .40863 .55487 L .984 .718 .44 r
F
.41701 .571 m .41686 .56459 L .40863 .55487 L F
0 g
.41686 .56459 m
.41977 .575 L
s
.26695 .3023 m .26011 .36449 L .26137 .36535 L .896 .63 .527 r
F
.26695 .3023 m .26572 .30142 L .26011 .36449 L F
0 g
.26695 .3023 m
.26757 .3034 L
s
.26695 .3023 m
.26695 .3023 L
s
.64661 .6875 m .66556 .67922 L .64602 .68284 L .656 .809 .957 r
F
.62686 .68877 m .64661 .6875 L .64602 .68284 L F
.36316 .57601 m .37711 .56323 L .35876 .57331 L .654 .782 .942 r
F
.36316 .57601 m .38587 .56869 L .37711 .56323 L F
.58913 .56902 m .56914 .56713 L .56954 .57354 L .607 .404 .58 r
F
.58913 .56902 m .58869 .5626 L .56914 .56713 L F
0 g
.5522 .57395 m
.56914 .56713 L
s
.6265 .69648 m .64728 .69281 L .62751 .69408 L .655 .81 .957 r
F
.64891 .57166 m .62982 .56163 L .63033 .56805 L .793 .545 .561 r
F
.64945 .57808 m .64891 .57166 L .63033 .56805 L F
0 g
.64891 .57166 m
.66431 .57769 L
s
.41841 .81961 m .41065 .81728 L .41025 .82181 L .515 .318 .552 r
F
0 g
.40408 .82492 m
.41025 .82181 L
s
.41841 .81961 m .41879 .81507 L .41065 .81728 L .515 .318 .552 r
F
0 g
.40448 .8204 m
.41065 .81728 L
s
.29334 .56443 m .26256 .56821 L .28874 .57111 L .655 .781 .941 r
F
.26112 .30134 m .26005 .30217 L .25431 .36523 L .329 .133 .455 r
F
.26005 .30217 m .2539 .3663 L .25431 .36523 L 0 0 .188 r
F
0 g
.25964 .30326 m
.26005 .30217 L
s
.26005 .30217 m
.26005 .30217 L
s
.3172 .68372 m .32276 .69412 L .32707 .68495 L .658 .806 .954 r
F
.3172 .68372 m .30803 .69232 L .32276 .69412 L F
0 g
.32276 .69412 m
.33831 .69406 L
s
.29485 .68342 m .30756 .68171 L .3078 .68701 L .844 .593 .559 r
F
.29485 .68342 m .29464 .6781 L .30756 .68171 L F
0 g
.30756 .68171 m
.31274 .68235 L
s
.79608 .6906 m .8102 .68163 L .81109 .68693 L .617 .422 .596 r
F
.79346 .68205 m .79608 .6906 L .81109 .68693 L .654 .811 .959 r
F
.78304 .68335 m .79608 .6906 L .79346 .68205 L F
0 g
.78057 .69252 m
.79608 .6906 L
s
.4668 .82063 m .45893 .81292 L .45859 .81745 L .845 .608 .581 r
F
.46647 .82517 m .4668 .82063 L .45859 .81745 L F
0 g
.4668 .82063 m
.47305 .8245 L
s
.17307 .41489 m .1922 .4202 L .19095 .42817 L .904 .663 .565 r
F
.17307 .41489 m .17438 .40689 L .1922 .4202 L F
0 g
.1922 .4202 m
.19885 .4234 L
s
.75954 .56901 m .73812 .56275 L .73148 .56944 L .653 .783 .943 r
F
.76437 .5661 m .73812 .56275 L .75954 .56901 L F
.43152 .82414 m .42798 .81848 L .41841 .81961 L .592 .769 .964 r
F
.43837 .82417 m .42798 .81848 L .43152 .82414 L F
.20203 .39815 m .19252 .42001 L .21382 .4071 L .643 .737 .917 r
F
.20203 .39815 m .17479 .40676 L .19252 .42001 L F
.44522 .82496 m .4383 .81852 L .43837 .82417 L .592 .769 .964 r
F
.44522 .82496 m .44863 .81972 L .4383 .81852 L F
.35295 .55852 m .35244 .54387 L .34647 .55731 L .656 .781 .94 r
F
.35295 .55852 m .36549 .54634 L .35244 .54387 L F
.26572 .30142 m .2589 .3641 L .26011 .36449 L .807 .543 .539 r
F
.26572 .30142 m .26454 .30102 L .2589 .3641 L F
0 g
.26572 .30142 m
.26695 .3023 L
s
.35871 .56689 m .36568 .55266 L .35306 .56486 L .655 .781 .941 r
F
.35871 .56689 m .37702 .55679 L .36568 .55266 L F
.26112 .30134 m .25431 .36523 L .2554 .36441 L .329 .133 .455 r
F
.26223 .30098 m .26112 .30134 L .2554 .36441 L .55 .315 .512 r
F
0 g
.26005 .30217 m
.26112 .30134 L
s
.58774 .68361 m .56711 .68728 L .5868 .68601 L .656 .808 .956 r
F
.30777 .41203 m .33226 .42735 L .3472 .41581 L .643 .737 .917 r
F
.2946 .41768 m .33226 .42735 L .30777 .41203 L F
.76372 .55974 m .74723 .55051 L .73765 .55638 L .654 .782 .942 r
F
.76965 .55745 m .74723 .55051 L .76372 .55974 L F
.83409 .57344 m .85555 .55961 L .83064 .56701 L .653 .784 .944 r
F
.83409 .57344 m .86055 .56932 L .85555 .55961 L F
.62686 .68877 m .64602 .68284 L .62653 .68645 L .656 .809 .957 r
F
.8102 .68163 m .82282 .67115 L .82373 .67645 L .548 .375 .599 r
F
.81109 .68693 m .8102 .68163 L .82373 .67645 L F
.80265 .67426 m .8102 .68163 L .82373 .67645 L .655 .81 .958 r
F
0 g
.80051 .684 m
.8102 .68163 L
s
.53495 .3402 m
.53513 .39792 L
s
.26454 .30102 m .25771 .36396 L .2589 .3641 L .734 .476 .538 r
F
0 g
.26348 .3108 m
.26388 .30625 L
s
.26454 .30102 m .26337 .30089 L .25771 .36396 L .734 .476 .538 r
F
0 g
.26454 .30102 m
.26572 .30142 L
s
.43837 .82417 m .4383 .81852 L .42798 .81848 L .592 .769 .964 r
F
.26223 .30098 m .2554 .36441 L .25654 .36405 L .55 .315 .512 r
F
.26337 .30089 m .26223 .30098 L .25654 .36405 L .656 .407 .53 r
F
0 g
.26112 .30134 m
.26223 .30098 L
s
.5282 .34008 m
.52825 .39786 L
s
.26337 .30089 m .25654 .36405 L .25771 .36396 L .656 .407 .53 r
F
0 g
.26337 .30089 m
.26454 .30102 L
s
.26223 .30098 m
.26337 .30089 L
s
.66703 .69153 m .66556 .67922 L .66627 .68454 L 0 0 .113 r
F
.64728 .69281 m .66703 .69153 L .66627 .68454 L .655 .81 .957 r
F
0 g
.66377 .6987 m
.66703 .69153 L
s
.78662 .43745 m .76031 .43012 L .76042 .43812 L .668 .434 .557 r
F
.78662 .43745 m .78645 .42944 L .76031 .43012 L F
0 g
.73532 .43479 m
.76031 .43012 L
s
.81201 .44082 m .81177 .43282 L .78645 .42944 L .732 .485 .555 r
F
0 g
.81177 .43282 m
.83439 .43999 L
s
.85966 .56291 m .85377 .54674 L .85466 .55317 L .943 .654 .198 r
F
.86055 .56932 m .85966 .56291 L .85466 .55317 L F
0 g
.85947 .56724 m
.85951 .56646 L
s
.36789 .68849 m .3797 .67801 L .38003 .68332 L .522 .343 .58 r
F
.35736 .68116 m .36789 .68849 L .38003 .68332 L .658 .806 .954 r
F
.34783 .68362 m .36789 .68849 L .35736 .68116 L F
0 g
.35368 .69214 m
.36789 .68849 L
s
.32648 .55914 m .3121 .54757 L .30148 .55221 L .656 .781 .94 r
F
.33276 .55763 m .3121 .54757 L .32648 .55914 L F
.3171 .5771 m .29328 .57087 L .28868 .57754 L .654 .782 .942 r
F
.32108 .5742 m .29328 .57087 L .3171 .5771 L F
.46481 .43045 m .43494 .44429 L .46699 .44087 L .642 .738 .918 r
F
.46481 .43045 m .43137 .4287 L .43494 .44429 L F
0 g
.43494 .44429 m
.44493 .45891 L
s
.80595 .57435 m .82376 .56154 L .80248 .57164 L .653 .784 .944 r
F
.80595 .57435 m .83064 .56701 L .82376 .56154 L F
0 g
.29225 .45257 m
.31573 .44795 L
s
.38544 .55594 m .39518 .54025 L .37675 .55047 L .656 .781 .94 r
F
.38544 .55594 m .40815 .54856 L .39518 .54025 L F
.73812 .56275 m .70663 .56653 L .73148 .56944 L .653 .783 .943 r
F
.56892 .68246 m .5474 .68855 L .56711 .68728 L .656 .808 .956 r
F
.58774 .68361 m .56892 .68246 L .56711 .68728 L F
.76387 .68215 m .76554 .69258 L .77296 .68338 L .654 .811 .959 r
F
.76387 .68215 m .75197 .69076 L .76554 .69258 L F
0 g
.76554 .69258 m
.78057 .69252 L
s
.3682 .44263 m .3432 .43125 L .34231 .43926 L .732 .489 .561 r
F
0 g
.3432 .43125 m
.36903 .43463 L
s
.3408 .43132 m
.3432 .43125 L
s
.73993 .68185 m .75034 .68015 L .75115 .68545 L .862 .59 .526 r
F
.73993 .68185 m .73913 .67653 L .75034 .68015 L F
0 g
.75034 .68015 m
.75717 .68107 L
s
.39164 .4578 m .3682 .44263 L .36736 .45067 L .791 .544 .563 r
F
0 g
.39164 .4578 m
.41244 .46812 L
s
.62578 .68116 m .64191 .67337 L .62413 .67908 L .656 .808 .956 r
F
.62578 .68116 m .64515 .67757 L .64191 .67337 L F
.32108 .56778 m .30124 .55855 L .29334 .56443 L .655 .781 .941 r
F
.32641 .56549 m .30124 .55855 L .32108 .56778 L F
.42835 .81394 m .41918 .81054 L .41879 .81507 L .606 .396 .57 r
F
.42835 .81394 m .42873 .8094 L .41918 .81054 L F
0 g
.41104 .81275 m
.41918 .81054 L
s
.627 .45437 m .63226 .43118 L .63206 .43924 L 0 0 .241 r
F
.59543 .44761 m .627 .45437 L .63206 .43924 L .642 .738 .918 r
F
0 g
.61566 .46788 m
.627 .45437 L
s
.46647 .82517 m .45859 .81745 L .45825 .82199 L .845 .608 .581 r
F
0 g
.46647 .82517 m
.47272 .82903 L
s
.64728 .69281 m .66627 .68454 L .6467 .68816 L .655 .81 .957 r
F
.62751 .69408 m .64728 .69281 L .6467 .68816 L F
.45859 .81745 m .45893 .81292 L .44934 .81064 L .787 .555 .586 r
F
0 g
.45893 .81292 m
.46713 .81611 L
s
.29363 .55807 m .26976 .55176 L .26306 .56183 L .656 .781 .94 r
F
.7959 .55683 m .80003 .54216 L .78991 .55562 L .654 .782 .942 r
F
.7959 .55683 m .8121 .54463 L .80003 .54216 L F
.29507 .68874 m .3078 .68701 L .30803 .69232 L .844 .593 .559 r
F
.29507 .68874 m .29485 .68342 L .3078 .68701 L F
.3083 .67596 m .3078 .68701 L .31695 .67838 L .659 .806 .954 r
F
.3083 .67596 m .29485 .68342 L .3078 .68701 L F
0 g
.3078 .68701 m
.31301 .68765 L
s
.26931 .55811 m .26266 .56179 L .26256 .56821 L .019 0 .41 r
F
.26931 .55811 m .2694 .55166 L .26266 .56179 L F
0 g
.26134 .57237 m
.26266 .56179 L
s
.80169 .56522 m .81308 .55095 L .79677 .56318 L .653 .783 .943 r
F
.80169 .56522 m .82293 .55509 L .81308 .55095 L F
.3797 .67801 m .37937 .67272 L .3886 .66634 L .388 .243 .56 r
F
0 g
.36934 .67702 m
.37937 .67272 L
s
.34647 .55731 m .33853 .54324 L .33958 .557 L .656 .781 .94 r
F
.34647 .55731 m .35244 .54387 L .33853 .54324 L F
.41701 .571 m .40863 .55487 L .40877 .56131 L .984 .718 .44 r
F
0 g
.41701 .571 m
.41993 .58138 L
s
.56892 .68246 m .55 .68131 L .5474 .68855 L .656 .808 .956 r
F
.55027 .68662 m .5471 .68856 L .54765 .69388 L 0 0 .394 r
F
0 g
.548 .6929 m
.5482 .69384 L
s
.55027 .68662 m .54972 .68129 L .5471 .68856 L 0 0 .394 r
F
.58957 .57547 m .56954 .57354 L .56995 .57998 L .607 .404 .58 r
F
0 g
.55296 .58678 m
.56995 .57998 L
s
.58957 .57547 m .58913 .56902 L .56954 .57354 L .607 .404 .58 r
F
0 g
.55258 .58036 m
.56954 .57354 L
s
.63033 .56805 m .62982 .56163 L .60943 .56072 L .733 .499 .573 r
F
0 g
.62982 .56163 m
.64838 .56526 L
s
.64945 .57808 m .63033 .56805 L .63085 .57449 L .793 .545 .561 r
F
0 g
.64945 .57808 m
.66487 .58409 L
s
.49878 .42417 m .46541 .42242 L .46759 .43286 L .643 .737 .917 r
F
.29328 .57087 m .26245 .57465 L .28868 .57754 L .654 .782 .942 r
F
.33276 .55763 m .32475 .54451 L .3121 .54757 L .656 .781 .94 r
F
.33958 .557 m .32475 .54451 L .33276 .55763 L F
.58825 .68891 m .56749 .6926 L .5873 .69132 L .656 .809 .957 r
F
.25984 .40118 m .26211 .42127 L .27905 .42082 L .643 .737 .917 r
F
.25112 .40004 m .26211 .42127 L .25984 .40118 L F
.25112 .40004 m .24487 .41902 L .26211 .42127 L F
.59572 .43959 m .63226 .43118 L .59889 .42943 L F
.62751 .69408 m .6467 .68816 L .62718 .69176 L .655 .81 .957 r
F
.81109 .68693 m .82373 .67645 L .82464 .68176 L .548 .375 .599 r
F
.80354 .67959 m .81109 .68693 L .82464 .68176 L .654 .811 .959 r
F
.79346 .68205 m .81109 .68693 L .80354 .67959 L F
0 g
.79608 .6906 m
.81109 .68693 L
s
.76965 .55745 m .75915 .54586 L .74723 .55051 L .654 .782 .942 r
F
.77631 .55594 m .75915 .54586 L .76965 .55745 L F
.76026 .57544 m .73882 .56919 L .73216 .57587 L .653 .784 .944 r
F
.7651 .57253 m .73882 .56919 L .76026 .57544 L F
.33958 .557 m .33853 .54324 L .32475 .54451 L .656 .781 .94 r
F
.8287 .55425 m .84325 .53853 L .82188 .54877 L .654 .782 .942 r
F
.8287 .55425 m .85339 .54686 L .84325 .53853 L F
.81201 .44082 m .78645 .42944 L .78662 .43745 L .732 .485 .555 r
F
0 g
.78645 .42944 m
.81177 .43282 L
s
.76031 .43012 m
.78645 .42944 L
s
.35306 .56486 m .35255 .55018 L .34654 .56365 L .655 .781 .941 r
F
.35306 .56486 m .36568 .55266 L .35255 .55018 L F
.35876 .57331 m .36575 .55912 L .3531 .57129 L .654 .782 .942 r
F
.35876 .57331 m .37711 .56323 L .36575 .55912 L F
.83497 .45601 m .81201 .44082 L .81224 .44887 L .798 .539 .546 r
F
0 g
.83497 .45601 m
.85331 .46635 L
s
.31669 .43992 m
.32848 .43962 L
s
.76437 .5661 m .74778 .55685 L .73812 .56275 L .653 .783 .943 r
F
.77034 .56381 m .74778 .55685 L .76437 .5661 L F
.36736 .45067 m .3682 .44263 L .34231 .43926 L .732 .489 .561 r
F
0 g
.3682 .44263 m
.39241 .44977 L
s
.58996 .68127 m .56892 .68246 L .58774 .68361 L .656 .808 .956 r
F
.42798 .81848 m .41879 .81507 L .41841 .81961 L .606 .396 .57 r
F
0 g
.41025 .82181 m
.41841 .81961 L
s
.42798 .81848 m .42835 .81394 L .41879 .81507 L .606 .396 .57 r
F
0 g
.41065 .81728 m
.41879 .81507 L
s
.56931 .68777 m .54765 .69388 L .56749 .6926 L .656 .809 .957 r
F
.58825 .68891 m .56931 .68777 L .56749 .6926 L F
.73765 .55638 m .71615 .55006 L .70636 .56015 L .654 .782 .942 r
F
.74074 .68718 m .75115 .68545 L .75197 .69076 L .862 .59 .526 r
F
.74074 .68718 m .73993 .68185 L .75115 .68545 L F
.75554 .67438 m .75115 .68545 L .76303 .67681 L .655 .81 .958 r
F
.75554 .67438 m .73993 .68185 L .75115 .68545 L F
0 g
.75115 .68545 m
.75803 .68637 L
s
.71648 .55641 m .70599 .56011 L .70663 .56653 L .252 .149 .538 r
F
.71648 .55641 m .71582 .54996 L .70599 .56011 L F
0 g
.70135 .57071 m
.70599 .56011 L
s
.82373 .67645 m .82282 .67115 L .83397 .66475 L .457 .314 .597 r
F
0 g
.81217 .67525 m
.82282 .67115 L
s
.45859 .81745 m .44934 .81064 L .44898 .81517 L .787 .555 .586 r
F
.45825 .82199 m .45859 .81745 L .44898 .81517 L F
0 g
.45859 .81745 m
.4668 .82063 L
s
.78991 .55562 m .78653 .54152 L .78322 .55532 L .654 .782 .942 r
F
.78991 .55562 m .80003 .54216 L .78653 .54152 L F
.62653 .68645 m .64276 .67863 L .62487 .68436 L .656 .809 .957 r
F
.62653 .68645 m .64602 .68284 L .64276 .67863 L F
.64515 .67757 m .6598 .66763 L .64191 .67337 L .656 .808 .956 r
F
.64515 .67757 m .66457 .67396 L .6598 .66763 L F
.6099 .56714 m .58869 .5626 L .58913 .56902 L .673 .453 .579 r
F
.6099 .56714 m .60943 .56072 L .58869 .5626 L F
0 g
.56914 .56713 m
.58869 .5626 L
s
.86055 .56932 m .85466 .55317 L .85555 .55961 L .943 .654 .198 r
F
0 g
.8601 .57973 m
.86055 .56932 L
s
.17176 .42292 m .19095 .42817 L .18969 .43618 L .904 .663 .565 r
F
.17176 .42292 m .17307 .41489 L .19095 .42817 L F
.20051 .40626 m .19095 .42817 L .21239 .41523 L .642 .738 .918 r
F
.20051 .40626 m .17307 .41489 L .19095 .42817 L F
0 g
.19095 .42817 m
.19767 .43139 L
s
.24282 .39758 m .24487 .41902 L .25112 .40004 L .643 .737 .917 r
F
.24282 .39758 m .22842 .4142 L .24487 .41902 L F
.32641 .56549 m .31193 .5539 L .30124 .55855 L .655 .781 .941 r
F
.33273 .56398 m .31193 .5539 L .32641 .56549 L F
.26841 .40094 m .27905 .42082 L .2946 .41768 L .643 .737 .917 r
F
.25984 .40118 m .27905 .42082 L .26841 .40094 L F
.73882 .56919 m .70727 .57297 L .73216 .57587 L .653 .784 .944 r
F
.30854 .6813 m .30803 .69232 L .3172 .68372 L .658 .806 .954 r
F
.30854 .6813 m .29507 .68874 L .30803 .69232 L F
0 g
.30803 .69232 m
.32276 .69412 L
s
.43866 .81397 m .42873 .8094 L .42835 .81394 L .674 .455 .58 r
F
.43866 .81397 m .43902 .80944 L .42873 .8094 L F
0 g
.41918 .81054 m
.42873 .8094 L
s
.38577 .56227 m .39557 .54655 L .37702 .55679 L .655 .781 .941 r
F
.38577 .56227 m .40863 .55487 L .39557 .54655 L F
.3797 .67801 m .3886 .66634 L .38894 .67164 L .388 .243 .56 r
F
.38003 .68332 m .3797 .67801 L .38894 .67164 L F
.36516 .67235 m .3797 .67801 L .38894 .67164 L .659 .806 .954 r
F
.35706 .67584 m .3797 .67801 L .36516 .67235 L F
0 g
.3696 .68233 m
.3797 .67801 L
s
.44898 .81517 m .44934 .81064 L .43902 .80944 L .732 .506 .585 r
F
0 g
.44934 .81064 m
.45893 .81292 L
s
.33171 .43557 m .34765 .41599 L .34676 .42401 L .29 .108 .453 r
F
.30703 .4202 m .33171 .43557 L .34676 .42401 L .642 .738 .918 r
F
.29377 .42586 m .33171 .43557 L .30703 .4202 L F
0 g
.32881 .43678 m
.33171 .43557 L
s
.33171 .43557 m
.33234 .43508 L
s
.34273 .60498 m
.34402 .58218 L
s
.77631 .55594 m .77257 .54279 L .75915 .54586 L .654 .782 .942 r
F
.78322 .55532 m .77257 .54279 L .77631 .55594 L F
0 g
.33581 .60487 m
.33713 .58234 L
s
.32108 .5742 m .3012 .56501 L .29328 .57087 L .654 .782 .942 r
F
.32641 .57192 m .3012 .56501 L .32108 .5742 L F
.30148 .55221 m .26976 .55176 L .29363 .55807 L .656 .781 .94 r
F
.78322 .55532 m .78653 .54152 L .77257 .54279 L .654 .782 .942 r
F
.56931 .68777 m .55027 .68662 L .54765 .69388 L .656 .809 .957 r
F
.55083 .69198 m .54765 .69388 L .5482 .69921 L 0 0 .394 r
F
0 g
.54855 .69823 m
.54875 .69917 L
s
.55083 .69198 m .55027 .68662 L .54765 .69388 L 0 0 .394 r
F
.62413 .67908 m .63621 .66993 L .62127 .67737 L .656 .808 .956 r
F
.62413 .67908 m .64191 .67337 L .63621 .66993 L F
.529 .55035 m .52866 .54395 L .54938 .54206 L .673 .452 .577 r
F
.5084 .54942 m .52866 .54395 L .529 .55035 L .733 .499 .573 r
F
.5084 .54942 m .50809 .54301 L .52866 .54395 L F
.58885 .69424 m .56806 .69793 L .5879 .69664 L .655 .81 .957 r
F
.29334 .56443 m .26931 .55811 L .26256 .56821 L .655 .781 .941 r
F
.26921 .56458 m .26256 .56821 L .26245 .57465 L .019 0 .41 r
F
.26921 .56458 m .26931 .55811 L .26256 .56821 L F
0 g
.26124 .57875 m
.26256 .56821 L
s
.79677 .56318 m .80094 .54847 L .79074 .56197 L .653 .783 .943 r
F
.79677 .56318 m .81308 .55095 L .80094 .54847 L F
.80248 .57164 m .81391 .55741 L .79756 .56961 L .653 .784 .944 r
F
.80248 .57164 m .82376 .56154 L .81391 .55741 L F
.63033 .56805 m .60943 .56072 L .6099 .56714 L .733 .499 .573 r
F
0 g
.58869 .5626 m
.60943 .56072 L
s
.60943 .56072 m
.62982 .56163 L
s
.52948 .52984 m .52867 .54374 L .54929 .54186 L .656 .78 .94 r
F
.51571 .52919 m .52867 .54374 L .52948 .52984 L F
.51571 .52919 m .5082 .54281 L .52867 .54374 L F
.34654 .56365 m .33854 .54956 L .3396 .56335 L .655 .781 .941 r
F
.34654 .56365 m .35255 .55018 L .33854 .54956 L F
.78679 .44549 m .76042 .43812 L .76053 .44615 L .668 .434 .557 r
F
0 g
.73542 .45078 m
.76053 .44615 L
s
.78679 .44549 m .78662 .43745 L .76042 .43812 L .668 .434 .557 r
F
0 g
.73537 .44277 m
.76042 .43812 L
s
.44898 .81517 m .43902 .80944 L .43866 .81397 L .732 .506 .585 r
F
0 g
.43902 .80944 m
.44934 .81064 L
s
.42873 .8094 m
.43902 .80944 L
s
.81224 .44887 m .81201 .44082 L .78662 .43745 L .732 .485 .555 r
F
0 g
.81201 .44082 m
.83468 .44798 L
s
.63085 .57449 m .63033 .56805 L .6099 .56714 L .733 .499 .573 r
F
0 g
.63033 .56805 m
.64891 .57166 L
s
.3404 .64597 m
.34273 .60498 L
s
.33338 .64602 m
.33581 .60487 L
s
.36736 .45067 m .34231 .43926 L .34141 .4473 L .732 .489 .561 r
F
0 g
.34231 .43926 m
.3682 .44263 L
s
.36736 .45067 m
.39164 .4578 L
s
.33415 .43947 m
.34231 .43926 L
s
.33273 .56398 m .32467 .55083 L .31193 .5539 L .655 .781 .941 r
F
.3396 .56335 m .32467 .55083 L .33273 .56398 L F
.45825 .82199 m .44898 .81517 L .44863 .81972 L .787 .555 .586 r
F
0 g
.45825 .82199 m
.46647 .82517 L
s
.54975 .54846 m .54938 .54206 L .56895 .53745 L .606 .401 .578 r
F
.529 .55035 m .54938 .54206 L .54975 .54846 L .673 .452 .577 r
F
0 g
.52866 .54395 m
.54938 .54206 L
s
.77034 .56381 m .75978 .5522 L .74778 .55685 L .653 .783 .943 r
F
.77704 .56229 m .75978 .5522 L .77034 .56381 L F
.59049 .68657 m .56931 .68777 L .58825 .68891 L .656 .809 .957 r
F
.3396 .56335 m .33854 .54956 L .32467 .55083 L .655 .781 .941 r
F
.56989 .69311 m .5482 .69921 L .56806 .69793 L .655 .81 .957 r
F
.58885 .69424 m .56989 .69311 L .56806 .69793 L F
.75637 .67972 m .75197 .69076 L .76387 .68215 L .654 .811 .959 r
F
.75637 .67972 m .74074 .68718 L .75197 .69076 L F
0 g
.75197 .69076 m
.76554 .69258 L
s
.82979 .56058 m .84445 .54483 L .82293 .55509 L .653 .783 .943 r
F
.82979 .56058 m .85466 .55317 L .84445 .54483 L F
.82373 .67645 m .83397 .66475 L .8349 .67006 L .457 .314 .597 r
F
.82464 .68176 m .82373 .67645 L .8349 .67006 L F
.8117 .67077 m .82373 .67645 L .8349 .67006 L .655 .81 .958 r
F
.80265 .67426 m .82373 .67645 L .8117 .67077 L F
0 g
.813 .68056 m
.82373 .67645 L
s
.54336 .52856 m .54929 .54186 L .56877 .53727 L .656 .78 .94 r
F
.52948 .52984 m .54929 .54186 L .54336 .52856 L F
.3531 .57129 m .35259 .55665 L .34657 .57008 L .654 .782 .942 r
F
.3531 .57129 m .36575 .55912 L .35259 .55665 L F
0 g
.78514 .58053 m
.78699 .60334 L
s
.62718 .69176 m .64344 .68397 L .62552 .68968 L .655 .81 .957 r
F
.62718 .69176 m .6467 .68816 L .64344 .68397 L F
.64602 .68284 m .66077 .67287 L .64276 .67863 L .656 .809 .957 r
F
.64602 .68284 m .66556 .67922 L .66077 .67287 L F
.4383 .81852 m .42835 .81394 L .42798 .81848 L .674 .455 .58 r
F
0 g
.41841 .81961 m
.42798 .81848 L
s
.4383 .81852 m .43866 .81397 L .42835 .81394 L .674 .455 .58 r
F
0 g
.41879 .81507 m
.42835 .81394 L
s
.77831 .58069 m
.78009 .60323 L
s
.66556 .67922 m .66486 .67391 L .66007 .66754 L .975 .68 .301 r
F
0 g
.6654 .67887 m
.66542 .67902 L
s
.7651 .57253 m .74849 .56332 L .73882 .56919 L .653 .784 .944 r
F
.77109 .57024 m .74849 .56332 L .7651 .57253 L F
.44863 .81972 m .44898 .81517 L .43866 .81397 L .732 .506 .585 r
F
0 g
.44898 .81517 m
.45859 .81745 L
s
.74723 .55051 m .71615 .55006 L .73765 .55638 L .654 .782 .942 r
F
.28455 .67827 m .29464 .6781 L .29485 .68342 L .908 .646 .53 r
F
.28455 .67827 m .28434 .67294 L .29464 .6781 L F
0 g
.29464 .6781 m
.30116 .67992 L
s
.60942 .77856 m .60865 .78447 L .61564 .78448 L .597 .767 .961 r
F
.60942 .77856 m .61564 .78448 L .61293 .77857 L F
.60609 .70685 m .60773 .70707 L .6094 .77473 L .749 .498 .552 r
F
.61132 .77503 m .60942 .77856 L .61293 .77857 L .597 .767 .961 r
F
.61101 .77498 m .60942 .77856 L .61132 .77503 L F
.60597 .77815 m .60865 .78447 L .60942 .77856 L F
.60609 .70685 m .6093 .77472 L .60772 .77447 L .749 .498 .552 r
F
.60609 .70685 m .6094 .77473 L .6093 .77472 L F
.60773 .70707 m .61103 .77467 L .6094 .77473 L .648 .418 .556 r
F
.60439 .70596 m .60506 .70646 L .60668 .77408 L .925 .648 .496 r
F
.60974 .77612 m .60597 .77815 L .60942 .77856 L .597 .767 .961 r
F
.60919 .77575 m .60812 .77655 L .60974 .77612 L F
.60812 .77655 m .60597 .77815 L .60835 .77687 L F
.60812 .77655 m .60835 .77687 L .60974 .77612 L F
.60402 .70537 m .60439 .70596 L .60599 .77362 L .988 .718 .377 r
F
.60855 .77477 m .60827 .77514 L .60986 .77526 L .597 .767 .961 r
F
.60506 .70646 m .60609 .70685 L .60772 .77447 L .84 .573 .536 r
F
.60506 .70646 m .60772 .77447 L .60766 .77444 L F
.604 .70468 m .60402 .70537 L .60561 .77311 L .712 .567 0 r
F
.60746 .77437 m .60568 .77551 L .60855 .77477 L .597 .767 .961 r
F
.60568 .77551 m .6028 .77737 L .6057 .77606 L F
.60568 .77551 m .6057 .77606 L .60855 .77477 L F
.60506 .70646 m .60766 .77444 L .60668 .77408 L .84 .573 .536 r
F
.60439 .70596 m .60663 .77405 L .60599 .77362 L .925 .648 .496 r
F
.60439 .70596 m .60668 .77408 L .60663 .77405 L F
.6102 .7726 m .60334 .77509 L .6028 .77737 L .597 .767 .961 r
F
.60334 .77509 m .60013 .77625 L .60173 .77692 L F
.60334 .77509 m .60173 .77692 L .6028 .77737 L F
.604 .70468 m .60561 .77307 L .6056 .77252 L .712 .567 0 r
F
.604 .70468 m .60561 .77311 L .60561 .77307 L F
.60402 .70537 m .60597 .77359 L .60561 .77311 L .988 .718 .377 r
F
.60402 .70537 m .60599 .77362 L .60597 .77359 L F
.60461 .70382 m .604 .70468 L .6056 .77252 L .07 0 .435 r
F
.6102 .7726 m .60459 .77367 L .60334 .77509 L .597 .767 .961 r
F
.60855 .77477 m .6057 .77606 L .60597 .77815 L F
.6057 .77606 m .60576 .7781 L .60597 .77815 L F
.599 .77473 m .59696 .77337 L .59814 .77489 L F
.6102 .7726 m .60327 .773 L .599 .77473 L F
.60327 .773 m .59696 .77337 L .599 .77473 L F
.6102 .7726 m .60746 .77437 L .60855 .77477 L F
.60767 .77593 m .60597 .77815 L .60812 .77655 L F
.60668 .77408 m .60782 .7789 L .60678 .77851 L .84 .573 .536 r
F
.60597 .77815 m .60177 .78365 L .60865 .78447 L .597 .767 .961 r
F
.6028 .77737 m .60177 .78365 L .60597 .77815 L F
.6028 .77737 m .59546 .78209 L .60177 .78365 L F
.60754 .77879 m .59989 .78086 L .60258 .78197 L .596 .768 .961 r
F
.60766 .77444 m .60783 .7789 L .60668 .77408 L .84 .573 .536 r
F
.60783 .7789 m .60782 .7789 L .60668 .77408 L F
.60599 .77362 m .60677 .77851 L .6061 .77806 L .925 .648 .496 r
F
.60561 .77311 m .60609 .77806 L .60572 .77751 L .988 .718 .377 r
F
.6057 .77606 m .6028 .77737 L .60576 .7781 L .597 .767 .961 r
F
.60013 .77625 m .59546 .78209 L .6028 .77737 L F
.60602 .77796 m .59789 .77949 L .60642 .7785 L .596 .768 .961 r
F
.60609 .77806 m .60597 .77788 L .60572 .77751 L .988 .718 .377 r
F
.60461 .70382 m .60563 .77248 L .60622 .77181 L .07 0 .435 r
F
.60461 .70382 m .6056 .77252 L .60563 .77248 L F
.6102 .7726 m .60219 .77212 L .59696 .77337 L .597 .767 .961 r
F
.60219 .77212 m .59669 .77179 L .59689 .77294 L F
.60219 .77212 m .59689 .77294 L .59696 .77337 L F
.60702 .70287 m .60583 .70316 L .60747 .77131 L .583 .366 .552 r
F
.60219 .77212 m .59733 .77027 L .59669 .77179 L .597 .767 .961 r
F
.6102 .7726 m .60509 .77167 L .60219 .77212 L F
.60509 .77167 m .59733 .77027 L .60219 .77212 L F
.6102 .7726 m .60855 .77477 L .60986 .77526 L F
.60827 .77514 m .60767 .77593 L .60919 .77575 L F
.60767 .77593 m .60812 .77655 L .60919 .77575 L F
.60766 .77444 m .60772 .77447 L .60783 .77895 L .84 .573 .536 r
F
.60863 .77903 m .60783 .7789 L .60853 .77916 L .596 .768 .961 r
F
.60772 .77447 m .60951 .77916 L .60783 .7789 L .749 .498 .552 r
F
.60977 .7792 m .60577 .78276 L .60925 .78318 L .596 .768 .961 r
F
.60827 .77514 m .60919 .77575 L .60986 .77526 L .597 .767 .961 r
F
.60986 .77526 m .60919 .77575 L .60974 .77612 L F
.61099 .77498 m .60942 .77856 L .61101 .77498 L F
.6099 .77495 m .60942 .77856 L .61113 .77466 L F
.6093 .77472 m .60951 .77916 L .60772 .77447 L .749 .498 .552 r
F
.6093 .77472 m .6094 .77473 L .60951 .77917 L F
.6094 .77473 m .61124 .779 L .60953 .77916 L .648 .418 .556 r
F
.60978 .77915 m .60951 .77916 L .60977 .7792 L .596 .768 .961 r
F
.60951 .77916 m .60953 .77916 L .60951 .77917 L .648 .418 .556 r
F
.6094 .77473 m .60953 .77916 L .60951 .77916 L F
.61003 .7772 m .60863 .77903 L .60951 .77916 L .596 .768 .961 r
F
.61003 .7772 m .60951 .77916 L .60978 .77915 L F
.60951 .77916 m .60577 .78276 L .60977 .7792 L F
.60771 .79495 m .60788 .7904 L .61835 .79043 L .674 .454 .58 r
F
.60865 .78447 m .60789 .79032 L .61831 .79034 L .597 .767 .961 r
F
.60771 .79495 m .61835 .79043 L .61819 .79498 L .674 .454 .58 r
F
.60865 .78447 m .61831 .79034 L .61564 .78448 L .597 .767 .961 r
F
.60753 .79952 m .60771 .79495 L .61819 .79498 L .674 .454 .58 r
F
.60847 .78909 m .60771 .79495 L .61819 .79498 L .596 .768 .961 r
F
.60753 .79952 m .61819 .79498 L .61803 .79954 L .674 .454 .58 r
F
.60847 .78909 m .61819 .79498 L .6155 .78911 L .596 .768 .961 r
F
.6083 .79367 m .60753 .79952 L .61803 .79954 L .595 .768 .962 r
F
.6083 .79367 m .61803 .79954 L .61534 .79369 L F
.60925 .78318 m .60847 .78909 L .6155 .78911 L .596 .768 .961 r
F
.60925 .78318 m .6155 .78911 L .61278 .78318 L F
.60908 .78777 m .6083 .79367 L .61534 .79369 L .595 .768 .962 r
F
.60908 .78777 m .61534 .79369 L .61261 .78778 L F
.60953 .77916 m .61124 .779 L .61124 .7791 L .648 .418 .556 r
F
.61094 .77917 m .60925 .78318 L .61278 .78318 L .596 .768 .961 r
F
.61003 .7772 m .60974 .77944 L .61094 .77917 L F
.60974 .77944 m .60925 .78318 L .61094 .77917 L F
.61124 .779 m .61124 .7791 L .61124 .7791 L .539 .333 .549 r
F
.61115 .77466 m .61101 .77498 L .61132 .77503 L .597 .767 .961 r
F
.61113 .77466 m .61237 .77864 L .61124 .779 L .539 .333 .549 r
F
.60993 .77471 m .6099 .77495 L .61113 .77466 L .597 .767 .961 r
F
.61103 .77467 m .61124 .779 L .6094 .77473 L .648 .418 .556 r
F
.61113 .77466 m .61099 .77498 L .61115 .77466 L .597 .767 .961 r
F
.61099 .77498 m .61101 .77498 L .61115 .77466 L F
.60773 .70707 m .60942 .7069 L .61113 .77466 L .648 .418 .556 r
F
.61103 .77467 m .61113 .77466 L .61124 .779 L F
.60773 .70707 m .61113 .77466 L .61103 .77467 L F
.61307 .77523 m .61293 .77857 L .61626 .77817 L .597 .767 .961 r
F
.61241 .77463 m .61267 .77659 L .61307 .77523 L F
.61267 .77659 m .61293 .77857 L .61307 .77523 L F
.60942 .7069 m .61219 .77442 L .61113 .77466 L .539 .333 .549 r
F
.61179 .70548 m .61196 .7048 L .61373 .77299 L 0 0 .235 r
F
.61335 .77428 m .61626 .77817 L .61657 .77809 L .597 .767 .961 r
F
.61491 .77511 m .61657 .77809 L .61918 .77739 L F
.61335 .77428 m .61657 .77809 L .61491 .77511 L F
.61332 .77437 m .61626 .77817 L .61335 .77428 L F
.6113 .70606 m .61179 .70548 L .61356 .77357 L .163 .05 .467 r
F
.61278 .77428 m .61626 .77817 L .61318 .77419 L .597 .767 .961 r
F
.61245 .77459 m .61626 .77817 L .61278 .77428 L F
.6122 .77443 m .61626 .77817 L .61226 .7744 L F
.61053 .70654 m .61301 .77405 L .61226 .7744 L .402 .228 .528 r
F
.60942 .7069 m .61053 .70654 L .61226 .7744 L .539 .333 .549 r
F
.60942 .7069 m .61226 .7744 L .61219 .77442 L F
.6113 .70606 m .61353 .77359 L .61305 .77403 L .163 .05 .467 r
F
.61369 .77374 m .61918 .77739 L .62149 .77629 L .597 .767 .961 r
F
.61053 .70654 m .6113 .70606 L .61305 .77403 L .402 .228 .528 r
F
.61053 .70654 m .61305 .77403 L .61301 .77405 L F
.6102 .7726 m .61296 .77407 L .61369 .77374 L .597 .767 .961 r
F
.6113 .70606 m .61356 .77357 L .61353 .77359 L .163 .05 .467 r
F
.61179 .70548 m .61373 .77299 L .61372 .77302 L 0 0 .235 r
F
.61179 .70548 m .61372 .77302 L .61356 .77357 L F
.61196 .7048 m .61153 .70392 L .6133 .77222 L .978 .72 .315 r
F
.61296 .77407 m .61491 .77511 L .61369 .77374 L .597 .767 .961 r
F
.61563 .77359 m .62149 .77629 L .62304 .77493 L F
.6102 .7726 m .61871 .77538 L .61563 .77359 L F
.61871 .77538 m .62149 .77629 L .61563 .77359 L F
.6102 .7726 m .61218 .77442 L .61318 .77419 L F
.61301 .77405 m .61305 .77403 L .61316 .77817 L .402 .228 .528 r
F
.6124 .77464 m .61293 .77857 L .61241 .77463 L .597 .767 .961 r
F
.6102 .7726 m .61115 .77466 L .6124 .77462 L F
.61115 .77466 m .61293 .77857 L .6124 .77462 L F
.61226 .7744 m .61316 .77817 L .61237 .77864 L .402 .228 .528 r
F
.61226 .7744 m .61245 .77459 L .61278 .77428 L .597 .767 .961 r
F
.6124 .77462 m .6124 .77464 L .61241 .77463 L F
.61301 .77405 m .61316 .77817 L .61226 .7744 L .402 .228 .528 r
F
.61318 .77419 m .61332 .77437 L .61335 .77428 L .597 .767 .961 r
F
.61305 .77403 m .61366 .77762 L .61316 .77817 L .163 .05 .467 r
F
.61196 .7048 m .61332 .77226 L .61373 .77299 L .978 .72 .315 r
F
.61437 .77285 m .62304 .77493 L .62372 .77341 L .597 .767 .961 r
F
.6102 .7726 m .61563 .77359 L .61437 .77285 L F
.61563 .77359 m .62304 .77493 L .61437 .77285 L F
.61153 .70392 m .61045 .70322 L .61219 .77158 L .906 .63 .507 r
F
.61153 .70392 m .61219 .77158 L .61225 .77161 L F
.61153 .70392 m .61225 .77161 L .6133 .77222 L F
.61196 .7048 m .6133 .77222 L .61332 .77226 L .978 .72 .315 r
F
.61045 .70322 m .61111 .77127 L .61219 .77158 L .805 .544 .543 r
F
.61191 .7715 m .62035 .76892 L .61767 .76779 L .597 .767 .961 r
F
.6102 .7726 m .61266 .77171 L .61191 .7715 L F
.61266 .77171 m .62035 .76892 L .61191 .7715 L F
.61218 .77442 m .6122 .77443 L .61226 .7744 L F
.61219 .77442 m .61237 .77864 L .61113 .77466 L .539 .333 .549 r
F
.61266 .77171 m .62233 .7703 L .62035 .76892 L .597 .767 .961 r
F
.6102 .7726 m .61355 .77196 L .61266 .77171 L F
.61355 .77196 m .62233 .7703 L .61266 .77171 L F
.61045 .70322 m .60933 .7029 L .61105 .77125 L .805 .544 .543 r
F
.61045 .70322 m .61105 .77125 L .61111 .77127 L F
.60933 .7029 m .60994 .77112 L .61105 .77125 L .733 .485 .553 r
F
.61039 .77117 m .61448 .76699 L .61099 .76658 L .597 .767 .961 r
F
.6102 .7726 m .61121 .77128 L .61039 .77117 L F
.61121 .77128 m .61448 .76699 L .61039 .77117 L F
.6102 .7726 m .60993 .77471 L .61115 .77466 L F
.6102 .7726 m .61767 .76779 L .61448 .76699 L F
.6102 .7726 m .62348 .77183 L .62233 .7703 L F
.6102 .7726 m .62372 .77341 L .62348 .77183 L F
.61105 .77125 m .60997 .775 L .61114 .7751 L .733 .485 .553 r
F
.60583 .70316 m .60629 .77178 L .60747 .77131 L .438 .255 .533 r
F
.60583 .70316 m .60461 .70382 L .60622 .77181 L F
.60583 .70316 m .60622 .77181 L .60629 .77178 L F
.60818 .7028 m .60702 .70287 L .60869 .77112 L .665 .431 .556 r
F
.6102 .7726 m .60573 .77114 L .60229 .77117 L .597 .767 .961 r
F
.60702 .70287 m .60754 .7713 L .60869 .77112 L .583 .366 .552 r
F
.60702 .70287 m .60747 .77131 L .60754 .7713 L F
.60573 .77114 m .60117 .76778 L .59886 .7689 L .597 .767 .961 r
F
.6102 .7726 m .60744 .77113 L .60573 .77114 L F
.60744 .77113 m .60117 .76778 L .60573 .77114 L F
.6102 .7726 m .6041 .76698 L .60117 .76778 L F
.60818 .7028 m .60875 .77112 L .60988 .77111 L .665 .431 .556 r
F
.60818 .7028 m .60869 .77112 L .60875 .77112 L F
.6102 .7726 m .60745 .76657 L .6041 .76698 L .597 .767 .961 r
F
.60933 .7029 m .60818 .7028 L .60988 .77111 L .733 .485 .553 r
F
.60933 .7029 m .60988 .77111 L .60994 .77112 L F
.6102 .7726 m .61099 .76658 L .60745 .76657 L .597 .767 .961 r
F
.60988 .77111 m .60878 .77507 L .60997 .775 L .665 .431 .556 r
F
.60875 .77112 m .60878 .77507 L .60988 .77111 L F
.60875 .77112 m .60869 .77112 L .60878 .77507 L F
.60229 .77117 m .60302 .77025 L .59733 .77027 L .597 .767 .961 r
F
.60573 .77114 m .60302 .77025 L .60229 .77117 L F
.60302 .77025 m .59886 .7689 L .59804 .76963 L F
.60302 .77025 m .59804 .76963 L .59733 .77027 L F
.60994 .77112 m .60988 .77111 L .60997 .775 L .733 .485 .553 r
F
.60994 .77112 m .60997 .775 L .61105 .77125 L F
.61111 .77127 m .61105 .77125 L .61114 .7751 L .805 .544 .543 r
F
.61219 .77158 m .61114 .7751 L .61229 .77541 L F
.61111 .77127 m .61114 .7751 L .61219 .77158 L F
.61225 .77161 m .61219 .77158 L .61229 .77541 L .906 .63 .507 r
F
.6133 .77222 m .61229 .77541 L .6134 .77609 L F
.61225 .77161 m .61229 .77541 L .6133 .77222 L F
.61332 .77226 m .6133 .77222 L .6134 .77609 L .978 .72 .315 r
F
.61491 .77511 m .61918 .77739 L .61441 .77422 L .597 .767 .961 r
F
.61491 .77511 m .61441 .77422 L .61369 .77374 L F
.61353 .77359 m .61356 .77357 L .61366 .77762 L .163 .05 .467 r
F
.61372 .77302 m .61373 .77299 L .61383 .77695 L 0 0 .235 r
F
.61356 .77357 m .61383 .77695 L .61366 .77762 L F
.61372 .77302 m .61383 .77695 L .61356 .77357 L F
.61373 .77299 m .6134 .77609 L .61383 .77695 L .978 .72 .315 r
F
.61353 .77359 m .61366 .77762 L .61305 .77403 L .163 .05 .467 r
F
.61332 .77226 m .6134 .77609 L .61373 .77299 L .978 .72 .315 r
F
.61219 .77442 m .61226 .7744 L .61237 .77864 L .539 .333 .549 r
F
.61293 .77857 m .61564 .78448 L .62226 .78369 L .597 .767 .961 r
F
.61193 .77894 m .61278 .78318 L .61613 .78278 L .596 .768 .961 r
F
.61124 .779 m .61237 .77884 L .61124 .7791 L .539 .333 .549 r
F
.61003 .7772 m .61094 .77917 L .61193 .77894 L .596 .768 .961 r
F
.61094 .77917 m .61278 .78318 L .61193 .77894 L F
.61124 .779 m .61237 .77864 L .61237 .77884 L .539 .333 .549 r
F
.61277 .77865 m .61613 .78278 L .61906 .782 L .596 .768 .961 r
F
.61237 .77864 m .61237 .77884 L .61237 .77884 L .402 .228 .528 r
F
.61201 .77901 m .61613 .78278 L .61277 .77865 L .596 .768 .961 r
F
.61293 .77857 m .62226 .78369 L .61626 .77817 L .597 .767 .961 r
F
.61564 .78448 m .61831 .79034 L .62822 .78917 L F
.61278 .78318 m .6155 .78911 L .62217 .78832 L .596 .768 .961 r
F
.61564 .78448 m .62822 .78917 L .62226 .78369 L .597 .767 .961 r
F
.61278 .78318 m .62217 .78832 L .61613 .78278 L .596 .768 .961 r
F
.61819 .79498 m .61835 .79043 L .6283 .78925 L .609 .4 .573 r
F
.61819 .79498 m .6283 .78925 L .62816 .79381 L F
.6155 .78911 m .61819 .79498 L .62816 .79381 L .596 .768 .961 r
F
.61261 .78778 m .61534 .79369 L .62201 .7929 L .595 .768 .962 r
F
.6155 .78911 m .62816 .79381 L .62217 .78832 L .596 .768 .961 r
F
.61261 .78778 m .62201 .7929 L .61596 .78738 L .595 .768 .962 r
F
.61626 .77817 m .62226 .78369 L .62809 .78215 L .597 .767 .961 r
F
.61348 .77832 m .61906 .782 L .62139 .7809 L .596 .768 .961 r
F
.61237 .77864 m .61316 .77817 L .61317 .77847 L .402 .228 .528 r
F
.61317 .77847 m .61906 .782 L .61348 .77832 L .596 .768 .961 r
F
.61277 .77865 m .61289 .77872 L .61317 .77847 L F
.61289 .77872 m .61906 .782 L .61317 .77847 L F
.61316 .77817 m .61366 .77762 L .61367 .778 L .163 .05 .467 r
F
.61337 .77828 m .61317 .77847 L .61348 .77832 L .596 .768 .961 r
F
.6131 .78477 m .61261 .78778 L .61596 .78738 L .595 .768 .962 r
F
.61626 .77817 m .62809 .78215 L .61918 .77739 L .597 .767 .961 r
F
.61371 .77786 m .62139 .7809 L .62295 .77954 L .596 .768 .961 r
F
.61357 .77835 m .62139 .7809 L .61371 .77786 L F
.61367 .778 m .61396 .78188 L .6138 .78241 L 0 0 .235 r
F
.61366 .77762 m .61369 .77796 L .61367 .778 L F
.61369 .77796 m .61396 .78188 L .61367 .778 L F
.61918 .77739 m .62809 .78215 L .63272 .77996 L .597 .767 .961 r
F
.61918 .77739 m .63272 .77996 L .62149 .77629 L F
.61384 .77743 m .62295 .77954 L .62363 .77801 L .596 .768 .961 r
F
.61366 .77762 m .61384 .77743 L .61369 .77796 L 0 0 .235 r
F
.61366 .77762 m .6138 .78241 L .61379 .78245 L F
.61384 .77743 m .62295 .77954 L .61384 .77743 L .596 .768 .961 r
F
.61371 .77786 m .61413 .77794 L .61384 .77743 L F
.61413 .77794 m .62295 .77954 L .61384 .77743 L F
.61383 .77695 m .6134 .77609 L .61341 .77666 L .978 .72 .315 r
F
.61003 .7772 m .61371 .77786 L .61384 .77743 L .596 .768 .961 r
F
.61003 .7772 m .61384 .77743 L .61384 .77743 L F
.61316 .77817 m .61367 .778 L .61317 .77847 L .163 .05 .467 r
F
.61003 .7772 m .61357 .77835 L .61371 .77786 L .596 .768 .961 r
F
.61366 .77762 m .61383 .77695 L .61384 .77743 L 0 0 .235 r
F
.61369 .77796 m .61384 .77743 L .61396 .78188 L F
.61342 .7837 m .61596 .78738 L .6189 .7866 L .595 .768 .962 r
F
.61332 .78403 m .61596 .78738 L .61342 .7837 L F
.61218 .78393 m .61596 .78738 L .61279 .78336 L F
.62226 .78369 m .62822 .78917 L .63694 .78688 L .597 .767 .961 r
F
.61613 .78278 m .62217 .78832 L .62803 .78678 L .596 .768 .961 r
F
.61482 .78342 m .6189 .7866 L .62123 .7855 L .595 .768 .962 r
F
.61317 .77847 m .61331 .78288 L .61317 .77847 L .163 .05 .467 r
F
.61328 .78292 m .61564 .78487 L .61482 .78342 L .595 .768 .962 r
F
.61279 .78336 m .61564 .78487 L .61328 .78292 L F
.61279 .78336 m .61332 .78403 L .61342 .7837 L F
.61331 .78288 m .61331 .78289 L .61317 .77847 L .163 .05 .467 r
F
.61613 .78278 m .62803 .78678 L .61906 .782 L .596 .768 .961 r
F
.61437 .78262 m .62123 .7855 L .62279 .78414 L .595 .768 .962 r
F
.61317 .77847 m .61331 .78289 L .61328 .78291 L .163 .05 .467 r
F
.61317 .77847 m .61379 .78245 L .61331 .78288 L F
.61241 .77882 m .61317 .77847 L .61328 .78291 L .402 .228 .528 r
F
.61237 .77864 m .61328 .78291 L .61254 .78326 L F
.61237 .77884 m .61253 .78326 L .61249 .78328 L F
.61124 .7791 m .61237 .77884 L .61249 .78328 L .539 .333 .549 r
F
.61259 .78326 m .61218 .78393 L .61279 .78336 L .595 .768 .962 r
F
.61256 .78327 m .61218 .78393 L .61259 .78326 L F
.61181 .78359 m .61218 .78393 L .61257 .78324 L F
.61218 .78393 m .6125 .7868 L .6131 .78477 L F
.6125 .7868 m .61261 .78778 L .6131 .78477 L F
.61181 .78359 m .61192 .78416 L .61218 .78393 L F
.61192 .78416 m .61261 .78778 L .61218 .78393 L F
.61124 .7791 m .61249 .78328 L .61142 .78353 L .539 .333 .549 r
F
.60953 .77916 m .61124 .7791 L .61135 .78354 L .648 .418 .556 r
F
.61174 .78353 m .61088 .78403 L .61181 .78359 L .595 .768 .962 r
F
.61158 .78353 m .61088 .78403 L .61174 .78353 L F
.61073 .78369 m .61088 .78403 L .61168 .78347 L F
.61088 .78403 m .61261 .78778 L .61181 .78359 L F
.60953 .77916 m .61135 .78354 L .60974 .7836 L .648 .418 .556 r
F
.60863 .77903 m .6085 .7792 L .60951 .77916 L .596 .768 .961 r
F
.6085 .7792 m .60577 .78276 L .60951 .77916 L F
.60853 .77916 m .60258 .78197 L .60577 .78276 L F
.60754 .77879 m .60258 .78197 L .60853 .77916 L F
.60783 .77895 m .60951 .77917 L .60962 .78361 L .749 .498 .552 r
F
.61077 .78379 m .60908 .78777 L .61261 .78778 L .595 .768 .962 r
F
.61069 .78378 m .60908 .78777 L .61077 .78379 L F
.61067 .78357 m .60958 .78395 L .61073 .78369 L F
.60962 .78361 m .60958 .78395 L .61067 .78357 L F
.60958 .78395 m .60908 .78777 L .61073 .78369 L F
.6104 .853 m .61013 .85517 L .61387 .85468 L .656 .815 .96 r
F
.6129 .85268 m .61387 .85468 L .61742 .85378 L F
.6104 .853 m .61387 .85468 L .6129 .85268 L F
.61455 .85226 m .61742 .85378 L .61527 .85208 L F
.6129 .85268 m .61433 .85303 L .61455 .85226 L F
.61433 .85303 m .61742 .85378 L .61455 .85226 L F
.61527 .85208 m .61742 .85378 L .61869 .85328 L F
.61812 .85233 m .61869 .85328 L .62053 .85254 L F
.61527 .85208 m .61869 .85328 L .61812 .85233 L F
.61527 .85208 m .62053 .85254 L .61735 .85124 L F
.61328 .78292 m .61482 .78342 L .61404 .78256 L .595 .768 .962 r
F
.61331 .78288 m .61548 .84889 L .61331 .78289 L .163 .05 .467 r
F
.61124 .7791 m .61142 .78353 L .61124 .7791 L .539 .333 .549 r
F
.61142 .78353 m .61142 .78353 L .61124 .7791 L F
.61124 .7791 m .61142 .78353 L .61135 .78354 L F
.61237 .77884 m .61254 .78326 L .61237 .77884 L .402 .228 .528 r
F
.61254 .78326 m .61253 .78326 L .61237 .77884 L F
.60986 .78181 m .61328 .78292 L .61404 .78256 L .595 .768 .962 r
F
.62226 .78369 m .63694 .78688 L .62809 .78215 L .597 .767 .961 r
F
.62809 .78215 m .63694 .78688 L .6439 .78361 L F
.61906 .782 m .62803 .78678 L .63269 .78458 L .596 .768 .961 r
F
.61906 .782 m .63269 .78458 L .62139 .7809 L F
.61406 .78206 m .62279 .78414 L .62348 .78262 L .595 .768 .962 r
F
.61317 .77847 m .61367 .778 L .61379 .78245 L .163 .05 .467 r
F
.60986 .78181 m .61437 .78262 L .61406 .78206 L .595 .768 .962 r
F
.61437 .78262 m .62279 .78414 L .61406 .78206 L F
.61384 .77743 m .61393 .78183 L .61384 .77743 L .978 .72 .315 r
F
.61393 .78183 m .61393 .78183 L .61384 .77743 L F
.61384 .77743 m .61393 .78183 L .61396 .78188 L F
.61384 .77743 m .61353 .78111 L .61393 .78183 L F
.62809 .78215 m .6439 .78361 L .63272 .77996 L .597 .767 .961 r
F
.62139 .7809 m .63269 .78458 L .63584 .78187 L .596 .768 .961 r
F
.61429 .78155 m .62348 .78262 L .62324 .78104 L .595 .768 .962 r
F
.60986 .78181 m .61529 .78213 L .61429 .78155 L F
.61529 .78213 m .62348 .78262 L .61429 .78155 L F
.61498 .85075 m .61527 .85208 L .61735 .85124 L .656 .815 .96 r
F
.61392 .85053 m .61476 .8515 L .61498 .85075 L F
.61548 .84889 m .61548 .84889 L .61331 .78289 L .163 .05 .467 r
F
.61254 .78326 m .61495 .84943 L .61253 .78326 L .402 .228 .528 r
F
.61372 .85075 m .61527 .85208 L .61392 .85053 L .656 .815 .96 r
F
.61323 .85046 m .61367 .8508 L .61331 .8504 L F
.61367 .8508 m .61527 .85208 L .61372 .85075 L F
.61367 .8508 m .61372 .85075 L .61331 .8504 L F
.61476 .8515 m .61527 .85208 L .61498 .85075 L F
.61248 .8509 m .6129 .85268 L .61527 .85208 L F
.61253 .78326 m .61495 .84943 L .61249 .78328 L .402 .228 .528 r
F
.61267 .85079 m .61527 .85208 L .61323 .85046 L .656 .815 .96 r
F
.61197 .85068 m .61248 .8509 L .61225 .85058 L F
.61248 .8509 m .61527 .85208 L .61267 .85079 L F
.61248 .8509 m .61267 .85079 L .61225 .85058 L F
.61257 .78324 m .61256 .78327 L .61259 .78326 L .595 .768 .962 r
F
.61254 .78326 m .61328 .78291 L .61499 .8494 L .402 .228 .528 r
F
.61331 .78289 m .61548 .84889 L .61328 .78291 L .163 .05 .467 r
F
.6151 .8503 m .61735 .85124 L .61744 .85119 L .656 .815 .96 r
F
.61439 .85004 m .6151 .85032 L .6151 .8503 L F
.6151 .85032 m .61735 .85124 L .6151 .8503 L F
.6138 .78241 m .61567 .84828 L .61379 .78245 L 0 0 .235 r
F
.61439 .85004 m .61735 .85124 L .61439 .85004 L .656 .815 .96 r
F
.61446 .84996 m .61744 .85119 L .61679 .8501 L F
.61415 .84995 m .61439 .85004 L .61446 .84996 L F
.61439 .85004 m .61744 .85119 L .61446 .84996 L F
.61331 .78288 m .61379 .78245 L .61551 .84886 L .163 .05 .467 r
F
.61311 .85036 m .61735 .85124 L .61415 .84995 L .656 .815 .96 r
F
.61331 .78288 m .61551 .84886 L .61548 .84889 L .163 .05 .467 r
F
.61567 .84828 m .61567 .84829 L .61379 .78245 L 0 0 .235 r
F
.61548 .84889 m .61548 .84889 L .61328 .78291 L .163 .05 .467 r
F
.61328 .78291 m .61548 .84889 L .61499 .8494 L F
.6138 .78241 m .61393 .78196 L .61429 .79976 L 0 0 .235 r
F
.61435 .80188 m .61396 .78188 L .61568 .84825 L F
.6138 .78241 m .61568 .84825 L .61567 .84828 L F
.61379 .78245 m .61567 .84829 L .61551 .84886 L F
.61393 .78183 m .61526 .84756 L .61396 .78188 L .978 .72 .315 r
F
.61497 .84944 m .61658 .84976 L .61641 .84947 L .656 .815 .96 r
F
.61634 .84935 m .61967 .84954 L .61889 .84919 L F
.61497 .84944 m .61641 .84947 L .61634 .84935 L F
.61641 .84947 m .61967 .84954 L .61634 .84935 L F
.6134 .77609 m .6134 .77666 L .61341 .77666 L .906 .63 .507 r
F
.61383 .77695 m .61341 .77666 L .61384 .77743 L .978 .72 .315 r
F
.61383 .77695 m .61384 .77743 L .61384 .77743 L F
.62149 .77629 m .63272 .77996 L .63585 .77725 L .597 .767 .961 r
F
.62149 .77629 m .63585 .77725 L .62304 .77493 L F
.61328 .77659 m .62339 .77643 L .62224 .77489 L .596 .768 .961 r
F
.61003 .7772 m .61395 .77697 L .61328 .77659 L F
.61395 .77697 m .62339 .77643 L .61328 .77659 L F
.6134 .77609 m .61229 .77541 L .61231 .77602 L .906 .63 .507 r
F
.61003 .7772 m .61328 .77659 L .61269 .77624 L .596 .768 .961 r
F
.61316 .77817 m .61317 .77847 L .61317 .77847 L .163 .05 .467 r
F
.61003 .7772 m .61277 .77865 L .61317 .77847 L .596 .768 .961 r
F
.61003 .7772 m .61317 .77847 L .61337 .77828 L F
.61237 .77864 m .61317 .77847 L .61241 .77882 L .402 .228 .528 r
F
.61539 .77689 m .62363 .77801 L .62339 .77643 L .596 .768 .961 r
F
.61003 .7772 m .61821 .77769 L .61539 .77689 L F
.61821 .77769 m .62363 .77801 L .61539 .77689 L F
.60986 .78181 m .61353 .78112 L .61286 .78073 L .595 .768 .962 r
F
.61415 .84995 m .61439 .85004 L .61439 .85004 L .656 .815 .96 r
F
.61495 .84943 m .61495 .84943 L .61249 .78328 L .402 .228 .528 r
F
.61225 .85058 m .61267 .85079 L .61311 .85036 L .656 .815 .96 r
F
.61047 .85801 m .61012 .8552 L .61389 .85471 L .672 .447 .572 r
F
.61424 .85752 m .61389 .85471 L .61745 .85381 L .609 .402 .576 r
F
.61047 .85801 m .61389 .85471 L .61424 .85752 L .672 .447 .572 r
F
.61228 .85349 m .61326 .85551 L .61564 .8549 L .655 .815 .96 r
F
.6178 .85662 m .61745 .85381 L .62058 .85256 L .531 .347 .577 r
F
.61424 .85752 m .61745 .85381 L .6178 .85662 L .609 .402 .576 r
F
.61348 .85319 m .61564 .8549 L .61773 .85407 L .655 .815 .96 r
F
.61331 .85323 m .61564 .8549 L .61348 .85319 L F
.61228 .85349 m .61263 .85363 L .61331 .85323 L F
.61263 .85363 m .61564 .8549 L .61331 .85323 L F
.61451 .85277 m .61773 .85407 L .61452 .85277 L F
.61348 .85319 m .61401 .8533 L .61451 .85277 L F
.61401 .8533 m .61773 .85407 L .61451 .85277 L F
.61452 .85277 m .61773 .85407 L .61939 .85305 L F
.61525 .85281 m .61939 .85305 L .6154 .85227 L F
.61735 .85124 m .62053 .85254 L .623 .85103 L .656 .815 .96 r
F
.61541 .85225 m .61939 .85305 L .62049 .85193 L .655 .815 .96 r
F
.61535 .85226 m .6154 .85227 L .61541 .85225 L F
.6154 .85227 m .61939 .85305 L .61541 .85225 L F
.61415 .84995 m .61899 .85023 L .61526 .8495 L .656 .815 .96 r
F
.61435 .84983 m .61526 .8495 L .61497 .84944 L F
.61415 .84995 m .61526 .8495 L .61435 .84983 L F
.61168 .78347 m .61158 .78353 L .61174 .78353 L .595 .768 .962 r
F
.61142 .78353 m .61249 .78328 L .61419 .84989 L .539 .333 .549 r
F
.61427 .85266 m .61348 .85319 L .61452 .85277 L .655 .815 .96 r
F
.6131 .85308 m .61429 .85394 L .61314 .85429 L .539 .333 .549 r
F
.61303 .8503 m .61389 .8528 L .6131 .85308 L F
.61327 .85302 m .61348 .85319 L .61427 .85266 L .655 .815 .96 r
F
.61389 .8528 m .61429 .85394 L .6131 .85308 L .539 .333 .549 r
F
.61331 .8504 m .61372 .85075 L .61392 .85053 L .656 .815 .96 r
F
.61311 .85036 m .61323 .85046 L .61331 .8504 L F
.61412 .84991 m .61424 .85267 L .61303 .8503 L .539 .333 .549 r
F
.61424 .85267 m .61429 .85394 L .61389 .8528 L F
.61424 .85267 m .61389 .8528 L .61303 .8503 L F
.61412 .84991 m .61419 .84989 L .61426 .85267 L F
.61412 .84991 m .61426 .85267 L .61424 .85267 L F
.61419 .84989 m .61481 .85234 L .61426 .85267 L .402 .228 .528 r
F
.61495 .84943 m .61499 .8494 L .61507 .85218 L F
.61452 .85277 m .61525 .85281 L .61535 .85226 L .655 .815 .96 r
F
.61505 .85219 m .61507 .85218 L .6151 .85349 L .402 .228 .528 r
F
.61495 .84943 m .61507 .85218 L .61505 .85219 L F
.61504 .8522 m .61427 .85266 L .61535 .85226 L .655 .815 .96 r
F
.61426 .85266 m .61427 .85266 L .61504 .8522 L F
.61427 .85266 m .61452 .85277 L .61529 .85229 L F
.61427 .85266 m .61529 .85229 L .61535 .85226 L F
.61495 .84943 m .61505 .85219 L .61419 .84989 L .402 .228 .528 r
F
.61505 .85219 m .6151 .85349 L .61481 .85234 L F
.61505 .85219 m .61481 .85234 L .61419 .84989 L F
.61589 .85169 m .61535 .85226 L .6159 .8517 L .655 .815 .96 r
F
.61499 .8494 m .61542 .85182 L .61507 .85218 L .163 .05 .467 r
F
.61497 .84944 m .62009 .84911 L .61552 .84888 L .656 .815 .96 r
F
.61548 .84889 m .61551 .84886 L .61558 .85164 L .163 .05 .467 r
F
.61541 .85225 m .62049 .85193 L .61543 .85218 L .655 .815 .96 r
F
.61548 .84889 m .61558 .85164 L .61557 .85165 L .163 .05 .467 r
F
.61575 .85104 m .6157 .85122 L .61551 .84886 L 0 0 .235 r
F
.61551 .84886 m .6157 .85122 L .61558 .85164 L F
.61548 .84889 m .61557 .85165 L .61548 .84889 L .163 .05 .467 r
F
.61543 .85218 m .61641 .85213 L .6159 .8517 L .655 .815 .96 r
F
.61557 .85165 m .61561 .85295 L .61557 .85165 L .163 .05 .467 r
F
.61557 .85165 m .61557 .85165 L .61548 .84889 L F
.61576 .85145 m .6159 .8517 L .616 .85145 L .655 .815 .96 r
F
.61495 .84943 m .6151 .85349 L .61495 .84943 L .402 .228 .528 r
F
.61216 .85109 m .6129 .85268 L .61248 .8509 L .656 .815 .96 r
F
.61194 .85069 m .6129 .85268 L .61197 .85068 L F
.61412 .84991 m .61429 .85394 L .61412 .84991 L .539 .333 .549 r
F
.61548 .84889 m .61557 .85165 L .61499 .8494 L .163 .05 .467 r
F
.61555 .85168 m .61507 .85218 L .61589 .85169 L .655 .815 .96 r
F
.61557 .85165 m .61561 .85295 L .61542 .85182 L .163 .05 .467 r
F
.61557 .85165 m .61542 .85182 L .61499 .8494 L F
.61495 .84943 m .61505 .85219 L .61495 .84943 L .402 .228 .528 r
F
.61505 .85219 m .6151 .85349 L .61505 .85219 L F
.61505 .85219 m .61505 .85219 L .61495 .84943 L F
.61552 .84888 m .62009 .84911 L .62057 .84796 L .656 .815 .96 r
F
.61552 .84888 m .62057 .84796 L .61576 .8483 L F
.61142 .78353 m .61419 .84989 L .61412 .84991 L .539 .333 .549 r
F
.61254 .78326 m .61499 .8494 L .61495 .84943 L .402 .228 .528 r
F
.61135 .78354 m .61412 .84991 L .61303 .8503 L .539 .333 .549 r
F
.61249 .78328 m .61495 .84943 L .61419 .84989 L .402 .228 .528 r
F
.61142 .78353 m .61412 .84991 L .61142 .78353 L .539 .333 .549 r
F
.61412 .84991 m .61412 .84991 L .61142 .78353 L F
.61495 .84943 m .61495 .84943 L .61253 .78326 L .402 .228 .528 r
F
.61267 .85079 m .61323 .85046 L .61311 .85036 L .656 .815 .96 r
F
.61193 .85066 m .61197 .85068 L .61225 .85058 L F
.61197 .85068 m .61216 .85109 L .61248 .8509 L F
.61193 .85066 m .61194 .85069 L .61197 .85068 L F
.61068 .85083 m .6104 .853 L .6129 .85268 L F
.61068 .85083 m .6129 .85268 L .61193 .85066 L F
.61103 .85365 m .61075 .85583 L .61326 .85551 L .655 .815 .96 r
F
.61103 .85365 m .61326 .85551 L .61228 .85349 L F
.6119 .85061 m .61068 .85083 L .61193 .85066 L .656 .815 .96 r
F
.61185 .8505 m .61149 .8506 L .6119 .85061 L F
.61149 .8506 m .61068 .85083 L .6119 .85061 L F
.60177 .78365 m .60789 .79032 L .60865 .78447 L .597 .767 .961 r
F
.60577 .78276 m .60847 .78909 L .60925 .78318 L .596 .768 .961 r
F
.60177 .78365 m .59762 .7891 L .60789 .79032 L .597 .767 .961 r
F
.60577 .78276 m .60155 .78828 L .60847 .78909 L .596 .768 .961 r
F
.60659 .77844 m .59989 .78086 L .60754 .77879 L F
.60678 .77856 m .60783 .77895 L .60793 .78334 L .84 .573 .536 r
F
.60948 .78467 m .6056 .78736 L .60908 .78777 L .595 .768 .962 r
F
.60958 .78395 m .60906 .78439 L .60948 .78467 L F
.60906 .78439 m .6056 .78736 L .60948 .78467 L F
.60642 .7785 m .59789 .77949 L .59989 .78086 L .596 .768 .961 r
F
.6061 .77808 m .60678 .77856 L .60689 .78296 L .925 .648 .496 r
F
.60935 .78387 m .6089 .78429 L .60958 .78395 L .595 .768 .962 r
F
.6089 .78429 m .6056 .78736 L .60906 .78439 L F
.6089 .78429 m .60906 .78439 L .60958 .78395 L F
.60597 .77359 m .6061 .77806 L .60561 .77311 L .988 .718 .377 r
F
.6061 .77806 m .6061 .77808 L .60609 .77806 L F
.6061 .77806 m .60609 .77806 L .60561 .77311 L F
.60013 .77625 m .59012 .77988 L .59546 .78209 L .597 .767 .961 r
F
.59814 .77489 m .59012 .77988 L .60013 .77625 L F
.60565 .77745 m .59643 .77639 L .59671 .77797 L .596 .768 .961 r
F
.6056 .77252 m .60572 .77751 L .6057 .77684 L .712 .567 0 r
F
.60561 .77307 m .60572 .77751 L .6056 .77252 L F
.60561 .77307 m .60561 .77311 L .60572 .77751 L F
.60663 .77405 m .60678 .77851 L .60599 .77362 L .925 .648 .496 r
F
.60678 .77851 m .60678 .77856 L .60677 .77851 L F
.60678 .77851 m .60677 .77851 L .60599 .77362 L F
.60597 .77359 m .60599 .77362 L .6061 .77808 L .988 .718 .377 r
F
.60663 .77405 m .60668 .77408 L .60678 .77856 L .925 .648 .496 r
F
.61003 .7772 m .60602 .77796 L .6061 .77806 L .596 .768 .961 r
F
.60664 .77842 m .6061 .77806 L .60642 .7785 L F
.61003 .7772 m .6061 .77806 L .60664 .77842 L F
.6057 .77684 m .60572 .77751 L .60572 .77754 L .712 .567 0 r
F
.60572 .77745 m .6055 .77719 L .60565 .77745 L .596 .768 .961 r
F
.6055 .77719 m .60526 .77691 L .60548 .77721 L F
.6055 .77719 m .60548 .77721 L .60565 .77745 L F
.60632 .77599 m .6057 .77684 L .6057 .77696 L .07 0 .435 r
F
.6057 .77694 m .60526 .77691 L .60572 .77745 L .596 .768 .961 r
F
.60773 .78459 m .6056 .78736 L .60807 .78506 L .595 .768 .962 r
F
.60573 .77801 m .59671 .77797 L .59789 .77949 L .596 .768 .961 r
F
.60572 .77754 m .59671 .77797 L .60573 .77801 L F
.60572 .77745 m .60565 .77745 L .60572 .77754 L F
.60565 .77745 m .59671 .77797 L .60572 .77754 L F
.59737 .79374 m .60788 .7904 L .60771 .79495 L .732 .504 .582 r
F
.59737 .79374 m .59756 .78918 L .60788 .7904 L F
.59719 .7983 m .60771 .79495 L .60753 .79952 L F
.59719 .7983 m .59737 .79374 L .60771 .79495 L F
.60155 .78828 m .60771 .79495 L .60847 .78909 L .596 .768 .961 r
F
.60155 .78828 m .59737 .79374 L .60771 .79495 L F
.60137 .79285 m .60753 .79952 L .6083 .79367 L .595 .768 .962 r
F
.60137 .79285 m .59719 .7983 L .60753 .79952 L F
.6056 .78736 m .6083 .79367 L .60908 .78777 L F
.6056 .78736 m .60137 .79285 L .6083 .79367 L F
.60258 .78197 m .60155 .78828 L .60577 .78276 L .596 .768 .961 r
F
.60773 .78459 m .6024 .78657 L .6056 .78736 L .595 .768 .962 r
F
.60678 .77856 m .60793 .78334 L .60695 .78298 L .84 .573 .536 r
F
.60783 .77895 m .60804 .78336 L .60793 .78334 L .749 .498 .552 r
F
.60951 .77917 m .60973 .7836 L .60962 .78361 L .648 .418 .556 r
F
.60951 .77917 m .60953 .77916 L .60974 .7836 L F
.60951 .77917 m .60974 .7836 L .60973 .7836 L F
.60783 .77895 m .60962 .78361 L .60804 .78336 L .749 .498 .552 r
F
.60986 .78181 m .60702 .78362 L .60773 .78459 L .595 .768 .962 r
F
.6057 .77696 m .60572 .77754 L .60582 .78199 L .712 .567 0 r
F
.60589 .78434 m .6024 .78657 L .60592 .78526 L .595 .768 .962 r
F
.59546 .78209 m .59762 .7891 L .60177 .78365 L .597 .767 .961 r
F
.59546 .78209 m .58818 .78678 L .59762 .7891 L F
.60258 .78197 m .5952 .78671 L .60155 .78828 L .596 .768 .961 r
F
.60702 .78362 m .59971 .78546 L .6024 .78657 L .595 .768 .962 r
F
.60678 .77856 m .60695 .78298 L .60689 .78296 L .84 .573 .536 r
F
.6061 .77808 m .60689 .78296 L .60624 .78253 L .925 .648 .496 r
F
.60986 .78181 m .60656 .78299 L .60702 .78362 L .595 .768 .962 r
F
.60572 .77754 m .60585 .78202 L .60572 .77754 L .988 .718 .377 r
F
.60585 .78202 m .60585 .78202 L .60572 .77754 L F
.6057 .77696 m .60582 .78199 L .60581 .78144 L .712 .567 0 r
F
.60572 .77754 m .60585 .78202 L .60582 .78199 L .988 .718 .377 r
F
.60572 .77751 m .60572 .77754 L .60572 .77754 L F
.6057 .77684 m .60572 .77754 L .6057 .77696 L .712 .567 0 r
F
.60586 .78325 m .60339 .78413 L .60588 .78378 L .595 .768 .962 r
F
.60339 .78413 m .60293 .78465 L .60702 .78362 L F
.60602 .77796 m .60572 .77754 L .60573 .77801 L .596 .768 .961 r
F
.60572 .77755 m .6061 .77808 L .6062 .7825 L .988 .718 .377 r
F
.60572 .77751 m .6062 .7825 L .60585 .78202 L F
.6061 .77808 m .60624 .78253 L .6062 .7825 L .925 .648 .496 r
F
.59989 .78086 m .5952 .78671 L .60258 .78197 L .596 .768 .961 r
F
.60986 .78181 m .60457 .7828 L .60339 .78413 L .595 .768 .962 r
F
.59012 .77988 m .58818 .78678 L .59546 .78209 L .597 .767 .961 r
F
.59989 .78086 m .58983 .78449 L .5952 .78671 L .596 .768 .961 r
F
.59819 .784 m .59652 .78257 L .5977 .78409 L .595 .768 .962 r
F
.60986 .78181 m .60263 .78222 L .59819 .784 L F
.60263 .78222 m .59652 .78257 L .59819 .784 L F
.60702 .78362 m .60589 .78434 L .60773 .78459 L F
.60589 .78434 m .60592 .78526 L .60773 .78459 L F
.60844 .78365 m .60773 .78459 L .60935 .78387 L F
.60773 .78459 m .60807 .78506 L .60935 .78387 L F
.60656 .78299 m .60586 .78325 L .60702 .78362 L F
.60586 .78325 m .60588 .78378 L .60702 .78362 L F
.60794 .85303 m .61013 .85517 L .6104 .853 L .656 .815 .96 r
F
.60794 .85303 m .60644 .85521 L .61013 .85517 L F
.60944 .85084 m .6104 .853 L .61068 .85083 L F
.60944 .85084 m .60794 .85303 L .6104 .853 L F
.60831 .85071 m .60794 .85303 L .60944 .85084 L F
.60676 .85805 m .61012 .8552 L .61047 .85801 L .73 .489 .563 r
F
.60676 .85805 m .60642 .85524 L .61012 .8552 L F
.60978 .85367 m .60827 .85586 L .61075 .85583 L .655 .815 .96 r
F
.60865 .85353 m .60827 .85586 L .60978 .85367 L F
.60336 .85765 m .60642 .85524 L .60676 .85805 L .789 .532 .548 r
F
.60865 .85353 m .606 .85559 L .60827 .85586 L .655 .815 .96 r
F
.60336 .85765 m .60302 .85484 L .60642 .85524 L .789 .532 .548 r
F
.60568 .85276 m .60644 .85521 L .60794 .85303 L .656 .815 .96 r
F
.60568 .85276 m .60306 .85481 L .60644 .85521 L F
.60769 .85325 m .606 .85559 L .60858 .85358 L .655 .815 .96 r
F
.60851 .85349 m .60858 .85358 L .60865 .85353 L F
.60769 .85325 m .60858 .85358 L .60851 .85349 L F
.59789 .77949 m .58983 .78449 L .59989 .78086 L .596 .768 .961 r
F
.60986 .78181 m .60073 .78126 L .59652 .78257 L .595 .768 .962 r
F
.60073 .78126 m .59624 .781 L .59641 .78192 L F
.60073 .78126 m .59641 .78192 L .59652 .78257 L F
.61003 .7772 m .6057 .77694 L .60572 .77745 L .596 .768 .961 r
F
.60878 .77507 m .60757 .77535 L .60758 .77575 L .583 .366 .552 r
F
.61003 .7772 m .60572 .77745 L .60572 .77754 L .596 .768 .961 r
F
.60572 .77751 m .60597 .77788 L .60572 .77755 L .988 .718 .377 r
F
.61003 .7772 m .60572 .77754 L .60602 .77796 L .596 .768 .961 r
F
.60783 .7789 m .60951 .77917 L .60783 .77895 L .749 .498 .552 r
F
.60951 .77916 m .60951 .77917 L .60783 .7789 L F
.61003 .7772 m .60754 .77879 L .60783 .7789 L .596 .768 .961 r
F
.61003 .7772 m .60783 .7789 L .60863 .77903 L F
.61003 .7772 m .60664 .77842 L .60754 .77879 L F
.60783 .7789 m .60783 .77895 L .60782 .7789 L .84 .573 .536 r
F
.60678 .77851 m .60783 .77895 L .60678 .77856 L F
.60782 .7789 m .60783 .77895 L .60678 .77851 L F
.60334 .77509 m .599 .77473 L .60013 .77625 L .597 .767 .961 r
F
.599 .77473 m .59831 .77501 L .60013 .77625 L F
.59814 .77489 m .58613 .77717 L .59012 .77988 L F
.59696 .77337 m .58613 .77717 L .59814 .77489 L F
.60146 .77669 m .59708 .77486 L .59643 .77639 L .596 .768 .961 r
F
.61003 .7772 m .60611 .77649 L .60572 .77694 L F
.6061 .77806 m .60678 .77856 L .6061 .77808 L .925 .648 .496 r
F
.60664 .77842 m .60659 .77844 L .60678 .77851 L .596 .768 .961 r
F
.60677 .77851 m .60678 .77856 L .6061 .77806 L .925 .648 .496 r
F
.60632 .77599 m .60633 .77625 L .60633 .77625 L .07 0 .435 r
F
.60622 .77181 m .6057 .77684 L .60632 .77599 L F
.60563 .77248 m .6057 .77684 L .60622 .77181 L F
.60459 .77367 m .599 .77473 L .60334 .77509 L .597 .767 .961 r
F
.599 .77473 m .59814 .77489 L .59831 .77501 L F
.60563 .77248 m .6056 .77252 L .6057 .77684 L .07 0 .435 r
F
.60585 .77644 m .59862 .77348 L .59708 .77486 L .596 .768 .961 r
F
.60632 .77599 m .6057 .77696 L .60633 .77625 L .07 0 .435 r
F
.61003 .7772 m .60668 .77611 L .60585 .77644 L .596 .768 .961 r
F
.60668 .77611 m .59862 .77348 L .60585 .77644 L F
.60757 .77535 m .60632 .77599 L .60633 .77625 L .438 .255 .533 r
F
.60757 .77535 m .60633 .77625 L .60748 .77579 L F
.60747 .77131 m .60632 .77599 L .60757 .77535 L F
.60629 .77178 m .60632 .77599 L .60747 .77131 L F
.60629 .77178 m .60622 .77181 L .60632 .77599 L F
.60668 .77611 m .60094 .77236 L .59862 .77348 L .596 .768 .961 r
F
.61003 .7772 m .60742 .77581 L .60668 .77611 L F
.60742 .77581 m .60094 .77236 L .60668 .77611 L F
.60664 .77842 m .60678 .77851 L .60754 .77879 L F
.60757 .77535 m .60758 .77575 L .60758 .77575 L .438 .255 .533 r
F
.60878 .77507 m .60758 .77575 L .60868 .77558 L .583 .366 .552 r
F
.60742 .77581 m .60389 .77157 L .60094 .77236 L .596 .768 .961 r
F
.61003 .7772 m .60832 .77563 L .60742 .77581 L F
.61068 .85081 m .60944 .85084 L .61068 .85083 L .656 .815 .96 r
F
.60964 .85056 m .60944 .85084 L .61068 .85081 L F
.60978 .85367 m .61075 .85583 L .61103 .85365 L .655 .815 .96 r
F
.60793 .78334 m .61118 .85059 L .60956 .85054 L .749 .498 .552 r
F
.60689 .78296 m .6095 .85053 L .6085 .85028 L .84 .573 .536 r
F
.60736 .85043 m .60568 .85276 L .60747 .85136 L .656 .815 .96 r
F
.60744 .85045 m .60747 .85136 L .60831 .85071 L F
.60736 .85043 m .60747 .85136 L .60744 .85045 L F
.59012 .77988 m .58018 .78349 L .58818 .78678 L .597 .767 .961 r
F
.59789 .77949 m .58581 .78178 L .58983 .78449 L .596 .768 .961 r
F
.59671 .77797 m .58581 .78178 L .59789 .77949 L F
.60073 .78126 m .59689 .77947 L .59624 .781 L .595 .768 .962 r
F
.6057 .77684 m .60581 .78144 L .60581 .78141 L .712 .567 0 r
F
.60597 .77788 m .6061 .77808 L .60572 .77755 L .988 .718 .377 r
F
.60609 .77806 m .6061 .77808 L .60597 .77788 L F
.60633 .77625 m .6057 .77696 L .60581 .78141 L .07 0 .435 r
F
.60633 .77625 m .60581 .78141 L .60639 .78075 L F
.60986 .78181 m .60403 .78076 L .60073 .78126 L .595 .768 .962 r
F
.60403 .78076 m .59689 .77947 L .60073 .78126 L F
.60695 .78298 m .60951 .85053 L .60689 .78296 L .84 .573 .536 r
F
.60951 .85053 m .6095 .85053 L .60689 .78296 L F
.60964 .85056 m .60912 .85062 L .60947 .85081 L .656 .815 .96 r
F
.60877 .85035 m .60871 .8504 L .60964 .85056 L F
.60871 .8504 m .60831 .85071 L .60912 .85062 L F
.60871 .8504 m .60912 .85062 L .60964 .85056 L F
.60624 .78253 m .60846 .85026 L .6062 .7825 L .925 .648 .496 r
F
.60947 .85081 m .60831 .85071 L .60944 .85084 L .656 .815 .96 r
F
.60912 .85062 m .60831 .85071 L .60947 .85081 L F
.60846 .85026 m .60846 .85026 L .6062 .7825 L .925 .648 .496 r
F
.60695 .78298 m .60793 .78334 L .60956 .85054 L .84 .573 .536 r
F
.60996 .8534 m .60865 .85353 L .60978 .85367 L .655 .815 .96 r
F
.60951 .85053 m .60956 .85054 L .60963 .85332 L .84 .573 .536 r
F
.60951 .85053 m .60963 .85332 L .60961 .85332 L F
.60963 .85332 m .60865 .85353 L .60996 .8534 L .655 .815 .96 r
F
.60908 .85319 m .60894 .8533 L .60963 .85332 L F
.60894 .8533 m .60865 .85353 L .60963 .85332 L F
.60956 .85054 m .61086 .85336 L .60963 .85332 L .749 .498 .552 r
F
.61106 .85336 m .60978 .85367 L .61103 .85365 L .655 .815 .96 r
F
.61071 .85058 m .60964 .85056 L .61068 .85081 L .656 .815 .96 r
F
.60965 .85054 m .60964 .85056 L .61071 .85058 L F
.61069 .85069 m .61068 .85083 L .61149 .8506 L F
.61128 .85059 m .61149 .8506 L .61185 .8505 L F
.61069 .85069 m .61149 .8506 L .61128 .85059 L F
.60804 .78336 m .61119 .85059 L .60793 .78334 L .749 .498 .552 r
F
.61119 .85059 m .61132 .85337 L .61118 .85059 L F
.61123 .85154 m .61132 .85337 L .61061 .85223 L F
.61123 .85154 m .61061 .85223 L .60956 .85054 L F
.61118 .85059 m .61123 .85154 L .60956 .85054 L F
.61132 .85337 m .61086 .85336 L .60956 .85054 L F
.60951 .85053 m .60961 .85332 L .6095 .85053 L .84 .573 .536 r
F
.60961 .85332 m .60965 .85424 L .60961 .85332 L F
.60961 .85332 m .60961 .85332 L .6095 .85053 L F
.60856 .85306 m .60965 .85424 L .60858 .85387 L F
.6085 .85028 m .60936 .85326 L .60856 .85306 L F
.60936 .85326 m .60965 .85424 L .60856 .85306 L F
.60846 .85026 m .60855 .85306 L .60846 .85026 L .925 .648 .496 r
F
.60897 .85328 m .60833 .85327 L .60865 .85353 L .655 .815 .96 r
F
.60833 .85327 m .60769 .85325 L .60851 .85349 L F
.60833 .85327 m .60851 .85349 L .60865 .85353 L F
.60747 .85136 m .60752 .85298 L .60794 .85303 L .656 .815 .96 r
F
.60839 .85065 m .60744 .85045 L .60831 .85071 L F
.60744 .85045 m .60736 .85043 L .60744 .85045 L F
.60744 .85045 m .60744 .85045 L .60831 .85071 L F
.60581 .78144 m .60582 .78199 L .60741 .84942 L .712 .567 0 r
F
.60818 .85038 m .60736 .85043 L .60839 .85065 L .656 .815 .96 r
F
.60794 .85014 m .60736 .85043 L .60818 .85038 L F
.60624 .78253 m .60689 .78296 L .6085 .85028 L .925 .648 .496 r
F
.60831 .85071 m .60747 .85136 L .60794 .85303 L .656 .815 .96 r
F
.60797 .85013 m .60665 .85003 L .60736 .85043 L F
.60585 .78202 m .60778 .84988 L .60582 .78199 L .988 .718 .377 r
F
.60778 .84988 m .60778 .84988 L .60582 .78199 L F
.60778 .84988 m .60665 .85003 L .60797 .85013 L .656 .815 .96 r
F
.60786 .85268 m .60786 .85268 L .60778 .84988 L .988 .718 .377 r
F
.60778 .84988 m .60778 .84988 L .60585 .78202 L F
.60786 .85268 m .60778 .84988 L .60778 .84988 L F
.60786 .85268 m .60786 .85268 L .60778 .84988 L F
.60778 .84988 m .60778 .84988 L .60582 .78199 L F
.60786 .85268 m .60778 .84988 L .60778 .84988 L F
.60624 .78253 m .6085 .85028 L .60846 .85026 L .925 .648 .496 r
F
.60585 .78202 m .60778 .84988 L .60585 .78202 L .988 .718 .377 r
F
.60778 .84988 m .60778 .84988 L .60585 .78202 L F
.60581 .78144 m .60741 .84942 L .60741 .8494 L .712 .567 0 r
F
.60582 .78199 m .60778 .84988 L .60741 .84942 L .988 .718 .377 r
F
.60695 .78298 m .60956 .85054 L .60951 .85053 L .84 .573 .536 r
F
.60581 .78144 m .60741 .8494 L .60581 .78141 L .712 .567 0 r
F
.60741 .8494 m .60741 .84939 L .60581 .78141 L F
.60581 .78141 m .60741 .84939 L .6074 .84883 L F
.6062 .7825 m .60846 .85026 L .6078 .8499 L .925 .648 .496 r
F
.60814 .85303 m .60749 .85269 L .60769 .85325 L .655 .815 .96 r
F
.60798 .85283 m .60749 .85269 L .60814 .85303 L F
.60734 .84933 m .60614 .84899 L .60624 .84954 L .656 .815 .96 r
F
.60585 .78202 m .6062 .7825 L .6078 .8499 L .988 .718 .377 r
F
.60585 .78202 m .6078 .8499 L .60778 .84988 L F
.60778 .84988 m .60786 .85268 L .60786 .85268 L F
.60585 .78202 m .60778 .84988 L .60778 .84988 L F
.60778 .84988 m .60786 .85268 L .60778 .84988 L F
.60702 .84893 m .60638 .84841 L .60614 .84899 L .656 .815 .96 r
F
.60403 .78076 m .59843 .7781 L .59689 .77947 L .595 .768 .962 r
F
.60633 .77625 m .60639 .78075 L .60643 .7807 L .07 0 .435 r
F
.60633 .77625 m .60639 .78075 L .60633 .77625 L F
.60986 .78181 m .60579 .78049 L .60403 .78076 L .595 .768 .962 r
F
.60579 .78049 m .59843 .7781 L .60403 .78076 L F
.60878 .77507 m .60879 .77556 L .6088 .77556 L .583 .366 .552 r
F
.60878 .77507 m .60868 .77558 L .60879 .77556 L F
.60869 .77112 m .60757 .77535 L .60878 .77507 L F
.60754 .7713 m .60757 .77535 L .60869 .77112 L F
.60754 .7713 m .60747 .77131 L .60757 .77535 L F
.60796 .7753 m .60726 .77116 L .60389 .77157 L .596 .768 .961 r
F
.60997 .775 m .60878 .77507 L .6088 .77556 L .665 .431 .556 r
F
.61003 .7772 m .60928 .77556 L .60825 .77556 L .596 .768 .961 r
F
.60643 .7807 m .60743 .84879 L .60803 .84802 L .07 0 .435 r
F
.60734 .8489 m .60661 .84842 L .60702 .84893 L .656 .815 .96 r
F
.61095 .84864 m .60767 .84848 L .60734 .8489 L F
.60639 .78075 m .60742 .84879 L .60643 .7807 L .07 0 .435 r
F
.61095 .84864 m .60734 .8489 L .60734 .84933 L .656 .815 .96 r
F
.60743 .84931 m .60734 .84933 L .60743 .84945 L F
.60743 .84931 m .60743 .84945 L .60764 .84971 L F
.61095 .84864 m .60743 .84931 L .60764 .84971 L F
.60764 .84971 m .60678 .84961 L .60665 .85003 L F
.60734 .84933 m .60694 .84941 L .60764 .84971 L F
.60694 .84941 m .60624 .84954 L .60678 .84961 L F
.60694 .84941 m .60678 .84961 L .60764 .84971 L F
.60639 .78075 m .60581 .78141 L .6074 .84883 L .07 0 .435 r
F
.60741 .84942 m .60744 .84959 L .60747 .85181 L .988 .718 .377 r
F
.60744 .84959 m .60786 .85268 L .60747 .85181 L F
.60747 .85181 m .60786 .85268 L .60748 .85221 L F
.60741 .8494 m .60741 .84942 L .60748 .85221 L .712 .567 0 r
F
.60741 .8494 m .60748 .85221 L .60748 .8522 L F
.60741 .8494 m .60748 .8522 L .60741 .84939 L F
.60747 .85136 m .60568 .85276 L .60752 .85298 L .656 .815 .96 r
F
.60748 .85219 m .60656 .85236 L .60749 .85269 L .655 .815 .96 r
F
.60748 .8522 m .60749 .85284 L .60748 .8522 L .712 .567 0 r
F
.60748 .8522 m .60748 .8522 L .60741 .84939 L F
.60749 .85269 m .60656 .85236 L .60698 .85286 L .655 .815 .96 r
F
.60778 .84988 m .6078 .8499 L .60786 .85268 L .988 .718 .377 r
F
.60778 .84988 m .60786 .85268 L .60778 .84988 L F
.60846 .85026 m .6085 .85028 L .60856 .85306 L .925 .648 .496 r
F
.60846 .85026 m .60856 .85306 L .60855 .85306 L F
.60778 .84988 m .60786 .85268 L .60778 .84988 L .988 .718 .377 r
F
.60778 .84988 m .60786 .85268 L .60741 .84942 L F
.60855 .85306 m .60855 .85306 L .60846 .85026 L .925 .648 .496 r
F
.61132 .85337 m .61132 .85337 L .61118 .85059 L .749 .498 .552 r
F
.60786 .85268 m .60858 .85387 L .60788 .85339 L .925 .648 .496 r
F
.6078 .8499 m .6084 .85298 L .60786 .85268 L F
.60833 .85294 m .60798 .85283 L .60814 .85303 L .655 .815 .96 r
F
.60824 .85298 m .60769 .85325 L .60882 .8532 L F
.60856 .85306 m .60882 .8532 L .60908 .85319 L F
.60824 .85298 m .60882 .8532 L .60856 .85306 L F
.608 .85016 m .60818 .85038 L .60864 .85036 L .656 .815 .96 r
F
.608 .85016 m .60864 .85036 L .6085 .85028 L F
.60794 .85014 m .60818 .85038 L .608 .85016 L F
.60877 .85035 m .60818 .85038 L .60839 .85065 L F
.60846 .85026 m .60855 .85306 L .6078 .8499 L .925 .648 .496 r
F
.60882 .8532 m .60769 .85325 L .60897 .85328 L .655 .815 .96 r
F
.60855 .85306 m .60858 .85387 L .6084 .85298 L .925 .648 .496 r
F
.60855 .85306 m .6084 .85298 L .6078 .8499 L F
.6084 .85298 m .60858 .85387 L .60786 .85268 L F
.6085 .85028 m .60864 .85036 L .60877 .85035 L .656 .815 .96 r
F
.6095 .85053 m .60965 .85424 L .6085 .85028 L .84 .573 .536 r
F
.61121 .85059 m .61128 .85059 L .61134 .85337 L .749 .498 .552 r
F
.61119 .85059 m .61134 .85337 L .61132 .85337 L F
.60804 .78336 m .61121 .85059 L .61119 .85059 L F
.61121 .85059 m .61134 .85337 L .61119 .85059 L F
.61119 .85059 m .61118 .85059 L .60793 .78334 L F
.60874 .78364 m .60935 .78387 L .60962 .78361 L .595 .768 .962 r
F
.60844 .78365 m .60935 .78387 L .60874 .78364 L F
.60962 .78361 m .60935 .78387 L .60958 .78395 L F
.60804 .78336 m .60962 .78361 L .61128 .85059 L .749 .498 .552 r
F
.60804 .78336 m .61128 .85059 L .61121 .85059 L F
.60962 .78361 m .61294 .85032 L .61128 .85059 L .648 .418 .556 r
F
.61095 .84864 m .61071 .85058 L .61185 .8505 L .656 .815 .96 r
F
.61071 .85058 m .61069 .85069 L .61128 .85059 L F
.61071 .85058 m .61128 .85059 L .61185 .8505 L F
.6113 .85146 m .60748 .85219 L .60749 .85248 L .655 .815 .96 r
F
.60773 .85261 m .60749 .85248 L .60749 .85269 L F
.6113 .85146 m .60749 .85248 L .60773 .85261 L F
.6074 .84883 m .60748 .85209 L .60746 .85161 L .712 .567 0 r
F
.60736 .85174 m .6067 .85123 L .60647 .85181 L .655 .815 .96 r
F
.60741 .84939 m .60749 .85284 L .6074 .84883 L .712 .567 0 r
F
.6113 .85146 m .60772 .85128 L .60736 .85174 L .655 .815 .96 r
F
.60742 .84879 m .60747 .8516 L .60743 .84879 L .07 0 .435 r
F
.6113 .85146 m .60747 .85173 L .60748 .85219 L .655 .815 .96 r
F
.60747 .8516 m .60748 .85219 L .60747 .8516 L .07 0 .435 r
F
.60747 .8516 m .60747 .8516 L .60743 .84879 L F
.6113 .85146 m .60808 .85083 L .60772 .85128 L .655 .815 .96 r
F
.60747 .85173 m .60647 .85181 L .60748 .85219 L F
.60748 .85209 m .60749 .85284 L .60746 .85161 L .712 .567 0 r
F
.61095 .84864 m .60764 .84971 L .60797 .85013 L .656 .815 .96 r
F
.61095 .84864 m .60794 .85014 L .60877 .85035 L F
.60639 .78075 m .6074 .84883 L .60742 .84879 L .07 0 .435 r
F
.60742 .84879 m .60743 .84879 L .60643 .7807 L F
.61095 .84864 m .60797 .84805 L .60722 .84845 L .656 .815 .96 r
F
.60937 .84988 m .60877 .85035 L .60939 .8505 L F
.60937 .84988 m .60939 .8505 L .60964 .85056 L F
.61095 .84864 m .60937 .84988 L .60964 .85056 L F
.60442 .78004 m .60076 .77698 L .59843 .7781 L .595 .768 .962 r
F
.60758 .77575 m .60643 .7807 L .60761 .78023 L .438 .255 .533 r
F
.60748 .77579 m .60643 .7807 L .60758 .77575 L F
.60748 .77579 m .60633 .77625 L .60643 .7807 L F
.60986 .78181 m .6065 .78003 L .60442 .78004 L .595 .768 .962 r
F
.6065 .78003 m .60076 .77698 L .60442 .78004 L F
.60997 .775 m .6088 .77556 L .60998 .77555 L .665 .431 .556 r
F
.61114 .7751 m .60997 .775 L .60999 .77555 L .733 .485 .553 r
F
.61114 .7751 m .60999 .77555 L .61115 .77569 L F
.60928 .77556 m .61082 .77116 L .60726 .77116 L .596 .768 .961 r
F
.61003 .7772 m .61025 .77555 L .60928 .77556 L F
.60997 .775 m .60998 .77555 L .60999 .77555 L .665 .431 .556 r
F
.61025 .77555 m .61082 .77116 L .60928 .77556 L .596 .768 .961 r
F
.60758 .77575 m .60761 .78023 L .60769 .7802 L .438 .255 .533 r
F
.60758 .77575 m .60761 .78023 L .60758 .77575 L F
.60572 .77694 m .60456 .77621 L .60146 .77669 L .596 .768 .961 r
F
.60456 .77621 m .59708 .77486 L .60146 .77669 L F
.60879 .77556 m .60769 .7802 L .60882 .78002 L .583 .366 .552 r
F
.60868 .77558 m .60769 .7802 L .60879 .77556 L F
.60832 .77563 m .60758 .77575 L .60742 .77581 L .596 .768 .961 r
F
.60868 .77558 m .60758 .77575 L .60769 .7802 L .583 .366 .552 r
F
.60526 .77691 m .59643 .77639 L .60565 .77745 L .596 .768 .961 r
F
.60986 .78181 m .60371 .77619 L .60076 .77698 L .595 .768 .962 r
F
.60769 .7802 m .60809 .84799 L .60931 .84734 L .438 .255 .533 r
F
.60797 .84805 m .60779 .84736 L .60692 .84785 L .656 .815 .96 r
F
.61095 .84864 m .60863 .8477 L .60797 .84805 L F
.60761 .78023 m .60809 .84799 L .60769 .7802 L .438 .255 .533 r
F
.6081 .8508 m .60748 .85219 L .60811 .85137 L .07 0 .435 r
F
.60803 .84802 m .60757 .85147 L .6081 .8508 L F
.60757 .85147 m .60748 .85219 L .6081 .8508 L F
.60742 .84879 m .60746 .85161 L .60747 .8516 L F
.60743 .84879 m .60748 .85219 L .60803 .84802 L F
.60806 .85082 m .60808 .85015 L .60725 .85066 L .655 .815 .96 r
F
.6113 .85146 m .60878 .85044 L .60806 .85082 L F
.61095 .84864 m .60931 .84734 L .60863 .8477 L .656 .815 .96 r
F
.60938 .85012 m .60811 .85137 L .60939 .85075 L .438 .255 .533 r
F
.60931 .84734 m .60832 .85069 L .60938 .85012 L F
.60832 .85069 m .60811 .85137 L .60938 .85012 L F
.60809 .84799 m .60811 .85137 L .60931 .84734 L F
.60761 .78023 m .60643 .7807 L .60811 .85137 L F
.60878 .85044 m .60912 .84973 L .60808 .85015 L .655 .815 .96 r
F
.61095 .84864 m .60965 .85054 L .61071 .85058 L .656 .815 .96 r
F
.6113 .85146 m .60955 .85007 L .60878 .85044 L .655 .815 .96 r
F
.60949 .85009 m .60939 .85075 L .60951 .85072 L .583 .366 .552 r
F
.60936 .84679 m .60936 .84732 L .60938 .84732 L F
.60986 .78181 m .60844 .78365 L .60962 .78361 L .595 .768 .962 r
F
.60998 .77555 m .6088 .77556 L .60891 .78001 L .665 .431 .556 r
F
.60998 .77555 m .60891 .78001 L .61002 .78 L F
.60879 .77556 m .60882 .78002 L .6088 .77556 L .583 .366 .552 r
F
.60882 .78002 m .60883 .78002 L .6088 .77556 L F
.6088 .77556 m .60883 .78002 L .60891 .78001 L F
.60611 .77649 m .60456 .77621 L .60572 .77694 L .596 .768 .961 r
F
.60986 .78181 m .60708 .77578 L .60371 .77619 L .595 .768 .962 r
F
.60882 .78002 m .60936 .84732 L .60883 .78002 L .583 .366 .552 r
F
.60936 .84732 m .60936 .84732 L .60883 .78002 L F
.61095 .84864 m .6102 .84709 L .60931 .84734 L .656 .815 .96 r
F
.60891 .78001 m .60936 .84679 L .60953 .84728 L .583 .366 .552 r
F
.61055 .84699 m .61041 .84983 L .61061 .84977 L F
.6113 .85146 m .61153 .84965 L .6105 .84981 L .655 .815 .96 r
F
.61095 .84864 m .61119 .84866 L .6112 .84863 L .656 .815 .96 r
F
.60973 .7836 m .61294 .85031 L .60962 .78361 L .648 .418 .556 r
F
.6133 .85305 m .61228 .85349 L .61348 .85319 L .655 .815 .96 r
F
.61294 .85031 m .61308 .85308 L .61294 .85032 L .648 .418 .556 r
F
.61308 .85308 m .61308 .85308 L .61294 .85032 L F
.61128 .85059 m .61257 .85317 L .61134 .85337 L F
.61216 .85324 m .61228 .85349 L .6133 .85305 L .655 .815 .96 r
F
.61303 .8503 m .61193 .85066 L .61311 .85036 L .656 .815 .96 r
F
.61185 .8505 m .61193 .85066 L .61303 .8503 L F
.61294 .85032 m .61314 .85429 L .61128 .85059 L .648 .418 .556 r
F
.60973 .7836 m .60974 .7836 L .61294 .85031 L F
.61294 .85031 m .61294 .85031 L .61314 .85429 L F
.60973 .7836 m .61294 .85031 L .61294 .85031 L F
.61294 .85031 m .61294 .85032 L .60962 .78361 L F
.61303 .8503 m .61311 .85036 L .61344 .85023 L .656 .815 .96 r
F
.61073 .78369 m .61069 .78378 L .61077 .78379 L .595 .768 .962 r
F
.60974 .7836 m .61135 .78354 L .61314 .85429 L .648 .418 .556 r
F
.61142 .78353 m .61412 .84991 L .61135 .78354 L .539 .333 .549 r
F
.61412 .84991 m .61429 .85394 L .61412 .84991 L F
.61412 .84991 m .61412 .84991 L .61135 .78354 L F
.61095 .84864 m .61303 .8503 L .61304 .8503 L .656 .815 .96 r
F
.61409 .84992 m .61304 .8503 L .61415 .84995 L F
.61095 .84864 m .61304 .8503 L .61409 .84992 L F
.61303 .8503 m .61344 .85023 L .61415 .84995 L F
.6113 .85146 m .61216 .85324 L .6133 .85305 L .655 .815 .96 r
F
.61308 .85308 m .61314 .85429 L .61308 .85308 L .648 .418 .556 r
F
.61095 .84864 m .61185 .8505 L .61303 .8503 L .656 .815 .96 r
F
.61119 .84866 m .61552 .84888 L .6112 .84863 L F
.6112 .84863 m .61552 .84888 L .61576 .8483 L F
.61095 .84864 m .61415 .84995 L .61497 .84944 L F
.61095 .84864 m .61497 .84944 L .61552 .84888 L F
.61396 .78188 m .61527 .84756 L .61568 .84825 L .978 .72 .315 r
F
.61095 .84864 m .61576 .8483 L .61567 .84775 L .656 .815 .96 r
F
.60986 .78181 m .60962 .78361 L .61067 .78357 L .595 .768 .962 r
F
.60986 .78181 m .61073 .78369 L .61168 .78347 L F
.60986 .78181 m .61181 .78359 L .61257 .78324 L F
.60986 .78181 m .61279 .78336 L .61328 .78292 L F
.61003 .7772 m .61201 .77901 L .61277 .77865 L .596 .768 .961 r
F
.61026 .77544 m .61433 .77158 L .61082 .77116 L F
.61003 .7772 m .61118 .7757 L .61116 .7757 L F
.60986 .78181 m .61115 .78013 L .6101 .78 L .595 .768 .962 r
F
.61229 .77541 m .61114 .7751 L .61116 .7757 L .805 .544 .543 r
F
.61229 .77541 m .61116 .7757 L .6123 .77602 L F
.61229 .77541 m .6123 .77602 L .61231 .77602 L F
.61003 .7772 m .61755 .77238 L .61433 .77158 L .596 .768 .961 r
F
.6134 .77609 m .61231 .77602 L .6134 .77666 L .906 .63 .507 r
F
.61003 .7772 m .62024 .77351 L .61755 .77238 L .596 .768 .961 r
F
.61115 .77569 m .61119 .78014 L .61116 .7757 L .733 .485 .553 r
F
.61119 .78014 m .6112 .78014 L .61116 .7757 L F
.61116 .7757 m .6112 .78014 L .61127 .78015 L F
.6123 .77602 m .61116 .7757 L .61127 .78015 L .805 .544 .543 r
F
.6123 .77602 m .61127 .78015 L .61234 .78045 L F
.61115 .77569 m .6101 .78 L .61119 .78014 L .733 .485 .553 r
F
.61231 .77602 m .61235 .78045 L .61242 .78047 L .805 .544 .543 r
F
.6123 .77602 m .61234 .78045 L .61231 .77602 L F
.61234 .78045 m .61235 .78045 L .61231 .77602 L F
.6134 .77666 m .61242 .78047 L .61345 .78107 L .906 .63 .507 r
F
.6134 .77666 m .61231 .77602 L .61242 .78047 L F
.61341 .77666 m .61345 .78107 L .61353 .78111 L F
.6134 .77666 m .61345 .78107 L .61341 .77666 L F
.61384 .77743 m .61341 .77666 L .61353 .78111 L .978 .72 .315 r
F
.61218 .78033 m .62008 .77813 L .61738 .77701 L .595 .768 .962 r
F
.6121 .78038 m .61221 .78035 L .61218 .78033 L F
.61221 .78035 m .62008 .77813 L .61218 .78033 L F
.60986 .78181 m .61307 .78065 L .6121 .78038 L F
.61307 .78065 m .62008 .77813 L .6121 .78038 L F
.62139 .7809 m .63584 .78187 L .62295 .77954 L .596 .768 .961 r
F
.60986 .78181 m .62324 .78104 L .62208 .77951 L .595 .768 .962 r
F
.61234 .78045 m .61301 .84683 L .61235 .78045 L .805 .544 .543 r
F
.61301 .84683 m .61301 .84683 L .61235 .78045 L F
.61095 .84864 m .61323 .84687 L .61295 .84682 L .656 .815 .96 r
F
.60986 .78181 m .6121 .78038 L .61116 .78012 L .595 .768 .962 r
F
.61127 .78015 m .61182 .84682 L .61295 .84682 L .733 .485 .553 r
F
.6122 .84682 m .61295 .84682 L .61228 .84672 L .656 .815 .96 r
F
.61095 .84864 m .61295 .84682 L .6122 .84682 L F
.61095 .84864 m .61419 .84704 L .61323 .84687 L F
.61419 .84704 m .61412 .847 L .61323 .84687 L F
.61345 .78107 m .61417 .84703 L .61353 .78111 L .906 .63 .507 r
F
.61393 .78183 m .61353 .78111 L .61524 .84752 L .978 .72 .315 r
F
.61393 .78183 m .61524 .84752 L .61526 .84756 L F
.61353 .78111 m .61418 .84703 L .61524 .84752 L .906 .63 .507 r
F
.61393 .78183 m .61526 .84756 L .61393 .78183 L .978 .72 .315 r
F
.61526 .84756 m .61526 .84756 L .61393 .78183 L F
.61095 .84864 m .61526 .84725 L .61508 .84716 L .656 .815 .96 r
F
.61422 .84702 m .61508 .84716 L .61455 .84686 L F
.61095 .84864 m .61508 .84716 L .61422 .84702 L F
.61235 .78045 m .61301 .84683 L .61242 .78047 L .805 .544 .543 r
F
.61526 .84756 m .61527 .84756 L .61396 .78188 L .978 .72 .315 r
F
.61095 .84864 m .61567 .84775 L .61526 .84725 L .656 .815 .96 r
F
.6113 .85146 m .61357 .84969 L .61302 .84961 L .655 .815 .96 r
F
.61295 .84682 m .61209 .84961 L .61302 .84961 L .733 .485 .553 r
F
.61258 .84961 m .61302 .84961 L .61262 .84954 L .655 .815 .96 r
F
.6113 .85146 m .61302 .84961 L .61258 .84961 L F
.61526 .84756 m .61532 .85031 L .61527 .84756 L .978 .72 .315 r
F
.61548 .84889 m .61557 .85165 L .61548 .84889 L .163 .05 .467 r
F
.61557 .85165 m .61561 .85295 L .61557 .85165 L F
.61557 .85165 m .61557 .85165 L .61548 .84889 L F
.61507 .85218 m .61535 .85226 L .61589 .85169 L .655 .815 .96 r
F
.61504 .8522 m .61505 .8522 L .61507 .85218 L F
.61505 .8522 m .61535 .85226 L .61507 .85218 L F
.6113 .85146 m .61563 .85145 L .61572 .85115 L F
.61567 .84828 m .61568 .84825 L .61575 .85103 L 0 0 .235 r
F
.61567 .84828 m .61575 .85103 L .61575 .85104 L F
.61567 .84828 m .61575 .85104 L .61567 .84829 L F
.61575 .85104 m .61575 .85104 L .61567 .84829 L F
.61567 .84829 m .61575 .85104 L .61551 .84886 L F
.61568 .84825 m .61544 .85052 L .61575 .85103 L .978 .72 .315 r
F
.61526 .84756 m .61532 .85031 L .61526 .84756 L F
.6113 .85146 m .61582 .85114 L .61557 .85073 L .655 .815 .96 r
F
.61553 .85066 m .61606 .85064 L .61593 .85058 L F
.6113 .85146 m .61557 .85073 L .61553 .85066 L F
.61557 .85073 m .61606 .85064 L .61553 .85066 L F
.61527 .84756 m .61532 .85031 L .61568 .84825 L .978 .72 .315 r
F
.61532 .85031 m .61544 .85052 L .61568 .84825 L F
.61532 .85031 m .61532 .85031 L .61526 .84756 L F
.61524 .84752 m .61449 .84993 L .61531 .8503 L .906 .63 .507 r
F
.61532 .85031 m .61532 .85031 L .61527 .84756 L .978 .72 .315 r
F
.61514 .85022 m .61605 .85056 L .61563 .85006 L .655 .815 .96 r
F
.6113 .85146 m .61593 .85058 L .61514 .85022 L F
.61593 .85058 m .61605 .85056 L .61514 .85022 L F
.61417 .84703 m .61412 .847 L .61419 .84979 L .906 .63 .507 r
F
.6113 .85146 m .61514 .85022 L .61444 .8499 L .655 .815 .96 r
F
.6142 .8498 m .61419 .84979 L .61421 .85081 L .906 .63 .507 r
F
.61417 .84703 m .61419 .84979 L .6142 .8498 L F
.61532 .85031 m .61534 .85147 L .61544 .85052 L .978 .72 .315 r
F
.61532 .85031 m .61534 .85147 L .61532 .85031 L F
.61557 .85073 m .61614 .85112 L .61606 .85064 L .655 .815 .96 r
F
.61582 .85114 m .61614 .85112 L .61557 .85073 L F
.61593 .85058 m .61606 .85064 L .61605 .85056 L F
.61531 .8503 m .61421 .85081 L .61534 .85147 L .906 .63 .507 r
F
.61449 .84993 m .61421 .85081 L .61531 .8503 L F
.61532 .85031 m .61534 .85147 L .61532 .85031 L .978 .72 .315 r
F
.61444 .8499 m .61513 .85 L .61492 .84966 L .655 .815 .96 r
F
.61513 .85 m .61563 .85006 L .61493 .84967 L F
.61513 .85 m .61493 .84967 L .61492 .84966 L F
.61514 .85022 m .61563 .85006 L .61444 .8499 L F
.61417 .84703 m .6142 .8498 L .61418 .84703 L .906 .63 .507 r
F
.6142 .8498 m .61421 .85081 L .6142 .8498 L F
.6142 .8498 m .6142 .8498 L .61418 .84703 L F
.61419 .84979 m .61304 .85051 L .61421 .85081 L .805 .544 .543 r
F
.61412 .847 m .61331 .84965 L .61419 .84979 L F
.6113 .85146 m .61444 .8499 L .61357 .84969 L .655 .815 .96 r
F
.6142 .8498 m .61449 .84993 L .61524 .84752 L .906 .63 .507 r
F
.61444 .8499 m .61456 .84985 L .61419 .84979 L .655 .815 .96 r
F
.61444 .8499 m .61419 .84979 L .61357 .84969 L F
.61418 .84703 m .6142 .8498 L .61524 .84752 L .906 .63 .507 r
F
.6142 .8498 m .61421 .85081 L .61449 .84993 L F
.61331 .84965 m .61304 .85051 L .61419 .84979 L .805 .544 .543 r
F
.61357 .84969 m .61492 .84966 L .61397 .84939 L .655 .815 .96 r
F
.61456 .84985 m .61492 .84966 L .61357 .84969 L F
.61302 .84961 m .61185 .85041 L .61304 .85051 L .733 .485 .553 r
F
.61184 .84961 m .61209 .84961 L .61295 .84682 L F
.6113 .85146 m .61258 .84961 L .61154 .84961 L .655 .815 .96 r
F
.61095 .84864 m .6122 .84682 L .61118 .84683 L .656 .815 .96 r
F
.61181 .84682 m .61185 .85041 L .61181 .84682 L .733 .485 .553 r
F
.6112 .78014 m .61185 .85041 L .61127 .78015 L F
.61115 .78013 m .6101 .78 L .6101 .78 L .595 .768 .962 r
F
.61119 .78014 m .6101 .78 L .61185 .85041 L .733 .485 .553 r
F
.61154 .84961 m .61283 .84925 L .61158 .84926 L .655 .815 .96 r
F
.61258 .84961 m .61283 .84925 L .61154 .84961 L F
.61182 .84682 m .61184 .84961 L .61295 .84682 L .733 .485 .553 r
F
.61184 .84961 m .61185 .85041 L .61209 .84961 L F
.61209 .84961 m .61185 .85041 L .61302 .84961 L F
.61301 .84683 m .61304 .85051 L .61412 .847 L .805 .544 .543 r
F
.61301 .84683 m .61304 .85051 L .61301 .84683 L F
.61234 .78045 m .61127 .78015 L .61304 .85051 L F
.61262 .84954 m .61397 .84939 L .61283 .84925 L .655 .815 .96 r
F
.61357 .84969 m .61397 .84939 L .61262 .84954 L F
.61301 .84683 m .61303 .84961 L .61301 .84683 L .805 .544 .543 r
F
.61303 .84961 m .61304 .85051 L .61303 .84961 L F
.61303 .84961 m .61303 .84961 L .61301 .84683 L F
.61301 .84683 m .61301 .84683 L .61242 .78047 L F
.61417 .84703 m .61418 .84703 L .61353 .78111 L .906 .63 .507 r
F
.61345 .78107 m .61242 .78047 L .61412 .847 L F
.61345 .78107 m .61412 .847 L .61417 .84703 L F
.61242 .78047 m .61301 .84683 L .61412 .847 L .805 .544 .543 r
F
.61345 .8467 m .61455 .84686 L .6136 .84658 L .656 .815 .96 r
F
.61323 .84687 m .6138 .84686 L .61345 .8467 L F
.6138 .84686 m .61455 .84686 L .61345 .8467 L F
.61419 .84704 m .61422 .84702 L .61412 .847 L F
.61422 .84702 m .61455 .84686 L .61323 .84687 L F
.61228 .84672 m .6136 .84658 L .61247 .84644 L F
.61323 .84687 m .6136 .84658 L .61228 .84672 L F
.61328 .77659 m .62224 .77489 L .61269 .77624 L .596 .768 .961 r
F
.61125 .77999 m .61417 .7762 L .61025 .77986 L .595 .768 .962 r
F
.61074 .78 m .61025 .77986 L .6101 .78 L F
.61125 .77999 m .61025 .77986 L .61074 .78 L F
.61384 .77743 m .61384 .77743 L .61384 .77743 L .596 .768 .961 r
F
.61116 .78012 m .61738 .77701 L .61417 .7762 L .595 .768 .962 r
F
.6121 .78038 m .61738 .77701 L .61116 .78012 L F
.61119 .78014 m .61181 .84682 L .6112 .78014 L .733 .485 .553 r
F
.61181 .84682 m .61181 .84682 L .6112 .78014 L F
.6101 .78 m .6106 .84698 L .61176 .84682 L .665 .431 .556 r
F
.61118 .84683 m .61247 .84644 L .61123 .84646 L .656 .815 .96 r
F
.6122 .84682 m .61247 .84644 L .61118 .84683 L F
.61115 .78013 m .61125 .77999 L .6101 .78 L .595 .768 .962 r
F
.61114 .7751 m .61115 .77569 L .61116 .7757 L .733 .485 .553 r
F
.61024 .77558 m .61116 .7757 L .61026 .77544 L .596 .768 .961 r
F
.61003 .7772 m .61116 .7757 L .61024 .77558 L F
.61118 .7757 m .61433 .77158 L .61026 .77544 L F
.61115 .77569 m .60999 .77555 L .6101 .78 L .733 .485 .553 r
F
.61269 .77624 m .62224 .77489 L .62024 .77351 L .596 .768 .961 r
F
.6101 .78 m .61417 .7762 L .61065 .77579 L .595 .768 .962 r
F
.60998 .77555 m .61002 .78 L .60999 .77555 L .665 .431 .556 r
F
.60986 .78181 m .6101 .78 L .60903 .78001 L .595 .768 .962 r
F
.61153 .84965 m .61061 .84977 L .6105 .84981 L .655 .815 .96 r
F
.61002 .78 m .6106 .84698 L .61003 .78 L .665 .431 .556 r
F
.61095 .84864 m .61117 .8469 L .6102 .84709 L .656 .815 .96 r
F
.61117 .8469 m .61055 .84699 L .6102 .84709 L F
.61002 .78 m .60891 .78001 L .61055 .84699 L .665 .431 .556 r
F
.6106 .84698 m .61055 .84699 L .61063 .85048 L F
.61002 .78 m .61055 .84699 L .6106 .84698 L F
.6106 .84698 m .6106 .84698 L .61003 .78 L F
.6106 .84698 m .6106 .84698 L .61003 .78 L F
.61003 .78 m .6106 .84698 L .6101 .78 L F
.60891 .78001 m .60953 .84728 L .61055 .84699 L .583 .366 .552 r
F
.61118 .84681 m .61123 .84646 L .61031 .84702 L .656 .815 .96 r
F
.61055 .84699 m .61031 .84702 L .6102 .84709 L F
.61118 .84681 m .61031 .84702 L .61055 .84699 L F
.61117 .8469 m .61118 .84681 L .61055 .84699 L F
.61062 .84977 m .61062 .84977 L .6106 .84698 L .665 .431 .556 r
F
.61062 .84977 m .6106 .84698 L .6106 .84698 L F
.6106 .84698 m .61062 .84977 L .6106 .84698 L F
.61018 .84704 m .61123 .84646 L .60997 .84662 L .656 .815 .96 r
F
.6102 .84709 m .61031 .84702 L .61018 .84704 L F
.61031 .84702 m .61123 .84646 L .61018 .84704 L F
.61176 .84682 m .61086 .84974 L .61183 .84961 L .665 .431 .556 r
F
.61155 .84951 m .61158 .84926 L .61055 .84978 L .655 .815 .96 r
F
.61061 .84977 m .61055 .84978 L .6105 .84981 L F
.61155 .84951 m .61055 .84978 L .61061 .84977 L F
.61062 .84977 m .61063 .85048 L .61062 .84977 L .665 .431 .556 r
F
.61002 .78 m .61003 .78 L .60999 .77555 L F
.60999 .77555 m .61003 .78 L .6101 .78 L F
.60757 .77535 m .60748 .77579 L .60758 .77575 L .438 .255 .533 r
F
.60818 .7755 m .60389 .77157 L .60742 .77581 L .596 .768 .961 r
F
.60903 .78001 m .61065 .77579 L .60708 .77578 L .595 .768 .962 r
F
.6101 .78 m .61065 .77579 L .60903 .78001 L F
.61153 .84965 m .61155 .84951 L .61061 .84977 L .655 .815 .96 r
F
.6106 .84698 m .61062 .84977 L .61176 .84682 L .665 .431 .556 r
F
.61062 .84977 m .61063 .85048 L .61086 .84974 L F
.61062 .84977 m .61086 .84974 L .61176 .84682 L F
.61183 .84961 m .61063 .85048 L .61185 .85041 L F
.61086 .84974 m .61063 .85048 L .61183 .84961 L F
.61049 .84979 m .61158 .84926 L .61032 .84943 L .655 .815 .96 r
F
.6105 .84981 m .61055 .84978 L .61049 .84979 L F
.61055 .84978 m .61158 .84926 L .61049 .84979 L F
.61055 .84699 m .60953 .84728 L .61041 .84983 L .583 .366 .552 r
F
.60938 .84732 m .60939 .85012 L .60949 .85009 L F
.60936 .84732 m .60939 .85012 L .60938 .84732 L F
.60936 .84732 m .60939 .85012 L .60936 .84732 L F
.60939 .85012 m .60939 .85012 L .60936 .84732 L F
.6113 .85146 m .6105 .84981 L .60955 .85007 L .655 .815 .96 r
F
.60936 .84679 m .60951 .85072 L .61063 .85048 L .583 .366 .552 r
F
.60955 .85007 m .60938 .85012 L .60878 .85044 L .655 .815 .96 r
F
.60882 .78002 m .60769 .7802 L .60938 .85012 L .583 .366 .552 r
F
.60939 .85012 m .60938 .85012 L .60939 .85075 L F
.60882 .78002 m .60938 .85012 L .60939 .85012 L F
.60952 .85005 m .60912 .84973 L .60886 .85027 L .655 .815 .96 r
F
.60938 .85012 m .60886 .85027 L .60878 .85044 L F
.60952 .85005 m .60886 .85027 L .60938 .85012 L F
.60955 .85007 m .61032 .84943 L .60912 .84973 L F
.6105 .84981 m .61032 .84943 L .60955 .85007 L F
.60939 .85012 m .60939 .85075 L .60939 .85012 L .583 .366 .552 r
F
.61061 .84977 m .61041 .84983 L .61063 .85048 L F
.60883 .78002 m .60936 .84679 L .60891 .78001 L F
.60931 .84734 m .60997 .84662 L .60878 .84692 L .656 .815 .96 r
F
.6102 .84709 m .60997 .84662 L .60931 .84734 L F
.60939 .85012 m .60939 .85075 L .60949 .85009 L .583 .366 .552 r
F
.60955 .85007 m .60952 .85005 L .60938 .85012 L .655 .815 .96 r
F
.60878 .85044 m .60808 .85015 L .60806 .85082 L F
.60809 .84799 m .60811 .8508 L .60809 .84799 L .438 .255 .533 r
F
.60811 .8508 m .60811 .85137 L .60811 .8508 L F
.60811 .8508 m .60811 .8508 L .60809 .84799 L F
.60809 .84799 m .60809 .84799 L .60769 .7802 L F
.60863 .8477 m .60878 .84692 L .60774 .84734 L .656 .815 .96 r
F
.60931 .84734 m .60878 .84692 L .60863 .8477 L F
.60863 .8477 m .60779 .84736 L .60797 .84805 L F
.60779 .84736 m .60774 .84734 L .60769 .84737 L F
.60779 .84736 m .60769 .84737 L .60692 .84785 L F
.60722 .84845 m .60727 .84792 L .60638 .84841 L F
.60797 .84805 m .60727 .84792 L .60722 .84845 L F
.60727 .84792 m .60692 .84785 L .6067 .84808 L F
.60727 .84792 m .6067 .84808 L .60638 .84841 L F
.60772 .85128 m .60725 .85066 L .6067 .85123 L .655 .815 .96 r
F
.60808 .85083 m .60725 .85066 L .60772 .85128 L F
.60772 .85128 m .6067 .85123 L .60736 .85174 L F
.60742 .84879 m .6074 .84883 L .60746 .85161 L .07 0 .435 r
F
.60747 .8516 m .60746 .85161 L .60748 .85219 L F
.60746 .85161 m .60749 .85284 L .60748 .85219 L .712 .567 0 r
F
.60748 .85219 m .60647 .85181 L .60656 .85236 L .655 .815 .96 r
F
.60734 .8489 m .60702 .84893 L .60717 .84912 L .656 .815 .96 r
F
.60734 .8489 m .60717 .84912 L .60734 .84933 L F
.60767 .84848 m .60661 .84842 L .60734 .8489 L F
.60825 .77556 m .60923 .77546 L .60796 .7753 L .596 .768 .961 r
F
.60928 .77556 m .60923 .77546 L .60825 .77556 L F
.60923 .77546 m .60726 .77116 L .60796 .7753 L F
.60661 .84842 m .60638 .84841 L .60702 .84893 L .656 .815 .96 r
F
.60702 .84893 m .60614 .84899 L .60734 .84933 L F
.60786 .85268 m .60786 .85268 L .60788 .85339 L .988 .718 .377 r
F
.6113 .85146 m .60779 .85259 L .60833 .85294 L .655 .815 .96 r
F
.60779 .85259 m .60773 .85261 L .60786 .85268 L F
.60779 .85259 m .60786 .85268 L .60833 .85294 L F
.60678 .84961 m .60624 .84954 L .60654 .84991 L .656 .815 .96 r
F
.60678 .84961 m .60654 .84991 L .60665 .85003 L F
.60786 .85268 m .60788 .85339 L .60786 .85268 L .988 .718 .377 r
F
.60773 .85261 m .60749 .85269 L .60833 .85294 L .655 .815 .96 r
F
.60855 .85306 m .60856 .85306 L .60858 .85387 L .925 .648 .496 r
F
.60749 .85269 m .60698 .85286 L .60751 .85315 L .655 .815 .96 r
F
.60749 .85269 m .60751 .85315 L .60769 .85325 L F
.60748 .8522 m .60748 .85221 L .60749 .85284 L .712 .567 0 r
F
.60748 .85221 m .60788 .85339 L .60749 .85284 L .988 .718 .377 r
F
.60786 .85268 m .60788 .85339 L .60748 .85221 L F
.60855 .85306 m .60858 .85387 L .60855 .85306 L .925 .648 .496 r
F
.60908 .85319 m .60882 .8532 L .60897 .85328 L .655 .815 .96 r
F
.6113 .85146 m .60824 .85298 L .60908 .85319 L F
.6113 .85146 m .60908 .85319 L .60963 .85332 L F
.61001 .85333 m .60963 .85332 L .60996 .8534 L F
.6113 .85146 m .60963 .85332 L .61001 .85333 L F
.61132 .85337 m .61137 .85445 L .61132 .85337 L .749 .498 .552 r
F
.6113 .85146 m .61001 .85333 L .61106 .85336 L .655 .815 .96 r
F
.61001 .85333 m .60978 .85367 L .61106 .85336 L F
.61132 .85337 m .61137 .85445 L .61086 .85336 L .749 .498 .552 r
F
.60963 .85332 m .61137 .85445 L .60965 .85424 L F
.61086 .85336 m .61137 .85445 L .60963 .85332 L F
.60961 .85332 m .60963 .85332 L .60965 .85424 L .84 .573 .536 r
F
.60832 .77563 m .60818 .7755 L .60758 .77575 L .596 .768 .961 r
F
.60786 .85268 m .60788 .85339 L .60786 .85268 L .988 .718 .377 r
F
.60339 .78413 m .59819 .784 L .59971 .78546 L .595 .768 .962 r
F
.60457 .7828 m .59819 .784 L .60339 .78413 L F
.59819 .784 m .5977 .78409 L .5978 .78416 L F
.59819 .784 m .5978 .78416 L .59971 .78546 L F
.60339 .78413 m .59971 .78546 L .60293 .78465 L F
.61132 .85337 m .61134 .85337 L .61137 .85445 L .749 .498 .552 r
F
.61224 .8534 m .61103 .85365 L .61228 .85349 L .655 .815 .96 r
F
.61216 .85324 m .61175 .85338 L .61224 .8534 L F
.61175 .85338 m .61103 .85365 L .61224 .8534 L F
.6113 .85146 m .61105 .85342 L .61216 .85324 L F
.61105 .85342 m .61103 .85365 L .61216 .85324 L F
.61134 .85337 m .61314 .85429 L .61137 .85445 L .648 .418 .556 r
F
.61257 .85317 m .61314 .85429 L .61134 .85337 L F
.61555 .85168 m .6159 .8517 L .61576 .85145 L .655 .815 .96 r
F
.61575 .85104 m .61575 .85103 L .61578 .8523 L 0 0 .235 r
F
.61572 .85115 m .61576 .85145 L .61582 .85114 L .655 .815 .96 r
F
.61563 .85145 m .61576 .85145 L .61572 .85115 L F
.61576 .85145 m .616 .85145 L .61591 .8513 L F
.61576 .85145 m .61591 .8513 L .61582 .85114 L F
.6113 .85146 m .61555 .85168 L .61576 .85145 L F
.61582 .85114 m .616 .85145 L .61614 .85112 L F
.61526 .84756 m .61524 .84752 L .61531 .8503 L .978 .72 .315 r
F
.61532 .85031 m .61531 .8503 L .61534 .85147 L F
.61526 .84756 m .61531 .8503 L .61532 .85031 L F
.61575 .85104 m .61578 .8523 L .61575 .85104 L 0 0 .235 r
F
.61575 .85104 m .61578 .8523 L .6157 .85122 L F
.6157 .85122 m .61578 .8523 L .61558 .85164 L F
.61575 .85103 m .61534 .85147 L .61578 .8523 L .978 .72 .315 r
F
.61544 .85052 m .61534 .85147 L .61575 .85103 L F
.61641 .85213 m .62049 .85193 L .61616 .85171 L .655 .815 .96 r
F
.61641 .85213 m .61616 .85171 L .6159 .8517 L F
.61535 .85226 m .61541 .85225 L .61543 .85218 L F
.61557 .85165 m .61558 .85164 L .61561 .85295 L .163 .05 .467 r
F
.6113 .85146 m .61504 .8522 L .61507 .85218 L .655 .815 .96 r
F
.6113 .85146 m .61507 .85218 L .61555 .85168 L F
.6113 .85146 m .61426 .85266 L .61504 .8522 L F
.6113 .85146 m .61327 .85302 L .61427 .85266 L F
.61424 .85267 m .61426 .85267 L .61429 .85394 L .539 .333 .549 r
F
.61558 .85164 m .61578 .8523 L .61561 .85295 L 0 0 .235 r
F
.61525 .85281 m .6154 .85227 L .61535 .85226 L .655 .815 .96 r
F
.61507 .85218 m .61561 .85295 L .6151 .85349 L .163 .05 .467 r
F
.61542 .85182 m .61561 .85295 L .61507 .85218 L F
.61426 .85267 m .6151 .85349 L .61429 .85394 L .402 .228 .528 r
F
.61481 .85234 m .6151 .85349 L .61426 .85267 L F
.61286 .78073 m .62208 .77951 L .62008 .77813 L .595 .768 .962 r
F
.61353 .78112 m .62208 .77951 L .61286 .78073 L F
.61641 .84947 m .61899 .85023 L .61967 .84954 L .656 .815 .96 r
F
.61658 .84976 m .61899 .85023 L .61641 .84947 L F
.61889 .84919 m .61967 .84954 L .62009 .84911 L F
.61679 .8501 m .61744 .85119 L .61899 .85023 L F
.61404 .78256 m .61482 .78342 L .61437 .78262 L .595 .768 .962 r
F
.61482 .78342 m .62123 .7855 L .61437 .78262 L F
.61564 .78487 m .6189 .7866 L .61482 .78342 L F
.3014 .66709 m .2846 .67285 L .29484 .67799 L .659 .805 .953 r
F
.58996 .68127 m .57332 .67776 L .56892 .68246 L .656 .808 .956 r
F
.59332 .67916 m .57332 .67776 L .58996 .68127 L F
.38003 .68332 m .38894 .67164 L .38929 .67696 L .388 .243 .56 r
F
.36548 .67768 m .38003 .68332 L .38929 .67696 L .658 .806 .954 r
F
.35736 .68116 m .38003 .68332 L .36548 .67768 L F
0 g
.36789 .68849 m
.38003 .68332 L
s
.49826 .43221 m .46699 .44087 L .49925 .43743 L .642 .738 .918 r
F
.49826 .43221 m .46481 .43045 L .46699 .44087 L F
.73812 .56275 m .71648 .55641 L .70663 .56653 L .653 .783 .943 r
F
.71714 .56288 m .70663 .56653 L .70727 .57297 L .252 .149 .538 r
F
.71714 .56288 m .71648 .55641 L .70663 .56653 L F
0 g
.70197 .5771 m
.70663 .56653 L
s
.25875 .40932 m .26105 .42946 L .27811 .429 L .642 .738 .918 r
F
.24997 .40816 m .26105 .42946 L .25875 .40932 L F
.24997 .40816 m .24368 .4272 L .26105 .42946 L F
.70826 .42327 m .70827 .41528 L .73444 .41458 L .667 .432 .555 r
F
.68266 .41986 m .70827 .41528 L .70826 .42327 L .732 .485 .555 r
F
.68266 .41986 m .68274 .41187 L .70827 .41528 L F
.61038 .57359 m .58913 .56902 L .58957 .57547 L .673 .453 .579 r
F
0 g
.56995 .57998 m
.58957 .57547 L
s
.61038 .57359 m .6099 .56714 L .58913 .56902 L .673 .453 .579 r
F
0 g
.56954 .57354 m
.58913 .56902 L
s
.79074 .56197 m .78735 .54784 L .784 .56166 L .653 .783 .943 r
F
.79074 .56197 m .80094 .54847 L .78735 .54784 L F
.59543 .44761 m .63206 .43924 L .59861 .43748 L .642 .738 .918 r
F
.56366 .44081 m .59543 .44761 L .59861 .43748 L F
.56002 .4454 m .59543 .44761 L .56366 .44081 L F
.56989 .69311 m .55083 .69198 L .5482 .69921 L .655 .81 .957 r
F
0 g
.5482 .69921 m
.54964 .7061 L
s
.32641 .57192 m .31191 .56037 L .3012 .56501 L .654 .782 .942 r
F
.33274 .57041 m .31191 .56037 L .32641 .57192 L F
.71141 .39476 m .70832 .41498 L .73436 .41429 L .645 .736 .915 r
F
.69427 .39246 m .70832 .41498 L .71141 .39476 L F
.69427 .39246 m .68291 .41159 L .70832 .41498 L F
0 g
.78699 .60334 m
.7903 .64425 L
s
.62487 .68436 m .63703 .67518 L .62199 .68265 L .656 .809 .957 r
F
.62487 .68436 m .64276 .67863 L .63703 .67518 L F
.44863 .81972 m .43866 .81397 L .4383 .81852 L .732 .506 .585 r
F
0 g
.43866 .81397 m
.44898 .81517 L
s
.44863 .81972 m
.45825 .82199 L
s
.42835 .81394 m
.43866 .81397 L
s
.38587 .56869 m .39569 .55302 L .37711 .56323 L .654 .782 .942 r
F
.38587 .56869 m .40877 .56131 L .39569 .55302 L F
0 g
.78009 .60323 m
.78338 .64497 L
s
.81224 .44887 m .78662 .43745 L .78679 .44549 L .732 .485 .555 r
F
0 g
.78662 .43745 m
.81201 .44082 L
s
.81224 .44887 m
.83497 .45601 L
s
.76042 .43812 m
.78662 .43745 L
s
.48923 .54571 m .50809 .54301 L .5084 .54942 L .792 .545 .564 r
F
.48923 .54571 m .48896 .53929 L .50809 .54301 L F
0 g
.50809 .54301 m
.52866 .54395 L
s
.77704 .56229 m .77329 .54911 L .75978 .5522 L .653 .783 .943 r
F
.784 .56166 m .77329 .54911 L .77704 .56229 L F
0 g
.31573 .44795 m
.34141 .4473 L
s
.50293 .52667 m .5082 .54281 L .51571 .52919 L .656 .78 .94 r
F
.50293 .52667 m .48916 .5391 L .5082 .54281 L F
.62127 .67737 m .62842 .66749 L .61738 .67617 L .656 .808 .956 r
F
.62127 .67737 m .63621 .66993 L .62842 .66749 L F
.30124 .55855 m .26931 .55811 L .29334 .56443 L .655 .781 .941 r
F
0 g
.34141 .4473 m
.36736 .45067 L
s
.784 .56166 m .78735 .54784 L .77329 .54911 L .653 .783 .943 r
F
.52934 .55677 m .529 .55035 L .54975 .54846 L .673 .452 .577 r
F
.5087 .55584 m .529 .55035 L .52934 .55677 L .733 .499 .573 r
F
.5087 .55584 m .5084 .54942 L .529 .55035 L F
.52982 .53642 m .529 .55035 L .54975 .54846 L .655 .781 .941 r
F
.51595 .53577 m .529 .55035 L .52982 .53642 L F
.51595 .53577 m .5084 .54942 L .529 .55035 L F
.29328 .57087 m .26921 .56458 L .26245 .57465 L .654 .782 .942 r
F
0 g
.26113 .58516 m
.26245 .57465 L
s
.79756 .56961 m .80174 .55494 L .79152 .5684 L .653 .784 .944 r
F
.79756 .56961 m .81391 .55741 L .80174 .55494 L F
.63085 .57449 m .6099 .56714 L .61038 .57359 L .733 .499 .573 r
F
0 g
.58913 .56902 m
.6099 .56714 L
s
.6099 .56714 m
.63033 .56805 L
s
.63085 .57449 m
.64945 .57808 L
s
.57332 .67776 m .55 .68131 L .56892 .68246 L .656 .808 .956 r
F
.34657 .57008 m .33856 .55603 L .33962 .56978 L .654 .782 .942 r
F
.34657 .57008 m .35259 .55665 L .33856 .55603 L F
.2416 .4057 m .24368 .4272 L .24997 .40816 L .642 .738 .918 r
F
.2416 .4057 m .22711 .42236 L .24368 .4272 L F
.26738 .40908 m .27811 .429 L .29377 .42586 L F
.25875 .40932 m .27811 .429 L .26738 .40908 L F
.23548 .39397 m .22842 .4142 L .24282 .39758 L .643 .737 .917 r
F
.23548 .39397 m .21382 .4071 L .22842 .4142 L F
.19926 .41432 m .18969 .43618 L .21117 .42328 L .642 .739 .919 r
F
.19926 .41432 m .17176 .42292 L .18969 .43618 L F
0 g
.18969 .43618 m
.21171 .44666 L
s
.7318 .67669 m .73913 .67653 L .73993 .68185 L .94 .645 .454 r
F
.7318 .67669 m .731 .67135 L .73913 .67653 L F
0 g
.73913 .67653 m
.74624 .67883 L
s
.42798 .81848 m
.4383 .81852 L
s
.59109 .6919 m .56989 .69311 L .58885 .69424 L .655 .81 .957 r
F
0 g
.61038 .57359 m
.63085 .57449 L
s
.4383 .81852 m
.44863 .81972 L
s
.74952 .6655 m .73128 .67127 L .73936 .67642 L .655 .809 .957 r
F
.27625 .39933 m .2946 .41768 L .30777 .41203 L .643 .737 .917 r
F
.26841 .40094 m .2946 .41768 L .27625 .39933 L F
.82464 .68176 m .8349 .67006 L .83583 .67539 L .457 .314 .597 r
F
.8126 .6761 m .82464 .68176 L .83583 .67539 L .654 .811 .959 r
F
.80354 .67959 m .82464 .68176 L .8126 .6761 L F
0 g
.81109 .68693 m
.82464 .68176 L
s
.6467 .68816 m .66147 .67821 L .64344 .68397 L .655 .81 .957 r
F
.6467 .68816 m .66627 .68454 L .66147 .67821 L F
.33079 .44359 m .34676 .42401 L .34587 .43207 L .29 .108 .453 r
F
.30604 .42826 m .33079 .44359 L .34587 .43207 L .642 .739 .919 r
F
.29276 .4339 m .33079 .44359 L .30604 .42826 L F
0 g
.32788 .4448 m
.33079 .44359 L
s
.33079 .44359 m
.33142 .44311 L
s
.33274 .57041 m .32467 .5573 L .31191 .56037 L .654 .782 .942 r
F
.33962 .56978 m .32467 .5573 L .33274 .57041 L F
.66556 .67922 m .66007 .66754 L .66077 .67287 L .975 .68 .301 r
F
.66627 .68454 m .66556 .67922 L .66077 .67287 L F
0 g
.6661 .68419 m
.66612 .68434 L
s
.37675 .55047 m .37824 .53396 L .36549 .54634 L .656 .781 .94 r
F
.37675 .55047 m .39518 .54025 L .37824 .53396 L F
.28475 .68362 m .29485 .68342 L .29507 .68874 L .908 .646 .53 r
F
.28475 .68362 m .28455 .67827 L .29485 .68342 L F
.30145 .67249 m .29485 .68342 L .3083 .67596 L .659 .806 .954 r
F
.30145 .67249 m .28455 .67827 L .29485 .68342 L F
0 g
.29485 .68342 m
.30142 .68524 L
s
.54975 .54846 m .56895 .53745 L .56936 .54386 L .606 .401 .578 r
F
.55013 .55488 m .54975 .54846 L .56936 .54386 L F
.52934 .55677 m .54975 .54846 L .55013 .55488 L .673 .452 .577 r
F
.54379 .53514 m .54975 .54846 L .56936 .54386 L .655 .781 .941 r
F
.52982 .53642 m .54975 .54846 L .54379 .53514 L F
0 g
.529 .55035 m
.54975 .54846 L
s
.77109 .57024 m .76051 .55867 L .74849 .56332 L .653 .784 .944 r
F
.7778 .56873 m .76051 .55867 L .77109 .57024 L F
.65927 .41255 m .68274 .41187 L .68266 .41986 L .797 .54 .549 r
F
.65927 .41255 m .6594 .40455 L .68274 .41187 L F
0 g
.68274 .41187 m
.70827 .41528 L
s
.33962 .56978 m .33856 .55603 L .32467 .5573 L .654 .782 .942 r
F
.59049 .68657 m .57374 .68306 L .56931 .68777 L .656 .809 .957 r
F
.59387 .68446 m .57374 .68306 L .59049 .68657 L F
.83064 .56701 m .84533 .5513 L .82376 .56154 L .653 .784 .944 r
F
.83064 .56701 m .85555 .55961 L .84533 .5513 L F
.46871 .40414 m .43323 .4127 L .46635 .41444 L .644 .737 .916 r
F
.46871 .40414 m .43648 .39719 L .43323 .4127 L F
.43532 .40511 m .43273 .41268 L .43205 .42067 L 0 0 .056 r
F
0 g
.43325 .41496 m
.43457 .4208 L
s
.43532 .40511 m .43599 .39708 L .43273 .41268 L 0 0 .056 r
F
.73448 .42258 m .73444 .41458 L .75963 .4098 L .596 .376 .551 r
F
.70826 .42327 m .73444 .41458 L .73448 .42258 L .667 .432 .555 r
F
0 g
.70827 .41528 m
.73444 .41458 L
s
.50074 .41105 m .46635 .41444 L .49946 .41618 L .644 .737 .916 r
F
.50074 .41105 m .46871 .40414 L .46635 .41444 L F
0 g
.61128 .69423 m
.61153 .70392 L
s
.40863 .55487 m .40849 .54845 L .39545 .5401 L .92 .656 .521 r
F
0 g
.40849 .54845 m
.4167 .5582 L
s
.59332 .67916 m .58003 .67352 L .57332 .67776 L .656 .808 .956 r
F
.5976 .67744 m .58003 .67352 L .59332 .67916 L F
.43679 .9122 m .43658 .90946 L .44019 .90899 L .674 .453 .578 r
F
.43317 .91226 m .43658 .90946 L .43679 .9122 L .73 .495 .572 r
F
.43317 .91226 m .43296 .90952 L .43658 .90946 L F
.43655 .90745 m .43658 .90946 L .44019 .90899 L .657 .814 .959 r
F
.43414 .90749 m .43658 .90946 L .43655 .90745 L F
.43414 .90749 m .43296 .90952 L .43658 .90946 L F
.67865 .3875 m .68291 .41159 L .69427 .39246 L .645 .736 .915 r
F
.67865 .3875 m .65968 .4043 L .68291 .41159 L F
0 g
.60439 .69466 m
.60461 .70382 L
s
.44041 .91173 m .44019 .90899 L .44356 .90814 L .611 .406 .579 r
F
.43679 .9122 m .44019 .90899 L .44041 .91173 L .674 .453 .578 r
F
.43897 .90714 m .44019 .90899 L .44356 .90814 L .657 .814 .959 r
F
.43655 .90745 m .44019 .90899 L .43897 .90714 L F
0 g
.43658 .90946 m
.44019 .90899 L
s
.72897 .39428 m .73436 .41429 L .75943 .40953 L .645 .736 .915 r
F
.71141 .39476 m .73436 .41429 L .72897 .39428 L F
.56571 .41965 m .59747 .41089 L .56493 .41442 L .644 .737 .916 r
F
.56571 .41965 m .59883 .42139 L .59747 .41089 L F
0 g
.76053 .44615 m
.78679 .44549 L
s
.74778 .55685 m .71648 .55641 L .73812 .56275 L .653 .783 .943 r
F
.59883 .42139 m .63022 .40735 L .59747 .41089 L .644 .737 .916 r
F
.59883 .42139 m .63196 .42313 L .63022 .40735 L F
.62552 .68968 m .6377 .68053 L .62264 .68798 L .655 .81 .957 r
F
.62552 .68968 m .64344 .68397 L .6377 .68053 L F
0 g
.78679 .44549 m
.81224 .44887 L
s
.42666 .90841 m .42937 .90642 L .42957 .90916 L .843 .583 .544 r
F
.42666 .90841 m .42645 .90567 L .42937 .90642 L F
0 g
.42937 .90642 m
.43221 .90672 L
s
.63226 .43118 m .63246 .42316 L .63072 .4073 L .847 .68 .143 r
F
0 g
.62985 .43105 m
.63186 .42497 L
s
.42976 .90399 m .4294 .90639 L .43169 .90449 L .657 .813 .959 r
F
.42976 .90399 m .4265 .90565 L .4294 .90639 L F
.38894 .67164 m .3886 .66634 L .39432 .65915 L .142 .062 .498 r
F
0 g
.38057 .67189 m
.3886 .66634 L
s
.73882 .56919 m .71714 .56288 L .70727 .57297 L .653 .784 .944 r
F
0 g
.7026 .58351 m
.70727 .57297 L
s
.42978 .91191 m .43296 .90952 L .43317 .91226 L .784 .537 .562 r
F
.42978 .91191 m .42957 .90916 L .43296 .90952 L F
.43188 .90725 m .43296 .90952 L .43414 .90749 L .657 .814 .959 r
F
.43188 .90725 m .42957 .90916 L .43296 .90952 L F
0 g
.43296 .90952 m
.43658 .90946 L
s
.58957 .57547 m
.61038 .57359 L
s
.79152 .5684 m .78813 .55432 L .78477 .5681 L .653 .784 .944 r
F
.79152 .5684 m .80174 .55494 L .78813 .55432 L F
.61738 .67617 m .61908 .66623 L .61273 .67555 L .656 .808 .956 r
F
.61738 .67617 m .62842 .66749 L .61908 .66623 L F
.44645 .90698 m .44623 .90423 L .44845 .90282 L .406 .255 .561 r
F
.44356 .90814 m .44623 .90423 L .44645 .90698 L .529 .345 .576 r
F
0 g
.44446 .90495 m
.44623 .90423 L
s
.44377 .91089 m .44356 .90814 L .44645 .90698 L .529 .345 .576 r
F
.44041 .91173 m .44356 .90814 L .44377 .91089 L .611 .406 .579 r
F
.44121 .90657 m .44356 .90814 L .44645 .90698 L .657 .814 .959 r
F
.43897 .90714 m .44356 .90814 L .44121 .90657 L F
0 g
.44019 .90899 m
.44356 .90814 L
s
.62199 .68265 m .62919 .67274 L .61808 .68145 L .656 .809 .957 r
F
.62199 .68265 m .63703 .67518 L .62919 .67274 L F
0 g
.61153 .70392 m
.61316 .76684 L
s
.60461 .70382 m
.6061 .76674 L
s
.48951 .55215 m .5084 .54942 L .5087 .55584 L .792 .545 .564 r
F
.48951 .55215 m .48923 .54571 L .5084 .54942 L F
.50309 .53325 m .5084 .54942 L .51595 .53577 L .655 .781 .941 r
F
.50309 .53325 m .48923 .54571 L .5084 .54942 L F
0 g
.5084 .54942 m
.529 .55035 L
s
.56936 .54386 m .56895 .53745 L .58614 .53039 L .522 .338 .572 r
F
0 g
.55808 .54001 m
.56895 .53745 L
s
.57374 .68306 m .55027 .68662 L .56931 .68777 L .656 .809 .957 r
F
.7778 .56873 m .77405 .55559 L .76051 .55867 L .653 .784 .944 r
F
.78477 .5681 m .77405 .55559 L .7778 .56873 L F
.64191 .67337 m .65129 .66241 L .63621 .66993 L .656 .808 .956 r
F
.64191 .67337 m .6598 .66763 L .65129 .66241 L F
.82188 .54877 m .82856 .53223 L .8121 .54463 L .654 .782 .942 r
F
.82188 .54877 m .84325 .53853 L .82856 .53223 L F
.43676 .9102 m .43679 .9122 L .44041 .91173 L .656 .814 .959 r
F
.43435 .91024 m .43679 .9122 L .43676 .9102 L F
.43435 .91024 m .43317 .91226 L .43679 .9122 L F
.43918 .90988 m .44041 .91173 L .44377 .91089 L F
.43676 .9102 m .44041 .91173 L .43918 .90988 L F
0 g
.43679 .9122 m
.44041 .91173 L
s
.55645 .52546 m .56877 .53727 L .58587 .53025 L .656 .78 .94 r
F
.54336 .52856 m .56877 .53727 L .55645 .52546 L F
.7326 .68204 m .73993 .68185 L .74074 .68718 L .94 .645 .454 r
F
.7326 .68204 m .7318 .67669 L .73993 .68185 L F
.75016 .6709 m .73993 .68185 L .75554 .67438 L .655 .81 .958 r
F
.75016 .6709 m .7318 .67669 L .73993 .68185 L F
0 g
.73993 .68185 m
.7471 .68415 L
s
.3012 .56501 m .26921 .56458 L .29328 .57087 L .654 .782 .942 r
F
.78477 .5681 m .78813 .55432 L .77405 .55559 L .653 .784 .944 r
F
.53017 .54287 m .52934 .55677 L .55013 .55488 L .655 .782 .942 r
F
.51628 .54224 m .52934 .55677 L .53017 .54287 L F
.51628 .54224 m .5087 .55584 L .52934 .55677 L F
.42686 .91116 m .42957 .90916 L .42978 .91191 L .843 .583 .544 r
F
.42686 .91116 m .42666 .90841 L .42957 .90916 L F
.42993 .90675 m .42957 .90916 L .43188 .90725 L .657 .814 .959 r
F
.42993 .90675 m .42666 .90841 L .42957 .90916 L F
0 g
.42957 .90916 m
.43296 .90952 L
s
.34189 .67497 m .34783 .68362 L .35736 .68116 L .658 .806 .954 r
F
.85466 .55317 m .85377 .54674 L .84357 .53838 L .952 .653 .432 r
F
0 g
.85377 .54674 m
.85877 .55652 L
s
.66627 .68454 m .66077 .67287 L .66147 .67821 L .975 .68 .301 r
F
0 g
.66627 .68454 m
.66703 .69153 L
s
.25764 .41739 m .25996 .43748 L .27706 .43703 L .642 .739 .919 r
F
.24883 .41623 m .25996 .43748 L .25764 .41739 L F
.24883 .41623 m .24255 .43522 L .25996 .43748 L F
.43209 .91 m .43317 .91226 L .43435 .91024 L .656 .814 .959 r
F
.43209 .91 m .42978 .91191 L .43317 .91226 L F
0 g
.43317 .91226 m
.43679 .9122 L
s
.5976 .67744 m .58861 .67003 L .58003 .67352 L .656 .808 .956 r
F
.60248 .67621 m .58861 .67003 L .5976 .67744 L F
.70824 .4313 m .70826 .42327 L .73448 .42258 L .667 .432 .555 r
F
.68259 .42789 m .70826 .42327 L .70824 .4313 L .732 .485 .555 r
F
.68259 .42789 m .68266 .41986 L .70826 .42327 L F
.71137 .403 m .70826 .42327 L .73448 .42258 L .644 .736 .916 r
F
.69411 .40069 m .70826 .42327 L .71137 .403 L F
.69411 .40069 m .68266 .41986 L .70826 .42327 L F
.4244 .90733 m .42645 .90567 L .42666 .90841 L .911 .637 .508 r
F
.4244 .90733 m .4242 .90458 L .42645 .90567 L F
0 g
.42645 .90567 m
.42937 .90642 L
s
.42827 .90326 m .4265 .90565 L .42976 .90399 L .657 .813 .959 r
F
.42827 .90326 m .42426 .90456 L .4265 .90565 L F
.30168 .67785 m .29507 .68874 L .30854 .6813 L .658 .806 .954 r
F
.30168 .67785 m .28475 .68362 L .29507 .68874 L F
0 g
.29507 .68874 m
.30803 .69232 L
s
.44645 .90698 m .44845 .90282 L .44867 .90556 L .406 .255 .561 r
F
.44667 .90972 m .44645 .90698 L .44867 .90556 L F
.44377 .91089 m .44645 .90698 L .44667 .90972 L .529 .345 .576 r
F
.44314 .90579 m .44645 .90698 L .44867 .90556 L .657 .814 .959 r
F
.44121 .90657 m .44645 .90698 L .44314 .90579 L F
0 g
.44356 .90814 m
.44645 .90698 L
s
.44143 .90932 m .44377 .91089 L .44667 .90972 L .656 .814 .959 r
F
.43918 .90988 m .44377 .91089 L .44143 .90932 L F
0 g
.44041 .91173 m
.44377 .91089 L
s
.59109 .6919 m .57432 .68841 L .56989 .69311 L .655 .81 .957 r
F
.59448 .6898 m .57432 .68841 L .59109 .6919 L F
.8349 .67006 m .83397 .66475 L .84201 .65755 L .317 .219 .583 r
F
0 g
.82414 .67039 m
.83397 .66475 L
s
.30148 .55221 m .28149 .54286 L .26976 .55176 L .656 .781 .94 r
F
.3121 .54757 m .28149 .54286 L .30148 .55221 L F
.61273 .67555 m .60885 .66625 L .60765 .67556 L .656 .808 .956 r
F
.61273 .67555 m .61908 .66623 L .60885 .66625 L F
.59387 .68446 m .58049 .67881 L .57374 .68306 L .656 .809 .957 r
F
.59817 .68273 m .58049 .67881 L .59387 .68446 L F
.44867 .90556 m .44845 .90282 L .44985 .90126 L .182 .092 .511 r
F
0 g
.44623 .90423 m
.44845 .90282 L
s
.44436 .9021 m .44839 .90281 L .44978 .90125 L .657 .813 .959 r
F
.44289 .90304 m .44839 .90281 L .44436 .9021 L F
.37702 .55679 m .37852 .54025 L .36568 .55266 L .655 .781 .941 r
F
.37702 .55679 m .39557 .54655 L .37852 .54025 L F
.55013 .55488 m .56936 .54386 L .56977 .55029 L .606 .401 .578 r
F
.54416 .5416 m .55013 .55488 L .56977 .55029 L .655 .782 .942 r
F
.53017 .54287 m .55013 .55488 L .54416 .5416 L F
0 g
.52934 .55677 m
.55013 .55488 L
s
.32647 .67501 m .3172 .68372 L .32707 .68495 L .658 .806 .954 r
F
.38894 .67164 m .39432 .65915 L .39467 .66448 L .142 .062 .498 r
F
.38929 .67696 m .38894 .67164 L .39467 .66448 L F
.37131 .66807 m .38894 .67164 L .39467 .66448 L .659 .806 .954 r
F
.36516 .67235 m .38894 .67164 L .37131 .66807 L F
0 g
.38086 .67722 m
.38894 .67164 L
s
.60248 .67621 m .59844 .66754 L .58861 .67003 L .656 .808 .956 r
F
.60765 .67556 m .59844 .66754 L .60248 .67621 L F
.43014 .9095 m .42978 .91191 L .43209 .91 L .656 .814 .959 r
F
.43014 .9095 m .42686 .91116 L .42978 .91191 L F
0 g
.42978 .91191 m
.43317 .91226 L
s
.40863 .55487 m .39545 .5401 L .39557 .54655 L .92 .656 .521 r
F
.40877 .56131 m .40863 .55487 L .39557 .54655 L F
0 g
.40863 .55487 m
.41686 .56459 L
s
.60765 .67556 m .60885 .66625 L .59844 .66754 L .656 .808 .956 r
F
.78048 .67405 m .77296 .68338 L .78304 .68335 L .654 .811 .959 r
F
.23421 .40207 m .22711 .42236 L .2416 .4057 L .642 .738 .918 r
F
.23421 .40207 m .21239 .41523 L .22711 .42236 L F
.61808 .68145 m .6198 .67148 L .6134 .68083 L .656 .809 .957 r
F
.61808 .68145 m .62919 .67274 L .6198 .67148 L F
.42461 .91008 m .42666 .90841 L .42686 .91116 L .911 .637 .508 r
F
.42461 .91008 m .4244 .90733 L .42666 .90841 L F
.42843 .90602 m .42666 .90841 L .42993 .90675 L .657 .814 .959 r
F
.42843 .90602 m .4244 .90733 L .42666 .90841 L F
0 g
.42666 .90841 m
.42957 .90916 L
s
.62264 .68798 m .62986 .6781 L .61872 .68678 L .655 .81 .957 r
F
.62264 .68798 m .6377 .68053 L .62986 .6781 L F
.24044 .41377 m .24255 .43522 L .24883 .41623 L .642 .739 .919 r
F
.24044 .41377 m .22593 .43039 L .24255 .43522 L F
.57332 .67776 m .55653 .67423 L .55 .68131 L .656 .808 .956 r
F
.56366 .44081 m .59861 .43748 L .56515 .43572 L .642 .738 .918 r
F
.74849 .56332 m .71714 .56288 L .73882 .56919 L .653 .784 .944 r
F
.55685 .67953 m .54972 .68129 L .55027 .68662 L .219 .131 .537 r
F
.55685 .67953 m .55628 .67417 L .54972 .68129 L F
0 g
.5471 .68856 m
.54972 .68129 L
s
.26629 .41715 m .27706 .43703 L .29276 .4339 L .642 .739 .919 r
F
.25764 .41739 m .27706 .43703 L .26629 .41715 L F
.26738 .40908 m .29377 .42586 L .27528 .40747 L .642 .738 .918 r
F
.27528 .40747 m .29377 .42586 L .30703 .4202 L F
.44667 .90972 m .44867 .90556 L .44889 .90831 L .406 .255 .561 r
F
.44336 .90854 m .44667 .90972 L .44889 .90831 L .656 .814 .959 r
F
.44143 .90932 m .44667 .90972 L .44336 .90854 L F
0 g
.44377 .91089 m
.44667 .90972 L
s
.57432 .68841 m .55083 .69198 L .56989 .69311 L .655 .81 .957 r
F
.64276 .67863 m .65221 .66764 L .63703 .67518 L .656 .809 .957 r
F
.64276 .67863 m .66077 .67287 L .65221 .66764 L F
.16053 .39962 m .17438 .40689 L .17307 .41489 L .964 .736 .544 r
F
.16053 .39962 m .16188 .39159 L .17438 .40689 L F
0 g
.17438 .40689 m
.18152 .41223 L
s
.75098 .67626 m .74074 .68718 L .75637 .67972 L .654 .811 .959 r
F
.75098 .67626 m .7326 .68204 L .74074 .68718 L F
0 g
.74074 .68718 m
.75197 .69076 L
s
.34669 .67373 m .35736 .68116 L .36548 .67768 L .658 .806 .954 r
F
.34189 .67497 m .35736 .68116 L .34669 .67373 L F
.44867 .90556 m .44985 .90126 L .45007 .904 L .182 .092 .511 r
F
.44889 .90831 m .44867 .90556 L .45007 .904 L F
.44462 .90485 m .44867 .90556 L .45007 .904 L .657 .814 .959 r
F
.44314 .90579 m .44867 .90556 L .44462 .90485 L F
0 g
.44645 .90698 m
.44867 .90556 L
s
.19388 .38792 m .17479 .40676 L .20203 .39815 L .643 .737 .917 r
F
.19388 .38792 m .16235 .39154 L .17479 .40676 L F
.43228 .90197 m .42827 .90326 L .42976 .90399 L .657 .813 .959 r
F
.42297 .90597 m .4242 .90458 L .4244 .90733 L .978 .695 .417 r
F
.42297 .90597 m .42277 .90322 L .4242 .90458 L F
0 g
.4242 .90458 m
.42645 .90567 L
s
.42732 .90236 m .42426 .90456 L .42827 .90326 L .657 .813 .959 r
F
.42732 .90236 m .42283 .90321 L .42426 .90456 L F
.65913 .42059 m .68266 .41986 L .68259 .42789 L .797 .54 .549 r
F
.65913 .42059 m .65927 .41255 L .68266 .41986 L F
.67837 .39571 m .68266 .41986 L .69411 .40069 L .644 .736 .916 r
F
.67837 .39571 m .65927 .41255 L .68266 .41986 L F
0 g
.68266 .41986 m
.70826 .42327 L
s
.43321 .90509 m .42993 .90675 L .43188 .90725 L .657 .814 .959 r
F
.74723 .55051 m .7305 .54114 L .71615 .55006 L .654 .782 .942 r
F
.75915 .54586 m .7305 .54114 L .74723 .55051 L F
.34676 .42401 m .34765 .41599 L .35683 .40182 L 0 0 .309 r
F
0 g
.3383 .4232 m
.34765 .41599 L
s
.46779 .41209 m .43205 .42067 L .46541 .42242 L .643 .737 .917 r
F
.46779 .41209 m .43532 .40511 L .43205 .42067 L F
.43463 .41318 m .43205 .42067 L .43137 .4287 L 0 0 .056 r
F
0 g
.43258 .42297 m
.43391 .42883 L
s
.43463 .41318 m .43532 .40511 L .43205 .42067 L 0 0 .056 r
F
.47273 .53943 m .48896 .53929 L .48923 .54571 L .856 .597 .547 r
F
.47273 .53943 m .47248 .53299 L .48896 .53929 L F
0 g
.48896 .53929 m
.49505 .54048 L
s
.73448 .42258 m .75963 .4098 L .75974 .41782 L .596 .376 .551 r
F
.73453 .43061 m .73448 .42258 L .75974 .41782 L F
.70824 .4313 m .73448 .42258 L .73453 .43061 L .667 .432 .555 r
F
.72906 .40252 m .73448 .42258 L .75974 .41782 L .644 .736 .916 r
F
.71137 .403 m .73448 .42258 L .72906 .40252 L F
0 g
.70826 .42327 m
.73448 .42258 L
s
.50339 .53973 m .5087 .55584 L .51628 .54224 L .655 .782 .942 r
F
.50339 .53973 m .48951 .55215 L .5087 .55584 L F
0 g
.5087 .55584 m
.52934 .55677 L
s
.54379 .53514 m .56936 .54386 L .55697 .53202 L .655 .781 .941 r
F
.56936 .54386 m .58614 .53039 L .58658 .53681 L .522 .338 .572 r
F
.56977 .55029 m .56936 .54386 L .58658 .53681 L F
.55697 .53202 m .56936 .54386 L .58658 .53681 L .655 .781 .941 r
F
0 g
.5584 .54643 m
.56936 .54386 L
s
.50007 .41903 m .46541 .42242 L .49878 .42417 L .643 .737 .917 r
F
.50007 .41903 m .46779 .41209 L .46541 .42242 L F
.59817 .68273 m .58912 .67531 L .58049 .67881 L .656 .809 .957 r
F
.60309 .68149 m .58912 .67531 L .59817 .68273 L F
.44436 .9021 m .44978 .90125 L .44529 .90106 L .657 .813 .959 r
F
.31767 .40422 m .3472 .41581 L .35633 .40172 L .643 .737 .917 r
F
.30777 .41203 m .3472 .41581 L .31767 .40422 L F
.43674 .90819 m .43676 .9102 L .43918 .90988 L .656 .814 .959 r
F
.43553 .90821 m .43676 .9102 L .43674 .90819 L F
.43553 .90821 m .43435 .91024 L .43676 .9102 L F
.43795 .90803 m .43918 .90988 L .44143 .90932 L F
.43674 .90819 m .43918 .90988 L .43795 .90803 L F
.49197 .52242 m .48916 .5391 L .50293 .52667 L .656 .78 .94 r
F
.49197 .52242 m .47276 .53283 L .48916 .5391 L F
.82293 .55509 m .82967 .53851 L .81308 .55095 L .653 .783 .943 r
F
.82293 .55509 m .84445 .54483 L .82967 .53851 L F
.56551 .42767 m .59752 .4189 L .56473 .42242 L .643 .737 .917 r
F
.56551 .42767 m .59889 .42943 L .59752 .4189 L F
.42864 .90878 m .42686 .91116 L .43014 .9095 L .656 .814 .959 r
F
.42864 .90878 m .42461 .91008 L .42686 .91116 L F
0 g
.42686 .91116 m
.42978 .91191 L
s
.77592 .67342 m .77296 .68338 L .78048 .67405 L .654 .811 .959 r
F
.77592 .67342 m .76387 .68215 L .77296 .68338 L F
.59889 .42943 m .63051 .41535 L .59752 .4189 L .643 .737 .917 r
F
.59889 .42943 m .63226 .43118 L .63051 .41535 L F
.8349 .67006 m .84201 .65755 L .84296 .66288 L .317 .219 .583 r
F
.83583 .67539 m .8349 .67006 L .84296 .66288 L F
.81915 .66647 m .8349 .67006 L .84296 .66288 L .655 .81 .958 r
F
.8117 .67077 m .8349 .67006 L .81915 .66647 L F
0 g
.825 .67572 m
.8349 .67006 L
s
.45007 .904 m .44985 .90126 L .45032 .89965 L 0 0 .325 r
F
0 g
.44845 .90282 m
.44985 .90126 L
s
.44529 .90106 m .44978 .90125 L .45025 .89966 L .657 .813 .959 r
F
.4344 .90809 m .43435 .91024 L .43553 .90821 L .656 .814 .959 r
F
.4344 .90809 m .43209 .91 L .43435 .91024 L F
.63226 .43118 m .63072 .4073 L .63051 .41535 L .847 .68 .143 r
F
.63206 .43924 m .63226 .43118 L .63051 .41535 L F
0 g
.62962 .43911 m
.63166 .43299 L
s
.59448 .6898 m .58109 .68417 L .57432 .68841 L .655 .81 .957 r
F
.59879 .68807 m .58109 .68417 L .59448 .6898 L F
.85466 .55317 m .84357 .53838 L .84445 .54483 L .952 .653 .432 r
F
.85555 .55961 m .85466 .55317 L .84445 .54483 L F
0 g
.85466 .55317 m
.85966 .56291 L
s
.6134 .68083 m .6095 .67151 L .60829 .68085 L .656 .809 .957 r
F
.6134 .68083 m .6198 .67148 L .6095 .67151 L F
.43908 .90775 m .44143 .90932 L .44336 .90854 L .656 .814 .959 r
F
.43795 .90803 m .44143 .90932 L .43908 .90775 L F
.58003 .67352 m .55653 .67423 L .57332 .67776 L .656 .808 .956 r
F
.44889 .90831 m .45007 .904 L .45029 .90675 L .182 .092 .511 r
F
.44484 .9076 m .44889 .90831 L .45029 .90675 L .656 .814 .959 r
F
.44336 .90854 m .44889 .90831 L .44484 .9076 L F
0 g
.44667 .90972 m
.44889 .90831 L
s
.28111 .54919 m .2694 .55166 L .26931 .55811 L .336 .181 .518 r
F
.28111 .54919 m .28119 .54272 L .2694 .55166 L F
0 g
.26266 .56179 m
.2694 .55166 L
s
.43246 .90472 m .42993 .90675 L .43321 .90509 L .657 .814 .959 r
F
.43246 .90472 m .42843 .90602 L .42993 .90675 L F
.38929 .67696 m .39467 .66448 L .39502 .66982 L .142 .062 .498 r
F
.37163 .67341 m .38929 .67696 L .39502 .66982 L .658 .806 .954 r
F
.36548 .67768 m .38929 .67696 L .37163 .67341 L F
0 g
.38003 .68332 m
.38929 .67696 L
s
.4318 .90151 m .42827 .90326 L .43228 .90197 L .657 .813 .959 r
F
.4318 .90151 m .42732 .90236 L .42827 .90326 L F
.42317 .90872 m .4244 .90733 L .42461 .91008 L .978 .695 .417 r
F
.42317 .90872 m .42297 .90597 L .4244 .90733 L F
.42748 .90512 m .4244 .90733 L .42843 .90602 L .657 .814 .959 r
F
.42748 .90512 m .42297 .90597 L .4244 .90733 L F
0 g
.4244 .90733 m
.42666 .90841 L
s
.60309 .68149 m .59902 .67281 L .58912 .67531 L .656 .809 .957 r
F
.60829 .68085 m .59902 .67281 L .60309 .68149 L F
.43342 .90784 m .43209 .91 L .4344 .90809 L .656 .814 .959 r
F
.43342 .90784 m .43014 .9095 L .43209 .91 L F
.30124 .55855 m .28111 .54919 L .26931 .55811 L .655 .781 .941 r
F
.31193 .5539 m .28111 .54919 L .30124 .55855 L F
.36549 .54634 m .35852 .53018 L .35244 .54387 L .656 .781 .94 r
F
.36549 .54634 m .37824 .53396 L .35852 .53018 L F
.60829 .68085 m .6095 .67151 L .59902 .67281 L .656 .809 .957 r
F
.50421 .40636 m .46871 .40414 L .50074 .41105 L .644 .737 .916 r
F
.44462 .90485 m .45007 .904 L .44555 .90381 L .657 .814 .959 r
F
.61872 .68678 m .62045 .67685 L .61404 .68617 L .655 .81 .957 r
F
.61872 .68678 m .62986 .6781 L .62045 .67685 L F
.79588 .67214 m .80354 .67959 L .8126 .6761 L .654 .811 .959 r
F
.37711 .56323 m .37861 .54674 L .36575 .55912 L .654 .782 .942 r
F
.37711 .56323 m .39569 .55302 L .37861 .54674 L F
.44529 .90106 m .45025 .89966 L .4456 .89999 L .657 .813 .959 r
F
.57374 .68306 m .55685 .67953 L .55027 .68662 L .656 .809 .957 r
F
.55741 .6849 m .55027 .68662 L .55083 .69198 L .219 .131 .537 r
F
.55741 .6849 m .55685 .67953 L .55027 .68662 L F
0 g
.54765 .69388 m
.55027 .68662 L
s
.44004 .90736 m .44336 .90854 L .44484 .9076 L .656 .814 .959 r
F
.43908 .90775 m .44336 .90854 L .44004 .90736 L F
.56493 .41442 m .59162 .40075 L .56192 .40939 L .644 .737 .916 r
F
.56493 .41442 m .59747 .41089 L .59162 .40075 L F
.22961 .38943 m .21382 .4071 L .23548 .39397 L .643 .737 .917 r
F
.22961 .38943 m .20203 .39815 L .21382 .4071 L F
.45007 .904 m .45032 .89965 L .45054 .9024 L 0 0 .325 r
F
.45029 .90675 m .45007 .904 L .45054 .9024 L F
.44555 .90381 m .45007 .904 L .45054 .9024 L .657 .814 .959 r
F
0 g
.44867 .90556 m
.45007 .904 L
s
.32214 .67379 m .3172 .68372 L .32647 .67501 L .658 .806 .954 r
F
.32214 .67379 m .30854 .6813 L .3172 .68372 L F
.40877 .56131 m .39557 .54655 L .39569 .55302 L .92 .656 .521 r
F
0 g
.40877 .56131 m
.41701 .571 L
s
.64344 .68397 m .65291 .67301 L .6377 .68053 L .655 .81 .957 r
F
.64344 .68397 m .66147 .67821 L .65291 .67301 L F
.28286 .39645 m .30777 .41203 L .31767 .40422 L .643 .737 .917 r
F
.27625 .39933 m .30777 .41203 L .28286 .39645 L F
.2776 .67189 m .28434 .67294 L .28455 .67827 L .974 .706 .46 r
F
.2776 .67189 m .2774 .66653 L .28434 .67294 L F
0 g
.28434 .67294 m
.29075 .67615 L
s
.63954 .40174 m .6594 .40455 L .65927 .41255 L .866 .6 .536 r
F
.63954 .40174 m .63972 .39372 L .6594 .40455 L F
0 g
.6594 .40455 m
.666 .40662 L
s
.29685 .66282 m .2846 .67285 L .3014 .66709 L .659 .805 .953 r
F
.29685 .66282 m .27769 .66648 L .2846 .67285 L F
.42245 .90444 m .42277 .90322 L .42297 .90597 L .895 .658 .145 r
F
.42245 .90444 m .42225 .90168 L .42277 .90322 L F
0 g
.42277 .90322 m
.4242 .90458 L
s
.42698 .90134 m .42283 .90321 L .42732 .90236 L .657 .813 .959 r
F
.42698 .90134 m .42232 .90168 L .42283 .90321 L F
.71136 .41108 m .70824 .4313 L .73453 .43061 L .643 .737 .917 r
F
.69406 .40876 m .70824 .4313 L .71136 .41108 L F
.69406 .40876 m .68259 .42789 L .70824 .4313 L F
.75974 .41782 m .75963 .4098 L .78228 .4012 L .51 .308 .542 r
F
0 g
.74806 .412 m
.75963 .4098 L
s
.66556 .38019 m .65968 .4043 L .67865 .3875 L .645 .736 .915 r
F
.66556 .38019 m .6401 .39352 L .65968 .4043 L F
.43267 .90747 m .43014 .9095 L .43342 .90784 L .656 .814 .959 r
F
.43267 .90747 m .42864 .90878 L .43014 .9095 L F
.43199 .90427 m .42843 .90602 L .43246 .90472 L .657 .814 .959 r
F
.43199 .90427 m .42748 .90512 L .42843 .90602 L F
.42768 .90787 m .42461 .91008 L .42864 .90878 L .656 .814 .959 r
F
.42768 .90787 m .42317 .90872 L .42461 .91008 L F
0 g
.42461 .91008 m
.42686 .91116 L
s
.72897 .39428 m .75943 .40953 L .74584 .39102 L .645 .736 .915 r
F
.74584 .39102 m .75943 .40953 L .78197 .40096 L F
.59879 .68807 m .58974 .68067 L .58109 .68417 L .655 .81 .957 r
F
.60371 .68684 m .58974 .68067 L .59879 .68807 L F
.43164 .901 m .42732 .90236 L .4318 .90151 L .657 .813 .959 r
F
.43164 .901 m .42698 .90134 L .42732 .90236 L F
.44484 .9076 m .45029 .90675 L .44577 .90656 L .656 .814 .959 r
F
.44078 .90688 m .44484 .9076 L .44577 .90656 L F
.44004 .90736 m .44484 .9076 L .44078 .90688 L F
0 g
.43678 .90623 m
.43846 .90608 L
s
.43678 .90623 m
.43678 .90623 L
s
.43509 .90604 m
.43678 .90623 L
s
.4456 .89999 m .45025 .89966 L .44977 .89812 L .657 .813 .959 r
F
.45054 .9024 m .45032 .89965 L .44984 .89811 L .878 .643 .118 r
F
0 g
.44985 .90126 m
.45017 .90015 L
s
.73094 .54747 m .71582 .54996 L .71648 .55641 L .425 .273 .57 r
F
.73094 .54747 m .73025 .541 L .71582 .54996 L F
0 g
.70599 .56011 m
.71582 .54996 L
s
.44555 .90381 m .45054 .9024 L .44586 .90274 L .657 .814 .959 r
F
.44103 .90361 m .44555 .90381 L .44586 .90274 L F
.83583 .67539 m .84296 .66288 L .8439 .66822 L .317 .219 .583 r
F
.82006 .67182 m .83583 .67539 L .8439 .66822 L .654 .811 .959 r
F
.8126 .6761 m .83583 .67539 L .82006 .67182 L F
0 g
.82464 .68176 m
.83583 .67539 L
s
.66077 .67287 m .66007 .66754 L .65152 .6623 L .935 .646 .469 r
F
0 g
.66007 .66754 m
.66486 .67391 L
s
.63621 .66993 m .6396 .6587 L .62842 .66749 L .656 .808 .956 r
F
.63621 .66993 m .65129 .66241 L .6396 .6587 L F
0 g
.43846 .90608 m
.43952 .90576 L
s
.43402 .90569 m
.43509 .90604 L
s
.61404 .68617 m .61014 .67688 L .60892 .68619 L .655 .81 .957 r
F
.61404 .68617 m .62045 .67685 L .61014 .67688 L F
.47297 .54589 m .48923 .54571 L .48951 .55215 L .856 .597 .547 r
F
.47297 .54589 m .47273 .53943 L .48923 .54571 L F
.49206 .52899 m .48923 .54571 L .50309 .53325 L .655 .781 .941 r
F
.49206 .52899 m .47273 .53943 L .48923 .54571 L F
0 g
.48923 .54571 m
.49538 .5469 L
s
.4456 .89999 m .44977 .89812 L .44528 .89897 L .657 .813 .959 r
F
.44095 .90033 m .4456 .89999 L .44528 .89897 L F
.45029 .90675 m .45054 .9024 L .45076 .90515 L 0 0 .325 r
F
.44577 .90656 m .45029 .90675 L .45076 .90515 L .656 .814 .959 r
F
0 g
.44889 .90831 m
.45029 .90675 L
s
.56977 .55029 m .58658 .53681 L .58702 .54326 L .522 .338 .572 r
F
.55736 .53848 m .56977 .55029 L .58702 .54326 L .655 .782 .942 r
F
.54416 .5416 m .56977 .55029 L .55736 .53848 L F
0 g
.55013 .55488 m
.56977 .55029 L
s
.74778 .55685 m .73094 .54747 L .71648 .55641 L .653 .783 .943 r
F
.75978 .5522 m .73094 .54747 L .74778 .55685 L F
.8121 .54463 m .81035 .52843 L .80003 .54216 L .654 .782 .942 r
F
.8121 .54463 m .82856 .53223 L .81035 .52843 L F
.43671 .90617 m .43674 .90819 L .43795 .90803 L .656 .814 .959 r
F
.43671 .90617 m .43553 .90821 L .43674 .90819 L F
.43671 .90617 m .43795 .90803 L .43908 .90775 L F
.58049 .67881 m .55685 .67953 L .57374 .68306 L .656 .809 .957 r
F
.82376 .56154 m .83053 .54501 L .81391 .55741 L .653 .784 .944 r
F
.82376 .56154 m .84533 .5513 L .83053 .54501 L F
.42265 .90719 m .42297 .90597 L .42317 .90872 L .895 .658 .145 r
F
.42265 .90719 m .42245 .90444 L .42297 .90597 L F
.42714 .9041 m .42297 .90597 L .42748 .90512 L .657 .814 .959 r
F
.42714 .9041 m .42245 .90444 L .42297 .90597 L F
0 g
.42297 .90597 m
.4244 .90733 L
s
.44095 .90033 m .44528 .89897 L .44078 .89982 L .657 .813 .959 r
F
.3121 .54757 m .29747 .53581 L .28149 .54286 L .656 .781 .94 r
F
.32475 .54451 m .29747 .53581 L .3121 .54757 L F
.43671 .90617 m .4344 .90809 L .43553 .90821 L .656 .814 .959 r
F
.23303 .41015 m .22593 .43039 L .24044 .41377 L .642 .739 .919 r
F
.23303 .41015 m .21117 .42328 L .22593 .43039 L F
0 g
.43952 .90576 m
.44025 .90534 L
s
.35076 .67197 m .36548 .67768 L .37163 .67341 L .658 .806 .954 r
F
.34669 .67373 m .36548 .67768 L .35076 .67197 L F
.43671 .90617 m .43908 .90775 L .44004 .90736 L .656 .814 .959 r
F
0 g
.43329 .90525 m
.43402 .90569 L
s
.26629 .41715 m .29276 .4339 L .27421 .41554 L .642 .739 .919 r
F
.27421 .41554 m .29276 .4339 L .30604 .42826 L F
.60371 .68684 m .59965 .67818 L .58974 .68067 L .655 .81 .957 r
F
.60892 .68619 m .59965 .67818 L .60371 .68684 L F
.77217 .67219 m .76387 .68215 L .77592 .67342 L .654 .811 .959 r
F
.77217 .67219 m .75637 .67972 L .76387 .68215 L F
.4322 .90702 m .42864 .90878 L .43267 .90747 L .656 .814 .959 r
F
.4322 .90702 m .42768 .90787 L .42864 .90878 L F
.85555 .55961 m .84445 .54483 L .84533 .5513 L .952 .653 .432 r
F
0 g
.85555 .55961 m
.86055 .56932 L
s
.72735 .67029 m .731 .67135 L .7318 .67669 L .966 .666 .258 r
F
.72735 .67029 m .72655 .66493 L .731 .67135 L F
0 g
.731 .67135 m
.73687 .67509 L
s
.43671 .90617 m .43342 .90784 L .4344 .90809 L .656 .814 .959 r
F
.60892 .68619 m .61014 .67688 L .59965 .67818 L .655 .81 .957 r
F
.74663 .66121 m .73128 .67127 L .74952 .6655 L .655 .809 .957 r
F
.74663 .66121 m .72685 .66488 L .73128 .67127 L F
.43182 .90376 m .42748 .90512 L .43199 .90427 L .657 .814 .959 r
F
.43182 .90376 m .42714 .9041 L .42748 .90512 L F
.44103 .90361 m .44586 .90274 L .44118 .90308 L F
.43179 .90047 m .42698 .90134 L .43164 .901 L .657 .813 .959 r
F
.43671 .90617 m .44004 .90736 L .44078 .90688 L .656 .814 .959 r
F
.15918 .40769 m .17307 .41489 L .17176 .42292 L .964 .736 .544 r
F
.15918 .40769 m .16053 .39962 L .17307 .41489 L F
.19229 .396 m .17307 .41489 L .20051 .40626 L .642 .738 .918 r
F
.19229 .396 m .16053 .39962 L .17307 .41489 L F
0 g
.17307 .41489 m
.18029 .42025 L
s
.57432 .68841 m .55741 .6849 L .55083 .69198 L .655 .81 .957 r
F
0 g
.5482 .69921 m
.55083 .69198 L
s
.44025 .90534 m
.44068 .90484 L
s
.37081 .66271 m .39402 .65913 L .37455 .65792 L .659 .805 .953 r
F
.28103 .55568 m .26931 .55811 L .26921 .56458 L .336 .181 .518 r
F
.28103 .55568 m .28111 .54919 L .26931 .55811 L F
0 g
.26256 .56821 m
.26931 .55811 L
s
.43285 .90474 m
.43329 .90525 L
s
.45054 .9024 m .44984 .89811 L .45006 .90086 L .878 .643 .118 r
F
.44586 .90274 m .45054 .9024 L .45006 .90086 L .657 .814 .959 r
F
.45076 .90515 m .45054 .9024 L .45006 .90086 L .878 .643 .118 r
F
0 g
.45007 .904 m
.4504 .90289 L
s
.44078 .89982 m .44434 .89806 L .44031 .89937 L .657 .813 .959 r
F
0 g
.44028 .90198 m
.44033 .89961 L
s
.44078 .89982 m .44528 .89897 L .44434 .89806 L .657 .813 .959 r
F
0 g
.44034 .89936 m
.44191 .83467 L
s
.44577 .90656 m .45076 .90515 L .44608 .90549 L .656 .814 .959 r
F
.44124 .90636 m .44577 .90656 L .44608 .90549 L F
.44078 .90688 m .44577 .90656 L .44124 .90636 L F
.42728 .90027 m .42232 .90168 L .42698 .90134 L .657 .813 .959 r
F
.43179 .90047 m .42728 .90027 L .42698 .90134 L F
.67828 .4038 m .68259 .42789 L .69406 .40876 L .643 .737 .917 r
F
.67828 .4038 m .65913 .42059 L .68259 .42789 L F
0 g
.68259 .42789 m
.70824 .4313 L
s
.43671 .90617 m .43267 .90747 L .43342 .90784 L .656 .814 .959 r
F
.2778 .67726 m .28455 .67827 L .28475 .68362 L .974 .706 .46 r
F
.2778 .67726 m .2776 .67189 L .28455 .67827 L F
.29688 .66821 m .28455 .67827 L .30145 .67249 L .659 .806 .954 r
F
.29688 .66821 m .2776 .67189 L .28455 .67827 L F
0 g
.28455 .67827 m
.291 .68149 L
s
.34676 .42401 m .35683 .40182 L .35595 .40988 L 0 0 .309 r
F
.34587 .43207 m .34676 .42401 L .35595 .40988 L F
.317 .41237 m .34676 .42401 L .35595 .40988 L .642 .738 .918 r
F
.30703 .4202 m .34676 .42401 L .317 .41237 L F
0 g
.33733 .43125 m
.34676 .42401 L
s
.3012 .56501 m .28103 .55568 L .26921 .56458 L .654 .782 .942 r
F
0 g
.26245 .57465 m
.26921 .56458 L
s
.31191 .56037 m .28103 .55568 L .3012 .56501 L .654 .782 .942 r
F
.44586 .90274 m .45006 .90086 L .44554 .90171 L .657 .814 .959 r
F
.44118 .90308 m .44586 .90274 L .44554 .90171 L F
.46719 .42015 m .43137 .4287 L .46481 .43045 L .642 .738 .918 r
F
.46719 .42015 m .43463 .41318 L .43137 .4287 L F
0 g
.43137 .4287 m
.43494 .44429 L
s
.73453 .43061 m .75974 .41782 L .75985 .42587 L .596 .376 .551 r
F
.72909 .4106 m .73453 .43061 L .75985 .42587 L .643 .737 .917 r
F
.71136 .41108 m .73453 .43061 L .72909 .4106 L F
0 g
.70824 .4313 m
.73453 .43061 L
s
.42728 .90027 m .42276 .90008 L .42232 .90168 L .657 .813 .959 r
F
.42289 .90283 m .42225 .90168 L .42245 .90444 L 0 0 .304 r
F
.42289 .90283 m .42269 .90007 L .42225 .90168 L F
.49955 .42708 m .46481 .43045 L .49826 .43221 L .642 .738 .918 r
F
.49955 .42708 m .46719 .42015 L .46481 .43045 L F
.43671 .90617 m .44078 .90688 L .44124 .90636 L .656 .814 .959 r
F
.36568 .55266 m .35867 .53646 L .35255 .55018 L .655 .781 .941 r
F
.36568 .55266 m .37852 .54025 L .35867 .53646 L F
.42734 .90685 m .42317 .90872 L .42768 .90787 L .656 .814 .959 r
F
.42734 .90685 m .42265 .90719 L .42317 .90872 L F
0 g
.42317 .90872 m
.42461 .91008 L
s
.43224 .89995 m .42728 .90027 L .43179 .90047 L .657 .813 .959 r
F
.44118 .90308 m .44554 .90171 L .44102 .90256 L .657 .814 .959 r
F
0 g
.44068 .90484 m
.44077 .90424 L
s
.44528 .89897 m .44837 .89676 L .44434 .89806 L .657 .813 .959 r
F
.44528 .89897 m .44977 .89812 L .44837 .89676 L F
.56515 .43572 m .59723 .42698 L .56436 .43048 L .642 .738 .918 r
F
.56515 .43572 m .59861 .43748 L .59723 .42698 L F
0 g
.43275 .90414 m
.43285 .90474 L
s
.59861 .43748 m .63031 .42345 L .59723 .42698 L .642 .738 .918 r
F
.59861 .43748 m .63206 .43924 L .63031 .42345 L F
.58658 .53681 m .58614 .53039 L .59982 .5213 L .402 .249 .557 r
F
0 g
.57505 .53495 m
.58614 .53039 L
s
.44031 .89937 m .44285 .89733 L .43957 .899 L .657 .813 .959 r
F
.44031 .89937 m .44434 .89806 L .44285 .89733 L F
.63206 .43924 m .63051 .41535 L .63031 .42345 L .847 .68 .143 r
F
0 g
.627 .45437 m
.63206 .43924 L
s
.43671 .90617 m .4322 .90702 L .43267 .90747 L .656 .814 .959 r
F
.5679 .5207 m .58587 .53025 L .59948 .5212 L .656 .78 .94 r
F
.55645 .52546 m .58587 .53025 L .5679 .5207 L F
.43203 .90651 m .42768 .90787 L .4322 .90702 L .656 .814 .959 r
F
.43203 .90651 m .42734 .90685 L .42768 .90787 L F
.44124 .90636 m .44608 .90549 L .4414 .90583 L F
.43671 .90617 m .44124 .90636 L .4414 .90583 L F
.43197 .90322 m .42714 .9041 L .43182 .90376 L .657 .814 .959 r
F
.75915 .54586 m .74847 .53407 L .7305 .54114 L .654 .782 .942 r
F
.77257 .54279 m .74847 .53407 L .75915 .54586 L F
.45006 .90086 m .44984 .89811 L .44843 .89674 L .979 .694 .406 r
F
0 g
.44984 .89811 m
.45032 .89965 L
s
.66077 .67287 m .65152 .6623 L .65221 .66764 L .935 .646 .469 r
F
.66147 .67821 m .66077 .67287 L .65221 .66764 L F
0 g
.66077 .67287 m
.66556 .67922 L
s
.80043 .67038 m .8126 .6761 L .82006 .67182 L .654 .811 .959 r
F
.79588 .67214 m .8126 .6761 L .80043 .67038 L F
.43224 .89995 m .42819 .89923 L .42728 .90027 L .657 .813 .959 r
F
.43298 .89948 m .42819 .89923 L .43224 .89995 L F
.35244 .54387 m .33746 .52921 L .33853 .54324 L .656 .781 .94 r
F
.35244 .54387 m .35852 .53018 L .33746 .52921 L F
.63703 .67518 m .64045 .66393 L .62919 .67274 L .656 .809 .957 r
F
.63703 .67518 m .65221 .66764 L .64045 .66393 L F
.45076 .90515 m .45006 .90086 L .45028 .90361 L .878 .643 .118 r
F
.44608 .90549 m .45076 .90515 L .45028 .90361 L .656 .814 .959 r
F
0 g
.45029 .90675 m
.45076 .90515 L
s
.44102 .90256 m .4446 .9008 L .44055 .90211 L .657 .814 .959 r
F
.44102 .90256 m .44554 .90171 L .4446 .9008 L F
.42744 .90302 m .42245 .90444 L .42714 .9041 L F
.43197 .90322 m .42744 .90302 L .42714 .9041 L F
0 g
.44024 .90347 m
.44077 .90424 L
s
.43957 .899 m .44092 .89683 L .4386 .89875 L .657 .813 .959 r
F
.43957 .899 m .44285 .89733 L .44092 .89683 L F
0 g
.43275 .90414 m
.43327 .90338 L
s
.39467 .66448 m .39432 .65915 L .39608 .65164 L 0 0 .283 r
F
0 g
.38944 .66528 m
.39432 .65915 L
s
.58109 .68417 m .55741 .6849 L .57432 .68841 L .655 .81 .957 r
F
.42819 .89923 m .42276 .90008 L .42728 .90027 L .657 .813 .959 r
F
.44608 .90549 m .45028 .90361 L .44576 .90446 L .656 .814 .959 r
F
.4414 .90583 m .44608 .90549 L .44576 .90446 L F
.43671 .90617 m .43203 .90651 L .4322 .90702 L F
.37455 .65792 m .39402 .65913 L .39578 .65166 L .659 .805 .953 r
F
.4231 .90558 m .42245 .90444 L .42265 .90719 L 0 0 .304 r
F
.42744 .90302 m .42289 .90283 L .42245 .90444 L .657 .814 .959 r
F
.4231 .90558 m .42289 .90283 L .42245 .90444 L 0 0 .304 r
F
.50356 .41433 m .46779 .41209 L .50007 .41903 L .643 .737 .917 r
F
.73162 .55396 m .71648 .55641 L .71714 .56288 L .425 .273 .57 r
F
.73162 .55396 m .73094 .54747 L .71648 .55641 L F
0 g
.70663 .56653 m
.71648 .55641 L
s
.22828 .39753 m .21239 .41523 L .23421 .40207 L .642 .738 .918 r
F
.22828 .39753 m .20051 .40626 L .21239 .41523 L F
.43298 .89948 m .42966 .89829 L .42819 .89923 L .657 .813 .959 r
F
.43394 .89909 m .42966 .89829 L .43298 .89948 L F
.4414 .90583 m .44576 .90446 L .44124 .90532 L .656 .814 .959 r
F
.43671 .90617 m .4414 .90583 L .44124 .90532 L F
.43243 .9027 m .42744 .90302 L .43197 .90322 L .657 .814 .959 r
F
.44554 .90171 m .44865 .89949 L .4446 .9008 L F
.44554 .90171 m .45006 .90086 L .44865 .89949 L F
.56473 .42242 m .59162 .40873 L .5617 .41738 L .643 .737 .917 r
F
.56473 .42242 m .59752 .4189 L .59162 .40873 L F
.58003 .67352 m .56659 .66781 L .55653 .67423 L .656 .808 .956 r
F
.58861 .67003 m .56659 .66781 L .58003 .67352 L F
.4386 .89875 m .43866 .89658 L .43747 .89863 L .657 .813 .959 r
F
.4386 .89875 m .44092 .89683 L .43866 .89658 L F
.28193 .40458 m .30703 .4202 L .317 .41237 L .642 .738 .918 r
F
.27528 .40747 m .30703 .4202 L .28193 .40458 L F
.49234 .53548 m .48951 .55215 L .50339 .53973 L .655 .782 .942 r
F
.49234 .53548 m .47297 .54589 L .48951 .55215 L F
0 g
.48951 .55215 m
.5087 .55584 L
s
.72815 .67566 m .7318 .67669 L .7326 .68204 L .966 .666 .258 r
F
.72815 .67566 m .72735 .67029 L .7318 .67669 L F
.74726 .66661 m .7318 .67669 L .75016 .6709 L .655 .81 .958 r
F
.74726 .66661 m .72735 .67029 L .7318 .67669 L F
0 g
.7318 .67669 m
.7377 .68044 L
s
.44434 .89806 m .44614 .89566 L .44285 .89733 L .657 .813 .959 r
F
.44434 .89806 m .44837 .89676 L .44614 .89566 L F
.74849 .56332 m .73162 .55396 L .71714 .56288 L .653 .784 .944 r
F
0 g
.70727 .57297 m
.71714 .56288 L
s
.76051 .55867 m .73162 .55396 L .74849 .56332 L .653 .784 .944 r
F
.44055 .90211 m .4431 .90007 L .4398 .90174 L .657 .814 .959 r
F
.44055 .90211 m .4446 .9008 L .4431 .90007 L F
.43671 .90617 m .43218 .90597 L .43203 .90651 L .656 .814 .959 r
F
.43671 .90617 m .43264 .90545 L .43218 .90597 L F
.43671 .90617 m .43338 .90498 L .43264 .90545 L F
.43671 .90617 m .43435 .90459 L .43338 .90498 L F
.43671 .90617 m .43548 .9043 L .43435 .90459 L F
.43671 .90617 m .43669 .90414 L .43548 .9043 L F
.43671 .90617 m .43791 .90412 L .43669 .90414 L F
.43671 .90617 m .43904 .90425 L .43791 .90412 L F
.43671 .90617 m .44001 .9045 L .43904 .90425 L F
.43671 .90617 m .44076 .90486 L .44001 .9045 L F
.43671 .90617 m .44124 .90532 L .44076 .90486 L F
.37131 .66807 m .39467 .66448 L .37507 .66327 L .659 .806 .954 r
F
.63936 .4098 m .65927 .41255 L .65913 .42059 L .866 .6 .536 r
F
.63936 .4098 m .63954 .40174 L .65927 .41255 L F
.66518 .38838 m .65927 .41255 L .67837 .39571 L .644 .736 .916 r
F
.66518 .38838 m .63954 .40174 L .65927 .41255 L F
0 g
.65927 .41255 m
.66593 .41463 L
s
.43394 .89909 m .43158 .8975 L .42966 .89829 L .657 .813 .959 r
F
.43506 .8988 m .43158 .8975 L .43394 .89909 L F
.81308 .55095 m .81133 .53471 L .80094 .54847 L .653 .783 .943 r
F
.81308 .55095 m .82967 .53851 L .81133 .53471 L F
.32475 .54451 m .31659 .53113 L .29747 .53581 L .656 .781 .94 r
F
.33853 .54324 m .31659 .53113 L .32475 .54451 L F
.43747 .89863 m .43624 .89662 L .43627 .89865 L .657 .813 .959 r
F
.43747 .89863 m .43866 .89658 L .43624 .89662 L F
.43218 .90597 m .42734 .90685 L .43203 .90651 L .656 .814 .959 r
F
.45006 .90086 m .44843 .89674 L .44865 .89949 L .979 .694 .406 r
F
.45028 .90361 m .45006 .90086 L .44865 .89949 L F
0 g
.45006 .90086 m
.45054 .9024 L
s
.43907 .90286 m
.44024 .90347 L
s
.44024 .90347 m
.44024 .90347 L
s
.31872 .67204 m .30854 .6813 L .32214 .67379 L .658 .806 .954 r
F
.31872 .67204 m .30168 .67785 L .30854 .6813 L F
.31193 .5539 m .2972 .54211 L .28111 .54919 L .655 .781 .941 r
F
.32467 .55083 m .2972 .54211 L .31193 .5539 L F
.43506 .8988 m .43382 .89693 L .43158 .8975 L .657 .813 .959 r
F
.43627 .89865 m .43382 .89693 L .43506 .8988 L F
.75974 .41782 m .78228 .4012 L .78245 .40924 L .51 .308 .542 r
F
.75985 .42587 m .75974 .41782 L .78245 .40924 L F
.74606 .39926 m .75974 .41782 L .78245 .40924 L .644 .736 .916 r
F
.72906 .40252 m .75974 .41782 L .74606 .39926 L F
0 g
.74806 .42002 m
.75974 .41782 L
s
.43327 .90338 m
.43327 .90338 L
s
.43327 .90338 m
.43442 .9028 L
s
.43627 .89865 m .43624 .89662 L .43382 .89693 L .657 .813 .959 r
F
.50421 .40636 m .47551 .39466 L .46871 .40414 L .644 .737 .916 r
F
.50965 .40244 m .47551 .39466 L .50421 .40636 L F
.43243 .9027 m .42835 .90198 L .42744 .90302 L .657 .814 .959 r
F
.43317 .90222 m .42835 .90198 L .43243 .9027 L F
.2971 .67358 m .28475 .68362 L .30168 .67785 L .658 .806 .954 r
F
.2971 .67358 m .2778 .67726 L .28475 .68362 L F
0 g
.28475 .68362 m
.29507 .68874 L
s
.42819 .89923 m .42412 .89851 L .42276 .90008 L .657 .813 .959 r
F
.42427 .90126 m .42269 .90007 L .42289 .90283 L .167 .079 .503 r
F
.42427 .90126 m .42406 .8985 L .42269 .90007 L F
0 g
.42225 .90168 m
.42269 .90007 L
s
.58787 .7914 m .59756 .78918 L .59737 .79374 L .789 .553 .58 r
F
.58787 .7914 m .58807 .78685 L .59756 .78918 L F
0 g
.59756 .78918 m
.60058 .78954 L
s
.44124 .90532 m .44482 .90355 L .44076 .90486 L .656 .814 .959 r
F
.44124 .90532 m .44576 .90446 L .44482 .90355 L F
.42764 .90578 m .42265 .90719 L .42734 .90685 L F
.43218 .90597 m .42764 .90578 L .42734 .90685 L F
.56192 .40939 m .58162 .39169 L .55689 .40492 L .644 .737 .916 r
F
.56192 .40939 m .59162 .40075 L .58162 .39169 L F
.4398 .90174 m .44115 .89956 L .43883 .90149 L .657 .814 .959 r
F
.4398 .90174 m .4431 .90007 L .44115 .89956 L F
.47551 .39466 m .43648 .39719 L .46871 .40414 L .644 .737 .916 r
F
.42835 .90198 m .42289 .90283 L .42744 .90302 L .657 .814 .959 r
F
.42764 .90578 m .4231 .90558 L .42265 .90719 L .656 .814 .959 r
F
0 g
.42265 .90719 m
.42317 .90872 L
s
.42966 .89829 m .42412 .89851 L .42819 .89923 L .657 .813 .959 r
F
.33853 .54324 m .33746 .52921 L .31659 .53113 L .656 .781 .94 r
F
.80003 .54216 m .78991 .52746 L .78653 .54152 L .654 .782 .942 r
F
.80003 .54216 m .81035 .52843 L .78991 .52746 L F
.59747 .41089 m .62168 .39202 L .59162 .40075 L .644 .737 .916 r
F
.59747 .41089 m .63022 .40735 L .62168 .39202 L F
.43317 .90222 m .42983 .90103 L .42835 .90198 L .657 .814 .959 r
F
.43414 .90183 m .42983 .90103 L .43317 .90222 L F
.43264 .90545 m .42764 .90578 L .43218 .90597 L .656 .814 .959 r
F
.44576 .90446 m .44888 .90224 L .44482 .90355 L F
.44576 .90446 m .45028 .90361 L .44888 .90224 L F
0 g
.43791 .90258 m
.43907 .90286 L
s
.39557 .54655 m .39545 .5401 L .37843 .53378 L .852 .597 .553 r
F
0 g
.39545 .5401 m
.40849 .54845 L
s
.43442 .9028 m
.43558 .90255 L
s
.43883 .90149 m .43889 .89932 L .43769 .90137 L .657 .814 .959 r
F
.43883 .90149 m .44115 .89956 L .43889 .89932 L F
.44865 .89949 m .44843 .89674 L .44619 .89563 L .914 .637 .503 r
F
0 g
.44843 .89674 m
.44984 .89811 L
s
.84296 .66288 m .84201 .65755 L .84635 .65002 L .056 .042 .523 r
F
0 g
.83466 .66413 m
.84201 .65755 L
s
.4446 .9008 m .44641 .89838 L .4431 .90007 L .657 .814 .959 r
F
.4446 .9008 m .44865 .89949 L .44641 .89838 L F
.44285 .89733 m .44324 .8949 L .44092 .89683 L .657 .813 .959 r
F
.44285 .89733 m .44614 .89566 L .44324 .8949 L F
.44076 .90486 m .44332 .90282 L .44001 .9045 L .656 .814 .959 r
F
.44076 .90486 m .44482 .90355 L .44332 .90282 L F
.82337 .65631 m .84173 .65753 L .84605 .65004 L .655 .809 .957 r
F
.36575 .55912 m .35873 .54297 L .35259 .55665 L .654 .782 .942 r
F
.36575 .55912 m .37861 .54674 L .35873 .54297 L F
.62842 .66749 m .62552 .65677 L .61908 .66623 L .656 .808 .956 r
F
.62842 .66749 m .6396 .6587 L .62552 .65677 L F
.66147 .67821 m .65221 .66764 L .65291 .67301 L .935 .646 .469 r
F
0 g
.66147 .67821 m
.66627 .68454 L
s
.43414 .90183 m .43176 .90024 L .42983 .90103 L .657 .814 .959 r
F
.43526 .90155 m .43176 .90024 L .43414 .90183 L F
0 g
.43675 .90249 m
.43791 .90258 L
s
.43558 .90255 m
.43675 .90249 L
s
.43769 .90137 m .43645 .89935 L .43648 .90139 L .657 .814 .959 r
F
.43769 .90137 m .43889 .89932 L .43645 .89935 L F
.45028 .90361 m .44865 .89949 L .44888 .90224 L .979 .694 .406 r
F
0 g
.45028 .90361 m
.45076 .90515 L
s
.6377 .68053 m .64113 .66931 L .62986 .6781 L .655 .81 .957 r
F
.6377 .68053 m .65291 .67301 L .64113 .66931 L F
.43526 .90155 m .43402 .89967 L .43176 .90024 L .657 .814 .959 r
F
.43648 .90139 m .43402 .89967 L .43526 .90155 L F
.58658 .53681 m .59982 .5213 L .60028 .52775 L .402 .249 .557 r
F
.58702 .54326 m .58658 .53681 L .60028 .52775 L F
.56849 .52725 m .58658 .53681 L .60028 .52775 L .655 .781 .941 r
F
.55697 .53202 m .58658 .53681 L .56849 .52725 L F
0 g
.5754 .54139 m
.58658 .53681 L
s
.43648 .90139 m .43645 .89935 L .43402 .89967 L .657 .814 .959 r
F
.43264 .90545 m .42856 .90473 L .42764 .90578 L .656 .814 .959 r
F
.43338 .90498 m .42856 .90473 L .43264 .90545 L F
.39467 .66448 m .39608 .65164 L .39643 .65699 L 0 0 .283 r
F
.39502 .66982 m .39467 .66448 L .39643 .65699 L F
.37507 .66327 m .39467 .66448 L .39643 .65699 L .659 .806 .954 r
F
0 g
.38976 .67063 m
.39467 .66448 L
s
.42447 .90401 m .42289 .90283 L .4231 .90558 L .167 .079 .503 r
F
.42835 .90198 m .42427 .90126 L .42289 .90283 L .657 .814 .959 r
F
.42447 .90401 m .42427 .90126 L .42289 .90283 L .167 .079 .503 r
F
0 g
.42245 .90444 m
.42289 .90283 L
s
.81915 .66647 m .84296 .66288 L .82448 .66166 L .655 .81 .958 r
F
.71143 .27818 m .71724 .34129 L .71549 .34151 L .638 .394 .533 r
F
.71143 .27818 m .71314 .27796 L .71724 .34129 L F
.70978 .27789 m .71143 .27818 L .71549 .34151 L .753 .483 .523 r
F
0 g
.71143 .27818 m
.71143 .27818 L
s
.44001 .9045 m .44137 .90232 L .43904 .90425 L .656 .814 .959 r
F
.44001 .9045 m .44332 .90282 L .44137 .90232 L F
.77257 .54279 m .76877 .52939 L .74847 .53407 L .654 .782 .942 r
F
.78653 .54152 m .76877 .52939 L .77257 .54279 L F
.42966 .89829 m .42632 .89709 L .42412 .89851 L .657 .813 .959 r
F
.43158 .8975 m .42632 .89709 L .42966 .89829 L F
.19101 .40408 m .17176 .42292 L .19926 .41432 L .642 .739 .919 r
F
.19101 .40408 m .15918 .40769 L .17176 .42292 L F
0 g
.17176 .42292 m
.18969 .43618 L
s
.42856 .90473 m .4231 .90558 L .42764 .90578 L .656 .814 .959 r
F
.71314 .27796 m .7184 .34082 L .71724 .34129 L .519 .305 .529 r
F
.71314 .27796 m .71428 .27748 L .7184 .34082 L F
0 g
.71143 .27818 m
.71314 .27796 L
s
.76949 .67044 m .75637 .67972 L .77217 .67219 L .654 .811 .959 r
F
.76949 .67044 m .75098 .67626 L .75637 .67972 L F
.75978 .5522 m .74902 .54038 L .73094 .54747 L .653 .783 .943 r
F
.77329 .54911 m .74902 .54038 L .75978 .5522 L F
.70978 .27789 m .71549 .34151 L .7138 .34123 L .753 .483 .523 r
F
.70877 .27738 m .70978 .27789 L .7138 .34123 L .857 .566 .495 r
F
0 g
.70978 .27789 m
.71143 .27818 L
s
.42983 .90103 m .42427 .90126 L .42835 .90198 L .657 .814 .959 r
F
.58049 .67881 m .56697 .67309 L .55685 .67953 L .656 .809 .957 r
F
.58912 .67531 m .56697 .67309 L .58049 .67881 L F
.74808 .67198 m .7326 .68204 L .75098 .67626 L .654 .811 .959 r
F
.74808 .67198 m .72815 .67566 L .7326 .68204 L F
0 g
.7326 .68204 m
.74074 .68718 L
s
.43338 .90498 m .43004 .90379 L .42856 .90473 L .656 .814 .959 r
F
.43435 .90459 m .43004 .90379 L .43338 .90498 L F
.56697 .67309 m .55628 .67417 L .55685 .67953 L .416 .272 .576 r
F
.56697 .67309 m .56638 .66772 L .55628 .67417 L F
0 g
.54972 .68129 m
.55628 .67417 L
s
.44092 .89683 m .43985 .89453 L .43866 .89658 L .657 .813 .959 r
F
.44092 .89683 m .44324 .8949 L .43985 .89453 L F
.35255 .55018 m .33746 .53549 L .33854 .54956 L .655 .781 .941 r
F
.35255 .55018 m .35867 .53646 L .33746 .53549 L F
.37163 .67341 m .39502 .66982 L .3754 .66862 L .658 .806 .954 r
F
.35383 .66982 m .37163 .67341 L .3754 .66862 L F
.35076 .67197 m .37163 .67341 L .35383 .66982 L F
.43904 .90425 m .4391 .90207 L .43791 .90412 L .656 .814 .959 r
F
.43904 .90425 m .44137 .90232 L .4391 .90207 L F
.34587 .43207 m .35595 .40988 L .35508 .41797 L 0 0 .309 r
F
.31603 .42045 m .34587 .43207 L .35508 .41797 L .642 .739 .919 r
F
.30604 .42826 m .34587 .43207 L .31603 .42045 L F
0 g
.33142 .44311 m
.34587 .43207 L
s
.44865 .89949 m .44619 .89563 L .44641 .89838 L .914 .637 .503 r
F
.44888 .90224 m .44865 .89949 L .44641 .89838 L F
0 g
.44865 .89949 m
.45006 .90086 L
s
.71428 .27748 m .71924 .34021 L .7184 .34082 L .379 .203 .512 r
F
.71428 .27748 m .71509 .27687 L .71924 .34021 L F
0 g
.71314 .27796 m
.71428 .27748 L
s
.44482 .90355 m .44663 .90114 L .44332 .90282 L .656 .814 .959 r
F
.44482 .90355 m .44888 .90224 L .44663 .90114 L F
.58768 .79597 m .59737 .79374 L .59719 .7983 L .789 .553 .58 r
F
.58768 .79597 m .58787 .7914 L .59737 .79374 L F
.5952 .78671 m .59737 .79374 L .60155 .78828 L .596 .768 .961 r
F
.5952 .78671 m .58787 .7914 L .59737 .79374 L F
0 g
.59737 .79374 m
.60042 .7941 L
s
.4431 .90007 m .44349 .89762 L .44115 .89956 L .657 .814 .959 r
F
.4431 .90007 m .44641 .89838 L .44349 .89762 L F
.42648 .89983 m .42406 .8985 L .42427 .90126 L .4 .248 .557 r
F
.42648 .89983 m .42627 .89707 L .42406 .8985 L F
0 g
.42269 .90007 m
.42406 .8985 L
s
.70877 .27738 m .7138 .34123 L .71278 .34072 L .857 .566 .495 r
F
.70813 .27674 m .70877 .27738 L .71278 .34072 L .947 .644 .431 r
F
0 g
.70877 .27738 m
.70978 .27789 L
s
.61803 .79954 m .61819 .79498 L .62816 .79381 L .609 .4 .573 r
F
0 g
.61593 .79497 m
.61819 .79498 L
s
.78653 .54152 m .78991 .52746 L .76877 .52939 L .654 .782 .942 r
F
.43435 .90459 m .43197 .903 L .43004 .90379 L .656 .814 .959 r
F
.43548 .9043 m .43197 .903 L .43435 .90459 L F
.43791 .90412 m .43666 .90211 L .43669 .90414 L F
.43791 .90412 m .4391 .90207 L .43666 .90211 L F
.43158 .8975 m .42921 .89591 L .42632 .89709 L .657 .813 .959 r
F
.43382 .89693 m .42921 .89591 L .43158 .8975 L F
.84445 .54483 m .84357 .53838 L .82881 .53204 L .872 .594 .515 r
F
0 g
.84357 .53838 m
.85377 .54674 L
s
.45998 .53095 m .47248 .53299 L .47273 .53943 L .926 .656 .509 r
F
.45998 .53095 m .45975 .52448 L .47248 .53299 L F
0 g
.47248 .53299 m
.47961 .53571 L
s
.43548 .9043 m .43423 .90243 L .43197 .903 L .656 .814 .959 r
F
.43669 .90414 m .43423 .90243 L .43548 .9043 L F
.43669 .90414 m .43666 .90211 L .43423 .90243 L F
.43866 .89658 m .43621 .89458 L .43624 .89662 L .657 .813 .959 r
F
.43866 .89658 m .43985 .89453 L .43621 .89458 L F
.48357 .5167 m .47276 .53283 L .49197 .52242 L .656 .78 .94 r
F
.48357 .5167 m .4601 .52436 L .47276 .53283 L F
.42856 .90473 m .42447 .90401 L .4231 .90558 L .656 .814 .959 r
F
0 g
.42265 .90719 m
.4231 .90558 L
s
.71509 .27687 m .71978 .33948 L .71924 .34021 L .157 .044 .463 r
F
.71509 .27687 m .71563 .27613 L .71978 .33948 L F
0 g
.71428 .27748 m
.71509 .27687 L
s
.53285 .51816 m .53069 .52973 L .54336 .52856 L .656 .78 .94 r
F
.53337 .51537 m .54336 .52856 L .53731 .51501 L F
.53031 .51565 m .53285 .51816 L .53337 .51537 L F
.53285 .51816 m .54336 .52856 L .53337 .51537 L F
.5357 .46995 m .53583 .46915 L .53594 .50158 L 0 0 .15 r
F
.53031 .51565 m .52948 .52984 L .53069 .52973 L .656 .78 .94 r
F
.53031 .51565 m .53069 .52973 L .53285 .51816 L F
.53065 .5222 m .52982 .53642 L .54379 .53514 L .655 .781 .941 r
F
.53065 .5222 m .54379 .53514 L .53771 .52155 L F
.53101 .5287 m .53017 .54287 L .54416 .5416 L .655 .782 .942 r
F
.53101 .5287 m .54416 .5416 L .53807 .52805 L F
.52997 .47156 m .53165 .47181 L .53172 .50408 L .751 .491 .539 r
F
.53316 .50568 m .53031 .51565 L .53731 .51501 L .656 .78 .94 r
F
.5327 .50467 m .53222 .50687 L .53316 .50568 L F
.53222 .50687 m .53031 .51565 L .53316 .50568 L F
.53336 .47161 m .53398 .50364 L .53344 .50384 L .517 .303 .528 r
F
.52997 .47156 m .53172 .50408 L .53083 .50399 L .751 .491 .539 r
F
.53165 .47181 m .53254 .50396 L .53172 .50408 L .641 .401 .54 r
F
.53447 .47118 m .53523 .47062 L .53533 .5029 L .358 .18 .498 r
F
.53431 .50421 m .53731 .51501 L .54251 .51376 L .656 .78 .94 r
F
.53431 .50421 m .54251 .51376 L .54063 .51028 L F
.53411 .50446 m .53731 .51501 L .53431 .50421 L F
.53389 .50387 m .53731 .51501 L .53393 .50385 L F
.53344 .50384 m .53731 .51501 L .53386 .50378 L F
.5324 .50398 m .53249 .5042 L .53344 .50384 L F
.53249 .5042 m .53731 .51501 L .53344 .50384 L F
.53336 .47161 m .53447 .47118 L .53456 .50342 L .517 .303 .528 r
F
.53393 .50385 m .53411 .50446 L .53431 .50421 L .656 .78 .94 r
F
.53336 .47161 m .53456 .50342 L .53398 .50364 L .517 .303 .528 r
F
.53165 .47181 m .53336 .47161 L .53344 .50384 L .641 .401 .54 r
F
.53165 .47181 m .53344 .50384 L .53254 .50396 L F
.53447 .47118 m .53493 .50317 L .53456 .50342 L .358 .18 .498 r
F
.53756 .50459 m .54391 .51343 L .54966 .51102 L .656 .78 .94 r
F
.53115 .50118 m .54063 .51028 L .53756 .50459 L F
.54063 .51028 m .54391 .51343 L .53756 .50459 L F
.53523 .47062 m .5357 .46995 L .53581 .50229 L .08 0 .418 r
F
.53523 .47062 m .53581 .50229 L .53556 .50261 L F
.53523 .47062 m .53556 .50261 L .53533 .5029 L F
.5357 .46995 m .53594 .50158 L .53587 .50195 L 0 0 .15 r
F
.5357 .46995 m .53587 .50195 L .53581 .50229 L F
.53583 .46915 m .53535 .46811 L .53546 .50069 L .983 .725 .332 r
F
.53731 .51501 m .54336 .52856 L .55645 .52546 L .656 .78 .94 r
F
.53731 .51501 m .55645 .52546 L .54391 .51343 L F
.53526 .51149 m .53771 .52155 L .54278 .52034 L .655 .781 .941 r
F
.53432 .51039 m .53503 .51273 L .53526 .51149 L F
.53503 .51273 m .53771 .52155 L .53526 .51149 L F
.53447 .47118 m .53533 .5029 L .53493 .50317 L .358 .18 .498 r
F
.53115 .50118 m .54966 .51102 L .5512 .50996 L .656 .78 .94 r
F
.54138 .50418 m .5512 .50996 L .55418 .50793 L F
.53115 .50118 m .5512 .50996 L .54138 .50418 L F
.53529 .51132 m .54278 .52034 L .54068 .51646 L .655 .781 .941 r
F
.53432 .51039 m .53526 .51149 L .53529 .51132 L F
.53526 .51149 m .54278 .52034 L .53529 .51132 L F
.53329 .51169 m .53465 .51473 L .53432 .51039 L F
.53465 .51473 m .53771 .52155 L .53503 .51273 L F
.53465 .51473 m .53503 .51273 L .53432 .51039 L F
.53764 .50198 m .55418 .50793 L .55715 .50437 L .656 .78 .94 r
F
.53115 .50118 m .54138 .50418 L .53764 .50198 L F
.54138 .50418 m .55418 .50793 L .53764 .50198 L F
.53535 .46811 m .53422 .4673 L .53431 .50002 L .911 .629 .497 r
F
.53398 .50364 m .53456 .50342 L .53458 .50959 L .517 .303 .528 r
F
.53386 .50995 m .53329 .51169 L .53432 .51039 L .655 .781 .941 r
F
.53379 .50988 m .53377 .50996 L .53386 .50995 L F
.53377 .50996 m .53329 .51169 L .53386 .50995 L F
.53236 .5049 m .53031 .51565 L .5327 .50467 L .656 .78 .94 r
F
.53254 .50396 m .53344 .50384 L .53346 .51001 L .641 .401 .54 r
F
.53254 .50396 m .53346 .51001 L .53271 .51011 L F
.53246 .50421 m .53031 .51565 L .53249 .5042 L .656 .78 .94 r
F
.53267 .5103 m .53329 .51169 L .53377 .50996 L .655 .781 .941 r
F
.53346 .51001 m .53377 .50996 L .53379 .50988 L F
.53267 .5103 m .53377 .50996 L .53346 .51001 L F
.53249 .5042 m .53236 .5049 L .5327 .50467 L .656 .78 .94 r
F
.53247 .50415 m .53246 .50421 L .53249 .5042 L F
.5324 .50398 m .53237 .50414 L .53247 .50415 L F
.53237 .50414 m .53031 .51565 L .53247 .50415 L F
.53098 .50418 m .53031 .51565 L .53237 .50414 L F
.53172 .50408 m .53237 .50414 L .5324 .50398 L F
.53098 .50418 m .53237 .50414 L .53172 .50408 L F
.52336 .51532 m .52948 .52984 L .52968 .5265 L F
.52883 .51558 m .52968 .5265 L .53031 .51565 L F
.52336 .51532 m .52968 .5265 L .52883 .51558 L F
.52774 .46901 m .52779 .46982 L .52781 .50246 L .781 .623 .061 r
F
.52336 .51532 m .51571 .52919 L .52948 .52984 L .656 .78 .94 r
F
.52366 .52187 m .52982 .53642 L .52989 .53524 L .655 .781 .941 r
F
.52887 .52212 m .52989 .53524 L .53065 .5222 L F
.52366 .52187 m .52989 .53524 L .52887 .52212 L F
.52366 .52187 m .51595 .53577 L .52982 .53642 L F
.524 .52837 m .53017 .54287 L .53101 .5287 L .655 .782 .942 r
F
.524 .52837 m .51628 .54224 L .53017 .54287 L F
.52997 .47156 m .53083 .50399 L .53001 .50391 L .751 .491 .539 r
F
.52891 .47109 m .52997 .47156 L .53001 .50391 L .845 .571 .524 r
F
.52779 .46982 m .5282 .4705 L .52822 .50305 L .988 .719 .384 r
F
.53082 .50679 m .52814 .50665 L .53031 .51565 L .656 .78 .94 r
F
.52994 .50552 m .52814 .50665 L .53082 .50679 L F
.53053 .50462 m .52814 .50665 L .53093 .5049 L F
.5297 .50381 m .5296 .50399 L .53097 .50425 L F
.5296 .50399 m .52814 .50665 L .53053 .50462 L F
.5296 .50399 m .53053 .50462 L .53097 .50425 L F
.52814 .50665 m .52336 .51532 L .52883 .51558 L F
.52814 .50665 m .52883 .51558 L .53031 .51565 L F
.5282 .4705 m .52891 .47109 L .52894 .50354 L .929 .648 .487 r
F
.5282 .4705 m .52894 .50354 L .52857 .50329 L F
.52891 .47109 m .53001 .50391 L .52945 .50372 L .845 .571 .524 r
F
.52928 .50457 m .52284 .5095 L .52336 .51532 L .656 .78 .94 r
F
.52284 .5095 m .51692 .51403 L .51962 .51457 L F
.52284 .5095 m .51962 .51457 L .52336 .51532 L F
.52779 .46982 m .52801 .50275 L .52781 .50246 L .988 .719 .384 r
F
.5282 .4705 m .52857 .50329 L .52822 .50305 L .929 .648 .487 r
F
.52779 .46982 m .52822 .50305 L .52801 .50275 L .988 .719 .384 r
F
.52774 .46901 m .52778 .5021 L .52776 .50176 L .781 .623 .061 r
F
.52774 .46901 m .52781 .50246 L .52778 .5021 L F
.52831 .46799 m .52774 .46901 L .52776 .50176 L 0 0 .377 r
F
.52909 .5043 m .5231 .50909 L .52928 .50457 L .656 .78 .94 r
F
.5231 .50909 m .51692 .51403 L .52284 .5095 L F
.5231 .50909 m .52284 .5095 L .52928 .50457 L F
.52865 .50344 m .51692 .51403 L .5297 .50381 L F
.52891 .47109 m .52945 .50372 L .52894 .50354 L .845 .571 .524 r
F
.53115 .50118 m .51143 .51187 L .51692 .51403 L .656 .78 .94 r
F
.53117 .51343 m .52366 .52187 L .53065 .5222 L .655 .781 .941 r
F
.53093 .5049 m .52994 .50552 L .53082 .50679 L .656 .78 .94 r
F
.52945 .50372 m .53001 .50391 L .53002 .51008 L .845 .571 .524 r
F
.53134 .51054 m .52959 .51117 L .53117 .51343 L .655 .781 .941 r
F
.53016 .51013 m .52959 .51117 L .53134 .51054 L F
.52959 .51117 m .52821 .51365 L .53117 .51343 L F
.52821 .51365 m .52366 .52187 L .52843 .51651 L F
.52821 .51365 m .52843 .51651 L .53117 .51343 L F
.53115 .50118 m .52363 .50364 L .51143 .51187 L .656 .78 .94 r
F
.52363 .50364 m .50725 .50898 L .51065 .51133 L F
.52363 .50364 m .51065 .51133 L .51143 .51187 L F
.52952 .46722 m .52831 .46799 L .52834 .50084 L .4 .211 .506 r
F
.53115 .50118 m .52865 .50344 L .5297 .50381 L .656 .78 .94 r
F
.52801 .50275 m .52805 .50897 L .52781 .50246 L .988 .719 .384 r
F
.51692 .51403 m .51571 .52919 L .52336 .51532 L .656 .78 .94 r
F
.52959 .51117 m .52227 .51655 L .52366 .52187 L .655 .781 .941 r
F
.5294 .5109 m .52227 .51655 L .52959 .51117 L F
.52801 .50275 m .52822 .50305 L .52823 .50922 L .988 .719 .384 r
F
.52884 .5101 m .52308 .51528 L .52937 .51086 L .655 .781 .941 r
F
.52308 .51528 m .52227 .51655 L .53 .51042 L F
.52945 .50372 m .53002 .51008 L .52956 .50992 L .845 .571 .524 r
F
.51692 .51403 m .50293 .52667 L .51571 .52919 L .656 .78 .94 r
F
.51143 .51187 m .50293 .52667 L .51692 .51403 L F
.52308 .51528 m .51165 .51842 L .51718 .52058 L .655 .781 .941 r
F
.52913 .50984 m .52602 .51066 L .52308 .51528 L F
.52918 .50979 m .5291 .50981 L .52913 .50984 L F
.5291 .50981 m .52602 .51066 L .52913 .50984 L F
.52857 .50329 m .52864 .5095 L .52822 .50305 L .929 .648 .487 r
F
.52864 .5095 m .52835 .50931 L .52822 .50305 L F
.52894 .50354 m .52913 .50977 L .52895 .50971 L .845 .571 .524 r
F
.52824 .50946 m .52602 .51066 L .5291 .50981 L .655 .781 .941 r
F
.52895 .50971 m .5291 .50981 L .52918 .50979 L F
.52824 .50946 m .5291 .50981 L .52895 .50971 L F
.52857 .50329 m .52894 .50354 L .52895 .50971 L .929 .648 .487 r
F
.52857 .50329 m .52895 .50971 L .52864 .5095 L F
.5297 .50381 m .52909 .5043 L .52928 .50457 L .656 .78 .94 r
F
.52945 .50372 m .52956 .50992 L .52894 .50354 L .845 .571 .524 r
F
.52913 .50984 m .52884 .5101 L .53 .51042 L .655 .781 .941 r
F
.52884 .5101 m .52937 .51086 L .53 .51042 L F
.53 .51042 m .5294 .5109 L .52959 .51117 L F
.52956 .50992 m .52913 .50977 L .52894 .50354 L .845 .571 .524 r
F
.53001 .50391 m .53032 .51011 L .53002 .51008 L .751 .491 .539 r
F
.53097 .50425 m .53053 .50462 L .53093 .5049 L .656 .78 .94 r
F
.53115 .50118 m .5297 .50381 L .53097 .50425 L F
.53083 .50399 m .53099 .51017 L .53001 .50391 L .751 .491 .539 r
F
.53136 .51021 m .53016 .51013 L .53134 .51054 L .655 .781 .941 r
F
.53018 .5101 m .53016 .51013 L .53136 .51021 L F
.53271 .51011 m .53203 .5102 L .53172 .50408 L .641 .401 .54 r
F
.53329 .51169 m .53065 .5222 L .53771 .52155 L .655 .781 .941 r
F
.53267 .5103 m .5322 .51308 L .53329 .51169 L F
.5322 .51308 m .53065 .5222 L .53329 .51169 L F
.53344 .50384 m .53365 .50993 L .53346 .51001 L .517 .303 .528 r
F
.53254 .50396 m .53271 .51011 L .53172 .50408 L .641 .401 .54 r
F
.53398 .50364 m .53458 .50959 L .53409 .50977 L .517 .303 .528 r
F
.53498 .50954 m .53989 .515 L .53771 .51098 L .655 .781 .941 r
F
.53432 .51039 m .54068 .51646 L .53498 .50954 L F
.54068 .51646 m .54435 .51997 L .53989 .515 L F
.54068 .51646 m .53989 .515 L .53498 .50954 L F
.5357 .50243 m .53581 .50229 L .53572 .5086 L .08 0 .418 r
F
.5357 .50243 m .53572 .5086 L .53568 .50865 L F
.53583 .46915 m .53546 .50069 L .53571 .50115 L .983 .725 .332 r
F
.53583 .46915 m .53571 .50115 L .53594 .50158 L F
.5384 .50102 m .55715 .50437 L .55836 .50058 L .656 .78 .94 r
F
.53115 .50118 m .54696 .50312 L .5384 .50102 L F
.54696 .50312 m .55715 .50437 L .5384 .50102 L F
.5348 .50944 m .53432 .51039 L .53498 .50954 L .655 .781 .941 r
F
.53456 .50342 m .53471 .5095 L .53458 .50959 L .358 .18 .498 r
F
.53393 .51002 m .53432 .51039 L .53476 .50952 L .655 .781 .941 r
F
.53458 .50959 m .53476 .50952 L .5348 .50944 L F
.53393 .51002 m .53476 .50952 L .53458 .50959 L F
.53386 .50378 m .53389 .50387 L .53393 .50385 L .656 .78 .94 r
F
.53398 .50364 m .53409 .50977 L .53344 .50384 L .517 .303 .528 r
F
.53409 .50977 m .53365 .50993 L .53344 .50384 L F
.53493 .50317 m .53502 .50929 L .53456 .50342 L .358 .18 .498 r
F
.54063 .51028 m .54251 .51376 L .54391 .51343 L .656 .78 .94 r
F
.54391 .51343 m .55645 .52546 L .5679 .5207 L F
.54391 .51343 m .5679 .5207 L .54966 .51102 L F
.53551 .50887 m .55014 .51755 L .55468 .51446 L .655 .781 .941 r
F
.53498 .50954 m .55014 .51755 L .53558 .50891 L F
.53535 .50907 m .53558 .50891 L .53551 .50887 L F
.53498 .50954 m .53558 .50891 L .53535 .50907 L F
.53493 .50317 m .53533 .5029 L .53535 .50907 L .358 .18 .498 r
F
.53493 .50317 m .53535 .50907 L .53502 .50929 L F
.53568 .51486 m .53553 .51505 L .53543 .50896 L .08 0 .418 r
F
.53551 .50887 m .53543 .50896 L .53533 .5029 L F
.53568 .51486 m .53543 .50896 L .53551 .50887 L F
.53502 .50929 m .53471 .5095 L .53456 .50342 L .358 .18 .498 r
F
.53343 .51772 m .53101 .5287 L .53807 .52805 L .655 .782 .942 r
F
.54966 .51102 m .5679 .5207 L .57695 .5146 L .656 .78 .94 r
F
.54966 .51102 m .57695 .5146 L .55418 .50793 L F
.53599 .50825 m .55468 .51446 L .55768 .51089 L .655 .781 .941 r
F
.53533 .5029 m .53543 .50896 L .53535 .50907 L .08 0 .418 r
F
.53556 .50261 m .53562 .50872 L .53533 .5029 L F
.53562 .50872 m .53551 .50887 L .53533 .5029 L F
.53572 .5086 m .53581 .50229 L .53583 .50846 L F
.5359 .50806 m .53585 .50834 L .53581 .50229 L 0 0 .15 r
F
.53581 .50229 m .53585 .50834 L .53583 .50846 L F
.53556 .50261 m .5357 .50243 L .53568 .50865 L .08 0 .418 r
F
.53556 .50261 m .53568 .50865 L .53562 .50872 L F
.53272 .51862 m .53101 .5287 L .53343 .51772 L .655 .782 .942 r
F
.53083 .50399 m .53172 .50408 L .53173 .51025 L .751 .491 .539 r
F
.53083 .50399 m .53173 .51025 L .53128 .5102 L F
.53136 .51021 m .53132 .51081 L .5326 .51033 L .655 .781 .941 r
F
.5329 .51655 m .53165 .51775 L .53302 .51683 L .655 .782 .942 r
F
.53132 .51081 m .53065 .5222 L .53266 .51034 L .655 .781 .941 r
F
.5326 .51033 m .53266 .51034 L .53267 .5103 L F
.53132 .51081 m .53266 .51034 L .5326 .51033 L F
.53099 .51017 m .53174 .51644 L .53116 .51638 L .751 .491 .539 r
F
.53083 .50399 m .53128 .5102 L .53099 .51017 L F
.53128 .5102 m .53174 .51644 L .53099 .51017 L F
.53173 .51025 m .5321 .51639 L .53174 .51644 L .641 .401 .54 r
F
.53186 .51424 m .53173 .51644 L .53174 .51644 L .655 .782 .942 r
F
.53278 .51629 m .53174 .51644 L .5329 .51655 L F
.53136 .51021 m .5326 .51033 L .53267 .5103 L .655 .781 .941 r
F
.53203 .5102 m .53234 .51635 L .53173 .51025 L .641 .401 .54 r
F
.53174 .51644 m .53165 .51775 L .5329 .51655 L .655 .782 .942 r
F
.53165 .51775 m .53101 .5287 L .53302 .51683 L F
.53234 .51635 m .53353 .53974 L .5321 .51639 L .641 .401 .54 r
F
.53234 .51635 m .5321 .51639 L .53173 .51025 L F
.53173 .51644 m .53173 .51644 L .53174 .51644 L .655 .782 .942 r
F
.53173 .51644 m .53165 .51775 L .53174 .51644 L F
.53259 .51013 m .53177 .51024 L .53267 .5103 L .655 .781 .941 r
F
.53271 .51011 m .53288 .51628 L .53203 .5102 L .641 .401 .54 r
F
.53347 .5162 m .53343 .51772 L .53386 .51614 L .655 .782 .942 r
F
.53278 .51629 m .53285 .51643 L .53347 .5162 L F
.53285 .51643 m .53343 .51772 L .53347 .5162 L F
.53386 .51614 m .53343 .51772 L .53433 .51658 L F
.53343 .51772 m .53473 .52061 L .53433 .51658 L F
.53473 .52061 m .53807 .52805 L .53506 .51883 L F
.53473 .52061 m .53506 .51883 L .53433 .51658 L F
.53771 .52155 m .54379 .53514 L .55697 .53202 L .655 .781 .941 r
F
.53771 .52155 m .55697 .53202 L .54435 .51997 L F
.53527 .51771 m .53807 .52805 L .54302 .52688 L .655 .782 .942 r
F
.53506 .51883 m .53807 .52805 L .53527 .51771 L F
.53531 .51752 m .54302 .52688 L .54073 .52267 L F
.53433 .51658 m .53527 .51771 L .53531 .51752 L F
.53527 .51771 m .54302 .52688 L .53531 .51752 L F
.53551 .50887 m .55468 .51446 L .53599 .50825 L .655 .781 .941 r
F
.53585 .50834 m .53589 .51441 L .53583 .50846 L 0 0 .15 r
F
.53346 .51001 m .53371 .51611 L .53347 .5162 L .517 .303 .528 r
F
.53288 .51628 m .53234 .51635 L .53203 .5102 L .641 .401 .54 r
F
.53172 .50408 m .53203 .5102 L .53173 .51025 L F
.53151 .5077 m .53551 .50887 L .53599 .50825 L .655 .781 .941 r
F
.53151 .5077 m .53498 .50954 L .53551 .50887 L F
.53562 .50872 m .53568 .51486 L .53551 .50887 L .08 0 .418 r
F
.55418 .50793 m .57695 .5146 L .58298 .50754 L .656 .78 .94 r
F
.55418 .50793 m .58298 .50754 L .55715 .50437 L F
.53975 .50752 m .55768 .51089 L .5589 .50709 L .655 .781 .941 r
F
.53535 .46811 m .5349 .50037 L .53546 .50069 L .911 .629 .497 r
F
.53588 .5004 m .55836 .50058 L .55772 .49681 L .656 .78 .94 r
F
.53115 .50118 m .5384 .50102 L .53588 .5004 L F
.5384 .50102 m .55836 .50058 L .53588 .5004 L F
.53422 .4673 m .53306 .46692 L .53314 .49973 L .81 .54 .53 r
F
.53587 .50195 m .5359 .50806 L .53581 .50229 L 0 0 .15 r
F
.53587 .50195 m .53594 .50158 L .53596 .50776 L F
.53587 .50195 m .53596 .50776 L .5359 .50806 L F
.53594 .50158 m .53587 .5076 L .53596 .50776 L .983 .725 .332 r
F
.53151 .5077 m .53831 .50853 L .5367 .50758 L .655 .781 .941 r
F
.53409 .50977 m .53421 .51592 L .53365 .50993 L .517 .303 .528 r
F
.53421 .51592 m .53386 .51605 L .53365 .50993 L F
.5359 .50806 m .53596 .50776 L .53598 .51395 L 0 0 .15 r
F
.53556 .51619 m .54011 .52153 L .53785 .51739 L .655 .782 .942 r
F
.5355 .51649 m .54011 .52153 L .53556 .51619 L F
.53486 .51591 m .54011 .52153 L .53491 .51584 L F
.53409 .50977 m .53458 .50959 L .53459 .51578 L .517 .303 .528 r
F
.53394 .51622 m .53433 .51658 L .53467 .51575 L .655 .782 .942 r
F
.53394 .51622 m .53467 .51575 L .53459 .51578 L F
.53433 .51658 m .54073 .52267 L .53486 .51591 L F
.54073 .52267 m .54472 .52647 L .54011 .52153 L F
.54073 .52267 m .54011 .52153 L .53486 .51591 L F
.53409 .50977 m .53459 .51578 L .53421 .51592 L .517 .303 .528 r
F
.53433 .51658 m .53486 .51591 L .53468 .51572 L .655 .782 .942 r
F
.53433 .51658 m .53506 .51883 L .53527 .51771 L F
.53459 .51578 m .53544 .53877 L .53466 .53932 L .358 .18 .498 r
F
.53458 .50959 m .53476 .51567 L .53459 .51578 L F
.53468 .51572 m .53785 .51739 L .53537 .51526 L .655 .782 .942 r
F
.54068 .51646 m .54278 .52034 L .54435 .51997 L .655 .781 .941 r
F
.54435 .51997 m .55697 .53202 L .56849 .52725 L F
.53785 .51739 m .55052 .52406 L .5373 .51638 L .655 .782 .942 r
F
.53785 .51739 m .5373 .51638 L .53537 .51526 L F
.5359 .50806 m .53593 .51419 L .53585 .50834 L 0 0 .15 r
F
.55715 .50437 m .58298 .50754 L .58554 .49998 L .656 .78 .94 r
F
.55715 .50437 m .58554 .49998 L .55836 .50058 L F
.53689 .50682 m .5589 .50709 L .55826 .50331 L .655 .781 .941 r
F
.53571 .50115 m .53568 .50725 L .53594 .50158 L .983 .725 .332 r
F
.53568 .50725 m .53587 .5076 L .53594 .50158 L F
.53571 .50115 m .53548 .50687 L .53568 .50725 L F
.53151 .5077 m .5367 .50758 L .53572 .50701 L .655 .781 .941 r
F
.53459 .51578 m .53467 .51575 L .53468 .51572 L .655 .782 .942 r
F
.53476 .51567 m .53544 .53877 L .53459 .51578 L .358 .18 .498 r
F
.53771 .51098 m .54435 .51997 L .55014 .51755 L .655 .781 .941 r
F
.53989 .515 m .54435 .51997 L .53771 .51098 L F
.54435 .51997 m .56849 .52725 L .55014 .51755 L F
.53537 .51526 m .55052 .52406 L .55229 .52286 L .655 .782 .942 r
F
.54309 .5175 m .55229 .52286 L .55508 .52097 L F
.53537 .51526 m .55229 .52286 L .54309 .5175 L F
.53421 .51592 m .53459 .51578 L .53466 .53932 L .517 .303 .528 r
F
.53491 .51584 m .5355 .51649 L .53556 .51619 L .655 .782 .942 r
F
.53379 .51608 m .53394 .51622 L .53459 .51578 L F
.53421 .51592 m .53466 .53932 L .53386 .51605 L .517 .303 .528 r
F
.5351 .51544 m .53537 .51526 L .53544 .53877 L .358 .18 .498 r
F
.53347 .5162 m .53466 .53932 L .53353 .53974 L .517 .303 .528 r
F
.53302 .51683 m .53272 .51862 L .53343 .51772 L .655 .782 .942 r
F
.53151 .5077 m .53259 .51013 L .53379 .50988 L .655 .781 .941 r
F
.53259 .51013 m .53267 .5103 L .53346 .51001 L F
.53259 .51013 m .53346 .51001 L .53379 .50988 L F
.5679 .5207 m .59948 .5212 L .57695 .5146 L .656 .78 .94 r
F
.55014 .51755 m .56849 .52725 L .57761 .52114 L .655 .781 .941 r
F
.55014 .51755 m .57761 .52114 L .55468 .51446 L F
.54029 .51526 m .55508 .52097 L .55808 .51742 L .655 .782 .942 r
F
.53271 .51011 m .53346 .51001 L .53347 .5162 L .641 .401 .54 r
F
.53271 .51011 m .53347 .5162 L .53288 .51628 L F
.53365 .50993 m .53386 .51605 L .53346 .51001 L .517 .303 .528 r
F
.53386 .51605 m .53371 .51611 L .53346 .51001 L F
.53502 .50929 m .53535 .50907 L .53537 .51526 L .358 .18 .498 r
F
.53502 .50929 m .53537 .51526 L .5351 .51544 L F
.53546 .50069 m .53527 .50675 L .53548 .50687 L .911 .629 .497 r
F
.53571 .50115 m .53546 .50069 L .53548 .50687 L .983 .725 .332 r
F
.53537 .50645 m .55826 .50331 L .55578 .49981 L .655 .781 .941 r
F
.53535 .46811 m .53431 .50002 L .5349 .50037 L .911 .629 .497 r
F
.53523 .49985 m .55772 .49681 L .55526 .49332 L .656 .78 .94 r
F
.53115 .50118 m .53818 .50003 L .53523 .49985 L F
.53818 .50003 m .55772 .49681 L .53523 .49985 L F
.53151 .5077 m .53572 .50701 L .53498 .50657 L .655 .781 .941 r
F
.53566 .51264 m .53576 .51477 L .53568 .51486 L .08 0 .418 r
F
.53535 .50907 m .53553 .51505 L .53537 .51526 L F
.53543 .50896 m .53553 .51505 L .53535 .50907 L F
.53502 .50929 m .5351 .51544 L .53471 .5095 L .358 .18 .498 r
F
.5351 .51544 m .53486 .5156 L .53471 .5095 L F
.53598 .51486 m .53696 .51572 L .53946 .51538 L .655 .782 .942 r
F
.53471 .5095 m .53486 .5156 L .53458 .50959 L .358 .18 .498 r
F
.53486 .5156 m .53476 .51567 L .53458 .50959 L F
.53186 .51424 m .53537 .51526 L .53598 .51486 L .655 .782 .942 r
F
.53537 .51526 m .53696 .51572 L .53598 .51486 L F
.53468 .51572 m .53486 .51591 L .53491 .51584 L F
.53486 .5156 m .53544 .53877 L .53476 .51567 L .358 .18 .498 r
F
.53572 .5086 m .53585 .51466 L .53576 .51477 L .08 0 .418 r
F
.53566 .51264 m .53572 .5086 L .53576 .51477 L F
.53186 .51424 m .53946 .51538 L .53899 .5151 L .655 .782 .942 r
F
.53288 .51628 m .53347 .5162 L .53353 .53974 L .641 .401 .54 r
F
.53186 .51424 m .53278 .51629 L .53347 .5162 L .655 .782 .942 r
F
.53186 .51424 m .53347 .5162 L .53379 .51608 L F
.53186 .51424 m .53468 .51572 L .53537 .51526 L F
.53186 .51424 m .53379 .51608 L .53468 .51572 L F
.53288 .51628 m .53353 .53974 L .53234 .51635 L .641 .401 .54 r
F
.53186 .51424 m .53174 .51644 L .53278 .51629 L .655 .782 .942 r
F
.53174 .51644 m .53353 .53974 L .53179 .53994 L .641 .401 .54 r
F
.5321 .51639 m .53353 .53974 L .53174 .51644 L F
.53151 .5077 m .53393 .51002 L .5348 .50944 L .655 .781 .941 r
F
.53115 .50118 m .5324 .50398 L .53386 .50378 L .656 .78 .94 r
F
.53306 .46692 m .53256 .4997 L .53314 .49973 L .734 .477 .539 r
F
.53422 .4673 m .53314 .49973 L .53374 .49988 L .81 .54 .53 r
F
.53422 .4673 m .53374 .49988 L .53431 .50002 L F
.53278 .49971 m .55114 .49035 L .54562 .48811 L .656 .78 .94 r
F
.53115 .50118 m .53376 .49977 L .53278 .49971 L F
.53376 .49977 m .55114 .49035 L .53278 .49971 L F
.53306 .46692 m .53189 .4668 L .53196 .49966 L .734 .477 .539 r
F
.53151 .5077 m .53177 .51024 L .53259 .51013 L .655 .781 .941 r
F
.53115 .50118 m .53098 .50418 L .5324 .50398 L .656 .78 .94 r
F
.53306 .46692 m .53196 .49966 L .53256 .4997 L .734 .477 .539 r
F
.53189 .4668 m .53077 .49978 L .53138 .49972 L .66 .416 .54 r
F
.53115 .50118 m .53199 .49966 L .53123 .49973 L .656 .78 .94 r
F
.53151 .5077 m .53136 .51021 L .53177 .51024 L .655 .781 .941 r
F
.53128 .5102 m .53173 .51025 L .53174 .51644 L .751 .491 .539 r
F
.52956 .50992 m .52966 .51615 L .52913 .50977 L .845 .571 .524 r
F
.53099 .51017 m .53032 .51011 L .53001 .50391 L .751 .491 .539 r
F
.52801 .50275 m .52823 .50922 L .52805 .50897 L .988 .719 .384 r
F
.52805 .50897 m .52789 .50874 L .52781 .50246 L F
.52822 .50305 m .52835 .50931 L .52823 .50922 L .929 .648 .487 r
F
.53151 .5077 m .52191 .51082 L .51165 .51842 L .655 .781 .941 r
F
.51143 .51187 m .49197 .52242 L .50293 .52667 L .656 .78 .94 r
F
.52191 .51082 m .50745 .51552 L .51045 .51759 L .655 .781 .941 r
F
.52191 .51082 m .51045 .51759 L .51165 .51842 L F
.52831 .46799 m .52776 .50176 L .52806 .50129 L 0 0 .377 r
F
.52363 .50364 m .50469 .50554 L .50725 .50898 L .656 .78 .94 r
F
.53115 .50118 m .52646 .50195 L .52363 .50364 L F
.52646 .50195 m .50469 .50554 L .52363 .50364 L F
.53151 .52009 m .524 .52837 L .53101 .5287 L .655 .782 .942 r
F
.53074 .51899 m .524 .52837 L .53151 .52009 L F
.53129 .51748 m .5305 .51865 L .53165 .51773 L F
.5305 .51865 m .524 .52837 L .53074 .51899 L F
.5305 .51865 m .53074 .51899 L .53165 .51773 L F
.50725 .50898 m .49197 .52242 L .51143 .51187 L .656 .78 .94 r
F
.52191 .51082 m .50486 .51207 L .50745 .51552 L .655 .781 .941 r
F
.52778 .5021 m .52781 .50246 L .52782 .50863 L .781 .623 .061 r
F
.52778 .5021 m .52782 .50863 L .52779 .50834 L F
.52781 .50246 m .52789 .50874 L .52782 .50863 L .988 .719 .384 r
F
.52776 .50176 m .52779 .50834 L .52776 .50793 L .781 .623 .061 r
F
.52778 .5021 m .52779 .50834 L .52776 .50176 L F
.53151 .5077 m .52553 .50868 L .52191 .51082 L .655 .781 .941 r
F
.52553 .50868 m .50486 .51207 L .52191 .51082 L F
.53151 .51678 m .53113 .51737 L .53171 .51685 L .655 .782 .942 r
F
.52779 .50834 m .52782 .50863 L .52782 .51483 L .781 .623 .061 r
F
.52835 .52165 m .524 .52837 L .52837 .52184 L .655 .782 .942 r
F
.5307 .51634 m .53062 .51648 L .53173 .51644 L F
.53039 .51688 m .52989 .51778 L .53113 .51737 L F
.52989 .51778 m .524 .52837 L .5304 .5185 L F
.52989 .51778 m .5304 .5185 L .53113 .51737 L F
.53099 .51017 m .53116 .51638 L .53032 .51011 L .751 .491 .539 r
F
.53116 .51638 m .53062 .51633 L .53032 .51011 L F
.52913 .50977 m .52933 .51603 L .52895 .50971 L .845 .571 .524 r
F
.52835 .50931 m .52848 .51559 L .52823 .50922 L .929 .648 .487 r
F
.51718 .52058 m .51595 .53577 L .52366 .52187 L .655 .781 .941 r
F
.52989 .51778 m .52158 .52379 L .524 .52837 L .655 .782 .942 r
F
.53039 .51688 m .52966 .51745 L .52989 .51778 L F
.52966 .51745 m .52158 .52379 L .52989 .51778 L F
.52789 .50874 m .52796 .51504 L .52782 .50863 L .988 .719 .384 r
F
.53025 .51678 m .52811 .51851 L .53039 .51688 L .655 .782 .942 r
F
.52811 .51851 m .52158 .52379 L .52812 .51866 L F
.52811 .51851 m .52812 .51866 L .53039 .51688 L F
.50725 .50898 m .48357 .5167 L .49197 .52242 L .656 .78 .94 r
F
.50469 .50554 m .48357 .5167 L .50725 .50898 L F
.52553 .50868 m .50408 .50831 L .50486 .51207 L .655 .781 .941 r
F
.52831 .46799 m .52806 .50129 L .52834 .50084 L 0 0 .377 r
F
.51807 .50334 m .50391 .50179 L .50469 .50554 L .656 .78 .94 r
F
.53115 .50118 m .5253 .50131 L .51807 .50334 L F
.5253 .50131 m .50391 .50179 L .51807 .50334 L F
.53071 .46688 m .52952 .46722 L .52956 .50012 L .567 .342 .533 r
F
.52806 .50129 m .52776 .50176 L .52776 .50793 L 0 0 .377 r
F
.52749 .50836 m .52702 .5078 L .52553 .50868 L .655 .781 .941 r
F
.53151 .5077 m .52786 .50778 L .52749 .50836 L F
.52786 .50778 m .52702 .5078 L .52749 .50836 L F
.53055 .51645 m .5281 .51845 L .53062 .51648 L .655 .782 .942 r
F
.5281 .51845 m .52811 .5185 L .53062 .51648 L F
.52161 .52374 m .52158 .52379 L .53062 .51648 L F
.52227 .51655 m .51941 .52103 L .52366 .52187 L .655 .781 .941 r
F
.52963 .51623 m .51751 .52709 L .53055 .51645 L .655 .782 .942 r
F
.53003 .51627 m .53055 .51645 L .5307 .51634 L F
.52963 .51623 m .53055 .51645 L .53003 .51627 L F
.53018 .5101 m .52941 .51002 L .53 .51042 L .655 .781 .941 r
F
.52956 .50992 m .53002 .51008 L .53003 .51627 L .845 .571 .524 r
F
.52956 .50992 m .53003 .51627 L .52966 .51615 L F
.53002 .51008 m .53039 .51631 L .53003 .51627 L .751 .491 .539 r
F
.53062 .51648 m .53025 .51678 L .53039 .51688 L .655 .782 .942 r
F
.5307 .51634 m .53055 .51645 L .53062 .51648 L F
.53062 .51648 m .53039 .51688 L .53151 .51678 L F
.53039 .51688 m .53113 .51737 L .53151 .51678 L F
.53062 .51648 m .53151 .51678 L .53173 .51644 L F
.53113 .51737 m .52835 .52165 L .53129 .51748 L F
.52835 .52165 m .52837 .52184 L .53129 .51748 L F
.53165 .51773 m .53074 .51899 L .53151 .52009 L F
.53032 .51011 m .53062 .51633 L .53002 .51008 L .751 .491 .539 r
F
.53062 .51633 m .53179 .53994 L .53039 .51631 L F
.53062 .51633 m .53039 .51631 L .53002 .51008 L F
.51718 .52058 m .50309 .53325 L .51595 .53577 L .655 .781 .941 r
F
.51165 .51842 m .50309 .53325 L .51718 .52058 L F
.52963 .51623 m .51197 .52493 L .51751 .52709 L .655 .782 .942 r
F
.52933 .51603 m .52918 .51598 L .52895 .50971 L .845 .571 .524 r
F
.52895 .50971 m .52918 .51598 L .52895 .5159 L F
.52864 .5095 m .52895 .50971 L .52895 .5159 L .929 .648 .487 r
F
.52864 .5095 m .52895 .5159 L .52871 .51574 L F
.52966 .51615 m .52933 .51603 L .52913 .50977 L .845 .571 .524 r
F
.53186 .51424 m .52838 .51611 L .52963 .51623 L .655 .782 .942 r
F
.52392 .50787 m .50517 .50449 L .50408 .50831 L .655 .781 .941 r
F
.52952 .46722 m .52834 .50084 L .52897 .50047 L .4 .211 .506 r
F
.5253 .50131 m .50499 .49797 L .50391 .50179 L .656 .78 .94 r
F
.53115 .50118 m .5274 .50072 L .5253 .50131 L F
.5274 .50072 m .50499 .49797 L .5253 .50131 L F
.52806 .50129 m .52801 .50754 L .52834 .50084 L 0 0 .377 r
F
.52806 .50129 m .52776 .50793 L .52801 .50754 L F
.52786 .50778 m .52665 .50711 L .52392 .50787 L .655 .781 .941 r
F
.53151 .5077 m .52817 .50729 L .52786 .50778 L F
.52801 .50754 m .52824 .50718 L .52834 .50084 L 0 0 .377 r
F
.52817 .50729 m .52665 .50711 L .52786 .50778 L .655 .781 .941 r
F
.53186 .51424 m .52963 .51623 L .5307 .51634 L .655 .782 .942 r
F
.52966 .51615 m .53003 .51627 L .53006 .53969 L .845 .571 .524 r
F
.52993 .53534 m .53006 .53969 L .5299 .53535 L F
.52838 .51611 m .52551 .51766 L .52963 .51623 L .655 .782 .942 r
F
.52551 .51766 m .52494 .51855 L .52963 .51623 L F
.52993 .53534 m .5299 .53535 L .52918 .51598 L .845 .571 .524 r
F
.52933 .51603 m .52993 .53534 L .52918 .51598 L F
.53003 .51627 m .53179 .53994 L .53006 .53969 L .751 .491 .539 r
F
.53039 .51631 m .53179 .53994 L .53003 .51627 L F
.52895 .5159 m .53006 .53969 L .52898 .53923 L .845 .571 .524 r
F
.52918 .51598 m .53006 .53969 L .52895 .5159 L F
.52966 .51615 m .53006 .53969 L .52933 .51603 L F
.53186 .51424 m .5307 .51634 L .53173 .51644 L .655 .782 .942 r
F
.53113 .51737 m .53129 .51748 L .53171 .51685 L F
.53116 .51638 m .53179 .53994 L .53062 .51633 L .751 .491 .539 r
F
.52848 .51559 m .52838 .51552 L .52823 .50922 L .929 .648 .487 r
F
.52823 .50922 m .52838 .51552 L .52823 .51542 L F
.52843 .50936 m .52824 .50946 L .52895 .50971 L .655 .781 .941 r
F
.52864 .5095 m .52871 .51574 L .52835 .50931 L .929 .648 .487 r
F
.52871 .51574 m .52848 .51559 L .52835 .50931 L F
.53186 .51424 m .5266 .51594 L .52551 .51766 L .655 .782 .942 r
F
.5281 .51845 m .52161 .52374 L .52811 .5185 L F
.52796 .51504 m .52793 .51499 L .52782 .50863 L .988 .719 .384 r
F
.52782 .50863 m .52793 .51499 L .52782 .51483 L F
.52805 .50897 m .52809 .51522 L .52789 .50874 L F
.52809 .51522 m .52796 .51504 L .52789 .50874 L F
.52805 .50897 m .52823 .50922 L .52823 .51542 L F
.52805 .50897 m .52823 .51542 L .52809 .51522 L F
.52308 .51528 m .51718 .52058 L .52227 .51655 L .655 .781 .941 r
F
.52227 .51655 m .51718 .52058 L .51941 .52103 L F
.53186 .51424 m .52458 .51543 L .52018 .51802 L .655 .782 .942 r
F
.52848 .51559 m .52898 .53923 L .52838 .51552 L .929 .648 .487 r
F
.52823 .51542 m .52898 .53923 L .52825 .53865 L F
.52838 .51552 m .52898 .53923 L .52823 .51542 L F
.52871 .51574 m .52898 .53923 L .52848 .51559 L F
.52894 .53584 m .52897 .53582 L .52898 .53923 L F
.52871 .51574 m .52897 .53582 L .52894 .53584 L F
.52871 .51574 m .52895 .5159 L .52897 .53582 L F
.50745 .51552 m .49206 .52899 L .51165 .51842 L .655 .781 .941 r
F
.50745 .51552 m .48361 .52327 L .49206 .52899 L F
.50486 .51207 m .48361 .52327 L .50745 .51552 L F
.51107 .51764 m .50439 .51486 L .50517 .51861 L .655 .782 .942 r
F
.52779 .50834 m .5278 .5146 L .52776 .50793 L .781 .623 .061 r
F
.5278 .5146 m .52778 .51428 L .52776 .50793 L F
.52779 .50834 m .52782 .51483 L .5278 .5146 L F
.53151 .5077 m .52913 .50984 L .52941 .51002 L .655 .781 .941 r
F
.53151 .5077 m .52843 .50936 L .52918 .50979 L F
.52665 .50711 m .50807 .50087 L .50517 .50449 L F
.53115 .50118 m .50787 .49436 L .50499 .49797 L .656 .78 .94 r
F
.52952 .46722 m .52897 .50047 L .52956 .50012 L .4 .211 .506 r
F
.53115 .50118 m .51236 .4912 L .50787 .49436 L .656 .78 .94 r
F
.52897 .50047 m .52834 .50084 L .52834 .50702 L .4 .211 .506 r
F
.52897 .50047 m .52834 .50702 L .52886 .50671 L F
.52834 .50084 m .52824 .50718 L .52834 .50702 L 0 0 .377 r
F
.53151 .5077 m .52809 .50671 L .52665 .50711 L .655 .781 .941 r
F
.52809 .50671 m .50807 .50087 L .52665 .50711 L F
.53071 .46688 m .52956 .50012 L .53018 .49995 L .567 .342 .533 r
F
.53115 .50118 m .51816 .48872 L .51236 .4912 L .656 .78 .94 r
F
.53071 .46688 m .53018 .49995 L .53077 .49978 L .567 .342 .533 r
F
.53115 .50118 m .52486 .48708 L .51816 .48872 L .656 .78 .94 r
F
.53186 .51424 m .5264 .51436 L .52458 .51543 L .655 .782 .942 r
F
.53171 .51685 m .53129 .51748 L .53165 .51773 L F
.53173 .51644 m .53151 .51678 L .53171 .51685 L F
.53142 .51641 m .53174 .51644 L .53178 .53503 L .751 .491 .539 r
F
.53142 .51641 m .53178 .53503 L .53179 .53994 L F
.53116 .51638 m .53142 .51641 L .53179 .53994 L F
.53115 .50118 m .54562 .48811 L .53909 .48677 L .656 .78 .94 r
F
.53115 .50118 m .55526 .49332 L .55114 .49035 L F
.57695 .5146 m .59948 .5212 L .60865 .51069 L F
.57695 .5146 m .60865 .51069 L .58298 .50754 L F
.55468 .51446 m .57761 .52114 L .58368 .51406 L .655 .781 .941 r
F
.55468 .51446 m .58368 .51406 L .55768 .51089 L F
.5373 .51412 m .55808 .51742 L .5593 .51362 L .655 .782 .942 r
F
.53572 .5086 m .53583 .50846 L .53585 .51466 L .08 0 .418 r
F
.5359 .50806 m .53598 .51395 L .53593 .51419 L 0 0 .15 r
F
.53589 .51441 m .53587 .51451 L .53583 .50846 L F
.53583 .50846 m .53587 .51451 L .53585 .51466 L F
.53593 .51419 m .53589 .51441 L .53585 .50834 L F
.53186 .51424 m .53899 .5151 L .5373 .51412 L .655 .782 .942 r
F
.53899 .5151 m .55808 .51742 L .5373 .51412 L F
.53563 .50547 m .55578 .49981 L .55163 .49684 L .655 .781 .941 r
F
.53256 .4997 m .53196 .49966 L .53197 .50584 L .734 .477 .539 r
F
.5349 .50037 m .53482 .50648 L .53546 .50069 L .911 .629 .497 r
F
.53482 .50648 m .53527 .50675 L .53546 .50069 L F
.5349 .50037 m .53433 .50619 L .53482 .50648 L F
.53151 .5077 m .53644 .5061 L .53467 .50599 L .655 .781 .941 r
F
.53256 .4997 m .53197 .50584 L .53247 .50587 L .734 .477 .539 r
F
.53196 .49966 m .53176 .50586 L .53197 .50584 L .66 .416 .54 r
F
.53128 .50591 m .53176 .50586 L .53196 .49966 L F
.53189 .4668 m .53138 .49972 L .53196 .49966 L F
.53123 .49973 m .53909 .48677 L .53201 .48642 L .656 .78 .94 r
F
.53199 .49966 m .53909 .48677 L .53123 .49973 L F
.53314 .49973 m .53295 .50589 L .53315 .50591 L .734 .477 .539 r
F
.53247 .50587 m .53295 .50589 L .53314 .49973 L F
.53374 .49988 m .53365 .50603 L .53431 .50002 L .81 .54 .53 r
F
.53365 .50603 m .53412 .50614 L .53431 .50002 L F
.53374 .49988 m .53314 .49973 L .53315 .50591 L F
.53374 .49988 m .53315 .50591 L .53365 .50603 L F
.5349 .50037 m .53431 .50002 L .53433 .50619 L .911 .629 .497 r
F
.53431 .50002 m .53412 .50614 L .53433 .50619 L .81 .54 .53 r
F
.53252 .50587 m .54608 .4946 L .53951 .49325 L .655 .781 .941 r
F
.53151 .5077 m .53348 .50593 L .53252 .50587 L F
.53348 .50593 m .54608 .4946 L .53252 .50587 L F
.53256 .4997 m .53247 .50587 L .53314 .49973 L .734 .477 .539 r
F
.53151 .5077 m .53257 .50578 L .53161 .50587 L .655 .781 .941 r
F
.53151 .5077 m .55163 .49684 L .54608 .4946 L F
.53365 .50603 m .53356 .5122 L .53412 .50614 L .81 .54 .53 r
F
.5373 .51412 m .5411 .51403 L .54109 .51403 L .655 .782 .942 r
F
.53186 .51424 m .5373 .51412 L .5373 .51412 L F
.5373 .51412 m .5411 .51403 L .5373 .51412 L F
.53482 .50648 m .53433 .50619 L .53434 .51239 L .911 .629 .497 r
F
.53789 .51325 m .5593 .51361 L .54185 .51261 L .655 .782 .942 r
F
.53587 .5076 m .53581 .51364 L .53596 .50776 L .983 .725 .332 r
F
.53581 .51364 m .53588 .51376 L .53596 .50776 L F
.53596 .50776 m .53588 .51376 L .53598 .51395 L F
.53566 .51336 m .53581 .51364 L .53587 .5076 L F
.53186 .51424 m .54109 .51403 L .53789 .51325 L .655 .782 .942 r
F
.54109 .51403 m .5593 .51361 L .53789 .51325 L F
.53365 .50603 m .53315 .50591 L .53317 .51211 L .81 .54 .53 r
F
.53379 .51608 m .53347 .5162 L .53386 .51614 L .655 .782 .942 r
F
.5335 .51619 m .5335 .51663 L .53347 .5162 L .517 .303 .528 r
F
.53371 .51611 m .5335 .51663 L .5335 .51619 L F
.53371 .51611 m .53466 .53932 L .5335 .51663 L F
.53365 .50603 m .53317 .51211 L .53356 .5122 L .81 .54 .53 r
F
.53482 .50648 m .53434 .51239 L .53473 .51262 L .911 .629 .497 r
F
.53356 .5122 m .53393 .51229 L .53412 .50614 L .81 .54 .53 r
F
.53315 .50591 m .53292 .51209 L .53317 .51211 L .734 .477 .539 r
F
.53467 .50599 m .53958 .50508 L .53563 .50547 L .655 .781 .941 r
F
.53644 .5061 m .53958 .50508 L .53467 .50599 L F
.53958 .50508 m .55578 .49981 L .53563 .50547 L F
.53482 .50648 m .53473 .51262 L .53527 .50675 L .911 .629 .497 r
F
.53473 .51262 m .53509 .51283 L .53527 .50675 L F
.53498 .50657 m .53689 .50682 L .53537 .50645 L .655 .781 .941 r
F
.53572 .50701 m .53689 .50682 L .53498 .50657 L F
.53689 .50682 m .55826 .50331 L .53537 .50645 L F
.53527 .50675 m .53509 .51283 L .53548 .50687 L .911 .629 .497 r
F
.53509 .51283 m .53525 .51292 L .53548 .50687 L F
.53548 .50687 m .53525 .51292 L .5355 .51306 L F
.53572 .50701 m .53975 .50752 L .53689 .50682 L .655 .781 .941 r
F
.5367 .50758 m .53975 .50752 L .53572 .50701 L F
.53975 .50752 m .5589 .50709 L .53689 .50682 L F
.5367 .50758 m .54947 .50989 L .53975 .50752 L F
.53831 .50853 m .54947 .50989 L .5367 .50758 L F
.53386 .51605 m .53466 .53932 L .53371 .51611 L .517 .303 .528 r
F
.53379 .51608 m .53459 .51578 L .53468 .51572 L .655 .782 .942 r
F
.53433 .50619 m .53409 .51233 L .53434 .51239 L .81 .54 .53 r
F
.54947 .50989 m .55768 .51089 L .53975 .50752 L .655 .781 .941 r
F
.53568 .50725 m .53548 .50687 L .5355 .51306 L .983 .725 .332 r
F
.53562 .50872 m .53568 .50865 L .53566 .51264 L .08 0 .418 r
F
.53568 .50725 m .5355 .51306 L .53566 .51336 L .983 .725 .332 r
F
.53568 .50865 m .53572 .5086 L .53566 .51264 L .08 0 .418 r
F
.53568 .50725 m .53566 .51336 L .53587 .5076 L .983 .725 .332 r
F
.53418 .51217 m .55202 .5034 L .54646 .50117 L .655 .782 .942 r
F
.53412 .50614 m .53393 .51229 L .53433 .50619 L .81 .54 .53 r
F
.53186 .51424 m .535 .51255 L .53402 .51231 L .655 .782 .942 r
F
.53393 .51229 m .53409 .51233 L .53433 .50619 L .81 .54 .53 r
F
.53186 .51424 m .53418 .51217 L .53305 .5121 L .655 .782 .942 r
F
.53557 .51225 m .55618 .50637 L .55202 .5034 L F
.53186 .51424 m .53765 .51237 L .53557 .51225 L F
.53765 .51237 m .55618 .50637 L .53557 .51225 L F
.53247 .50587 m .53197 .50584 L .53198 .51204 L .734 .477 .539 r
F
.53162 .50582 m .53951 .49325 L .53237 .4929 L .655 .781 .941 r
F
.53161 .50587 m .53165 .50582 L .53162 .50582 L F
.53165 .50582 m .53951 .49325 L .53162 .50582 L F
.53257 .50578 m .53951 .49325 L .53161 .50587 L F
.53138 .49972 m .53128 .50591 L .53196 .49966 L .66 .416 .54 r
F
.53151 .5077 m .53018 .5101 L .53136 .51021 L .655 .781 .941 r
F
.53151 .5077 m .52941 .51002 L .53018 .5101 L F
.52809 .50671 m .51259 .4977 L .50807 .50087 L F
.53151 .5077 m .52909 .50643 L .52809 .50671 L F
.52897 .50047 m .52886 .50671 L .52956 .50012 L .4 .211 .506 r
F
.52886 .50671 m .52935 .50642 L .52956 .50012 L F
.52909 .50643 m .51259 .4977 L .52809 .50671 L .655 .781 .941 r
F
.52909 .50643 m .51843 .49521 L .51259 .4977 L F
.53151 .5077 m .52993 .50619 L .52909 .50643 L F
.53018 .49995 m .52956 .50012 L .52957 .50629 L .567 .342 .533 r
F
.53018 .49995 m .52957 .50629 L .53008 .50615 L F
.52956 .50012 m .52935 .50642 L .52957 .50629 L .4 .211 .506 r
F
.52993 .50619 m .51843 .49521 L .52909 .50643 L .655 .781 .941 r
F
.53077 .49978 m .53056 .50602 L .53078 .50596 L .567 .342 .533 r
F
.53037 .50607 m .53056 .50602 L .53077 .49978 L F
.53115 .50118 m .53123 .49973 L .53054 .4998 L .656 .78 .94 r
F
.53018 .49995 m .53008 .50615 L .53077 .49978 L .567 .342 .533 r
F
.53008 .50615 m .53037 .50607 L .53077 .49978 L F
.52978 .50606 m .52518 .49357 L .51843 .49521 L .655 .781 .941 r
F
.53151 .5077 m .53073 .50596 L .52978 .50606 L F
.53073 .50596 m .52518 .49357 L .52978 .50606 L F
.53138 .49972 m .53077 .49978 L .53078 .50596 L .66 .416 .54 r
F
.53186 .51424 m .53199 .51204 L .53092 .51215 L .655 .782 .942 r
F
.53138 .49972 m .53078 .50596 L .53128 .50591 L .66 .416 .54 r
F
.53189 .4668 m .53071 .46688 L .53077 .49978 L F
.53054 .4998 m .53201 .48642 L .52486 .48708 L .656 .78 .94 r
F
.53123 .49973 m .53201 .48642 L .53054 .4998 L F
.53151 .5077 m .53237 .4929 L .52518 .49357 L .655 .781 .941 r
F
.52801 .50754 m .52796 .51382 L .52824 .50718 L 0 0 .377 r
F
.52796 .51382 m .52814 .51354 L .52824 .50718 L F
.52776 .50793 m .52778 .51428 L .52777 .51413 L .781 .623 .061 r
F
.52801 .50754 m .52776 .50793 L .52777 .51413 L 0 0 .377 r
F
.52801 .50754 m .52777 .51413 L .52796 .51382 L F
.52843 .50936 m .52895 .50971 L .52918 .50979 L .655 .781 .941 r
F
.52886 .50671 m .52834 .50702 L .52835 .51322 L .4 .211 .506 r
F
.53186 .51424 m .52751 .51371 L .5264 .51436 L .655 .782 .942 r
F
.52702 .5078 m .50408 .50831 L .52553 .50868 L .655 .781 .941 r
F
.52602 .51066 m .51165 .51842 L .52308 .51528 L F
.52194 .51304 m .50838 .50743 L .50548 .51105 L .655 .782 .942 r
F
.52834 .50702 m .52822 .51341 L .52835 .51322 L 0 0 .377 r
F
.52824 .50718 m .52814 .51354 L .52834 .50702 L F
.52814 .51354 m .52822 .51341 L .52834 .50702 L F
.53186 .51424 m .52624 .51261 L .52194 .51304 L .655 .782 .942 r
F
.52624 .51261 m .50838 .50743 L .52194 .51304 L F
.53247 .50587 m .53198 .51204 L .53238 .51206 L .734 .477 .539 r
F
.53295 .50589 m .53275 .51208 L .53315 .50591 L F
.53275 .51208 m .53292 .51209 L .53315 .50591 L F
.53247 .50587 m .53238 .51206 L .53295 .50589 L F
.53238 .51206 m .53275 .51208 L .53295 .50589 L F
.53186 .51424 m .53988 .49983 L .53273 .49948 L .655 .782 .942 r
F
.58298 .50754 m .61269 .49937 L .58554 .49998 L .656 .78 .94 r
F
.55768 .51089 m .58626 .50648 L .5589 .50709 L .655 .781 .941 r
F
.53186 .51424 m .55866 .50986 L .55618 .50637 L .655 .782 .942 r
F
.53198 .51204 m .53082 .5351 L .53203 .53501 L .66 .416 .54 r
F
.53197 .50584 m .53173 .51206 L .53198 .51204 L F
.52886 .50671 m .52835 .51322 L .52876 .51298 L .4 .211 .506 r
F
.52665 .50711 m .50517 .50449 L .52392 .50787 L .655 .781 .941 r
F
.52624 .51261 m .51291 .50427 L .50838 .50743 L .655 .782 .942 r
F
.52886 .50671 m .52876 .51298 L .52935 .50642 L .4 .211 .506 r
F
.52876 .51298 m .52914 .51275 L .52935 .50642 L F
.53186 .51424 m .52836 .5124 L .52624 .51261 L .655 .782 .942 r
F
.52836 .5124 m .51291 .50427 L .52624 .51261 L F
.53176 .50586 m .53156 .51208 L .53197 .50584 L .66 .416 .54 r
F
.52935 .50642 m .52914 .51275 L .52957 .50629 L .4 .211 .506 r
F
.52914 .51275 m .52931 .51265 L .52957 .50629 L F
.53008 .50615 m .52957 .50629 L .52958 .51249 L .567 .342 .533 r
F
.53008 .50615 m .52958 .51249 L .52998 .51238 L F
.52957 .50629 m .52931 .51265 L .52958 .51249 L .4 .211 .506 r
F
.53186 .51424 m .51876 .50179 L .51291 .50427 L .655 .782 .942 r
F
.53128 .50591 m .53078 .50596 L .53079 .51216 L .66 .416 .54 r
F
.53128 .50591 m .53079 .51216 L .53118 .51212 L F
.53078 .50596 m .53036 .51228 L .53079 .51216 L .567 .342 .533 r
F
.53056 .50602 m .53036 .51228 L .53078 .50596 L F
.52998 .51238 m .53036 .51228 L .53056 .50602 L F
.52998 .51238 m .53056 .50602 L .53037 .50607 L F
.53008 .50615 m .52998 .51238 L .53037 .50607 L F
.53186 .51424 m .52553 .50015 L .51876 .50179 L .655 .782 .942 r
F
.53156 .51208 m .53082 .5351 L .53173 .51206 L .66 .416 .54 r
F
.53156 .51208 m .53173 .51206 L .53197 .50584 L F
.53173 .51206 m .53082 .5351 L .53198 .51204 L F
.52876 .51298 m .52835 .51322 L .52837 .53619 L .4 .211 .506 r
F
.5264 .51436 m .52194 .51304 L .50439 .51486 L .655 .782 .942 r
F
.52751 .51371 m .52194 .51304 L .5264 .51436 L F
.52194 .51304 m .50548 .51105 L .50441 .51479 L F
.52194 .51304 m .50441 .51479 L .50439 .51486 L F
.53118 .51212 m .53079 .51216 L .53082 .5351 L .66 .416 .54 r
F
.53128 .50591 m .53118 .51212 L .53176 .50586 L F
.53118 .51212 m .53156 .51208 L .53176 .50586 L F
.53092 .51215 m .53273 .49948 L .52553 .50015 L .655 .782 .942 r
F
.53199 .51204 m .53273 .49948 L .53092 .51215 L F
.53118 .51212 m .53082 .5351 L .53156 .51208 L .66 .416 .54 r
F
.53238 .51206 m .53198 .51204 L .53203 .53501 L .734 .477 .539 r
F
.53393 .51229 m .53322 .53514 L .53409 .51233 L .81 .54 .53 r
F
.53402 .51231 m .53557 .51225 L .53418 .51217 L .655 .782 .942 r
F
.535 .51255 m .53557 .51225 L .53402 .51231 L F
.53557 .51225 m .55202 .5034 L .53418 .51217 L F
.53275 .51208 m .53203 .53501 L .53292 .51209 L .734 .477 .539 r
F
.53434 .51239 m .53322 .53514 L .53441 .5355 L .81 .54 .53 r
F
.53409 .51233 m .53322 .53514 L .53434 .51239 L F
.53306 .51208 m .54646 .50117 L .53988 .49983 L .655 .782 .942 r
F
.53305 .5121 m .53307 .51208 L .53306 .51208 L F
.53307 .51208 m .54646 .50117 L .53306 .51208 L F
.53418 .51217 m .54646 .50117 L .53305 .5121 L F
.53317 .51211 m .53203 .53501 L .53322 .53514 L .734 .477 .539 r
F
.53292 .51209 m .53203 .53501 L .53317 .51211 L F
.53356 .5122 m .53317 .51211 L .53322 .53514 L .81 .54 .53 r
F
.53473 .51262 m .53434 .51239 L .53441 .5355 L .911 .629 .497 r
F
.53356 .5122 m .53322 .53514 L .53393 .51229 L .81 .54 .53 r
F
.54109 .51403 m .5593 .51362 L .5593 .51361 L .655 .782 .942 r
F
.5411 .51403 m .5593 .51362 L .54109 .51403 L F
.58298 .50754 m .60865 .51069 L .61269 .49937 L .656 .78 .94 r
F
.55768 .51089 m .58368 .51406 L .58626 .50648 L .655 .781 .941 r
F
.54185 .51261 m .5593 .51361 L .55866 .50986 L .655 .782 .942 r
F
.53238 .51206 m .53203 .53501 L .53275 .51208 L .734 .477 .539 r
F
.5351 .51544 m .53544 .53877 L .53486 .5156 L .358 .18 .498 r
F
.53473 .51262 m .53441 .5355 L .53509 .51283 L .911 .629 .497 r
F
.52914 .51275 m .52837 .53619 L .52931 .51265 L .4 .211 .506 r
F
.52458 .51543 m .52255 .51445 L .51107 .51764 L .655 .782 .942 r
F
.5264 .51436 m .52255 .51445 L .52458 .51543 L F
.52255 .51445 m .50439 .51486 L .51107 .51764 L F
.52998 .51238 m .52958 .51249 L .52961 .53543 L .567 .342 .533 r
F
.52958 .51249 m .52837 .53619 L .52961 .53543 L .4 .211 .506 r
F
.52931 .51265 m .52837 .53619 L .52958 .51249 L F
.51165 .51842 m .49206 .52899 L .50309 .53325 L .655 .781 .941 r
F
.52018 .51802 m .51107 .51764 L .50776 .52204 L .655 .782 .942 r
F
.52458 .51543 m .51107 .51764 L .52018 .51802 L F
.51107 .51764 m .50517 .51861 L .50559 .51917 L F
.51107 .51764 m .50559 .51917 L .50776 .52204 L F
.52998 .51238 m .52961 .53543 L .53036 .51228 L .567 .342 .533 r
F
.5278 .5146 m .52784 .53798 L .52778 .51428 L .781 .623 .061 r
F
.52777 .51413 m .52784 .53798 L .52778 .53719 L F
.52778 .51428 m .52784 .53798 L .52777 .51413 L F
.5278 .5146 m .52782 .51483 L .52784 .53798 L F
.52809 .51522 m .52825 .53865 L .52796 .51504 L .988 .719 .384 r
F
.52809 .51522 m .52823 .51542 L .52825 .53865 L F
.52803 .52071 m .52825 .53865 L .52783 .53376 L F
.52783 .53376 m .52825 .53865 L .52784 .53798 L F
.52835 .51322 m .52778 .53719 L .52837 .53619 L 0 0 .377 r
F
.52822 .51341 m .52778 .53719 L .52835 .51322 L F
.52551 .51766 m .52018 .51802 L .51197 .52493 L .655 .782 .942 r
F
.5266 .51594 m .52018 .51802 L .52551 .51766 L F
.52018 .51802 m .50776 .52204 L .51034 .52381 L F
.52018 .51802 m .51034 .52381 L .51197 .52493 L F
.52876 .51298 m .52837 .53619 L .52914 .51275 L .4 .211 .506 r
F
.53079 .51216 m .52961 .53543 L .53082 .5351 L .567 .342 .533 r
F
.53036 .51228 m .52961 .53543 L .53079 .51216 L F
.52814 .51354 m .52778 .53719 L .52822 .51341 L 0 0 .377 r
F
.52551 .51766 m .51197 .52493 L .52494 .51855 L .655 .782 .942 r
F
.52161 .52374 m .51751 .52709 L .52158 .52379 L F
.52796 .51504 m .52803 .52071 L .52793 .51499 L .988 .719 .384 r
F
.52782 .51483 m .52803 .52071 L .52783 .53376 L F
.52793 .51499 m .52803 .52071 L .52782 .51483 L F
.52796 .51382 m .52778 .53719 L .52814 .51354 L 0 0 .377 r
F
.52158 .52379 m .51751 .52709 L .51925 .52743 L .655 .782 .942 r
F
.52158 .52379 m .51925 .52743 L .524 .52837 L F
.52796 .51382 m .52777 .51413 L .52778 .53719 L 0 0 .377 r
F
.53509 .51283 m .53441 .5355 L .53525 .51292 L .911 .629 .497 r
F
.53899 .5151 m .53946 .51538 L .54029 .51526 L .655 .782 .942 r
F
.53696 .51572 m .55508 .52097 L .54029 .51526 L F
.53537 .51526 m .53592 .53811 L .53544 .53877 L .08 0 .418 r
F
.53553 .51505 m .53592 .53811 L .53537 .51526 L F
.5355 .51306 m .53441 .5355 L .53557 .5363 L .911 .629 .497 r
F
.53525 .51292 m .53441 .5355 L .5355 .51306 L F
.5358 .51472 m .53585 .51466 L .53585 .51573 L .08 0 .418 r
F
.5358 .51472 m .53585 .51573 L .53592 .53811 L F
.53576 .51477 m .5358 .51472 L .53592 .53811 L F
.53568 .51486 m .53576 .51477 L .53592 .53811 L F
.53585 .51466 m .53606 .53732 L .53592 .53811 L 0 0 .15 r
F
.53587 .51451 m .53606 .53732 L .53585 .51466 L F
.53568 .51486 m .53592 .53811 L .53553 .51505 L .08 0 .418 r
F
.53581 .51364 m .53557 .5363 L .53588 .51376 L .983 .725 .332 r
F
.53593 .51419 m .53598 .51395 L .53606 .53732 L 0 0 .15 r
F
.53589 .51441 m .53606 .53732 L .53587 .51451 L F
.53593 .51419 m .53606 .53732 L .53589 .51441 L F
.53598 .51395 m .53557 .5363 L .53606 .53732 L .983 .725 .332 r
F
.53588 .51376 m .53557 .5363 L .53598 .51395 L F
.53566 .51336 m .5355 .51306 L .53557 .5363 L F
.53785 .51739 m .54472 .52647 L .55052 .52406 L .655 .782 .942 r
F
.54011 .52153 m .54472 .52647 L .53785 .51739 L F
.54073 .52267 m .54302 .52688 L .54472 .52647 L F
.53566 .51336 m .53557 .5363 L .53581 .51364 L .983 .725 .332 r
F
.57983 .7881 m .58807 .78685 L .58787 .7914 L .852 .609 .571 r
F
.57983 .7881 m .58003 .78354 L .58807 .78685 L F
0 g
.58807 .78685 m
.59306 .78808 L
s
.81391 .55741 m .81216 .54123 L .80174 .55494 L .653 .784 .944 r
F
.81391 .55741 m .83053 .54501 L .81216 .54123 L F
.44641 .89838 m .44619 .89563 L .44327 .89487 L .845 .582 .541 r
F
0 g
.44619 .89563 m
.44843 .89674 L
s
.70813 .27674 m .71278 .34072 L .71212 .34008 L .947 .644 .431 r
F
.70779 .27598 m .70813 .27674 L .71212 .34008 L .965 .686 .26 r
F
0 g
.70813 .27674 m
.70877 .27738 L
s
.62816 .79381 m .6283 .78925 L .63707 .78695 L .526 .332 .561 r
F
0 g
.62377 .78979 m
.6283 .78925 L
s
.76647 .65753 m .74663 .66121 L .74952 .6655 L .655 .809 .957 r
F
.43382 .89693 m .43259 .89506 L .42921 .89591 L .657 .813 .959 r
F
.43624 .89662 m .43259 .89506 L .43382 .89693 L F
.42983 .90103 m .42648 .89983 L .42427 .90126 L .657 .814 .959 r
F
.43176 .90024 m .42648 .89983 L .42983 .90103 L F
.31191 .56037 m .29715 .54862 L .28103 .55568 L .654 .782 .942 r
F
.32467 .5573 m .29715 .54862 L .31191 .56037 L F
.43624 .89662 m .43621 .89458 L .43259 .89506 L .657 .813 .959 r
F
.32467 .55083 m .31645 .53742 L .2972 .54211 L .655 .781 .941 r
F
.33854 .54956 m .31645 .53742 L .32467 .55083 L F
.43004 .90379 m .42447 .90401 L .42856 .90473 L .656 .814 .959 r
F
.58861 .67003 m .57949 .66252 L .56659 .66781 L .656 .808 .956 r
F
.59844 .66754 m .57949 .66252 L .58861 .67003 L F
.84296 .66288 m .84635 .65002 L .84731 .65537 L .056 .042 .523 r
F
.8439 .66822 m .84296 .66288 L .84731 .65537 L F
.82448 .66166 m .84296 .66288 L .84731 .65537 L .655 .81 .958 r
F
0 g
.83555 .66948 m
.84296 .66288 L
s
.44115 .89956 m .44008 .89726 L .43889 .89932 L .657 .814 .959 r
F
.44115 .89956 m .44349 .89762 L .44008 .89726 L F
.71563 .27613 m .72 .33861 L .71978 .33948 L 0 0 .297 r
F
.71563 .27613 m .71584 .27524 L .72 .33861 L F
0 g
.71509 .27687 m
.71563 .27613 L
s
.44888 .90224 m .44641 .89838 L .44663 .90114 L .914 .637 .503 r
F
0 g
.44888 .90224 m
.45028 .90361 L
s
.31621 .66452 m .29688 .66821 L .30145 .67249 L .659 .806 .954 r
F
.44332 .90282 m .44371 .90038 L .44137 .90232 L .656 .814 .959 r
F
.44332 .90282 m .44663 .90114 L .44371 .90038 L F
.62919 .67274 m .62628 .662 L .6198 .67148 L .656 .809 .957 r
F
.62919 .67274 m .64045 .66393 L .62628 .662 L F
.42668 .90259 m .42427 .90126 L .42447 .90401 L .4 .248 .557 r
F
.42668 .90259 m .42648 .89983 L .42427 .90126 L F
0 g
.42289 .90283 m
.42427 .90126 L
s
.70779 .27598 m .71212 .34008 L .71178 .33933 L .965 .686 .26 r
F
.70782 .27509 m .70779 .27598 L .71178 .33933 L 0 0 .132 r
F
0 g
.70789 .2762 m
.70813 .27674 L
s
.50305 .42239 m .46719 .42015 L .49955 .42708 L .642 .738 .918 r
F
.37455 .65792 m .39578 .65166 L .37565 .65292 L .659 .805 .953 r
F
.35498 .65669 m .37455 .65792 L .37565 .65292 L F
.22709 .40561 m .21117 .42328 L .23303 .41015 L .642 .739 .919 r
F
.22709 .40561 m .19926 .41432 L .21117 .42328 L F
.56436 .43048 m .59132 .41683 L .56133 .42545 L .642 .738 .918 r
F
.56436 .43048 m .59723 .42698 L .59132 .41683 L F
.33854 .54956 m .33746 .53549 L .31645 .53742 L .655 .781 .941 r
F
.39557 .54655 m .37843 .53378 L .37852 .54025 L .852 .597 .553 r
F
.39569 .55302 m .39557 .54655 L .37852 .54025 L F
0 g
.39557 .54655 m
.40863 .55487 L
s
.39502 .66982 m .39643 .65699 L .39679 .66235 L 0 0 .283 r
F
.3754 .66862 m .39502 .66982 L .39679 .66235 L .658 .806 .954 r
F
0 g
.38929 .67696 m
.39502 .66982 L
s
.80094 .54847 m .79076 .53374 L .78735 .54784 L .653 .783 .943 r
F
.80094 .54847 m .81133 .53471 L .79076 .53374 L F
.43176 .90024 m .42938 .89864 L .42648 .89983 L .657 .814 .959 r
F
.43402 .89967 m .42938 .89864 L .43176 .90024 L F
.28087 .41266 m .30604 .42826 L .31603 .42045 L .642 .739 .919 r
F
.27421 .41554 m .30604 .42826 L .28087 .41266 L F
.82006 .67182 m .8439 .66822 L .8254 .66702 L .654 .811 .959 r
F
.80415 .66822 m .82006 .67182 L .8254 .66702 L F
.80043 .67038 m .82006 .67182 L .80415 .66822 L F
.2256 .38427 m .20203 .39815 L .22961 .38943 L .643 .737 .917 r
F
.2256 .38427 m .19388 .38792 L .20203 .39815 L F
.42938 .89864 m .42627 .89707 L .42648 .89983 L .526 .341 .573 r
F
.42938 .89864 m .42918 .89589 L .42627 .89707 L F
0 g
.42406 .8985 m
.42627 .89707 L
s
.43889 .89932 m .43643 .89731 L .43645 .89935 L .657 .814 .959 r
F
.43889 .89932 m .44008 .89726 L .43643 .89731 L F
.66506 .39648 m .65913 .42059 L .67828 .4038 L .643 .737 .917 r
F
.66506 .39648 m .63936 .4098 L .65913 .42059 L F
0 g
.65913 .42059 m
.68259 .42789 L
s
.25824 .36926 m .25992 .36905 L .25864 .38345 L .636 .39 .528 r
F
.25867 .38386 m .25877 .38538 L .25904 .38356 L .643 .737 .917 r
F
.25877 .38538 m .25984 .40118 L .25909 .3848 L F
.25877 .38538 m .25909 .3848 L .25904 .38356 L F
.25788 .38374 m .25795 .38442 L .25864 .38345 L F
.26163 .368 m .262 .36729 L .26071 .38186 L 0 0 .268 r
F
.25818 .38645 m .25984 .40118 L .25877 .38538 L .643 .737 .917 r
F
.25903 .38342 m .25984 .40118 L .26066 .40116 L F
.2607 .38654 m .26066 .40116 L .26841 .40094 L F
.25903 .38342 m .26066 .40116 L .2607 .38654 L F
.25824 .36926 m .25864 .38345 L .25733 .38356 L .636 .39 .528 r
F
.25652 .36899 m .25824 .36926 L .25696 .38359 L .751 .492 .54 r
F
.25459 .36788 m .25539 .3685 L .2541 .38277 L .913 .647 .523 r
F
.2585 .38926 m .25112 .40004 L .25984 .40118 L .643 .737 .917 r
F
.25811 .38583 m .25726 .38756 L .2585 .38926 L F
.25726 .38756 m .25112 .40004 L .2585 .38926 L F
.25408 .36715 m .25459 .36788 L .25329 .38216 L .98 .727 .476 r
F
.25756 .38541 m .25685 .38701 L .25811 .38583 L .643 .737 .917 r
F
.25685 .38701 m .25112 .40004 L .25726 .38756 L F
.25685 .38701 m .25726 .38756 L .25811 .38583 L F
.25764 .38435 m .25728 .3852 L .25796 .38449 L F
.25728 .3852 m .25112 .40004 L .25756 .38541 L F
.25728 .3852 m .25756 .38541 L .25796 .38449 L F
.25776 .38374 m .25753 .3843 L .25788 .38376 L F
.25753 .3843 m .25112 .40004 L .25764 .38435 L F
.25753 .3843 m .25764 .38435 L .25788 .38376 L F
.25653 .38363 m .25112 .40004 L .25776 .38374 L F
.25696 .38359 m .25776 .38374 L .25785 .38352 L F
.25653 .38363 m .25776 .38374 L .25696 .38359 L F
.25652 .36899 m .25561 .38334 L .25523 .38327 L .751 .492 .54 r
F
.25539 .3685 m .25652 .36899 L .25523 .38327 L .839 .573 .538 r
F
.25539 .3685 m .25523 .38327 L .25435 .38288 L F
.25652 .36899 m .25696 .38359 L .25561 .38334 L .751 .492 .54 r
F
.25824 .36926 m .25733 .38356 L .25696 .38359 L .636 .39 .528 r
F
.2546 .38949 m .24282 .39758 L .25112 .40004 L .643 .737 .917 r
F
.25752 .38061 m .25361 .38513 L .2546 .38949 L F
.2539 .3663 m .25408 .36715 L .25278 .38145 L .952 .765 .308 r
F
.2539 .3663 m .25278 .38145 L .25263 .38082 L F
.25408 .36715 m .25289 .38161 L .25278 .38145 L .98 .727 .476 r
F
.25408 .36715 m .25329 .38216 L .25289 .38161 L F
.25361 .38513 m .24816 .39142 L .2546 .38949 L .643 .737 .917 r
F
.24816 .39142 m .24672 .3949 L .2546 .38949 L F
.24816 .39142 m .23548 .39397 L .24282 .39758 L F
.25361 .38513 m .25003 .38687 L .24816 .39142 L F
.25003 .38687 m .23548 .39397 L .24816 .39142 L F
.25318 .38324 m .23548 .39397 L .25361 .38513 L F
.25224 .39822 m .25776 .39552 L .25755 .39868 L .731 .477 .544 r
F
.25224 .39822 m .25245 .39506 L .25776 .39552 L F
.25473 .40102 m .24997 .40816 L .25656 .40903 L .642 .738 .918 r
F
.25318 .40081 m .25755 .39868 L .25738 .40136 L .731 .477 .544 r
F
.25243 .40071 m .24997 .40816 L .25473 .40102 L .642 .738 .918 r
F
.25318 .40081 m .25224 .39822 L .25755 .39868 L .731 .477 .544 r
F
.25207 .40067 m .25224 .39822 L .25318 .40081 L F
.25539 .3685 m .25435 .38288 L .2541 .38277 L .839 .573 .538 r
F
.25459 .36788 m .25347 .38229 L .25329 .38216 L .913 .647 .523 r
F
.25459 .36788 m .2541 .38277 L .25347 .38229 L F
.25752 .38061 m .24638 .38413 L .23548 .39397 L .643 .737 .917 r
F
.24638 .38413 m .22961 .38943 L .23379 .39265 L F
.24638 .38413 m .23379 .39265 L .23548 .39397 L F
.2554 .36441 m .25431 .36523 L .253 .37964 L .329 .133 .455 r
F
.24718 .39691 m .25245 .39506 L .25224 .39822 L .792 .532 .544 r
F
.25377 .39089 m .25247 .395 L .25775 .39546 L .668 .746 .909 r
F
.25355 .39409 m .25224 .39822 L .25755 .39868 L F
.25241 .40077 m .24779 .3994 L .24997 .40816 L .642 .738 .918 r
F
.24838 .39958 m .24718 .39691 L .25224 .39822 L .792 .532 .544 r
F
.24739 .39935 m .2416 .4057 L .24442 .40653 L .642 .738 .918 r
F
.24741 .39929 m .24736 .39934 L .24739 .39935 L F
.24736 .39934 m .2416 .4057 L .24739 .39935 L F
.24722 .39923 m .2416 .4057 L .24741 .39929 L F
.24396 .39767 m .24718 .39691 L .24703 .39918 L .852 .588 .538 r
F
.24703 .39918 m .24718 .39691 L .24838 .39958 L .792 .532 .544 r
F
.24763 .39876 m .23421 .40207 L .2416 .4057 L .642 .738 .918 r
F
.24638 .38413 m .2256 .38427 L .22961 .38943 L .643 .737 .917 r
F
.25752 .38061 m .25037 .38143 L .24638 .38413 L F
.25037 .38143 m .2256 .38427 L .24638 .38413 L F
.24718 .39691 m .2474 .39376 L .25245 .39506 L .792 .532 .544 r
F
.25041 .39002 m .25247 .395 L .25377 .39089 L .668 .746 .909 r
F
.25041 .39002 m .24744 .3937 L .25247 .395 L F
.25017 .39321 m .25224 .39822 L .25355 .39409 L F
.25017 .39321 m .24718 .39691 L .25224 .39822 L F
.24816 .39142 m .24282 .39758 L .24672 .3949 L .643 .737 .917 r
F
.24273 .39485 m .2474 .39376 L .24718 .39691 L .852 .588 .538 r
F
.24273 .39485 m .24295 .39169 L .2474 .39376 L F
.24746 .38864 m .24744 .3937 L .25041 .39002 L .668 .746 .909 r
F
.24746 .38864 m .24302 .39165 L .24744 .3937 L F
.2472 .39183 m .24718 .39691 L .25017 .39321 L F
.2534 .38632 m .25041 .39002 L .25377 .39089 L F
.25317 .3895 m .25017 .39321 L .25355 .39409 L F
.25168 .38881 m .25017 .39321 L .25304 .38966 L F
.25299 .38941 m .25304 .38966 L .25317 .3895 L F
.25168 .38881 m .25304 .38966 L .25299 .38941 L F
.25192 .38563 m .25041 .39002 L .2534 .38632 L F
.2539 .3663 m .25263 .38082 L .25259 .38064 L .952 .765 .308 r
F
.25431 .36523 m .2539 .3663 L .25259 .38064 L 0 0 .188 r
F
.25431 .36523 m .25259 .38064 L .25291 .37987 L F
.23952 .38267 m .22374 .37883 L .2256 .38427 L .643 .737 .917 r
F
.25752 .38061 m .24921 .38017 L .23952 .38267 L F
.24921 .38017 m .22374 .37883 L .23952 .38267 L F
.25654 .36405 m .2554 .36441 L .25409 .37891 L .55 .315 .512 r
F
.25192 .38563 m .24746 .38864 L .25041 .39002 L .668 .746 .909 r
F
.25168 .38881 m .2472 .39183 L .25017 .39321 L F
.25285 .39276 m .25027 .39238 L .24763 .39876 L .642 .738 .918 r
F
.25752 .38061 m .25318 .38324 L .25361 .38513 L .643 .737 .917 r
F
.25416 .38537 m .25192 .38563 L .2534 .38632 L .668 .746 .909 r
F
.25355 .38453 m .25192 .38563 L .25416 .38537 L F
.2534 .38632 m .25377 .39089 L .25508 .38676 L F
.25377 .39089 m .25775 .39546 L .2573 .3912 L F
.25508 .38676 m .25377 .39089 L .2573 .3912 L F
.25317 .3895 m .25355 .39409 L .25486 .38994 L F
.25435 .38288 m .25422 .38467 L .2541 .38277 L .839 .573 .538 r
F
.25542 .38566 m .2534 .38632 L .25508 .38676 L .668 .746 .909 r
F
.25556 .38523 m .25513 .38544 L .25542 .38566 L F
.25513 .38544 m .2534 .38632 L .25542 .38566 L F
.25347 .38229 m .2541 .38277 L .25393 .38455 L .913 .647 .523 r
F
.25545 .38518 m .2534 .38632 L .25556 .38523 L .668 .746 .909 r
F
.25451 .38494 m .2534 .38632 L .25545 .38518 L F
.25507 .38503 m .25545 .38518 L .2556 .3851 L F
.25451 .38494 m .25545 .38518 L .25507 .38503 L F
.25435 .38288 m .25523 .38327 L .25507 .38503 L .839 .573 .538 r
F
.2546 .38483 m .25355 .38453 L .25416 .38537 L .668 .746 .909 r
F
.25367 .38445 m .25355 .38453 L .2546 .38483 L F
.25381 .39166 m .25247 .39106 L .25285 .39276 L .642 .738 .918 r
F
.2542 .39122 m .25343 .39115 L .25381 .39166 L F
.25343 .39115 m .25247 .39106 L .25381 .39166 L F
.25436 .39103 m .25396 .39104 L .2542 .39122 L F
.25396 .39104 m .25247 .39106 L .2542 .39122 L F
.25329 .39056 m .25247 .39106 L .25396 .39104 L F
.25339 .3906 m .25396 .39104 L .25436 .39103 L F
.25329 .39056 m .25396 .39104 L .25339 .3906 L F
.25435 .38288 m .25507 .38503 L .25422 .38467 L .839 .573 .538 r
F
.25347 .38229 m .25393 .38455 L .25333 .3841 L .913 .647 .523 r
F
.25422 .38467 m .25397 .38457 L .2541 .38277 L .839 .573 .538 r
F
.25523 .38327 m .25513 .38503 L .25507 .38503 L .751 .492 .54 r
F
.2541 .38277 m .25397 .38457 L .25393 .38455 L .839 .573 .538 r
F
.25289 .38161 m .25329 .38216 L .25313 .38396 L .98 .727 .476 r
F
.25289 .38161 m .25313 .38396 L .25282 .38353 L F
.25355 .38453 m .25074 .38473 L .25192 .38563 L .668 .746 .909 r
F
.25347 .38229 m .25333 .3841 L .25329 .38216 L .913 .647 .523 r
F
.25313 .38396 m .25277 .38397 L .25355 .38453 L .668 .746 .909 r
F
.25277 .38397 m .2529 .38458 L .25355 .38453 L F
.25247 .39106 m .25027 .39238 L .25285 .39276 L .642 .738 .918 r
F
.25375 .3967 m .24763 .39876 L .24779 .3994 L F
.24838 .39958 m .25224 .39822 L .25207 .40067 L .792 .532 .544 r
F
.25375 .3967 m .24779 .3994 L .25241 .40077 L .642 .738 .918 r
F
.24763 .39876 m .24442 .40653 L .24997 .40816 L F
.24696 .40007 m .24838 .39958 L .25202 .40138 L .792 .532 .544 r
F
.24838 .39958 m .25207 .40067 L .25202 .40138 L F
.25285 .39276 m .24763 .39876 L .25375 .3967 L .642 .738 .918 r
F
.24396 .39767 m .24273 .39485 L .24718 .39691 L .852 .588 .538 r
F
.24258 .39699 m .24273 .39485 L .24396 .39767 L F
.2472 .39183 m .24273 .39485 L .24718 .39691 L .668 .746 .909 r
F
.25027 .39238 m .2426 .39701 L .24763 .39876 L .642 .738 .918 r
F
.2426 .39701 m .23421 .40207 L .24554 .39928 L F
.2426 .39701 m .24554 .39928 L .24763 .39876 L F
.24022 .39517 m .24273 .39485 L .24258 .39699 L .915 .65 .521 r
F
.23918 .39217 m .24295 .39169 L .24273 .39485 L F
.24022 .39517 m .23918 .39217 L .24273 .39485 L F
.24511 .38686 m .24302 .39165 L .24746 .38864 L .668 .746 .909 r
F
.24483 .39004 m .24273 .39485 L .2472 .39183 L F
.23918 .39217 m .2394 .38901 L .24295 .39169 L .915 .65 .521 r
F
.24511 .38686 m .23948 .38898 L .24302 .39165 L .668 .746 .909 r
F
.24483 .39004 m .23918 .39217 L .24273 .39485 L F
.25027 .39238 m .24382 .39319 L .24102 .39578 L .642 .738 .918 r
F
.24116 .39589 m .24102 .39578 L .24071 .39607 L F
.25027 .39238 m .24102 .39578 L .24116 .39589 L F
.23903 .39425 m .23918 .39217 L .24022 .39517 L .915 .65 .521 r
F
.24013 .39568 m .22828 .39753 L .23254 .40079 L .642 .738 .918 r
F
.24382 .39319 m .23921 .39448 L .24013 .39568 L F
.23921 .39448 m .22828 .39753 L .24013 .39568 L F
.23744 .39219 m .23918 .39217 L .23903 .39425 L .977 .72 .476 r
F
.2505 .38791 m .2472 .39183 L .25168 .38881 L .668 .746 .909 r
F
.2505 .38791 m .24483 .39004 L .2472 .39183 L F
.25248 .38992 m .24536 .39216 L .25303 .3906 L .642 .738 .918 r
F
.24536 .39216 m .24382 .39319 L .25304 .39062 L F
.25303 .3906 m .25304 .39062 L .25331 .39055 L F
.24536 .39216 m .25304 .39062 L .25303 .3906 L F
.25277 .38397 m .25074 .38473 L .2529 .38458 L .668 .746 .909 r
F
.25277 .38397 m .24995 .38369 L .25074 .38473 L F
.25274 .38384 m .24995 .38369 L .25277 .38397 L F
.25261 .38324 m .25207 .38333 L .2527 .38367 L F
.25207 .38333 m .25189 .3838 L .25274 .38384 L F
.2527 .38367 m .25274 .38384 L .25306 .38386 L F
.25207 .38333 m .25274 .38384 L .2527 .38367 L F
.25263 .38082 m .25248 .38262 L .25259 .38064 L .952 .765 .308 r
F
.25333 .3841 m .25308 .38726 L .25316 .38398 L .913 .647 .523 r
F
.25393 .38856 m .25271 .38811 L .25317 .3895 L .668 .746 .909 r
F
.25427 .38814 m .25361 .38813 L .25393 .38856 L F
.25361 .38813 m .25271 .38811 L .25393 .38856 L F
.25306 .38386 m .25274 .38384 L .25277 .38397 L F
.25306 .38386 m .25302 .38388 L .25313 .38396 L F
.25302 .38388 m .25277 .38397 L .25313 .38396 L F
.25282 .38353 m .25313 .38396 L .25284 .38708 L .98 .727 .476 r
F
.25271 .38811 m .25168 .38881 L .25299 .38941 L .668 .746 .909 r
F
.25282 .38353 m .25284 .38708 L .2527 .38688 L .98 .727 .476 r
F
.25308 .38726 m .253 .3872 L .25316 .38398 L .913 .647 .523 r
F
.25271 .38811 m .2505 .38791 L .25168 .38881 L .668 .746 .909 r
F
.25365 .38768 m .25271 .38811 L .25427 .38814 L F
.25351 .38757 m .25346 .3876 L .25365 .38768 L F
.25346 .3876 m .25271 .38811 L .25365 .38768 L F
.25422 .38467 m .25507 .38503 L .25479 .38815 L .839 .573 .538 r
F
.25422 .38467 m .25479 .38815 L .25399 .38782 L F
.2533 .38771 m .2525 .38715 L .25271 .38811 L .668 .746 .909 r
F
.25351 .38757 m .25307 .38739 L .2533 .38771 L F
.25307 .38739 m .2525 .38715 L .2533 .38771 L F
.2525 .38715 m .25134 .38759 L .25271 .38811 L F
.25134 .38759 m .2505 .38791 L .25119 .38797 L F
.25134 .38759 m .25119 .38797 L .25271 .38811 L F
.25248 .38262 m .25245 .38248 L .25259 .38064 L .952 .765 .308 r
F
.25263 .38082 m .2525 .38275 L .25248 .38262 L F
.25263 .38082 m .25252 .38283 L .2525 .38275 L F
.25289 .38161 m .25274 .38342 L .25278 .38145 L .98 .727 .476 r
F
.25274 .38342 m .25265 .3833 L .25278 .38145 L F
.25261 .38324 m .25215 .38314 L .25207 .38333 L .668 .746 .909 r
F
.25265 .3833 m .25263 .38327 L .25278 .38145 L .98 .727 .476 r
F
.25261 .38325 m .25238 .38645 L .25233 .38638 L F
.25278 .38145 m .25263 .38327 L .25261 .38325 L F
.25263 .38327 m .25238 .38645 L .25261 .38325 L F
.25213 .38259 m .24971 .38146 L .2496 .38257 L .668 .746 .909 r
F
.25333 .3841 m .25316 .38398 L .25329 .38216 L .913 .647 .523 r
F
.25263 .38082 m .25278 .38145 L .25261 .38325 L .952 .765 .308 r
F
.25263 .38082 m .25261 .38325 L .25252 .38283 L F
.25329 .38216 m .25316 .38398 L .25313 .38396 L .913 .647 .523 r
F
.25289 .38161 m .25282 .38353 L .25274 .38342 L .98 .727 .476 r
F
.25247 .38259 m .25243 .38241 L .25236 .38259 L .668 .746 .909 r
F
.25639 .38261 m .25236 .38259 L .25261 .38324 L F
.2525 .38715 m .25155 .38705 L .25134 .38759 L F
.25247 .38702 m .25159 .38697 L .2525 .38715 L F
.25074 .38473 m .24746 .38864 L .25192 .38563 L F
.25159 .38697 m .2497 .38686 L .25155 .38705 L F
.25159 .38697 m .25155 .38705 L .2525 .38715 L F
.25235 .38641 m .25234 .38642 L .25281 .38704 L F
.25234 .38642 m .25176 .38651 L .25247 .38702 L F
.25176 .38651 m .25159 .38697 L .25247 .38702 L F
.25639 .38261 m .25261 .38196 L .25243 .38241 L F
.25639 .38261 m .25243 .38241 L .25247 .38259 L F
.25213 .38259 m .2496 .38257 L .25261 .38324 L F
.25259 .38064 m .25244 .38244 L .25243 .38241 L .952 .765 .308 r
F
.25245 .38248 m .25244 .38244 L .25259 .38064 L F
.2554 .36441 m .253 .37964 L .25385 .37907 L .329 .133 .455 r
F
.25431 .36523 m .25291 .37987 L .253 .37964 L 0 0 .188 r
F
.25752 .38061 m .25205 .37944 L .24921 .38017 L .643 .737 .917 r
F
.25639 .38261 m .25286 .38134 L .25261 .38196 L .668 .746 .909 r
F
.25286 .38134 m .25285 .38135 L .25261 .38196 L F
.23159 .37507 m .22691 .36858 L .22418 .37348 L .643 .737 .917 r
F
.25771 .36396 m .25654 .36405 L .25523 .37861 L .656 .407 .53 r
F
.25752 .38061 m .25271 .37871 L .2493 .37885 L .643 .737 .917 r
F
.2525 .38275 m .25228 .38614 L .25248 .38262 L .952 .765 .308 r
F
.25228 .38614 m .25226 .38608 L .25248 .38262 L F
.25243 .38651 m .25238 .38645 L .25263 .38327 L .98 .727 .476 r
F
.25234 .38642 m .25247 .38702 L .25281 .38704 L .668 .746 .909 r
F
.25261 .38324 m .2527 .38367 L .25261 .38325 L F
.25244 .38653 m .25263 .38327 L .25265 .3833 L .98 .727 .476 r
F
.25224 .38953 m .25243 .38651 L .25244 .38653 L F
.25243 .38651 m .25263 .38327 L .25244 .38653 L F
.25074 .38473 m .24511 .38686 L .24746 .38864 L .668 .746 .909 r
F
.24995 .38369 m .24511 .38686 L .25074 .38473 L F
.25187 .38575 m .24946 .38462 L .24935 .38574 L F
.25274 .38342 m .25266 .38683 L .25248 .38659 L .98 .727 .476 r
F
.25261 .38325 m .2527 .38367 L .25306 .38386 L .668 .746 .909 r
F
.25639 .38261 m .25261 .38324 L .25306 .38386 L F
.25274 .38342 m .25248 .38659 L .25265 .3833 L .98 .727 .476 r
F
.25248 .38659 m .25224 .38953 L .25244 .38653 L F
.25248 .38659 m .25244 .38653 L .25265 .3833 L F
.25127 .38492 m .25003 .38357 L .24946 .38462 L .668 .746 .909 r
F
.25639 .38261 m .25306 .38386 L .25313 .38396 L F
.25508 .38676 m .2573 .3912 L .25685 .38691 L F
.25561 .38334 m .2555 .38509 L .25523 .38327 L .751 .492 .54 r
F
.25668 .38529 m .25508 .38676 L .25685 .38691 L .668 .746 .909 r
F
.25667 .38525 m .25662 .3853 L .25668 .38529 L F
.25662 .3853 m .25508 .38676 L .25668 .38529 L F
.25375 .3967 m .25656 .40903 L .25875 .40932 L .642 .738 .918 r
F
.26095 .3686 m .26035 .38252 L .25982 .38294 L .269 .086 .437 r
F
.26095 .3686 m .25982 .38294 L .25967 .38306 L F
.25992 .36905 m .25887 .38336 L .25864 .38345 L .487 .263 .5 r
F
.26163 .368 m .26071 .38186 L .26043 .38237 L 0 0 .268 r
F
.262 .36729 m .262 .36644 L .26071 .38106 L .796 .683 .137 r
F
.25989 .38297 m .2607 .38469 L .26071 .38379 L .643 .737 .917 r
F
.25898 .38332 m .26841 .40094 L .25989 .38297 L F
.25992 .36905 m .26095 .3686 L .25967 .38306 L .487 .263 .5 r
F
.25992 .36905 m .25967 .38306 L .25887 .38336 L F
.26095 .3686 m .26163 .368 L .26035 .38252 L .269 .086 .437 r
F
.26163 .368 m .26043 .38237 L .26035 .38252 L 0 0 .268 r
F
.26223 .38355 m .27625 .39933 L .28286 .39645 L .643 .737 .917 r
F
.25752 .38061 m .26498 .38806 L .26223 .38355 L F
.26498 .38806 m .27625 .39933 L .26223 .38355 L F
.262 .36729 m .26071 .38168 L .26071 .38186 L .796 .683 .137 r
F
.26135 .38211 m .28286 .39645 L .28778 .39248 L .643 .737 .917 r
F
.25752 .38061 m .26223 .38355 L .26135 .38211 L F
.26223 .38355 m .28286 .39645 L .26135 .38211 L F
.262 .36644 m .26137 .36535 L .26007 .38001 L .991 .745 .452 r
F
.25752 .38061 m .25898 .38332 L .25989 .38297 L .643 .737 .917 r
F
.25604 .40351 m .25543 .40459 L .25764 .41739 L .642 .739 .919 r
F
.25543 .40459 m .24895 .41625 L .25764 .41739 L F
.25785 .40142 m .25738 .40136 L .25875 .40932 L .642 .738 .918 r
F
.25738 .40136 m .2555 .40112 L .25562 .40141 L F
.25738 .40136 m .25562 .40141 L .25875 .40932 L F
.2581 .40134 m .25755 .39868 L .26277 .39826 L .663 .418 .539 r
F
.25738 .40136 m .25755 .39868 L .2581 .40134 L F
.26071 .38379 m .26841 .40094 L .27625 .39933 L .643 .737 .917 r
F
.2607 .38469 m .26841 .40094 L .26071 .38379 L F
.25858 .38677 m .26077 .39092 L .26394 .39008 L .668 .746 .909 r
F
.25685 .38691 m .26077 .39092 L .25858 .38677 L F
.26017 .38635 m .26394 .39008 L .26661 .38873 L F
.25858 .38677 m .26394 .39008 L .26017 .38635 L F
.26017 .38635 m .26661 .38873 L .26151 .38567 L F
.26077 .39092 m .26294 .39505 L .26769 .39379 L F
.26394 .39008 m .26769 .39379 L .27169 .39178 L F
.26077 .39092 m .26769 .39379 L .26394 .39008 L F
.25999 .38953 m .26378 .39327 L .26646 .39192 L F
.2573 .3912 m .26294 .39505 L .26077 .39092 L F
.25685 .38691 m .2573 .3912 L .26077 .39092 L F
.25847 .38993 m .26378 .39327 L .25999 .38953 L F
.25839 .38995 m .25844 .38998 L .25847 .38993 L F
.25844 .38998 m .26378 .39327 L .25847 .38993 L F
.25755 .39868 m .25776 .39552 L .26297 .39511 L .663 .418 .539 r
F
.2573 .3912 m .25775 .39546 L .26294 .39505 L .668 .746 .909 r
F
.25755 .39868 m .26297 .39511 L .26277 .39826 L .663 .418 .539 r
F
.2571 .39439 m .25755 .39868 L .26277 .39826 L .668 .746 .909 r
F
.2581 .40134 m .26277 .39826 L .26259 .40121 L .663 .418 .539 r
F
.2571 .39439 m .26277 .39826 L .26059 .39412 L .668 .746 .909 r
F
.25664 .39009 m .2571 .39439 L .26059 .39412 L F
.25846 .39251 m .25925 .40131 L .26001 .39538 L .642 .738 .918 r
F
.25925 .40131 m .25997 .40928 L .25999 .40129 L F
.25925 .40131 m .25999 .40129 L .26001 .39538 L F
.25846 .39251 m .25875 .40932 L .25997 .40928 L F
.26309 .40111 m .25997 .40928 L .26738 .40908 L F
.26287 .40116 m .26277 .39826 L .26755 .397 L .58 .348 .529 r
F
.26259 .40121 m .26277 .39826 L .26287 .40116 L F
.25999 .40175 m .25997 .40928 L .26309 .40111 L .642 .738 .918 r
F
.26613 .40049 m .26755 .397 L .26736 .40016 L .58 .348 .529 r
F
.26309 .40111 m .26738 .40908 L .26777 .40241 L .642 .738 .918 r
F
.26613 .40049 m .26777 .40241 L .2679 .40012 L F
.26309 .40111 m .26777 .40241 L .26613 .40049 L F
.26257 .40142 m .26287 .40116 L .26613 .40049 L .58 .348 .529 r
F
.26287 .40116 m .26755 .397 L .26613 .40049 L F
.26504 .3992 m .26613 .40049 L .26736 .40016 L .667 .747 .91 r
F
.26277 .39826 m .26297 .39511 L .26775 .39385 L .58 .348 .529 r
F
.26277 .39826 m .26775 .39385 L .26755 .397 L F
.26059 .39412 m .26277 .39826 L .26755 .397 L .668 .746 .909 r
F
.26059 .39412 m .26755 .397 L .26378 .39327 L F
.26736 .40016 m .26755 .397 L .27157 .39498 L .464 .252 .506 r
F
.26736 .40016 m .27157 .39498 L .27138 .39814 L F
.26358 .39644 m .26736 .40016 L .27138 .39814 L .667 .747 .91 r
F
.26284 .39663 m .26736 .40016 L .26358 .39644 L F
.25839 .38995 m .26059 .39412 L .26378 .39327 L .668 .746 .909 r
F
.26056 .39395 m .26309 .40111 L .26613 .40049 L .642 .738 .918 r
F
.26001 .39359 m .26309 .40111 L .26056 .39395 L F
.26755 .397 m .26775 .39385 L .27176 .39182 L .464 .252 .506 r
F
.26755 .397 m .27176 .39182 L .27157 .39498 L F
.26378 .39327 m .26755 .397 L .27157 .39498 L .668 .746 .909 r
F
.25664 .39009 m .26059 .39412 L .25839 .38995 L F
.25979 .39269 m .26358 .39644 L .26626 .39508 L .667 .747 .91 r
F
.26001 .39359 m .26056 .39395 L .26001 .39331 L .642 .738 .918 r
F
.26029 .38938 m .26646 .39192 L .26133 .38885 L .668 .746 .909 r
F
.25999 .38953 m .26029 .38964 L .26029 .38938 L F
.26029 .38964 m .26646 .39192 L .26029 .38938 L F
.25986 .38468 m .26017 .38635 L .26151 .38567 L F
.26058 .3841 m .26151 .38567 L .26249 .38479 L F
.25982 .38294 m .26035 .38252 L .26022 .38399 L .269 .086 .437 r
F
.26022 .38399 m .26057 .38511 L .26023 .38398 L .668 .746 .909 r
F
.2596 .38453 m .25986 .38468 L .26022 .38399 L F
.25986 .38468 m .26057 .38511 L .26022 .38399 L F
.25887 .38336 m .25967 .38306 L .25954 .38458 L .487 .263 .5 r
F
.25795 .38442 m .25818 .38645 L .25867 .38386 L .643 .737 .917 r
F
.25818 .38645 m .25877 .38538 L .25867 .38386 L F
.25796 .38528 m .25858 .38677 L .2588 .38672 L .668 .746 .909 r
F
.25939 .38557 m .2588 .38672 L .26017 .38635 L F
.25796 .38449 m .25756 .38541 L .25811 .38583 L .643 .737 .917 r
F
.25788 .38376 m .25764 .38435 L .25796 .38449 L F
.25752 .38061 m .25653 .38363 L .25785 .38352 L F
.25881 .385 m .2588 .38672 L .25939 .38557 L .668 .746 .909 r
F
.25733 .38356 m .25723 .38521 L .25696 .38359 L .636 .39 .528 r
F
.25795 .38442 m .25867 .38386 L .25864 .38345 L .643 .737 .917 r
F
.2585 .38504 m .2588 .38672 L .25881 .385 L .668 .746 .909 r
F
.25787 .38513 m .25796 .38528 L .2585 .38504 L F
.25796 .38528 m .2588 .38672 L .2585 .38504 L F
.25864 .38345 m .25867 .38386 L .25903 .38342 L .643 .737 .917 r
F
.25887 .38336 m .25875 .38493 L .25864 .38345 L .487 .263 .5 r
F
.25874 .38493 m .2585 .38504 L .25881 .385 L .668 .746 .909 r
F
.25783 .38534 m .25858 .38677 L .25796 .38528 L F
.25875 .38493 m .25853 .38503 L .25864 .38345 L .487 .263 .5 r
F
.25864 .38345 m .25853 .38503 L .2585 .38504 L F
.25867 .38386 m .25904 .38356 L .25903 .38342 L .643 .737 .917 r
F
.25887 .38336 m .25954 .38458 L .25875 .38493 L .487 .263 .5 r
F
.25785 .38352 m .25776 .38374 L .25788 .38376 L .643 .737 .917 r
F
.2596 .38453 m .25939 .38557 L .25986 .38468 L .668 .746 .909 r
F
.25892 .38511 m .25939 .38557 L .2596 .38453 L F
.25939 .38557 m .26017 .38635 L .25986 .38468 L F
.25846 .39251 m .26309 .40111 L .25978 .39304 L .642 .738 .918 r
F
.25355 .39409 m .25755 .39868 L .2571 .39439 L .668 .746 .909 r
F
.25711 .39495 m .25875 .40932 L .25846 .39251 L .642 .738 .918 r
F
.25818 .39312 m .26168 .39527 L .25954 .39276 L .667 .747 .91 r
F
.25913 .38868 m .25847 .38993 L .25999 .38953 L .668 .746 .909 r
F
.25846 .39251 m .25978 .39304 L .25881 .39189 L .642 .738 .918 r
F
.25886 .39178 m .25818 .39312 L .25979 .39269 L .667 .747 .91 r
F
.25966 .39025 m .26113 .39202 L .26171 .39149 L F
.25966 .39025 m .26171 .39149 L .26132 .39084 L F
.25931 .39093 m .26113 .39202 L .25966 .39025 L F
.25958 .3878 m .25999 .38953 L .26029 .38938 L .668 .746 .909 r
F
.2603 .38823 m .26029 .38938 L .26133 .38885 L F
.25958 .3878 m .26029 .38938 L .2603 .38823 L F
.26053 .38339 m .26071 .38186 L .26059 .38329 L 0 0 .268 r
F
.26023 .38398 m .26057 .38511 L .26058 .3841 L .668 .746 .909 r
F
.26058 .38333 m .26249 .38479 L .26307 .38375 L F
.26022 .38399 m .25998 .38705 L .25994 .38712 L 0 0 .268 r
F
.26035 .38252 m .26023 .38397 L .26022 .38399 L F
.26023 .38397 m .25998 .38705 L .26022 .38399 L F
.26057 .38332 m .26058 .3841 L .26058 .38333 L .668 .746 .909 r
F
.25982 .38294 m .25971 .38443 L .25967 .38306 L .269 .086 .437 r
F
.25971 .38443 m .25946 .38753 L .2596 .38452 L F
.25971 .38443 m .2596 .38452 L .25967 .38306 L F
.262 .36729 m .26071 .38106 L .26071 .38168 L .796 .683 .137 r
F
.26253 .38168 m .28778 .39248 L .29066 .38769 L .643 .737 .917 r
F
.25752 .38061 m .26568 .38381 L .26253 .38168 L F
.26568 .38381 m .28778 .39248 L .26253 .38168 L F
.26065 .3824 m .26059 .38308 L .26071 .38186 L .796 .683 .137 r
F
.26059 .38308 m .26059 .38321 L .26071 .38186 L F
.25946 .38753 m .2594 .38759 L .25967 .38306 L .269 .086 .437 r
F
.26043 .38237 m .26031 .38382 L .26035 .38252 L 0 0 .268 r
F
.26031 .38382 m .26025 .38392 L .26035 .38252 L F
.26005 .38691 m .25998 .38705 L .26023 .38397 L F
.26025 .38392 m .26023 .38397 L .26035 .38252 L F
.26005 .38691 m .26023 .38397 L .26025 .38392 L F
.262 .36644 m .26007 .38001 L .26057 .38082 L .991 .745 .452 r
F
.262 .36644 m .26057 .38082 L .26071 .38106 L F
.26124 .3808 m .29066 .38769 L .29131 .38238 L .643 .737 .917 r
F
.25752 .38061 m .26253 .38168 L .26124 .3808 L F
.26253 .38168 m .29066 .38769 L .26124 .3808 L F
.26137 .36535 m .26011 .36449 L .2588 .37915 L .896 .63 .527 r
F
.26057 .38332 m .26058 .38333 L .26059 .38329 L .668 .746 .909 r
F
.25971 .38443 m .25969 .38734 L .25946 .38753 L .269 .086 .437 r
F
.25875 .38493 m .25954 .38458 L .25926 .38771 L .487 .263 .5 r
F
.25875 .38493 m .25926 .38771 L .25853 .38803 L F
.25922 .39064 m .25909 .39075 L .25932 .38765 L .269 .086 .437 r
F
.2594 .38759 m .25932 .38765 L .25967 .38306 L F
.25913 .38868 m .25999 .38953 L .25946 .38803 L .668 .746 .909 r
F
.25913 .38868 m .25946 .38803 L .25934 .38767 L F
.25922 .39064 m .25932 .38765 L .2594 .38759 L .269 .086 .437 r
F
.25971 .38443 m .25994 .38712 L .25969 .38734 L F
.25867 .38822 m .25913 .38868 L .25934 .38767 L .668 .746 .909 r
F
.25867 .38822 m .25934 .38767 L .25926 .38771 L F
.25926 .38771 m .25907 .39077 L .25898 .39084 L .269 .086 .437 r
F
.25954 .38458 m .2593 .38767 L .25926 .38771 L F
.2593 .38767 m .25907 .39077 L .25926 .38771 L F
.26062 .38653 m .26232 .38796 L .2629 .38692 L .668 .746 .909 r
F
.26058 .38329 m .26059 .38329 L .26029 .38644 L 0 0 .268 r
F
.26028 .38647 m .25995 .38711 L .26031 .3868 L .668 .746 .909 r
F
.26031 .38647 m .26031 .3868 L .26062 .38653 L F
.26028 .38647 m .26031 .3868 L .26031 .38647 L F
.26031 .38382 m .26005 .38691 L .26025 .38392 L 0 0 .268 r
F
.26013 .38675 m .26053 .38339 L .26028 .38647 L F
.25971 .38443 m .26022 .38399 L .25994 .38712 L .269 .086 .437 r
F
.26031 .3868 m .26159 .3877 L .26062 .38653 L .668 .746 .909 r
F
.25995 .38711 m .2603 .38724 L .26031 .3868 L F
.2603 .38724 m .26159 .3877 L .26031 .3868 L F
.2603 .38823 m .2603 .38756 L .25995 .38711 L F
.25995 .38711 m .2603 .38756 L .2603 .38724 L F
.26013 .38675 m .26028 .38647 L .26003 .38955 L 0 0 .268 r
F
.26013 .38675 m .26003 .38955 L .26002 .38956 L F
.25958 .3878 m .2603 .38823 L .25995 .38711 L .668 .746 .909 r
F
.26151 .38567 m .26661 .38873 L .26858 .38696 L F
.26151 .38567 m .26858 .38696 L .26249 .38479 L F
.26064 .38579 m .2629 .38692 L .26302 .3858 L F
.26029 .38644 m .26059 .38329 L .26031 .38641 L 0 0 .268 r
F
.26053 .38339 m .26058 .38329 L .26029 .38645 L F
.26053 .38339 m .26029 .38645 L .26028 .38647 L F
.26057 .38332 m .26059 .38329 L .26059 .38262 L .668 .746 .909 r
F
.26059 .38308 m .26031 .38585 L .26031 .38617 L .796 .683 .137 r
F
.26071 .38168 m .26059 .38298 L .26059 .38308 L F
.26023 .38398 m .26058 .3841 L .26057 .38332 L .668 .746 .909 r
F
.26059 .38298 m .26031 .38585 L .26059 .38308 L .796 .683 .137 r
F
.26167 .38013 m .29131 .38238 L .28965 .37691 L .643 .737 .917 r
F
.25752 .38061 m .26407 .38095 L .26167 .38013 L F
.26407 .38095 m .29131 .38238 L .26167 .38013 L F
.26057 .38082 m .26043 .38219 L .26071 .38106 L .991 .745 .452 r
F
.25956 .38456 m .25932 .38765 L .25954 .38458 L .269 .086 .437 r
F
.25932 .38765 m .25909 .39075 L .25931 .38766 L F
.25932 .38765 m .25931 .38766 L .25954 .38458 L F
.26043 .38219 m .26057 .38242 L .26071 .38106 L .991 .745 .452 r
F
.26029 .38195 m .26059 .38223 L .26059 .3819 L .668 .746 .909 r
F
.25752 .38061 m .25785 .38352 L .25903 .38342 L .643 .737 .917 r
F
.25639 .38261 m .26046 .38224 L .26029 .38195 L .668 .746 .909 r
F
.26046 .38224 m .26059 .38223 L .26029 .38195 L F
.26043 .38237 m .26046 .38353 L .26033 .38378 L 0 0 .268 r
F
.26043 .38237 m .26033 .38378 L .26031 .38382 L F
.26061 .38204 m .26071 .38186 L .26008 .38723 L F
.25639 .38261 m .26059 .38262 L .26059 .38245 L .668 .746 .909 r
F
.26043 .38237 m .26061 .38204 L .26046 .38353 L 0 0 .268 r
F
.26046 .38224 m .26059 .38245 L .26059 .38223 L .668 .746 .909 r
F
.25639 .38261 m .26059 .38245 L .26046 .38224 L F
.25967 .38306 m .25956 .38456 L .25954 .38458 L .269 .086 .437 r
F
.25982 .38294 m .26022 .38399 L .25971 .38443 L F
.25639 .38261 m .26057 .38332 L .26059 .38262 L .668 .746 .909 r
F
.25639 .38261 m .26023 .38398 L .26057 .38332 L F
.26059 .38245 m .26026 .38549 L .26031 .38558 L .991 .745 .452 r
F
.26071 .38106 m .26057 .38242 L .26059 .38245 L F
.26057 .38242 m .26026 .38549 L .26059 .38245 L F
.25785 .38352 m .25788 .38374 L .25864 .38345 L .643 .737 .917 r
F
.25733 .38356 m .25864 .38345 L .2585 .38504 L .636 .39 .528 r
F
.25773 .38515 m .25685 .38691 L .25858 .38677 L .668 .746 .909 r
F
.25668 .38529 m .25685 .38691 L .25761 .38538 L F
.25681 .38527 m .25761 .38538 L .25773 .38515 L F
.25668 .38529 m .25761 .38538 L .25681 .38527 L F
.25561 .38334 m .25696 .38359 L .25681 .38527 L .751 .492 .54 r
F
.2556 .3851 m .25508 .38676 L .25667 .38525 L .668 .746 .909 r
F
.2556 .3851 m .25545 .38518 L .25556 .38523 L F
.2555 .38509 m .25681 .38527 L .25653 .3884 L .751 .492 .54 r
F
.25826 .39126 m .25846 .39251 L .25881 .39189 L .642 .738 .918 r
F
.25723 .38521 m .2577 .38824 L .25703 .38833 L .636 .39 .528 r
F
.25733 .38356 m .25746 .38518 L .25723 .38521 L F
.25746 .38518 m .2577 .38824 L .25723 .38521 L F
.25787 .38513 m .25783 .38534 L .25796 .38528 L .668 .746 .909 r
F
.25733 .38356 m .25764 .38516 L .25746 .38518 L .636 .39 .528 r
F
.25639 .38261 m .25773 .38515 L .25787 .38513 L .668 .746 .909 r
F
.25773 .38515 m .25783 .38534 L .25787 .38513 L F
.2555 .38509 m .25653 .3884 L .25531 .38822 L .751 .492 .54 r
F
.25759 .38844 m .25664 .39009 L .25839 .38995 L .668 .746 .909 r
F
.25723 .38521 m .25703 .38833 L .25687 .38526 L .636 .39 .528 r
F
.2575 .38827 m .25652 .38892 L .25759 .38844 L .668 .746 .909 r
F
.25646 .38841 m .25652 .38892 L .2575 .38827 L F
.25652 .38892 m .25664 .39009 L .25759 .38844 L F
.25794 .39128 m .25846 .39251 L .25826 .39126 L .642 .738 .918 r
F
.25781 .3913 m .25782 .39133 L .25794 .39128 L F
.25782 .39133 m .25846 .39251 L .25794 .39128 L F
.25785 .38893 m .25839 .38995 L .25867 .38822 L .668 .746 .909 r
F
.25853 .38803 m .2583 .39114 L .25832 .38813 L .487 .263 .5 r
F
.2583 .39114 m .2583 .39114 L .25832 .38813 L F
.2583 .39114 m .2581 .39122 L .25832 .38813 L F
.25824 .39117 m .25832 .39125 L .2589 .39088 L .667 .747 .91 r
F
.2583 .39115 m .2582 .39119 L .2583 .39114 L .487 .263 .5 r
F
.2582 .39119 m .2581 .39122 L .2583 .39114 L F
.25703 .38833 m .25684 .39138 L .25669 .38838 L .636 .39 .528 r
F
.25486 .38994 m .25355 .39409 L .2571 .39439 L .668 .746 .909 r
F
.25671 .39139 m .25711 .39495 L .25781 .3913 L .642 .738 .918 r
F
.25684 .39138 m .25683 .39145 L .25683 .39138 L .636 .39 .528 r
F
.25684 .39138 m .25683 .39138 L .25669 .38838 L F
.25856 .38812 m .25867 .38822 L .25883 .38809 L .668 .746 .909 r
F
.25856 .38812 m .25883 .38809 L .25933 .38765 L F
.25867 .38822 m .25847 .38993 L .25913 .38868 L F
.25853 .38803 m .25926 .38771 L .25898 .39089 L .487 .263 .5 r
F
.25782 .39133 m .25711 .39495 L .25846 .39251 L .642 .738 .918 r
F
.25832 .39125 m .25761 .39203 L .25841 .39134 L .667 .747 .91 r
F
.25781 .3913 m .2578 .39134 L .25782 .39133 L .642 .738 .918 r
F
.25794 .3913 m .25761 .39203 L .25832 .39125 L .667 .747 .91 r
F
.25727 .39139 m .25736 .39156 L .25794 .3913 L F
.25736 .39156 m .25761 .39203 L .25794 .3913 L F
.25761 .39203 m .25818 .39312 L .25841 .39134 L F
.25486 .38994 m .2571 .39439 L .25664 .39009 L .668 .746 .909 r
F
.25627 .39142 m .2555 .40112 L .25671 .39139 L .642 .738 .918 r
F
.25683 .39145 m .25651 .3915 L .25652 .3914 L .636 .39 .528 r
F
.25683 .39138 m .25652 .3914 L .25669 .38838 L F
.25683 .39145 m .25652 .3914 L .25683 .39138 L F
.25856 .38812 m .25765 .38856 L .25867 .38822 L .668 .746 .909 r
F
.25703 .38833 m .25669 .38838 L .25687 .38526 L .636 .39 .528 r
F
.25746 .38518 m .25822 .38817 L .2577 .38824 L F
.25675 .39174 m .2555 .40112 L .25785 .40142 L .642 .738 .918 r
F
.25666 .39177 m .2555 .40112 L .25675 .39174 L F
.2562 .39143 m .2555 .40112 L .25627 .39143 L F
.25626 .39143 m .25627 .39143 L .25627 .39142 L F
.2562 .39143 m .25627 .39143 L .25626 .39143 L F
.25646 .38841 m .25486 .38994 L .25664 .39009 L .668 .746 .909 r
F
.25618 .38577 m .2553 .38857 L .25646 .38841 L F
.2553 .38857 m .25486 .38994 L .25646 .38841 L F
.25653 .3884 m .25647 .39141 L .25626 .39143 L .636 .39 .528 r
F
.25681 .38527 m .25664 .38838 L .25653 .3884 L F
.25664 .38838 m .25647 .39141 L .25653 .3884 L F
.2555 .38509 m .25531 .38822 L .25526 .38505 L .751 .492 .54 r
F
.25531 .38822 m .25496 .38818 L .25523 .38327 L F
.25373 .3844 m .25313 .38396 L .25355 .38453 L .668 .746 .909 r
F
.25333 .3841 m .25393 .38455 L .25365 .38768 L .913 .647 .523 r
F
.25521 .38884 m .25317 .3895 L .25486 .38994 L .668 .746 .909 r
F
.25427 .38814 m .25317 .3895 L .25521 .38884 L F
.25336 .38746 m .25365 .38768 L .25339 .3906 L .913 .647 .523 r
F
.25333 .3841 m .25365 .38768 L .25336 .38746 L F
.2554 .38824 m .25427 .38814 L .25521 .38884 L .668 .746 .909 r
F
.25431 .38808 m .25427 .38814 L .2554 .38824 L F
.25543 .40459 m .24883 .41623 L .24895 .41625 L .642 .739 .919 r
F
.25509 .40222 m .24883 .41623 L .25604 .40351 L F
.25431 .38808 m .25417 .38806 L .25427 .38814 L .668 .746 .909 r
F
.25399 .38782 m .25479 .38815 L .25453 .39111 L .839 .573 .538 r
F
.25617 .39184 m .25375 .3967 L .2555 .40112 L .642 .738 .918 r
F
.25603 .39178 m .25375 .3967 L .25617 .39184 L F
.25554 .39129 m .25375 .3967 L .2562 .39142 L F
.25375 .3967 m .25243 .40071 L .25473 .40102 L F
.25202 .40138 m .25318 .40081 L .25735 .40184 L .731 .477 .544 r
F
.25318 .40081 m .25738 .40136 L .25735 .40184 L F
.25202 .40138 m .25207 .40067 L .25318 .40081 L F
.25333 .39725 m .25202 .40138 L .25735 .40184 L .667 .747 .91 r
F
.25397 .40071 m .2529 .40395 L .25509 .40222 L .642 .739 .919 r
F
.2529 .40395 m .24883 .41623 L .25338 .40604 L F
.2529 .40395 m .25338 .40604 L .25509 .40222 L F
.25331 .39055 m .25073 .39127 L .25027 .39238 L .642 .738 .918 r
F
.24996 .39638 m .25202 .40138 L .25333 .39725 L .667 .747 .91 r
F
.25399 .38782 m .25453 .39111 L .25378 .39078 L .839 .573 .538 r
F
.25479 .38815 m .25464 .39113 L .25453 .39111 L .751 .492 .54 r
F
.23677 .38904 m .2394 .38901 L .23918 .39217 L .977 .72 .476 r
F
.23744 .39219 m .23677 .38904 L .23918 .39217 L F
.23686 .39144 m .23672 .39145 L .23897 .39417 L .642 .738 .918 r
F
.23672 .39145 m .22424 .39235 L .23758 .394 L F
.23672 .39145 m .23758 .394 L .23897 .39417 L F
.23587 .38891 m .23677 .38904 L .23662 .39113 L .979 .764 .349 r
F
.23662 .39113 m .23677 .38904 L .23744 .39219 L .977 .72 .476 r
F
.24323 .38795 m .23918 .39217 L .24483 .39004 L .668 .746 .909 r
F
.23677 .38904 m .237 .38588 L .2394 .38901 L .977 .72 .476 r
F
.24352 .38478 m .23948 .38898 L .24511 .38686 L .668 .746 .909 r
F
.24352 .38478 m .23709 .38586 L .23948 .38898 L F
.24323 .38795 m .23677 .38904 L .23918 .39217 L F
.2497 .38686 m .24483 .39004 L .2505 .38791 L F
.2497 .38686 m .24323 .38795 L .24483 .39004 L F
.24709 .38975 m .22424 .39235 L .25084 .39043 L .642 .738 .918 r
F
.2549 .38817 m .25474 .39115 L .25479 .38815 L .751 .492 .54 r
F
.25474 .39115 m .25464 .39113 L .25479 .38815 L F
.25531 .38822 m .25653 .3884 L .25626 .39143 L F
.25531 .38822 m .25626 .39143 L .25512 .39122 L F
.23568 .38567 m .237 .38588 L .23677 .38904 L .979 .764 .349 r
F
.23587 .38891 m .23568 .38567 L .23677 .38904 L F
.23571 .38844 m .23547 .38841 L .23656 .39095 L .642 .738 .918 r
F
.23547 .38841 m .22236 .3869 L .23527 .39058 L F
.23547 .38841 m .23527 .39058 L .23656 .39095 L F
.23552 .38786 m .23568 .38567 L .23587 .38891 L .979 .764 .349 r
F
.23568 .38567 m .23591 .38251 L .237 .38588 L F
.2428 .38254 m .23709 .38586 L .24352 .38478 L .668 .746 .909 r
F
.2428 .38254 m .23601 .38251 L .23709 .38586 L F
.24251 .38571 m .23568 .38567 L .23677 .38904 L F
.24273 .38346 m .23568 .38567 L .24251 .38571 L F
.24302 .38031 m .23601 .38251 L .2428 .38254 L F
.24921 .38017 m .23159 .37507 L .22374 .37883 L .643 .737 .917 r
F
.24302 .38031 m .23631 .37916 L .23601 .38251 L .668 .746 .909 r
F
.24273 .38346 m .23598 .38231 L .23568 .38567 L F
.23573 .38553 m .23568 .38567 L .23552 .38786 L 0 0 0 r
F
.25531 .38822 m .25512 .39122 L .25496 .38818 L .751 .492 .54 r
F
.25512 .39122 m .25479 .39116 L .25496 .38818 L F
.24251 .38571 m .23677 .38904 L .24323 .38795 L .668 .746 .909 r
F
.24931 .38949 m .23522 .38757 L .24709 .38975 L .642 .738 .918 r
F
.25224 .38953 m .25214 .3894 L .25238 .38645 L .98 .727 .476 r
F
.25224 .38953 m .25238 .38645 L .25243 .38651 L F
.25507 .38503 m .2549 .38817 L .25479 .38815 L .751 .492 .54 r
F
.25268 .38177 m .25227 .38523 L .25274 .38162 L 0 0 .188 r
F
.2525 .38275 m .25233 .38638 L .25228 .38614 L .952 .765 .308 r
F
.25227 .38523 m .2523 .38516 L .25274 .38162 L 0 0 .188 r
F
.25244 .38244 m .25216 .38562 L .25243 .38241 L .952 .765 .308 r
F
.25216 .38562 m .25216 .38561 L .25243 .38241 L F
.25252 .38283 m .25233 .38638 L .2525 .38275 L F
.25252 .38283 m .25261 .38325 L .25233 .38638 L F
.25274 .38162 m .2523 .38516 L .25244 .3848 L 0 0 .188 r
F
.25243 .38241 m .25216 .38561 L .25215 .38554 L .952 .765 .308 r
F
.25219 .38575 m .25184 .38502 L .25187 .38575 L .668 .746 .909 r
F
.25218 .3857 m .25216 .38562 L .25244 .38244 L .952 .765 .308 r
F
.25219 .38572 m .25244 .38244 L .25245 .38248 L F
.25219 .38575 m .24935 .38574 L .25234 .38642 L .668 .746 .909 r
F
.25194 .38876 m .25218 .3857 L .25219 .38572 L .952 .765 .308 r
F
.25218 .3857 m .25244 .38244 L .25219 .38572 L F
.25204 .38506 m .25039 .3837 L .25127 .38492 L .668 .746 .909 r
F
.25069 .38057 m .25126 .37953 L .25027 .38042 L F
.25654 .36405 m .25409 .37891 L .25497 .37868 L .55 .315 .512 r
F
.2554 .36441 m .25385 .37907 L .25409 .37891 L .329 .133 .455 r
F
.25752 .38061 m .25439 .37865 L .25271 .37871 L .643 .737 .917 r
F
.25385 .37907 m .253 .37964 L .25285 .38135 L .329 .133 .455 r
F
.25291 .37987 m .25259 .38064 L .25243 .38241 L 0 0 .188 r
F
.25291 .37987 m .25268 .38177 L .25274 .38162 L F
.25291 .37987 m .25243 .38241 L .25268 .38177 L F
.253 .3872 m .25295 .38716 L .25316 .38398 L .913 .647 .523 r
F
.25422 .38467 m .25399 .38782 L .25397 .38457 L .839 .573 .538 r
F
.25399 .38782 m .25387 .38777 L .25397 .38457 L F
.25428 .38794 m .25365 .38768 L .25417 .38806 L .668 .746 .909 r
F
.25378 .39078 m .25356 .39068 L .25397 .38457 L .839 .573 .538 r
F
.25546 .39152 m .25285 .39276 L .25375 .3967 L .642 .738 .918 r
F
.25513 .38503 m .25479 .39116 L .25507 .38503 L .751 .492 .54 r
F
.25554 .39129 m .25453 .39111 L .25546 .39152 L .642 .738 .918 r
F
.2544 .39105 m .25285 .39276 L .25546 .39152 L F
.25431 .39971 m .25397 .40071 L .25573 .40078 L .642 .739 .919 r
F
.25397 .40071 m .25509 .40222 L .25573 .40078 L F
.25333 .39725 m .25735 .40184 L .25689 .39756 L .667 .747 .91 r
F
.25556 .3993 m .25431 .39971 L .25573 .40078 L .642 .739 .919 r
F
.25556 .3993 m .25431 .39971 L .25556 .3993 L F
.25451 .39911 m .25441 .3994 L .25556 .3993 L F
.25441 .3994 m .25431 .39971 L .25556 .3993 L F
.25573 .40078 m .25509 .40222 L .25604 .40351 L F
.25556 .3993 m .25407 .43484 L .25236 .43505 L .636 .39 .528 r
F
.25465 .3931 m .25689 .39756 L .25643 .39326 L .667 .747 .91 r
F
.25465 .3931 m .25333 .39725 L .25689 .39756 L F
.2562 .39142 m .25603 .39178 L .25617 .39184 L .642 .738 .918 r
F
.25625 .39153 m .25465 .3931 L .25643 .39326 L .667 .747 .91 r
F
.25479 .39116 m .25474 .39115 L .25507 .38503 L .751 .492 .54 r
F
.25631 .38896 m .2544 .39105 L .25453 .39111 L .642 .738 .918 r
F
.25631 .38896 m .25453 .39111 L .25554 .39129 L F
.25623 .38887 m .25285 .39276 L .25631 .38896 L F
.25637 .38904 m .25554 .39129 L .2562 .39142 L F
.25832 .38813 m .2581 .39122 L .2583 .38813 L .487 .263 .5 r
F
.2581 .39122 m .25807 .39123 L .25829 .38814 L F
.2583 .38813 m .25829 .38814 L .2585 .38504 L F
.2581 .39122 m .25829 .38814 L .2583 .38813 L F
.25822 .38817 m .25765 .38856 L .25856 .38812 L .668 .746 .909 r
F
.2575 .38827 m .25759 .38844 L .25822 .38817 L F
.25759 .38844 m .25765 .38856 L .25822 .38817 L F
.2582 .39119 m .25794 .39128 L .25826 .39126 L .642 .738 .918 r
F
.25794 .39128 m .25807 .39124 L .25794 .3913 L .487 .263 .5 r
F
.25765 .38856 m .25819 .38863 L .25867 .38822 L .668 .746 .909 r
F
.2585 .38504 m .25829 .38814 L .25822 .38817 L .487 .263 .5 r
F
.25853 .38503 m .25832 .38813 L .2585 .38504 L F
.25832 .38813 m .2583 .38813 L .2585 .38504 L F
.25875 .38493 m .25853 .38803 L .25853 .38503 L F
.25853 .38803 m .25832 .38813 L .25853 .38503 L F
.25764 .38516 m .25822 .38817 L .25746 .38518 L .636 .39 .528 r
F
.25764 .38516 m .2585 .38504 L .25822 .38817 L F
.25926 .38771 m .25934 .38767 L .25933 .38765 L .668 .746 .909 r
F
.25909 .39075 m .25907 .39077 L .25954 .38458 L .269 .086 .437 r
F
.25687 .38526 m .25652 .3914 L .25681 .38527 L .636 .39 .528 r
F
.26001 .39538 m .25999 .40175 L .26309 .40111 L .642 .738 .918 r
F
.25735 .40184 m .2581 .40134 L .26257 .40142 L .663 .418 .539 r
F
.2581 .40134 m .26259 .40121 L .26257 .40142 L F
.25735 .40184 m .25738 .40136 L .2581 .40134 L F
.25689 .39756 m .25735 .40184 L .26257 .40142 L .667 .747 .91 r
F
.25689 .39756 m .26257 .40142 L .26038 .39728 L F
.2578 .39134 m .25711 .39495 L .25782 .39133 L .642 .738 .918 r
F
.25643 .39326 m .25689 .39756 L .26038 .39728 L .667 .747 .91 r
F
.25643 .39326 m .26038 .39728 L .25818 .39312 L F
.25736 .39156 m .25643 .39326 L .25818 .39312 L F
.25652 .3914 m .25651 .3915 L .25647 .39141 L .636 .39 .528 r
F
.25727 .39139 m .2563 .39202 L .25736 .39156 L .667 .747 .91 r
F
.25671 .39139 m .25666 .39177 L .25675 .39174 L .642 .738 .918 r
F
.25625 .39153 m .2563 .39202 L .25727 .39139 L .667 .747 .91 r
F
.2563 .39202 m .25643 .39326 L .25736 .39156 L F
.25651 .3915 m .25608 .39926 L .25647 .3915 L .636 .39 .528 r
F
.25651 .3915 m .25647 .3915 L .25647 .39141 L F
.25652 .3914 m .25647 .39141 L .25681 .38527 L F
.25631 .38896 m .25554 .39129 L .25637 .38904 L .642 .738 .918 r
F
.25626 .39143 m .25625 .39153 L .25625 .39153 L .636 .39 .528 r
F
.25556 .3993 m .25561 .39977 L .25658 .39921 L .642 .739 .919 r
F
.25822 .38817 m .25807 .39123 L .25794 .39128 L .487 .263 .5 r
F
.25829 .38814 m .25807 .39123 L .25822 .38817 L F
.25867 .38822 m .25839 .38995 L .25847 .38993 L .668 .746 .909 r
F
.25853 .38803 m .25898 .39089 L .2583 .39115 L .487 .263 .5 r
F
.25703 .38833 m .25717 .3888 L .257 .38882 L .636 .39 .528 r
F
.25717 .3888 m .25794 .39128 L .257 .38882 L F
.257 .38882 m .25794 .39128 L .25684 .39138 L F
.2577 .38824 m .25794 .39128 L .25703 .38833 L F
.25794 .39128 m .25794 .3913 L .25794 .39128 L F
.25794 .39128 m .25794 .39128 L .25703 .38833 L F
.25841 .39134 m .25886 .39178 L .25906 .39078 L .667 .747 .91 r
F
.25886 .39178 m .25979 .39269 L .2592 .39115 L F
.25886 .39178 m .2592 .39115 L .25906 .39078 L F
.25995 .38711 m .25995 .38711 L .26028 .38647 L .668 .746 .909 r
F
.26011 .3868 m .25989 .38983 L .26005 .38691 L 0 0 .268 r
F
.25951 .39062 m .2592 .39118 L .26026 .39109 L .642 .738 .918 r
F
.25931 .39093 m .25979 .39269 L .26113 .39202 L .667 .747 .91 r
F
.2592 .39115 m .25979 .39269 L .25931 .39093 L F
.26358 .39644 m .27138 .39814 L .26626 .39508 L F
.25979 .39269 m .26626 .39508 L .26113 .39202 L F
.25893 .3912 m .27528 .40747 L .26026 .39109 L .642 .738 .918 r
F
.25966 .39025 m .26132 .39084 L .25999 .38962 L .667 .747 .91 r
F
.26132 .39084 m .26212 .39113 L .26103 .39035 L F
.26132 .39084 m .26103 .39035 L .25999 .38962 L F
.26071 .38168 m .26031 .38558 L .26031 .38585 L .796 .683 .137 r
F
.26058 .38329 m .26029 .38644 L .26029 .38645 L 0 0 .268 r
F
.26031 .38625 m .26059 .38326 L .26059 .38323 L .796 .683 .137 r
F
.26031 .38626 m .26059 .38326 L .26031 .38625 L F
.26031 .38626 m .26031 .38634 L .26059 .38326 L F
.26031 .38617 m .26031 .38625 L .26059 .38323 L F
.26031 .38617 m .26059 .38323 L .26059 .38321 L F
.26059 .38308 m .26031 .38617 L .26059 .38321 L F
.26033 .38378 m .26046 .38353 L .26008 .38723 L 0 0 .268 r
F
.26031 .38382 m .26011 .3868 L .26005 .38691 L F
.26033 .38378 m .26011 .3868 L .26031 .38382 L F
.26059 .38329 m .26031 .38634 L .26031 .38641 L .796 .683 .137 r
F
.26059 .38326 m .26031 .38634 L .26059 .38329 L F
.25618 .38577 m .26044 .38579 L .26003 .38512 L .668 .746 .909 r
F
.25618 .38577 m .26028 .38647 L .26054 .38596 L F
.25618 .38577 m .26054 .38596 L .26044 .38579 L F
.25994 .38711 m .25995 .38711 L .26003 .38694 L F
.25994 .38711 m .26003 .38694 L .26028 .38647 L F
.25618 .38577 m .25994 .38711 L .26028 .38647 L F
.25994 .38712 m .25995 .38711 L .25995 .38711 L F
.26012 .38527 m .25982 .38835 L .26026 .38549 L .991 .745 .452 r
F
.26005 .38691 m .25979 .39001 L .25998 .38705 L 0 0 .268 r
F
.25998 .38705 m .25972 .39014 L .25994 .38712 L F
.26005 .38691 m .25984 .39003 L .25978 .39013 L F
.25982 .38835 m .25994 .38856 L .26026 .38549 L .991 .745 .452 r
F
.25989 .38983 m .25985 .3899 L .26005 .38691 L 0 0 .268 r
F
.25765 .38856 m .25785 .38893 L .25819 .38863 L .668 .746 .909 r
F
.2577 .38824 m .25822 .38817 L .25794 .39128 L .636 .39 .528 r
F
.25794 .39128 m .25794 .39128 L .25794 .3913 L F
.2577 .38824 m .25794 .39128 L .25794 .39128 L F
.25999 .38962 m .26212 .39113 L .2627 .39009 L .667 .747 .91 r
F
.27157 .39498 m .27176 .39182 L .27474 .38917 L .275 .101 .455 r
F
.27157 .39498 m .27474 .38917 L .27456 .39232 L F
.27138 .39814 m .27157 .39498 L .27456 .39232 L F
.26646 .39192 m .27157 .39498 L .27456 .39232 L .668 .746 .909 r
F
.26378 .39327 m .27157 .39498 L .26646 .39192 L F
.27138 .39814 m .27456 .39232 L .27437 .39549 L .275 .101 .455 r
F
.26626 .39508 m .27138 .39814 L .27437 .39549 L .667 .747 .91 r
F
.26626 .39508 m .27437 .39549 L .26825 .39331 L F
.26113 .39202 m .26626 .39508 L .26825 .39331 L F
.26394 .39008 m .27169 .39178 L .26661 .38873 L .668 .746 .909 r
F
.26661 .38873 m .27169 .39178 L .27465 .38913 L F
.26646 .39192 m .27456 .39232 L .26845 .39014 L F
.26133 .38885 m .26646 .39192 L .26845 .39014 L F
.26212 .39113 m .26825 .39331 L .26941 .39123 L .667 .747 .91 r
F
.26113 .39202 m .26825 .39331 L .26212 .39113 L F
.26212 .39113 m .26941 .39123 L .2627 .39009 L F
.26215 .39093 m .28193 .40458 L .28688 .4006 L .642 .738 .918 r
F
.25626 .3889 m .25676 .38891 L .25668 .38886 L .667 .747 .91 r
F
.26021 .38739 m .26029 .38644 L .26003 .38955 L 0 0 .268 r
F
.26029 .38644 m .26031 .38641 L .26003 .38955 L F
.26021 .38739 m .26003 .38955 L .26003 .38955 L F
.26031 .38617 m .26004 .38875 L .26003 .38926 L .796 .683 .137 r
F
.25946 .38803 m .25999 .38953 L .25958 .3878 L .668 .746 .909 r
F
.25979 .39001 m .25972 .39014 L .25998 .38705 L 0 0 .268 r
F
.25933 .38765 m .25946 .38803 L .25958 .3878 L .668 .746 .909 r
F
.25946 .38753 m .25966 .39025 L .25922 .39064 L .269 .086 .437 r
F
.25933 .38765 m .25958 .3878 L .25994 .38712 L .668 .746 .909 r
F
.25969 .38734 m .25966 .39025 L .25946 .38753 L .269 .086 .437 r
F
.26028 .38647 m .26029 .38645 L .26021 .38739 L 0 0 .268 r
F
.26003 .38926 m .26031 .38626 L .26031 .38625 L .796 .683 .137 r
F
.26003 .38926 m .26003 .38942 L .26031 .38634 L F
.26029 .38645 m .26029 .38644 L .26021 .38739 L 0 0 .268 r
F
.26003 .38926 m .26031 .38634 L .26031 .38626 L .796 .683 .137 r
F
.26031 .38617 m .26003 .38926 L .26031 .38625 L F
.26008 .38723 m .26013 .38675 L .26002 .3897 L 0 0 .268 r
F
.25958 .3878 m .25995 .38711 L .25994 .38712 L .668 .746 .909 r
F
.25969 .38734 m .25994 .38712 L .25966 .39025 L .269 .086 .437 r
F
.25972 .39014 m .25969 .3902 L .25994 .38712 L 0 0 .268 r
F
.25994 .38712 m .25969 .3902 L .25966 .39025 L F
.25946 .38753 m .25922 .39064 L .2594 .38759 L .269 .086 .437 r
F
.26008 .38723 m .26002 .38957 L .25989 .38983 L 0 0 .268 r
F
.25629 .38894 m .25999 .38962 L .26004 .38895 L .667 .747 .91 r
F
.25999 .38962 m .26003 .38963 L .26003 .38955 L F
.25999 .38962 m .26003 .38955 L .26004 .38895 L F
.25989 .38983 m .26002 .3897 L .25988 .38996 L 0 0 .268 r
F
.26002 .38957 m .26002 .3897 L .25989 .38983 L F
.26003 .38955 m .26003 .38955 L .26002 .3897 L F
.26002 .38956 m .26003 .38955 L .26002 .3897 L F
.26031 .38641 m .26002 .38958 L .26002 .3897 L .796 .683 .137 r
F
.26031 .38634 m .26002 .38958 L .26031 .38641 L F
.25676 .38891 m .26139 .38895 L .25668 .38886 L .667 .747 .91 r
F
.26139 .38895 m .26137 .38894 L .25668 .38886 L F
.26031 .38585 m .26004 .38873 L .26031 .38617 L .796 .683 .137 r
F
.25668 .38886 m .26016 .38892 L .2599 .38848 L .667 .747 .91 r
F
.26004 .38873 m .26002 .3889 L .26004 .38875 L .796 .683 .137 r
F
.26004 .38873 m .26004 .38875 L .26031 .38617 L F
.2603 .38823 m .26133 .38885 L .2603 .38756 L .668 .746 .909 r
F
.2603 .38724 m .26133 .38885 L .26232 .38796 L F
.2603 .38756 m .26133 .38885 L .2603 .38724 L F
.26133 .38885 m .26845 .39014 L .26232 .38796 L F
.26004 .38847 m .26281 .38897 L .26257 .38818 L .667 .747 .91 r
F
.26031 .38558 m .25994 .38856 L .26004 .38872 L .991 .745 .452 r
F
.2599 .38848 m .26004 .38851 L .26004 .38847 L .667 .747 .91 r
F
.26004 .38851 m .26281 .38897 L .26004 .38847 L F
.26031 .38585 m .26031 .38558 L .26004 .38872 L .796 .683 .137 r
F
.26004 .38873 m .26004 .38872 L .26002 .3889 L F
.26031 .38585 m .26004 .38872 L .26004 .38873 L F
.26016 .38892 m .26281 .38897 L .26004 .38851 L .667 .747 .91 r
F
.26004 .38872 m .26004 .38851 L .2599 .38848 L F
.26016 .38892 m .26004 .38851 L .26004 .38872 L F
.25618 .38577 m .25933 .38765 L .25995 .38711 L .668 .746 .909 r
F
.25933 .38765 m .25994 .38712 L .25995 .38711 L F
.26012 .38527 m .25942 .3877 L .25982 .38835 L .991 .745 .452 r
F
.26026 .38822 m .26257 .38818 L .26183 .38795 L .667 .747 .91 r
F
.26026 .38549 m .25994 .38856 L .26031 .38558 L .991 .745 .452 r
F
.25399 .38782 m .25378 .39078 L .25387 .38777 L .839 .573 .538 r
F
.25279 .38704 m .2525 .38715 L .25307 .38739 L .668 .746 .909 r
F
.25284 .38708 m .25307 .38739 L .25351 .38757 L F
.25279 .38704 m .25307 .38739 L .25284 .38708 L F
.25282 .38353 m .2527 .38688 L .25274 .38342 L .98 .727 .476 r
F
.2527 .38688 m .25258 .38999 L .25266 .38683 L F
.2527 .38688 m .25266 .38683 L .25274 .38342 L F
.25271 .38811 m .25299 .38941 L .25317 .3895 L .668 .746 .909 r
F
.25333 .3841 m .25339 .3906 L .25286 .3902 L .913 .647 .523 r
F
.25393 .38455 m .25356 .39068 L .25339 .3906 L .839 .573 .538 r
F
.25397 .38457 m .25356 .39068 L .25393 .38455 L F
.25623 .38887 m .25329 .39056 L .25436 .39103 L .642 .738 .918 r
F
.25639 .38261 m .25881 .385 L .2596 .38453 L .668 .746 .909 r
F
.25639 .38261 m .25955 .3845 L .25964 .38377 L F
.25955 .3845 m .2596 .38453 L .25964 .38377 L F
.25964 .38377 m .2596 .38453 L .26023 .38398 L F
.25639 .38261 m .26029 .38195 L .26024 .38188 L F
.25639 .38261 m .26059 .38181 L .25993 .38138 L F
.26137 .36535 m .25978 .37981 L .26007 .38001 L .896 .63 .527 r
F
.25752 .38061 m .28965 .37691 L .28578 .37167 L .643 .737 .917 r
F
.26057 .38082 m .26007 .38001 L .25995 .38139 L .991 .745 .452 r
F
.26007 .38001 m .25991 .38136 L .25995 .38139 L .896 .63 .527 r
F
.26057 .38082 m .25995 .38139 L .26036 .38207 L .991 .745 .452 r
F
.25983 .38131 m .2606 .38114 L .26042 .38109 L .668 .746 .909 r
F
.25639 .38261 m .25993 .38138 L .25983 .38131 L F
.25993 .38138 m .2606 .38114 L .25983 .38131 L F
.26137 .36535 m .2588 .37915 L .25978 .37981 L .896 .63 .527 r
F
.25752 .38061 m .28578 .37167 L .27994 .36701 L .643 .737 .917 r
F
.25978 .37981 m .25963 .38118 L .26007 .38001 L .896 .63 .527 r
F
.25881 .385 m .2591 .38496 L .2596 .38453 L .668 .746 .909 r
F
.25963 .38118 m .25991 .38136 L .26007 .38001 L .896 .63 .527 r
F
.25978 .37981 m .25868 .38056 L .25963 .38118 L F
.25919 .38071 m .26205 .38047 L .26088 .37957 L .668 .746 .909 r
F
.25639 .38261 m .26042 .38109 L .25919 .38071 L F
.26042 .38109 m .26205 .38047 L .25919 .38071 L F
.25771 .36396 m .25613 .37858 L .2564 .37857 L .656 .407 .53 r
F
.25771 .36396 m .25523 .37861 L .25613 .37858 L F
.2589 .3641 m .25771 .36396 L .2564 .37857 L .734 .476 .538 r
F
.2589 .3641 m .2564 .37857 L .25732 .3787 L F
.25654 .36405 m .25497 .37868 L .25523 .37861 L .55 .315 .512 r
F
.25752 .38061 m .25515 .35952 L .24638 .35979 L .643 .737 .917 r
F
.26011 .36449 m .2589 .3641 L .25759 .37874 L .807 .543 .539 r
F
.26011 .36449 m .25759 .37874 L .25853 .37906 L F
.26011 .36449 m .25853 .37906 L .2588 .37915 L F
.2589 .3641 m .25732 .3787 L .25759 .37874 L .734 .476 .538 r
F
.25752 .38061 m .26408 .36071 L .25515 .35952 L .643 .737 .917 r
F
.25752 .38061 m .27254 .36327 L .26408 .36071 L F
.25853 .37906 m .25759 .37874 L .25746 .38018 L .807 .543 .539 r
F
.25618 .38577 m .25849 .38805 L .25933 .38765 L .668 .746 .909 r
F
.25723 .38521 m .25687 .38526 L .25696 .38359 L .636 .39 .528 r
F
.25696 .38359 m .25687 .38526 L .25681 .38527 L F
.25639 .38261 m .25668 .38529 L .25773 .38515 L .668 .746 .909 r
F
.25733 .38356 m .2585 .38504 L .25764 .38516 L .636 .39 .528 r
F
.25639 .38261 m .25787 .38513 L .2585 .38504 L .668 .746 .909 r
F
.25639 .38261 m .2585 .38504 L .25874 .38493 L F
.25752 .38061 m .2384 .36148 L .23175 .36449 L .643 .737 .917 r
F
.25752 .38061 m .24638 .35979 L .2384 .36148 L F
.25752 .38061 m .27994 .36701 L .27254 .36327 L F
.25853 .37906 m .25746 .38018 L .25823 .38042 L .807 .543 .539 r
F
.25853 .37906 m .25823 .38042 L .25838 .38046 L F
.25618 .38577 m .2575 .38827 L .25822 .38817 L .668 .746 .909 r
F
.25618 .38577 m .25822 .38817 L .25849 .38805 L F
.25618 .38577 m .25646 .38841 L .2575 .38827 L F
.25617 .3888 m .25939 .38765 L .25862 .38715 L .667 .747 .91 r
F
.25618 .38881 m .25329 .39056 L .25623 .38887 L .642 .738 .918 r
F
.25597 .38894 m .25621 .38885 L .25617 .3888 L .667 .747 .91 r
F
.25621 .38885 m .25939 .38765 L .25617 .3888 L F
.25276 .39013 m .2527 .39009 L .25316 .38398 L .913 .647 .523 r
F
.25194 .38876 m .25191 .38861 L .25216 .38562 L .952 .765 .308 r
F
.25194 .38876 m .25216 .38562 L .25218 .3857 L F
.25248 .38262 m .25226 .38608 L .2522 .38579 L F
.25313 .38396 m .2527 .39009 L .25258 .38999 L .913 .647 .523 r
F
.25316 .38398 m .2527 .39009 L .25313 .38396 L F
.25618 .38577 m .25232 .38511 L .25219 .38575 L .668 .746 .909 r
F
.25232 .38511 m .25204 .38506 L .25215 .38554 L F
.2522 .38579 m .25219 .38572 L .25245 .38248 L .952 .765 .308 r
F
.25232 .38511 m .25215 .38554 L .25219 .38575 L .668 .746 .909 r
F
.25283 .38139 m .25252 .38458 L .25285 .38135 L 0 0 .188 r
F
.25618 .38577 m .25256 .38449 L .25232 .38511 L .668 .746 .909 r
F
.25618 .38577 m .25219 .38575 L .25233 .38638 L F
.25252 .38458 m .25223 .38764 L .25253 .38457 L 0 0 .188 r
F
.25252 .38458 m .25253 .38457 L .25285 .38135 L F
.2522 .38579 m .25194 .38876 L .25219 .38572 L .952 .765 .308 r
F
.25227 .38523 m .25188 .38848 L .2523 .38516 L 0 0 .188 r
F
.25219 .38741 m .25206 .38929 L .25216 .38771 L .952 .765 .308 r
F
.25219 .38741 m .25216 .38771 L .25226 .38608 L F
.25228 .38614 m .25219 .38741 L .25226 .38608 L F
.2522 .38579 m .25206 .38929 L .25194 .38876 L F
.25226 .38608 m .25206 .38929 L .2522 .38579 L F
.25244 .3848 m .25188 .38848 L .25215 .38783 L 0 0 .188 r
F
.2523 .38516 m .25188 .38848 L .25244 .3848 L F
.25215 .38554 m .25191 .38861 L .25188 .38848 L .952 .765 .308 r
F
.25234 .38642 m .25185 .3863 L .25176 .38651 L .668 .746 .909 r
F
.25216 .38562 m .25191 .38861 L .25216 .38561 L .952 .765 .308 r
F
.25216 .38561 m .25191 .38861 L .25215 .38554 L F
.25227 .38523 m .25215 .38554 L .25188 .38848 L 0 0 .188 r
F
.24995 .38369 m .24352 .38478 L .24511 .38686 L .668 .746 .909 r
F
.24935 .38574 m .24323 .38795 L .2497 .38686 L F
.24935 .38574 m .24251 .38571 L .24323 .38795 L F
.25189 .38845 m .24712 .38675 L .23134 .38737 L .642 .738 .918 r
F
.25233 .38638 m .25224 .38785 L .2522 .38784 L .98 .727 .476 r
F
.25224 .38785 m .25214 .3894 L .2522 .38784 L F
.2522 .38784 m .25214 .3894 L .25206 .38929 L F
.25235 .38641 m .25233 .38638 L .25234 .38642 L .668 .746 .909 r
F
.25238 .38645 m .25214 .3894 L .25233 .38638 L .98 .727 .476 r
F
.25248 .38659 m .25258 .38999 L .25224 .38953 L F
.25281 .38704 m .25247 .38702 L .2525 .38715 L .668 .746 .909 r
F
.25266 .38683 m .25258 .38999 L .25248 .38659 L .98 .727 .476 r
F
.25286 .3902 m .25276 .39013 L .25295 .38716 L .913 .647 .523 r
F
.25286 .3902 m .25295 .38716 L .253 .3872 L F
.2527 .38688 m .25284 .38708 L .25258 .38999 L .98 .727 .476 r
F
.25308 .38726 m .25286 .3902 L .253 .3872 L .913 .647 .523 r
F
.25228 .38614 m .25233 .38638 L .25206 .38929 L .952 .765 .308 r
F
.25605 .38867 m .25215 .38783 L .25189 .38845 L .642 .738 .918 r
F
.25134 .38759 m .2497 .38686 L .2505 .38791 L .668 .746 .909 r
F
.25215 .38783 m .24712 .38675 L .25189 .38845 L .642 .738 .918 r
F
.25215 .38783 m .25223 .38764 L .25252 .38458 L 0 0 .188 r
F
.25215 .38783 m .25252 .38458 L .25248 .38471 L F
.25244 .3848 m .25215 .38783 L .25248 .38471 L F
.256 .3886 m .25063 .38746 L .25605 .38867 L .642 .738 .918 r
F
.25063 .38746 m .25059 .38747 L .25605 .38867 L F
.24728 .38674 m .24712 .38675 L .25054 .38748 L F
.25059 .38747 m .25054 .38748 L .25605 .38867 L F
.24728 .38674 m .25054 .38748 L .25059 .38747 L F
.25618 .38577 m .25257 .38448 L .25256 .38449 L .668 .746 .909 r
F
.25639 .38261 m .2535 .38087 L .25286 .38134 L F
.2555 .38509 m .25526 .38505 L .25523 .38327 L .751 .492 .54 r
F
.25639 .38261 m .25313 .38396 L .25373 .3844 L .668 .746 .909 r
F
.25497 .37868 m .2548 .38026 L .25523 .37861 L .55 .315 .512 r
F
.25618 .38577 m .25233 .38638 L .25235 .38641 L .668 .746 .909 r
F
.25618 .38577 m .25235 .38641 L .25281 .38704 L F
.25561 .38334 m .25681 .38527 L .2555 .38509 L .751 .492 .54 r
F
.25639 .38261 m .25367 .38445 L .2546 .38483 L .668 .746 .909 r
F
.253 .37964 m .25283 .38139 L .25285 .38135 L 0 0 .188 r
F
.25385 .37907 m .25285 .38135 L .25367 .38074 L .329 .133 .455 r
F
.25205 .37944 m .23159 .37507 L .24921 .38017 L .643 .737 .917 r
F
.25282 .38143 m .25283 .38139 L .253 .37964 L 0 0 .188 r
F
.2528 .38147 m .25282 .38143 L .253 .37964 L F
.25291 .37987 m .25274 .38162 L .253 .37964 L F
.25274 .38162 m .2528 .38147 L .253 .37964 L F
.25328 .38074 m .25259 .37884 L .25126 .37953 L .668 .746 .909 r
F
.25639 .38261 m .25394 .38053 L .2535 .38087 L F
.25618 .38577 m .25279 .38704 L .25351 .38757 L F
.25248 .38471 m .25252 .38458 L .25283 .38139 L 0 0 .188 r
F
.25248 .38471 m .25283 .38139 L .25282 .38143 L F
.25244 .3848 m .25248 .38471 L .25282 .38143 L F
.25244 .3848 m .25282 .38143 L .2528 .38147 L F
.25274 .38162 m .25244 .3848 L .2528 .38147 L F
.25207 .38333 m .2496 .38257 L .24995 .38369 L .668 .746 .909 r
F
.25215 .38314 m .2496 .38257 L .25207 .38333 L F
.25236 .38259 m .25228 .3828 L .25261 .38324 L F
.25248 .38262 m .2522 .38579 L .25245 .38248 L .952 .765 .308 r
F
.25207 .38333 m .24995 .38369 L .25189 .3838 L .668 .746 .909 r
F
.25186 .38422 m .25102 .38268 L .25003 .38357 L F
.25268 .38177 m .25243 .38241 L .25215 .38554 L 0 0 .188 r
F
.25268 .38177 m .25215 .38554 L .25227 .38523 L F
.25257 .38448 m .25169 .38346 L .25186 .38422 L .668 .746 .909 r
F
.25169 .38346 m .25102 .38268 L .25186 .38422 L F
.25639 .38261 m .25451 .38494 L .2556 .3851 L F
.25618 .38577 m .25322 .38399 L .25257 .38448 L F
.25285 .38135 m .25253 .38457 L .25256 .38448 L 0 0 .188 r
F
.25367 .38074 m .25285 .38135 L .25256 .38448 L .329 .133 .455 r
F
.25367 .38074 m .25256 .38448 L .25333 .38391 L F
.25322 .38399 m .25102 .38268 L .25257 .38448 L .668 .746 .909 r
F
.25345 .38382 m .25356 .38374 L .25391 .38056 L .329 .133 .455 r
F
.25243 .38241 m .25153 .38177 L .25236 .38259 L .668 .746 .909 r
F
.25236 .38259 m .25153 .38177 L .25213 .38259 L F
.25153 .38177 m .24971 .38146 L .25213 .38259 L F
.25236 .38259 m .25213 .38259 L .25228 .3828 L F
.25322 .38399 m .25236 .38199 L .25102 .38268 L F
.25618 .38577 m .25396 .38357 L .25322 .38399 L F
.25639 .38261 m .25421 .38045 L .25394 .38053 L F
.25387 .38059 m .25391 .38056 L .25409 .37891 L .329 .133 .455 r
F
.25501 .3802 m .25505 .38018 L .25523 .37861 L .55 .315 .512 r
F
.2548 .38026 m .25501 .3802 L .25523 .37861 L F
.25439 .37865 m .25086 .37644 L .25271 .37871 L .643 .737 .917 r
F
.25385 .37907 m .25367 .38074 L .25409 .37891 L .329 .133 .455 r
F
.25367 .38074 m .25387 .38059 L .25409 .37891 L F
.25394 .38053 m .25357 .38373 L .25366 .38366 L F
.25396 .38357 m .25366 .38366 L .25322 .38399 L .668 .746 .909 r
F
.25391 .38056 m .25321 .38686 L .25394 .38053 L .329 .133 .455 r
F
.25343 .38384 m .25391 .38056 L .25387 .38059 L F
.25345 .38382 m .25391 .38056 L .25343 .38384 L F
.25367 .38074 m .25333 .38391 L .25387 .38059 L F
.25333 .38391 m .25343 .38384 L .25387 .38059 L F
.25639 .38261 m .25511 .38017 L .25421 .38045 L .668 .746 .909 r
F
.25613 .37858 m .25509 .38017 L .2557 .38012 L .656 .407 .53 r
F
.25511 .38017 m .25511 .38017 L .25509 .38017 L .668 .746 .909 r
F
.25511 .38017 m .25509 .38017 L .25421 .38045 L F
.25613 .37858 m .25597 .38009 L .2564 .37857 L .656 .407 .53 r
F
.25639 .38261 m .2556 .3851 L .25667 .38525 L .668 .746 .909 r
F
.25618 .38577 m .25488 .3833 L .25396 .38357 L F
.25639 .38261 m .25612 .38008 L .25511 .38017 L F
.25597 .38009 m .25481 .3833 L .25563 .38323 L .656 .407 .53 r
F
.25613 .37858 m .2557 .38012 L .25597 .38009 L F
.2557 .38012 m .25481 .3833 L .25597 .38009 L F
.25497 .37868 m .25409 .37891 L .25394 .38053 L .55 .315 .512 r
F
.25453 .38035 m .25394 .38053 L .25366 .38366 L F
.25497 .37868 m .25394 .38053 L .25453 .38035 L F
.25497 .37868 m .25366 .38366 L .25401 .38355 L F
.25523 .37861 m .25505 .38018 L .25509 .38017 L F
.25613 .37858 m .25523 .37861 L .25509 .38017 L .656 .407 .53 r
F
.25488 .3833 m .25481 .3833 L .25396 .38357 L .668 .746 .909 r
F
.25447 .38341 m .25338 .38675 L .25413 .38656 L .55 .315 .512 r
F
.25497 .37868 m .25401 .38355 L .25447 .38341 L F
.25401 .38355 m .25338 .38675 L .25447 .38341 L F
.25618 .38577 m .25351 .38757 L .25365 .38768 L .668 .746 .909 r
F
.25618 .38577 m .25365 .38768 L .25428 .38794 L F
.25606 .38868 m .25094 .3884 L .25069 .38856 L .642 .738 .918 r
F
.25605 .38867 m .25094 .3884 L .25606 .38868 L F
.2561 .38872 m .25069 .38856 L .25158 .38923 L F
.25838 .38046 m .2586 .38053 L .2588 .37915 L .807 .543 .539 r
F
.25639 .38261 m .25919 .38071 L .25817 .3804 L .668 .746 .909 r
F
.25815 .38361 m .25829 .38365 L .2588 .37915 L .807 .543 .539 r
F
.25804 .38358 m .25815 .38361 L .2586 .38053 L F
.25618 .38577 m .25884 .38397 L .25797 .38356 L .668 .746 .909 r
F
.25963 .38118 m .2584 .38369 L .2593 .38427 L .896 .63 .527 r
F
.25884 .38397 m .259 .38387 L .2584 .38369 L .668 .746 .909 r
F
.25884 .38397 m .2584 .38369 L .25797 .38356 L F
.25963 .38118 m .25868 .38056 L .2584 .38369 L .896 .63 .527 r
F
.25881 .385 m .25892 .38511 L .2591 .38496 L .668 .746 .909 r
F
.25963 .38118 m .2593 .38427 L .25991 .38136 L .896 .63 .527 r
F
.25618 .38577 m .25961 .38448 L .25884 .38397 L .668 .746 .909 r
F
.26012 .38527 m .26026 .38549 L .26057 .38242 L .991 .745 .452 r
F
.26059 .3829 m .26059 .38245 L .26031 .38558 L .796 .683 .137 r
F
.26058 .3841 m .26249 .38479 L .26058 .38333 L .668 .746 .909 r
F
.26057 .38511 m .26151 .38567 L .26058 .3841 L F
.26023 .38424 m .26267 .38468 L .26188 .38363 L F
.26043 .38219 m .25992 .38493 L .26012 .38527 L .991 .745 .452 r
F
.25618 .38577 m .26003 .38512 L .25961 .38448 L .668 .746 .909 r
F
.26003 .38512 m .25967 .38452 L .25961 .38448 L F
.26036 .38207 m .25988 .38487 L .26043 .38219 L .991 .745 .452 r
F
.25896 .38737 m .2592 .38753 L .25956 .38444 L .896 .63 .527 r
F
.25939 .38765 m .25939 .38765 L .25862 .38715 L .667 .747 .91 r
F
.25988 .38487 m .25941 .38767 L .25992 .38493 L .991 .745 .452 r
F
.25941 .38767 m .25941 .38768 L .25992 .38493 L F
.25991 .38136 m .25956 .38444 L .25995 .38139 L .896 .63 .527 r
F
.25956 .38444 m .2592 .38753 L .25958 .38445 L F
.25956 .38444 m .25958 .38445 L .25995 .38139 L F
.25988 .38487 m .25992 .38493 L .26043 .38219 L .991 .745 .452 r
F
.25944 .38436 m .25956 .38444 L .25991 .38136 L .896 .63 .527 r
F
.2593 .38427 m .25944 .38436 L .25991 .38136 L F
.2592 .38753 m .25923 .38755 L .25959 .38446 L F
.25958 .38445 m .25959 .38446 L .25995 .38139 L F
.2592 .38753 m .25959 .38446 L .25958 .38445 L F
.25995 .38139 m .25923 .38755 L .25939 .38765 L F
.26043 .38219 m .26012 .38527 L .26057 .38242 L .991 .745 .452 r
F
.25613 .38875 m .2588 .38703 L .25777 .38672 L .667 .747 .91 r
F
.25618 .38881 m .25248 .38992 L .25331 .39055 L .642 .738 .918 r
F
.25617 .3888 m .2588 .38703 L .25613 .38875 L .667 .747 .91 r
F
.2564 .38868 m .25614 .38877 L .25618 .38881 L .642 .738 .918 r
F
.25614 .38877 m .25248 .38992 L .25618 .38881 L F
.25618 .38577 m .25797 .38356 L .25718 .38331 L .668 .746 .909 r
F
.25618 .38577 m .25718 .38331 L .25697 .38329 L F
.25625 .38889 m .26055 .38841 L .26026 .38822 L .667 .747 .91 r
F
.25626 .3889 m .26055 .38841 L .25625 .38889 L F
.25984 .39003 m .26026 .39109 L .26215 .39093 L .642 .738 .918 r
F
.25629 .38894 m .26281 .38897 L .25626 .3889 L .667 .747 .91 r
F
.25979 .39001 m .25978 .39013 L .25972 .39014 L 0 0 .268 r
F
.25978 .39013 m .25971 .39025 L .25972 .39014 L F
.25634 .389 m .26003 .38963 L .25629 .38894 L .667 .747 .91 r
F
.25597 .38894 m .25966 .39025 L .25999 .38962 L F
.25645 .38913 m .25671 .39139 L .25696 .38973 L .642 .738 .918 r
F
.25637 .38904 m .2562 .39143 L .25645 .38913 L F
.2562 .39143 m .25627 .39142 L .25645 .38913 L F
.25645 .38913 m .25627 .39142 L .25671 .39139 L F
.25597 .38894 m .25906 .39078 L .25966 .39025 L .667 .747 .91 r
F
.25906 .39078 m .25966 .39025 L .25966 .39025 L F
.25849 .38805 m .25822 .38817 L .25856 .38812 L .668 .746 .909 r
F
.25944 .38773 m .26183 .38795 L .26022 .38746 L .667 .747 .91 r
F
.25597 .38894 m .25978 .3883 L .25944 .38773 L F
.25978 .3883 m .26183 .38795 L .25944 .38773 L F
.25992 .38493 m .25941 .38768 L .26012 .38527 L .991 .745 .452 r
F
.25941 .38768 m .25942 .3877 L .26012 .38527 L F
.25849 .38805 m .25856 .38812 L .25917 .38775 L .668 .746 .909 r
F
.25849 .38805 m .25917 .38775 L .25933 .38765 L F
.26159 .3877 m .26116 .38698 L .26062 .38653 L F
.25939 .38765 m .26177 .38692 L .26142 .38689 L .667 .747 .91 r
F
.25597 .38894 m .25944 .38773 L .25939 .38765 L F
.25944 .38773 m .26177 .38692 L .25939 .38765 L F
.26036 .38207 m .25995 .38139 L .25967 .38452 L .991 .745 .452 r
F
.26036 .38207 m .25967 .38452 L .25988 .38486 L F
.25988 .38487 m .25939 .38765 L .25941 .38767 L F
.26036 .38207 m .25988 .38486 L .25988 .38487 L F
.25988 .38486 m .25939 .38765 L .25988 .38487 L F
.25868 .38056 m .25796 .38678 L .25812 .38682 L .807 .543 .539 r
F
.2564 .38868 m .25951 .39062 L .25984 .39003 L .642 .738 .918 r
F
.25661 .38931 m .25824 .39117 L .25906 .39078 L .667 .747 .91 r
F
.25792 .39086 m .25824 .39117 L .25661 .38931 L F
.25792 .39086 m .2582 .39119 L .25824 .39117 L F
.2583 .39114 m .2583 .39115 L .2583 .39114 L .487 .263 .5 r
F
.25832 .39125 m .25855 .39122 L .25906 .39078 L .667 .747 .91 r
F
.25696 .38973 m .25826 .39126 L .25889 .39121 L .642 .738 .918 r
F
.25696 .38973 m .25671 .39139 L .25781 .3913 L F
.25824 .39117 m .2589 .39088 L .25906 .39078 L .667 .747 .91 r
F
.25893 .39093 m .25893 .3912 L .2592 .39118 L .642 .738 .918 r
F
.2564 .38868 m .25878 .39105 L .25893 .39093 L F
.25878 .39105 m .25893 .3912 L .25893 .39093 L F
.25906 .39078 m .25931 .39093 L .25966 .39025 L .667 .747 .91 r
F
.25909 .39075 m .25908 .39081 L .25907 .39077 L .269 .086 .437 r
F
.25889 .39121 m .25881 .39189 L .2591 .39137 L .642 .738 .918 r
F
.25906 .39078 m .2592 .39115 L .25931 .39093 L .667 .747 .91 r
F
.25908 .39081 m .25907 .39082 L .25907 .39077 L .269 .086 .437 r
F
.25941 .39055 m .2592 .39118 L .25951 .39062 L .642 .738 .918 r
F
.25898 .39084 m .25898 .39089 L .25898 .39089 L .269 .086 .437 r
F
.25922 .39064 m .25921 .39071 L .25909 .39075 L F
.25921 .39071 m .25908 .39081 L .25909 .39075 L F
.2564 .38868 m .25893 .39093 L .25941 .39055 L .642 .738 .918 r
F
.25893 .39093 m .2592 .39118 L .25941 .39055 L F
.25604 .40349 m .25764 .41739 L .25675 .40221 L .642 .739 .919 r
F
.25951 .39062 m .26026 .39109 L .25989 .39017 L .642 .738 .918 r
F
.25966 .39036 m .25989 .39017 L .25984 .39003 L F
.25951 .39062 m .25989 .39017 L .25966 .39036 L F
.25922 .39064 m .25966 .39025 L .25966 .39036 L .269 .086 .437 r
F
.25748 .40089 m .25764 .41739 L .25929 .41734 L .642 .739 .919 r
F
.25931 .40426 m .25929 .41734 L .26629 .41715 L F
.25748 .40089 m .25929 .41734 L .25931 .40426 L F
.25881 .39189 m .25978 .39304 L .2591 .39137 L .642 .738 .918 r
F
.26003 .38926 m .26002 .38942 L .26003 .38942 L .796 .683 .137 r
F
.25954 .39276 m .26001 .39319 L .25979 .39269 L .667 .747 .91 r
F
.26168 .39527 m .26358 .39644 L .25954 .39276 L F
.25818 .39312 m .26038 .39728 L .26284 .39663 L F
.25818 .39312 m .26284 .39663 L .26168 .39527 L F
.26001 .39319 m .26001 .39292 L .25979 .39269 L F
.2591 .39137 m .26001 .39359 L .26001 .3924 L .642 .738 .918 r
F
.26504 .3992 m .26736 .40016 L .26284 .39663 L .667 .747 .91 r
F
.2591 .39137 m .26701 .40031 L .26533 .39757 L .642 .738 .918 r
F
.26002 .38942 m .26002 .38957 L .26003 .38942 L .796 .683 .137 r
F
.26034 .38896 m .2627 .39009 L .26281 .38897 L .667 .747 .91 r
F
.26029 .38906 m .2627 .39009 L .26034 .38896 L F
.26003 .38963 m .2627 .39009 L .26004 .38895 L F
.28286 .39645 m .31767 .40422 L .28778 .39248 L .643 .737 .917 r
F
.27437 .39549 m .27456 .39232 L .2763 .38922 L 0 0 .322 r
F
.27437 .39549 m .2763 .38922 L .27611 .39238 L F
.26825 .39331 m .27437 .39549 L .27611 .39238 L .667 .747 .91 r
F
.27456 .39232 m .27474 .38917 L .27649 .38606 L 0 0 .322 r
F
.27456 .39232 m .27649 .38606 L .2763 .38922 L F
.26845 .39014 m .27456 .39232 L .2763 .38922 L .668 .746 .909 r
F
.26825 .39331 m .27611 .39238 L .26941 .39123 L .667 .747 .91 r
F
.26858 .38696 m .27465 .38913 L .27639 .38604 L .668 .746 .909 r
F
.26661 .38873 m .27465 .38913 L .26858 .38696 L F
.26845 .39014 m .2763 .38922 L .2696 .38807 L F
.26232 .38796 m .26845 .39014 L .2696 .38807 L F
.2627 .39009 m .26941 .39123 L .26965 .389 L .667 .747 .91 r
F
.2627 .39009 m .26965 .389 L .26281 .38897 L F
.26002 .38945 m .28688 .4006 L .28979 .39579 L .642 .738 .918 r
F
.25989 .38983 m .25988 .38996 L .25985 .3899 L 0 0 .268 r
F
.25988 .38996 m .25984 .39003 L .25985 .3899 L F
.2564 .38868 m .26002 .3901 L .26002 .38945 L .642 .738 .918 r
F
.26002 .38957 m .26002 .38958 L .26003 .38942 L .796 .683 .137 r
F
.26002 .3901 m .28688 .4006 L .26002 .38945 L .642 .738 .918 r
F
.25988 .38996 m .26001 .38972 L .25945 .39577 L 0 0 .268 r
F
.26001 .38972 m .26002 .3897 L .25945 .39577 L F
.25945 .39577 m .26002 .3897 L .25932 .39758 L F
.25932 .39721 m .25932 .39733 L .26002 .38958 L .796 .683 .137 r
F
.25932 .39721 m .26002 .38958 L .26002 .38957 L F
.25865 .38055 m .25794 .38677 L .25868 .38056 L .807 .543 .539 r
F
.25794 .38677 m .25794 .38677 L .25868 .38056 L F
.25792 .38693 m .25795 .38694 L .25868 .38056 L F
.25718 .38331 m .25671 .38643 L .2569 .38645 L .734 .476 .538 r
F
.25639 .38261 m .25817 .3804 L .25746 .38018 L .668 .746 .909 r
F
.25639 .38261 m .25746 .38018 L .25717 .38016 L F
.25648 .38641 m .25671 .38643 L .25707 .3833 L .734 .476 .538 r
F
.25693 .38329 m .25707 .3833 L .25759 .37874 L F
.25648 .38641 m .25707 .3833 L .25693 .38329 L F
.25618 .38577 m .25697 .38329 L .25598 .3832 L .668 .746 .909 r
F
.25626 .38007 m .25587 .38321 L .25598 .3832 L .656 .407 .53 r
F
.2564 .37857 m .25623 .38007 L .25626 .38007 L F
.25623 .38007 m .25587 .38321 L .25626 .38007 L F
.25732 .3787 m .2564 .37857 L .25626 .38007 L .734 .476 .538 r
F
.25639 .38261 m .25717 .38016 L .25612 .38008 L .668 .746 .909 r
F
.25732 .3787 m .25626 .38007 L .25689 .38013 L .734 .476 .538 r
F
.25717 .38016 m .25722 .37998 L .25626 .38007 L .668 .746 .909 r
F
.25717 .38016 m .25626 .38007 L .25612 .38008 L F
.25716 .38015 m .25598 .3832 L .25682 .38328 L .734 .476 .538 r
F
.25732 .3787 m .25689 .38013 L .25716 .38015 L F
.25689 .38013 m .25598 .3832 L .25716 .38015 L F
.25689 .38013 m .25626 .38007 L .25598 .3832 L F
.25597 .38009 m .25618 .38007 L .2564 .37857 L .656 .407 .53 r
F
.25509 .38017 m .25435 .3865 L .25452 .38644 L .55 .315 .512 r
F
.25505 .38018 m .25435 .3865 L .25509 .38017 L F
.25413 .38656 m .25434 .3865 L .2547 .38334 L F
.25413 .38656 m .2547 .38334 L .25459 .38337 L F
.25413 .38656 m .25505 .38018 L .25501 .3802 L F
.2548 .38026 m .25413 .38656 L .25501 .3802 L F
.25488 .3833 m .25589 .38296 L .25487 .38328 L .668 .746 .909 r
F
.25618 .38577 m .25591 .3832 L .25488 .3833 L F
.25591 .3832 m .25589 .38296 L .25488 .3833 L F
.25529 .38637 m .25552 .38635 L .25587 .38321 L .656 .407 .53 r
F
.25574 .38322 m .25587 .38321 L .2564 .37857 L F
.25529 .38637 m .25587 .38321 L .25574 .38322 L F
.25563 .38323 m .25481 .3833 L .25452 .38644 L F
.25618 .38577 m .25431 .38808 L .2554 .38824 L .668 .746 .909 r
F
.25618 .38577 m .25417 .38806 L .25431 .38808 L F
.25547 .38798 m .25549 .38635 L .25465 .38643 L .667 .747 .91 r
F
.25614 .38877 m .24709 .38975 L .25084 .39043 L .642 .738 .918 r
F
.2561 .38872 m .24709 .38975 L .25614 .38877 L F
.25606 .38868 m .25069 .38856 L .2561 .38872 L F
.23159 .37507 m .22413 .37401 L .22374 .37883 L .643 .737 .917 r
F
.22374 .37883 m .19388 .38792 L .2256 .38427 L F
.23598 .38231 m .23591 .38251 L .23568 .38567 L 0 0 0 r
F
.23598 .38231 m .23621 .37914 L .23591 .38251 L F
.24946 .38462 m .24251 .38571 L .24935 .38574 L .668 .746 .909 r
F
.2496 .38257 m .24352 .38478 L .24995 .38369 L F
.2496 .38257 m .2428 .38254 L .24352 .38478 L F
.24946 .38462 m .24273 .38346 L .24251 .38571 L F
.23573 .38553 m .23598 .38231 L .23568 .38567 L 0 0 0 r
F
.23581 .38464 m .23598 .38231 L .23573 .38553 L F
.23432 .38725 m .2228 .38153 L .23134 .38737 L .642 .738 .918 r
F
.24712 .38675 m .23598 .38436 L .23432 .38725 L F
.24971 .38146 m .2428 .38254 L .2496 .38257 L .668 .746 .909 r
F
.24971 .38146 m .24302 .38031 L .2428 .38254 L F
.24386 .38137 m .23598 .38231 L .24273 .38346 L F
.23713 .38233 m .23598 .38231 L .23581 .38464 L 0 0 .297 r
F
.23598 .38436 m .2228 .38153 L .23432 .38725 L .642 .738 .918 r
F
.24414 .37822 m .23631 .37916 L .24302 .38031 L .668 .746 .909 r
F
.23767 .37916 m .23621 .37914 L .23598 .38231 L 0 0 .297 r
F
.24386 .38137 m .23767 .37916 L .23598 .38231 L .668 .746 .909 r
F
.23599 .38434 m .2361 .38154 L .23584 .38431 L .642 .738 .918 r
F
.24728 .38674 m .23727 .38208 L .23599 .38434 L F
.23713 .38233 m .23767 .37916 L .23598 .38231 L 0 0 .297 r
F
.23727 .38208 m .2361 .38154 L .23599 .38434 L .642 .738 .918 r
F
.23749 .38171 m .23767 .37916 L .23713 .38233 L 0 0 .297 r
F
.25176 .38651 m .24935 .38574 L .2497 .38686 L .668 .746 .909 r
F
.25003 .38357 m .24273 .38346 L .24946 .38462 L F
.25003 .38357 m .24386 .38137 L .24273 .38346 L F
.25105 .38659 m .23783 .38142 L .24728 .38674 L .642 .738 .918 r
F
.25027 .38042 m .24302 .38031 L .24971 .38146 L .668 .746 .909 r
F
.25027 .38042 m .24414 .37822 L .24302 .38031 L F
.24583 .37957 m .23767 .37916 L .24386 .38137 L F
.24005 .37957 m .23767 .37916 L .23749 .38171 L .258 .083 .443 r
F
.23783 .38142 m .22554 .37662 L .23712 .38201 L .642 .738 .918 r
F
.23783 .38142 m .23712 .38201 L .24728 .38674 L F
.2493 .37885 m .25005 .37767 L .23159 .37507 L .643 .737 .917 r
F
.25005 .37767 m .22691 .36858 L .23159 .37507 L F
.23159 .37507 m .22418 .37348 L .22413 .37401 L F
.24414 .37822 m .23799 .37603 L .23631 .37916 L .668 .746 .909 r
F
.23767 .37916 m .2379 .37599 L .23621 .37914 L 0 0 .297 r
F
.24611 .37644 m .23799 .37603 L .24414 .37822 L .668 .746 .909 r
F
.24063 .37646 m .2379 .37599 L .23767 .37916 L .258 .083 .443 r
F
.24583 .37957 m .24063 .37646 L .23767 .37916 L .668 .746 .909 r
F
.24005 .37957 m .24063 .37646 L .23767 .37916 L .258 .083 .443 r
F
.24043 .37926 m .24063 .37646 L .24005 .37957 L F
.25127 .38492 m .24946 .38462 L .25187 .38575 L .668 .746 .909 r
F
.25102 .38268 m .24386 .38137 L .25003 .38357 L F
.25102 .38268 m .24583 .37957 L .24386 .38137 L F
.25189 .38588 m .24091 .37904 L .24771 .38529 L .642 .738 .918 r
F
.25126 .37953 m .24414 .37822 L .25027 .38042 L .668 .746 .909 r
F
.25271 .37871 m .25005 .37767 L .2493 .37885 L .643 .737 .917 r
F
.25126 .37953 m .24611 .37644 L .24414 .37822 L .668 .746 .909 r
F
.24852 .3782 m .24063 .37646 L .24583 .37957 L F
.24431 .37753 m .24063 .37646 L .24043 .37926 L .456 .242 .499 r
F
.24091 .37904 m .23042 .37251 L .23988 .3795 L .642 .738 .918 r
F
.24091 .37904 m .23988 .3795 L .24771 .38529 L F
.25593 .38852 m .25669 .38643 L .2557 .38633 L .667 .747 .91 r
F
.25648 .38641 m .2557 .38633 L .25569 .38641 L .734 .476 .538 r
F
.25401 .38355 m .25366 .38366 L .25338 .38675 L .55 .315 .512 r
F
.25366 .38366 m .25321 .38686 L .25338 .38675 L .329 .133 .455 r
F
.25357 .38373 m .25321 .38686 L .25366 .38366 L F
.25301 .387 m .25345 .38382 L .25343 .38384 L F
.25301 .387 m .25321 .38686 L .25356 .38374 L F
.25301 .387 m .25356 .38374 L .25345 .38382 L F
.25256 .38448 m .25223 .38764 L .25229 .38748 L 0 0 .188 r
F
.25253 .38457 m .25223 .38764 L .25256 .38448 L F
.25333 .38391 m .25301 .387 L .25343 .38384 L .329 .133 .455 r
F
.25333 .38391 m .25256 .38448 L .25229 .38748 L F
.25333 .38391 m .25229 .38748 L .25301 .387 L F
.2557 .38825 m .25358 .38611 L .25189 .38588 L .642 .738 .918 r
F
.25607 .38868 m .25777 .38672 L .2569 .38645 L .667 .747 .91 r
F
.25613 .38875 m .25777 .38672 L .25607 .38868 L F
.25606 .38867 m .2569 .38645 L .25677 .38644 L F
.25597 .38894 m .25607 .38868 L .25606 .38867 L F
.25607 .38868 m .2569 .38645 L .25606 .38867 L F
.25185 .3863 m .24935 .38574 L .25176 .38651 L .668 .746 .909 r
F
.25176 .38651 m .2497 .38686 L .25159 .38697 L F
.2559 .38849 m .25189 .38588 L .24771 .38529 L .642 .738 .918 r
F
.25823 .38042 m .25746 .38018 L .25718 .38331 L .807 .543 .539 r
F
.25756 .38343 m .25718 .38331 L .2569 .38645 L F
.25823 .38042 m .25718 .38331 L .25756 .38343 L F
.25716 .38015 m .25682 .38328 L .25738 .38018 L .734 .476 .538 r
F
.25682 .38328 m .25648 .38641 L .25693 .38329 L F
.25682 .38328 m .25693 .38329 L .25738 .38018 L F
.25746 .38018 m .25707 .3833 L .25718 .38331 L F
.25742 .38018 m .25707 .3833 L .25746 .38018 L F
.25597 .38009 m .25563 .38323 L .25618 .38007 L .656 .407 .53 r
F
.25563 .38323 m .25574 .38322 L .25618 .38007 L F
.25588 .38292 m .25751 .38158 L .25572 .38142 L .668 .746 .909 r
F
.25591 .38319 m .25611 .38299 L .25588 .38292 L F
.25611 .38299 m .25751 .38158 L .25588 .38292 L F
.25606 .38867 m .2573 .38475 L .25593 .38852 L .667 .747 .91 r
F
.2564 .38868 m .2557 .38825 L .2559 .38849 L .642 .738 .918 r
F
.2557 .38825 m .25189 .38588 L .2559 .38849 L F
.25593 .38852 m .2557 .38633 L .25547 .38798 L .667 .747 .91 r
F
.2557 .38633 m .25551 .3846 L .25549 .38635 L F
.2557 .38633 m .25549 .38635 L .25547 .38798 L F
.2557 .38633 m .25551 .38642 L .25569 .38641 L .656 .407 .53 r
F
.25598 .3832 m .25552 .38635 L .2557 .38633 L F
.25552 .38635 m .25551 .38642 L .2557 .38633 L F
.2564 .38868 m .25423 .38653 L .2557 .38825 L .642 .738 .918 r
F
.25232 .38511 m .25256 .38449 L .25204 .38506 L .668 .746 .909 r
F
.25271 .37871 m .25086 .37644 L .22691 .36858 L .643 .737 .917 r
F
.25086 .37644 m .23175 .36449 L .22718 .36835 L F
.25086 .37644 m .22718 .36835 L .22691 .36858 L F
.25257 .38448 m .25186 .38422 L .25201 .3849 L .668 .746 .909 r
F
.25257 .38448 m .25201 .3849 L .25204 .38506 L F
.25186 .38422 m .25039 .3837 L .25204 .38506 L F
.25261 .38196 m .25027 .38042 L .24971 .38146 L F
.25232 .38191 m .25153 .38177 L .25243 .38241 L F
.25236 .38199 m .24583 .37957 L .25102 .38268 L F
.25285 .38134 m .25269 .38039 L .25069 .38057 L F
.25269 .38039 m .25126 .37953 L .25069 .38057 L F
.25285 .38134 m .25027 .38042 L .25231 .38176 L F
.25236 .38199 m .24852 .3782 L .24583 .37957 L F
.24611 .37644 m .24093 .37334 L .23799 .37603 L F
.24878 .37507 m .24093 .37334 L .24611 .37644 L F
.24878 .37507 m .24495 .37128 L .24093 .37334 L F
.25259 .37884 m .24611 .37644 L .25126 .37953 L F
.25259 .37884 m .24878 .37507 L .24611 .37644 L F
.24852 .3782 m .24467 .37439 L .24063 .37646 L F
.24467 .37439 m .24086 .37329 L .24063 .37646 L .456 .242 .499 r
F
.24467 .37439 m .24489 .37122 L .24086 .37329 L F
.25419 .37842 m .24878 .37507 L .25259 .37884 L .668 .746 .909 r
F
.25174 .37734 m .24467 .37439 L .24852 .3782 L F
.25419 .37842 m .25197 .37421 L .24878 .37507 L F
.25197 .37421 m .24495 .37128 L .24878 .37507 L F
.25197 .37421 m .24975 .36999 L .24495 .37128 L F
.25174 .37734 m .2495 .3731 L .24467 .37439 L F
.24928 .37627 m .24467 .37439 L .24445 .37746 L .576 .342 .524 r
F
.25423 .38653 m .245 .37735 L .2557 .38825 L .642 .738 .918 r
F
.245 .37735 m .245 .37735 L .2557 .38825 L F
.24928 .37627 m .24445 .37746 L .2462 .3771 L .576 .342 .524 r
F
.24491 .37726 m .24484 .37729 L .2557 .38825 L .642 .738 .918 r
F
.24431 .37753 m .24467 .37439 L .24063 .37646 L .456 .242 .499 r
F
.24445 .37746 m .24467 .37439 L .24431 .37753 L F
.25204 .38506 m .25184 .38502 L .25219 .38575 L .668 .746 .909 r
F
.25039 .3837 m .25036 .38369 L .25037 .3837 L F
.25039 .3837 m .25037 .3837 L .25127 .38492 L F
.25036 .38369 m .25003 .38357 L .25127 .38492 L F
.25184 .38502 m .25127 .38492 L .25152 .38527 L F
.25184 .38502 m .25152 .38527 L .25187 .38575 L F
.24063 .37646 m .24086 .37329 L .2379 .37599 L .258 .083 .443 r
F
.25358 .38611 m .23711 .3695 L .25189 .38588 L .642 .738 .918 r
F
.25529 .38637 m .25452 .38644 L .25452 .38646 L .656 .407 .53 r
F
.25529 .38637 m .25452 .38646 L .25529 .38643 L F
.25563 .38323 m .25452 .38644 L .25529 .38637 L F
.25465 .38643 m .25549 .38613 L .25464 .3864 L .667 .747 .91 r
F
.25549 .38635 m .25549 .38613 L .25465 .38643 L F
.25464 .3864 m .25551 .3846 L .25375 .38474 L F
.25549 .38613 m .25551 .3846 L .25464 .3864 L F
.25547 .38798 m .25464 .3864 L .25423 .38653 L F
.25452 .38644 m .25434 .3865 L .25452 .38646 L .55 .315 .512 r
F
.25435 .3865 m .25434 .3865 L .25452 .38644 L F
.25372 .38593 m .25375 .38474 L .2529 .38496 L .667 .747 .91 r
F
.25423 .38653 m .23932 .36903 L .23711 .3695 L .642 .738 .918 r
F
.25464 .3864 m .25375 .38474 L .2537 .3867 L .667 .747 .91 r
F
.25388 .3835 m .25397 .38156 L .25236 .38199 L .668 .746 .909 r
F
.25396 .38357 m .25388 .3835 L .25366 .38366 L F
.25261 .38196 m .25232 .38191 L .25243 .38241 L F
.25388 .3835 m .25236 .38199 L .25322 .38399 L F
.25285 .38135 m .25231 .38176 L .25261 .38196 L F
.25285 .38134 m .25231 .38176 L .25285 .38135 L F
.2535 .38087 m .25313 .38065 L .25286 .38134 L F
.25313 .38065 m .25269 .38039 L .25286 .38133 L F
.25313 .38065 m .25286 .38133 L .25286 .38134 L F
.25286 .38134 m .25286 .38133 L .25285 .38134 L F
.25286 .38133 m .25269 .38039 L .25285 .38134 L F
.25286 .38134 m .25285 .38134 L .25285 .38135 L F
.25397 .38156 m .24852 .3782 L .25236 .38199 L F
.2535 .38087 m .25394 .38053 L .25328 .38074 L F
.25421 .38045 m .25259 .37884 L .25328 .38074 L F
.25397 .38156 m .25174 .37734 L .24852 .3782 L F
.25375 .38474 m .2483 .38137 L .25215 .38516 L .667 .747 .91 r
F
.25375 .38474 m .25152 .38051 L .2483 .38137 L F
.25396 .38357 m .25467 .38291 L .25388 .3835 L .668 .746 .909 r
F
.25487 .38328 m .25467 .38291 L .25396 .38357 L F
.25467 .38291 m .25397 .38156 L .25388 .3835 L F
.25551 .3846 m .25152 .38051 L .25375 .38474 L .667 .747 .91 r
F
.25486 .38149 m .25491 .38149 L .25505 .38018 L .55 .315 .512 r
F
.25459 .38337 m .25491 .38149 L .25486 .38149 L F
.25459 .38337 m .2547 .38334 L .25491 .38149 L F
.2557 .38012 m .25509 .38017 L .25481 .3833 L .656 .407 .53 r
F
.25487 .38328 m .25572 .38142 L .25397 .38156 L .668 .746 .909 r
F
.25589 .38296 m .25572 .38142 L .25487 .38328 L F
.25488 .3833 m .25487 .38328 L .25481 .3833 L F
.25409 .37891 m .25391 .38056 L .25394 .38053 L .329 .133 .455 r
F
.25415 .38038 m .25419 .37842 L .25259 .37884 L .668 .746 .909 r
F
.25421 .38045 m .25421 .38033 L .25415 .38038 L F
.25421 .38033 m .25419 .37842 L .25415 .38038 L F
.25511 .38017 m .25419 .37842 L .25421 .38045 L F
.25572 .38142 m .25174 .37734 L .25397 .38156 L F
.25511 .38017 m .25593 .37828 L .25419 .37842 L F
.25511 .38017 m .25511 .38016 L .25511 .38017 L F
.25511 .38016 m .25593 .37828 L .25511 .38017 L F
.25612 .38008 m .25593 .37828 L .25511 .38017 L F
.25593 .37828 m .25197 .37421 L .25419 .37842 L F
.25593 .37828 m .25548 .37393 L .25197 .37421 L F
.25572 .38142 m .25526 .37706 L .25174 .37734 L F
.25551 .3846 m .25505 .38023 L .25152 .38051 L .667 .747 .91 r
F
.25152 .38051 m .24444 .37757 L .2483 .38137 L F
.2495 .3731 m .24489 .37122 L .24467 .37439 L .576 .342 .524 r
F
.2495 .3731 m .24972 .36992 L .24489 .37122 L F
.25152 .38051 m .24928 .37627 L .24444 .37757 L .667 .747 .91 r
F
.25505 .38023 m .24928 .37627 L .25152 .38051 L F
.25526 .37706 m .2495 .3731 L .25174 .37734 L .668 .746 .909 r
F
.25548 .37393 m .24975 .36999 L .25197 .37421 L F
.25548 .37393 m .25501 .36957 L .24975 .36999 L F
.25526 .37706 m .2548 .37267 L .2495 .3731 L F
.25505 .38023 m .25458 .37585 L .24928 .37627 L .667 .747 .91 r
F
.24928 .37627 m .2495 .3731 L .24467 .37439 L .576 .342 .524 r
F
.25458 .37585 m .2495 .3731 L .24928 .37627 L .662 .415 .535 r
F
.2564 .38868 m .24516 .3678 L .23932 .36903 L .642 .738 .918 r
F
.2564 .38868 m .23932 .36903 L .25423 .38653 L F
.2537 .3867 m .25372 .38593 L .25215 .38516 L .667 .747 .91 r
F
.25372 .38593 m .2529 .38496 L .25215 .38516 L F
.2462 .3771 m .24445 .37746 L .24444 .37757 L .576 .342 .524 r
F
.245 .37735 m .24491 .37726 L .245 .37735 L .642 .738 .918 r
F
.24491 .37726 m .23711 .3695 L .24484 .37729 L F
.25189 .38588 m .23711 .3695 L .23042 .37251 L F
.24444 .37757 m .24445 .37746 L .24431 .37753 L .456 .242 .499 r
F
.25597 .38894 m .25613 .38875 L .25607 .38868 L .667 .747 .91 r
F
.25155 .38705 m .2497 .38686 L .25134 .38759 L .668 .746 .909 r
F
.2564 .38868 m .25105 .38659 L .24728 .38674 L .642 .738 .918 r
F
.25597 .38894 m .25554 .38811 L .25551 .38847 L .667 .747 .91 r
F
.25554 .38811 m .25547 .38798 L .25551 .38847 L F
.25551 .38847 m .25547 .38798 L .2537 .3867 L F
.25597 .38894 m .25606 .38867 L .25593 .38852 L F
.25597 .38894 m .25617 .3888 L .25613 .38875 L F
.2564 .38868 m .2561 .38872 L .25614 .38877 L .642 .738 .918 r
F
.2564 .38868 m .25606 .38868 L .2561 .38872 L F
.25597 .38894 m .25593 .38852 L .25547 .38798 L .667 .747 .91 r
F
.2564 .38868 m .25605 .38867 L .25606 .38868 L .642 .738 .918 r
F
.2564 .38868 m .256 .3886 L .25605 .38867 L F
.2564 .38868 m .25618 .38881 L .25623 .38887 L F
.25597 .38894 m .25626 .3889 L .25625 .38889 L .667 .747 .91 r
F
.25597 .38894 m .25629 .38894 L .25626 .3889 L F
.25647 .39141 m .25647 .3915 L .25626 .39143 L .636 .39 .528 r
F
.25561 .39977 m .25604 .40349 L .25659 .39941 L .642 .739 .919 r
F
.25561 .39977 m .25659 .39941 L .25658 .39921 L F
.25921 .39071 m .25966 .39036 L .25896 .39823 L .269 .086 .437 r
F
.25932 .40122 m .26629 .41715 L .27125 .41614 L .642 .739 .919 r
F
.25813 .39974 m .25931 .40227 L .25932 .40122 L F
.25931 .40227 m .26629 .41715 L .25932 .40122 L F
.25804 .3999 m .25931 .40257 L .25813 .39974 L F
.25931 .40257 m .26629 .41715 L .25931 .40227 L F
.25931 .40257 m .25931 .40227 L .25813 .39974 L F
.26002 .38958 m .25932 .39733 L .26002 .3897 L .796 .683 .137 r
F
.26004 .38895 m .26029 .38906 L .26034 .38896 L .667 .747 .91 r
F
.26003 .38926 m .26002 .3889 L .26002 .38942 L .796 .683 .137 r
F
.26004 .38875 m .26002 .3889 L .26003 .38926 L F
.2564 .38868 m .26041 .38954 L .26 .38887 L .642 .738 .918 r
F
.25816 .39967 m .25932 .40112 L .25932 .40081 L .642 .739 .919 r
F
.25813 .39974 m .27125 .41614 L .25816 .39967 L F
.25969 .3902 m .25905 .39808 L .25966 .39025 L 0 0 .268 r
F
.25768 .39924 m .26629 .41715 L .25771 .39922 L .642 .739 .919 r
F
.25807 .39124 m .25754 .39905 L .25794 .3913 L .487 .263 .5 r
F
.25724 .39916 m .25692 .39984 L .25762 .39913 L .642 .739 .919 r
F
.25692 .39984 m .26629 .41715 L .25768 .39924 L F
.25692 .39984 m .25768 .39924 L .25762 .39913 L F
.25754 .39905 m .25743 .39909 L .25794 .3913 L .487 .263 .5 r
F
.25647 .3915 m .25604 .39926 L .25625 .39153 L .636 .39 .528 r
F
.25604 .39926 m .25586 .39927 L .25625 .39153 L F
.25794 .3913 m .25743 .39909 L .25724 .39916 L .487 .263 .5 r
F
.25608 .39926 m .25604 .39926 L .25647 .39141 L .636 .39 .528 r
F
.25625 .39153 m .25586 .39927 L .25556 .3993 L F
.25625 .39153 m .25586 .39927 L .25625 .39153 L F
.2551 .39169 m .25465 .3931 L .25625 .39153 L .667 .747 .91 r
F
.25625 .39153 m .2551 .39169 L .25625 .39153 L F
.25512 .39122 m .25626 .39143 L .25625 .39153 L .751 .492 .54 r
F
.25512 .39122 m .25625 .39153 L .25513 .39137 L F
.25597 .38894 m .2552 .39138 L .25625 .39153 L .667 .747 .91 r
F
.2552 .39138 m .2551 .39169 L .25625 .39153 L F
.2552 .39138 m .25296 .39266 L .25465 .3931 L F
.25512 .39122 m .25513 .39137 L .25511 .39137 L .751 .492 .54 r
F
.25512 .39122 m .25511 .39137 L .25479 .39116 L F
.25412 .39123 m .25296 .39266 L .25501 .39149 L .667 .747 .91 r
F
.25451 .39129 m .25501 .39149 L .2552 .39138 L F
.25412 .39123 m .25501 .39149 L .25451 .39129 L F
.25378 .39078 m .25453 .39111 L .25451 .39129 L .839 .573 .538 r
F
.2531 .39434 m .24996 .39638 L .25333 .39725 L .667 .747 .91 r
F
.25296 .39266 m .25278 .39289 L .2531 .39434 L F
.25278 .39289 m .24996 .39638 L .2531 .39434 L F
.25194 .38876 m .25192 .38897 L .25191 .38861 L .952 .765 .308 r
F
.25147 .39197 m .24996 .39638 L .25296 .39266 L .667 .747 .91 r
F
.25369 .39176 m .25147 .39197 L .25296 .39266 L F
.25378 .39078 m .25451 .39129 L .25376 .39098 L .839 .573 .538 r
F
.25378 .39078 m .25376 .39098 L .25356 .39068 L F
.25405 .39132 m .25306 .3909 L .25369 .39176 L .667 .747 .91 r
F
.25418 .39115 m .25367 .39104 L .25405 .39132 L F
.25367 .39104 m .25306 .3909 L .25405 .39132 L F
.25258 .38999 m .25303 .3906 L .25331 .39055 L .642 .738 .918 r
F
.25286 .3902 m .25339 .3906 L .25337 .39082 L .913 .647 .523 r
F
.25326 .39077 m .25306 .3909 L .25418 .39115 L .667 .747 .91 r
F
.25306 .3909 m .25147 .39197 L .25369 .39176 L F
.2529 .40395 m .24627 .40815 L .24883 .41623 L .642 .739 .919 r
F
.25249 .40215 m .24627 .40815 L .2529 .40395 L F
.25233 .40146 m .24657 .40743 L .25247 .40208 L F
.24657 .40743 m .24627 .40815 L .25249 .40215 L F
.25247 .40208 m .25249 .40215 L .25397 .40071 L F
.24657 .40743 m .25249 .40215 L .25247 .40208 L F
.25286 .3902 m .25337 .39082 L .25284 .39042 L .913 .647 .523 r
F
.25328 .39075 m .25029 .39107 L .25147 .39197 L .667 .747 .91 r
F
.25269 .39032 m .25269 .39031 L .2527 .39009 L .913 .647 .523 r
F
.25256 .39022 m .25256 .39022 L .25328 .39075 L .667 .747 .91 r
F
.25256 .39022 m .25029 .39107 L .25297 .39078 L F
.25256 .39022 m .25297 .39078 L .25328 .39075 L F
.25224 .38953 m .25258 .38999 L .25256 .39022 L .98 .727 .476 r
F
.25224 .38953 m .25256 .39022 L .25223 .38977 L F
.25274 .39035 m .2527 .39009 L .25276 .39013 L .913 .647 .523 r
F
.25224 .39815 m .25269 .39032 L .25274 .39035 L F
.25269 .39032 m .2527 .39009 L .25274 .39035 L F
.25084 .39043 m .23686 .39144 L .23897 .39417 L .642 .738 .918 r
F
.25256 .39022 m .24949 .39003 L .25029 .39107 L .667 .747 .91 r
F
.25194 .38876 m .25206 .38929 L .25204 .38951 L .952 .765 .308 r
F
.25206 .38959 m .25178 .38964 L .25213 .3899 L .667 .747 .91 r
F
.25178 .38964 m .24949 .39003 L .25256 .39022 L F
.25224 .38953 m .25222 .38976 L .25214 .3894 L .98 .727 .476 r
F
.25222 .38976 m .25159 .39749 L .25213 .38963 L F
.25222 .38976 m .25213 .38963 L .25214 .3894 L F
.25194 .38876 m .25204 .38951 L .25193 .38898 L .952 .765 .308 r
F
.25158 .38923 m .25069 .38856 L .24931 .38949 L .642 .738 .918 r
F
.25094 .3884 m .23522 .38757 L .24931 .38949 L F
.25206 .38959 m .24913 .38891 L .24949 .39003 L .667 .747 .91 r
F
.25206 .38929 m .25205 .38952 L .25204 .38951 L .98 .727 .476 r
F
.25204 .38951 m .24913 .38891 L .25206 .38959 L .667 .747 .91 r
F
.25191 .38892 m .25161 .38892 L .25204 .38951 L F
.25161 .38892 m .24913 .38891 L .25204 .38951 L F
.25214 .3894 m .25212 .38962 L .25206 .38929 L .98 .727 .476 r
F
.25438 .39923 m .25353 .40012 L .25445 .39926 L .642 .739 .919 r
F
.25353 .40012 m .24044 .41377 L .25357 .40017 L F
.25353 .40012 m .25357 .40017 L .25445 .39926 L F
.25212 .38962 m .25151 .39738 L .25205 .38952 L .98 .727 .476 r
F
.25343 .39891 m .25336 .39899 L .25451 .39911 L .642 .739 .919 r
F
.24696 .40007 m .24703 .39918 L .24838 .39958 L .792 .532 .544 r
F
.24996 .39638 m .24696 .40007 L .25202 .40138 L .667 .747 .91 r
F
.25336 .39899 m .2471 .40615 L .25409 .39954 L .642 .739 .919 r
F
.2471 .40615 m .2466 .40735 L .25409 .39954 L F
.25296 .39266 m .25333 .39725 L .25465 .3931 L .667 .747 .91 r
F
.25284 .39042 m .25337 .39082 L .25267 .39848 L .913 .647 .523 r
F
.25284 .39042 m .25267 .39848 L .25224 .39815 L F
.2471 .40615 m .23303 .41015 L .24044 .41377 L .642 .739 .919 r
F
.25336 .39899 m .2491 .40133 L .2471 .40615 L F
.2491 .40133 m .23303 .41015 L .2471 .40615 L F
.25151 .39738 m .25144 .3973 L .25205 .38952 L .98 .727 .476 r
F
.25212 .38962 m .25205 .38952 L .25206 .38929 L F
.25192 .38897 m .25135 .39717 L .25125 .39673 L .952 .765 .308 r
F
.25194 .38876 m .25193 .38898 L .25192 .38897 L F
.25193 .38898 m .25135 .39717 L .25192 .38897 L F
.25159 .39749 m .25151 .39738 L .25212 .38962 L .98 .727 .476 r
F
.25213 .38963 m .25212 .38962 L .25214 .3894 L F
.25159 .39749 m .25212 .38962 L .25213 .38963 L F
.25597 .38894 m .25191 .38892 L .25204 .38951 L .667 .747 .91 r
F
.2521 .38959 m .25204 .38951 L .25206 .38959 L F
.25222 .38976 m .25187 .39787 L .25159 .39749 L .98 .727 .476 r
F
.25224 .38953 m .25223 .38977 L .25222 .38976 L F
.25223 .38977 m .25187 .39787 L .25222 .38976 L F
.25286 .3902 m .25224 .39815 L .25276 .39013 L .913 .647 .523 r
F
.25329 .39895 m .23303 .41015 L .25336 .39899 L .642 .739 .919 r
F
.25248 .38992 m .25303 .3906 L .25258 .38999 L .642 .738 .918 r
F
.2527 .39009 m .25212 .39806 L .25258 .38999 L .913 .647 .523 r
F
.25256 .39843 m .23303 .41015 L .25329 .39895 L .642 .739 .919 r
F
.25212 .39806 m .25201 .39798 L .25258 .38999 L .913 .647 .523 r
F
.25258 .38999 m .25201 .39798 L .25187 .39787 L F
.25376 .39098 m .2532 .39871 L .25355 .39089 L .839 .573 .538 r
F
.2532 .39871 m .25303 .39863 L .25355 .39089 L F
.2521 .38959 m .25206 .38959 L .25256 .39022 L .667 .747 .91 r
F
.25206 .38959 m .25213 .3899 L .25256 .39022 L F
.25223 .38977 m .25256 .39022 L .25187 .39787 L .98 .727 .476 r
F
.25224 .39815 m .25212 .39806 L .25269 .39031 L .913 .647 .523 r
F
.25224 .39815 m .25269 .39031 L .25269 .39032 L F
.25376 .39098 m .25451 .39129 L .25382 .39898 L .839 .573 .538 r
F
.25376 .39098 m .25382 .39898 L .2532 .39871 L F
.25597 .38894 m .2521 .38959 L .25256 .39022 L .667 .747 .91 r
F
.2521 .38959 m .25256 .39022 L .25256 .39022 L F
.25597 .38894 m .25204 .38951 L .2521 .38959 L F
.25177 .38892 m .24924 .38778 L .24913 .38891 L F
.25191 .38861 m .25189 .38881 L .25188 .38848 L .952 .765 .308 r
F
.25189 .38881 m .25186 .38869 L .25188 .38848 L F
.25122 .39661 m .2512 .39651 L .25186 .38868 L F
.25186 .38869 m .25186 .38868 L .25188 .38848 L F
.25122 .39661 m .25186 .38868 L .25186 .38869 L F
.25125 .39673 m .25122 .39661 L .25191 .38861 L F
.25597 .38894 m .25203 .38826 L .25186 .38868 L .667 .747 .91 r
F
.25191 .38892 m .25186 .38868 L .25177 .38892 L F
.25192 .38897 m .25189 .38881 L .25191 .38861 L .952 .765 .308 r
F
.25597 .38894 m .25186 .38868 L .25191 .38892 L .667 .747 .91 r
F
.25203 .38826 m .24924 .38778 L .25177 .38892 L F
.25223 .38764 m .25221 .38779 L .25229 .38748 L 0 0 .188 r
F
.25205 .38952 m .25144 .3973 L .25204 .38951 L .98 .727 .476 r
F
.25221 .38779 m .25228 .38763 L .25229 .38748 L 0 0 .188 r
F
.25063 .38746 m .24728 .38674 L .25059 .38747 L .642 .738 .918 r
F
.25153 .38818 m .24981 .38674 L .24924 .38778 L .667 .747 .91 r
F
.25597 .38894 m .25228 .38762 L .25203 .38826 L F
.25204 .38951 m .25144 .3973 L .25135 .39717 L .98 .727 .476 r
F
.25145 .39567 m .2515 .39555 L .25228 .38762 L 0 0 .188 r
F
.25228 .38763 m .25228 .38762 L .25229 .38748 L F
.25145 .39567 m .25228 .38762 L .25228 .38763 L F
.25203 .38826 m .25228 .38762 L .25153 .38818 L .667 .747 .91 r
F
.25193 .38898 m .25204 .38951 L .25135 .39717 L .952 .765 .308 r
F
.25215 .38783 m .25138 .39583 L .25223 .38764 L 0 0 .188 r
F
.25228 .38762 m .25228 .38762 L .25203 .38826 L .667 .747 .91 r
F
.25228 .38762 m .24981 .38674 L .25153 .38818 L F
.25301 .387 m .25229 .38748 L .25228 .38762 L .329 .133 .455 r
F
.25301 .387 m .25228 .38762 L .25299 .38709 L F
.25228 .38762 m .2508 .38585 L .24981 .38674 L .667 .747 .91 r
F
.25597 .38894 m .25294 .38712 L .25228 .38762 L F
.25294 .38712 m .2508 .38585 L .25228 .38762 L F
.25357 .40017 m .25233 .40146 L .25397 .40071 L .642 .739 .919 r
F
.25233 .40146 m .25247 .40208 L .25397 .40071 L F
.25267 .39848 m .25059 .43478 L .24943 .43429 L .839 .573 .538 r
F
.25339 .3906 m .25288 .39857 L .25267 .39848 L F
.25256 .39843 m .25329 .39895 L .25267 .39848 L .642 .739 .919 r
F
.25397 .40071 m .25249 .40215 L .2529 .40395 L F
.25288 .39857 m .25059 .43478 L .25267 .39848 L .839 .573 .538 r
F
.25256 .39843 m .25033 .39835 L .25214 .39868 L .642 .739 .919 r
F
.25511 .39137 m .25462 .39913 L .25478 .39132 L .751 .492 .54 r
F
.25462 .39913 m .25435 .39908 L .25478 .39132 L F
.25511 .39137 m .25556 .3993 L .25462 .39913 L F
.25479 .39116 m .25435 .39908 L .25474 .39115 L F
.25435 .39908 m .25431 .39907 L .25474 .39115 L F
.25336 .39899 m .25409 .39954 L .25451 .39911 L .642 .739 .919 r
F
.25445 .39926 m .25357 .40017 L .25397 .40071 L F
.25474 .39115 m .25431 .39907 L .25464 .39113 L .751 .492 .54 r
F
.25431 .39907 m .25236 .43505 L .25423 .39906 L F
.25431 .39907 m .25423 .39906 L .25464 .39113 L F
.24261 .397 m .24071 .39607 L .23421 .40207 L .642 .738 .918 r
F
.24382 .39319 m .23254 .40079 L .23421 .40207 L F
.24251 .39801 m .24396 .39767 L .24696 .40007 L .852 .588 .538 r
F
.24396 .39767 m .24703 .39918 L .24696 .40007 L F
.24763 .39876 m .24722 .39923 L .24741 .39929 L .642 .738 .918 r
F
.24698 .395 m .24696 .40007 L .24996 .39638 L .667 .747 .91 r
F
.24251 .39801 m .24258 .39699 L .24396 .39767 L .852 .588 .538 r
F
.24698 .395 m .24251 .39801 L .24696 .40007 L .667 .747 .91 r
F
.25033 .39835 m .22303 .40045 L .22709 .40561 L .642 .739 .919 r
F
.25382 .39898 m .25236 .43505 L .25059 .43478 L .751 .492 .54 r
F
.25453 .39111 m .25413 .39904 L .25382 .39898 L F
.25413 .39904 m .25236 .43505 L .25382 .39898 L F
.23897 .39417 m .22424 .39235 L .22828 .39753 L .642 .738 .918 r
F
.24536 .39216 m .22828 .39753 L .24382 .39319 L F
.25027 .39238 m .24071 .39607 L .24261 .397 L F
.23895 .39533 m .24022 .39517 L .24251 .39801 L .915 .65 .521 r
F
.24022 .39517 m .24258 .39699 L .24251 .39801 L F
.22424 .39235 m .20051 .40626 L .22828 .39753 L .642 .738 .918 r
F
.24461 .3932 m .24251 .39801 L .24698 .395 L .667 .747 .91 r
F
.23895 .39533 m .23903 .39425 L .24022 .39517 L .915 .65 .521 r
F
.24461 .3932 m .23895 .39533 L .24251 .39801 L .667 .747 .91 r
F
.247 .39774 m .22115 .39501 L .22303 .40045 L .642 .739 .919 r
F
.25189 .38881 m .25122 .39661 L .25186 .38869 L .952 .765 .308 r
F
.25192 .38897 m .25125 .39673 L .25189 .38881 L F
.25356 .39068 m .25303 .39863 L .25339 .3906 L .839 .573 .538 r
F
.25267 .39848 m .25329 .39895 L .25349 .39884 L .642 .739 .919 r
F
.25303 .39863 m .25059 .43478 L .25288 .39857 L .839 .573 .538 r
F
.25303 .39863 m .25288 .39857 L .25339 .3906 L F
.25018 .39738 m .24607 .39632 L .247 .39774 L .642 .739 .919 r
F
.25464 .39113 m .25423 .39906 L .25453 .39111 L .751 .492 .54 r
F
.25423 .39906 m .25236 .43505 L .25413 .39904 L F
.25423 .39906 m .25413 .39904 L .25453 .39111 L F
.25188 .38848 m .2512 .39651 L .25116 .39636 L .952 .765 .308 r
F
.25215 .38783 m .25188 .38848 L .25116 .39636 L 0 0 .188 r
F
.25215 .38783 m .25116 .39636 L .25138 .39583 L F
.25597 .38894 m .25256 .39022 L .25328 .39075 L .667 .747 .91 r
F
.25376 .39098 m .25355 .39089 L .25356 .39068 L .839 .573 .538 r
F
.25597 .38894 m .25326 .39077 L .25418 .39115 L .667 .747 .91 r
F
.25511 .39137 m .25478 .39132 L .25479 .39116 L .751 .492 .54 r
F
.25597 .38894 m .25412 .39123 L .2552 .39138 L .667 .747 .91 r
F
.25547 .38798 m .25423 .38653 L .2537 .3867 L F
.25301 .387 m .25299 .38709 L .253 .38708 L .329 .133 .455 r
F
.25294 .38712 m .25215 .38516 L .2508 .38585 L .667 .747 .91 r
F
.25413 .38656 m .25338 .38675 L .25338 .3868 L .55 .315 .512 r
F
.25597 .38894 m .2537 .3867 L .25294 .38712 L .667 .747 .91 r
F
.2537 .3867 m .25338 .3868 L .25294 .38712 L F
.23654 .3922 m .23744 .39219 L .23895 .39533 L .977 .72 .476 r
F
.23744 .39219 m .23903 .39425 L .23895 .39533 L F
.25073 .39127 m .24382 .39319 L .25027 .39238 L .642 .738 .918 r
F
.24301 .39112 m .23895 .39533 L .24461 .3932 L .667 .747 .91 r
F
.23654 .3922 m .23662 .39113 L .23744 .39219 L .977 .72 .476 r
F
.24301 .39112 m .23654 .3922 L .23895 .39533 L .667 .747 .91 r
F
.24753 .39595 m .24524 .39467 L .23843 .39494 L .642 .739 .919 r
F
.253 .38708 m .25216 .39497 L .2532 .38693 L .329 .133 .455 r
F
.25527 .3968 m .25084 .39586 L .25026 .39625 L .642 .739 .919 r
F
.22424 .39235 m .19229 .396 L .20051 .40626 L .642 .738 .918 r
F
.24607 .39632 m .22131 .39305 L .23646 .39581 L .642 .739 .919 r
F
.25527 .3968 m .25026 .39625 L .24986 .39652 L F
.25527 .3968 m .24986 .39652 L .25018 .39738 L F
.24986 .39652 m .24802 .39642 L .24921 .39695 L F
.24986 .39652 m .24921 .39695 L .25018 .39738 L F
.25321 .38686 m .25233 .39486 L .25338 .38675 L .329 .133 .455 r
F
.25527 .3968 m .247 .39774 L .25033 .39835 L .642 .739 .919 r
F
.25527 .3968 m .25153 .39797 L .25256 .39843 L F
.25153 .39797 m .25033 .39835 L .25256 .39843 L F
.25214 .39868 m .24276 .40128 L .23303 .41015 L F
.25033 .39835 m .22709 .40561 L .25214 .39868 L F
.25212 .39806 m .24943 .43429 L .25201 .39798 L .913 .647 .523 r
F
.25187 .39787 m .24943 .43429 L .24861 .43368 L F
.25201 .39798 m .24943 .43429 L .25187 .39787 L F
.25151 .39738 m .24861 .43368 L .25144 .3973 L .98 .727 .476 r
F
.25135 .39717 m .24861 .43368 L .24809 .43297 L F
.25144 .3973 m .24861 .43368 L .25135 .39717 L F
.25159 .39749 m .24861 .43368 L .25151 .39738 L F
.25159 .39749 m .25187 .39787 L .24861 .43368 L F
.253 .38708 m .25157 .39537 L .25216 .39497 L .329 .133 .455 r
F
.25299 .38709 m .25157 .39537 L .253 .38708 L F
.25299 .38709 m .25228 .38762 L .25157 .39537 L F
.25221 .38779 m .25145 .39567 L .25228 .38763 L 0 0 .188 r
F
.25229 .38748 m .2515 .39555 L .25157 .39537 L F
.25138 .39583 m .25145 .39567 L .25223 .38764 L F
.25434 .3865 m .25346 .39443 L .25452 .38646 L .55 .315 .512 r
F
.25147 .39197 m .24698 .395 L .24996 .39638 L .667 .747 .91 r
F
.25527 .3968 m .25088 .39509 L .24921 .39552 L .642 .739 .919 r
F
.25527 .3968 m .25256 .39843 L .25349 .39884 L F
.2532 .39871 m .25059 .43478 L .25303 .39863 L .839 .573 .538 r
F
.25224 .39815 m .25267 .39848 L .24943 .43429 L .913 .647 .523 r
F
.25224 .39815 m .24943 .43429 L .25212 .39806 L F
.25216 .39497 m .25233 .39486 L .2532 .38693 L .329 .133 .455 r
F
.24728 .38674 m .2228 .38153 L .24712 .38675 L .642 .738 .918 r
F
.23744 .38233 m .23713 .38233 L .23575 .38548 L 0 0 .297 r
F
.23713 .38233 m .23581 .38464 L .23575 .38548 L F
.23575 .38548 m .23581 .38464 L .23573 .38553 L 0 0 0 r
F
.23584 .38431 m .22554 .37662 L .2228 .38153 L .642 .738 .918 r
F
.23134 .38737 m .2228 .38153 L .22236 .3869 L F
.23522 .38757 m .22236 .3869 L .24709 .38975 L F
.23575 .38548 m .23573 .38553 L .23545 .38884 L 0 0 0 r
F
.23573 .38553 m .23552 .38786 L .23545 .38884 L F
.23545 .38884 m .23552 .38786 L .23587 .38891 L .979 .764 .349 r
F
.24709 .38975 m .23571 .38844 L .23656 .39095 L .642 .738 .918 r
F
.23656 .39095 m .22236 .3869 L .22424 .39235 L F
.23545 .38884 m .23587 .38891 L .23654 .3922 L .979 .764 .349 r
F
.23587 .38891 m .23662 .39113 L .23654 .3922 L F
.25029 .39107 m .24698 .395 L .25147 .39197 L .667 .747 .91 r
F
.25029 .39107 m .24461 .3932 L .24698 .395 L F
.24949 .39003 m .24461 .3932 L .25029 .39107 L F
.24949 .39003 m .24301 .39112 L .24461 .3932 L F
.24229 .38887 m .23654 .3922 L .24301 .39112 L F
.24229 .38887 m .23545 .38884 L .23654 .3922 L F
.24913 .38891 m .24301 .39112 L .24949 .39003 L F
.24913 .38891 m .24229 .38887 L .24301 .39112 L F
.2425 .38663 m .23545 .38884 L .24229 .38887 L F
.2425 .38663 m .23575 .38548 L .23545 .38884 L F
.24363 .38454 m .23575 .38548 L .2425 .38663 L F
.24363 .38454 m .23744 .38233 L .23575 .38548 L F
.24939 .39451 m .22922 .38066 L .22433 .38476 L .642 .739 .919 r
F
.25527 .3968 m .25145 .39443 L .24939 .39451 L F
.24924 .38778 m .24229 .38887 L .24913 .38891 L .667 .747 .91 r
F
.24924 .38778 m .2425 .38663 L .24229 .38887 L F
.25145 .39443 m .22922 .38066 L .24939 .39451 L .642 .739 .919 r
F
.25648 .38641 m .25569 .38641 L .25647 .38652 L .734 .476 .538 r
F
.25529 .38643 m .25551 .38642 L .25552 .38635 L .656 .407 .53 r
F
.25529 .38643 m .25552 .38635 L .25529 .38637 L F
.25618 .38577 m .25598 .3832 L .25591 .3832 L .668 .746 .909 r
F
.25587 .38321 m .25551 .38642 L .25598 .3832 L .656 .407 .53 r
F
.25707 .3833 m .25671 .38643 L .25718 .38331 L .734 .476 .538 r
F
.25682 .38328 m .25598 .3832 L .2557 .38633 L F
.25682 .38328 m .2557 .38633 L .25648 .38641 L F
.2557 .38633 m .2573 .38475 L .25551 .3846 L .667 .747 .91 r
F
.25669 .38643 m .2573 .38475 L .2557 .38633 L F
.25563 .38323 m .25529 .38643 L .25574 .38322 L .656 .407 .53 r
F
.25591 .3832 m .25598 .3832 L .25591 .38319 L .668 .746 .909 r
F
.25697 .38329 m .25751 .38158 L .25591 .38319 L F
.2573 .38475 m .25505 .38023 L .25551 .3846 L .667 .747 .91 r
F
.25823 .38042 m .25756 .38343 L .25838 .38046 L .807 .543 .539 r
F
.25756 .38343 m .25764 .38345 L .25838 .38046 L F
.25838 .38046 m .25764 .38345 L .25804 .38358 L F
.25838 .38046 m .25804 .38358 L .2586 .38053 L F
.25718 .38331 m .25921 .38202 L .25698 .38325 L .668 .746 .909 r
F
.25797 .38356 m .25809 .3834 L .25718 .38331 L F
.25809 .3834 m .25921 .38202 L .25718 .38331 L F
.25697 .38329 m .25718 .38331 L .25698 .38325 L F
.25756 .38343 m .2569 .38645 L .25764 .38345 L .807 .543 .539 r
F
.25698 .38325 m .25921 .38202 L .25751 .38158 L .668 .746 .909 r
F
.25853 .37906 m .25838 .38046 L .2588 .37915 L .807 .543 .539 r
F
.25746 .38018 m .2594 .37888 L .25718 .3801 L .668 .746 .909 r
F
.25817 .3804 m .25828 .38026 L .25746 .38018 L F
.25828 .38026 m .2594 .37888 L .25746 .38018 L F
.2588 .37915 m .25865 .38055 L .25868 .38056 L .807 .543 .539 r
F
.25978 .37981 m .2588 .37915 L .25868 .38056 L .896 .63 .527 r
F
.25817 .3804 m .26088 .37957 L .2594 .37888 L .668 .746 .909 r
F
.25919 .38071 m .26088 .37957 L .25817 .3804 L F
.25716 .38015 m .25738 .38018 L .25759 .37874 L .734 .476 .538 r
F
.25759 .37874 m .25742 .38018 L .25746 .38018 L F
.25718 .3801 m .2594 .37888 L .25771 .37844 L .668 .746 .909 r
F
.2594 .37888 m .25904 .37425 L .25771 .37844 L F
.25921 .38202 m .25885 .37737 L .25751 .38158 L F
.25612 .38005 m .25771 .37844 L .25593 .37828 L F
.25612 .38008 m .25615 .38006 L .25612 .38005 L F
.25615 .38006 m .25771 .37844 L .25612 .38005 L F
.25732 .3787 m .25716 .38015 L .25759 .37874 L .734 .476 .538 r
F
.25722 .37998 m .25771 .37844 L .25612 .38008 L .668 .746 .909 r
F
.25751 .38158 m .25526 .37706 L .25572 .38142 L F
.25717 .38016 m .25746 .38018 L .25718 .3801 L F
.25771 .37844 m .25548 .37393 L .25593 .37828 L F
.25771 .37844 m .25904 .37425 L .25548 .37393 L F
.25751 .38158 m .25885 .37737 L .25526 .37706 L F
.2573 .38475 m .25864 .38055 L .25505 .38023 L .667 .747 .91 r
F
.25904 .37425 m .25501 .36957 L .25548 .37393 L .668 .746 .909 r
F
.25885 .37737 m .2548 .37267 L .25526 .37706 L F
.25864 .38055 m .25458 .37585 L .25505 .38023 L .667 .747 .91 r
F
.2594 .37888 m .26242 .37513 L .25904 .37425 L .668 .746 .909 r
F
.26205 .38047 m .26538 .37653 L .26088 .37957 L F
.26088 .37957 m .26242 .37513 L .2594 .37888 L F
.26088 .37957 m .26538 .37653 L .26242 .37513 L F
.25921 .38202 m .26225 .37826 L .25885 .37737 L F
.26242 .37513 m .26037 .37004 L .25904 .37425 L F
.26225 .37826 m .26019 .37315 L .25885 .37737 L F
.25904 .37425 m .26037 .37004 L .25501 .36957 L F
.25885 .37737 m .26019 .37315 L .2548 .37267 L F
.25864 .38055 m .25998 .37632 L .25458 .37585 L .667 .747 .91 r
F
.2548 .37267 m .24972 .36992 L .2495 .3731 L .662 .415 .535 r
F
.2548 .37267 m .25501 .3695 L .24972 .36992 L F
.25458 .37585 m .2548 .37267 L .2495 .3731 L F
.25998 .37632 m .2548 .37267 L .25458 .37585 L .731 .475 .54 r
F
.2564 .38868 m .25399 .36754 L .24516 .3678 L .642 .738 .918 r
F
.25529 .38643 m .25444 .39432 L .25551 .38642 L .656 .407 .53 r
F
.25349 .39884 m .25329 .39895 L .25336 .39899 L .642 .739 .919 r
F
.2532 .39871 m .25382 .39898 L .25059 .43478 L .839 .573 .538 r
F
.25527 .3968 m .25343 .39891 L .25451 .39911 L .642 .739 .919 r
F
.25233 .39486 m .25247 .39477 L .25338 .38675 L .329 .133 .455 r
F
.25338 .38675 m .25247 .39477 L .25267 .39463 L F
.25413 .38656 m .25338 .3868 L .25267 .39463 L .55 .315 .512 r
F
.25413 .38656 m .25267 .39463 L .25328 .39448 L F
.23783 .38142 m .23042 .37251 L .22554 .37662 L .642 .738 .918 r
F
.24771 .38529 m .24002 .3796 L .23783 .38142 L F
.24002 .3796 m .23042 .37251 L .23783 .38142 L F
.24041 .37963 m .24005 .37957 L .23744 .38233 L .258 .083 .443 r
F
.24005 .37957 m .23749 .38171 L .23744 .38233 L F
.23744 .38233 m .23749 .38171 L .23713 .38233 L 0 0 .297 r
F
.2361 .38154 m .22554 .37662 L .23584 .38431 L .642 .738 .918 r
F
.24981 .38674 m .2425 .38663 L .24924 .38778 L .667 .747 .91 r
F
.24981 .38674 m .24363 .38454 L .2425 .38663 L F
.24561 .38275 m .23744 .38233 L .24363 .38454 L F
.24561 .38275 m .24041 .37963 L .23744 .38233 L F
.25145 .39443 m .23592 .37766 L .22922 .38066 L .642 .739 .919 r
F
.25527 .3968 m .25282 .39438 L .25145 .39443 L F
.25282 .39438 m .23592 .37766 L .25145 .39443 L F
.25451 .39911 m .25438 .39923 L .25445 .39926 L F
.25462 .39913 m .25236 .43505 L .25435 .39908 L .751 .492 .54 r
F
.25527 .3968 m .25451 .39911 L .25556 .3993 L .642 .739 .919 r
F
.25435 .39908 m .25236 .43505 L .25431 .39907 L .751 .492 .54 r
F
.25346 .39443 m .2536 .39439 L .25452 .38646 L .55 .315 .512 r
F
.25452 .38646 m .2536 .39439 L .25381 .39434 L F
.25529 .38643 m .25452 .38646 L .25381 .39434 L .656 .407 .53 r
F
.25529 .38643 m .25381 .39434 L .25444 .39432 L F
.25423 .38653 m .25328 .39448 L .25434 .3865 L .55 .315 .512 r
F
.25413 .38656 m .25328 .39448 L .25423 .38653 L F
.25328 .39448 m .25346 .39443 L .25434 .3865 L F
.24444 .37757 m .24431 .37753 L .24041 .37963 L .456 .242 .499 r
F
.24431 .37753 m .24043 .37926 L .24041 .37963 L F
.24041 .37963 m .24043 .37926 L .24005 .37957 L .258 .083 .443 r
F
.2508 .38585 m .24363 .38454 L .24981 .38674 L .667 .747 .91 r
F
.2508 .38585 m .24561 .38275 L .24363 .38454 L F
.25215 .38516 m .24561 .38275 L .2508 .38585 L F
.25215 .38516 m .2483 .38137 L .24561 .38275 L F
.2483 .38137 m .24041 .37963 L .24561 .38275 L F
.2483 .38137 m .24444 .37757 L .24041 .37963 L F
.25282 .39438 m .24399 .37596 L .23592 .37766 L .642 .739 .919 r
F
.25527 .3968 m .25393 .39434 L .25282 .39438 L F
.25393 .39434 m .24399 .37596 L .25282 .39438 L F
.25551 .38642 m .25462 .39431 L .25569 .38641 L .656 .407 .53 r
F
.25462 .39431 m .25477 .3943 L .25569 .38641 L F
.25513 .39137 m .25556 .3993 L .25511 .39137 L .751 .492 .54 r
F
.25513 .39137 m .25625 .39153 L .25556 .3993 L F
.25569 .38641 m .25477 .3943 L .25498 .39429 L .656 .407 .53 r
F
.25444 .39432 m .25462 .39431 L .25551 .38642 L F
.25413 .38656 m .25338 .3868 L .25413 .38656 L .55 .315 .512 r
F
.2537 .3867 m .25362 .38662 L .25338 .3868 L .667 .747 .91 r
F
.25301 .387 m .253 .38708 L .25321 .38686 L .329 .133 .455 r
F
.253 .38708 m .2532 .38693 L .25321 .38686 L F
.25362 .38662 m .25215 .38516 L .25294 .38712 L .667 .747 .91 r
F
.25527 .3968 m .25284 .37571 L .24399 .37596 L .642 .739 .919 r
F
.25462 .39431 m .2506 .42991 L .25477 .3943 L .656 .407 .53 r
F
.25647 .3915 m .25625 .39153 L .25626 .39143 L .636 .39 .528 r
F
.25684 .39138 m .25794 .3913 L .25683 .39145 L F
.25597 .38894 m .25625 .39153 L .25727 .39139 L .667 .747 .91 r
F
.25597 .38894 m .25792 .39086 L .25661 .38931 L F
.2581 .39122 m .2581 .39123 L .25807 .39123 L .487 .263 .5 r
F
.2581 .39123 m .25807 .39124 L .25807 .39123 L F
.25807 .39123 m .25807 .39124 L .25794 .39128 L F
.25696 .38973 m .25781 .3913 L .25794 .39128 L .642 .738 .918 r
F
.25696 .38973 m .25794 .39128 L .2582 .39119 L F
.25597 .38894 m .25794 .3913 L .2582 .39119 L .667 .747 .91 r
F
.25597 .38894 m .2582 .39119 L .25792 .39086 L F
.25794 .39128 m .25794 .3913 L .25684 .39138 L .636 .39 .528 r
F
.25597 .38894 m .25727 .39139 L .25794 .3913 L .667 .747 .91 r
F
.25648 .38641 m .25647 .38652 L .25671 .38643 L .734 .476 .538 r
F
.25647 .38652 m .2567 .38655 L .25671 .38643 L F
.25677 .38644 m .2569 .38645 L .25678 .38641 L .667 .747 .91 r
F
.25804 .38358 m .2569 .38645 L .2577 .38669 L .807 .543 .539 r
F
.25764 .38345 m .2569 .38645 L .25804 .38358 L F
.2593 .38427 m .2584 .38369 L .25812 .38682 L .896 .63 .527 r
F
.2593 .38427 m .25812 .38682 L .25896 .38737 L F
.25804 .38358 m .2577 .38669 L .25815 .38361 L .807 .543 .539 r
F
.2577 .38669 m .25794 .38677 L .25829 .38365 L F
.2577 .38669 m .25829 .38365 L .25815 .38361 L F
.2569 .38603 m .259 .38519 L .2573 .38475 L .667 .747 .91 r
F
.25678 .38641 m .25717 .3862 L .2569 .38603 L F
.25717 .3862 m .259 .38519 L .2569 .38603 L F
.25777 .38672 m .259 .38519 L .25678 .38641 L F
.25813 .38351 m .25892 .38327 L .25805 .38346 L .668 .746 .909 r
F
.25892 .38327 m .25889 .38322 L .25805 .38346 L F
.25805 .38346 m .25889 .38322 L .25861 .38276 L F
.26242 .37513 m .26545 .37137 L .26037 .37004 L F
.26538 .37653 m .26545 .37137 L .26242 .37513 L F
.26225 .37826 m .2653 .37449 L .26019 .37315 L F
.26538 .37653 m .2699 .37347 L .26545 .37137 L F
.2653 .37449 m .2655 .37132 L .26039 .36998 L .793 .53 .54 r
F
.26057 .38082 m .26036 .38207 L .26043 .38219 L .991 .745 .452 r
F
.2606 .38102 m .26284 .38152 L .26205 .38047 L .668 .746 .909 r
F
.26071 .38168 m .26071 .38106 L .26059 .38245 L .796 .683 .137 r
F
.26059 .3819 m .26284 .38152 L .2606 .38102 L .668 .746 .909 r
F
.25994 .38137 m .26059 .38181 L .2606 .38114 L F
.25993 .38138 m .25995 .38139 L .25994 .38137 L F
.25995 .38139 m .26059 .38181 L .25994 .38137 L F
.26024 .38188 m .26059 .3819 L .26059 .38181 L F
.26029 .38195 m .26059 .3819 L .26024 .38188 L F
.26042 .38109 m .2606 .38114 L .2606 .38102 L F
.26059 .3819 m .26116 .38218 L .2607 .38188 L F
.26071 .38168 m .26065 .3824 L .26071 .38186 L .796 .683 .137 r
F
.26059 .38223 m .26116 .38218 L .26059 .3819 L .668 .746 .909 r
F
.26071 .38168 m .26059 .38245 L .26059 .3829 L .796 .683 .137 r
F
.26059 .38262 m .26093 .38263 L .26059 .38223 L .668 .746 .909 r
F
.2607 .38272 m .26225 .37826 L .25921 .38202 L F
.26059 .38223 m .26093 .38263 L .26116 .38218 L F
.2607 .38188 m .26116 .38218 L .26138 .38176 L F
.26138 .38176 m .26318 .38264 L .26284 .38152 L F
.26093 .38263 m .26318 .38264 L .26138 .38176 L F
.26284 .38152 m .26773 .37833 L .26205 .38047 L F
.26205 .38047 m .26773 .37833 L .26538 .37653 L F
.2607 .38272 m .26523 .37966 L .26225 .37826 L F
.26204 .38144 m .25998 .37632 L .25864 .38055 L .667 .747 .91 r
F
.26523 .37966 m .2653 .37449 L .26225 .37826 L .668 .746 .909 r
F
.26204 .38144 m .26509 .37766 L .25998 .37632 L .667 .747 .91 r
F
.26019 .37315 m .26039 .36998 L .25501 .3695 L .731 .475 .54 r
F
.2653 .37449 m .26039 .36998 L .26019 .37315 L .793 .53 .54 r
F
.26509 .37766 m .2653 .37449 L .26019 .37315 L F
.26019 .37315 m .25501 .3695 L .2548 .37267 L .731 .475 .54 r
F
.25998 .37632 m .26019 .37315 L .2548 .37267 L F
.26509 .37766 m .26019 .37315 L .25998 .37632 L .793 .53 .54 r
F
.25615 .38647 m .26299 .36874 L .25399 .36754 L .642 .738 .918 r
F
.2577 .38669 m .2569 .38645 L .25688 .38658 L .807 .543 .539 r
F
.2564 .38868 m .25707 .38664 L .25615 .38647 L .642 .738 .918 r
F
.2564 .38868 m .25645 .38913 L .25696 .38973 L F
.25604 .40349 m .25675 .40221 L .25659 .39941 L .642 .739 .919 r
F
.25683 .39145 m .25633 .39923 L .25651 .3915 L .636 .39 .528 r
F
.25633 .39923 m .25407 .43484 L .25608 .39926 L F
.25633 .39923 m .25608 .39926 L .25651 .3915 L F
.25978 .39013 m .25913 .39793 L .25971 .39025 L 0 0 .268 r
F
.25913 .39793 m .25907 .39803 L .25972 .39014 L F
.25978 .39013 m .25932 .39758 L .25913 .39793 L F
.25984 .39003 m .25932 .39758 L .25978 .39013 L F
.26055 .38841 m .26257 .38818 L .26026 .38822 L .667 .747 .91 r
F
.25942 .3877 m .25938 .38785 L .25982 .38835 L .991 .745 .452 r
F
.26183 .38795 m .26257 .38818 L .26247 .38784 L .667 .747 .91 r
F
.28778 .39248 m .3236 .39472 L .29066 .38769 L .643 .737 .917 r
F
.2763 .38922 m .27649 .38606 L .27686 .3827 L 0 0 .008 r
F
.2763 .38922 m .27686 .3827 L .27668 .38586 L F
.27611 .39238 m .2763 .38922 L .27668 .38586 L F
.26858 .38696 m .27639 .38604 L .26973 .3849 L .668 .746 .909 r
F
.26973 .3849 m .27639 .38604 L .27676 .3827 L F
.2696 .38807 m .2763 .38922 L .27668 .38586 L F
.2696 .38807 m .27668 .38586 L .26985 .38583 L F
.26249 .38479 m .26858 .38696 L .26973 .3849 L F
.2629 .38692 m .2696 .38807 L .26985 .38583 L F
.26232 .38796 m .2696 .38807 L .2629 .38692 L F
.27611 .39238 m .27668 .38586 L .27649 .38903 L 0 0 .008 r
F
.26941 .39123 m .27611 .39238 L .27649 .38903 L .667 .747 .91 r
F
.26941 .39123 m .27649 .38903 L .26965 .389 L F
.26973 .3849 m .27676 .3827 L .26997 .38267 L .668 .746 .909 r
F
.26997 .38267 m .27676 .3827 L .27575 .37934 L F
.26985 .38583 m .27668 .38586 L .27566 .38249 L F
.27649 .38903 m .27668 .38586 L .27566 .38249 L .97 .756 .323 r
F
.27649 .38903 m .27566 .38249 L .27547 .38566 L F
.26965 .389 m .27649 .38903 L .27547 .38566 L .667 .747 .91 r
F
.26965 .389 m .27547 .38566 L .26896 .38675 L F
.26281 .38897 m .26965 .389 L .26896 .38675 L F
.26281 .38897 m .26896 .38675 L .26247 .38784 L F
.25966 .38831 m .29044 .39047 L .28877 .38499 L .642 .738 .918 r
F
.2564 .38868 m .26 .38887 L .25966 .38831 L F
.25994 .38856 m .25992 .38874 L .26004 .38872 L .991 .745 .452 r
F
.25992 .38874 m .26002 .38889 L .26004 .38872 L F
.25905 .39808 m .25903 .39811 L .25966 .39025 L 0 0 .268 r
F
.25907 .39803 m .25905 .39808 L .25969 .3902 L F
.25912 .39646 m .2592 .39659 L .26004 .38872 L .991 .745 .452 r
F
.26004 .38872 m .26002 .3889 L .26002 .3889 L F
.26139 .38895 m .26281 .38897 L .26137 .38894 L .667 .747 .91 r
F
.26 .38887 m .29044 .39047 L .25966 .38831 L .642 .738 .918 r
F
.25992 .38874 m .25912 .39646 L .26002 .38889 L .991 .745 .452 r
F
.25886 .39902 m .26434 .40492 L .26185 .40088 L .642 .739 .919 r
F
.25908 .39081 m .25849 .3986 L .25907 .39082 L .269 .086 .437 r
F
.25785 .39911 m .26568 .40711 L .25886 .39902 L .642 .739 .919 r
F
.25771 .39922 m .26568 .40711 L .25785 .39911 L F
.25898 .39089 m .25841 .39867 L .25828 .39877 L .269 .086 .437 r
F
.2581 .39123 m .25756 .39904 L .25807 .39124 L .487 .263 .5 r
F
.25756 .39904 m .25754 .39905 L .25807 .39123 L F
.25907 .39077 m .25848 .39861 L .25898 .39084 L .269 .086 .437 r
F
.25838 .39873 m .25823 .39881 L .25886 .39902 L .642 .739 .919 r
F
.25823 .39881 m .25785 .39911 L .25886 .39902 L F
.257 .40177 m .25764 .41739 L .25748 .40089 L F
.2567 .40001 m .25764 .41739 L .25692 .39984 L F
.25659 .39941 m .25663 .40007 L .25666 .39938 L F
.25663 .40007 m .25764 .41739 L .2567 .40001 L F
.25663 .40007 m .2567 .40001 L .25666 .39938 L F
.25921 .39071 m .2586 .39852 L .25908 .39081 L .269 .086 .437 r
F
.2586 .39852 m .25849 .3986 L .25908 .39081 L F
.25848 .39861 m .25841 .39867 L .25898 .39084 L F
.25832 .39125 m .25841 .39134 L .25855 .39122 L .667 .747 .91 r
F
.25841 .39134 m .2584 .39142 L .25886 .39178 L F
.2584 .39142 m .25881 .39189 L .25886 .39178 L F
.25826 .39126 m .25881 .39189 L .25889 .39121 L .642 .738 .918 r
F
.25895 .39122 m .25895 .39125 L .2591 .39137 L F
.25878 .39105 m .25895 .39125 L .25895 .39122 L F
.25878 .39105 m .25873 .39109 L .25895 .39125 L F
.2584 .39142 m .25819 .39307 L .25881 .39189 L .667 .747 .91 r
F
.25819 .39307 m .25818 .39312 L .25886 .39178 L F
.2583 .39115 m .25898 .39089 L .25828 .39877 L .487 .263 .5 r
F
.2583 .39115 m .25828 .39877 L .25772 .39898 L F
.25849 .3986 m .25848 .39861 L .25907 .39082 L .269 .086 .437 r
F
.25898 .39089 m .25841 .39867 L .25898 .39089 L F
.25841 .39867 m .25841 .39867 L .25898 .39089 L F
.26026 .39109 m .27528 .40747 L .28193 .40458 L .642 .738 .918 r
F
.26257 .40142 m .26259 .40121 L .26287 .40116 L .58 .348 .529 r
F
.26038 .39728 m .26257 .40142 L .26613 .40049 L .667 .747 .91 r
F
.2679 .40012 m .26738 .40908 L .27528 .40747 L .642 .738 .918 r
F
.26062 .39888 m .28087 .41266 L .28583 .4087 L .642 .739 .919 r
F
.25921 .39071 m .25896 .39823 L .2586 .39852 L .269 .086 .437 r
F
.25824 .39117 m .25794 .3913 L .25832 .39125 L .667 .747 .91 r
F
.2583 .39115 m .25772 .39898 L .2581 .39122 L .487 .263 .5 r
F
.25754 .39905 m .25762 .39913 L .25838 .39873 L .642 .739 .919 r
F
.25658 .39921 m .25666 .39938 L .25724 .39916 L F
.25666 .39938 m .25692 .39984 L .25724 .39916 L F
.25692 .39984 m .257 .40177 L .25748 .40089 L F
.25666 .39938 m .2567 .40001 L .25692 .39984 L F
.25658 .39921 m .25659 .39941 L .25666 .39938 L F
.25683 .39145 m .25794 .3913 L .25724 .39916 L .636 .39 .528 r
F
.25633 .39923 m .25724 .39916 L .25407 .43484 L F
.25683 .39145 m .25724 .39916 L .25633 .39923 L F
.26132 .39084 m .26171 .39149 L .26212 .39113 L .667 .747 .91 r
F
.26026 .39109 m .28193 .40458 L .26215 .39093 L .642 .738 .918 r
F
.26038 .39728 m .26504 .3992 L .26284 .39663 L .667 .747 .91 r
F
.26001 .39319 m .26358 .39644 L .26001 .39292 L F
.26168 .39527 m .26284 .39663 L .26358 .39644 L F
.26001 .3924 m .26056 .39395 L .26701 .40031 L .642 .738 .918 r
F
.26056 .39395 m .26613 .40049 L .26701 .40031 L F
.26533 .39757 m .26701 .40031 L .2679 .40012 L F
.28193 .40458 m .317 .41237 L .28688 .4006 L F
.26381 .39861 m .28583 .4087 L .28875 .4039 L .642 .739 .919 r
F
.25772 .39898 m .25756 .39904 L .2581 .39122 L .487 .263 .5 r
F
.25966 .39025 m .25903 .39811 L .25896 .39823 L 0 0 .268 r
F
.25972 .39014 m .25907 .39803 L .25969 .3902 L F
.2564 .38868 m .25696 .38973 L .25873 .39109 L .642 .738 .918 r
F
.2564 .38868 m .25873 .39109 L .25878 .39105 L F
.25988 .38486 m .25967 .38452 L .25939 .38765 L .991 .745 .452 r
F
.25964 .38447 m .26201 .38479 L .26023 .38424 L .668 .746 .909 r
F
.25965 .38448 m .26201 .38479 L .25964 .38447 L F
.26003 .38512 m .26048 .38504 L .25967 .38452 L F
.25896 .38737 m .25956 .38444 L .25944 .38436 L .896 .63 .527 r
F
.26048 .38504 m .26201 .38479 L .25961 .38448 L .668 .746 .909 r
F
.26201 .38479 m .26267 .38468 L .26023 .38424 L F
.2593 .38427 m .25896 .38737 L .25944 .38436 L .896 .63 .527 r
F
.26059 .38323 m .26059 .38326 L .26071 .38186 L .796 .683 .137 r
F
.26059 .38321 m .26059 .38323 L .26071 .38186 L F
.26071 .38186 m .26059 .38326 L .26059 .38329 L F
.26058 .38333 m .26092 .38338 L .26059 .38262 L .668 .746 .909 r
F
.259 .38387 m .26188 .38363 L .2607 .38272 L F
.26023 .38424 m .26188 .38363 L .259 .38387 L F
.25784 .38664 m .26049 .38589 L .259 .38519 L .667 .747 .91 r
F
.2579 .38668 m .26049 .38589 L .25784 .38664 L F
.2588 .38703 m .26049 .38589 L .25777 .38672 L F
.26003 .38512 m .26147 .38579 L .26267 .38468 L .668 .746 .909 r
F
.26044 .38579 m .26147 .38579 L .26003 .38512 L F
.26059 .38262 m .26092 .38338 L .26178 .38263 L F
.26178 .38263 m .26307 .38375 L .26318 .38264 L F
.26092 .38338 m .26307 .38375 L .26178 .38263 L F
.26307 .38375 m .26973 .3849 L .26997 .38267 L F
.26249 .38479 m .26973 .3849 L .26307 .38375 L F
.26307 .38375 m .26997 .38267 L .26318 .38264 L F
.26997 .38267 m .27575 .37934 L .26929 .38043 L F
.26318 .38264 m .26997 .38267 L .26929 .38043 L F
.26318 .38264 m .26929 .38043 L .26284 .38152 L F
.26284 .38152 m .26929 .38043 L .26773 .37833 L F
.26929 .38043 m .27341 .37619 L .26773 .37833 L F
.26929 .38043 m .27575 .37934 L .27341 .37619 L F
.26267 .38468 m .26759 .38148 L .26188 .38363 L F
.27566 .38249 m .27585 .37932 L .2735 .37616 L .98 .72 .464 r
F
.26188 .38363 m .26523 .37966 L .2607 .38272 L .668 .746 .909 r
F
.26188 .38363 m .26759 .38148 L .26523 .37966 L F
.26773 .37833 m .2699 .37347 L .26538 .37653 L F
.26773 .37833 m .27341 .37619 L .2699 .37347 L F
.27566 .38249 m .2735 .37616 L .27331 .37933 L .98 .72 .464 r
F
.26147 .38579 m .26302 .3858 L .26269 .38474 L .668 .746 .909 r
F
.26147 .38579 m .26269 .38474 L .26267 .38468 L F
.26028 .38647 m .2629 .38692 L .26064 .38579 L F
.26302 .3858 m .26916 .38358 L .26267 .38468 L F
.26267 .38468 m .26916 .38358 L .26759 .38148 L F
.26167 .3868 m .26503 .38284 L .26049 .38589 L .667 .747 .91 r
F
.2629 .38692 m .26985 .38583 L .26302 .3858 L .668 .746 .909 r
F
.26302 .3858 m .26985 .38583 L .26916 .38358 L F
.26167 .3868 m .26739 .38465 L .26503 .38284 L .667 .747 .91 r
F
.26759 .38148 m .26977 .3766 L .26523 .37966 L .668 .746 .909 r
F
.26759 .38148 m .27331 .37933 L .26977 .3766 L F
.27331 .37933 m .2735 .37616 L .26997 .37343 L .919 .65 .514 r
F
.25961 .38448 m .25965 .38448 L .25964 .38447 L .668 .746 .909 r
F
.25884 .38397 m .26023 .38424 L .259 .38387 L F
.25961 .38448 m .26023 .38424 L .25884 .38397 L F
.26049 .38589 m .26204 .38144 L .259 .38519 L .667 .747 .91 r
F
.26044 .38579 m .26054 .38596 L .26064 .38579 L .668 .746 .909 r
F
.26049 .38589 m .26503 .38284 L .26204 .38144 L .667 .747 .91 r
F
.26523 .37966 m .26977 .3766 L .2653 .37449 L .668 .746 .909 r
F
.26916 .38358 m .27331 .37933 L .26759 .38148 L F
.26739 .38465 m .26958 .37977 L .26503 .38284 L .667 .747 .91 r
F
.26985 .38583 m .27566 .38249 L .26916 .38358 L .668 .746 .909 r
F
.26916 .38358 m .27566 .38249 L .27331 .37933 L F
.26739 .38465 m .27311 .3825 L .26958 .37977 L .667 .747 .91 r
F
.27331 .37933 m .26997 .37343 L .26977 .3766 L .919 .65 .514 r
F
.27311 .3825 m .27331 .37933 L .26977 .3766 L F
.26977 .3766 m .26997 .37343 L .2655 .37132 L .855 .587 .533 r
F
.26503 .38284 m .26509 .37766 L .26204 .38144 L .667 .747 .91 r
F
.26503 .38284 m .26958 .37977 L .26509 .37766 L F
.27311 .3825 m .26977 .3766 L .26958 .37977 L .919 .65 .514 r
F
.26977 .3766 m .2655 .37132 L .2653 .37449 L .855 .587 .533 r
F
.26958 .37977 m .26977 .3766 L .2653 .37449 L F
.26958 .37977 m .2653 .37449 L .26509 .37766 L F
.25796 .38689 m .27898 .37506 L .27152 .3713 L .642 .738 .918 r
F
.2564 .38868 m .25862 .38734 L .25811 .38699 L F
.25527 .3968 m .26061 .39888 L .26062 .39888 L .642 .739 .919 r
F
.26038 .39728 m .26613 .40049 L .26504 .3992 L .667 .747 .91 r
F
.26004 .39795 m .26062 .39888 L .26306 .39867 L .642 .739 .919 r
F
.25527 .3968 m .26062 .39888 L .26004 .39795 L F
.25922 .39064 m .25966 .39036 L .25921 .39071 L .269 .086 .437 r
F
.25941 .38768 m .25938 .38785 L .25942 .3877 L .991 .745 .452 r
F
.26159 .3877 m .26232 .38796 L .26116 .38698 L .668 .746 .909 r
F
.26022 .38746 m .26247 .38784 L .26177 .38692 L .667 .747 .91 r
F
.26183 .38795 m .26247 .38784 L .26022 .38746 L F
.25982 .38835 m .25938 .38785 L .2598 .38854 L .991 .745 .452 r
F
.2564 .38868 m .26 .38827 L .25927 .38778 L .642 .738 .918 r
F
.25527 .3968 m .26306 .39867 L .26258 .39835 L .642 .739 .919 r
F
.25762 .39913 m .25768 .39924 L .25771 .39922 L F
.25772 .39898 m .25512 .43439 L .25756 .39904 L .487 .263 .5 r
F
.25527 .3968 m .25838 .39873 L .25932 .39838 L .642 .739 .919 r
F
.25838 .39873 m .26185 .40088 L .25932 .39838 L F
.25848 .39861 m .25581 .43381 L .25841 .39867 L .269 .086 .437 r
F
.25823 .39881 m .25762 .39913 L .25785 .39911 L .642 .739 .919 r
F
.25527 .3968 m .25754 .39905 L .25838 .39873 L F
.25762 .39913 m .25771 .39922 L .25785 .39911 L F
.25771 .39922 m .25813 .39974 L .25816 .39967 L F
.25771 .39922 m .25804 .3999 L .25813 .39974 L F
.25772 .39898 m .25828 .39877 L .25512 .43439 L .487 .263 .5 r
F
.25754 .39905 m .25724 .39916 L .25762 .39913 L .642 .739 .919 r
F
.25754 .39905 m .25512 .43439 L .25743 .39909 L .487 .263 .5 r
F
.25841 .39867 m .25581 .43381 L .25841 .39867 L .269 .086 .437 r
F
.25604 .39926 m .25407 .43484 L .25586 .39927 L .636 .39 .528 r
F
.25828 .39877 m .25581 .43381 L .25512 .43439 L .269 .086 .437 r
F
.25841 .39867 m .25581 .43381 L .25828 .39877 L F
.25724 .39916 m .25512 .43439 L .25407 .43484 L .487 .263 .5 r
F
.25743 .39909 m .25512 .43439 L .25724 .39916 L F
.25756 .39904 m .25512 .43439 L .25754 .39905 L F
.25608 .39926 m .25407 .43484 L .25604 .39926 L .636 .39 .528 r
F
.25586 .39927 m .25407 .43484 L .25556 .3993 L F
.26002 .38942 m .25932 .39678 L .25932 .39721 L .796 .683 .137 r
F
.25932 .39733 m .25932 .39743 L .26002 .3897 L F
.26002 .3897 m .25932 .39743 L .25932 .39758 L F
.26002 .38942 m .25932 .39721 L .26002 .38957 L F
.25988 .38996 m .25932 .39758 L .25984 .39003 L 0 0 .268 r
F
.25527 .3968 m .26258 .39835 L .26069 .39709 L .642 .739 .919 r
F
.25938 .38785 m .25844 .39557 L .25868 .39573 L .896 .63 .527 r
F
.25939 .38765 m .25937 .38785 L .25938 .38785 L F
.25937 .38785 m .25844 .39557 L .25938 .38785 L F
.25896 .38737 m .25812 .38682 L .25811 .38699 L F
.25896 .38737 m .25811 .38699 L .25892 .38754 L F
.25939 .38765 m .26167 .3868 L .25906 .3871 L .667 .747 .91 r
F
.25939 .38765 m .25906 .3871 L .25862 .38715 L F
.25862 .38715 m .26167 .3868 L .26049 .38589 L F
.27668 .38586 m .27686 .3827 L .27585 .37932 L .97 .756 .323 r
F
.27668 .38586 m .27585 .37932 L .27566 .38249 L F
.26247 .38784 m .26739 .38465 L .26167 .3868 L .667 .747 .91 r
F
.26247 .38784 m .26896 .38675 L .26739 .38465 L F
.27547 .38566 m .27566 .38249 L .27331 .37933 L .98 .72 .464 r
F
.26896 .38675 m .27311 .3825 L .26739 .38465 L .667 .747 .91 r
F
.26896 .38675 m .27547 .38566 L .27311 .3825 L F
.27547 .38566 m .27331 .37933 L .27311 .3825 L .98 .72 .464 r
F
.25862 .38734 m .28486 .37973 L .27898 .37506 L .642 .738 .918 r
F
.2564 .38868 m .25927 .38778 L .25862 .38734 L F
.25896 .38737 m .25892 .38754 L .25894 .38755 L .896 .63 .527 r
F
.25941 .38767 m .25939 .38765 L .25938 .38785 L .991 .745 .452 r
F
.26142 .38689 m .26177 .38692 L .26167 .3868 L .667 .747 .91 r
F
.25941 .38767 m .25938 .38785 L .25941 .38768 L .991 .745 .452 r
F
.25896 .38737 m .25808 .39533 L .2592 .38753 L .896 .63 .527 r
F
.25808 .39533 m .25828 .39547 L .2592 .38753 L F
.25527 .3968 m .25868 .39573 L .25791 .39522 L .642 .739 .919 r
F
.25923 .38755 m .25831 .39548 L .25939 .38765 L .896 .63 .527 r
F
.2598 .38854 m .25868 .39573 L .25902 .39629 L .991 .745 .452 r
F
.26002 .3889 m .25921 .39659 L .25932 .39678 L F
.26 .38887 m .27425 .39248 L .26429 .3891 L .642 .738 .918 r
F
.26041 .38954 m .27425 .39248 L .26 .38887 L F
.26002 .38942 m .26002 .3889 L .25932 .39678 L .796 .683 .137 r
F
.28778 .39248 m .31767 .40422 L .3236 .39472 L .643 .737 .917 r
F
.26429 .3891 m .28979 .39579 L .29044 .39047 L .642 .738 .918 r
F
.27425 .39248 m .28979 .39579 L .26429 .3891 L F
.25933 .39553 m .28771 .39313 L .2838 .38788 L .642 .739 .919 r
F
.26002 .3889 m .2592 .39659 L .26002 .3889 L .991 .745 .452 r
F
.2592 .39659 m .25921 .39659 L .26002 .3889 L F
.25982 .38835 m .25902 .39629 L .25994 .38856 L F
.25902 .39629 m .25912 .39646 L .25994 .38856 L F
.2592 .38753 m .25828 .39547 L .25923 .38755 L .896 .63 .527 r
F
.25527 .3968 m .25955 .39632 L .25868 .39573 L .642 .739 .919 r
F
.31767 .40422 m .35633 .40172 L .3236 .39472 L .643 .737 .917 r
F
.28688 .4006 m .32297 .40286 L .28979 .39579 L .642 .738 .918 r
F
.26112 .39614 m .28939 .39859 L .28771 .39313 L .642 .739 .919 r
F
.25527 .3968 m .26452 .39729 L .26112 .39614 L F
.26452 .39729 m .28939 .39859 L .26112 .39614 L F
.2581 .38699 m .25718 .3948 L .25811 .38699 L .807 .543 .539 r
F
.25527 .3968 m .25658 .39921 L .25724 .39916 L .642 .739 .919 r
F
.25527 .3968 m .25724 .39916 L .25754 .39905 L F
.25718 .3948 m .25718 .3948 L .25811 .38699 L .807 .543 .539 r
F
.25828 .39547 m .25831 .39548 L .25923 .38755 L .896 .63 .527 r
F
.25811 .38699 m .25718 .3948 L .2574 .39488 L .807 .543 .539 r
F
.25831 .39548 m .25844 .39557 L .25939 .38765 L .896 .63 .527 r
F
.25927 .38778 m .28877 .38499 L .28486 .37973 L .642 .738 .918 r
F
.27235 .38654 m .2779 .38321 L .27631 .38242 L .642 .739 .919 r
F
.25927 .38778 m .28486 .37973 L .25862 .38734 L .642 .738 .918 r
F
.25812 .38682 m .2581 .38699 L .25811 .38699 L .807 .543 .539 r
F
.25795 .38694 m .2581 .38699 L .25812 .38682 L F
.25811 .38699 m .27898 .37506 L .25796 .38689 L .642 .738 .918 r
F
.25862 .38734 m .25881 .38723 L .25811 .38699 L F
.25881 .38723 m .27898 .37506 L .25811 .38699 L F
.25796 .38678 m .25795 .38694 L .25812 .38682 L .807 .543 .539 r
F
.25705 .39476 m .25718 .3948 L .2581 .38699 L F
.26 .38827 m .28877 .38499 L .25927 .38778 L .642 .738 .918 r
F
.25894 .38755 m .2574 .39488 L .25808 .39533 L .896 .63 .527 r
F
.25892 .38754 m .2574 .39488 L .25894 .38755 L F
.2598 .38854 m .25938 .38785 L .25868 .39573 L .991 .745 .452 r
F
.25892 .38754 m .25811 .38699 L .2574 .39488 L .896 .63 .527 r
F
.26001 .39331 m .26056 .39395 L .26001 .3924 L .642 .738 .918 r
F
.25705 .39476 m .27235 .38654 L .27041 .37947 L .642 .739 .919 r
F
.25527 .3968 m .25809 .39511 L .25705 .39476 L F
.25809 .39511 m .27235 .38654 L .25705 .39476 L F
.2564 .38868 m .25811 .38699 L .25792 .38693 L .642 .738 .918 r
F
.25795 .38694 m .25705 .39476 L .2581 .38699 L .807 .543 .539 r
F
.25527 .3968 m .25556 .3993 L .25658 .39921 L .642 .739 .919 r
F
.25705 .39476 m .25301 .42995 L .25718 .3948 L .807 .543 .539 r
F
.27235 .38654 m .27631 .38242 L .27041 .37947 L .642 .739 .919 r
F
.25718 .3948 m .25301 .42995 L .25718 .3948 L .807 .543 .539 r
F
.25828 .39547 m .25425 .43034 L .25831 .39548 L .896 .63 .527 r
F
.25868 .39573 m .26112 .39614 L .25933 .39553 L .642 .739 .919 r
F
.25955 .39632 m .26112 .39614 L .25868 .39573 L F
.26112 .39614 m .28771 .39313 L .25933 .39553 L F
.2574 .39488 m .25301 .42995 L .25425 .43034 L .807 .543 .539 r
F
.25718 .3948 m .25301 .42995 L .2574 .39488 L F
.25831 .39548 m .25425 .43034 L .25844 .39557 L .896 .63 .527 r
F
.25628 .39395 m .25622 .39401 L .25618 .39446 L .807 .543 .539 r
F
.2577 .38669 m .25688 .38658 L .25768 .38685 L F
.25794 .38677 m .25792 .38693 L .25794 .38677 L F
.25892 .38327 m .2607 .38272 L .25889 .38322 L .668 .746 .909 r
F
.25861 .38276 m .2607 .38272 L .25921 .38202 L F
.25889 .38322 m .2607 .38272 L .25861 .38276 L F
.259 .38387 m .2592 .38373 L .25813 .38351 L F
.2592 .38373 m .2607 .38272 L .25892 .38327 L F
.2592 .38373 m .25892 .38327 L .25813 .38351 L F
.2584 .38369 m .25813 .38351 L .25797 .38356 L F
.259 .38387 m .25813 .38351 L .2584 .38369 L F
.25797 .38356 m .25813 .38351 L .25805 .38346 L F
.259 .38519 m .25864 .38055 L .2573 .38475 L .667 .747 .91 r
F
.259 .38519 m .26204 .38144 L .25864 .38055 L F
.25709 .38661 m .27152 .3713 L .26299 .36874 L .642 .738 .918 r
F
.2577 .38669 m .25768 .38685 L .25794 .38677 L .807 .543 .539 r
F
.2564 .38868 m .25792 .38693 L .25707 .38664 L .642 .738 .918 r
F
.25768 .38685 m .25618 .39446 L .25683 .39468 L .807 .543 .539 r
F
.25527 .3968 m .25705 .39476 L .25618 .39446 L .642 .739 .919 r
F
.25688 .38658 m .25596 .39443 L .25618 .39446 L .734 .476 .538 r
F
.25605 .39444 m .25618 .39446 L .25606 .39442 L .642 .739 .919 r
F
.25527 .3968 m .25618 .39446 L .25605 .39444 L F
.25707 .38664 m .25688 .38658 L .25615 .38647 L .642 .738 .918 r
F
.2567 .38655 m .25581 .39441 L .25688 .38658 L .734 .476 .538 r
F
.25647 .38652 m .25498 .39429 L .25498 .39429 L F
.25647 .38652 m .25569 .38641 L .25498 .39429 L F
.25597 .38894 m .25634 .389 L .25629 .38894 L .667 .747 .91 r
F
.25647 .38652 m .25498 .39429 L .25562 .39438 L .734 .476 .538 r
F
.25527 .3968 m .25605 .39444 L .25498 .39429 L .642 .739 .919 r
F
.25462 .39913 m .25556 .3993 L .25236 .43505 L .751 .492 .54 r
F
.2564 .38868 m .25631 .38896 L .25637 .38904 L .642 .738 .918 r
F
.2564 .38868 m .25623 .38887 L .25631 .38896 L F
.2564 .38868 m .25637 .38904 L .25645 .38913 L F
.25647 .38652 m .25179 .42982 L .2567 .38655 L .734 .476 .538 r
F
.25498 .39429 m .25606 .39442 L .25495 .39405 L .642 .739 .919 r
F
.25605 .39444 m .25606 .39442 L .25498 .39429 L F
.25688 .38658 m .25596 .39443 L .25688 .38658 L .734 .476 .538 r
F
.25596 .39443 m .25179 .42982 L .25596 .39443 L F
.25596 .39443 m .25596 .39443 L .25688 .38658 L F
.25581 .39441 m .25179 .42982 L .25596 .39443 L F
.25581 .39441 m .25596 .39443 L .25688 .38658 L F
.25618 .39446 m .25179 .42982 L .25301 .42995 L F
.25596 .39443 m .25179 .42982 L .25618 .39446 L F
.25606 .39442 m .25628 .39448 L .25618 .39406 L .642 .739 .919 r
F
.25792 .38693 m .25301 .42995 L .25795 .38694 L .807 .543 .539 r
F
.25628 .39448 m .25712 .39469 L .25695 .39457 L .642 .739 .919 r
F
.25628 .39448 m .25695 .39457 L .25618 .39406 L F
.25705 .39476 m .25712 .39469 L .25606 .39442 L F
.25768 .38685 m .25683 .39468 L .25792 .38693 L .807 .543 .539 r
F
.25683 .39468 m .25301 .42995 L .25702 .39475 L F
.25683 .39468 m .25702 .39475 L .25792 .38693 L F
.25768 .38685 m .25792 .38693 L .25794 .38677 L F
.25707 .38664 m .25808 .38675 L .25709 .38661 L .642 .738 .918 r
F
.25792 .38693 m .25808 .38675 L .25707 .38664 L F
.25777 .38672 m .2579 .38668 L .25784 .38664 L .667 .747 .91 r
F
.25808 .38675 m .27152 .3713 L .25709 .38661 L .642 .738 .918 r
F
.25671 .38643 m .2567 .38655 L .2569 .38645 L .734 .476 .538 r
F
.2567 .38655 m .25688 .38658 L .2569 .38645 L F
.25768 .38685 m .25622 .39401 L .25628 .39395 L .807 .543 .539 r
F
.25768 .38685 m .25688 .38658 L .25622 .39401 L F
.25618 .39406 m .27041 .37947 L .26186 .3769 L .642 .739 .919 r
F
.25712 .39469 m .27041 .37947 L .25618 .39406 L F
.25791 .39522 m .2838 .38788 L .2779 .38321 L F
.25868 .39573 m .2838 .38788 L .25791 .39522 L F
.25808 .39533 m .25425 .43034 L .25828 .39547 L .896 .63 .527 r
F
.25868 .39573 m .25425 .43034 L .25554 .43119 L F
.25844 .39557 m .25425 .43034 L .25868 .39573 L F
.28688 .4006 m .317 .41237 L .32297 .40286 L .642 .738 .918 r
F
.26069 .39709 m .28875 .4039 L .28939 .39859 L .642 .739 .919 r
F
.26258 .39835 m .28875 .4039 L .26069 .39709 L F
.2586 .39852 m .25581 .43381 L .25849 .3986 L .269 .086 .437 r
F
.25849 .3986 m .25581 .43381 L .25848 .39861 L F
.26568 .40711 m .26434 .40492 L .25886 .39902 L .642 .739 .919 r
F
.2586 .39852 m .25896 .39823 L .25581 .43381 L .269 .086 .437 r
F
.25902 .39629 m .25868 .39573 L .25554 .43119 L .991 .745 .452 r
F
.25792 .38693 m .25811 .38699 L .25796 .38689 L .642 .738 .918 r
F
.25808 .39533 m .2574 .39488 L .25425 .43034 L .896 .63 .527 r
F
.26258 .39835 m .26306 .39867 L .26381 .39861 L .642 .739 .919 r
F
.26061 .39888 m .28583 .4087 L .26381 .39861 L F
.25932 .39838 m .26185 .40088 L .26062 .39888 L F
.26185 .40088 m .28087 .41266 L .26062 .39888 L F
.25905 .39808 m .25904 .39813 L .25905 .39808 L 0 0 .268 r
F
.25904 .39813 m .25619 .43311 L .25905 .39808 L F
.25905 .39808 m .25619 .43311 L .25903 .39811 L F
.25896 .39823 m .25619 .43311 L .25581 .43381 L F
.25903 .39811 m .25619 .43311 L .25896 .39823 L F
.2592 .39659 m .25554 .43119 L .25921 .39659 L .991 .745 .452 r
F
.26568 .40711 m .27421 .41554 L .26434 .40492 L .642 .739 .919 r
F
.25907 .39803 m .25619 .43311 L .25905 .39808 L 0 0 .268 r
F
.25913 .39793 m .25619 .43311 L .25907 .39803 L F
.25913 .39793 m .25932 .39758 L .25619 .43311 L F
.25932 .39678 m .25554 .43119 L .25619 .43227 L .991 .745 .452 r
F
.25921 .39659 m .25554 .43119 L .25932 .39678 L F
.25912 .39646 m .25554 .43119 L .2592 .39659 L F
.26185 .40088 m .27421 .41554 L .28087 .41266 L .642 .739 .919 r
F
.26434 .40492 m .27421 .41554 L .26185 .40088 L F
.25707 .38664 m .25709 .38661 L .25688 .38658 L .642 .738 .918 r
F
.2569 .38645 m .25688 .38658 L .25688 .38658 L .734 .476 .538 r
F
.25709 .38661 m .26299 .36874 L .25615 .38647 L .642 .738 .918 r
F
.25413 .38656 m .25413 .38656 L .25423 .38653 L .55 .315 .512 r
F
.25495 .39405 m .26186 .3769 L .25284 .37571 L .642 .739 .919 r
F
.25606 .39442 m .26186 .3769 L .25495 .39405 L F
.25683 .39468 m .25618 .39446 L .25301 .42995 L .807 .543 .539 r
F
.25498 .39429 m .2506 .42991 L .25179 .42982 L .656 .407 .53 r
F
.25477 .3943 m .2506 .42991 L .25498 .39429 L F
.25444 .39432 m .2506 .42991 L .25462 .39431 L F
.25346 .39443 m .24944 .43026 L .2536 .39439 L .55 .315 .512 r
F
.22236 .3869 m .19229 .396 L .22424 .39235 L .642 .738 .918 r
F
.24921 .39552 m .24536 .39294 L .22158 .38966 L .642 .739 .919 r
F
.25088 .39509 m .24536 .39294 L .24921 .39552 L F
.24536 .39294 m .22433 .38476 L .22161 .38961 L F
.24536 .39294 m .22161 .38961 L .22158 .38966 L F
.25562 .39438 m .25498 .39429 L .25179 .42982 L .734 .476 .538 r
F
.25233 .39486 m .24833 .43107 L .25247 .39477 L .329 .133 .455 r
F
.25267 .39463 m .24833 .43107 L .24944 .43026 L F
.25247 .39477 m .24833 .43107 L .25267 .39463 L F
.24986 .39652 m .24753 .39595 L .24607 .39632 L .642 .739 .919 r
F
.25026 .39625 m .24753 .39595 L .24986 .39652 L F
.24753 .39595 m .22131 .39305 L .24607 .39632 L F
.25381 .39434 m .24944 .43026 L .2506 .42991 L .55 .315 .512 r
F
.2536 .39439 m .24944 .43026 L .25381 .39434 L F
.25216 .39497 m .24833 .43107 L .25233 .39486 L .329 .133 .455 r
F
.25026 .39625 m .24921 .39552 L .24753 .39595 L .642 .739 .919 r
F
.25084 .39586 m .24921 .39552 L .25026 .39625 L F
.24921 .39552 m .24524 .39467 L .24753 .39595 L F
.25328 .39448 m .25267 .39463 L .24944 .43026 L .55 .315 .512 r
F
.25444 .39432 m .25381 .39434 L .2506 .42991 L .656 .407 .53 r
F
.23843 .39494 m .22158 .38966 L .22131 .39305 L .642 .739 .919 r
F
.24524 .39467 m .22158 .38966 L .23843 .39494 L F
.23646 .39581 m .22131 .39305 L .22115 .39501 L F
.24802 .39642 m .24607 .39632 L .25018 .39738 L F
.25328 .39448 m .24944 .43026 L .25346 .39443 L .55 .315 .512 r
F
.24607 .39632 m .23646 .39581 L .24322 .39705 L .642 .739 .919 r
F
.24607 .39632 m .24322 .39705 L .247 .39774 L F
.23646 .39581 m .22115 .39501 L .247 .39774 L F
.247 .39774 m .22303 .40045 L .25033 .39835 L F
.25216 .39497 m .25157 .39537 L .24833 .43107 L .329 .133 .455 r
F
.24276 .40128 m .22709 .40561 L .23139 .4089 L .642 .739 .919 r
F
.24276 .40128 m .23139 .4089 L .23303 .41015 L F
.24998 .41103 m .24809 .43297 L .24983 .41251 L .952 .765 .308 r
F
.24998 .41103 m .24983 .41251 L .2512 .39651 L F
.25122 .39661 m .24998 .41103 L .2512 .39651 L F
.25116 .39636 m .24809 .43297 L .2479 .43213 L F
.2512 .39651 m .24809 .43297 L .25116 .39636 L F
.25125 .39673 m .24809 .43297 L .25122 .39661 L F
.25125 .39673 m .25135 .39717 L .24809 .43297 L F
.25145 .39567 m .2479 .43213 L .2515 .39555 L 0 0 .188 r
F
.25157 .39537 m .2479 .43213 L .24833 .43107 L F
.2515 .39555 m .2479 .43213 L .25157 .39537 L F
.2471 .40615 m .24044 .41377 L .2466 .40735 L .642 .739 .919 r
F
.24657 .40743 m .24044 .41377 L .24627 .40815 L F
.25138 .39583 m .2479 .43213 L .25145 .39567 L 0 0 .188 r
F
.24627 .40815 m .24044 .41377 L .24356 .41469 L .642 .739 .919 r
F
.24627 .40815 m .24356 .41469 L .24883 .41623 L F
.25138 .39583 m .25116 .39636 L .2479 .43213 L 0 0 .188 r
F
.25932 .39721 m .25932 .39678 L .25619 .43227 L .796 .683 .137 r
F
.25932 .40081 m .27125 .41614 L .26568 .40711 L .642 .739 .919 r
F
.25932 .40112 m .27125 .41614 L .25932 .40081 L F
.25674 .42614 m .25619 .43227 L .25673 .42629 L .796 .683 .137 r
F
.25674 .42614 m .25673 .42629 L .25932 .39743 L F
.25932 .39733 m .25674 .42614 L .25932 .39743 L F
.25932 .39758 m .25619 .43227 L .25619 .43311 L F
.25932 .39743 m .25619 .43227 L .25932 .39758 L F
.26568 .40711 m .27125 .41614 L .27421 .41554 L .642 .739 .919 r
F
.25902 .39629 m .25554 .43119 L .25912 .39646 L .991 .745 .452 r
F
.25932 .39721 m .25619 .43227 L .25932 .39733 L .796 .683 .137 r
F
.44641 .89838 m .44327 .89487 L .44349 .89762 L .845 .582 .541 r
F
.44663 .90114 m .44641 .89838 L .44349 .89762 L F
0 g
.44641 .89838 m
.44865 .89949 L
s
.61908 .66623 m .61006 .65679 L .60885 .66625 L .656 .808 .956 r
F
.61908 .66623 m .62552 .65677 L .61006 .65679 L F
.71584 .27524 m .71963 .33748 L .72 .33861 L .925 .667 .181 r
F
.71584 .27524 m .71547 .27411 L .71963 .33748 L F
.59501 .79129 m .59719 .7983 L .60137 .79285 L .595 .768 .962 r
F
.59501 .79129 m .58768 .79597 L .59719 .7983 L F
0 g
.59719 .7983 m
.60623 .79936 L
s
.43004 .90379 m .42668 .90259 L .42447 .90401 L .656 .814 .959 r
F
0 g
.4231 .90558 m
.42447 .90401 L
s
.43197 .903 m .42668 .90259 L .43004 .90379 L .656 .814 .959 r
F
.58109 .68417 m .56755 .67847 L .55741 .6849 L .655 .81 .957 r
F
.58974 .68067 m .56755 .67847 L .58109 .68417 L F
.43402 .89967 m .43278 .89779 L .42938 .89864 L .657 .814 .959 r
F
.43645 .89935 m .43278 .89779 L .43402 .89967 L F
.56755 .67847 m .55685 .67953 L .55741 .6849 L .416 .272 .576 r
F
0 g
.55083 .69198 m
.55741 .6849 L
s
.56755 .67847 m .56697 .67309 L .55685 .67953 L .416 .272 .576 r
F
0 g
.55027 .68662 m
.55685 .67953 L
s
.61803 .79954 m .62816 .79381 L .62801 .79838 L .609 .4 .573 r
F
.61534 .79369 m .61803 .79954 L .62801 .79838 L .595 .768 .962 r
F
0 g
.61441 .79953 m
.61803 .79954 L
s
.72909 .4106 m .75985 .42587 L .74613 .40736 L .643 .737 .917 r
F
.75985 .42587 m .78245 .40924 L .78261 .41731 L .51 .308 .542 r
F
.74613 .40736 m .75985 .42587 L .78261 .41731 L .643 .737 .917 r
F
0 g
.73453 .43061 m
.75985 .42587 L
s
.43645 .89935 m .43643 .89731 L .43278 .89779 L .657 .814 .959 r
F
.70782 .27509 m .71178 .33933 L .71181 .33846 L 0 0 .132 r
F
.70849 .27398 m .70782 .27509 L .71181 .33846 L .076 0 .438 r
F
0 g
.70779 .27598 m
.70782 .27509 L
s
.58702 .54326 m .60028 .52775 L .60075 .53421 L .402 .249 .557 r
F
.56891 .53373 m .58702 .54326 L .60075 .53421 L .655 .782 .942 r
F
.55736 .53848 m .58702 .54326 L .56891 .53373 L F
0 g
.56977 .55029 m
.58702 .54326 L
s
.50356 .41433 m .47463 .40259 L .46779 .41209 L .643 .737 .917 r
F
.50904 .4104 m .47463 .40259 L .50356 .41433 L F
.44349 .89762 m .44327 .89487 L .43987 .8945 L .785 .536 .56 r
F
0 g
.44327 .89487 m
.44619 .89563 L
s
.50965 .40244 m .48633 .3867 L .47551 .39466 L .644 .737 .916 r
F
.5167 .39957 m .48633 .3867 L .50965 .40244 L F
.5617 .41738 m .58154 .39964 L .55663 .41289 L .643 .737 .917 r
F
.5617 .41738 m .59162 .40873 L .58154 .39964 L F
.44137 .90232 m .4403 .90002 L .4391 .90207 L .656 .814 .959 r
F
.44137 .90232 m .44371 .90038 L .4403 .90002 L F
.55689 .40492 m .56811 .38438 L .55016 .40132 L .644 .737 .916 r
F
.55689 .40492 m .58162 .39169 L .56811 .38438 L F
.47463 .40259 m .43532 .40511 L .46779 .41209 L .643 .737 .917 r
F
.57962 .79268 m .58787 .7914 L .58768 .79597 L .852 .609 .571 r
F
.57962 .79268 m .57983 .7881 L .58787 .7914 L F
.58983 .78449 m .58787 .7914 L .5952 .78671 L .596 .768 .961 r
F
.58983 .78449 m .57983 .7881 L .58787 .7914 L F
0 g
.58787 .7914 m
.5929 .79264 L
s
.76051 .55867 m .74975 .54689 L .73162 .55396 L .653 .784 .944 r
F
.77405 .55559 m .74975 .54689 L .76051 .55867 L F
.77329 .54911 m .76946 .53568 L .74902 .54038 L .653 .783 .943 r
F
.78735 .54784 m .76946 .53568 L .77329 .54911 L F
.62816 .79381 m .63707 .78695 L .63693 .79151 L .526 .332 .561 r
F
.62801 .79838 m .62816 .79381 L .63693 .79151 L F
.62217 .78832 m .62816 .79381 L .63693 .79151 L .596 .768 .961 r
F
0 g
.61867 .79492 m
.62816 .79381 L
s
.2972 .54211 m .28119 .54272 L .28111 .54919 L .498 .309 .554 r
F
.2972 .54211 m .29725 .53563 L .28119 .54272 L F
0 g
.2694 .55166 m
.28119 .54272 L
s
.35259 .55665 m .33748 .54201 L .33856 .55603 L .654 .782 .942 r
F
.35259 .55665 m .35873 .54297 L .33748 .54201 L F
.59752 .4189 m .62191 .39997 L .59162 .40873 L .643 .737 .917 r
F
.59752 .4189 m .63051 .41535 L .62191 .39997 L F
.43197 .903 m .42959 .90141 L .42668 .90259 L .656 .814 .959 r
F
.43423 .90243 m .42959 .90141 L .43197 .903 L F
.65221 .66764 m .65152 .6623 L .63977 .65856 L .859 .591 .531 r
F
0 g
.65152 .6623 m
.66007 .66754 L
s
.71547 .27411 m .71856 .33659 L .71963 .33748 L .928 .626 .449 r
F
.71547 .27411 m .71442 .27321 L .71856 .33659 L F
0 g
.71547 .27411 m
.71584 .27524 L
s
.71547 .27411 m
.71547 .27411 L
s
.43278 .89779 m .42918 .89589 L .42938 .89864 L .609 .403 .577 r
F
.43278 .89779 m .43257 .89503 L .42918 .89589 L F
0 g
.42627 .89707 m
.42918 .89589 L
s
.76722 .66291 m .74726 .66661 L .75016 .6709 L .655 .81 .958 r
F
.42959 .90141 m .42648 .89983 L .42668 .90259 L .526 .341 .573 r
F
0 g
.42447 .90401 m
.42668 .90259 L
s
.42959 .90141 m .42938 .89864 L .42648 .89983 L .526 .341 .573 r
F
0 g
.42427 .90126 m
.42648 .89983 L
s
.4391 .90207 m .43664 .90007 L .43666 .90211 L .656 .814 .959 r
F
.4391 .90207 m .4403 .90002 L .43664 .90007 L F
.59844 .66754 m .59434 .65875 L .57949 .66252 L .656 .808 .956 r
F
.60885 .66625 m .59434 .65875 L .59844 .66754 L F
.27453 .66467 m .2774 .66653 L .2776 .67189 L .954 .715 .258 r
F
.27453 .66467 m .27433 .6593 L .2774 .66653 L F
0 g
.2774 .66653 m
.28224 .671 L
s
.70977 .27312 m .70849 .27398 L .7125 .33735 L .414 .228 .517 r
F
.70849 .27398 m .71181 .33846 L .7125 .33735 L .076 0 .438 r
F
0 g
.70782 .27509 m
.70849 .27398 L
s
.70849 .27398 m
.70849 .27398 L
s
.29489 .658 m .27769 .66648 L .29685 .66282 L .659 .805 .953 r
F
.29489 .658 m .27464 .65928 L .27769 .66648 L F
.82337 .65631 m .84605 .65004 L .82618 .65131 L .655 .809 .957 r
F
.44663 .90114 m .44349 .89762 L .44371 .90038 L .845 .582 .541 r
F
0 g
.44663 .90114 m
.44888 .90224 L
s
.78735 .54784 m .79076 .53374 L .76946 .53568 L .653 .783 .943 r
F
.44008 .89726 m .43987 .8945 L .43621 .89455 L .73 .494 .57 r
F
.44349 .89762 m .43987 .8945 L .44008 .89726 L .785 .536 .56 r
F
0 g
.43987 .8945 m
.44327 .89487 L
s
.84445 .54483 m .82881 .53204 L .82967 .53851 L .872 .594 .515 r
F
.84533 .5513 m .84445 .54483 L .82967 .53851 L F
0 g
.84445 .54483 m
.85466 .55317 L
s
.46021 .53744 m .47273 .53943 L .47297 .54589 L .926 .656 .509 r
F
.46021 .53744 m .45998 .53095 L .47273 .53943 L F
.48361 .52327 m .47273 .53943 L .49206 .52899 L .655 .781 .941 r
F
.48361 .52327 m .45998 .53095 L .47273 .53943 L F
0 g
.47273 .53943 m
.47991 .54216 L
s
.43423 .90243 m .43299 .90055 L .42959 .90141 L .656 .814 .959 r
F
.43666 .90211 m .43299 .90055 L .43423 .90243 L F
.8439 .66822 m .84731 .65537 L .84827 .66074 L .056 .042 .523 r
F
.8254 .66702 m .8439 .66822 L .84827 .66074 L .654 .811 .959 r
F
0 g
.83583 .67539 m
.8439 .66822 L
s
.62479 .38806 m .63972 .39372 L .63954 .40174 L .94 .671 .501 r
F
.62479 .38806 m .62501 .38002 L .63972 .39372 L F
0 g
.63972 .39372 m
.64712 .39779 L
s
.43666 .90211 m .43664 .90007 L .43299 .90055 L .656 .814 .959 r
F
.60885 .66625 m .61006 .65679 L .59434 .65875 L .656 .808 .956 r
F
.58912 .67531 m .57996 .66778 L .56697 .67309 L .656 .809 .957 r
F
.59902 .67281 m .57996 .66778 L .58912 .67531 L F
.44371 .90038 m .44349 .89762 L .44008 .89726 L .785 .536 .56 r
F
0 g
.44349 .89762 m
.44641 .89838 L
s
.47551 .39466 m .44646 .38283 L .43648 .39719 L .644 .737 .916 r
F
.31646 .66989 m .30168 .67785 L .31872 .67204 L .658 .806 .954 r
F
.31646 .66989 m .2971 .67358 L .30168 .67785 L F
.65587 .37098 m .6401 .39352 L .66556 .38019 L .645 .736 .915 r
F
.65587 .37098 m .62546 .37988 L .6401 .39352 L F
.44536 .39071 m .43599 .39708 L .43532 .40511 L 0 0 .35 r
F
.44536 .39071 m .44601 .38265 L .43599 .39708 L F
0 g
.43273 .41268 m
.43599 .39708 L
s
.62986 .6781 m .62695 .66739 L .62045 .67685 L .655 .81 .957 r
F
.62986 .6781 m .64113 .66931 L .62695 .66739 L F
.37507 .66327 m .39643 .65699 L .37618 .65826 L .659 .806 .954 r
F
.35538 .66205 m .37507 .66327 L .37618 .65826 L F
.43643 .89731 m .43257 .89503 L .43278 .89779 L .673 .451 .576 r
F
.43643 .89731 m .43621 .89455 L .43257 .89503 L F
0 g
.42918 .89589 m
.43257 .89503 L
s
.78245 .40924 m .78228 .4012 L .80092 .38924 L .391 .217 .522 r
F
0 g
.77006 .40584 m
.78228 .4012 L
s
.32467 .5573 m .31644 .54394 L .29715 .54862 L .654 .782 .942 r
F
.33856 .55603 m .31644 .54394 L .32467 .5573 L F
.44008 .89726 m .43621 .89455 L .43643 .89731 L .73 .494 .57 r
F
0 g
.43257 .89503 m
.43621 .89455 L
s
.43621 .89455 m
.43987 .8945 L
s
.71442 .27321 m .71743 .33619 L .71856 .33659 L .818 .533 .507 r
F
.71442 .27321 m .71331 .2728 L .71743 .33619 L F
0 g
.71442 .27321 m
.71547 .27411 L
s
.70977 .27312 m .7125 .33735 L .71381 .33651 L .414 .228 .517 r
F
.71099 .27275 m .70977 .27312 L .71381 .33651 L .566 .34 .531 r
F
0 g
.70849 .27398 m
.70977 .27312 L
s
.76094 .38519 m .78197 .40096 L .80051 .38906 L .645 .736 .915 r
F
.74584 .39102 m .78197 .40096 L .76094 .38519 L F
.63051 .41535 m .63072 .4073 L .62214 .39188 L .992 .739 .409 r
F
0 g
.63072 .4073 m
.63246 .42316 L
s
.71331 .2728 m .71626 .33605 L .71743 .33619 L .735 .468 .525 r
F
.71331 .2728 m .71217 .27266 L .71626 .33605 L F
0 g
.71331 .2728 m
.71442 .27321 L
s
.71099 .27275 m .71381 .33651 L .71505 .33614 L .566 .34 .531 r
F
.71217 .27266 m .71099 .27275 L .71505 .33614 L .657 .408 .532 r
F
0 g
.70977 .27312 m
.71099 .27275 L
s
.43299 .90055 m .42938 .89864 L .42959 .90141 L .609 .403 .577 r
F
.43299 .90055 m .43278 .89779 L .42938 .89864 L F
0 g
.42648 .89983 m
.42938 .89864 L
s
.71217 .27266 m .71505 .33614 L .71626 .33605 L .657 .408 .532 r
F
0 g
.71099 .27275 m
.71217 .27266 L
s
.71217 .27266 m
.71331 .2728 L
s
.42668 .90259 m
.42959 .90141 L
s
.6198 .67148 m .61073 .66203 L .6095 .67151 L .656 .809 .957 r
F
.6198 .67148 m .62628 .662 L .61073 .66203 L F
.33856 .55603 m .33748 .54201 L .31644 .54394 L .654 .782 .942 r
F
.74902 .54038 m .73025 .541 L .73094 .54747 L .531 .349 .579 r
F
.74902 .54038 m .7483 .53389 L .73025 .541 L F
0 g
.71582 .54996 m
.73025 .541 L
s
.39569 .55302 m .37852 .54025 L .37861 .54674 L .852 .597 .553 r
F
0 g
.39569 .55302 m
.40877 .56131 L
s
.80174 .55494 m .79156 .54026 L .78813 .55432 L .653 .784 .944 r
F
.80174 .55494 m .81216 .54123 L .79156 .54026 L F
.4403 .90002 m .44008 .89726 L .43643 .89731 L .73 .494 .57 r
F
.44371 .90038 m .44008 .89726 L .4403 .90002 L .785 .536 .56 r
F
0 g
.44008 .89726 m
.44349 .89762 L
s
.44371 .90038 m
.44663 .90114 L
s
.58963 .78908 m .58768 .79597 L .59501 .79129 L .595 .768 .962 r
F
.58963 .78908 m .57962 .79268 L .58768 .79597 L F
0 g
.58768 .79597 m
.59719 .7983 L
s
.57379 .78405 m .58003 .78354 L .57983 .7881 L .923 .676 .546 r
F
.57379 .78405 m .574 .77948 L .58003 .78354 L F
0 g
.58003 .78354 m
.58584 .78593 L
s
.62801 .79838 m .63693 .79151 L .63679 .79609 L .526 .332 .561 r
F
.62201 .7929 m .62801 .79838 L .63679 .79609 L .595 .768 .962 r
F
.61534 .79369 m .62801 .79838 L .62201 .7929 L F
0 g
.61803 .79954 m
.62801 .79838 L
s
.58613 .77717 m .58018 .78349 L .59012 .77988 L .597 .767 .961 r
F
.58613 .77717 m .57418 .77944 L .58018 .78349 L F
.74643 .65639 m .72685 .66488 L .74663 .66121 L .655 .809 .957 r
F
.74643 .65639 m .72644 .65766 L .72685 .66488 L F
.72693 .66306 m .72655 .66493 L .72735 .67029 L 0 0 .177 r
F
0 g
.72708 .6657 m
.72994 .66981 L
s
.72693 .66306 m .72613 .65768 L .72655 .66493 L 0 0 .177 r
F
.63693 .79151 m .63707 .78695 L .64407 .78366 L .405 .235 .535 r
F
0 g
.6283 .78925 m
.63707 .78695 L
s
.43664 .90007 m .43278 .89779 L .43299 .90055 L .673 .451 .576 r
F
.43664 .90007 m .43643 .89731 L .43278 .89779 L F
0 g
.42938 .89864 m
.43278 .89779 L
s
.4403 .90002 m .43643 .89731 L .43664 .90007 L .73 .494 .57 r
F
0 g
.43278 .89779 m
.43643 .89731 L
s
.43643 .89731 m
.44008 .89726 L
s
.4403 .90002 m
.44371 .90038 L
s
.65221 .66764 m .63977 .65856 L .64045 .66393 L .859 .591 .531 r
F
.65291 .67301 m .65221 .66764 L .64045 .66393 L F
0 g
.65221 .66764 m
.66077 .67287 L
s
.76807 .66829 m .75098 .67626 L .76949 .67044 L .654 .811 .959 r
F
.76807 .66829 m .74808 .67198 L .75098 .67626 L F
.27472 .67006 m .2776 .67189 L .2778 .67726 L .954 .715 .258 r
F
.27472 .67006 m .27453 .66467 L .2776 .67189 L F
.29491 .66339 m .2776 .67189 L .29688 .66821 L .659 .806 .954 r
F
.29491 .66339 m .27453 .66467 L .2776 .67189 L F
0 g
.2776 .67189 m
.28247 .67636 L
s
.82448 .66166 m .84731 .65537 L .82731 .65665 L .655 .81 .958 r
F
.31512 .65673 m .29489 .658 L .29685 .66282 L .659 .805 .953 r
F
.59902 .67281 m .5949 .664 L .57996 .66778 L .656 .809 .957 r
F
.6095 .67151 m .5949 .664 L .59902 .67281 L F
0 g
.42959 .90141 m
.43299 .90055 L
s
.77405 .55559 m .77022 .5422 L .74975 .54689 L .653 .784 .944 r
F
.78813 .55432 m .77022 .5422 L .77405 .55559 L F
.5167 .39957 m .50047 .38083 L .48633 .3867 L .644 .737 .916 r
F
.52485 .39795 m .50047 .38083 L .5167 .39957 L F
.55016 .40132 m .55204 .37936 L .5422 .39886 L F
.55016 .40132 m .56811 .38438 L .55204 .37936 L F
.29715 .54862 m .28111 .54919 L .28103 .55568 L .498 .309 .554 r
F
0 g
.26921 .56458 m
.28103 .55568 L
s
.29715 .54862 m .2972 .54211 L .28111 .54919 L .498 .309 .554 r
F
0 g
.26931 .55811 m
.28111 .54919 L
s
.58974 .68067 m .58056 .67318 L .56755 .67847 L .655 .81 .957 r
F
.59965 .67818 m .58056 .67318 L .58974 .68067 L F
.35498 .65669 m .37565 .65292 L .35549 .65419 L .659 .805 .953 r
F
0 g
.43664 .90007 m
.4403 .90002 L
s
.6095 .67151 m .61073 .66203 L .5949 .664 L .656 .809 .957 r
F
.3754 .66862 m .39679 .66235 L .37651 .66363 L .658 .806 .954 r
F
.35568 .66741 m .3754 .66862 L .37651 .66363 L F
.35383 .66982 m .3754 .66862 L .35568 .66741 L F
.317 .41237 m .35595 .40988 L .32297 .40286 L .642 .738 .918 r
F
0 g
.43299 .90055 m
.43664 .90007 L
s
.1543 .38333 m .16188 .39159 L .16053 .39962 L .999 .807 .471 r
F
.1543 .38333 m .15567 .37526 L .16188 .39159 L F
0 g
.16188 .39159 m
.16776 .3988 L
s
.78813 .55432 m .79156 .54026 L .77022 .5422 L .653 .784 .944 r
F
.84533 .5513 m .82967 .53851 L .83053 .54501 L .872 .594 .515 r
F
0 g
.84533 .5513 m
.85555 .55961 L
s
.48388 .52977 m .47297 .54589 L .49234 .53548 L .655 .782 .942 r
F
.48388 .52977 m .46021 .53744 L .47297 .54589 L F
0 g
.47297 .54589 m
.48951 .55215 L
s
.71457 .37405 m .71141 .39476 L .72897 .39428 L .645 .736 .915 r
F
.7059 .37288 m .71141 .39476 L .71457 .37405 L F
.7059 .37288 m .69427 .39246 L .71141 .39476 L F
.18996 .37706 m .16235 .39154 L .19388 .38792 L .643 .737 .917 r
F
.18996 .37706 m .15618 .37529 L .16235 .39154 L F
.50305 .42239 m .47405 .41068 L .46719 .42015 L .642 .738 .918 r
F
.50854 .41847 m .47405 .41068 L .50305 .42239 L F
.60028 .52775 m .59982 .5213 L .60904 .51074 L .2 .102 .511 r
F
0 g
.59035 .52759 m
.59982 .5213 L
s
.50904 .4104 m .48554 .3946 L .47463 .40259 L .643 .737 .917 r
F
.51613 .40752 m .48554 .3946 L .50904 .4104 L F
.56133 .42545 m .58121 .40776 L .55625 .42098 L .642 .738 .918 r
F
.56133 .42545 m .59132 .41683 L .58121 .40776 L F
.57357 .78863 m .57983 .7881 L .57962 .79268 L .923 .676 .546 r
F
.57357 .78863 m .57379 .78405 L .57983 .7881 L F
.58581 .78178 m .57983 .7881 L .58983 .78449 L .596 .768 .961 r
F
.58581 .78178 m .57379 .78405 L .57983 .7881 L F
0 g
.57983 .7881 m
.58568 .7905 L
s
.55663 .41289 m .56793 .3923 L .54985 .40929 L .643 .737 .917 r
F
.55663 .41289 m .58154 .39964 L .56793 .3923 L F
.35595 .40988 m .35683 .40182 L .3594 .38595 L 0 0 0 r
F
0 g
.35213 .40906 m
.35683 .40182 L
s
.47405 .41068 m .43463 .41318 L .46719 .42015 L .642 .738 .918 r
F
.62045 .67685 m .61137 .66742 L .61014 .67688 L .655 .81 .957 r
F
.62045 .67685 m .62695 .66739 L .61137 .66742 L F
.3236 .39472 m .35633 .40172 L .35889 .38592 L .643 .737 .917 r
F
.63693 .79151 m .64407 .78366 L .64394 .78824 L .405 .235 .535 r
F
.63679 .79609 m .63693 .79151 L .64394 .78824 L F
.62803 .78678 m .63693 .79151 L .64394 .78824 L .596 .768 .961 r
F
.62217 .78832 m .63693 .79151 L .62803 .78678 L F
0 g
.62816 .79381 m
.63693 .79151 L
s
.37565 .65292 m .39578 .65166 L .39341 .64436 L .659 .805 .953 r
F
.39643 .65699 m .39608 .65164 L .39371 .6443 L .9 .666 .156 r
F
0 g
.3948 .65709 m
.39566 .65341 L
s
.53807 .52805 m .54416 .5416 L .55736 .53848 L .655 .782 .942 r
F
.59723 .42698 m .62168 .4081 L .59132 .41683 L .642 .738 .918 r
F
.59723 .42698 m .63031 .42345 L .62168 .4081 L F
.74706 .66178 m .72735 .67029 L .74726 .66661 L .655 .81 .958 r
F
.74706 .66178 m .72693 .66306 L .72735 .67029 L F
.72773 .66846 m .72735 .67029 L .72815 .67566 L 0 0 .177 r
F
0 g
.72788 .67106 m
.73075 .67518 L
s
.72773 .66846 m .72693 .66306 L .72735 .67029 L 0 0 .177 r
F
.76641 .65512 m .74663 .66121 L .76647 .65753 L .655 .809 .957 r
F
.76641 .65512 m .74643 .65639 L .74663 .66121 L F
.57996 .66778 m .56638 .66772 L .56697 .67309 L .531 .354 .587 r
F
.57996 .66778 m .57935 .6624 L .56638 .66772 L F
0 g
.55628 .67417 m
.56638 .66772 L
s
.37852 .54025 m .37843 .53378 L .35862 .52997 L .791 .546 .566 r
F
0 g
.37843 .53378 m
.39545 .5401 L
s
.74975 .54689 m .73094 .54747 L .73162 .55396 L .531 .349 .579 r
F
0 g
.71714 .56288 m
.73162 .55396 L
s
.74975 .54689 m .74902 .54038 L .73094 .54747 L .531 .349 .579 r
F
0 g
.71648 .55641 m
.73094 .54747 L
s
.65291 .67301 m .64045 .66393 L .64113 .66931 L .859 .591 .531 r
F
0 g
.65291 .67301 m
.66147 .67821 L
s
.62457 .39615 m .63954 .40174 L .63936 .4098 L .94 .671 .501 r
F
.62457 .39615 m .62479 .38806 L .63954 .40174 L F
.65541 .37914 m .63954 .40174 L .66518 .38838 L .644 .736 .916 r
F
.65541 .37914 m .62479 .38806 L .63954 .40174 L F
0 g
.63954 .40174 m
.64701 .40583 L
s
.69802 .37035 m .69427 .39246 L .7059 .37288 L .645 .736 .915 r
F
.69802 .37035 m .67865 .3875 L .69427 .39246 L F
.52485 .39795 m .51694 .37752 L .50047 .38083 L .644 .737 .916 r
F
.53356 .39771 m .51694 .37752 L .52485 .39795 L F
.29513 .66877 m .2778 .67726 L .2971 .67358 L .658 .806 .954 r
F
.29513 .66877 m .27472 .67006 L .2778 .67726 L F
0 g
.2778 .67726 m
.28475 .68362 L
s
.5422 .39886 m .53456 .37701 L .53356 .39771 L .644 .737 .916 r
F
.5422 .39886 m .55204 .37936 L .53456 .37701 L F
.8254 .66702 m .84827 .66074 L .82824 .66202 L .654 .811 .959 r
F
.8068 .66581 m .8254 .66702 L .82824 .66202 L F
.80415 .66822 m .8254 .66702 L .8068 .66581 L F
.31526 .6621 m .29688 .66821 L .31621 .66452 L .659 .806 .954 r
F
.31526 .6621 m .29491 .66339 L .29688 .66821 L F
.72345 .3738 m .72897 .39428 L .74584 .39102 L .645 .736 .915 r
F
.71457 .37405 m .72897 .39428 L .72345 .3738 L F
.47463 .40259 m .44536 .39071 L .43532 .40511 L .643 .737 .917 r
F
.44469 .39882 m .43532 .40511 L .43463 .41318 L 0 0 .35 r
F
.44469 .39882 m .44536 .39071 L .43532 .40511 L F
0 g
.43205 .42067 m
.43532 .40511 L
s
.59965 .67818 m .59552 .6694 L .58056 .67318 L .655 .81 .957 r
F
.61014 .67688 m .59552 .6694 L .59965 .67818 L F
.78245 .40924 m .80092 .38924 L .80113 .39731 L .391 .217 .522 r
F
.78261 .41731 m .78245 .40924 L .80113 .39731 L F
.76127 .39342 m .78245 .40924 L .80113 .39731 L .644 .736 .916 r
F
.74606 .39926 m .78245 .40924 L .76127 .39342 L F
0 g
.7701 .4139 m
.78245 .40924 L
s
.51751 .52709 m .51628 .54224 L .524 .52837 L .655 .782 .942 r
F
.51751 .52709 m .50339 .53973 L .51628 .54224 L F
.37565 .65292 m .39341 .64436 L .374 .64807 L .659 .805 .953 r
F
.35549 .65419 m .37565 .65292 L .374 .64807 L F
.35538 .66205 m .37618 .65826 L .3559 .65954 L .659 .806 .954 r
F
.61014 .67688 m .61137 .66742 L .59552 .6694 L .655 .81 .957 r
F
.48633 .3867 m .44646 .38283 L .47551 .39466 L .644 .737 .916 r
F
.63051 .41535 m .62214 .39188 L .62191 .39997 L .992 .739 .409 r
F
.63031 .42345 m .63051 .41535 L .62191 .39997 L F
0 g
.63051 .41535 m
.63226 .43118 L
s
.53356 .39771 m .53456 .37701 L .51694 .37752 L .644 .737 .916 r
F
.59162 .40075 m .60677 .37824 L .58162 .39169 L F
.59162 .40075 m .62168 .39202 L .60677 .37824 L F
.58561 .78637 m .57962 .79268 L .58963 .78908 L .595 .768 .962 r
F
.58561 .78637 m .57357 .78863 L .57962 .79268 L F
0 g
.57962 .79268 m
.58768 .79597 L
s
.84731 .65537 m .84635 .65002 L .84664 .64267 L 0 0 .293 r
F
0 g
.84311 .65564 m
.84635 .65002 L
s
.82618 .65131 m .84605 .65004 L .84634 .64272 L .655 .809 .957 r
F
.63679 .79609 m .64394 .78824 L .64381 .79283 L .405 .235 .535 r
F
.62788 .79136 m .63679 .79609 L .64381 .79283 L .595 .768 .962 r
F
.62201 .7929 m .63679 .79609 L .62788 .79136 L F
0 g
.62801 .79838 m
.63679 .79609 L
s
.35549 .65419 m .374 .64807 L .35463 .65177 L .659 .805 .953 r
F
.82967 .53851 m .82881 .53204 L .81051 .52823 L .798 .541 .549 r
F
0 g
.82881 .53204 m
.84357 .53838 L
s
.39643 .65699 m .39371 .6443 L .39406 .64967 L .9 .666 .156 r
F
.37618 .65826 m .39643 .65699 L .39406 .64967 L .659 .806 .954 r
F
.39679 .66235 m .39643 .65699 L .39406 .64967 L .9 .666 .156 r
F
0 g
.39514 .66245 m
.39602 .65875 L
s
.60028 .52775 m .60904 .51074 L .60952 .51721 L .2 .102 .511 r
F
.60075 .53421 m .60028 .52775 L .60952 .51721 L F
.57761 .52114 m .60028 .52775 L .60952 .51721 L .655 .781 .941 r
F
.56849 .52725 m .60028 .52775 L .57761 .52114 L F
0 g
.59074 .53406 m
.60028 .52775 L
s
.74788 .66717 m .72815 .67566 L .74808 .67198 L .654 .811 .959 r
F
.74788 .66717 m .72773 .66846 L .72815 .67566 L F
0 g
.72815 .67566 m
.7326 .68204 L
s
.76716 .66049 m .74726 .66661 L .76722 .66291 L .655 .81 .958 r
F
.76716 .66049 m .74706 .66178 L .74726 .66661 L F
.58056 .67318 m .56697 .67309 L .56755 .67847 L .531 .354 .587 r
F
0 g
.55741 .6849 m
.56755 .67847 L
s
.58056 .67318 m .57996 .66778 L .56697 .67309 L .531 .354 .587 r
F
0 g
.55685 .67953 m
.56697 .67309 L
s
.64045 .66393 m .63977 .65856 L .62562 .65663 L .793 .543 .559 r
F
0 g
.63977 .65856 m
.65152 .6623 L
s
.82618 .65131 m .84634 .64272 L .82629 .64644 L .655 .809 .957 r
F
.80628 .65258 m .82618 .65131 L .82629 .64644 L F
.51613 .40752 m .49978 .38873 L .48554 .3946 L .643 .737 .917 r
F
.52435 .4059 m .49978 .38873 L .51613 .40752 L F
.53807 .52805 m .55736 .53848 L .54472 .52647 L .655 .782 .942 r
F
.54472 .52647 m .55736 .53848 L .56891 .53373 L F
.57016 .7795 m .574 .77948 L .57379 .78405 L .991 .751 .471 r
F
.57016 .7795 m .57038 .77492 L .574 .77948 L F
0 g
.574 .77948 m
.57925 .78302 L
s
.54985 .40929 m .55174 .38726 L .54183 .40682 L .643 .737 .917 r
F
.54985 .40929 m .56793 .3923 L .55174 .38726 L F
.58375 .77414 m .57418 .77944 L .58613 .77717 L .597 .767 .961 r
F
.58375 .77414 m .57058 .77491 L .57418 .77944 L F
.31551 .66749 m .2971 .67358 L .31646 .66989 L .658 .806 .954 r
F
.31551 .66749 m .29513 .66877 L .2971 .67358 L F
.22303 .40045 m .19926 .41432 L .22709 .40561 L .642 .739 .919 r
F
.22303 .40045 m .19101 .40408 L .19926 .41432 L F
.64394 .78824 m .64407 .78366 L .64882 .7796 L .192 .067 .471 r
F
0 g
.63707 .78695 m
.64407 .78366 L
s
.63272 .77996 m .6439 .78361 L .64862 .77957 L .597 .767 .961 r
F
.71455 .38224 m .71137 .403 L .72906 .40252 L .644 .736 .916 r
F
.70582 .38106 m .71137 .403 L .71455 .38224 L F
.70582 .38106 m .69411 .40069 L .71137 .403 L F
.37618 .65826 m .39406 .64967 L .37452 .6534 L .659 .806 .954 r
F
.3559 .65954 m .37618 .65826 L .37452 .6534 L F
.6024 .78657 m .60137 .79285 L .6056 .78736 L .595 .768 .962 r
F
.6024 .78657 m .59501 .79129 L .60137 .79285 L F
.31645 .53742 m .29725 .53563 L .2972 .54211 L .598 .389 .568 r
F
.31645 .53742 m .31647 .53093 L .29725 .53563 L F
0 g
.28119 .54272 m
.29725 .53563 L
s
.31603 .42045 m .35508 .41797 L .32201 .41096 L .642 .739 .919 r
F
.28583 .4087 m .31603 .42045 L .32201 .41096 L F
.28087 .41266 m .31603 .42045 L .28583 .4087 L F
.35568 .66741 m .37651 .66363 L .3562 .66491 L .658 .806 .954 r
F
.37852 .54025 m .35862 .52997 L .35867 .53646 L .791 .546 .566 r
F
.37861 .54674 m .37852 .54025 L .35867 .53646 L F
0 g
.37852 .54025 m
.39557 .54655 L
s
.15292 .39143 m .16053 .39962 L .15918 .40769 L .999 .807 .471 r
F
.15292 .39143 m .1543 .38333 L .16053 .39962 L F
.18833 .38511 m .16053 .39962 L .19229 .396 L .642 .738 .918 r
F
.18833 .38511 m .1543 .38333 L .16053 .39962 L F
0 g
.16053 .39962 m
.16648 .40686 L
s
.50854 .41847 m .48497 .40271 L .47405 .41068 L .642 .738 .918 r
F
.51565 .4156 m .48497 .40271 L .50854 .41847 L F
.80628 .65258 m .82629 .64644 L .80629 .65015 L .655 .809 .957 r
F
.55625 .42098 m .56757 .40043 L .54945 .41738 L .642 .738 .918 r
F
.55625 .42098 m .58121 .40776 L .56757 .40043 L F
.35595 .40988 m .3594 .38595 L .35853 .39404 L 0 0 0 r
F
.35508 .41797 m .35595 .40988 L .35853 .39404 L F
.32297 .40286 m .35595 .40988 L .35853 .39404 L .642 .738 .918 r
F
0 g
.35122 .41715 m
.35595 .40988 L
s
.84731 .65537 m .84664 .64267 L .8476 .64804 L 0 0 .293 r
F
.84827 .66074 m .84731 .65537 L .8476 .64804 L F
.82731 .65665 m .84731 .65537 L .8476 .64804 L .655 .81 .958 r
F
0 g
.84404 .66101 m
.84731 .65537 L
s
.31555 .65422 m .29489 .658 L .31512 .65673 L .659 .805 .953 r
F
.3559 .65954 m .37452 .6534 L .35503 .65711 L .659 .806 .954 r
F
.4519 .52077 m .45975 .52448 L .45998 .53095 L .986 .716 .416 r
F
.4519 .52077 m .45169 .51427 L .45975 .52448 L F
0 g
.45975 .52448 m
.46634 .52888 L
s
.39679 .66235 m .39406 .64967 L .39441 .65505 L .9 .666 .156 r
F
.37651 .66363 m .39679 .66235 L .39441 .65505 L .658 .806 .954 r
F
0 g
.39502 .66982 m
.39679 .66235 L
s
.47833 .50988 m .4601 .52436 L .48357 .5167 L .656 .78 .94 r
F
.47833 .50988 m .45208 .5142 L .4601 .52436 L F
.69788 .37852 m .69411 .40069 L .70582 .38106 L .644 .736 .916 r
F
.69788 .37852 m .67837 .39571 L .69411 .40069 L F
.7235 .38199 m .72906 .40252 L .74606 .39926 L F
.71455 .38224 m .72906 .40252 L .7235 .38199 L F
.22374 .37883 m .18996 .37706 L .19388 .38792 L .643 .737 .917 r
F
.69146 .36663 m .67865 .3875 L .69802 .37035 L .645 .736 .915 r
F
.69146 .36663 m .66556 .38019 L .67865 .3875 L F
.65527 .38726 m .63936 .4098 L .66506 .39648 L .643 .737 .917 r
F
.65527 .38726 m .62457 .39615 L .63936 .4098 L F
0 g
.63936 .4098 m
.65913 .42059 L
s
.76801 .66588 m .74808 .67198 L .76807 .66829 L .654 .811 .959 r
F
.76801 .66588 m .74788 .66717 L .74808 .67198 L F
.51197 .52493 m .50339 .53973 L .51751 .52709 L .655 .782 .942 r
F
.51197 .52493 m .49234 .53548 L .50339 .53973 L F
.56995 .78409 m .57379 .78405 L .57357 .78863 L .991 .751 .471 r
F
.56995 .78409 m .57016 .7795 L .57379 .78405 L F
.58342 .77874 m .57379 .78405 L .58581 .78178 L .596 .768 .961 r
F
.58342 .77874 m .57016 .7795 L .57379 .78405 L F
0 g
.57379 .78405 m
.57907 .7876 L
s
.72345 .3738 m .74584 .39102 L .73197 .37213 L .645 .736 .915 r
F
.73197 .37213 m .74584 .39102 L .76094 .38519 L F
.52435 .4059 m .51638 .3854 L .49978 .38873 L .643 .737 .917 r
F
.53312 .40566 m .51638 .3854 L .52435 .4059 L F
.59971 .78546 m .59501 .79129 L .6024 .78657 L .595 .768 .962 r
F
.59971 .78546 m .58963 .78908 L .59501 .79129 L F
.47405 .41068 m .44469 .39882 L .43463 .41318 L .642 .738 .918 r
F
0 g
.43137 .4287 m
.43463 .41318 L
s
.64045 .66393 m .62562 .65663 L .62628 .662 L .793 .543 .559 r
F
.64113 .66931 m .64045 .66393 L .62628 .662 L F
0 g
.64045 .66393 m
.65221 .66764 L
s
.54183 .40682 m .53413 .3849 L .53312 .40566 L .643 .737 .917 r
F
.54183 .40682 m .55174 .38726 L .53413 .3849 L F
.82731 .65665 m .8476 .64804 L .82743 .65177 L .655 .81 .958 r
F
.80728 .65793 m .82731 .65665 L .82743 .65177 L F
.3236 .39472 m .35889 .38592 L .3251 .38415 L .643 .737 .917 r
F
.29066 .38769 m .3236 .39472 L .3251 .38415 L F
.76946 .53568 m .7483 .53389 L .74902 .54038 L .608 .404 .58 r
F
.76946 .53568 m .76871 .52918 L .7483 .53389 L F
0 g
.73025 .541 m
.7483 .53389 L
s
.8068 .66581 m .82824 .66202 L .80819 .6633 L .654 .811 .959 r
F
.61596 .78738 m .62201 .7929 L .62788 .79136 L .595 .768 .962 r
F
.82967 .53851 m .81051 .52823 L .81133 .53471 L .798 .541 .549 r
F
.83053 .54501 m .82967 .53851 L .81133 .53471 L F
0 g
.82967 .53851 m
.84445 .54483 L
s
.78261 .41731 m .80113 .39731 L .80135 .40542 L .391 .217 .522 r
F
.76139 .40153 m .78261 .41731 L .80135 .40542 L .643 .737 .917 r
F
.74613 .40736 m .78261 .41731 L .76139 .40153 L F
0 g
.75985 .42587 m
.78261 .41731 L
s
.64394 .78824 m .64882 .7796 L .64869 .78419 L .192 .067 .471 r
F
.64381 .79283 m .64394 .78824 L .64869 .78419 L F
.63269 .78458 m .64394 .78824 L .64869 .78419 L .596 .768 .961 r
F
.62803 .78678 m .64394 .78824 L .63269 .78458 L F
0 g
.63693 .79151 m
.64394 .78824 L
s
.29569 .65298 m .27464 .65928 L .29489 .658 L .659 .805 .953 r
F
.31555 .65422 m .29569 .65298 L .29489 .658 L F
.60075 .53421 m .60952 .51721 L .61001 .5237 L .2 .102 .511 r
F
.57804 .52763 m .60075 .53421 L .61001 .5237 L .655 .782 .942 r
F
.56891 .53373 m .60075 .53421 L .57804 .52763 L F
0 g
.58702 .54326 m
.60075 .53421 L
s
.35463 .65177 m .36968 .64368 L .35244 .64959 L .659 .805 .953 r
F
.35463 .65177 m .374 .64807 L .36968 .64368 L F
.63031 .42345 m .62191 .39997 L .62168 .4081 L .992 .739 .409 r
F
0 g
.63031 .42345 m
.63206 .43924 L
s
.48554 .3946 m .44536 .39071 L .47463 .40259 L .643 .737 .917 r
F
.37651 .66363 m .39441 .65505 L .37485 .65878 L .658 .806 .954 r
F
.3562 .66491 m .37651 .66363 L .37485 .65878 L F
.53312 .40566 m .53413 .3849 L .51638 .3854 L .643 .737 .917 r
F
.59162 .40873 m .60688 .38615 L .58154 .39964 L F
.59162 .40873 m .62191 .39997 L .60688 .38615 L F
.5949 .664 m .57935 .6624 L .57996 .66778 L .61 .411 .588 r
F
.5949 .664 m .59428 .65862 L .57935 .6624 L F
0 g
.56638 .66772 m
.57935 .6624 L
s
.76771 .6526 m .74643 .65639 L .76641 .65512 L .655 .809 .957 r
F
.80728 .65793 m .82743 .65177 L .8073 .6555 L .655 .81 .958 r
F
.29569 .65298 m .27572 .65173 L .27464 .65928 L .659 .805 .953 r
F
.27561 .65711 m .27433 .6593 L .27453 .66467 L 0 0 .174 r
F
0 g
.27506 .661 m
.27656 .66455 L
s
.27561 .65711 m .27542 .65171 L .27433 .6593 L 0 0 .174 r
F
.31644 .54394 m .2972 .54211 L .29715 .54862 L .598 .389 .568 r
F
0 g
.28103 .55568 m
.29715 .54862 L
s
.31644 .54394 m .31645 .53742 L .2972 .54211 L .598 .389 .568 r
F
0 g
.28111 .54919 m
.2972 .54211 L
s
.35867 .53646 m .35862 .52997 L .33744 .529 L .733 .498 .572 r
F
0 g
.35862 .52997 m
.37843 .53378 L
s
.37861 .54674 m .35867 .53646 L .35873 .54297 L .791 .546 .566 r
F
0 g
.37861 .54674 m
.39569 .55302 L
s
.84827 .66074 m .8476 .64804 L .84857 .65342 L 0 0 .293 r
F
.82824 .66202 m .84827 .66074 L .84857 .65342 L .654 .811 .959 r
F
0 g
.8439 .66822 m
.84827 .66074 L
s
.3157 .65959 m .29491 .66339 L .31526 .6621 L .659 .806 .954 r
F
.3562 .66491 m .37485 .65878 L .35533 .66249 L .658 .806 .954 r
F
.58322 .78333 m .57357 .78863 L .58561 .78637 L .595 .768 .962 r
F
.58322 .78333 m .56995 .78409 L .57357 .78863 L F
0 g
.57357 .78863 m
.57962 .79268 L
s
.74897 .65136 m .72644 .65766 L .74643 .65639 L .655 .809 .957 r
F
.76771 .6526 m .74897 .65136 L .74643 .65639 L F
0 g
.26181 .36041 m
.26695 .3023 L
s
.51565 .4156 m .49925 .39685 L .48497 .40271 L .642 .738 .918 r
F
.52389 .41399 m .49925 .39685 L .51565 .4156 L F
0 g
.25483 .35953 m
.26005 .30217 L
s
.64381 .79283 m .64869 .78419 L .64856 .78879 L .192 .067 .471 r
F
.63255 .78917 m .64381 .79283 L .64856 .78879 L .595 .768 .962 r
F
.62788 .79136 m .64381 .79283 L .63255 .78917 L F
0 g
.63679 .79609 m
.64381 .79283 L
s
.54945 .41738 m .55134 .3954 L .5414 .41491 L .642 .738 .918 r
F
.54945 .41738 m .56757 .40043 L .55134 .3954 L F
.80629 .65015 m .82366 .64204 L .80495 .64796 L .655 .809 .957 r
F
.80629 .65015 m .82629 .64644 L .82366 .64204 L F
.59696 .77337 m .58375 .77414 L .58613 .77717 L .597 .767 .961 r
F
.64113 .66931 m .62628 .662 L .62695 .66739 L .793 .543 .559 r
F
0 g
.64113 .66931 m
.65291 .67301 L
s
.82824 .66202 m .84857 .65342 L .82836 .65716 L .654 .811 .959 r
F
.80819 .6633 m .82824 .66202 L .82836 .65716 L F
.62628 .662 m .62562 .65663 L .61008 .65664 L .733 .5 .575 r
F
0 g
.62562 .65663 m
.63977 .65856 L
s
.31734 .65179 m .29569 .65298 L .31555 .65422 L .659 .805 .953 r
F
.45212 .52729 m .45998 .53095 L .46021 .53744 L .986 .716 .416 r
F
.45212 .52729 m .4519 .52077 L .45998 .53095 L F
.47833 .51643 m .45998 .53095 L .48361 .52327 L .655 .781 .941 r
F
.47833 .51643 m .4519 .52077 L .45998 .53095 L F
0 g
.45998 .53095 m
.46662 .53536 L
s
.63272 .77996 m .64862 .77957 L .63585 .77725 L .597 .767 .961 r
F
.71455 .39036 m .71136 .41108 L .72909 .4106 L .643 .737 .917 r
F
.7058 .38918 m .71136 .41108 L .71455 .39036 L F
.7058 .38918 m .69406 .40876 L .71136 .41108 L F
.29571 .65836 m .27453 .66467 L .29491 .66339 L .659 .806 .954 r
F
.3157 .65959 m .29571 .65836 L .29491 .66339 L F
.18703 .39322 m .15918 .40769 L .19101 .40408 L .642 .739 .919 r
F
.18703 .39322 m .15292 .39143 L .15918 .40769 L F
0 g
.15918 .40769 m
.17176 .42292 L
s
.5977 .78409 m .58963 .78908 L .59971 .78546 L .595 .768 .962 r
F
.5977 .78409 m .58561 .78637 L .58963 .78908 L F
.35503 .65711 m .37017 .649 L .35283 .65493 L .659 .806 .954 r
F
.35503 .65711 m .37452 .6534 L .37017 .649 L F
.374 .64807 m .38702 .63773 L .36968 .64368 L .659 .805 .953 r
F
.374 .64807 m .39341 .64436 L .38702 .63773 L F
.33746 .53549 m .31647 .53093 L .31645 .53742 L .672 .448 .573 r
F
.33746 .53549 m .33744 .529 L .31647 .53093 L F
0 g
.29725 .53563 m
.31647 .53093 L
s
.6189 .7866 m .62788 .79136 L .63255 .78917 L .595 .768 .962 r
F
.61596 .78738 m .62788 .79136 L .6189 .7866 L F
.55052 .52406 m .56891 .53373 L .57804 .52763 L .655 .782 .942 r
F
.54472 .52647 m .56891 .53373 L .55052 .52406 L F
.74897 .65136 m .73013 .6501 L .72644 .65766 L .655 .809 .957 r
F
.73065 .65548 m .72613 .65768 L .72693 .66306 L 0 0 .479 r
F
.73065 .65548 m .72984 .65008 L .72613 .65768 L F
0 g
.72613 .65768 m
.72655 .66493 L
s
.77022 .5422 m .74902 .54038 L .74975 .54689 L .608 .404 .58 r
F
0 g
.73162 .55396 m
.74975 .54689 L
s
.77022 .5422 m .76946 .53568 L .74902 .54038 L .608 .404 .58 r
F
0 g
.73094 .54747 m
.74902 .54038 L
s
.81133 .53471 m .81051 .52823 L .78997 .52725 L .734 .495 .567 r
F
0 g
.81051 .52823 m
.82881 .53204 L
s
.83053 .54501 m .81133 .53471 L .81216 .54123 L .798 .541 .549 r
F
0 g
.83053 .54501 m
.84533 .5513 L
s
.35508 .41797 m .35853 .39404 L .35765 .40217 L 0 0 0 r
F
.32201 .41096 m .35508 .41797 L .35765 .40217 L .642 .739 .919 r
F
0 g
.34587 .43207 m
.35508 .41797 L
s
.59552 .6694 m .57996 .66778 L .58056 .67318 L .61 .411 .588 r
F
0 g
.56755 .67847 m
.58056 .67318 L
s
.59552 .6694 m .5949 .664 L .57996 .66778 L .61 .411 .588 r
F
0 g
.56697 .67309 m
.57996 .66778 L
s
.76847 .65797 m .74706 .66178 L .76716 .66049 L .655 .81 .958 r
F
.80819 .6633 m .82836 .65716 L .80821 .66088 L .654 .811 .959 r
F
.29571 .65836 m .27561 .65711 L .27453 .66467 L .659 .806 .954 r
F
.27581 .66252 m .27453 .66467 L .27472 .67006 L 0 0 .174 r
F
0 g
.27525 .66638 m
.27677 .66994 L
s
.27581 .66252 m .27561 .65711 L .27453 .66467 L 0 0 .174 r
F
.35244 .64959 m .36296 .64007 L .34907 .64781 L .659 .805 .953 r
F
.35244 .64959 m .36968 .64368 L .36296 .64007 L F
.31595 .66498 m .29513 .66877 L .31551 .66749 L .658 .806 .954 r
F
.35867 .53646 m .33744 .529 L .33746 .53549 L .733 .498 .572 r
F
0 g
.31647 .53093 m
.33744 .529 L
s
.33744 .529 m
.35862 .52997 L
s
.69127 .37479 m .67837 .39571 L .69788 .37852 L .644 .736 .916 r
F
.69127 .37479 m .66518 .38838 L .67837 .39571 L F
.69784 .38665 m .69406 .40876 L .7058 .38918 L .643 .737 .917 r
F
.69784 .38665 m .67828 .4038 L .69406 .40876 L F
.22236 .3869 m .18833 .38511 L .19229 .396 L .642 .738 .918 r
F
.72352 .39011 m .72909 .4106 L .74613 .40736 L .643 .737 .917 r
F
.71455 .39036 m .72909 .4106 L .72352 .39011 L F
.73209 .38032 m .74606 .39926 L .76127 .39342 L .644 .736 .916 r
F
.7235 .38199 m .74606 .39926 L .73209 .38032 L F
.61073 .66203 m .59428 .65862 L .5949 .664 L .674 .458 .583 r
F
.61073 .66203 m .61008 .65664 L .59428 .65862 L F
0 g
.57935 .6624 m
.59428 .65862 L
s
.56923 .77476 m .57038 .77492 L .57016 .7795 L .897 .727 .221 r
F
.56923 .77476 m .56945 .77017 L .57038 .77492 L F
0 g
.57038 .77492 m
.57385 .77929 L
s
.53524 .43295 m
.53535 .46811 L
s
.58317 .77099 m .57058 .77491 L .58375 .77414 L .597 .767 .961 r
F
.58317 .77099 m .56965 .77018 L .57058 .77491 L F
.52389 .41399 m .51589 .39354 L .49925 .39685 L .642 .738 .918 r
F
.53268 .41375 m .51589 .39354 L .52389 .41399 L F
.35873 .54297 m .35867 .53646 L .33746 .53549 L .733 .498 .572 r
F
0 g
.35867 .53646 m
.37852 .54025 L
s
.77029 .65017 m .74897 .65136 L .76771 .6526 L .655 .809 .957 r
F
.32297 .40286 m .35853 .39404 L .32448 .39225 L .642 .738 .918 r
F
.28979 .39579 m .32297 .40286 L .32448 .39225 L F
.59671 .77797 m .58342 .77874 L .58581 .78178 L .596 .768 .961 r
F
.5414 .41491 m .53368 .39304 L .53268 .41375 L .642 .738 .918 r
F
.5414 .41491 m .55134 .3954 L .53368 .39304 L F
0 g
.52828 .43259 m
.52831 .46799 L
s
.74961 .65673 m .72693 .66306 L .74706 .66178 L .655 .81 .958 r
F
.76847 .65797 m .74961 .65673 L .74706 .66178 L F
.61607 .37233 m .62501 .38002 L .62479 .38806 L .992 .739 .407 r
F
.61607 .37233 m .61631 .36425 L .62501 .38002 L F
0 g
.62501 .38002 m
.63154 .3861 L
s
.64869 .78419 m .64882 .7796 L .65097 .77503 L 0 0 .283 r
F
0 g
.64407 .78366 m
.64882 .7796 L
s
.63269 .78458 m .64869 .78419 L .63584 .78187 L .596 .768 .961 r
F
.63585 .77725 m .64862 .77957 L .65076 .77502 L .597 .767 .961 r
F
.65026 .36043 m .62546 .37988 L .65587 .37098 L .645 .736 .915 r
F
.65026 .36043 m .61681 .3642 L .62546 .37988 L F
.8073 .6555 m .82479 .64737 L .80595 .65331 L .655 .81 .958 r
F
.8073 .6555 m .82743 .65177 L .82479 .64737 L F
.82629 .64644 m .8425 .63608 L .82366 .64204 L .655 .809 .957 r
F
.82629 .64644 m .84634 .64272 L .8425 .63608 L F
.62628 .662 m .61008 .65664 L .61073 .66203 L .733 .5 .575 r
F
0 g
.59428 .65862 m
.61008 .65664 L
s
.61008 .65664 m
.62562 .65663 L
s
.79076 .53374 m .76871 .52918 L .76946 .53568 L .673 .451 .576 r
F
.79076 .53374 m .78997 .52725 L .76871 .52918 L F
0 g
.7483 .53389 m
.76871 .52918 L
s
.62695 .66739 m .62628 .662 L .61073 .66203 L .733 .5 .575 r
F
0 g
.62628 .662 m
.64045 .66393 L
s
.80113 .39731 m .80092 .38924 L .81426 .37462 L .203 .077 .476 r
F
0 g
.79003 .39623 m
.80092 .38924 L
s
.3175 .65715 m .29571 .65836 L .3157 .65959 L .659 .806 .954 r
F
.48497 .40271 m .44469 .39882 L .47405 .41068 L .642 .738 .918 r
F
.29593 .66375 m .27472 .67006 L .29513 .66877 L .658 .806 .954 r
F
.31595 .66498 m .29593 .66375 L .29513 .66877 L F
.77328 .37713 m .80051 .38906 L .81378 .37452 L .645 .736 .915 r
F
.76094 .38519 m .80051 .38906 L .77328 .37713 L F
.48633 .3867 m .46261 .37069 L .44646 .38283 L .644 .737 .916 r
F
.50047 .38083 m .46261 .37069 L .48633 .3867 L F
.53268 .41375 m .53368 .39304 L .51589 .39354 L .642 .738 .918 r
F
.35533 .66249 m .3705 .6544 L .35313 .66032 L .658 .806 .954 r
F
.35533 .66249 m .37485 .65878 L .3705 .6544 L F
.59132 .41683 m .60662 .39431 L .58121 .40776 L .642 .738 .918 r
F
.59132 .41683 m .62168 .4081 L .60662 .39431 L F
.37452 .6534 m .38763 .64303 L .37017 .649 L .659 .806 .954 r
F
.37452 .6534 m .39406 .64967 L .38763 .64303 L F
.39406 .64967 m .39371 .6443 L .38729 .63764 L .981 .703 .418 r
F
0 g
.39371 .6443 m
.39608 .65164 L
s
.53535 .46811 m
.53541 .48659 L
s
.58162 .39169 m .58644 .36707 L .56811 .38438 L .644 .737 .916 r
F
.58162 .39169 m .60677 .37824 L .58644 .36707 L F
0 g
.52831 .46799 m
.52833 .48676 L
s
.74961 .65673 m .73065 .65548 L .72693 .66306 L .655 .81 .958 r
F
.73146 .6609 m .72693 .66306 L .72773 .66846 L 0 0 .479 r
F
.73146 .6609 m .73065 .65548 L .72693 .66306 L F
0 g
.72693 .66306 m
.72735 .67029 L
s
.33244 .75044 m .33304 .7566 L .34006 .75661 L .595 .768 .962 r
F
.32887 .75002 m .33304 .7566 L .33244 .75044 L F
.33244 .75044 m .34006 .75661 L .33597 .75044 L F
.33547 .67809 m .33314 .74638 L .33152 .74645 L .644 .409 .547 r
F
.33892 .67703 m .33932 .67644 L .33543 .74523 L 0 0 .355 r
F
.33532 .74697 m .33597 .75044 L .33921 .75002 L .595 .768 .962 r
F
.33452 .74633 m .33524 .74838 L .33532 .74697 L F
.33524 .74838 m .33597 .75044 L .33532 .74697 L F
.33932 .67644 m .33936 .67573 L .33546 .74463 L 0 0 0 r
F
.33451 .74634 m .33597 .75044 L .33452 .74633 L .595 .768 .962 r
F
.33386 .74635 m .33597 .75044 L .3345 .74632 L F
.33326 .74637 m .33341 .7466 L .33386 .74635 L F
.33341 .7466 m .33597 .75044 L .33386 .74635 L F
.33822 .67753 m .33892 .67703 L .33503 .74571 L .335 .155 .483 r
F
.33381 .7472 m .33244 .75044 L .33512 .75044 L .595 .768 .962 r
F
.33381 .7472 m .33512 .75044 L .33519 .74927 L F
.33547 .67809 m .33716 .67791 L .33324 .74637 L .644 .409 .547 r
F
.33547 .67809 m .33324 .74637 L .33314 .74638 L F
.33822 .67753 m .33499 .74573 L .33432 .7461 L .335 .155 .483 r
F
.33519 .74588 m .33921 .75002 L .33951 .74994 L .595 .768 .962 r
F
.33519 .74588 m .33951 .74994 L .33715 .74684 L F
.33716 .67791 m .33425 .74612 L .33324 .74637 L .516 .302 .527 r
F
.33424 .74612 m .33921 .75002 L .33519 .74588 L .595 .768 .962 r
F
.33716 .67791 m .33822 .67753 L .33432 .7461 L .516 .302 .527 r
F
.33424 .74612 m .33326 .74637 L .3345 .74632 L .595 .768 .962 r
F
.33425 .74612 m .33432 .7461 L .33407 .75038 L .516 .302 .527 r
F
.33716 .67791 m .33432 .7461 L .33425 .74612 L F
.33183 .74422 m .33326 .74637 L .33424 .74612 L .595 .768 .962 r
F
.33326 .74637 m .33326 .74637 L .33424 .74612 L F
.33183 .74422 m .33424 .74612 L .33519 .74588 L F
.33822 .67753 m .33503 .74571 L .33499 .74573 L .335 .155 .483 r
F
.33892 .67703 m .3354 .74525 L .33503 .74571 L 0 0 .355 r
F
.3362 .74559 m .34196 .74921 L .34403 .74805 L .595 .768 .962 r
F
.33183 .74422 m .33715 .74684 L .3362 .74559 L F
.33715 .74684 m .34196 .74921 L .3362 .74559 L F
.33892 .67703 m .33543 .74523 L .3354 .74525 L 0 0 .355 r
F
.33936 .67573 m .33877 .67481 L .33485 .74382 L .992 .745 .442 r
F
.3345 .74632 m .33451 .74634 L .33452 .74633 L .595 .768 .962 r
F
.33499 .74573 m .33479 .7499 L .33432 .7461 L .335 .155 .483 r
F
.33932 .67644 m .33546 .74466 L .33543 .74523 L 0 0 0 r
F
.33752 .74524 m .34403 .74805 L .34527 .74663 L .595 .768 .962 r
F
.33183 .74422 m .34103 .74711 L .33752 .74524 L F
.34103 .74711 m .34403 .74805 L .33752 .74524 L F
.33341 .7466 m .33301 .74818 L .33381 .7472 L F
.33301 .74818 m .33244 .75044 L .33381 .7472 L F
.33326 .74637 m .33319 .74671 L .33341 .7466 L F
.33319 .74671 m .33244 .75044 L .33341 .7466 L F
.33425 .74612 m .33407 .75038 L .33324 .74637 L .516 .302 .527 r
F
.33432 .7461 m .33479 .7499 L .33407 .75038 L .335 .155 .483 r
F
.33932 .67644 m .33546 .74463 L .33546 .74466 L 0 0 0 r
F
.33936 .67573 m .33488 .74387 L .33546 .74463 L .992 .745 .442 r
F
.33608 .74448 m .34527 .74663 L .3456 .74504 L .595 .768 .962 r
F
.33183 .74422 m .33752 .74524 L .33608 .74448 L F
.33752 .74524 m .34527 .74663 L .33608 .74448 L F
.33877 .67481 m .33754 .67409 L .33359 .74315 L .892 .63 .535 r
F
.33877 .67481 m .33359 .74315 L .33366 .74319 L F
.33877 .67481 m .33366 .74319 L .33485 .74382 L F
.33936 .67573 m .33485 .74382 L .33488 .74387 L .992 .745 .442 r
F
.33754 .67409 m .33243 .74284 L .33359 .74315 L .802 .546 .551 r
F
.33329 .74307 m .34117 .74037 L .33822 .7392 L .595 .768 .962 r
F
.33183 .74422 m .33409 .74329 L .33329 .74307 L F
.33409 .74329 m .34117 .74037 L .33329 .74307 L F
.33324 .74637 m .33407 .75038 L .33299 .75075 L .516 .302 .527 r
F
.33314 .74638 m .33324 .74637 L .33299 .75075 L .644 .409 .547 r
F
.33183 .74422 m .33205 .74642 L .33326 .74637 L .595 .768 .962 r
F
.33205 .74642 m .33244 .75044 L .33326 .74637 L F
.33263 .67745 m .33375 .67786 L .32977 .74617 L .834 .575 .548 r
F
.3321 .747 m .32887 .75002 L .33244 .75044 L .595 .768 .962 r
F
.33175 .74687 m .32887 .75002 L .3321 .747 L F
.33076 .74633 m .33067 .74649 L .33206 .74653 L F
.33067 .74649 m .32887 .75002 L .33175 .74687 L F
.33067 .74649 m .33175 .74687 L .33206 .74653 L F
.32887 .75002 m .32594 .75576 L .33304 .7566 L F
.3255 .7492 m .32594 .75576 L .32887 .75002 L F
.33263 .67745 m .3297 .74615 L .32863 .74577 L .834 .575 .548 r
F
.33263 .67745 m .32977 .74617 L .3297 .74615 L F
.33375 .67786 m .33547 .67809 L .33152 .74645 L .749 .499 .553 r
F
.33375 .67786 m .33152 .74645 L .33142 .74643 L F
.33186 .67693 m .33263 .67745 L .32863 .74577 L .909 .647 .529 r
F
.33123 .67561 m .33137 .67632 L .32734 .74476 L .923 .74 .252 r
F
.32823 .7483 m .3255 .7492 L .32865 .74997 L .595 .768 .962 r
F
.32965 .74726 m .32815 .74797 L .33006 .7477 L F
.32815 .74797 m .3255 .7492 L .32823 .7483 L F
.32815 .74797 m .32823 .7483 L .33006 .7477 L F
.33013 .74667 m .32945 .74704 L .33048 .74687 L F
.32945 .74704 m .3255 .7492 L .32965 .74726 L F
.32945 .74704 m .32965 .74726 L .33048 .74687 L F
.32942 .74612 m .32933 .74619 L .33076 .74633 L F
.32933 .74619 m .3255 .7492 L .33013 .74667 L F
.32933 .74619 m .33013 .74667 L .33076 .74633 L F
.33186 .67693 m .32858 .74574 L .32784 .7453 L .909 .647 .529 r
F
.33186 .67693 m .32863 .74577 L .32858 .74574 L F
.33375 .67786 m .33142 .74643 L .32977 .74617 L .749 .499 .553 r
F
.33183 .74422 m .32551 .74683 L .3255 .7492 L .595 .768 .962 r
F
.32551 .74683 m .32256 .74805 L .32432 .74874 L F
.32551 .74683 m .32432 .74874 L .3255 .7492 L F
.33137 .67632 m .32781 .74526 L .32734 .74476 L .981 .727 .472 r
F
.33123 .67561 m .32733 .74472 L .32718 .74415 L .923 .74 .252 r
F
.33123 .67561 m .32734 .74476 L .32733 .74472 L F
.33137 .67632 m .33186 .67693 L .32784 .7453 L .981 .727 .472 r
F
.33137 .67632 m .32784 .7453 L .32781 .74526 L F
.33169 .67471 m .33123 .67561 L .32718 .74415 L 0 0 .29 r
F
.33183 .74422 m .32644 .74534 L .32551 .74683 L .595 .768 .962 r
F
.32107 .74646 m .31871 .74505 L .32024 .74663 L F
.33183 .74422 m .32496 .74465 L .32107 .74646 L F
.32496 .74465 m .31871 .74505 L .32107 .74646 L F
.32784 .7453 m .32836 .75025 L .32757 .74978 L .909 .647 .529 r
F
.3255 .7492 m .31923 .75414 L .32594 .75576 L .595 .768 .962 r
F
.32256 .74805 m .31923 .75414 L .3255 .7492 L F
.32256 .74805 m .31335 .75185 L .31923 .75414 L F
.32821 .75016 m .31967 .75129 L .322 .75271 L .594 .768 .963 r
F
.33006 .7477 m .32823 .7483 L .32887 .75002 L .595 .768 .962 r
F
.32823 .7483 m .32865 .74997 L .32887 .75002 L F
.32858 .74574 m .32837 .75025 L .32784 .7453 L .909 .647 .529 r
F
.32837 .75025 m .32836 .75025 L .32784 .7453 L F
.32734 .74476 m .32757 .74978 L .32708 .7492 L .981 .727 .472 r
F
.32748 .74967 m .32742 .74969 L .32757 .74978 L .594 .768 .963 r
F
.32757 .74978 m .3274 .7496 L .32708 .7492 L .981 .727 .472 r
F
.3271 .74819 m .32708 .7492 L .32693 .74851 L .923 .74 .252 r
F
.32024 .74663 m .31335 .75185 L .32256 .74805 L .595 .768 .962 r
F
.32748 .74967 m .31812 .7497 L .31967 .75129 L .594 .768 .963 r
F
.32781 .74526 m .32757 .74978 L .32734 .74476 L .981 .727 .472 r
F
.32757 .74978 m .32757 .74978 L .32734 .74476 L F
.33169 .67471 m .32721 .7441 L .32765 .74341 L 0 0 .29 r
F
.33169 .67471 m .32718 .74415 L .32721 .7441 L F
.33183 .74422 m .32367 .74374 L .31871 .74505 L .595 .768 .962 r
F
.32367 .74374 m .31806 .7434 L .31853 .7446 L F
.32367 .74374 m .31853 .7446 L .31871 .74505 L F
.33398 .67372 m .33282 .67402 L .32879 .74288 L .57 .346 .536 r
F
.32367 .74374 m .31836 .74181 L .31806 .7434 L .595 .768 .962 r
F
.33183 .74422 m .32648 .74326 L .32367 .74374 L F
.32648 .74326 m .31836 .74181 L .32367 .74374 L F
.33183 .74422 m .32942 .74612 L .33076 .74633 L F
.3292 .75054 m .32837 .75025 L .32905 .75066 L .594 .768 .963 r
F
.32863 .74577 m .3295 .75065 L .32837 .75025 L .834 .575 .548 r
F
.33035 .75078 m .32496 .75387 L .32835 .75469 L .594 .768 .963 r
F
.33048 .74687 m .32965 .74726 L .33006 .7477 L .595 .768 .962 r
F
.32977 .74617 m .33127 .75093 L .32951 .75065 L .749 .499 .553 r
F
.33076 .74633 m .33013 .74667 L .33048 .74687 L .595 .768 .962 r
F
.33142 .74643 m .33127 .75093 L .32977 .74617 L .749 .499 .553 r
F
.33153 .75097 m .32835 .75469 L .33194 .75511 L .594 .768 .963 r
F
.33133 .74888 m .33035 .75078 L .33153 .75097 L F
.33127 .75093 m .32835 .75469 L .33153 .75097 L F
.32249 .76614 m .33364 .76279 L .33315 .7674 L .732 .503 .581 r
F
.32249 .76614 m .32299 .76153 L .33364 .76279 L F
.32594 .75576 m .33364 .7627 L .33304 .7566 L .595 .768 .962 r
F
.32594 .75576 m .32304 .76145 L .33364 .7627 L F
.32198 .77076 m .33315 .7674 L .33265 .77201 L .732 .503 .581 r
F
.32198 .77076 m .32249 .76614 L .33315 .7674 L F
.3254 .76044 m .33315 .7674 L .33255 .76129 L .594 .768 .963 r
F
.3254 .76044 m .32249 .76614 L .33315 .7674 L F
.3249 .76508 m .33265 .77201 L .33205 .76592 L .593 .769 .963 r
F
.3249 .76508 m .32198 .77076 L .33265 .77201 L F
.32835 .75469 m .33255 .76129 L .33194 .75511 L .594 .768 .963 r
F
.32835 .75469 m .3254 .76044 L .33255 .76129 L F
.32784 .75934 m .33205 .76592 L .33144 .75976 L .593 .769 .963 r
F
.32784 .75934 m .3249 .76508 L .33205 .76592 L F
.33304 .7566 m .33364 .7627 L .34411 .76271 L .595 .768 .962 r
F
.33304 .7566 m .34411 .76271 L .34006 .75661 L F
.33194 .75511 m .33255 .76129 L .33961 .76129 L .594 .768 .963 r
F
.3329 .75665 m .33144 .75976 L .33499 .75976 L .593 .769 .963 r
F
.33315 .7674 m .33364 .76279 L .34417 .7628 L .672 .449 .574 r
F
.33315 .7674 m .34417 .7628 L .34369 .76741 L F
.33265 .77201 m .33315 .7674 L .34369 .76741 L F
.33255 .76129 m .33315 .7674 L .34369 .76741 L .594 .768 .963 r
F
.33265 .77201 m .34369 .76741 L .34321 .77203 L .672 .449 .574 r
F
.33255 .76129 m .34369 .76741 L .33961 .76129 L .594 .768 .963 r
F
.33205 .76592 m .33265 .77201 L .34321 .77203 L .593 .769 .963 r
F
.33205 .76592 m .34321 .77203 L .33912 .76592 L F
.33194 .75511 m .33961 .76129 L .33549 .75511 L .594 .768 .963 r
F
.33144 .75976 m .33205 .76592 L .33912 .76592 L .593 .769 .963 r
F
.33144 .75976 m .33912 .76592 L .33499 .75976 L F
.33336 .75192 m .33194 .75511 L .33549 .75511 L .594 .768 .963 r
F
.3327 .75093 m .33181 .7538 L .33336 .75192 L F
.33181 .7538 m .33194 .75511 L .33336 .75192 L F
.33299 .75075 m .33299 .75086 L .33299 .75086 L .516 .302 .527 r
F
.33373 .75076 m .33549 .75511 L .33876 .75469 L .594 .768 .963 r
F
.33128 .75093 m .33299 .75075 L .33299 .75086 L .644 .409 .547 r
F
.33142 .74643 m .33152 .74645 L .33127 .75093 L .749 .499 .553 r
F
.33206 .74653 m .33175 .74687 L .3321 .747 L .595 .768 .962 r
F
.33314 .74638 m .33299 .75075 L .33152 .74645 L .644 .409 .547 r
F
.33152 .74645 m .33299 .75075 L .33128 .75093 L F
.33127 .75093 m .33128 .75093 L .33127 .75093 L F
.33152 .74645 m .33128 .75093 L .33127 .75093 L F
.33266 .75087 m .33156 .75122 L .3327 .75093 L .594 .768 .963 r
F
.33133 .74888 m .33153 .75092 L .33266 .75087 L F
.33153 .75092 m .33156 .75122 L .33266 .75087 L F
.33299 .75075 m .33407 .75038 L .33406 .75058 L .516 .302 .527 r
F
.33364 .75069 m .33312 .75082 L .33373 .75076 L .594 .768 .963 r
F
.33266 .75087 m .33286 .75118 L .33359 .75083 L F
.33266 .75087 m .33359 .75083 L .33373 .75076 L F
.33286 .75118 m .33294 .75119 L .33373 .75076 L F
.33289 .75122 m .33549 .75511 L .33373 .75076 L F
.33237 .75585 m .33189 .75788 L .3329 .75665 L .593 .769 .963 r
F
.33189 .75788 m .33144 .75976 L .3329 .75665 L F
.33299 .75075 m .33406 .75058 L .33299 .75086 L .516 .302 .527 r
F
.33407 .75038 m .33406 .75058 L .33406 .75058 L .335 .155 .483 r
F
.33597 .75044 m .34006 .75661 L .34653 .75577 L .595 .768 .962 r
F
.33442 .75039 m .33876 .75469 L .34152 .75388 L .594 .768 .963 r
F
.33407 .75038 m .33477 .7502 L .33406 .75058 L .335 .155 .483 r
F
.33133 .74888 m .33373 .75076 L .33442 .75039 L .594 .768 .963 r
F
.33373 .75076 m .33876 .75469 L .33442 .75039 L F
.33407 .75038 m .33479 .7499 L .33477 .7502 L .335 .155 .483 r
F
.33519 .74927 m .33512 .75044 L .33597 .75044 L .595 .768 .962 r
F
.33921 .75002 m .34653 .75577 L .35203 .75416 L F
.33597 .75044 m .34653 .75577 L .33921 .75002 L F
.33493 .75 m .34152 .75388 L .3436 .75272 L .594 .768 .963 r
F
.33456 .75046 m .34152 .75388 L .33493 .75 L F
.33478 .75019 m .33492 .75421 L .33454 .75466 L 0 0 .355 r
F
.33479 .7499 m .3348 .75017 L .33478 .75019 L F
.3348 .75017 m .33492 .75421 L .33478 .75019 L F
.33921 .75002 m .35203 .75416 L .34196 .74921 L .595 .768 .962 r
F
.33528 .74958 m .3436 .75272 L .34485 .75129 L .594 .768 .963 r
F
.33479 .7499 m .33519 .74932 L .33517 .74971 L 0 0 .355 r
F
.33479 .7499 m .33517 .74971 L .3348 .75017 L F
.33481 .7495 m .33481 .7495 L .33479 .7499 L .335 .155 .483 r
F
.33499 .74573 m .33481 .7495 L .33481 .7495 L F
.33499 .74573 m .33503 .74571 L .33481 .7495 L F
.33503 .74571 m .33519 .74932 L .33479 .7499 L 0 0 .355 r
F
.33517 .74971 m .3436 .75272 L .33528 .74958 L .594 .768 .963 r
F
.33493 .75 m .33515 .75007 L .33517 .74971 L F
.33515 .75007 m .3436 .75272 L .33517 .74971 L F
.33519 .74932 m .33524 .74863 L .33521 .74911 L 0 0 0 r
F
.33477 .75662 m .33499 .75976 L .33826 .75934 L .593 .769 .963 r
F
.33365 .75575 m .33465 .75874 L .33477 .75662 L F
.33465 .75874 m .33499 .75976 L .33477 .75662 L F
.33519 .74932 m .33521 .74911 L .33517 .74971 L 0 0 0 r
F
.33519 .74932 m .33517 .74971 L .33517 .74971 L F
.33715 .74684 m .33951 .74994 L .34196 .74921 L .595 .768 .962 r
F
.3354 .74525 m .33543 .74523 L .33519 .74932 L 0 0 .355 r
F
.33543 .74523 m .33524 .74863 L .33519 .74932 L 0 0 0 r
F
.3354 .74525 m .33519 .74932 L .33503 .74571 L 0 0 .355 r
F
.34196 .74921 m .35203 .75416 L .35617 .75186 L .595 .768 .962 r
F
.34196 .74921 m .35617 .75186 L .34403 .74805 L F
.3352 .74911 m .34485 .75129 L .34518 .7497 L .594 .768 .963 r
F
.33133 .74888 m .33561 .74964 L .3352 .74911 L F
.33561 .74964 m .34485 .75129 L .3352 .74911 L F
.33517 .74971 m .33521 .74911 L .33495 .75361 L 0 0 0 r
F
.33345 .75599 m .33464 .75891 L .33365 .75575 L .593 .769 .963 r
F
.33464 .75891 m .33499 .75976 L .33465 .75874 L F
.33464 .75891 m .33465 .75874 L .33365 .75575 L F
.33237 .75585 m .33462 .75921 L .33321 .7554 L F
.33462 .75921 m .33499 .75976 L .33464 .75891 L F
.33462 .75921 m .33464 .75891 L .33321 .7554 L F
.33517 .74971 m .33492 .75417 L .33517 .74971 L 0 0 0 r
F
.33299 .75086 m .33406 .75058 L .33381 .75508 L .516 .302 .527 r
F
.34006 .75661 m .34411 .76271 L .35379 .76147 L .595 .768 .962 r
F
.33549 .75511 m .33961 .76129 L .34612 .76046 L .594 .768 .963 r
F
.33332 .7552 m .33826 .75934 L .33916 .75908 L .593 .769 .963 r
F
.33304 .75527 m .33826 .75934 L .33332 .7552 L F
.33299 .75086 m .33381 .75508 L .3328 .75533 L .516 .302 .527 r
F
.33406 .75058 m .33452 .75469 L .33385 .75505 L .335 .155 .483 r
F
.33406 .75058 m .33385 .75505 L .33381 .75508 L F
.33406 .75058 m .33385 .75505 L .33406 .75058 L F
.33299 .75086 m .3328 .75533 L .33273 .75535 L .516 .302 .527 r
F
.33299 .75086 m .3328 .75533 L .33299 .75086 L F
.33127 .75093 m .33128 .75093 L .33112 .75541 L .644 .409 .547 r
F
.33127 .75093 m .33112 .75541 L .33111 .75542 L F
.33438 .75528 m .33916 .75908 L .33735 .75673 L .593 .769 .963 r
F
.33286 .75118 m .33289 .75122 L .33294 .75119 L .594 .768 .963 r
F
.33156 .75122 m .33181 .7538 L .3327 .75093 L F
.33128 .75093 m .33299 .75086 L .33273 .75535 L .644 .409 .547 r
F
.33128 .75093 m .33273 .75535 L .33112 .75541 L F
.33026 .75097 m .32835 .75469 L .33127 .75093 L .594 .768 .963 r
F
.32914 .7506 m .32496 .75387 L .33035 .75078 L F
.32905 .75066 m .322 .75271 L .32496 .75387 L F
.32821 .75016 m .322 .75271 L .32905 .75066 L F
.32837 .7503 m .32951 .75071 L .32925 .75515 L .834 .575 .548 r
F
.33104 .75578 m .32784 .75934 L .33144 .75976 L .593 .769 .963 r
F
.33079 .75569 m .32784 .75934 L .33104 .75578 L F
.32994 .75525 m .32988 .75537 L .33101 .75542 L F
.32988 .75537 m .32784 .75934 L .33079 .75569 L F
.32988 .75537 m .33079 .75569 L .33101 .75542 L F
.31923 .75414 m .32304 .76145 L .32594 .75576 L .595 .768 .962 r
F
.32496 .75387 m .3254 .76044 L .32835 .75469 L .594 .768 .963 r
F
.3124 .76372 m .32299 .76153 L .32249 .76614 L .787 .554 .584 r
F
.3124 .76372 m .31292 .75911 L .32299 .76153 L F
.31923 .75414 m .31301 .75904 L .32304 .76145 L .595 .768 .962 r
F
.31865 .75882 m .32249 .76614 L .3254 .76044 L .594 .768 .963 r
F
.32496 .75387 m .31865 .75882 L .3254 .76044 L F
.32445 .75852 m .3249 .76508 L .32784 .75934 L .593 .769 .963 r
F
.32837 .7503 m .32925 .75515 L .32817 .75477 L .834 .575 .548 r
F
.33035 .75078 m .33026 .75097 L .33127 .75093 L .594 .768 .963 r
F
.32951 .75071 m .33127 .75093 L .33101 .75542 L .749 .499 .553 r
F
.32951 .75071 m .33101 .75542 L .32935 .75516 L F
.32742 .74969 m .31967 .75129 L .32796 .75019 L .594 .768 .963 r
F
.32757 .74978 m .32796 .75019 L .32821 .75016 L F
.32742 .74969 m .32796 .75019 L .32757 .74978 L F
.32933 .75644 m .32445 .75852 L .32784 .75934 L .593 .769 .963 r
F
.32971 .7557 m .329 .75608 L .32933 .75644 L F
.329 .75608 m .32445 .75852 L .32933 .75644 L F
.32699 .74915 m .31812 .7497 L .32718 .74967 L .594 .768 .963 r
F
.32707 .74924 m .32718 .74967 L .32748 .74967 L F
.32699 .74915 m .32718 .74967 L .32707 .74924 L F
.32693 .74851 m .32708 .7492 L .32707 .74924 L .923 .74 .252 r
F
.32945 .75554 m .32445 .75852 L .32971 .7557 L .593 .769 .963 r
F
.32885 .75508 m .32743 .75619 L .32994 .75525 L F
.32743 .75619 m .32445 .75852 L .32755 .75667 L F
.32743 .75619 m .32755 .75667 L .32994 .75525 L F
.32693 .74851 m .32707 .74924 L .32692 .74863 L .923 .74 .252 r
F
.32733 .74472 m .32708 .7492 L .32718 .74415 L F
.32024 .74663 m .30871 .74903 L .31335 .75185 L .595 .768 .962 r
F
.3274 .74763 m .32693 .74851 L .32692 .74863 L 0 0 .29 r
F
.32705 .74914 m .32663 .7491 L .32658 .74917 L .594 .768 .963 r
F
.32733 .74472 m .32734 .74476 L .32708 .7492 L .923 .74 .252 r
F
.32781 .74526 m .32784 .7453 L .32757 .7498 L .981 .727 .472 r
F
.32858 .74574 m .32863 .74577 L .32837 .7503 L .909 .647 .529 r
F
.3297 .74615 m .32951 .75065 L .32863 .74577 L .834 .575 .548 r
F
.32951 .75065 m .32951 .75071 L .3295 .75065 L F
.32951 .75065 m .3295 .75065 L .32863 .74577 L F
.3297 .74615 m .32977 .74617 L .32951 .75071 L F
.33133 .74888 m .3292 .75054 L .33035 .75078 L .594 .768 .963 r
F
.3292 .75054 m .32914 .7506 L .32951 .75065 L F
.3292 .75054 m .32951 .75065 L .33035 .75078 L F
.32692 .74861 m .31747 .74805 L .32705 .74914 L F
.32743 .75619 m .32148 .75736 L .32445 .75852 L .593 .769 .963 r
F
.32714 .75505 m .32148 .75736 L .32743 .75619 L F
.322 .75271 m .31865 .75882 L .32496 .75387 L .594 .768 .963 r
F
.31335 .75185 m .31301 .75904 L .31923 .75414 L .595 .768 .962 r
F
.31335 .75185 m .30421 .75562 L .31301 .75904 L F
.322 .75271 m .31274 .75652 L .31865 .75882 L .594 .768 .963 r
F
.32487 .75598 m .31915 .75594 L .32148 .75736 L .593 .769 .963 r
F
.32757 .7498 m .32837 .7503 L .32811 .75475 L .909 .647 .529 r
F
.32757 .7498 m .32811 .75475 L .32736 .7543 L F
.32951 .75071 m .32935 .75516 L .32925 .75515 L .749 .499 .553 r
F
.32837 .7503 m .32817 .75477 L .32811 .75475 L .834 .575 .548 r
F
.32779 .75478 m .32574 .75459 L .32487 .75598 L .593 .769 .963 r
F
.32801 .75469 m .32768 .75468 L .32779 .75478 L F
.32768 .75468 m .32574 .75459 L .32779 .75478 L F
.3273 .75427 m .32574 .75459 L .32801 .75469 L F
.32757 .7498 m .32736 .7543 L .32731 .75427 L .909 .647 .529 r
F
.32707 .74924 m .32757 .7498 L .32731 .75427 L .981 .727 .472 r
F
.32707 .74924 m .32731 .75427 L .32684 .75377 L F
.31967 .75129 m .31274 .75652 L .322 .75271 L .594 .768 .963 r
F
.31961 .75585 m .3176 .75436 L .31915 .75594 L .593 .769 .963 r
F
.33082 .75354 m .32622 .75383 L .32574 .75459 L F
.32708 .7492 m .32684 .75377 L .32681 .75374 L .981 .727 .472 r
F
.32692 .74863 m .32707 .74924 L .32681 .75374 L .923 .74 .252 r
F
.32692 .74863 m .32681 .75374 L .32666 .75317 L F
.30871 .74903 m .30421 .75562 L .31335 .75185 L .595 .768 .962 r
F
.31967 .75129 m .30806 .75369 L .31274 .75652 L .594 .768 .963 r
F
.32366 .75398 m .31695 .75271 L .3176 .75436 L .593 .769 .963 r
F
.33082 .75354 m .32533 .75321 L .32366 .75398 L F
.32533 .75321 m .31695 .75271 L .32366 .75398 L F
.32175 .8254 m .32312 .82796 L .32418 .82569 L .659 .811 .957 r
F
.32403 .82327 m .3233 .82395 L .32418 .82569 L F
.3233 .82395 m .32175 .8254 L .32372 .82564 L F
.3233 .82395 m .32372 .82564 L .32418 .82569 L F
.32297 .82298 m .32175 .8254 L .3233 .82395 L F
.32306 .823 m .3233 .82395 L .32403 .82327 L F
.32297 .82298 m .3233 .82395 L .32306 .823 L F
.32692 .74863 m .32666 .75317 L .32665 .75313 L .923 .74 .252 r
F
.32693 .74851 m .32692 .74863 L .32692 .74863 L F
.32692 .74863 m .32666 .75317 L .32692 .74863 L F
.32551 .74683 m .32107 .74646 L .32256 .74805 L .595 .768 .962 r
F
.32107 .74646 m .32044 .74675 L .32256 .74805 L F
.31871 .74505 m .30871 .74903 L .32024 .74663 L F
.32692 .74861 m .31777 .74645 L .31747 .74805 L .594 .768 .963 r
F
.3274 .74763 m .32692 .74863 L .32738 .74789 L 0 0 .29 r
F
.32718 .74415 m .32712 .74714 L .32693 .74851 L .923 .74 .252 r
F
.33282 .67402 m .32771 .74338 L .32879 .74288 L .385 .194 .495 r
F
.33282 .67402 m .33169 .67471 L .32765 .74341 L F
.33282 .67402 m .32765 .74341 L .32771 .74338 L F
.33515 .67364 m .33398 .67372 L .32996 .74268 L .663 .424 .548 r
F
.33183 .74422 m .327 .74271 L .32354 .74274 L .595 .768 .962 r
F
.33398 .67372 m .32885 .74287 L .32996 .74268 L .57 .346 .536 r
F
.33398 .67372 m .32879 .74288 L .32885 .74287 L F
.32406 .74179 m .32163 .7392 L .31957 .74038 L .595 .768 .962 r
F
.33183 .74422 m .32872 .74269 L .327 .74271 L F
.33183 .74422 m .33076 .74633 L .33206 .74653 L F
.33183 .74422 m .32439 .73837 L .32163 .7392 L F
.33515 .67364 m .33003 .74268 L .33116 .74267 L .663 .424 .548 r
F
.33515 .67364 m .32996 .74268 L .33003 .74268 L F
.33183 .74422 m .32766 .73794 L .32439 .73837 L .595 .768 .962 r
F
.33634 .67376 m .33515 .67364 L .33116 .74267 L .733 .485 .553 r
F
.33634 .67376 m .33116 .74267 L .33122 .74268 L F
.33634 .67376 m .33122 .74268 L .33236 .74282 L F
.33183 .74422 m .33122 .73794 L .32766 .73794 L .595 .768 .962 r
F
.33116 .74267 m .32973 .74667 L .33093 .7466 L .663 .424 .548 r
F
.33003 .74268 m .32973 .74667 L .33116 .74267 L F
.327 .74271 m .32783 .74225 L .32406 .74179 L .595 .768 .962 r
F
.32872 .74269 m .32783 .74225 L .327 .74271 L F
.32783 .74225 m .32163 .7392 L .32406 .74179 L F
.33122 .74268 m .33116 .74267 L .33093 .7466 L .733 .485 .553 r
F
.33003 .74268 m .32996 .74268 L .32973 .74667 L .663 .424 .548 r
F
.32354 .74274 m .32406 .74179 L .31836 .74181 L .595 .768 .962 r
F
.327 .74271 m .32406 .74179 L .32354 .74274 L F
.32406 .74179 m .31957 .74038 L .31892 .74115 L F
.32406 .74179 m .31892 .74115 L .31836 .74181 L F
.33754 .67409 m .33634 .67376 L .33236 .74282 L .802 .546 .551 r
F
.33754 .67409 m .33236 .74282 L .33243 .74284 L F
.33168 .74263 m .33482 .73837 L .33122 .73794 L .595 .768 .962 r
F
.33183 .74422 m .33253 .74286 L .33168 .74263 L F
.33253 .74286 m .33482 .73837 L .33168 .74263 L F
.33183 .74422 m .33822 .7392 L .33482 .73837 L F
.33183 .74422 m .34348 .7418 L .34117 .74037 L F
.33183 .74422 m .34499 .7434 L .34348 .7418 L F
.33183 .74422 m .3456 .74504 L .34499 .7434 L F
.33243 .74284 m .33236 .74282 L .33214 .74671 L .802 .546 .551 r
F
.33236 .74282 m .33093 .7466 L .33214 .74671 L .733 .485 .553 r
F
.33122 .74268 m .33093 .7466 L .33236 .74282 L F
.32765 .74341 m .32693 .74851 L .3274 .74763 L 0 0 .29 r
F
.32721 .7441 m .32693 .74851 L .32765 .74341 L F
.32721 .7441 m .32718 .74415 L .32693 .74851 L F
.33133 .74888 m .32678 .74806 L .32692 .74861 L .594 .768 .963 r
F
.32678 .74806 m .31777 .74645 L .32692 .74861 L F
.33133 .74888 m .32693 .74861 L .32705 .74914 L F
.32693 .74861 m .32692 .74861 L .32692 .74863 L F
.32693 .74861 m .32692 .74863 L .32705 .74914 L F
.3274 .7496 m .32757 .7498 L .32707 .74924 L .981 .727 .472 r
F
.32708 .7492 m .3274 .7496 L .32707 .74924 L F
.33133 .74888 m .32699 .74915 L .32748 .74967 L .594 .768 .963 r
F
.32644 .74534 m .32107 .74646 L .32551 .74683 L .595 .768 .962 r
F
.32107 .74646 m .32024 .74663 L .32044 .74675 L F
.32695 .74809 m .31899 .74502 L .31777 .74645 L .594 .768 .963 r
F
.33133 .74888 m .32738 .74789 L .32722 .74814 L F
.32738 .74789 m .32709 .75244 L .32712 .75239 L 0 0 .29 r
F
.3274 .74763 m .32738 .74789 L .32738 .74789 L F
.32738 .74789 m .32709 .75244 L .32738 .74789 L F
.33133 .74888 m .3277 .74774 L .32738 .74789 L .594 .768 .963 r
F
.32722 .74814 m .32738 .74789 L .32695 .74809 L F
.32757 .74978 m .32757 .7498 L .32757 .74978 L .981 .727 .472 r
F
.32757 .74978 m .32757 .7498 L .3274 .7496 L F
.33133 .74888 m .32748 .74967 L .32821 .75016 L .594 .768 .963 r
F
.32748 .74967 m .32757 .74978 L .32821 .75016 L F
.32757 .74978 m .32837 .7503 L .32757 .7498 L .909 .647 .529 r
F
.32836 .75025 m .32837 .7503 L .32757 .74978 L F
.32855 .74696 m .3274 .74763 L .32738 .74789 L .385 .194 .495 r
F
.33133 .74888 m .32838 .74743 L .3277 .74774 L .594 .768 .963 r
F
.32855 .74696 m .32738 .74789 L .32843 .74741 L .385 .194 .495 r
F
.32855 .74696 m .32852 .74737 L .32852 .74736 L F
.32879 .74288 m .3274 .74763 L .32855 .74696 L F
.32771 .74338 m .3274 .74763 L .32879 .74288 L F
.32771 .74338 m .32765 .74341 L .3274 .74763 L F
.32838 .74743 m .32383 .74301 L .32106 .74384 L .594 .768 .963 r
F
.32973 .74667 m .32855 .74696 L .32852 .74736 L .57 .346 .536 r
F
.33133 .74888 m .32924 .74724 L .32838 .74743 L .594 .768 .963 r
F
.32924 .74724 m .32852 .74736 L .32838 .74743 L F
.31812 .7497 m .30806 .75369 L .31967 .75129 L F
.32152 .75299 m .31724 .75112 L .31695 .75271 L .593 .769 .963 r
F
.32738 .74789 m .32692 .74863 L .32665 .75313 L 0 0 .29 r
F
.32738 .74789 m .32665 .75313 L .32709 .75244 L F
.33082 .75354 m .32472 .75245 L .32152 .75299 L .593 .769 .963 r
F
.32472 .75245 m .31724 .75112 L .32152 .75299 L F
.32837 .75025 m .32951 .75071 L .32837 .7503 L .834 .575 .548 r
F
.3295 .75065 m .32951 .75071 L .32837 .75025 L F
.33133 .74888 m .32821 .75016 L .32837 .75025 L .594 .768 .963 r
F
.33133 .74888 m .32837 .75025 L .3292 .75054 L F
.32837 .75025 m .32837 .7503 L .32836 .75025 L .909 .647 .529 r
F
.32973 .74667 m .32852 .74736 L .32969 .74717 L .57 .346 .536 r
F
.32996 .74268 m .32855 .74696 L .32973 .74667 L F
.32885 .74287 m .32855 .74696 L .32996 .74268 L F
.32885 .74287 m .32879 .74288 L .32855 .74696 L F
.3288 .7469 m .32712 .74258 L .32383 .74301 L .594 .768 .963 r
F
.33133 .74888 m .33018 .74716 L .32924 .74724 L F
.33093 .7466 m .3297 .74717 L .33089 .74716 L .663 .424 .548 r
F
.33018 .74716 m .33014 .74709 L .3297 .74717 L .594 .768 .963 r
F
.33018 .74716 m .3297 .74717 L .32924 .74724 L F
.33093 .7466 m .32973 .74667 L .3297 .74717 L .663 .424 .548 r
F
.33082 .75354 m .3273 .75427 L .32801 .75469 L .593 .769 .963 r
F
.33082 .75354 m .32714 .75505 L .32743 .75619 L F
.32994 .75525 m .32945 .75554 L .32971 .7557 L F
.33082 .75354 m .32885 .75508 L .32994 .75525 L F
.32675 .82567 m .32697 .82792 L .33077 .82742 L .659 .811 .957 r
F
.32418 .82569 m .32697 .82792 L .32675 .82567 L F
.32418 .82569 m .32312 .82796 L .32697 .82792 L F
.32675 .82567 m .33077 .82742 L .32928 .82533 L F
.32686 .82363 m .32675 .82567 L .32928 .82533 L F
.32653 .8234 m .32656 .82375 L .32686 .82363 L F
.32656 .82375 m .32675 .82567 L .32686 .82363 L F
.32928 .82533 m .33077 .82742 L .33426 .8265 L F
.33091 .8249 m .33426 .8265 L .33162 .82471 L F
.32928 .82533 m .33086 .8257 L .33091 .8249 L F
.33086 .8257 m .33426 .8265 L .33091 .8249 L F
.33349 .75532 m .33916 .75908 L .33438 .75528 L .593 .769 .963 r
F
.33127 .75093 m .33111 .75542 L .33101 .75542 L .644 .409 .547 r
F
.34006 .75661 m .35379 .76147 L .34653 .75577 L .595 .768 .962 r
F
.34653 .75577 m .35379 .76147 L .36202 .75907 L F
.33876 .75469 m .34612 .76046 L .35165 .75884 L .594 .768 .963 r
F
.33549 .75511 m .34612 .76046 L .33876 .75469 L F
.33619 .75521 m .34103 .75853 L .34311 .75737 L .593 .769 .963 r
F
.33082 .75354 m .33735 .75673 L .33619 .75521 L F
.33735 .75673 m .34103 .75853 L .33619 .75521 L F
.3348 .75017 m .33517 .74971 L .33492 .75421 L 0 0 .355 r
F
.3352 .74911 m .33491 .75356 L .33521 .74911 L .992 .745 .442 r
F
.33094 .82445 m .33091 .8249 L .33162 .82471 L .659 .811 .957 r
F
.33406 .75058 m .33477 .7502 L .33452 .75469 L .335 .155 .483 r
F
.33477 .7502 m .33454 .75466 L .33452 .75469 L 0 0 .355 r
F
.33478 .75019 m .33454 .75466 L .33477 .7502 L F
.33876 .75469 m .35165 .75884 L .34152 .75388 L .594 .768 .963 r
F
.33555 .75438 m .34311 .75737 L .34436 .75596 L .593 .769 .963 r
F
.33082 .75354 m .33619 .75521 L .33555 .75438 L F
.33619 .75521 m .34311 .75737 L .33555 .75438 L F
.33133 .74888 m .33493 .75 L .33517 .74971 L .594 .768 .963 r
F
.33133 .74888 m .33517 .74971 L .33518 .74957 L F
.33479 .7499 m .33478 .75019 L .33477 .7502 L 0 0 .355 r
F
.33133 .74888 m .33456 .75046 L .33493 .75 L .594 .768 .963 r
F
.33485 .74382 m .33337 .74703 L .33463 .74773 L .892 .63 .535 r
F
.33488 .74387 m .33485 .74382 L .33463 .74773 L .992 .745 .442 r
F
.33546 .74466 m .33546 .74463 L .33524 .74863 L 0 0 0 r
F
.33546 .74466 m .33524 .74863 L .33543 .74523 L F
.33546 .74463 m .33463 .74773 L .33524 .74863 L .992 .745 .442 r
F
.33488 .74387 m .33463 .74773 L .33546 .74463 L F
.33463 .74773 m .33337 .74703 L .33333 .74764 L .892 .63 .535 r
F
.33133 .74888 m .33445 .74823 L .33377 .74787 L .594 .768 .963 r
F
.33312 .75533 m .33237 .75585 L .33321 .7554 L .593 .769 .963 r
F
.33205 .75538 m .33237 .75585 L .33312 .75533 L F
.33082 .75354 m .33349 .75532 L .33438 .75528 L F
.33321 .7554 m .33345 .75599 L .33365 .75575 L F
.3328 .75533 m .33381 .75508 L .32998 .82243 L .516 .302 .527 r
F
.3328 .75533 m .32998 .82243 L .32992 .82245 L F
.33273 .75535 m .32991 .82245 L .32887 .82286 L F
.32921 .82399 m .32928 .82533 L .33091 .8249 L .659 .811 .957 r
F
.32843 .82348 m .33091 .8249 L .33094 .82445 L F
.32785 .82325 m .32836 .82353 L .32843 .82348 L F
.32836 .82353 m .33091 .8249 L .32843 .82348 L F
.34653 .75577 m .36202 .75907 L .35203 .75416 L .595 .768 .962 r
F
.34152 .75388 m .35165 .75884 L .35582 .75654 L .594 .768 .963 r
F
.34152 .75388 m .35582 .75654 L .3436 .75272 L F
.33635 .75387 m .34436 .75596 L .34469 .75437 L .593 .769 .963 r
F
.33492 .75417 m .33492 .75417 L .33517 .74971 L 0 0 0 r
F
.33517 .74971 m .33492 .75417 L .33492 .75421 L F
.33517 .74971 m .33495 .75361 L .33492 .75417 L F
.33082 .75354 m .33822 .75486 L .33635 .75387 L .593 .769 .963 r
F
.33822 .75486 m .34436 .75596 L .33635 .75387 L F
.33133 .74888 m .33312 .75082 L .33364 .75069 L .594 .768 .963 r
F
.33463 .74773 m .33333 .74764 L .33458 .74831 L .892 .63 .535 r
F
.33337 .74703 m .33332 .74764 L .33333 .74764 L .802 .546 .551 r
F
.33133 .74888 m .33393 .74781 L .33301 .74755 L .594 .768 .963 r
F
.3278 .82323 m .32932 .82383 L .32897 .82292 L .659 .811 .957 r
F
.32836 .82353 m .32885 .82448 L .32921 .82399 L F
.32785 .82325 m .32814 .82368 L .32836 .82353 L F
.32814 .82368 m .32928 .82533 L .32836 .82353 L F
.3278 .82323 m .32782 .82326 L .32785 .82325 L F
.32782 .82326 m .32928 .82533 L .32785 .82325 L F
.33101 .75542 m .33079 .75569 L .33104 .75578 L .593 .769 .963 r
F
.32653 .8234 m .32928 .82533 L .3278 .82323 L .659 .811 .957 r
F
.32711 .8308 m .32697 .82796 L .33079 .82746 L .67 .442 .566 r
F
.32324 .83084 m .32697 .82796 L .32711 .8308 L .73 .489 .562 r
F
.32324 .83084 m .3231 .82799 L .32697 .82796 L F
.32667 .82626 m .32689 .82853 L .32944 .8282 L .658 .812 .957 r
F
.33093 .8303 m .33079 .82746 L .3343 .82653 L .6 .388 .565 r
F
.32711 .8308 m .33079 .82746 L .33093 .8303 L .67 .442 .566 r
F
.32795 .82609 m .32944 .8282 L .33179 .82758 L .658 .812 .957 r
F
.32667 .82626 m .32944 .8282 L .32795 .82609 L F
.32896 .82582 m .33179 .82758 L .32912 .82578 L F
.32795 .82609 m .32834 .82624 L .32896 .82582 L F
.32834 .82624 m .33179 .82758 L .32896 .82582 L F
.32912 .82578 m .33179 .82758 L .33378 .82671 L F
.3301 .82535 m .33378 .82671 L .33012 .82535 L F
.32912 .82578 m .32971 .8259 L .3301 .82535 L F
.32971 .8259 m .33378 .82671 L .3301 .82535 L F
.33162 .82471 m .33426 .8265 L .33723 .82521 L .659 .811 .957 r
F
.33012 .82535 m .33378 .82671 L .33527 .82566 L .658 .812 .957 r
F
.33012 .82535 m .33089 .82539 L .33086 .82482 L F
.33089 .82539 m .33527 .82566 L .33092 .82483 L F
.33089 .82539 m .33092 .82483 L .33086 .82482 L F
.32932 .82383 m .33094 .82445 L .32965 .82338 L .659 .811 .957 r
F
.33094 .82445 m .33162 .82471 L .33095 .82426 L F
.33094 .82445 m .33095 .82426 L .32965 .82338 L F
.33492 .75417 m .33116 .82076 L .33492 .75421 L 0 0 0 r
F
.33133 .74888 m .33266 .75087 L .33312 .75082 L .594 .768 .963 r
F
.33214 .74671 m .33093 .7466 L .3309 .74716 L .733 .485 .553 r
F
.33359 .74315 m .33214 .74671 L .33337 .74703 L .802 .546 .551 r
F
.33243 .74284 m .33214 .74671 L .33359 .74315 L F
.33366 .74319 m .33359 .74315 L .33337 .74703 L .892 .63 .535 r
F
.33366 .74319 m .33337 .74703 L .33485 .74382 L F
.33115 .74704 m .33433 .74301 L .33071 .74258 L .594 .768 .963 r
F
.33133 .74888 m .33213 .74731 L .33211 .74731 L F
.3352 .74911 m .33434 .75281 L .33491 .75356 L .992 .745 .442 r
F
.33524 .74863 m .33515 .74903 L .3352 .74911 L F
.34403 .74805 m .35617 .75186 L .35868 .74903 L .595 .768 .962 r
F
.34403 .74805 m .35868 .74903 L .34527 .74663 L F
.33664 .74855 m .34518 .7497 L .34457 .74805 L .594 .768 .963 r
F
.33524 .74863 m .33459 .74831 L .33515 .74903 L .992 .745 .442 r
F
.33524 .74863 m .3352 .74911 L .33521 .74911 L F
.33133 .74888 m .33621 .74917 L .33521 .74864 L .594 .768 .963 r
F
.33133 .74888 m .33486 .74866 L .33452 .74822 L F
.33521 .75327 m .34027 .75411 L .33684 .75317 L .593 .769 .963 r
F
.33491 .75356 m .33492 .75356 L .33521 .74911 L .992 .745 .442 r
F
.33521 .74911 m .33492 .75356 L .33495 .75361 L F
.33082 .75354 m .33635 .75387 L .33521 .75327 L .593 .769 .963 r
F
.33635 .75387 m .34027 .75411 L .33521 .75327 L F
.32985 .8231 m .33095 .82426 L .331 .82333 L .659 .811 .957 r
F
.32897 .82292 m .32965 .82338 L .32985 .8231 L F
.32965 .82338 m .33095 .82426 L .32985 .8231 L F
.33454 .75466 m .3311 .82139 L .33452 .75469 L 0 0 .355 r
F
.32996 .82249 m .3336 .82385 L .33368 .82379 L .659 .811 .957 r
F
.33275 .82266 m .33368 .82379 L .33508 .8228 L F
.32996 .82249 m .33368 .82379 L .33275 .82266 L F
.3311 .82139 m .3311 .8214 L .33452 .75469 L 0 0 .355 r
F
.33454 .75466 m .33492 .75421 L .33112 .82136 L F
.33454 .75466 m .33112 .82136 L .3311 .82139 L F
.33381 .75508 m .33067 .82196 L .32998 .82243 L .335 .155 .483 r
F
.33452 .75469 m .3311 .8214 L .33071 .82193 L 0 0 .355 r
F
.33385 .75505 m .33452 .75469 L .33071 .82193 L .335 .155 .483 r
F
.33385 .75505 m .33071 .82193 L .33067 .82195 L F
.33385 .75505 m .33067 .82195 L .33381 .75508 L F
.32975 .82258 m .3336 .82385 L .32996 .82249 L .659 .811 .957 r
F
.32919 .82297 m .3336 .82385 L .32975 .82258 L F
.32996 .82249 m .33275 .82266 L .3307 .82197 L F
.33275 .82266 m .33508 .8228 L .33245 .8223 L F
.33275 .82266 m .33245 .8223 L .3307 .82197 L F
.33067 .82195 m .33067 .82196 L .33381 .75508 L .335 .155 .483 r
F
.33491 .75356 m .33056 .82 L .33492 .75356 L .992 .745 .442 r
F
.33067 .82196 m .33054 .82475 L .32998 .82243 L .335 .155 .483 r
F
.33053 .82475 m .33012 .82535 L .33086 .82482 L .658 .812 .957 r
F
.33054 .82475 m .33047 .82606 L .33032 .8249 L .335 .155 .483 r
F
.33054 .82475 m .33032 .8249 L .32998 .82243 L F
.32998 .82243 m .33032 .8249 L .32982 .82524 L F
.32694 .82597 m .32864 .82689 L .32687 .82706 L .644 .409 .547 r
F
.32524 .82341 m .32675 .82567 L .32653 .8234 L .659 .811 .957 r
F
.32524 .82341 m .32418 .82569 L .32675 .82567 L F
.32537 .82627 m .32689 .82853 L .32667 .82626 L .658 .812 .957 r
F
.32537 .82627 m .32431 .82856 L .32689 .82853 L F
.32415 .82613 m .32431 .82856 L .32537 .82627 L F
.32925 .75515 m .327 .82315 L .32529 .8231 L .749 .499 .553 r
F
.32653 .82339 m .32524 .82341 L .32653 .8234 L .659 .811 .957 r
F
.32631 .82113 m .32538 .82312 L .32653 .82339 L F
.32538 .82312 m .32524 .82341 L .32653 .82339 L F
.32817 .75477 m .32925 .75515 L .32529 .8231 L .834 .575 .548 r
F
.3255 .826 m .32415 .82613 L .32537 .82627 L .658 .812 .957 r
F
.32524 .82309 m .32529 .8231 L .32513 .82591 L .834 .575 .548 r
F
.32524 .82309 m .32513 .82591 L .32511 .82591 L F
.32529 .8231 m .32643 .82595 L .32513 .82591 L .749 .499 .553 r
F
.32664 .82596 m .32537 .82627 L .32667 .82626 L .658 .812 .957 r
F
.32651 .82326 m .32653 .8234 L .32732 .82316 L .659 .811 .957 r
F
.3271 .82316 m .32732 .82316 L .32767 .82306 L F
.32651 .82326 m .32732 .82316 L .3271 .82316 L F
.32935 .75516 m .32701 .82315 L .32925 .75515 L .749 .499 .553 r
F
.32788 .826 m .32667 .82626 L .32795 .82609 L .658 .812 .957 r
F
.32701 .82315 m .32691 .82597 L .327 .82315 L .749 .499 .553 r
F
.32691 .82597 m .32691 .82597 L .327 .82315 L F
.32817 .75477 m .32529 .8231 L .32524 .82309 L .834 .575 .548 r
F
.32526 .82338 m .32403 .82327 L .32524 .82341 L .659 .811 .957 r
F
.32437 .82295 m .32403 .82327 L .32526 .82338 L F
.32453 .82577 m .32415 .82613 L .3255 .826 L .658 .812 .957 r
F
.32403 .82327 m .32418 .82569 L .32524 .82341 L .659 .811 .957 r
F
.31959 .83041 m .3231 .82799 L .32324 .83084 L .787 .534 .553 r
F
.31959 .83041 m .31945 .82756 L .3231 .82799 L F
.32175 .8254 m .31949 .82753 L .32312 .82796 L .659 .811 .957 r
F
.32415 .82613 m .32187 .82827 L .32431 .82856 L .658 .812 .957 r
F
.32309 .82584 m .32187 .82827 L .3241 .82618 L F
.324 .82608 m .3241 .82618 L .32415 .82613 L F
.32309 .82584 m .3241 .82618 L .324 .82608 L F
.32297 .82298 m .32109 .82402 L .32175 .8254 L .659 .811 .957 r
F
.32109 .82402 m .31964 .82483 L .3205 .82506 L F
.32109 .82402 m .3205 .82506 L .32175 .8254 L F
.32213 .82256 m .32168 .82297 L .32297 .82298 L F
.32168 .82297 m .31964 .82483 L .32109 .82402 L F
.32168 .82297 m .32109 .82402 L .32297 .82298 L F
.32681 .75374 m .32328 .82241 L .32279 .82193 L .981 .727 .472 r
F
.32811 .75475 m .32523 .82309 L .32412 .82282 L .834 .575 .548 r
F
.32731 .75427 m .32408 .82281 L .3233 .82243 L .909 .647 .529 r
F
.32666 .75317 m .32681 .75374 L .32279 .82193 L .923 .74 .252 r
F
.32304 .82294 m .32213 .82256 L .32297 .82298 L .659 .811 .957 r
F
.32296 .82262 m .32213 .82256 L .32304 .82294 L F
.3231 .82223 m .32213 .82256 L .32354 .82266 L F
.32409 .82321 m .32297 .82298 L .32403 .82327 L F
.32354 .82266 m .32297 .82298 L .32409 .82321 L F
.32328 .82241 m .32313 .82524 L .32328 .82241 L .981 .727 .472 r
F
.32351 .82561 m .32275 .82525 L .32309 .82584 L .658 .812 .957 r
F
.32313 .82524 m .32309 .82596 L .32313 .82524 L .981 .727 .472 r
F
.32313 .82524 m .32313 .82524 L .32328 .82241 L F
.32666 .75317 m .32279 .82193 L .32278 .8219 L .923 .74 .252 r
F
.32684 .75377 m .32328 .82241 L .32681 .75374 L .981 .727 .472 r
F
.32328 .82241 m .32328 .82241 L .32681 .75374 L F
.32666 .75317 m .32278 .8219 L .32665 .75313 L .923 .74 .252 r
F
.32278 .8219 m .32278 .8219 L .32665 .75313 L F
.32665 .75313 m .32278 .8219 L .32263 .82131 L F
.32684 .75377 m .32731 .75427 L .3233 .82243 L .981 .727 .472 r
F
.32225 .82192 m .32159 .82205 L .32298 .82227 L .659 .811 .957 r
F
.32278 .8219 m .32262 .82474 L .32278 .8219 L .923 .74 .252 r
F
.3226 .82473 m .3217 .8249 L .32271 .82509 L .658 .812 .957 r
F
.32262 .82474 m .32271 .82509 L .32304 .82515 L F
.3226 .82473 m .32271 .82509 L .32262 .82474 L F
.3231 .82223 m .32225 .82192 L .32298 .82227 L .659 .811 .957 r
F
.32269 .82183 m .32225 .82192 L .3231 .82223 L F
.32298 .82227 m .32216 .82214 L .32213 .82256 L F
.32684 .75377 m .3233 .82243 L .32328 .82241 L .981 .727 .472 r
F
.32736 .7543 m .32408 .82281 L .32731 .75427 L .909 .647 .529 r
F
.32408 .82281 m .32408 .82281 L .32731 .75427 L F
.32736 .7543 m .32811 .75475 L .32412 .82282 L F
.32408 .82281 m .32412 .82282 L .32395 .82564 L F
.32408 .82281 m .32395 .82564 L .32395 .82563 L F
.32328 .82241 m .3233 .82243 L .32313 .82524 L .981 .727 .472 r
F
.32328 .82241 m .32313 .82524 L .32313 .82524 L F
.32408 .82281 m .32395 .82563 L .32408 .82281 L .909 .647 .529 r
F
.32443 .82587 m .32309 .82584 L .32415 .82613 L .658 .812 .957 r
F
.32395 .82563 m .32391 .82645 L .32394 .82563 L .909 .647 .529 r
F
.32395 .82563 m .32394 .82563 L .32408 .82281 L F
.32395 .82564 m .32507 .82684 L .32391 .82645 L .834 .575 .548 r
F
.32736 .7543 m .32412 .82282 L .32408 .82281 L .909 .647 .529 r
F
.32817 .75477 m .32524 .82309 L .32811 .75475 L .834 .575 .548 r
F
.32524 .82309 m .32523 .82309 L .32811 .75475 L F
.32631 .82113 m .32354 .82266 L .32357 .8227 L .659 .811 .957 r
F
.32442 .8229 m .32357 .8227 L .32409 .82321 L F
.32631 .82113 m .32357 .8227 L .32442 .8229 L F
.32524 .82309 m .32507 .82684 L .32523 .82309 L .834 .575 .548 r
F
.32412 .82282 m .32484 .82584 L .32395 .82564 L F
.32453 .82577 m .32395 .82564 L .32443 .82587 L .658 .812 .957 r
F
.32484 .82584 m .32507 .82684 L .32395 .82564 L .834 .575 .548 r
F
.32538 .82312 m .32437 .82295 L .32526 .82338 L .659 .811 .957 r
F
.32442 .8229 m .32437 .82295 L .32538 .82312 L F
.32523 .82309 m .32507 .82684 L .32412 .82282 L .834 .575 .548 r
F
.32368 .82551 m .32309 .82584 L .32443 .82587 L .658 .812 .957 r
F
.32368 .82551 m .32313 .82524 L .32351 .82561 L F
.3233 .82243 m .32391 .82645 L .32309 .82596 L .909 .647 .529 r
F
.32408 .82281 m .32391 .82645 L .3233 .82243 L F
.327 .82315 m .32691 .82597 L .32529 .8231 L .749 .499 .553 r
F
.32691 .82597 m .32643 .82595 L .32529 .8231 L F
.32645 .82398 m .32368 .82551 L .32395 .82564 L .658 .812 .957 r
F
.32645 .82398 m .32395 .82564 L .32453 .82577 L F
.32279 .82193 m .32313 .82524 L .32262 .82474 L .981 .727 .472 r
F
.32354 .82266 m .32296 .82262 L .32304 .82294 L .659 .811 .957 r
F
.32328 .82241 m .32313 .82524 L .32279 .82193 L .981 .727 .472 r
F
.32645 .82398 m .32304 .82515 L .32313 .82524 L .658 .812 .957 r
F
.32645 .82398 m .32313 .82524 L .32368 .82551 L F
.32395 .82563 m .32395 .82564 L .32391 .82645 L .909 .647 .529 r
F
.32631 .82113 m .32144 .82147 L .32146 .82154 L .659 .811 .957 r
F
.32225 .82192 m .32146 .82154 L .32159 .82205 L F
.32631 .82113 m .32146 .82154 L .32225 .82192 L F
.32144 .82147 m .32136 .82147 L .32137 .82151 L F
.32144 .82147 m .32137 .82151 L .32159 .82205 L F
.32631 .82113 m .32269 .82183 L .3231 .82223 L F
.32631 .82113 m .3231 .82223 L .32354 .82266 L F
.32074 .75174 m .31847 .74969 L .31724 .75112 L .593 .769 .963 r
F
.33082 .75354 m .32642 .75217 L .32472 .75245 L F
.32709 .75244 m .32665 .75313 L .32263 .82131 L 0 0 .29 r
F
.32258 .82139 m .32147 .82087 L .32136 .82147 L .659 .811 .957 r
F
.32631 .82113 m .32284 .82094 L .32258 .82139 L F
.32709 .75244 m .32263 .82131 L .32265 .82127 L 0 0 .29 r
F
.32709 .75244 m .32265 .82127 L .32712 .75239 L F
.32265 .82127 m .32265 .82127 L .32712 .75239 L F
.32712 .75239 m .32265 .82127 L .32311 .82047 L F
.32284 .82094 m .32147 .82087 L .32258 .82139 L .659 .811 .957 r
F
.32631 .82113 m .32442 .8229 L .32538 .82312 L F
.32631 .82113 m .32305 .8205 L .32236 .82092 L F
.32386 .81108 m .32338 .8203 L .32402 .81992 L .385 .194 .495 r
F
.32386 .81108 m .32316 .82043 L .32338 .8203 L F
.32658 .74917 m .31747 .74805 L .31812 .7497 L .594 .768 .963 r
F
.32642 .75217 m .32054 .74852 L .31847 .74969 L .593 .769 .963 r
F
.32852 .74737 m .32712 .75239 L .32819 .7519 L .385 .194 .495 r
F
.32843 .74741 m .32712 .75239 L .32852 .74737 L F
.32843 .74741 m .32738 .74789 L .32712 .75239 L F
.33082 .75354 m .32761 .75197 L .32642 .75217 L .593 .769 .963 r
F
.32761 .75197 m .32054 .74852 L .32642 .75217 L F
.32969 .74717 m .32936 .75168 L .3297 .74717 L .57 .346 .536 r
F
.32663 .7491 m .31747 .74805 L .32658 .74917 L .594 .768 .963 r
F
.32761 .75197 m .32331 .74769 L .32054 .74852 L .593 .769 .963 r
F
.33082 .75354 m .3286 .75181 L .32761 .75197 L F
.32969 .74717 m .32852 .74736 L .32826 .75186 L .57 .346 .536 r
F
.32969 .74717 m .32826 .75186 L .32936 .75168 L F
.32852 .74736 m .32819 .7519 L .32826 .75186 L .385 .194 .495 r
F
.32852 .74737 m .32819 .7519 L .32852 .74736 L F
.3286 .75181 m .32331 .74769 L .32761 .75197 L .593 .769 .963 r
F
.32937 .75168 m .32937 .75168 L .3297 .74717 L .57 .346 .536 r
F
.32936 .75168 m .32937 .75168 L .3297 .74717 L F
.3297 .74717 m .32937 .75168 L .32944 .75167 L F
.32951 .75065 m .33127 .75093 L .32951 .75071 L .749 .499 .553 r
F
.33127 .75093 m .33127 .75093 L .32951 .75065 L F
.33214 .74671 m .3309 .74716 L .3321 .74731 L .733 .485 .553 r
F
.33018 .74716 m .33071 .74258 L .32712 .74258 L .594 .768 .963 r
F
.33133 .74888 m .33116 .74715 L .33018 .74716 L F
.33093 .7466 m .33089 .74716 L .3309 .74716 L .663 .424 .548 r
F
.33116 .74715 m .33071 .74258 L .33018 .74716 L .594 .768 .963 r
F
.3277 .74774 m .32106 .74384 L .31899 .74502 L F
.3277 .74774 m .31899 .74502 L .32695 .74809 L F
.32843 .75168 m .32661 .74726 L .32331 .74769 L .593 .769 .963 r
F
.33082 .75354 m .32956 .75167 L .32843 .75168 L F
.33089 .74716 m .3297 .74717 L .32944 .75167 L .663 .424 .548 r
F
.33089 .74716 m .32944 .75167 L .33055 .75166 L F
.32956 .75167 m .32661 .74726 L .32843 .75168 L .593 .769 .963 r
F
.32631 .82113 m .32366 .82014 L .32305 .8205 L .659 .811 .957 r
F
.32819 .7519 m .32316 .82044 L .32826 .75186 L .385 .194 .495 r
F
.32263 .82131 m .32259 .82463 L .32246 .82412 L .923 .74 .252 r
F
.3225 .82425 m .32216 .82375 L .32147 .82433 L .658 .812 .957 r
F
.32262 .82474 m .32262 .82474 L .32278 .8219 L .923 .74 .252 r
F
.32265 .82127 m .32263 .82131 L .32246 .82412 L 0 0 .29 r
F
.32206 .82483 m .32147 .82433 L .3217 .8249 L .658 .812 .957 r
F
.32278 .8219 m .32279 .82193 L .32262 .82474 L .923 .74 .252 r
F
.32278 .8219 m .32262 .82474 L .32262 .82474 L F
.32278 .8219 m .32262 .82474 L .32263 .82131 L F
.32262 .82474 m .32258 .82539 L .32259 .82463 L F
.32262 .82474 m .32259 .82463 L .32263 .82131 L F
.32262 .82472 m .32239 .82426 L .32206 .82483 L .658 .812 .957 r
F
.32645 .82398 m .3225 .82425 L .32262 .82472 L F
.3225 .82425 m .32239 .82426 L .32262 .82472 L F
.32239 .82426 m .32147 .82433 L .32206 .82483 L F
.32246 .82412 m .32258 .82539 L .32243 .82471 L .923 .74 .252 r
F
.32247 .82412 m .32246 .82412 L .32243 .82471 L 0 0 .29 r
F
.32265 .82127 m .32246 .82412 L .32247 .82412 L F
.32645 .82398 m .32266 .82378 L .3225 .82425 L .658 .812 .957 r
F
.32265 .82127 m .32247 .82412 L .32311 .82047 L 0 0 .29 r
F
.32259 .82463 m .32258 .82539 L .32246 .82412 L .923 .74 .252 r
F
.32247 .82412 m .32243 .82471 L .32255 .82398 L 0 0 .29 r
F
.32247 .82412 m .32255 .82398 L .32311 .82047 L F
.32265 .82127 m .32247 .82412 L .32265 .82127 L F
.32247 .82412 m .32243 .82471 L .32247 .82412 L F
.32247 .82412 m .32247 .82412 L .32265 .82127 L F
.32293 .82331 m .32276 .82261 L .32202 .82313 L .658 .812 .957 r
F
.32631 .82113 m .32428 .81976 L .32366 .82014 L .659 .811 .957 r
F
.32428 .81976 m .32402 .81992 L .32407 .82261 L .385 .194 .495 r
F
.32428 .81976 m .32407 .82261 L .32412 .82258 L F
.32316 .82044 m .32295 .82328 L .32316 .82043 L F
.32295 .82328 m .32295 .82328 L .32316 .82043 L F
.32645 .82398 m .32357 .82291 L .32293 .82331 L .658 .812 .957 r
F
.32645 .82398 m .32293 .82331 L .32266 .82378 L F
.32407 .82261 m .32321 .82369 L .32408 .82321 L .385 .194 .495 r
F
.32402 .81992 m .32335 .82304 L .32407 .82261 L F
.32335 .82304 m .32321 .82369 L .32407 .82261 L F
.32645 .82398 m .32429 .82253 L .32412 .82258 L .658 .812 .957 r
F
.32357 .82291 m .32412 .82258 L .32333 .82281 L F
.32645 .82398 m .32412 .82258 L .32357 .82291 L F
.32338 .8203 m .32321 .82369 L .32402 .81992 L .385 .194 .495 r
F
.32357 .82291 m .32294 .82328 L .32293 .82331 L .658 .812 .957 r
F
.32338 .8203 m .32291 .82386 L .32321 .82369 L .385 .194 .495 r
F
.32316 .82043 m .32291 .82386 L .32338 .8203 L F
.32311 .82047 m .32274 .82278 L .32291 .82386 L 0 0 .29 r
F
.32819 .7519 m .32712 .75239 L .32294 .82328 L .385 .194 .495 r
F
.32295 .82328 m .32294 .82328 L .32291 .82386 L F
.32819 .7519 m .32294 .82328 L .32295 .82328 L F
.32323 .82278 m .32276 .82261 L .32292 .82329 L .658 .812 .957 r
F
.32294 .82328 m .32292 .82329 L .32293 .82331 L F
.32323 .82278 m .32292 .82329 L .32294 .82328 L F
.32333 .82281 m .32376 .82217 L .32276 .82261 L F
.32826 .75186 m .32386 .81108 L .32402 .81992 L .385 .194 .495 r
F
.32826 .75186 m .32402 .81992 L .32428 .81976 L F
.32434 .81974 m .32434 .81974 L .32937 .75168 L .57 .346 .536 r
F
.32434 .81974 m .32937 .75168 L .32937 .75168 L F
.32936 .75168 m .32434 .81974 L .32937 .75168 L F
.32937 .75168 m .32434 .81974 L .32944 .75167 L F
.32434 .81974 m .32434 .81974 L .32944 .75167 L F
.32944 .75167 m .32434 .81974 L .32549 .8194 L F
.32936 .75168 m .32826 .75186 L .32428 .81976 L F
.32434 .81974 m .32428 .81976 L .32412 .82258 L F
.32434 .81974 m .32412 .82258 L .32413 .82258 L F
.32434 .81974 m .32413 .82258 L .32434 .81974 L F
.32413 .82258 m .32408 .82321 L .32413 .82258 L F
.32413 .82258 m .32413 .82258 L .32434 .81974 L F
.32434 .81974 m .32413 .82258 L .32434 .81974 L F
.32413 .82258 m .32413 .82258 L .32434 .81974 L F
.32645 .82398 m .32522 .82225 L .32429 .82253 L .658 .812 .957 r
F
.32631 .82113 m .32515 .8195 L .32428 .81976 L .659 .811 .957 r
F
.32701 .82315 m .327 .82315 L .32925 .75515 L .749 .499 .553 r
F
.33082 .75354 m .32994 .75525 L .33101 .75542 L .593 .769 .963 r
F
.32664 .82596 m .32667 .82626 L .32788 .826 L .658 .812 .957 r
F
.32776 .82318 m .32653 .8234 L .3278 .82323 L .659 .811 .957 r
F
.32732 .82316 m .32653 .8234 L .32776 .82318 L F
.32935 .75516 m .33101 .75542 L .3271 .82316 L .749 .499 .553 r
F
.32701 .82315 m .3271 .82316 L .32694 .82597 L F
.32701 .82315 m .32694 .82597 L .32691 .82597 L F
.3271 .82316 m .32868 .82567 L .32694 .82597 L .644 .409 .547 r
F
.32767 .82306 m .32732 .82316 L .32776 .82318 L .659 .811 .957 r
F
.32877 .82287 m .32868 .82567 L .3271 .82316 L .644 .409 .547 r
F
.32871 .82567 m .32974 .82653 L .32864 .82689 L .516 .302 .527 r
F
.32885 .82448 m .32928 .82533 L .32921 .82399 L .659 .811 .957 r
F
.32887 .82286 m .32947 .82538 L .32871 .82567 L .516 .302 .527 r
F
.32947 .82538 m .32974 .82653 L .32871 .82567 L F
.33101 .75542 m .33144 .75976 L .33205 .75538 L .593 .769 .963 r
F
.32887 .82286 m .3278 .82323 L .32897 .82292 L .659 .811 .957 r
F
.33111 .75542 m .32878 .82287 L .33101 .75542 L .644 .409 .547 r
F
.32878 .82287 m .32877 .82287 L .33101 .75542 L F
.32767 .82306 m .3278 .82323 L .32887 .82286 L .659 .811 .957 r
F
.32868 .82567 m .32868 .82567 L .32877 .82287 L .644 .409 .547 r
F
.32877 .82287 m .32877 .82287 L .33101 .75542 L F
.32868 .82567 m .32877 .82287 L .32877 .82287 L F
.32935 .75516 m .3271 .82316 L .32701 .82315 L .749 .499 .553 r
F
.33101 .75542 m .32877 .82287 L .3271 .82316 L .644 .409 .547 r
F
.32887 .82286 m .32897 .82292 L .32928 .82279 L .659 .811 .957 r
F
.32891 .82564 m .32788 .826 L .32912 .82578 L .658 .812 .957 r
F
.32872 .82567 m .32788 .826 L .32891 .82564 L F
.33213 .7555 m .33205 .75603 L .33237 .75585 L .593 .769 .963 r
F
.33205 .75603 m .33144 .75976 L .33237 .75585 L F
.33205 .75538 m .33203 .75553 L .33213 .7555 L F
.33203 .75553 m .33144 .75976 L .33213 .7555 L F
.33112 .75541 m .33273 .75535 L .32871 .82567 L .644 .409 .547 r
F
.32868 .82567 m .32871 .82567 L .32864 .82689 L F
.33112 .75541 m .32871 .82567 L .32868 .82567 L F
.32878 .82287 m .32868 .82567 L .32877 .82287 L F
.32776 .82583 m .32788 .82599 L .32871 .82567 L .658 .812 .957 r
F
.33111 .75542 m .33112 .75541 L .32868 .82567 L .644 .409 .547 r
F
.32868 .82567 m .32868 .82567 L .32864 .82689 L F
.33111 .75542 m .32868 .82567 L .32868 .82567 L F
.32788 .82599 m .32788 .826 L .32872 .82567 L .658 .812 .957 r
F
.32871 .82567 m .32872 .82567 L .32887 .82561 L F
.32788 .82599 m .32872 .82567 L .32871 .82567 L F
.32645 .82398 m .32776 .82583 L .32887 .82561 L F
.32776 .82583 m .32871 .82567 L .32887 .82561 L F
.3328 .75533 m .32992 .82245 L .33273 .75535 L .516 .302 .527 r
F
.32992 .82245 m .32991 .82245 L .33273 .75535 L F
.32631 .82113 m .32996 .82249 L .3307 .82197 L .659 .811 .957 r
F
.32982 .82524 m .32912 .82578 L .33012 .82535 L .658 .812 .957 r
F
.32988 .82246 m .32887 .82286 L .32996 .82249 L .659 .811 .957 r
F
.32887 .82286 m .32928 .82279 L .32996 .82249 L F
.32897 .82292 m .32919 .82297 L .32975 .82258 L F
.32932 .82383 m .32965 .82338 L .32897 .82292 L F
.32991 .82245 m .3298 .82525 L .32887 .82286 L .516 .302 .527 r
F
.3298 .82525 m .32974 .82653 L .32947 .82538 L F
.3298 .82525 m .32947 .82538 L .32887 .82286 L F
.32992 .82245 m .32998 .82243 L .32974 .82653 L F
.32645 .82398 m .32887 .82561 L .32982 .82524 L .658 .812 .957 r
F
.32887 .82561 m .32912 .82578 L .32982 .82524 L F
.32992 .82245 m .3298 .82525 L .32991 .82245 L .516 .302 .527 r
F
.3298 .82525 m .32974 .82653 L .3298 .82525 L F
.3298 .82525 m .3298 .82525 L .32991 .82245 L F
.32631 .82113 m .32887 .82286 L .32887 .82286 L .659 .811 .957 r
F
.32631 .82113 m .32887 .82286 L .32988 .82246 L F
.32631 .82113 m .32767 .82306 L .32887 .82286 L F
.32868 .82567 m .32864 .82689 L .32868 .82567 L .644 .409 .547 r
F
.32887 .82561 m .32872 .82567 L .32891 .82564 L .658 .812 .957 r
F
.32788 .826 m .32795 .82609 L .32825 .82601 L F
.32788 .826 m .32825 .82601 L .32912 .82578 L F
.32691 .82597 m .32694 .82597 L .32687 .82706 L .749 .499 .553 r
F
.32631 .82113 m .3265 .82314 L .32767 .82306 L .659 .811 .957 r
F
.3265 .82314 m .32651 .82326 L .3271 .82316 L F
.3265 .82314 m .3271 .82316 L .32767 .82306 L F
.3309 .74716 m .33056 .75166 L .33064 .75166 L .663 .424 .548 r
F
.32855 .74696 m .32843 .74741 L .32852 .74737 L .385 .194 .495 r
F
.32907 .74711 m .32383 .74301 L .32838 .74743 L .594 .768 .963 r
F
.32838 .74743 m .32106 .74384 L .3277 .74774 L F
.32956 .75167 m .3302 .74726 L .32661 .74726 L .593 .769 .963 r
F
.33082 .75354 m .33063 .75166 L .32956 .75167 L F
.33063 .75166 m .3302 .74726 L .32956 .75167 L F
.33089 .74716 m .33055 .75166 L .3309 .74716 L .663 .424 .548 r
F
.33055 .75166 m .32555 .81939 L .33056 .75166 L F
.32555 .81939 m .32555 .81939 L .33056 .75166 L F
.33064 .75166 m .32555 .81939 L .32672 .81923 L F
.32557 .81917 m .32608 .81885 L .32559 .81891 L .659 .811 .957 r
F
.32631 .82113 m .32613 .81931 L .32512 .81945 L F
.33056 .75166 m .32534 .82222 L .33064 .75166 L .663 .424 .548 r
F
.32534 .82222 m .32529 .82293 L .32534 .82222 L F
.32534 .82222 m .32534 .82222 L .33064 .75166 L F
.32533 .82222 m .32408 .82321 L .32529 .82293 L .57 .346 .536 r
F
.32549 .8194 m .32434 .82251 L .32533 .82222 L F
.32434 .82251 m .32408 .82321 L .32533 .82222 L F
.32645 .82398 m .32626 .82209 L .32533 .82222 L .658 .812 .957 r
F
.32522 .82225 m .32533 .82222 L .32521 .82223 L F
.32645 .82398 m .32533 .82222 L .32522 .82225 L F
.32555 .81939 m .32529 .82293 L .32555 .81939 L .663 .424 .548 r
F
.32631 .82113 m .3307 .82197 L .33114 .82138 L .659 .811 .957 r
F
.33492 .75421 m .33116 .82076 L .33112 .82136 L 0 0 0 r
F
.32631 .82113 m .33114 .82138 L .33124 .82083 L .659 .811 .957 r
F
.3312 .82079 m .33124 .82083 L .33125 .82078 L F
.32631 .82113 m .33124 .82083 L .3312 .82079 L F
.33067 .82195 m .33054 .82475 L .33067 .82196 L .335 .155 .483 r
F
.33054 .82475 m .33047 .82606 L .33054 .82475 L F
.33054 .82475 m .33054 .82475 L .33067 .82196 L F
.33129 .82423 m .33086 .82482 L .33131 .82423 L .658 .812 .957 r
F
.3307 .82197 m .33508 .8228 L .33597 .82164 L .659 .811 .957 r
F
.3307 .82197 m .33597 .82164 L .33114 .82138 L F
.3311 .82139 m .33095 .82419 L .3311 .8214 L 0 0 .355 r
F
.33055 .82474 m .33086 .82482 L .33129 .82423 L .658 .812 .957 r
F
.33053 .82475 m .33054 .82476 L .33055 .82474 L F
.33054 .82476 m .33086 .82482 L .33055 .82474 L F
.3311 .82139 m .33112 .82136 L .33096 .82418 L 0 0 .355 r
F
.33095 .82419 m .33096 .82418 L .33089 .8255 L F
.3311 .82139 m .33096 .82418 L .33095 .82419 L F
.33095 .82419 m .33089 .8255 L .33095 .82419 L F
.33095 .82419 m .33095 .82419 L .3311 .8214 L F
.32645 .82398 m .33053 .82475 L .33055 .82474 L .658 .812 .957 r
F
.33093 .82421 m .33055 .82474 L .33129 .82423 L F
.33071 .82193 m .33083 .82436 L .33055 .82474 L 0 0 .355 r
F
.3336 .82385 m .33723 .82521 L .33945 .82364 L .659 .811 .957 r
F
.33162 .82471 m .33723 .82521 L .3336 .82385 L F
.33086 .82482 m .33527 .82566 L .33616 .82449 L .658 .812 .957 r
F
.331 .82333 m .33162 .82471 L .3336 .82385 L .659 .811 .957 r
F
.33086 .82482 m .33616 .82449 L .33131 .82423 L .658 .812 .957 r
F
.3311 .8214 m .33095 .82419 L .33071 .82193 L 0 0 .355 r
F
.33095 .82419 m .33089 .8255 L .33083 .82436 L F
.33095 .82419 m .33083 .82436 L .33071 .82193 L F
.33136 .82363 m .33131 .82423 L .33142 .82363 L .658 .812 .957 r
F
.33067 .82195 m .33071 .82193 L .33047 .82606 L .335 .155 .483 r
F
.32645 .82398 m .33093 .82421 L .33096 .82418 L .658 .812 .957 r
F
.33095 .82426 m .33162 .82471 L .331 .82333 L .659 .811 .957 r
F
.33098 .82383 m .33096 .82418 L .33122 .82382 L .658 .812 .957 r
F
.32645 .82398 m .33096 .82418 L .33098 .82383 L F
.33492 .75417 m .33495 .75361 L .33116 .82073 L 0 0 0 r
F
.33492 .75417 m .33116 .82073 L .33116 .82076 L F
.33116 .82076 m .33116 .82076 L .33492 .75421 L F
.33492 .75417 m .33116 .82076 L .33492 .75417 L F
.33116 .82076 m .33116 .82076 L .33492 .75417 L F
.33495 .75361 m .33056 .82001 L .33116 .82073 L .992 .745 .442 r
F
.33077 .82026 m .33125 .82078 L .33103 .8202 L .659 .811 .957 r
F
.32631 .82113 m .3312 .82079 L .33077 .82026 L F
.3312 .82079 m .33125 .82078 L .33077 .82026 L F
.33492 .75356 m .33056 .82 L .33495 .75361 L .992 .745 .442 r
F
.33099 .82366 m .33122 .82382 L .33109 .82365 L .658 .812 .957 r
F
.32645 .82398 m .33098 .82383 L .33099 .82366 L F
.33098 .82383 m .33122 .82382 L .33099 .82366 L F
.33116 .82076 m .331 .82355 L .33116 .82076 L 0 0 0 r
F
.331 .82355 m .331 .82355 L .33116 .82076 L F
.33112 .82136 m .33099 .82374 L .33096 .82418 L F
.33116 .82076 m .331 .82355 L .33116 .82076 L F
.331 .82355 m .33093 .82483 L .331 .82355 L F
.331 .82355 m .331 .82355 L .33116 .82076 L F
.33103 .82308 m .33142 .82363 L .3312 .82305 L .658 .812 .957 r
F
.33116 .82076 m .33116 .82073 L .331 .82354 L 0 0 0 r
F
.33116 .82076 m .331 .82354 L .331 .82355 L F
.33116 .82076 m .331 .82355 L .33112 .82136 L F
.331 .82355 m .33093 .82483 L .33099 .82374 L F
.331 .82355 m .33099 .82374 L .33112 .82136 L F
.32645 .82398 m .33099 .82366 L .33068 .82315 L .658 .812 .957 r
F
.33099 .82366 m .33109 .82365 L .331 .82354 L F
.33099 .82366 m .331 .82354 L .33068 .82315 L F
.33116 .82073 m .33055 .82301 L .331 .82354 L .992 .745 .442 r
F
.33068 .82315 m .33101 .82337 L .33103 .82308 L .658 .812 .957 r
F
.33101 .82337 m .33142 .82363 L .33103 .82308 L F
.33109 .82365 m .33142 .82363 L .33068 .82315 L F
.33056 .82 m .33056 .82001 L .33495 .75361 L .992 .745 .442 r
F
.33056 .82 m .33056 .82 L .33492 .75356 L F
.33459 .74831 m .33426 .75277 L .33434 .75281 L .892 .63 .535 r
F
.33458 .74831 m .33425 .75276 L .33459 .74831 L F
.33425 .75276 m .33426 .75277 L .33459 .74831 L F
.33515 .74903 m .33434 .75281 L .3352 .74911 L .992 .745 .442 r
F
.33458 .74831 m .33308 .75214 L .33425 .75276 L .892 .63 .535 r
F
.33515 .74903 m .33459 .74831 L .33434 .75281 L .992 .745 .442 r
F
.33358 .75241 m .34256 .75113 L .34023 .74969 L .593 .769 .963 r
F
.33082 .75354 m .33435 .75282 L .33358 .75241 L F
.33435 .75282 m .34256 .75113 L .33358 .75241 L F
.32631 .82113 m .33103 .8202 L .33097 .82015 L .659 .811 .957 r
F
.35203 .75416 m .36825 .75565 L .35617 .75186 L .595 .768 .962 r
F
.3436 .75272 m .35834 .75371 L .34485 .75129 L .594 .768 .963 r
F
.33647 .75238 m .34408 .75272 L .34256 .75113 L .593 .769 .963 r
F
.33082 .75354 m .33684 .75317 L .33503 .75268 L F
.32631 .82113 m .33097 .82015 L .33015 .8198 L .659 .811 .957 r
F
.33082 .75354 m .33205 .75538 L .33312 .75533 L .593 .769 .963 r
F
.33082 .75354 m .33304 .75527 L .33332 .7552 L F
.33333 .74764 m .333 .75212 L .33308 .75214 L .802 .546 .551 r
F
.33521 .74864 m .33966 .74937 L .33664 .74855 L .594 .768 .963 r
F
.33621 .74917 m .33966 .74937 L .33521 .74864 L F
.33966 .74937 m .34518 .7497 L .33664 .74855 L F
.33332 .74764 m .33185 .75181 L .33299 .75212 L .802 .546 .551 r
F
.33332 .74764 m .33299 .75212 L .33333 .74764 L F
.33082 .75354 m .33377 .75233 L .33273 .75205 L .593 .769 .963 r
F
.33299 .75212 m .32803 .81924 L .333 .75212 L .802 .546 .551 r
F
.32803 .81924 m .32803 .81924 L .333 .75212 L F
.32631 .82113 m .32827 .81928 L .32797 .81923 L .659 .811 .957 r
F
.32631 .82113 m .32797 .81923 L .32719 .81923 L F
.32631 .82113 m .32931 .81946 L .32827 .81928 L F
.32931 .81946 m .32923 .81943 L .32827 .81928 L F
.33426 .75277 m .3293 .81945 L .33434 .75281 L .892 .63 .535 r
F
.33425 .75276 m .33308 .75214 L .32923 .81943 L F
.32631 .82113 m .33015 .8198 L .32994 .81972 L .659 .811 .957 r
F
.32631 .82113 m .33028 .81959 L .32934 .81944 L F
.32645 .82398 m .32936 .82236 L .32907 .82224 L .658 .812 .957 r
F
.32645 .82398 m .32907 .82224 L .32841 .82214 L F
.3293 .81945 m .32909 .82225 L .3293 .81945 L .892 .63 .535 r
F
.32645 .82398 m .33017 .8227 L .32936 .82236 L .658 .812 .957 r
F
.33056 .82001 m .33038 .82279 L .33116 .82073 L .992 .745 .442 r
F
.32645 .82398 m .33068 .82315 L .33017 .8227 L .658 .812 .957 r
F
.33068 .82315 m .33108 .82307 L .33037 .82278 L F
.33068 .82315 m .33037 .82278 L .33017 .8227 L F
.33056 .82 m .33038 .82279 L .33056 .82 L .992 .745 .442 r
F
.33038 .82279 m .3303 .82396 L .33038 .82279 L F
.33038 .82279 m .33038 .82279 L .33056 .82 L F
.33038 .82279 m .3303 .82396 L .33055 .82301 L F
.33038 .82279 m .33055 .82301 L .33116 .82073 L F
.33056 .82 m .33053 .81996 L .33037 .82278 L F
.33038 .82279 m .33037 .82278 L .3303 .82396 L F
.33056 .82 m .33037 .82278 L .33038 .82279 L F
.33108 .82307 m .3312 .82305 L .33035 .82276 L .658 .812 .957 r
F
.33053 .81996 m .32942 .82239 L .33037 .82278 L .892 .63 .535 r
F
.33037 .82278 m .33035 .82276 L .33017 .8227 L .658 .812 .957 r
F
.33108 .82307 m .33035 .82276 L .33037 .82278 L F
.33027 .82266 m .3312 .82305 L .33065 .82253 L F
.33017 .8227 m .33035 .82276 L .33027 .82266 L F
.33035 .82276 m .3312 .82305 L .33027 .82266 L F
.33037 .82278 m .32901 .82328 L .3303 .82396 L .892 .63 .535 r
F
.32942 .82239 m .32901 .82328 L .33037 .82278 L F
.32909 .82225 m .32901 .82328 L .32909 .82225 L F
.32909 .82225 m .32909 .82225 L .3293 .81945 L F
.32936 .82236 m .33065 .82253 L .32981 .82211 L .658 .812 .957 r
F
.33017 .8227 m .33065 .82253 L .32936 .82236 L F
.32907 .82224 m .32776 .82296 L .32901 .82328 L .802 .546 .551 r
F
.32923 .81943 m .32812 .8221 L .32907 .82224 L F
.32812 .8221 m .32776 .82296 L .32907 .82224 L F
.3293 .81945 m .32901 .82328 L .33053 .81996 L .892 .63 .535 r
F
.3293 .81945 m .32901 .82328 L .3293 .81945 L F
.32907 .82224 m .32981 .82211 L .32853 .82202 L .658 .812 .957 r
F
.32936 .82236 m .32947 .8223 L .32907 .82224 L F
.32947 .8223 m .32981 .82211 L .32907 .82224 L F
.32841 .82214 m .32907 .82224 L .32853 .82202 L F
.32803 .81924 m .32782 .82205 L .32804 .81924 L .802 .546 .551 r
F
.32804 .81924 m .32782 .82205 L .32923 .81943 L F
.32645 .82398 m .32841 .82214 L .32781 .82205 L .658 .812 .957 r
F
.32645 .82398 m .32781 .82205 L .32735 .82205 L F
.32797 .81923 m .32684 .82205 L .32781 .82205 L .733 .485 .553 r
F
.33082 .75354 m .33101 .75542 L .33205 .75538 L .593 .769 .963 r
F
.33299 .75212 m .333 .75212 L .33333 .74764 L .802 .546 .551 r
F
.33337 .74703 m .33319 .7476 L .33332 .74764 L F
.33337 .74703 m .33214 .74671 L .33211 .74731 L F
.33337 .74703 m .33211 .74731 L .33319 .7476 L F
.33133 .74888 m .33775 .74384 L .33433 .74301 L .594 .768 .963 r
F
.3321 .74731 m .33176 .7518 L .33211 .74731 L .733 .485 .553 r
F
.33176 .7518 m .33177 .7518 L .33211 .74731 L F
.33211 .74731 m .33177 .7518 L .33185 .75181 L F
.33463 .74773 m .33458 .74831 L .33459 .74831 L .892 .63 .535 r
F
.33319 .7476 m .33185 .75181 L .33332 .74764 L .802 .546 .551 r
F
.33524 .74863 m .33463 .74773 L .33459 .74831 L .992 .745 .442 r
F
.33452 .74822 m .34457 .74805 L .34305 .74645 L .594 .768 .963 r
F
.33486 .74866 m .34457 .74805 L .33452 .74822 L F
.33319 .7476 m .33211 .74731 L .33185 .75181 L .802 .546 .551 r
F
.33393 .74781 m .34072 .74502 L .33301 .74755 L .594 .768 .963 r
F
.33458 .74831 m .33333 .74764 L .33308 .75214 L .892 .63 .535 r
F
.33377 .74787 m .33452 .74822 L .33414 .74772 L .594 .768 .963 r
F
.33445 .74823 m .33452 .74822 L .33377 .74787 L F
.33452 .74822 m .34305 .74645 L .33414 .74772 L F
.3321 .74731 m .33064 .75166 L .33176 .7518 L .733 .485 .553 r
F
.33518 .74957 m .33517 .74971 L .33528 .74958 L .594 .768 .963 r
F
.33172 .75179 m .33725 .74852 L .33383 .74769 L .593 .769 .963 r
F
.33082 .75354 m .33288 .75194 L .33172 .75179 L F
.33288 .75194 m .33725 .74852 L .33172 .75179 L F
.33133 .74888 m .33211 .74731 L .33116 .74719 L .594 .768 .963 r
F
.3321 .74731 m .3309 .74716 L .33064 .75166 L .733 .485 .553 r
F
.33055 .75166 m .33056 .75166 L .3309 .74716 L .663 .424 .548 r
F
.33082 .75354 m .33383 .74769 L .3302 .74726 L .593 .769 .963 r
F
.33176 .7518 m .33064 .75166 L .32672 .81923 L .733 .485 .553 r
F
.33176 .7518 m .32672 .81923 L .32678 .81923 L F
.33185 .75181 m .32679 .81923 L .32797 .81923 L F
.3268 .81902 m .32738 .81883 L .32682 .81884 L .659 .811 .957 r
F
.33176 .7518 m .32678 .81923 L .33177 .7518 L .733 .485 .553 r
F
.32678 .81923 m .32678 .81923 L .33177 .7518 L F
.32631 .82113 m .32719 .81923 L .32612 .81923 L .659 .811 .957 r
F
.32645 .82398 m .32656 .82205 L .32626 .82209 L .658 .812 .957 r
F
.32656 .82205 m .32529 .82293 L .32651 .82286 L .663 .424 .548 r
F
.32672 .81923 m .32558 .82218 L .32656 .82205 L F
.32558 .82218 m .32529 .82293 L .32656 .82205 L F
.32645 .82398 m .32735 .82205 L .32656 .82205 L .658 .812 .957 r
F
.32626 .82209 m .32656 .82205 L .32626 .82205 L F
.33177 .7518 m .32651 .82286 L .33185 .75181 L .733 .485 .553 r
F
.3268 .81902 m .32682 .81884 L .32608 .81885 L .659 .811 .957 r
F
.32612 .81923 m .3268 .81902 L .32608 .81885 L F
.32719 .81923 m .32738 .81883 L .32612 .81923 L F
.32678 .81923 m .32672 .81923 L .32651 .82286 L .733 .485 .553 r
F
.32679 .81923 m .32658 .82205 L .32797 .81923 L F
.32658 .82205 m .32684 .82205 L .32797 .81923 L F
.32678 .81923 m .32651 .82286 L .32678 .81923 L F
.32626 .82205 m .32752 .82168 L .32622 .82169 L .658 .812 .957 r
F
.32735 .82205 m .32752 .82168 L .32626 .82205 L F
.32658 .82205 m .32651 .82286 L .32684 .82205 L .733 .485 .553 r
F
.32781 .82205 m .32651 .82286 L .32776 .82296 L F
.32684 .82205 m .32651 .82286 L .32781 .82205 L F
.32735 .82205 m .32781 .82205 L .32738 .82198 L .658 .812 .957 r
F
.32803 .81924 m .32776 .82296 L .32803 .81924 L .802 .546 .551 r
F
.33299 .75212 m .33185 .75181 L .32776 .82296 L F
.32738 .82198 m .32875 .82182 L .32752 .82168 L .658 .812 .957 r
F
.32841 .82214 m .32875 .82182 L .32738 .82198 L F
.32782 .82205 m .32776 .82296 L .32812 .8221 L .802 .546 .551 r
F
.32782 .82205 m .32812 .8221 L .32923 .81943 L F
.32782 .82205 m .32776 .82296 L .32782 .82205 L F
.32782 .82205 m .32782 .82205 L .32804 .81924 L F
.32853 .82202 m .32981 .82211 L .32875 .82182 L .658 .812 .957 r
F
.3293 .81945 m .32923 .81943 L .32907 .82224 L .892 .63 .535 r
F
.32909 .82225 m .32907 .82224 L .32901 .82328 L F
.3293 .81945 m .32907 .82224 L .32909 .82225 L F
.33425 .75276 m .32923 .81943 L .3293 .81945 L F
.33434 .75281 m .3293 .81945 L .33053 .81996 L F
.32994 .81972 m .33048 .81969 L .33028 .81959 L .659 .811 .957 r
F
.33015 .8198 m .33048 .81969 L .32994 .81972 L F
.32934 .81944 m .33028 .81959 L .32965 .81927 L F
.333 .75212 m .32803 .81924 L .33308 .75214 L .802 .546 .551 r
F
.32803 .81924 m .32804 .81924 L .33308 .75214 L F
.3293 .81945 m .3293 .81945 L .33434 .75281 L .892 .63 .535 r
F
.33308 .75214 m .32804 .81924 L .32923 .81943 L .802 .546 .551 r
F
.33425 .75276 m .3293 .81945 L .33426 .75277 L .892 .63 .535 r
F
.3293 .81945 m .3293 .81945 L .33426 .75277 L F
.32846 .8191 m .32965 .81927 L .32859 .81898 L .659 .811 .957 r
F
.32827 .81928 m .32887 .81927 L .32846 .8191 L F
.32887 .81927 m .32965 .81927 L .32846 .8191 L F
.32931 .81946 m .32934 .81944 L .32923 .81943 L F
.32934 .81944 m .32965 .81927 L .32827 .81928 L F
.32797 .81923 m .32859 .81898 L .32724 .81912 L F
.32827 .81928 m .32832 .81923 L .32797 .81923 L F
.32832 .81923 m .32859 .81898 L .32797 .81923 L F
.32719 .81923 m .32797 .81923 L .32724 .81912 L F
.32724 .81912 m .32859 .81898 L .32738 .81883 L F
.33273 .75205 m .33431 .75211 L .33288 .75194 L .593 .769 .963 r
F
.33377 .75233 m .33431 .75211 L .33273 .75205 L F
.33288 .75194 m .34023 .74969 L .33725 .74852 L F
.33431 .75211 m .34023 .74969 L .33288 .75194 L F
.33503 .75268 m .34084 .75292 L .33647 .75238 L F
.33684 .75317 m .34084 .75292 L .33503 .75268 L F
.35203 .75416 m .36202 .75907 L .36825 .75565 L .595 .768 .962 r
F
.3436 .75272 m .35582 .75654 L .35834 .75371 L .594 .768 .963 r
F
.34084 .75292 m .34408 .75272 L .33647 .75238 L .593 .769 .963 r
F
.33491 .75356 m .33434 .75281 L .33053 .81996 L .992 .745 .442 r
F
.33491 .75356 m .33053 .81996 L .33056 .82 L F
.33034 .81974 m .33097 .82015 L .33048 .81969 L .659 .811 .957 r
F
.33015 .8198 m .33053 .81996 L .33034 .81974 L F
.33053 .81996 m .33097 .82015 L .33034 .81974 L F
.33056 .82 m .33038 .82279 L .33056 .82001 L .992 .745 .442 r
F
.33038 .82279 m .3303 .82396 L .33038 .82279 L F
.33038 .82279 m .33038 .82279 L .33056 .82001 L F
.331 .82355 m .33093 .82483 L .331 .82355 L 0 0 0 r
F
.331 .82355 m .331 .82354 L .33093 .82483 L F
.33099 .82374 m .33093 .82483 L .33096 .82418 L F
.331 .82354 m .3303 .82396 L .33093 .82483 L .992 .745 .442 r
F
.33055 .82301 m .3303 .82396 L .331 .82354 L F
.33109 .82365 m .33122 .82382 L .33136 .82363 L .658 .812 .957 r
F
.33093 .82421 m .33131 .82423 L .33136 .82363 L F
.32645 .82398 m .33055 .82474 L .33093 .82421 L F
.32555 .81939 m .32529 .82293 L .32672 .81923 L .663 .424 .548 r
F
.32555 .81939 m .32549 .8194 L .32529 .82293 L F
.32521 .82223 m .32622 .82169 L .32494 .82186 L .658 .812 .957 r
F
.32626 .82209 m .32622 .82169 L .32521 .82223 L F
.33055 .75166 m .32944 .75167 L .32549 .8194 L .663 .424 .548 r
F
.33055 .75166 m .32549 .8194 L .32555 .81939 L F
.32557 .81917 m .32559 .81891 L .32481 .81901 L .659 .811 .957 r
F
.32512 .81945 m .32557 .81917 L .32481 .81901 L F
.32613 .81931 m .32608 .81885 L .32512 .81945 L F
.32434 .81974 m .32408 .82321 L .32549 .8194 L .57 .346 .536 r
F
.32429 .82253 m .32494 .82186 L .32376 .82217 L .658 .812 .957 r
F
.32522 .82225 m .32494 .82186 L .32429 .82253 L F
.32413 .82258 m .32412 .82258 L .32408 .82321 L .57 .346 .536 r
F
.32936 .75168 m .32428 .81976 L .32434 .81974 L F
.32428 .81976 m .32512 .81945 L .32404 .8196 L .659 .811 .957 r
F
.32515 .8195 m .32512 .81945 L .32428 .81976 L F
.32404 .8196 m .32481 .81901 L .32364 .81932 L F
.32512 .81945 m .32481 .81901 L .32404 .8196 L F
.32429 .82253 m .32376 .82217 L .32333 .82281 L .658 .812 .957 r
F
.32413 .82258 m .32408 .82321 L .32413 .82258 L .57 .346 .536 r
F
.32412 .82258 m .32407 .82261 L .32408 .82321 L .385 .194 .495 r
F
.32357 .82291 m .32323 .82278 L .32294 .82328 L .658 .812 .957 r
F
.32266 .82378 m .32202 .82313 L .32158 .82372 L F
.32293 .82331 m .32202 .82313 L .32266 .82378 L F
.32266 .82378 m .32237 .82376 L .32246 .82412 L F
.32266 .82378 m .32246 .82412 L .3225 .82425 L F
.32237 .82376 m .32216 .82375 L .3225 .82425 L F
.32216 .82375 m .32158 .82372 L .3215 .82415 L F
.32216 .82375 m .3215 .82415 L .32147 .82433 L F
.32295 .82328 m .32291 .82386 L .32295 .82328 L .385 .194 .495 r
F
.32316 .82044 m .32316 .82043 L .32826 .75186 L F
.32366 .82014 m .32364 .81932 L .32265 .81976 L .659 .811 .957 r
F
.32428 .81976 m .32364 .81932 L .32366 .82014 L F
.32305 .8205 m .32338 .82003 L .32228 .82036 L F
.32366 .82014 m .32338 .82003 L .32305 .8205 L F
.32228 .82036 m .3227 .81978 L .32191 .82029 L F
.32338 .82003 m .3227 .81978 L .32228 .82036 L F
.3227 .81978 m .32265 .81976 L .3226 .81979 L F
.3227 .81978 m .3226 .81979 L .32191 .82029 L F
.32236 .82092 m .32228 .82036 L .32147 .82087 L F
.32305 .8205 m .32228 .82036 L .32236 .82092 L F
.32228 .82036 m .32191 .82029 L .32173 .82052 L F
.32228 .82036 m .32173 .82052 L .32147 .82087 L F
.32472 .75245 m .32494 .75171 L .32074 .75174 L .593 .769 .963 r
F
.32642 .75217 m .32494 .75171 L .32472 .75245 L F
.32494 .75171 m .31847 .74969 L .32074 .75174 L F
.32262 .82474 m .32258 .82539 L .32262 .82474 L .923 .74 .252 r
F
.32275 .82525 m .3217 .8249 L .32225 .82542 L .658 .812 .957 r
F
.32304 .82515 m .32271 .82509 L .32275 .82525 L F
.32271 .82509 m .3217 .8249 L .32275 .82525 L F
.32645 .82398 m .3226 .82473 L .32304 .82515 L F
.32313 .82524 m .32313 .82524 L .32309 .82596 L .981 .727 .472 r
F
.32216 .82214 m .32159 .82205 L .32199 .82243 L .659 .811 .957 r
F
.32216 .82214 m .32199 .82243 L .32213 .82256 L F
.32304 .82515 m .32275 .82525 L .32351 .82561 L .658 .812 .957 r
F
.32275 .82525 m .32225 .82542 L .32287 .82573 L F
.32275 .82525 m .32287 .82573 L .32309 .82584 L F
.32262 .82474 m .32262 .82474 L .32258 .82539 L .923 .74 .252 r
F
.32274 .82278 m .32243 .82471 L .32265 .82433 L 0 0 .29 r
F
.32274 .82278 m .32265 .82433 L .32291 .82386 L F
.32262 .82474 m .32309 .82596 L .32258 .82539 L .981 .727 .472 r
F
.32313 .82524 m .32309 .82596 L .32262 .82474 L F
.32645 .82398 m .32658 .82539 L .32695 .82469 L .658 .812 .957 r
F
.32658 .82539 m .32664 .82596 L .32695 .82469 L F
.32695 .82469 m .32664 .82596 L .32788 .826 L F
.32691 .82597 m .32687 .82706 L .32691 .82597 L .749 .499 .553 r
F
.32645 .82398 m .32554 .82593 L .32664 .82596 L .658 .812 .957 r
F
.32554 .82593 m .32537 .82627 L .32664 .82596 L F
.32691 .82597 m .32687 .82706 L .32643 .82595 L .749 .499 .553 r
F
.32513 .82591 m .32687 .82706 L .32507 .82684 L F
.32554 .82593 m .32513 .82591 L .3255 .826 L .658 .812 .957 r
F
.32643 .82595 m .32687 .82706 L .32513 .82591 L .749 .499 .553 r
F
.32645 .82398 m .32453 .82577 L .32513 .82591 L .658 .812 .957 r
F
.32645 .82398 m .32513 .82591 L .32554 .82593 L F
.32511 .82591 m .32513 .82591 L .32507 .82684 L .834 .575 .548 r
F
.32868 .82567 m .32864 .82689 L .32694 .82597 L .644 .409 .547 r
F
.32645 .82398 m .32982 .82524 L .33053 .82475 L .658 .812 .957 r
F
.32982 .82524 m .33012 .82535 L .33053 .82475 L F
.33214 .74671 m .3321 .74731 L .33211 .74731 L .733 .485 .553 r
F
.33116 .74719 m .33211 .74731 L .33115 .74704 L .594 .768 .963 r
F
.33213 .74731 m .33433 .74301 L .33115 .74704 L F
.33684 .75317 m .34469 .75437 L .34408 .75272 L .593 .769 .963 r
F
.34027 .75411 m .34469 .75437 L .33684 .75317 L F
.33096 .82418 m .33093 .82483 L .33089 .8255 L 0 0 0 r
F
.33055 .82474 m .33089 .8255 L .33047 .82606 L 0 0 .355 r
F
.33083 .82436 m .33089 .8255 L .33055 .82474 L F
.32982 .82524 m .33047 .82606 L .32974 .82653 L .335 .155 .483 r
F
.33032 .8249 m .33047 .82606 L .32982 .82524 L F
.33301 .74755 m .34072 .74502 L .33775 .74384 L .594 .768 .963 r
F
.33414 .74772 m .34305 .74645 L .34072 .74502 L F
.32973 .74667 m .32969 .74717 L .3297 .74717 L .57 .346 .536 r
F
.32924 .74724 m .33011 .74706 L .3288 .7469 L .594 .768 .963 r
F
.33014 .74709 m .33011 .74706 L .32924 .74724 L F
.33011 .74706 m .32712 .74258 L .3288 .7469 L F
.32924 .74724 m .32907 .74711 L .32852 .74736 L F
.32574 .75459 m .32366 .75398 L .31961 .75585 L .593 .769 .963 r
F
.32622 .75383 m .32366 .75398 L .32574 .75459 L F
.32366 .75398 m .3176 .75436 L .31961 .75585 L F
.32574 .75459 m .31915 .75594 L .32487 .75598 L F
.33735 .75673 m .33916 .75908 L .34103 .75853 L F
.29066 .38769 m .3251 .38415 L .29131 .38238 L .643 .737 .917 r
F
.47859 .52296 m .46021 .53744 L .48388 .52977 L .655 .782 .942 r
F
.47859 .52296 m .45212 .52729 L .46021 .53744 L F
0 g
.46021 .53744 m
.47297 .54589 L
s
.80495 .64796 m .81845 .63843 L .80232 .64617 L .655 .809 .957 r
F
.80495 .64796 m .82366 .64204 L .81845 .63843 L F
.31734 .65179 m .29921 .64809 L .29569 .65298 L .659 .805 .953 r
F
.32037 .6496 m .29921 .64809 L .31734 .65179 L F
.76933 .66336 m .74788 .66717 L .76801 .66588 L .654 .811 .959 r
F
.81133 .53471 m .78997 .52725 L .79076 .53374 L .734 .495 .567 r
F
0 g
.76871 .52918 m
.78997 .52725 L
s
.78997 .52725 m
.81051 .52823 L
s
.33748 .54201 m .31645 .53742 L .31644 .54394 L .672 .448 .573 r
F
0 g
.29715 .54862 m
.31644 .54394 L
s
.33748 .54201 m .33746 .53549 L .31645 .53742 L .672 .448 .573 r
F
0 g
.2972 .54211 m
.31645 .53742 L
s
.50776 .52204 m .49234 .53548 L .51197 .52493 L .655 .782 .942 r
F
.50776 .52204 m .48388 .52977 L .49234 .53548 L F
.29593 .66375 m .27581 .66252 L .27472 .67006 L .658 .806 .954 r
F
0 g
.27472 .67006 m
.2778 .67726 L
s
.81216 .54123 m .81133 .53471 L .79076 .53374 L .734 .495 .567 r
F
0 g
.81133 .53471 m
.82967 .53851 L
s
.35283 .65493 m .36342 .64539 L .34944 .65314 L .659 .806 .954 r
F
.35283 .65493 m .37017 .649 L .36342 .64539 L F
.56901 .77937 m .57016 .7795 L .56995 .78409 L .897 .727 .221 r
F
.56901 .77937 m .56923 .77476 L .57016 .7795 L F
.58283 .77558 m .57016 .7795 L .58342 .77874 L .596 .768 .961 r
F
.58283 .77558 m .56923 .77476 L .57016 .7795 L F
0 g
.57016 .7795 m
.57365 .78388 L
s
.59652 .78257 m .58561 .78637 L .5977 .78409 L .595 .768 .962 r
F
.59652 .78257 m .58322 .78333 L .58561 .78637 L F
.2541 .51578 m .25423 .50931 L .27521 .50736 L .671 .446 .571 r
F
.23268 .51477 m .25423 .50931 L .2541 .51578 L .733 .498 .572 r
F
.23268 .51477 m .23283 .5083 L .25423 .50931 L F
.61137 .66742 m .5949 .664 L .59552 .6694 L .674 .458 .583 r
F
0 g
.58056 .67318 m
.59552 .6694 L
s
.61137 .66742 m .61073 .66203 L .5949 .664 L .674 .458 .583 r
F
0 g
.57996 .66778 m
.5949 .664 L
s
.68665 .36196 m .66556 .38019 L .69146 .36663 L .645 .736 .915 r
F
.68665 .36196 m .65587 .37098 L .66556 .38019 L F
.64869 .78419 m .65097 .77503 L .65084 .77964 L 0 0 .283 r
F
.64856 .78879 m .64869 .78419 L .65084 .77964 L F
.63584 .78187 m .64869 .78419 L .65084 .77964 L .596 .768 .961 r
F
0 g
.64394 .78824 m
.64869 .78419 L
s
.59669 .77179 m .58375 .77414 L .59696 .77337 L .597 .767 .961 r
F
.59669 .77179 m .58317 .77099 L .58375 .77414 L F
.63255 .78917 m .64856 .78879 L .63569 .78647 L .595 .768 .962 r
F
.62123 .7855 m .63255 .78917 L .63569 .78647 L F
.6189 .7866 m .63255 .78917 L .62123 .7855 L F
.34907 .64781 m .3543 .63751 L .34475 .64654 L .659 .805 .953 r
F
.34907 .64781 m .36296 .64007 L .3543 .63751 L F
.77107 .65553 m .74961 .65673 L .76847 .65797 L .655 .81 .958 r
F
.25226 .49455 m .2542 .50909 L .27507 .50715 L .657 .779 .938 r
F
.23794 .49386 m .2542 .50909 L .25226 .49455 L F
.23794 .49386 m .23291 .50808 L .2542 .50909 L F
.75044 .66213 m .72773 .66846 L .74788 .66717 L .654 .811 .959 r
F
.76933 .66336 m .75044 .66213 L .74788 .66717 L F
.63585 .77725 m .65076 .77502 L .63724 .77421 L .597 .767 .961 r
F
.62304 .77493 m .63585 .77725 L .63724 .77421 L F
.73956 .36915 m .76094 .38519 L .77328 .37713 L .645 .736 .915 r
F
.73197 .37213 m .76094 .38519 L .73956 .36915 L F
.60952 .51721 m .60904 .51074 L .6131 .49936 L 0 0 .37 r
F
0 g
.60265 .51806 m
.60904 .51074 L
s
.35873 .54297 m .33746 .53549 L .33748 .54201 L .733 .498 .572 r
F
0 g
.31645 .53742 m
.33746 .53549 L
s
.33746 .53549 m
.35867 .53646 L
s
.35873 .54297 m
.37861 .54674 L
s
.46163 .37854 m .44601 .38265 L .44536 .39071 L .308 .127 .466 r
F
.46163 .37854 m .46225 .37044 L .44601 .38265 L F
0 g
.43599 .39708 m
.44601 .38265 L
s
.29921 .64809 m .27572 .65173 L .29569 .65298 L .659 .805 .953 r
F
.80821 .66088 m .82572 .65276 L .80686 .6587 L .654 .811 .959 r
F
.80821 .66088 m .82836 .65716 L .82572 .65276 L F
.62695 .66739 m .61073 .66203 L .61137 .66742 L .733 .5 .575 r
F
0 g
.5949 .664 m
.61073 .66203 L
s
.61073 .66203 m
.62628 .662 L
s
.62695 .66739 m
.64113 .66931 L
s
.82743 .65177 m .84375 .64139 L .82479 .64737 L .655 .81 .958 r
F
.82743 .65177 m .8476 .64804 L .84375 .64139 L F
.57761 .52114 m .60952 .51721 L .58368 .51406 L .655 .781 .941 r
F
.8476 .64804 m .84664 .64267 L .84278 .63599 L .932 .628 .163 r
F
0 g
.84651 .64614 m
.84654 .64537 L
s
.61137 .66742 m
.62695 .66739 L
s
.31776 .66255 m .29593 .66375 L .31595 .66498 L .658 .806 .954 r
F
.79328 .74889 m .79876 .75507 L .7969 .74889 L .599 .766 .959 r
F
.78675 .67626 m .7884 .67649 L .79386 .74489 L .75 .494 .544 r
F
.79578 .7452 m .79328 .74889 L .7969 .74889 L .599 .766 .959 r
F
.79547 .74515 m .79328 .74889 L .79578 .7452 L F
.79545 .74514 m .79328 .74889 L .79547 .74515 L F
.79433 .74511 m .79328 .74889 L .79564 .74481 L F
.79328 .74889 m .79157 .75506 L .79876 .75507 L F
.78979 .74847 m .79157 .75506 L .79328 .74889 L F
.78675 .67626 m .79375 .74487 L .79216 .74461 L .75 .494 .544 r
F
.78675 .67626 m .79386 .74489 L .79375 .74487 L F
.7884 .67649 m .79554 .74482 L .79386 .74489 L .648 .416 .554 r
F
.78512 .67533 m .78575 .67584 L .79115 .74421 L .941 .646 .452 r
F
.79334 .7487 m .78979 .74847 L .79328 .74889 L .599 .766 .959 r
F
.79399 .74634 m .79244 .74712 L .79334 .7487 L F
.79244 .74712 m .78979 .74847 L .79334 .7487 L F
.78482 .67472 m .78512 .67533 L .79051 .74373 L .966 .687 .262 r
F
.79348 .74595 m .79225 .74679 L .79399 .74634 L .599 .766 .959 r
F
.79225 .74679 m .78979 .74847 L .79244 .74712 L F
.79225 .74679 m .79244 .74712 L .79399 .74634 L F
.79297 .74493 m .79262 .74531 L .79424 .74544 L F
.79262 .74531 m .78979 .74847 L .79348 .74595 L F
.79262 .74531 m .79348 .74595 L .79424 .74544 L F
.78575 .67584 m .78675 .67626 L .79216 .74461 L .848 .57 .516 r
F
.78575 .67584 m .79216 .74461 L .7921 .74459 L F
.78482 .67472 m .79049 .7437 L .7902 .74319 L .966 .687 .262 r
F
.78482 .67472 m .79051 .74373 L .79049 .7437 L F
.78488 .674 m .78482 .67472 L .7902 .74319 L 0 0 .196 r
F
.79297 .74493 m .78984 .74628 L .78979 .74847 L .599 .766 .959 r
F
.79191 .74451 m .7899 .7457 L .79297 .74493 L F
.7899 .7457 m .78664 .74765 L .78984 .74628 L F
.7899 .7457 m .78984 .74628 L .79297 .74493 L F
.78575 .67584 m .7921 .74459 L .79115 .74421 L .848 .57 .516 r
F
.78512 .67533 m .79111 .74418 L .79051 .74373 L .941 .646 .452 r
F
.78512 .67533 m .79115 .74421 L .79111 .74418 L F
.79501 .74266 m .78755 .74527 L .78664 .74765 L .599 .766 .959 r
F
.78755 .74527 m .78407 .74649 L .78561 .74719 L F
.78755 .74527 m .78561 .74719 L .78664 .74765 L F
.7856 .6731 m .78488 .674 L .79028 .74258 L .159 .061 .485 r
F
.79501 .74266 m .78906 .74378 L .78755 .74527 L .599 .766 .959 r
F
.78979 .74847 m .78462 .75422 L .79157 .75506 L F
.78664 .74765 m .78462 .75422 L .78979 .74847 L F
.78664 .74765 m .77835 .7526 L .78462 .75422 L F
.78407 .74649 m .77835 .7526 L .78664 .74765 L F
.79113 .74868 m .78219 .74973 L .78404 .75116 L .598 .766 .96 r
F
.78488 .674 m .79021 .74316 L .79028 .74258 L 0 0 .196 r
F
.78488 .674 m .7902 .74319 L .79021 .74316 L F
.78314 .7449 m .78125 .74348 L .78222 .74507 L .599 .766 .959 r
F
.79501 .74266 m .7878 .74309 L .78314 .7449 L F
.7878 .74309 m .78125 .74348 L .78314 .7449 L F
.79501 .74266 m .79191 .74451 L .79297 .74493 L F
.79115 .74421 m .79251 .74909 L .7915 .74869 L .848 .57 .516 r
F
.7932 .74937 m .78664 .75232 L .7898 .75314 L .598 .766 .96 r
F
.7921 .74459 m .79252 .74909 L .79115 .74421 L .848 .57 .516 r
F
.79252 .74909 m .79251 .74909 L .79115 .74421 L F
.7921 .74459 m .79216 .74461 L .79252 .74909 L F
.79224 .74898 m .78664 .75232 L .7932 .74937 L .598 .766 .96 r
F
.79252 .74909 m .79252 .74909 L .79252 .74915 L .848 .57 .516 r
F
.7921 .74459 m .79252 .74909 L .79252 .74909 L F
.79224 .74898 m .78404 .75116 L .78664 .75232 L .598 .766 .96 r
F
.79051 .74373 m .79149 .74869 L .79086 .74822 L .941 .646 .452 r
F
.7902 .74319 m .79086 .74821 L .79055 .74764 L .966 .687 .262 r
F
.79111 .74418 m .7915 .74869 L .79051 .74373 L .941 .646 .452 r
F
.79131 .74862 m .78404 .75116 L .79224 .74898 L .598 .766 .96 r
F
.7915 .74869 m .7915 .74874 L .79149 .74869 L .941 .646 .452 r
F
.7915 .74869 m .79149 .74869 L .79051 .74373 L F
.78984 .74628 m .78664 .74765 L .78958 .74841 L .599 .766 .959 r
F
.78984 .74628 m .78958 .74841 L .78979 .74847 L F
.78407 .74649 m .7732 .7503 L .77835 .7526 L F
.79074 .74812 m .78121 .74814 L .78219 .74973 L .598 .766 .96 r
F
.79086 .74821 m .79076 .74803 L .79055 .74764 L .966 .687 .262 r
F
.79075 .7468 m .79086 .74822 L .79069 .74687 L F
.79086 .74822 m .79086 .74821 L .79069 .74687 L F
.7856 .6731 m .79032 .74254 L .79103 .74184 L .159 .061 .485 r
F
.7856 .6731 m .79028 .74258 L .79032 .74254 L F
.79501 .74266 m .78683 .74217 L .78125 .74348 L .599 .766 .959 r
F
.78683 .74217 m .78121 .74183 L .78124 .74303 L F
.78683 .74217 m .78124 .74303 L .78125 .74348 L F
.79564 .74481 m .79545 .74514 L .79566 .74481 L F
.79545 .74514 m .79547 .74515 L .79566 .74481 L F
.7944 .74486 m .79433 .74511 L .79564 .74481 L F
.79566 .74481 m .79547 .74515 L .79578 .7452 L F
.7884 .67649 m .79015 .67631 L .79564 .74481 L .648 .416 .554 r
F
.79554 .74482 m .79564 .74481 L .796 .7492 L F
.7884 .67649 m .79564 .74481 L .79554 .74482 L F
.79755 .74541 m .7969 .74889 L .80038 .74847 L .599 .766 .959 r
F
.79697 .74477 m .79693 .74682 L .79755 .74541 L F
.79693 .74682 m .7969 .74889 L .79755 .74541 L F
.79015 .67631 m .79678 .74455 L .79564 .74481 L .544 .339 .553 r
F
.79273 .67483 m .79298 .67412 L .79858 .74306 L 0 0 .362 r
F
.79799 .74441 m .80038 .74847 L .80072 .74838 L .599 .766 .959 r
F
.79947 .74528 m .80072 .74838 L .80351 .74765 L F
.79799 .74441 m .80072 .74838 L .79947 .74528 L F
.79795 .7445 m .80038 .74847 L .79799 .74441 L F
.79216 .67543 m .79273 .67483 L .79831 .74366 L .231 .113 .505 r
F
.79741 .74441 m .80038 .74847 L .79783 .74431 L .599 .766 .959 r
F
.79702 .74473 m .80038 .74847 L .79741 .74441 L F
.79678 .74457 m .80038 .74847 L .79685 .74454 L F
.79132 .67593 m .79767 .74417 L .79685 .74454 L .424 .252 .542 r
F
.79015 .67631 m .79132 .67593 L .79685 .74454 L .544 .339 .553 r
F
.79015 .67631 m .79685 .74454 L .79678 .74455 L F
.79216 .67543 m .79828 .74369 L .79772 .74415 L .231 .113 .505 r
F
.79842 .74384 m .80351 .74765 L .80607 .74649 L .599 .766 .959 r
F
.79132 .67593 m .79216 .67543 L .79772 .74415 L .424 .252 .542 r
F
.79132 .67593 m .79772 .74415 L .79767 .74417 L F
.79501 .74266 m .79762 .74419 L .79842 .74384 L .599 .766 .959 r
F
.79273 .67483 m .79858 .74306 L .79856 .74309 L 0 0 .362 r
F
.79273 .67483 m .79856 .74309 L .79831 .74366 L F
.79298 .67412 m .79265 .6732 L .79825 .74226 L .919 .662 .17 r
F
.79762 .74419 m .79947 .74528 L .79842 .74384 L .599 .766 .959 r
F
.79947 .74528 m .79909 .74434 L .79842 .74384 L F
.79216 .67543 m .79831 .74366 L .79828 .74369 L .231 .113 .505 r
F
.80045 .74368 m .80607 .74649 L .80787 .74507 L .599 .766 .959 r
F
.79501 .74266 m .80334 .74555 L .80045 .74368 L F
.80334 .74555 m .80607 .74649 L .80045 .74368 L F
.79501 .74266 m .79677 .74456 L .79783 .74431 L F
.79767 .74417 m .79772 .74415 L .79806 .74834 L .424 .252 .542 r
F
.79828 .74369 m .79831 .74366 L .79865 .74776 L .231 .113 .505 r
F
.79685 .74454 m .79702 .74473 L .79741 .74441 L .599 .766 .959 r
F
.79695 .74476 m .79695 .74478 L .79697 .74477 L F
.79767 .74417 m .79806 .74834 L .79685 .74454 L .424 .252 .542 r
F
.79783 .74431 m .79795 .7445 L .79799 .74441 L .599 .766 .959 r
F
.79772 .74415 m .79865 .74776 L .79806 .74834 L .231 .113 .505 r
F
.79828 .74369 m .79865 .74776 L .79772 .74415 L F
.79298 .67412 m .79827 .7423 L .79858 .74306 L .919 .662 .17 r
F
.79926 .74291 m .80787 .74507 L .80881 .74348 L .599 .766 .959 r
F
.79501 .74266 m .80045 .74368 L .79926 .74291 L F
.80045 .74368 m .80787 .74507 L .79926 .74291 L F
.79265 .6732 m .79163 .67248 L .79722 .74158 L .921 .628 .471 r
F
.79265 .6732 m .79722 .74158 L .79727 .74162 L F
.79265 .6732 m .79727 .74162 L .79825 .74226 L F
.79298 .67412 m .79825 .74226 L .79827 .7423 L .919 .662 .17 r
F
.79163 .67248 m .79615 .74127 L .79722 .74158 L .811 .54 .528 r
F
.79694 .7415 m .80603 .73879 L .80345 .73762 L .599 .766 .959 r
F
.79501 .74266 m .79768 .74172 L .79694 .7415 L F
.79768 .74172 m .80603 .73879 L .79694 .7415 L F
.79677 .74456 m .79678 .74457 L .79685 .74454 L F
.79501 .74266 m .79566 .74481 L .79695 .74476 L F
.79566 .74481 m .7969 .74889 L .79695 .74476 L F
.79685 .74454 m .79806 .74834 L .79719 .74882 L .424 .252 .542 r
F
.79695 .74478 m .7969 .74889 L .79697 .74477 L .599 .766 .959 r
F
.79678 .74455 m .79685 .74454 L .79719 .74882 L .544 .339 .553 r
F
.79678 .74455 m .79719 .74882 L .79564 .74481 L F
.79768 .74172 m .80786 .74023 L .80603 .73879 L .599 .766 .959 r
F
.79501 .74266 m .79856 .74199 L .79768 .74172 L F
.79856 .74199 m .80786 .74023 L .79768 .74172 L F
.79163 .67248 m .79053 .67215 L .79609 .74125 L .811 .54 .528 r
F
.79163 .67248 m .79609 .74125 L .79615 .74127 L F
.79053 .67215 m .79497 .7411 L .79609 .74125 L .734 .481 .546 r
F
.79542 .74116 m .80028 .73679 L .79675 .73636 L .599 .766 .959 r
F
.79501 .74266 m .79626 .74127 L .79542 .74116 L F
.79626 .74127 m .80028 .73679 L .79542 .74116 L F
.79564 .74481 m .79719 .74882 L .796 .7492 L .544 .339 .553 r
F
.79501 .74266 m .7944 .74486 L .79566 .74481 L .599 .766 .959 r
F
.79424 .74544 m .79348 .74595 L .79399 .74634 L F
.79501 .74266 m .79297 .74493 L .79424 .74544 L F
.79554 .74482 m .796 .7492 L .79386 .74489 L .648 .416 .554 r
F
.79626 .74127 m .80345 .73762 L .80028 .73679 L .599 .766 .959 r
F
.79501 .74266 m .79714 .74138 L .79626 .74127 L F
.79714 .74138 m .80345 .73762 L .79626 .74127 L F
.79053 .67215 m .78937 .67204 L .7949 .7411 L .734 .481 .546 r
F
.79053 .67215 m .7949 .7411 L .79497 .7411 L F
.78817 .67211 m .79247 .7413 L .79368 .74111 L .585 .369 .554 r
F
.78937 .67204 m .78817 .67211 L .79368 .74111 L .664 .428 .553 r
F
.79501 .74266 m .78708 .74117 L .78121 .74183 L .599 .766 .959 r
F
.78693 .67241 m .79111 .74181 L .7924 .74131 L .454 .273 .545 r
F
.78693 .67241 m .7856 .6731 L .79103 .74184 L F
.78693 .67241 m .79103 .74184 L .79111 .74181 L F
.78708 .74117 m .7839 .7388 L .78211 .74024 L .599 .766 .959 r
F
.79501 .74266 m .79063 .74114 L .78708 .74117 L F
.79063 .74114 m .7839 .7388 L .78708 .74117 L F
.78937 .67204 m .79374 .74111 L .7949 .7411 L .664 .428 .553 r
F
.79501 .74266 m .79552 .74082 L .7945 .74098 L .599 .766 .959 r
F
.78817 .67211 m .78693 .67241 L .7924 .74131 L .585 .369 .554 r
F
.78817 .67211 m .7924 .74131 L .79247 .7413 L F
.79501 .74266 m .78645 .73763 L .7839 .7388 L .599 .766 .959 r
F
.79501 .74266 m .78959 .73679 L .78645 .73763 L F
.78937 .67204 m .79368 .74111 L .79374 .74111 L .664 .428 .553 r
F
.79501 .74266 m .79311 .73636 L .78959 .73679 L .599 .766 .959 r
F
.79501 .74266 m .80881 .74183 L .80786 .74023 L F
.79501 .74266 m .80881 .74348 L .80881 .74183 L F
.7949 .7411 m .794 .74511 L .79522 .74503 L .664 .428 .553 r
F
.79374 .74111 m .794 .74511 L .7949 .7411 L F
.79374 .74111 m .79368 .74111 L .794 .74511 L F
.78708 .74117 m .78211 .74024 L .78156 .74122 L .599 .766 .959 r
F
.78708 .74117 m .78156 .74122 L .78121 .74183 L F
.7945 .74098 m .79675 .73636 L .79311 .73636 L F
.79552 .74082 m .79675 .73636 L .7945 .74098 L F
.79375 .74487 m .79421 .74937 L .79216 .74461 L .75 .494 .544 r
F
.79333 .74923 m .79252 .74909 L .7932 .74937 L .598 .766 .96 r
F
.79252 .74909 m .79421 .74937 L .79252 .74915 L .75 .494 .544 r
F
.79216 .74461 m .79421 .74937 L .79252 .74909 L F
.79421 .74937 m .7898 .75314 L .79447 .74941 L .598 .766 .96 r
F
.79333 .74923 m .79316 .74941 L .79421 .74937 L F
.79316 .74941 m .7898 .75314 L .79421 .74937 L F
.79447 .74941 m .7898 .75314 L .79332 .75356 L F
.78989 .76587 m .78986 .76127 L .80064 .76127 L .673 .452 .577 r
F
.79157 .75506 m .78988 .76117 L .80061 .76118 L .599 .766 .959 r
F
.78989 .76587 m .80064 .76127 L .80069 .76589 L .673 .452 .577 r
F
.79157 .75506 m .80061 .76118 L .79876 .75507 L .599 .766 .959 r
F
.78993 .77049 m .78989 .76587 L .80069 .76589 L .673 .452 .577 r
F
.7916 .75975 m .78989 .76587 L .80069 .76589 L .598 .766 .96 r
F
.78993 .77049 m .80069 .76589 L .80074 .77051 L .673 .452 .577 r
F
.7916 .75975 m .80069 .76589 L .79883 .75975 L .598 .766 .96 r
F
.79164 .76439 m .78993 .77049 L .80074 .77051 L .597 .767 .96 r
F
.79164 .76439 m .80074 .77051 L .79888 .76439 L F
.79332 .75356 m .7916 .75975 L .79883 .75975 L .598 .766 .96 r
F
.79332 .75356 m .79883 .75975 L .79695 .75356 L F
.79336 .75821 m .79164 .76439 L .79888 .76439 L .597 .767 .96 r
F
.79336 .75821 m .79888 .76439 L .797 .75822 L F
.79423 .74937 m .796 .7492 L .796 .7493 L .648 .416 .554 r
F
.79568 .74937 m .79332 .75356 L .79695 .75356 L .598 .766 .96 r
F
.796 .7492 m .79601 .7493 L .796 .7493 L .544 .339 .553 r
F
.79386 .74489 m .796 .7492 L .79423 .74937 L .648 .416 .554 r
F
.7969 .74889 m .79876 .75507 L .80571 .75423 L .599 .766 .959 r
F
.79674 .74913 m .79695 .75356 L .80046 .75314 L .598 .766 .96 r
F
.7969 .74889 m .80571 .75423 L .80038 .74847 L .599 .766 .959 r
F
.796 .7492 m .79721 .74902 L .79601 .7493 L .544 .339 .553 r
F
.79505 .74731 m .79568 .74937 L .79674 .74913 L .598 .766 .96 r
F
.79568 .74937 m .79695 .75356 L .79674 .74913 L F
.796 .7492 m .79719 .74882 L .79721 .74902 L .544 .339 .553 r
F
.79876 .75507 m .80061 .76118 L .81099 .75994 L .599 .766 .959 r
F
.79876 .75507 m .81099 .75994 L .80571 .75423 L F
.79695 .75356 m .79883 .75975 L .80582 .75892 L .598 .766 .96 r
F
.79695 .75356 m .80582 .75892 L .80046 .75314 L F
.80069 .76589 m .80064 .76127 L .81107 .76003 L .609 .401 .574 r
F
.80069 .76589 m .81107 .76003 L .81113 .76465 L F
.79883 .75975 m .80069 .76589 L .81113 .76465 L .598 .766 .96 r
F
.79883 .75975 m .81113 .76465 L .80582 .75892 L F
.797 .75822 m .79888 .76439 L .80587 .76356 L .597 .767 .96 r
F
.797 .75822 m .80587 .76356 L .80051 .7578 L F
.79764 .74883 m .80046 .75314 L .80361 .75232 L .598 .766 .96 r
F
.79719 .74882 m .79721 .74902 L .79721 .74902 L .424 .252 .542 r
F
.7968 .7492 m .80046 .75314 L .79764 .74883 L .598 .766 .96 r
F
.80074 .77051 m .80069 .76589 L .81113 .76465 L .609 .401 .574 r
F
.80074 .77051 m .81113 .76465 L .81119 .76927 L F
.79888 .76439 m .80074 .77051 L .81119 .76927 L .597 .767 .96 r
F
.79888 .76439 m .81119 .76927 L .80587 .76356 L F
.80038 .74847 m .80571 .75423 L .81195 .75261 L .599 .766 .959 r
F
.79843 .74848 m .80361 .75232 L .80618 .75116 L .598 .766 .96 r
F
.79719 .74882 m .79806 .74834 L .79809 .74863 L .424 .252 .542 r
F
.79809 .74863 m .80361 .75232 L .79843 .74848 L .598 .766 .96 r
F
.79764 .74883 m .79776 .7489 L .79809 .74863 L F
.79776 .7489 m .80361 .75232 L .79809 .74863 L F
.79806 .74834 m .79865 .74776 L .79868 .74815 L .231 .113 .505 r
F
.79832 .74844 m .79809 .74863 L .79843 .74848 L .598 .766 .96 r
F
.79797 .75507 m .797 .75822 L .80051 .7578 L .597 .767 .96 r
F
.80351 .74765 m .81195 .75261 L .81707 .75031 L .599 .766 .959 r
F
.80038 .74847 m .81195 .75261 L .80351 .74765 L F
.79874 .748 m .80618 .75116 L .808 .74974 L .598 .766 .96 r
F
.79852 .74851 m .80618 .75116 L .79874 .748 L F
.79868 .74815 m .79931 .75205 L .79906 .75261 L 0 0 .362 r
F
.79865 .74776 m .7987 .7481 L .79868 .74815 L F
.7987 .7481 m .79931 .75205 L .79868 .74815 L F
.80351 .74765 m .81707 .75031 L .80607 .74649 L .599 .766 .959 r
F
.79894 .74754 m .808 .74974 L .80894 .74814 L .598 .766 .96 r
F
.79865 .74776 m .79894 .74755 L .7987 .7481 L 0 0 .362 r
F
.79865 .74776 m .79906 .75261 L .79904 .75265 L F
.79831 .74366 m .7989 .74706 L .79865 .74776 L F
.79894 .74755 m .808 .74974 L .79894 .74754 L .598 .766 .96 r
F
.79874 .748 m .79916 .74808 L .79894 .74755 L F
.79916 .74808 m .808 .74974 L .79894 .74755 L F
.7989 .74706 m .79857 .74617 L .79862 .74675 L .919 .662 .17 r
F
.79505 .74731 m .79874 .748 L .79894 .74755 L .598 .766 .96 r
F
.79505 .74731 m .79894 .74755 L .79894 .74754 L F
.79806 .74834 m .79868 .74815 L .79809 .74863 L .231 .113 .505 r
F
.79505 .74731 m .79852 .74851 L .79874 .748 L .598 .766 .96 r
F
.79865 .74776 m .7989 .74706 L .79894 .74755 L 0 0 .362 r
F
.7987 .7481 m .79894 .74755 L .79931 .75205 L F
.79847 .75395 m .80051 .7578 L .80366 .75698 L .597 .767 .96 r
F
.79831 .7543 m .80051 .7578 L .79847 .75395 L F
.79715 .75419 m .80051 .7578 L .79787 .7536 L F
.80571 .75423 m .81099 .75994 L .82033 .75754 L .599 .766 .959 r
F
.80046 .75314 m .80582 .75892 L .8121 .7573 L .598 .766 .96 r
F
.79996 .75366 m .80366 .75698 L .80623 .75582 L .597 .767 .96 r
F
.79809 .74863 m .79849 .7531 L .79809 .74863 L .231 .113 .505 r
F
.79845 .75314 m .80057 .75518 L .79996 .75366 L .597 .767 .96 r
F
.79787 .7536 m .80057 .75518 L .79845 .75314 L F
.79849 .7531 m .79849 .7531 L .79809 .74863 L .231 .113 .505 r
F
.80571 .75423 m .82033 .75754 L .81195 .75261 L .599 .766 .959 r
F
.81195 .75261 m .82033 .75754 L .82801 .75411 L F
.80361 .75232 m .8121 .7573 L .81724 .75499 L .598 .766 .96 r
F
.80046 .75314 m .8121 .7573 L .80361 .75232 L F
.79962 .75283 m .80623 .75582 L .80806 .7544 L .597 .767 .96 r
F
.79809 .74863 m .79849 .7531 L .79845 .75313 L .231 .113 .505 r
F
.79809 .74863 m .79904 .75265 L .79849 .7531 L F
.79725 .74901 m .79809 .74863 L .79845 .75313 L .424 .252 .542 r
F
.79719 .74882 m .79845 .75313 L .79763 .75349 L F
.79721 .74902 m .79762 .7535 L .79757 .75352 L F
.79601 .7493 m .79721 .74902 L .79757 .75352 L .544 .339 .553 r
F
.79769 .75349 m .79715 .75419 L .79787 .7536 L .597 .767 .96 r
F
.79765 .7535 m .79715 .75419 L .79769 .75349 L F
.79683 .75384 m .79715 .75419 L .79766 .75348 L F
.79715 .75419 m .79704 .75719 L .79797 .75507 L F
.79704 .75719 m .797 .75822 L .79797 .75507 L F
.79683 .75384 m .79685 .75444 L .79715 .75419 L F
.79685 .75444 m .797 .75822 L .79715 .75419 L F
.79601 .7493 m .79757 .75352 L .79644 .75377 L .544 .339 .553 r
F
.79566 .74931 m .79562 .74938 L .79568 .74937 L .598 .766 .96 r
F
.79562 .74938 m .79332 .75356 L .79568 .74937 L F
.79449 .74936 m .79332 .75356 L .79566 .74931 L F
.79423 .74937 m .796 .7493 L .79636 .75379 L .648 .416 .554 r
F
.79677 .75378 m .7958 .7543 L .79683 .75384 L .597 .767 .96 r
F
.7966 .75378 m .7958 .7543 L .79677 .75378 L F
.7957 .75394 m .7958 .7543 L .79671 .75371 L F
.7958 .7543 m .797 .75822 L .79683 .75384 L F
.79423 .74937 m .79636 .75379 L .79469 .75386 L .648 .416 .554 r
F
.79252 .74915 m .79421 .74937 L .79457 .75386 L .75 .494 .544 r
F
.79573 .75405 m .79336 .75821 L .797 .75822 L .597 .767 .96 r
F
.79564 .75404 m .79336 .75821 L .79573 .75405 L F
.79566 .75382 m .79447 .75422 L .7957 .75394 L F
.79457 .75386 m .79447 .75422 L .79566 .75382 L F
.79447 .75422 m .79336 .75821 L .79564 .75404 L F
.79543 .754 m .79564 .75404 L .7957 .75394 L F
.79447 .75422 m .79564 .75404 L .79543 .754 L F
.78462 .75422 m .78988 .76117 L .79157 .75506 L .599 .766 .959 r
F
.7898 .75314 m .7916 .75975 L .79332 .75356 L .598 .766 .96 r
F
.77944 .76462 m .78986 .76127 L .78989 .76587 L .733 .5 .576 r
F
.77944 .76462 m .77942 .76001 L .78986 .76127 L F
.78462 .75422 m .7795 .75992 L .78988 .76117 L .599 .766 .959 r
F
.7846 .75891 m .78989 .76587 L .7916 .75975 L .598 .766 .96 r
F
.7898 .75314 m .7846 .75891 L .7916 .75975 L F
.78984 .75779 m .79164 .76439 L .79336 .75821 L .597 .767 .96 r
F
.79873 .82416 m .79812 .82642 L .80195 .82592 L .654 .816 .961 r
F
.80128 .82382 m .80195 .82592 L .80565 .82499 L F
.79873 .82416 m .80195 .82592 L .80128 .82382 L F
.80128 .82382 m .80565 .82499 L .80375 .8232 L F
.79934 .82188 m .79873 .82416 L .80128 .82382 L F
.80114 .82197 m .80128 .82382 L .80375 .8232 L F
.80375 .8232 m .80565 .82499 L .80896 .8237 L F
.80375 .8232 m .80658 .82347 L .80597 .82234 L F
.80658 .82347 m .80896 .8237 L .80612 .82241 L F
.80658 .82347 m .80612 .82241 L .80597 .82234 L F
.79929 .75276 m .79996 .75366 L .79962 .75283 L .597 .767 .96 r
F
.79601 .7493 m .79644 .75377 L .796 .7493 L .544 .339 .553 r
F
.79644 .75377 m .79644 .75378 L .796 .7493 L F
.796 .7493 m .79644 .75378 L .79636 .75379 L F
.79721 .74902 m .79763 .75349 L .79721 .74902 L .424 .252 .542 r
F
.79763 .75349 m .79762 .7535 L .79721 .74902 L F
.7951 .75198 m .79844 .75313 L .79929 .75276 L .597 .767 .96 r
F
.79844 .75313 m .79996 .75366 L .79929 .75276 L F
.80361 .75232 m .81724 .75499 L .80618 .75116 L .598 .766 .96 r
F
.79938 .75224 m .80806 .7544 L .809 .75281 L .597 .767 .96 r
F
.79809 .74863 m .79868 .74815 L .79904 .75265 L .231 .113 .505 r
F
.7951 .75198 m .79962 .75283 L .79938 .75224 L .597 .767 .96 r
F
.79962 .75283 m .80806 .7544 L .79938 .75224 L F
.79894 .74754 m .79928 .752 L .79894 .74755 L .919 .662 .17 r
F
.79928 .752 m .79929 .752 L .79894 .74755 L F
.79894 .74755 m .79929 .752 L .79931 .75205 L F
.79894 .74754 m .79898 .75125 L .79928 .752 L F
.81195 .75261 m .82801 .75411 L .81707 .75031 L .599 .766 .959 r
F
.80618 .75116 m .81724 .75499 L .82091 .75215 L .598 .766 .96 r
F
.80618 .75116 m .82091 .75215 L .808 .74974 L F
.7997 .75171 m .809 .75281 L .809 .75116 L .597 .767 .96 r
F
.7951 .75198 m .80064 .75231 L .7997 .75171 L F
.80064 .75231 m .809 .75281 L .7997 .75171 L F
.79906 .75261 m .79907 .75258 L .79912 .75332 L 0 0 .362 r
F
.79907 .75258 m .79931 .75205 L .79912 .75332 L F
.80366 .82182 m .80375 .8232 L .80597 .82234 L .654 .816 .961 r
F
.80186 .82141 m .80327 .82275 L .80366 .82182 L F
.80327 .82275 m .80375 .8232 L .80366 .82182 L F
.79912 .75332 m .79931 .75205 L .80476 .81921 L 0 0 .362 r
F
.79849 .7531 m .80446 .81987 L .79849 .7531 L .231 .113 .505 r
F
.80386 .82135 m .80597 .82234 L .80607 .82228 L .654 .816 .961 r
F
.80319 .82107 m .80385 .82137 L .80386 .82135 L F
.80385 .82137 m .80597 .82234 L .80386 .82135 L F
.80318 .82108 m .80385 .82138 L .80319 .82107 L F
.80385 .82138 m .80597 .82234 L .80385 .82137 L F
.80385 .82138 m .80385 .82137 L .80319 .82107 L F
.79906 .75261 m .80474 .81924 L .79904 .75265 L 0 0 .362 r
F
.80327 .82099 m .80607 .82228 L .80558 .82115 L .654 .816 .961 r
F
.80296 .82097 m .80319 .82107 L .80327 .82099 L F
.80319 .82107 m .80607 .82228 L .80327 .82099 L F
.79849 .7531 m .80446 .81988 L .79845 .75313 L .231 .113 .505 r
F
.80306 .82119 m .80597 .82234 L .80318 .82108 L .654 .816 .961 r
F
.80205 .82145 m .80264 .82159 L .80273 .82106 L F
.80264 .82159 m .80597 .82234 L .80306 .82119 L F
.80264 .82159 m .80306 .82119 L .80273 .82106 L F
.79849 .7531 m .79904 .75265 L .80449 .81984 L .231 .113 .505 r
F
.80474 .81924 m .80474 .81924 L .79904 .75265 L 0 0 .362 r
F
.79904 .75265 m .80474 .81924 L .80449 .81984 L F
.79912 .75332 m .80476 .81921 L .80474 .81924 L F
.79929 .752 m .80445 .81848 L .79931 .75205 L .919 .662 .17 r
F
.80387 .82045 m .80543 .82078 L .8053 .82049 L .654 .816 .961 r
F
.80525 .82036 m .80856 .82057 L .80784 .8202 L F
.80387 .82045 m .8053 .82049 L .80525 .82036 L F
.8053 .82049 m .80856 .82057 L .80525 .82036 L F
.79857 .74617 m .79861 .74674 L .79862 .74675 L .921 .628 .471 r
F
.7989 .74706 m .79862 .74675 L .79894 .74754 L .919 .662 .17 r
F
.7989 .74706 m .79894 .74754 L .79894 .74755 L F
.79856 .74309 m .7989 .74706 L .79831 .74366 L 0 0 .362 r
F
.79947 .74528 m .80351 .74765 L .79909 .74434 L .599 .766 .959 r
F
.80787 .74507 m .8207 .74748 L .82261 .7443 L F
.80607 .74649 m .8207 .74748 L .80787 .74507 L F
.80787 .74507 m .82261 .7443 L .80881 .74348 L F
.7994 .7465 m .80894 .74649 L .80798 .74488 L .598 .766 .96 r
F
.79886 .7466 m .79886 .7466 L .7989 .74706 L 0 0 .362 r
F
.79856 .74309 m .79886 .7466 L .79886 .7466 L F
.79856 .74309 m .79858 .74306 L .79886 .7466 L F
.79858 .74306 m .79857 .74617 L .7989 .74706 L .919 .662 .17 r
F
.79857 .74617 m .79753 .74546 L .79758 .74608 L .921 .628 .471 r
F
.79505 .74731 m .79912 .74707 L .79849 .74667 L .598 .766 .96 r
F
.79505 .74731 m .79849 .74667 L .79794 .74631 L F
.80607 .74649 m .81707 .75031 L .8207 .74748 L .599 .766 .959 r
F
.80062 .74698 m .80894 .74814 L .80894 .74649 L .598 .766 .96 r
F
.79505 .74731 m .80341 .74781 L .80062 .74698 L F
.80341 .74781 m .80894 .74814 L .80062 .74698 L F
.7951 .75198 m .79899 .75125 L .79836 .75085 L .597 .767 .96 r
F
.80273 .82106 m .80306 .82119 L .80296 .82097 L .654 .816 .961 r
F
.80306 .82119 m .80318 .82108 L .80296 .82097 L F
.80186 .82141 m .80205 .82145 L .80273 .82106 L F
.79763 .75349 m .80384 .82044 L .79762 .7535 L .424 .252 .542 r
F
.80384 .82044 m .80384 .82044 L .79762 .7535 L F
.80296 .82097 m .80318 .82108 L .80319 .82107 L .654 .816 .961 r
F
.80095 .82163 m .80375 .8232 L .80186 .82141 L F
.80062 .82172 m .80066 .82174 L .80095 .82163 L F
.80066 .82174 m .80375 .8232 L .80095 .82163 L F
.79861 .82929 m .79811 .82645 L .80196 .82595 L .671 .445 .569 r
F
.80246 .82879 m .80196 .82595 L .80567 .82502 L .609 .403 .577 r
F
.79861 .82929 m .80196 .82595 L .80246 .82879 L .671 .445 .569 r
F
.80113 .82458 m .80179 .82669 L .80428 .82607 L .653 .817 .962 r
F
.80618 .82786 m .80567 .82502 L .80901 .82372 L .537 .355 .582 r
F
.80246 .82879 m .80567 .82502 L .80618 .82786 L .609 .403 .577 r
F
.80237 .82427 m .80428 .82607 L .8065 .8252 L .653 .817 .962 r
F
.80113 .82458 m .80428 .82607 L .80237 .82427 L F
.80347 .82384 m .8065 .8252 L .80348 .82383 L F
.80237 .82427 m .80289 .82438 L .80347 .82384 L F
.80289 .82438 m .8065 .8252 L .80347 .82384 L F
.80348 .82383 m .8065 .8252 L .80832 .82414 L F
.80348 .82383 m .80421 .82388 L .80439 .8233 L F
.80421 .82388 m .80832 .82414 L .80444 .82331 L F
.80421 .82388 m .80444 .82331 L .80439 .8233 L F
.80597 .82234 m .80896 .8237 L .81167 .82213 L .654 .816 .961 r
F
.80445 .8233 m .80832 .82414 L .8096 .82297 L .653 .817 .962 r
F
.80439 .8233 m .80444 .82331 L .80445 .8233 L F
.80444 .82331 m .80832 .82414 L .80445 .8233 L F
.80296 .82097 m .80777 .82129 L .80415 .82051 L .654 .816 .961 r
F
.80318 .82085 m .80415 .82051 L .80387 .82045 L F
.80296 .82097 m .80415 .82051 L .80318 .82085 L F
.79671 .75371 m .7966 .75378 L .79677 .75378 L .597 .767 .96 r
F
.79644 .75377 m .79757 .75352 L .80301 .82091 L .544 .339 .553 r
F
.80324 .82372 m .80237 .82427 L .80348 .82383 L .653 .817 .962 r
F
.80219 .82409 m .80237 .82427 L .80324 .82372 L F
.80201 .82416 m .80334 .82502 L .80211 .82538 L .544 .339 .553 r
F
.80179 .82134 m .80285 .82386 L .80201 .82416 L F
.80285 .82386 m .80334 .82502 L .80201 .82416 L F
.79984 .82475 m .79922 .82702 L .80179 .82669 L .653 .817 .962 r
F
.79984 .82475 m .80179 .82669 L .80113 .82458 L F
.8002 .82446 m .80211 .82538 L .80029 .82555 L .648 .416 .554 r
F
.80066 .82174 m .80079 .82217 L .80114 .82197 L .654 .816 .961 r
F
.80079 .82217 m .80128 .82382 L .80114 .82197 L F
.80062 .82172 m .80063 .82175 L .80066 .82174 L F
.80063 .82175 m .80128 .82382 L .80066 .82174 L F
.79934 .82188 m .80128 .82382 L .80062 .82172 L F
.79625 .82418 m .79812 .82642 L .79869 .8243 L F
.79859 .82416 m .79869 .8243 L .79873 .82416 L F
.79625 .82418 m .79869 .8243 L .79859 .82416 L F
.79369 .75703 m .78984 .75779 L .79336 .75821 L .597 .767 .96 r
F
.7915 .74874 m .79252 .74915 L .79287 .75359 L .848 .57 .516 r
F
.79447 .75422 m .79274 .75538 L .79369 .75703 L .597 .767 .96 r
F
.79425 .75413 m .79274 .75538 L .79447 .75422 L F
.79274 .75538 m .78984 .75779 L .79369 .75703 L F
.79335 .75391 m .79246 .75489 L .79457 .75386 L F
.79246 .75489 m .78984 .75779 L .79274 .75538 L F
.79246 .75489 m .79274 .75538 L .79457 .75386 L F
.7915 .74874 m .79287 .75359 L .79192 .75321 L .848 .57 .516 r
F
.79421 .74937 m .79468 .75386 L .79457 .75386 L .648 .416 .554 r
F
.79252 .74915 m .79297 .75361 L .79287 .75359 L .75 .494 .544 r
F
.79421 .74937 m .79423 .74937 L .79469 .75386 L .648 .416 .554 r
F
.79421 .74937 m .79469 .75386 L .79468 .75386 L F
.79252 .74915 m .79457 .75386 L .79297 .75361 L .75 .494 .544 r
F
.79131 .74862 m .79103 .7485 L .79113 .74868 L .598 .766 .96 r
F
.7908 .74811 m .78219 .74973 L .79113 .74868 L F
.79087 .74824 m .7915 .74874 L .79186 .75319 L .941 .646 .452 r
F
.79314 .75414 m .78667 .75697 L .78984 .75779 L .597 .767 .96 r
F
.79298 .75403 m .78667 .75697 L .79314 .75414 L F
.79258 .75347 m .79239 .75358 L .79344 .75381 L F
.79189 .75388 m .79061 .75464 L .79218 .7544 L F
.79061 .75464 m .78667 .75697 L .79055 .75516 L F
.79061 .75464 m .79055 .75516 L .79218 .7544 L F
.79005 .74761 m .78121 .74814 L .7905 .74812 L .598 .766 .96 r
F
.79052 .74796 m .7905 .74812 L .79074 .74812 L F
.79005 .74761 m .7905 .74812 L .79052 .74796 L F
.79062 .74694 m .79055 .74764 L .79056 .74768 L 0 0 .196 r
F
.79055 .74764 m .79056 .74768 L .79056 .74768 L .966 .687 .262 r
F
.79088 .75158 m .79093 .75221 L .79091 .75218 L F
.79055 .74764 m .79093 .75221 L .79093 .75221 L F
.79055 .74764 m .79122 .75271 L .79093 .75221 L F
.79386 .74489 m .79423 .74937 L .79421 .74937 L .648 .416 .554 r
F
.79049 .7437 m .79051 .74373 L .79086 .74822 L .966 .687 .262 r
F
.79086 .74822 m .79086 .74822 L .79087 .74824 L F
.79049 .7437 m .79086 .74822 L .79086 .74822 L F
.78222 .74507 m .7732 .7503 L .78407 .74649 L .599 .766 .959 r
F
.7905 .74758 m .78117 .74649 L .78121 .74814 L .598 .766 .96 r
F
.79062 .74694 m .79056 .74768 L .79063 .74708 L 0 0 .196 r
F
.79028 .74258 m .79055 .74764 L .79062 .74694 L F
.79057 .74758 m .79018 .74702 L .7905 .74758 L .598 .766 .96 r
F
.79111 .74418 m .79115 .74421 L .7915 .74874 L .941 .646 .452 r
F
.79375 .74487 m .79386 .74489 L .79421 .74937 L .75 .494 .544 r
F
.79136 .74607 m .79062 .74694 L .79063 .74707 L .159 .061 .485 r
F
.79505 .74731 m .79065 .74705 L .79057 .74758 L .598 .766 .96 r
F
.79505 .74731 m .79057 .74758 L .79074 .74812 L F
.79065 .74785 m .79052 .74796 L .79074 .74812 L F
.79055 .74764 m .79076 .74803 L .79056 .74768 L .966 .687 .262 r
F
.79057 .74758 m .79056 .74768 L .79065 .74785 L .598 .766 .96 r
F
.79056 .74768 m .79052 .74796 L .79065 .74785 L F
.79056 .74768 m .79087 .74824 L .79122 .75271 L .966 .687 .262 r
F
.79076 .74803 m .79087 .74824 L .79056 .74768 L F
.79087 .74824 m .79186 .75319 L .79126 .75274 L .941 .646 .452 r
F
.7915 .74874 m .79192 .75321 L .79186 .75319 L .848 .57 .516 r
F
.78664 .75232 m .7846 .75891 L .7898 .75314 L .598 .766 .96 r
F
.7951 .75198 m .79075 .75349 L .79061 .75464 L .597 .767 .96 r
F
.79087 .74824 m .79126 .75274 L .79122 .75271 L .941 .646 .452 r
F
.77835 .7526 m .7795 .75992 L .78462 .75422 L .599 .766 .959 r
F
.77835 .7526 m .77013 .75751 L .7795 .75992 L F
.78664 .75232 m .77829 .75728 L .7846 .75891 L .598 .766 .96 r
F
.78404 .75116 m .77829 .75728 L .78664 .75232 L F
.7951 .75198 m .78949 .75303 L .78807 .75442 L .597 .767 .96 r
F
.7732 .7503 m .77013 .75751 L .77835 .7526 L .599 .766 .959 r
F
.78404 .75116 m .77311 .75497 L .77829 .75728 L .598 .766 .96 r
F
.78273 .75429 m .78124 .7528 L .78222 .75439 L .597 .767 .96 r
F
.7951 .75198 m .78759 .75242 L .78273 .75429 L F
.78759 .75242 m .78124 .7528 L .78273 .75429 L F
.79239 .75358 m .79298 .75403 L .79344 .75381 L F
.79344 .75381 m .79298 .75403 L .79314 .75414 L F
.7951 .75198 m .79258 .75347 L .79344 .75381 L F
.79239 .75358 m .79189 .75388 L .79298 .75403 L F
.79189 .75388 m .79218 .7544 L .79298 .75403 L F
.7981 .8219 m .79873 .82416 L .79934 .82188 L .654 .816 .961 r
F
.79759 .82253 m .79625 .82418 L .79859 .82416 L F
.79698 .82175 m .79625 .82418 L .79759 .82253 L F
.79712 .82177 m .79759 .82253 L .7981 .8219 L F
.79698 .82175 m .79759 .82253 L .79712 .82177 L F
.79063 .74707 m .79091 .75218 L .79098 .7516 L 0 0 .196 r
F
.79063 .74708 m .79091 .75218 L .79063 .74707 L F
.79065 .74705 m .79063 .74707 L .79057 .74758 L .598 .766 .96 r
F
.79063 .74708 m .79056 .74768 L .79091 .75218 L 0 0 .196 r
F
.78219 .74973 m .77311 .75497 L .78404 .75116 L .598 .766 .96 r
F
.7951 .75198 m .78577 .75142 L .78124 .7528 L .597 .767 .96 r
F
.78577 .75142 m .7812 .75115 L .78122 .75212 L F
.78577 .75142 m .78122 .75212 L .78124 .7528 L F
.79421 .74937 m .79421 .74937 L .79252 .74909 L .75 .494 .544 r
F
.79505 .74731 m .79224 .74898 L .79252 .74909 L .598 .766 .96 r
F
.79505 .74731 m .79252 .74909 L .79333 .74923 L F
.79505 .74731 m .7908 .74811 L .79103 .7485 L F
.794 .74511 m .79272 .74539 L .79276 .7458 L .585 .369 .554 r
F
.79505 .74731 m .79137 .7486 L .79224 .74898 L .598 .766 .96 r
F
.79505 .74731 m .79103 .7485 L .79131 .74862 L F
.78755 .74527 m .78314 .7449 L .78407 .74649 L .599 .766 .959 r
F
.78314 .7449 m .78238 .74519 L .78407 .74649 L F
.78222 .74507 m .7695 .74747 L .7732 .7503 L F
.78125 .74348 m .7695 .74747 L .78222 .74507 L F
.7863 .74679 m .78208 .74488 L .78117 .74649 L .598 .766 .96 r
F
.79505 .74731 m .79113 .74658 L .79065 .74705 L F
.79137 .7486 m .7915 .74869 L .79224 .74898 L F
.79136 .74607 m .79138 .74633 L .79138 .74633 L .159 .061 .485 r
F
.79075 .7468 m .79069 .74687 L .7902 .74319 L .966 .687 .262 r
F
.79049 .7437 m .79075 .7468 L .7902 .74319 L F
.79103 .74184 m .79062 .74694 L .79136 .74607 L .159 .061 .485 r
F
.79032 .74254 m .79062 .74694 L .79103 .74184 L F
.78906 .74378 m .78314 .7449 L .78755 .74527 L .599 .766 .959 r
F
.79032 .74254 m .79028 .74258 L .79062 .74694 L .159 .061 .485 r
F
.79021 .74316 m .79055 .74764 L .79028 .74258 L 0 0 .196 r
F
.79021 .74316 m .7902 .74319 L .79055 .74764 L F
.79086 .74653 m .78387 .74345 L .78208 .74488 L .598 .766 .96 r
F
.79136 .74607 m .79063 .74707 L .79138 .74633 L .159 .061 .485 r
F
.79505 .74731 m .79177 .74618 L .79086 .74653 L .598 .766 .96 r
F
.7915 .74869 m .79252 .74915 L .7915 .74874 L .848 .57 .516 r
F
.79251 .74909 m .79252 .74915 L .7915 .74869 L F
.79272 .74539 m .79136 .74607 L .79138 .74633 L .454 .273 .545 r
F
.79505 .74731 m .79258 .74586 L .79177 .74618 L .598 .766 .96 r
F
.79272 .74539 m .79138 .74633 L .79264 .74584 L .454 .273 .545 r
F
.79272 .74539 m .79275 .7458 L .79276 .7458 L F
.794 .74511 m .79276 .7458 L .79391 .74562 L .585 .369 .554 r
F
.7924 .74131 m .79136 .74607 L .79272 .74539 L .454 .273 .545 r
F
.79111 .74181 m .79136 .74607 L .7924 .74131 L F
.79111 .74181 m .79103 .74184 L .79136 .74607 L F
.79258 .74586 m .7896 .74143 L .78644 .74227 L .598 .766 .96 r
F
.79505 .74731 m .79354 .74568 L .79258 .74586 L F
.79457 .75386 m .79425 .75413 L .79447 .75422 L .597 .767 .96 r
F
.79287 .75359 m .79988 .82164 L .79826 .82158 L .75 .494 .544 r
F
.79938 .82174 m .79934 .82188 L .80019 .82165 L .654 .816 .961 r
F
.79998 .82164 m .80019 .82165 L .80056 .82154 L F
.79938 .82174 m .80019 .82165 L .79998 .82164 L F
.79297 .75361 m .79989 .82164 L .79287 .75359 L .75 .494 .544 r
F
.8011 .82449 m .79984 .82475 L .80113 .82458 L .653 .817 .962 r
F
.79989 .82164 m .79988 .82164 L .79287 .75359 L .75 .494 .544 r
F
.79488 .82933 m .79811 .82645 L .79861 .82929 L .731 .485 .556 r
F
.79488 .82933 m .79438 .82649 L .79811 .82645 L F
.79625 .82418 m .79441 .82645 L .79812 .82642 L .654 .816 .961 r
F
.79859 .82476 m .79673 .82705 L .79922 .82702 L .653 .817 .962 r
F
.79747 .82461 m .79673 .82705 L .79856 .8248 L F
.79846 .82474 m .79856 .8248 L .79859 .82476 L F
.79747 .82461 m .79856 .8248 L .79846 .82474 L F
.79698 .82175 m .79604 .82244 L .79625 .82418 L .654 .816 .961 r
F
.79604 .82244 m .79402 .82389 L .79583 .82413 L F
.79604 .82244 m .79583 .82413 L .79625 .82418 L F
.79607 .82146 m .79402 .82389 L .79604 .82244 L F
.79615 .82149 m .79604 .82244 L .79698 .82175 L F
.79607 .82146 m .79604 .82244 L .79615 .82149 L F
.79093 .75221 m .79658 .82089 L .79091 .75218 L .966 .687 .262 r
F
.79658 .82089 m .79658 .82089 L .79091 .75218 L F
.79091 .75218 m .79658 .82089 L .79628 .82041 L F
.79093 .75221 m .79659 .82091 L .79658 .82089 L F
.79093 .75221 m .79659 .82091 L .79093 .75221 L F
.79093 .75221 m .79122 .75271 L .79659 .82091 L F
.7732 .7503 m .76241 .75408 L .77013 .75751 L .599 .766 .959 r
F
.78219 .74973 m .76939 .75214 L .77311 .75497 L .598 .766 .96 r
F
.78121 .74814 m .76939 .75214 L .78219 .74973 L F
.78577 .75142 m .78211 .74956 L .7812 .75115 L .597 .767 .96 r
F
.79063 .74707 m .79098 .7516 L .79099 .75157 L 0 0 .196 r
F
.79062 .74694 m .79063 .74707 L .79063 .74707 L F
.79063 .74707 m .79098 .7516 L .79063 .74707 L F
.79063 .74705 m .78957 .74629 L .7863 .74679 L .598 .766 .96 r
F
.79065 .74705 m .79063 .74704 L .79063 .74705 L F
.79063 .74704 m .78957 .74629 L .79063 .74705 L F
.79086 .74822 m .7915 .74874 L .79087 .74824 L .941 .646 .452 r
F
.79137 .7486 m .79131 .74862 L .7915 .74869 L .598 .766 .96 r
F
.79149 .74869 m .7915 .74874 L .79086 .74822 L .941 .646 .452 r
F
.79086 .74821 m .79087 .74824 L .79076 .74803 L .966 .687 .262 r
F
.79086 .74822 m .79087 .74824 L .79086 .74821 L F
.79138 .74633 m .79063 .74707 L .79099 .75157 L .159 .061 .485 r
F
.79138 .74633 m .79099 .75157 L .79169 .75087 L F
.7951 .75198 m .78926 .75089 L .78577 .75142 L .597 .767 .96 r
F
.78926 .75089 m .78211 .74956 L .78577 .75142 L F
.79457 .75386 m .80169 .82136 L .79998 .82164 L .648 .416 .554 r
F
.79941 .82162 m .79834 .8216 L .79934 .82187 L .654 .816 .961 r
F
.79297 .75361 m .79457 .75386 L .79998 .82164 L .75 .494 .544 r
F
.79297 .75361 m .79998 .82164 L .79989 .82164 L F
.79995 .81961 m .79835 .82159 L .79941 .82162 L .654 .816 .961 r
F
.79835 .82159 m .79834 .8216 L .79941 .82162 L F
.79992 .82445 m .79984 .82475 L .8011 .82449 L .653 .817 .962 r
F
.79992 .82445 m .79859 .82476 L .79984 .82475 L F
.79989 .82164 m .79998 .82164 L .8002 .82446 L .75 .494 .544 r
F
.79989 .82164 m .8002 .82446 L .80018 .82446 L F
.79934 .82187 m .7981 .8219 L .79934 .82188 L .654 .816 .961 r
F
.79834 .8216 m .7981 .8219 L .79934 .82187 L F
.79813 .82186 m .79698 .82175 L .7981 .8219 L F
.79186 .75319 m .79821 .82157 L .79723 .82131 L .848 .57 .516 r
F
.79192 .75321 m .79821 .82157 L .79186 .75319 L F
.7981 .8219 m .79759 .82253 L .79873 .82416 L .654 .816 .961 r
F
.79759 .82253 m .79859 .82416 L .79873 .82416 L F
.79821 .82157 m .79847 .8244 L .79821 .82157 L .848 .57 .516 r
F
.79847 .8244 m .79847 .82439 L .79821 .82157 L F
.79821 .82157 m .79821 .82157 L .79186 .75319 L F
.79122 .75271 m .7972 .82129 L .79659 .82091 L .941 .646 .452 r
F
.79126 .75274 m .7972 .82129 L .79122 .75271 L F
.79743 .82143 m .79698 .82175 L .79813 .82186 L .654 .816 .961 r
F
.79743 .82143 m .79616 .82142 L .79698 .82175 L F
.79687 .82108 m .79616 .82142 L .79743 .82143 L F
.7972 .82129 m .7972 .82129 L .79122 .75271 L .941 .646 .452 r
F
.79616 .82142 m .79542 .82105 L .79607 .82146 L .654 .816 .961 r
F
.79126 .75274 m .79186 .75319 L .79723 .82131 L .941 .646 .452 r
F
.7972 .82129 m .79723 .82131 L .79752 .82494 L F
.79126 .75274 m .79723 .82131 L .7972 .82129 L F
.79687 .82108 m .79623 .82079 L .79616 .82142 L .654 .816 .961 r
F
.79192 .75321 m .79287 .75359 L .79826 .82158 L .848 .57 .516 r
F
.79881 .82449 m .79747 .82461 L .79859 .82476 L .653 .817 .962 r
F
.79821 .82157 m .79826 .82158 L .79848 .8244 L .848 .57 .516 r
F
.79821 .82157 m .79848 .8244 L .79847 .8244 L F
.79988 .82164 m .80017 .82446 L .79826 .82158 L .75 .494 .544 r
F
.79848 .8244 m .79747 .82461 L .79881 .82449 L .653 .817 .962 r
F
.79796 .82426 m .7978 .82438 L .79848 .8244 L F
.7978 .82438 m .79747 .82461 L .79848 .8244 L F
.79859 .82476 m .79922 .82702 L .79984 .82475 L F
.79848 .8244 m .80029 .82555 L .79856 .82533 L .75 .494 .544 r
F
.79826 .82158 m .79972 .82444 L .79848 .8244 L F
.79887 .82441 m .79848 .8244 L .79881 .82449 L .653 .817 .962 r
F
.79887 .82441 m .79859 .82476 L .79992 .82445 L F
.79972 .82444 m .80029 .82555 L .79848 .8244 L .75 .494 .544 r
F
.79796 .82426 m .79746 .82412 L .79783 .82435 L .653 .817 .962 r
F
.79723 .82131 m .79856 .82533 L .79752 .82494 L .848 .57 .516 r
F
.7975 .82138 m .79723 .82131 L .79743 .82143 L .654 .816 .961 r
F
.79834 .8216 m .79743 .82143 L .79813 .82186 L F
.7975 .82138 m .79743 .82143 L .79834 .8216 L F
.79821 .82157 m .79856 .82533 L .79723 .82131 L .848 .57 .516 r
F
.80017 .82446 m .79972 .82444 L .79826 .82158 L .75 .494 .544 r
F
.79989 .82164 m .80018 .82446 L .79988 .82164 L F
.80018 .82446 m .80017 .82446 L .79988 .82164 L F
.80019 .82165 m .79934 .82188 L .8006 .82166 L .654 .816 .961 r
F
.79998 .82164 m .80198 .82416 L .8002 .82446 L .648 .416 .554 r
F
.80046 .82246 m .79796 .82426 L .79848 .8244 L .653 .817 .962 r
F
.80046 .82246 m .79848 .8244 L .79887 .82441 L F
.79847 .8244 m .79848 .8244 L .79856 .82533 L .848 .57 .516 r
F
.79192 .75321 m .79826 .82158 L .79821 .82157 L F
.79995 .81961 m .79687 .82108 L .79723 .82131 L .654 .816 .961 r
F
.79995 .81961 m .79723 .82131 L .7975 .82138 L F
.79995 .81961 m .79634 .82076 L .79687 .82108 L F
.79634 .82076 m .79623 .82079 L .79687 .82108 L F
.79623 .82079 m .79542 .82105 L .79616 .82142 L F
.79098 .7516 m .79091 .75218 L .79628 .82041 L 0 0 .196 r
F
.79616 .82142 m .79615 .82149 L .79698 .82175 L .654 .816 .961 r
F
.79098 .7516 m .79628 .82041 L .79628 .82038 L 0 0 .196 r
F
.79098 .7516 m .79628 .82038 L .79099 .75157 L F
.79628 .82038 m .79628 .82038 L .79099 .75157 L F
.79099 .75157 m .79628 .82038 L .79362 .78498 L F
.79628 .82038 m .79629 .82035 L .79362 .78498 L F
.79362 .78498 m .79629 .82035 L .79636 .81979 L F
.79995 .81961 m .7958 .82039 L .79542 .82105 L .654 .816 .961 r
F
.7958 .82039 m .79508 .82053 L .79533 .82091 L F
.7958 .82039 m .79533 .82091 L .79542 .82105 L F
.79681 .82372 m .79681 .82372 L .79658 .82089 L .966 .687 .262 r
F
.7972 .82129 m .79745 .82412 L .7972 .82129 L .941 .646 .452 r
F
.79659 .82091 m .7968 .82169 L .79671 .82244 L F
.7968 .82169 m .79745 .82412 L .79671 .82244 L F
.79671 .82244 m .79745 .82412 L .79681 .82373 L F
.7972 .82129 m .79745 .82412 L .79659 .82091 L F
.78926 .75089 m .7839 .74812 L .78211 .74956 L .597 .767 .96 r
F
.79138 .74633 m .79169 .75087 L .79174 .75083 L .159 .061 .485 r
F
.79138 .74633 m .79169 .75087 L .79138 .74633 L F
.7951 .75198 m .79111 .75061 L .78926 .75089 L .597 .767 .96 r
F
.79111 .75061 m .7839 .74812 L .78926 .75089 L F
.79505 .74731 m .79333 .74923 L .79447 .74941 L .598 .766 .96 r
F
.794 .74511 m .79403 .7456 L .79404 .7456 L .585 .369 .554 r
F
.794 .74511 m .79391 .74562 L .79403 .7456 L F
.79368 .74111 m .79272 .74539 L .794 .74511 L F
.79247 .7413 m .79272 .74539 L .79368 .74111 L F
.79247 .7413 m .7924 .74131 L .79272 .74539 L F
.79347 .7456 m .79314 .741 L .7896 .74143 L .598 .766 .96 r
F
.79505 .74731 m .79453 .7456 L .79347 .7456 L F
.79522 .74503 m .794 .74511 L .79404 .7456 L .664 .428 .553 r
F
.79522 .74503 m .79404 .7456 L .79526 .74559 L F
.79453 .7456 m .79314 .741 L .79347 .7456 L .598 .766 .96 r
F
.79995 .81961 m .79628 .81987 L .7958 .82039 L .654 .816 .961 r
F
.79995 .81961 m .7975 .82138 L .79834 .8216 L F
.79995 .81961 m .79938 .82174 L .80056 .82154 L F
.80222 .82412 m .80113 .82458 L .80237 .82427 L .653 .817 .962 r
F
.80208 .82414 m .80113 .82458 L .80222 .82412 L F
.80179 .82134 m .80062 .82172 L .80186 .82141 L .654 .816 .961 r
F
.79468 .75386 m .80169 .82136 L .79457 .75386 L .648 .416 .554 r
F
.80169 .82136 m .80169 .82136 L .79457 .75386 L F
.80056 .82154 m .80062 .82172 L .80179 .82134 L .654 .816 .961 r
F
.80198 .82416 m .80198 .82416 L .80169 .82136 L .648 .416 .554 r
F
.80169 .82136 m .80169 .82136 L .79457 .75386 L F
.80198 .82416 m .80169 .82136 L .80169 .82136 L F
.79636 .75379 m .80294 .82094 L .80179 .82134 L .544 .339 .553 r
F
.80104 .82432 m .80109 .82448 L .80201 .82416 L .653 .817 .962 r
F
.79468 .75386 m .79469 .75386 L .80198 .82416 L .648 .416 .554 r
F
.80198 .82416 m .80198 .82416 L .80211 .82538 L F
.79468 .75386 m .80198 .82416 L .80198 .82416 L F
.80109 .82448 m .80113 .82458 L .80208 .82414 L .653 .817 .962 r
F
.80201 .82416 m .80208 .82414 L .80219 .82409 L F
.80109 .82448 m .80208 .82414 L .80201 .82416 L F
.80179 .82134 m .80186 .82141 L .80221 .82127 L .654 .816 .961 r
F
.7957 .75394 m .79564 .75404 L .79573 .75405 L .597 .767 .96 r
F
.79469 .75386 m .79636 .75379 L .80211 .82538 L .648 .416 .554 r
F
.79644 .75378 m .80294 .82093 L .79636 .75379 L .544 .339 .553 r
F
.80294 .82093 m .80321 .82373 L .80294 .82094 L F
.80321 .82373 m .80321 .82373 L .80294 .82094 L F
.80169 .82136 m .80198 .82416 L .80169 .82136 L .648 .416 .554 r
F
.8006 .82166 m .79934 .82188 L .80062 .82172 L .654 .816 .961 r
F
.80056 .82154 m .80019 .82165 L .8006 .82166 L F
.80169 .82136 m .80198 .82416 L .79998 .82164 L .648 .416 .554 r
F
.80294 .82093 m .80301 .82091 L .80323 .82373 L .544 .339 .553 r
F
.80294 .82093 m .80323 .82373 L .80321 .82373 L F
.8029 .82095 m .80179 .82134 L .80296 .82097 L .654 .816 .961 r
F
.80179 .82134 m .80221 .82127 L .80296 .82097 L F
.80294 .82094 m .80334 .82502 L .80179 .82134 L .544 .339 .553 r
F
.80323 .82373 m .80423 .82455 L .80334 .82502 L .424 .252 .542 r
F
.80301 .82091 m .80384 .82338 L .80323 .82373 L F
.80324 .82372 m .80324 .82372 L .80409 .82324 L .653 .817 .962 r
F
.80324 .82372 m .80348 .82383 L .80433 .82334 L F
.80384 .82338 m .80423 .82455 L .80323 .82373 L .424 .252 .542 r
F
.80409 .82324 m .80324 .82372 L .80439 .8233 L .653 .817 .962 r
F
.80324 .82372 m .80433 .82334 L .80439 .8233 L F
.80384 .82044 m .8041 .82323 L .80301 .82091 L .424 .252 .542 r
F
.8041 .82323 m .80423 .82455 L .80384 .82338 L F
.8041 .82323 m .80384 .82338 L .80301 .82091 L F
.80502 .82272 m .80439 .8233 L .80503 .82272 L .653 .817 .962 r
F
.80389 .82041 m .80453 .82284 L .80412 .82322 L .231 .113 .505 r
F
.80387 .82045 m .80905 .82012 L .80482 .81988 L .654 .816 .961 r
F
.80394 .82038 m .80482 .81988 L .8045 .81986 L F
.80387 .82045 m .80482 .81988 L .80394 .82038 L F
.79766 .75348 m .79765 .7535 L .79769 .75349 L .597 .767 .96 r
F
.79787 .7536 m .79831 .7543 L .79847 .75395 L F
.79763 .75349 m .79845 .75313 L .80389 .82041 L .424 .252 .542 r
F
.80384 .82044 m .80389 .82041 L .80412 .82322 L F
.80384 .82044 m .80412 .82322 L .8041 .82323 L F
.80446 .81987 m .80449 .81984 L .80472 .82266 L .231 .113 .505 r
F
.80446 .81987 m .80472 .82266 L .80471 .82267 L F
.80498 .82204 m .8049 .82222 L .80449 .81984 L 0 0 .362 r
F
.80449 .81984 m .8049 .82222 L .80472 .82266 L F
.8045 .81986 m .80905 .82012 L .80971 .81892 L .654 .816 .961 r
F
.8045 .81986 m .80971 .81892 L .80483 .81926 L F
.79763 .75349 m .80389 .82041 L .80384 .82044 L .424 .252 .542 r
F
.80294 .82093 m .80294 .82094 L .79636 .75379 L .544 .339 .553 r
F
.79644 .75377 m .80301 .82091 L .80294 .82093 L F
.79849 .7531 m .80449 .81984 L .80446 .81987 L .231 .113 .505 r
F
.80446 .81988 m .80446 .81988 L .79845 .75313 L F
.79845 .75313 m .80446 .81988 L .80389 .82041 L F
.80446 .81987 m .80446 .81988 L .79849 .7531 L F
.79757 .75352 m .80384 .82044 L .80301 .82091 L .424 .252 .542 r
F
.79644 .75377 m .80294 .82093 L .79644 .75378 L .544 .339 .553 r
F
.80294 .82093 m .80294 .82093 L .79644 .75378 L F
.80412 .82322 m .80439 .8233 L .80502 .82272 L .653 .817 .962 r
F
.80409 .82324 m .8041 .82324 L .80412 .82322 L F
.8041 .82324 m .80439 .8233 L .80412 .82322 L F
.80446 .81988 m .80471 .82267 L .80446 .81988 L .231 .113 .505 r
F
.80449 .82322 m .80548 .82317 L .80503 .82272 L .653 .817 .962 r
F
.80445 .8233 m .8096 .82297 L .80449 .82322 L F
.80471 .82267 m .80471 .82267 L .80446 .81988 L .231 .113 .505 r
F
.80384 .82044 m .80296 .82097 L .80387 .82045 L .654 .816 .961 r
F
.79995 .81961 m .80292 .82096 L .80384 .82044 L F
.80292 .82096 m .80296 .82097 L .80384 .82044 L F
.79762 .7535 m .80384 .82044 L .79757 .75352 L .424 .252 .542 r
F
.80384 .82044 m .8041 .82323 L .80384 .82044 L F
.80384 .82044 m .80384 .82044 L .79757 .75352 L F
.8041 .82323 m .80423 .82455 L .8041 .82323 L F
.80384 .82044 m .80384 .82044 L .79757 .75352 L F
.79995 .81961 m .80384 .82044 L .8045 .81986 L .654 .816 .961 r
F
.80384 .82044 m .80387 .82045 L .80394 .82038 L F
.80384 .82044 m .80394 .82038 L .8045 .81986 L F
.8041 .82323 m .8041 .82323 L .80384 .82044 L .424 .252 .542 r
F
.8041 .82323 m .80384 .82044 L .80384 .82044 L F
.80384 .82044 m .80423 .82455 L .80384 .82044 L F
.80446 .81988 m .80471 .82267 L .80389 .82041 L .231 .113 .505 r
F
.80468 .8227 m .80412 .82322 L .80502 .82272 L .653 .817 .962 r
F
.80471 .82267 m .80483 .82398 L .80453 .82284 L .231 .113 .505 r
F
.80471 .82267 m .80453 .82284 L .80389 .82041 L F
.80494 .82245 m .80502 .82272 L .80517 .82245 L .653 .817 .962 r
F
.80446 .81987 m .80471 .82267 L .80446 .81988 L .231 .113 .505 r
F
.80471 .82267 m .80483 .82398 L .80471 .82267 L F
.80471 .82267 m .80471 .82267 L .80446 .81988 L F
.80473 .81927 m .8045 .81986 L .80483 .81926 L .654 .816 .961 r
F
.79995 .81961 m .80448 .81986 L .80473 .81927 L F
.80448 .81986 m .8045 .81986 L .80473 .81927 L F
.79931 .75205 m .80445 .81848 L .80476 .81921 L .919 .662 .17 r
F
.79995 .81961 m .80483 .81926 L .80483 .81868 L .654 .816 .961 r
F
.80474 .81924 m .80476 .81921 L .80499 .82202 L 0 0 .362 r
F
.80474 .81924 m .80499 .82202 L .80498 .82204 L F
.80474 .81924 m .80498 .82204 L .80474 .81924 L F
.80498 .82204 m .80498 .82204 L .80474 .81924 L F
.80474 .81924 m .80498 .82204 L .80449 .81984 L F
.80476 .81921 m .80476 .82149 L .80499 .82202 L .919 .662 .17 r
F
.80482 .82163 m .80536 .82211 L .80536 .82153 L .653 .817 .962 r
F
.80294 .82093 m .80334 .82502 L .80294 .82093 L .544 .339 .553 r
F
.80046 .82246 m .80503 .82214 L .80482 .82163 L .653 .817 .962 r
F
.80503 .82214 m .80536 .82211 L .80482 .82163 L F
.79995 .81961 m .80483 .81868 L .80479 .81863 L .654 .816 .961 r
F
.7951 .75198 m .80141 .75161 L .80011 .75122 L .597 .767 .96 r
F
.79974 .75111 m .8083 .74998 L .80565 .75001 L F
.7951 .75198 m .80011 .75122 L .79974 .75111 L F
.80011 .75122 m .8083 .74998 L .79974 .75111 L F
.79505 .74731 m .79764 .74883 L .79809 .74863 L .598 .766 .96 r
F
.79806 .74834 m .79809 .74863 L .79809 .74863 L .231 .113 .505 r
F
.79505 .74731 m .79809 .74863 L .79832 .74844 L .598 .766 .96 r
F
.79719 .74882 m .79809 .74863 L .79725 .74901 L .424 .252 .542 r
F
.79753 .74546 m .79757 .74607 L .79758 .74608 L .811 .54 .528 r
F
.79857 .74617 m .79758 .74608 L .79861 .74674 L .921 .628 .471 r
F
.79825 .74226 m .79753 .74546 L .79857 .74617 L F
.79827 .7423 m .79825 .74226 L .79857 .74617 L .919 .662 .17 r
F
.79827 .7423 m .79857 .74617 L .79858 .74306 L F
.79728 .74599 m .80615 .74344 L .80355 .74226 L .598 .766 .96 r
F
.79505 .74731 m .79813 .74624 L .79728 .74599 L F
.79813 .74624 m .80615 .74344 L .79728 .74599 L F
.79753 .74546 m .7964 .74514 L .79645 .74574 L .811 .54 .528 r
F
.79995 .81961 m .80479 .81863 L .80412 .81828 L .654 .816 .961 r
F
.79995 .81961 m .80179 .82134 L .8029 .82095 L F
.7951 .75198 m .79683 .75384 L .79766 .75348 L .597 .767 .96 r
F
.7951 .75198 m .79787 .7536 L .79845 .75314 L F
.79505 .74731 m .7968 .7492 L .79764 .74883 L .598 .766 .96 r
F
.79609 .74125 m .79522 .74503 L .7964 .74514 L .734 .481 .546 r
F
.79615 .74127 m .79609 .74125 L .7964 .74514 L .811 .54 .528 r
F
.79722 .74158 m .7964 .74514 L .79753 .74546 L F
.79615 .74127 m .7964 .74514 L .79722 .74158 L F
.79727 .74162 m .79722 .74158 L .79753 .74546 L .921 .628 .471 r
F
.79727 .74162 m .79753 .74546 L .79825 .74226 L F
.79505 .74731 m .79647 .74574 L .79552 .74562 L .598 .766 .96 r
F
.79995 .81961 m .80179 .82134 L .80179 .82134 L .654 .816 .961 r
F
.79995 .81961 m .80056 .82154 L .80179 .82134 L F
.7951 .75198 m .7957 .75394 L .79671 .75371 L .597 .767 .96 r
F
.79505 .74731 m .79449 .74936 L .79566 .74931 L .598 .766 .96 r
F
.7964 .74514 m .79522 .74503 L .79526 .74559 L .734 .481 .546 r
F
.79505 .74731 m .79552 .74562 L .79526 .74559 L .598 .766 .96 r
F
.79453 .7456 m .79526 .74559 L .7945 .74549 L F
.79505 .74731 m .79526 .74559 L .79453 .7456 L F
.79753 .74546 m .79645 .74574 L .79757 .74607 L .811 .54 .528 r
F
.79505 .74731 m .80355 .74226 L .80036 .74143 L .598 .766 .96 r
F
.79526 .74559 m .79555 .75009 L .79563 .75009 L .664 .428 .553 r
F
.7951 .75198 m .79562 .75009 L .79453 .7501 L .597 .767 .96 r
F
.79526 .74559 m .79554 .75009 L .79526 .74559 L .664 .428 .553 r
F
.7951 .75198 m .79669 .75023 L .79562 .75009 L .597 .767 .96 r
F
.79644 .74574 m .79563 .75009 L .79673 .75023 L .734 .481 .546 r
F
.79645 .74574 m .79674 .75023 L .79681 .75024 L F
.79644 .74574 m .79673 .75023 L .79645 .74574 L F
.79673 .75023 m .79674 .75023 L .79645 .74574 L F
.79757 .74607 m .79645 .74574 L .79681 .75024 L .811 .54 .528 r
F
.7951 .75198 m .79782 .75037 L .79669 .75023 L .597 .767 .96 r
F
.79757 .74607 m .79681 .75024 L .79787 .75056 L .811 .54 .528 r
F
.79757 .74607 m .79787 .75056 L .79758 .74608 L F
.79787 .75056 m .79787 .75056 L .79758 .74608 L F
.79758 .74608 m .79787 .75056 L .79794 .75058 L F
.79861 .74674 m .79794 .75058 L .79891 .7512 L .921 .628 .471 r
F
.79861 .74674 m .79758 .74608 L .79794 .75058 L F
.79862 .74675 m .79891 .7512 L .79898 .75125 L F
.79861 .74674 m .79891 .7512 L .79862 .74675 L F
.79894 .74754 m .79862 .74675 L .79898 .75125 L .919 .662 .17 r
F
.79771 .75043 m .8062 .74812 L .8036 .74695 L .597 .767 .96 r
F
.7951 .75198 m .79836 .75085 L .79771 .75043 L F
.79836 .75085 m .8062 .74812 L .79771 .75043 L F
.79787 .75056 m .79681 .75024 L .80224 .81771 L .811 .54 .528 r
F
.79787 .75056 m .80224 .81771 L .8023 .81772 L F
.79995 .81961 m .80252 .81775 L .80224 .81771 L .654 .816 .961 r
F
.79787 .75056 m .8023 .81772 L .79787 .75056 L .811 .54 .528 r
F
.79995 .81961 m .80345 .81794 L .80335 .8179 L .654 .816 .961 r
F
.80344 .81793 m .80344 .81793 L .79898 .75125 L .921 .628 .471 r
F
.80345 .81794 m .80348 .81792 L .80338 .8179 L .654 .816 .961 r
F
.80345 .81794 m .80338 .8179 L .80335 .8179 L F
.79891 .7512 m .80344 .81793 L .79898 .75125 L .921 .628 .471 r
F
.79928 .752 m .79898 .75125 L .80443 .81844 L .919 .662 .17 r
F
.79898 .75125 m .80344 .81793 L .80443 .81844 L .921 .628 .471 r
F
.80428 .81808 m .80449 .81817 L .80433 .81806 L .654 .816 .961 r
F
.79995 .81961 m .80433 .81821 L .80428 .81808 L F
.80433 .81821 m .80449 .81817 L .80428 .81808 L F
.80348 .81792 m .80433 .81806 L .80384 .81775 L F
.79995 .81961 m .80433 .81806 L .80348 .81792 L F
.80046 .82246 m .80301 .82062 L .80247 .82053 L .653 .817 .962 r
F
.79794 .75058 m .8023 .81772 L .80338 .8179 L .811 .54 .528 r
F
.79891 .7512 m .79794 .75058 L .80338 .8179 L .921 .628 .471 r
F
.79891 .7512 m .80338 .8179 L .80344 .81793 L F
.80252 .81775 m .80372 .81771 L .80258 .81771 L .654 .816 .961 r
F
.79995 .81961 m .80335 .8179 L .80252 .81775 L F
.80335 .8179 m .80372 .81771 L .80252 .81775 L F
.79787 .75056 m .8023 .81772 L .79794 .75058 L .811 .54 .528 r
F
.80344 .81793 m .80363 .82073 L .80344 .81793 L .921 .628 .471 r
F
.80046 .82246 m .8045 .82118 L .80385 .82084 L .653 .817 .962 r
F
.80443 .81844 m .80389 .82087 L .80466 .82126 L .921 .628 .471 r
F
.80445 .81848 m .80467 .82127 L .80445 .81848 L .919 .662 .17 r
F
.80467 .82127 m .80467 .82127 L .80445 .81848 L F
.80445 .81848 m .80443 .81844 L .80466 .82126 L F
.80445 .81848 m .80466 .82126 L .80467 .82127 L F
.80445 .81848 m .80467 .82127 L .80445 .81848 L F
.80046 .82246 m .80482 .82163 L .8045 .82118 L .653 .817 .962 r
F
.80482 .82163 m .80523 .82155 L .80466 .82126 L F
.80482 .82163 m .80466 .82126 L .8045 .82118 L F
.80445 .81848 m .80467 .82127 L .80476 .81921 L .919 .662 .17 r
F
.80467 .82127 m .80476 .82244 L .80476 .82149 L F
.80467 .82127 m .80476 .82149 L .80476 .81921 L F
.80467 .82127 m .80476 .82244 L .80467 .82127 L F
.80467 .82127 m .80467 .82127 L .80445 .81848 L F
.80461 .82114 m .80536 .82153 L .80502 .82101 L .653 .817 .962 r
F
.8045 .82118 m .80465 .82124 L .80461 .82114 L F
.80465 .82124 m .80536 .82153 L .80461 .82114 L F
.80523 .82155 m .80536 .82153 L .8045 .82118 L F
.80344 .81793 m .80363 .82073 L .80443 .81844 L .921 .628 .471 r
F
.80363 .82073 m .8037 .82176 L .80389 .82087 L F
.80363 .82073 m .80389 .82087 L .80443 .81844 L F
.80466 .82126 m .8037 .82176 L .80476 .82244 L F
.80389 .82087 m .8037 .82176 L .80466 .82126 L F
.80046 .82246 m .80385 .82084 L .80301 .82062 L .653 .817 .962 r
F
.80385 .82084 m .80397 .82078 L .80361 .82072 L F
.80385 .82084 m .80361 .82072 L .80301 .82062 L F
.80385 .82084 m .80502 .82101 L .80437 .82059 L F
.8045 .82118 m .80502 .82101 L .80385 .82084 L F
.80344 .81793 m .80338 .8179 L .80361 .82072 L .921 .628 .471 r
F
.80363 .82073 m .80361 .82072 L .8037 .82176 L F
.80344 .81793 m .80361 .82072 L .80363 .82073 L F
.80363 .82073 m .8037 .82176 L .80363 .82073 L F
.80363 .82073 m .80363 .82073 L .80344 .81793 L F
.80318 .8205 m .80437 .82059 L .80345 .8203 L .653 .817 .962 r
F
.80338 .8179 m .80275 .82057 L .80361 .82072 L .811 .54 .528 r
F
.80301 .82062 m .8034 .82061 L .80318 .8205 L .653 .817 .962 r
F
.8034 .82061 m .80437 .82059 L .80318 .8205 L F
.80397 .82078 m .80437 .82059 L .80301 .82062 L F
.8023 .81772 m .80248 .82053 L .8023 .81772 L .811 .54 .528 r
F
.80248 .82053 m .80254 .82144 L .80248 .82053 L F
.80248 .82053 m .80248 .82053 L .8023 .81772 L F
.8023 .81772 m .8023 .81772 L .79794 .75058 L F
.80224 .81771 m .80154 .82053 L .80247 .82053 L .734 .481 .546 r
F
.80202 .82053 m .80247 .82053 L .80208 .82046 L .653 .817 .962 r
F
.80046 .82246 m .80247 .82053 L .80202 .82053 L F
.80247 .82053 m .80133 .82134 L .80254 .82144 L .734 .481 .546 r
F
.80046 .82246 m .80202 .82053 L .80127 .82053 L .653 .817 .962 r
F
.79995 .81961 m .80224 .81771 L .80149 .81771 L .654 .816 .961 r
F
.79563 .75009 m .79986 .81787 L .80104 .81771 L .664 .428 .553 r
F
.79673 .75023 m .8011 .81771 L .79674 .75023 L .734 .481 .546 r
F
.8011 .81771 m .8011 .81771 L .79674 .75023 L F
.79681 .75024 m .8011 .81771 L .80224 .81771 L F
.79674 .75023 m .8011 .81771 L .79681 .75024 L F
.8011 .81771 m .8011 .81771 L .79681 .75024 L F
.79995 .81961 m .80149 .81771 L .80104 .81771 L .654 .816 .961 r
F
.80044 .81779 m .80104 .81771 L .80046 .81771 L F
.79995 .81961 m .80104 .81771 L .80044 .81779 L F
.79554 .75009 m .79986 .81787 L .79555 .75009 L .664 .428 .553 r
F
.79995 .81961 m .80044 .81779 L .7998 .81788 L .654 .816 .961 r
F
.7951 .75198 m .79335 .75391 L .79457 .75386 L .597 .767 .96 r
F
.7951 .75198 m .79457 .75386 L .79566 .75382 L F
.79252 .74909 m .79252 .74915 L .79251 .74909 L .848 .57 .516 r
F
.79275 .7458 m .79174 .75083 L .79302 .75033 L .454 .273 .545 r
F
.79264 .74584 m .79174 .75083 L .79275 .7458 L F
.79264 .74584 m .79138 .74633 L .79174 .75083 L F
.79018 .74702 m .78117 .74649 L .7905 .74758 L .598 .766 .96 r
F
.7951 .75198 m .78647 .74695 L .7839 .74812 L .597 .767 .96 r
F
.79276 .7458 m .79302 .75033 L .79311 .7503 L .454 .273 .545 r
F
.79275 .7458 m .79302 .75033 L .79276 .7458 L F
.79062 .74694 m .79063 .74708 L .79063 .74707 L 0 0 .196 r
F
.79113 .74658 m .78957 .74629 L .79065 .74705 L .598 .766 .96 r
F
.78314 .7449 m .78222 .74507 L .78238 .74519 L .599 .766 .959 r
F
.78957 .74629 m .78208 .74488 L .7863 .74679 L .598 .766 .96 r
F
.79421 .74937 m .79423 .74937 L .79421 .74937 L .648 .416 .554 r
F
.79403 .7456 m .79311 .7503 L .79431 .75012 L .585 .369 .554 r
F
.79391 .74562 m .79311 .7503 L .79403 .7456 L F
.79354 .74568 m .79276 .7458 L .79258 .74586 L .598 .766 .96 r
F
.79391 .74562 m .79276 .7458 L .79311 .7503 L .585 .369 .554 r
F
.79063 .74705 m .79018 .74702 L .79057 .74758 L .598 .766 .96 r
F
.79057 .74758 m .79005 .74761 L .79052 .74796 L F
.7951 .75198 m .78964 .74611 L .78647 .74695 L .597 .767 .96 r
F
.79526 .74559 m .79404 .7456 L .7944 .7501 L .664 .428 .553 r
F
.79526 .74559 m .7944 .7501 L .79554 .75009 L F
.79403 .7456 m .79431 .75012 L .79404 .7456 L .585 .369 .554 r
F
.79431 .75012 m .79432 .75011 L .79404 .7456 L F
.79404 .7456 m .79432 .75011 L .7944 .7501 L F
.79272 .74539 m .79264 .74584 L .79275 .7458 L .454 .273 .545 r
F
.79341 .74554 m .7896 .74143 L .79258 .74586 L .598 .766 .96 r
F
.79177 .74618 m .78644 .74227 L .78387 .74345 L F
.79258 .74586 m .78644 .74227 L .79177 .74618 L F
.79177 .74618 m .78387 .74345 L .79086 .74653 L F
.79065 .74705 m .79063 .74705 L .79063 .74707 L F
.7951 .75198 m .79318 .74568 L .78964 .74611 L .597 .767 .96 r
F
.7944 .7501 m .79857 .81822 L .7998 .81788 L .585 .369 .554 r
F
.79944 .81798 m .7998 .81788 L .79942 .81793 L .654 .816 .961 r
F
.79995 .81961 m .7998 .81788 L .79944 .81798 L F
.79169 .75087 m .79639 .81975 L .79174 .75083 L .159 .061 .485 r
F
.79639 .81975 m .79639 .81975 L .79174 .75083 L F
.79174 .75083 m .79639 .81975 L .79712 .81894 L F
.79516 .81995 m .7954 .81935 L .79507 .81995 L .654 .816 .961 r
F
.79169 .75087 m .79099 .75157 L .79636 .81979 L .159 .061 .485 r
F
.79995 .81961 m .79669 .81942 L .79628 .81987 L .654 .816 .961 r
F
.79704 .82409 m .7959 .8239 L .79655 .82432 L .653 .817 .962 r
F
.79696 .82397 m .7959 .8239 L .79704 .82409 L F
.79658 .82089 m .79681 .82372 L .79628 .82041 L .966 .687 .262 r
F
.79669 .82365 m .7959 .8239 L .79696 .82397 L .653 .817 .962 r
F
.79681 .82373 m .79696 .82397 L .79724 .82399 L F
.79669 .82365 m .79696 .82397 L .79681 .82373 L F
.79658 .82089 m .79659 .82091 L .79681 .82373 L .966 .687 .262 r
F
.79681 .82372 m .79681 .82373 L .79687 .82445 L F
.79658 .82089 m .79681 .82373 L .79681 .82372 L F
.79681 .82372 m .79687 .82445 L .79675 .82363 L F
.79681 .82372 m .79675 .82363 L .79628 .82041 L F
.79658 .82089 m .79681 .82372 L .79658 .82089 L F
.79745 .82412 m .79745 .82412 L .7972 .82129 L .941 .646 .452 r
F
.80046 .82246 m .79675 .82363 L .79724 .82399 L .653 .817 .962 r
F
.79675 .82363 m .79669 .82365 L .79681 .82373 L F
.79675 .82363 m .79681 .82373 L .79724 .82399 L F
.79593 .82332 m .79555 .82281 L .79556 .82339 L F
.79628 .82041 m .79675 .82363 L .7965 .82323 L .966 .687 .262 r
F
.79628 .82038 m .79628 .82041 L .7965 .82323 L 0 0 .196 r
F
.79644 .82373 m .79556 .82339 L .7959 .8239 L .653 .817 .962 r
F
.80046 .82246 m .7965 .82321 L .79644 .82373 L F
.7965 .82321 m .79556 .82339 L .79644 .82373 L F
.79628 .82038 m .7965 .82322 L .79628 .82038 L 0 0 .196 r
F
.7965 .82323 m .7965 .82323 L .79655 .82387 L .966 .687 .262 r
F
.7965 .82323 m .79687 .82445 L .79655 .82387 L F
.7965 .82322 m .79655 .82387 L .7965 .82322 L 0 0 .196 r
F
.7965 .82322 m .7965 .82322 L .79628 .82038 L F
.7965 .82322 m .7965 .82323 L .79655 .82387 L F
.79628 .82038 m .7965 .82323 L .7965 .82322 L F
.7965 .82321 m .7963 .82291 L .79649 .82321 L .653 .817 .962 r
F
.80046 .82246 m .79654 .82288 L .7965 .82321 L F
.79654 .82288 m .7963 .82291 L .7965 .82321 L F
.79628 .82038 m .79655 .82387 L .79629 .82035 L 0 0 .196 r
F
.79636 .81979 m .79652 .82311 L .79658 .8226 L F
.79639 .81975 m .79636 .81979 L .79658 .8226 L .159 .061 .485 r
F
.79639 .81975 m .79658 .8226 L .79658 .8226 L F
.79639 .81975 m .79658 .8226 L .79639 .81975 L F
.80046 .82246 m .79656 .82274 L .79654 .82288 L .653 .817 .962 r
F
.79658 .8226 m .79662 .82319 L .79658 .8226 L .159 .061 .485 r
F
.79658 .8226 m .79658 .8226 L .79639 .81975 L F
.79645 .82274 m .79642 .82223 L .79555 .82281 L .653 .817 .962 r
F
.79629 .82035 m .79655 .82387 L .79636 .81979 L 0 0 .196 r
F
.80046 .82246 m .79689 .82226 L .79645 .82274 L .653 .817 .962 r
F
.79169 .75087 m .79636 .81979 L .79639 .81975 L .159 .061 .485 r
F
.79302 .75033 m .79174 .75083 L .79712 .81894 L .454 .273 .545 r
F
.79995 .81961 m .79705 .81898 L .79623 .8194 L .654 .816 .961 r
F
.79302 .75033 m .79712 .81894 L .79718 .81891 L .454 .273 .545 r
F
.79302 .75033 m .79718 .81891 L .79311 .7503 L F
.79718 .81891 m .79718 .81891 L .79311 .7503 L F
.79311 .7503 m .79718 .81891 L .79851 .81824 L F
.79432 .75011 m .79856 .81822 L .7944 .7501 L .585 .369 .554 r
F
.79995 .81961 m .79754 .81851 L .79637 .81884 L .654 .816 .961 r
F
.79754 .81851 m .79804 .8178 L .79693 .81823 L F
.79995 .81961 m .79851 .81824 L .79754 .81851 L F
.79851 .81824 m .79804 .8178 L .79754 .81851 L F
.79431 .75012 m .79311 .7503 L .79851 .81824 L .585 .369 .554 r
F
.80046 .82246 m .79873 .82106 L .79808 .82139 L .653 .817 .962 r
F
.79642 .82223 m .79651 .82161 L .79587 .8222 L F
.79639 .81975 m .79658 .8226 L .79712 .81894 L .159 .061 .485 r
F
.79658 .8226 m .79662 .82319 L .79671 .82246 L F
.79658 .8226 m .79671 .82246 L .79712 .81894 L F
.80046 .82246 m .79732 .82179 L .79689 .82226 L .653 .817 .962 r
F
.79734 .82176 m .79662 .82319 L .79739 .82234 L .159 .061 .485 r
F
.79712 .81894 m .79671 .82246 L .79734 .82176 L F
.79671 .82246 m .79662 .82319 L .79734 .82176 L F
.79732 .82179 m .79742 .82108 L .79651 .82161 L .653 .817 .962 r
F
.79718 .81891 m .79735 .82176 L .79851 .81824 L .454 .273 .545 r
F
.79735 .82176 m .79739 .82234 L .79758 .82164 L F
.79735 .82176 m .79758 .82164 L .79851 .81824 L F
.80046 .82246 m .79808 .82139 L .79732 .82179 L .653 .817 .962 r
F
.79851 .81824 m .79758 .82164 L .79873 .82106 L .454 .273 .545 r
F
.79808 .82139 m .7978 .82126 L .79734 .82176 L .653 .817 .962 r
F
.79808 .82139 m .79734 .82176 L .79732 .82179 L F
.7978 .82126 m .79742 .82108 L .79732 .82179 L F
.79689 .82226 m .7973 .82178 L .79642 .82223 L F
.79732 .82179 m .7973 .82178 L .79689 .82226 L F
.7973 .82178 m .79651 .82161 L .79642 .82223 L F
.79718 .81891 m .79712 .81894 L .79734 .82176 L .454 .273 .545 r
F
.79735 .82176 m .79734 .82176 L .79739 .82234 L F
.79718 .81891 m .79734 .82176 L .79735 .82176 L F
.79873 .82106 m .79739 .82234 L .79878 .82169 L F
.79758 .82164 m .79739 .82234 L .79873 .82106 L F
.80046 .82246 m .79892 .821 L .79873 .82106 L .653 .817 .962 r
F
.79808 .82139 m .79873 .82106 L .79788 .82129 L F
.79788 .82129 m .79854 .82065 L .79742 .82108 L F
.79856 .81822 m .79874 .82105 L .79857 .81822 L .585 .369 .554 r
F
.79874 .82105 m .79878 .82169 L .79874 .82105 L F
.79874 .82105 m .79874 .82105 L .79857 .81822 L F
.79856 .81822 m .79851 .81824 L .79873 .82106 L F
.79856 .81822 m .79873 .82106 L .79874 .82105 L F
.79856 .81822 m .79878 .82169 L .79856 .81822 L F
.80046 .82246 m .79991 .82073 L .79892 .821 L .653 .817 .962 r
F
.79431 .75012 m .79851 .81824 L .79856 .81822 L .585 .369 .554 r
F
.79856 .81822 m .79857 .81822 L .7944 .7501 L F
.79431 .75012 m .79856 .81822 L .79432 .75011 L F
.79856 .81822 m .79856 .81822 L .79432 .75011 L F
.79995 .81961 m .79928 .81749 L .79804 .8178 L .654 .816 .961 r
F
.80003 .82069 m .79878 .82169 L .80008 .82141 L .585 .369 .554 r
F
.7998 .81788 m .79897 .82099 L .80003 .82069 L F
.79897 .82099 m .79878 .82169 L .80003 .82069 L F
.79986 .81787 m .7998 .81788 L .80003 .82069 L .664 .428 .553 r
F
.80046 .82246 m .80097 .82057 L .79991 .82073 L .653 .817 .962 r
F
.80104 .81771 m .80004 .82069 L .80127 .82053 L .664 .428 .553 r
F
.80097 .82057 m .80003 .82069 L .79991 .82073 L .653 .817 .962 r
F
.79555 .75009 m .80004 .82069 L .79563 .75009 L .664 .428 .553 r
F
.80004 .82069 m .80008 .82141 L .80004 .82069 L F
.80004 .82069 m .80004 .82069 L .79563 .75009 L F
.80101 .82042 m .80108 .82016 L .79996 .8207 L .653 .817 .962 r
F
.80003 .82069 m .79996 .8207 L .79991 .82073 L F
.80101 .82042 m .79996 .8207 L .80003 .82069 L F
.80097 .82057 m .80101 .82042 L .80003 .82069 L F
.79986 .81787 m .80004 .82069 L .79986 .81787 L .664 .428 .553 r
F
.80004 .82069 m .80008 .82141 L .80004 .82069 L F
.80004 .82069 m .80004 .82069 L .79986 .81787 L F
.80004 .82069 m .80003 .82069 L .80008 .82141 L F
.79986 .81787 m .80003 .82069 L .80004 .82069 L F
.79986 .81787 m .80004 .82069 L .80104 .81771 L F
.7999 .82071 m .80108 .82016 L .79978 .82033 L .653 .817 .962 r
F
.79991 .82073 m .79996 .8207 L .7999 .82071 L F
.79996 .8207 m .80108 .82016 L .7999 .82071 L F
.79857 .81822 m .79878 .82169 L .7998 .81788 L .585 .369 .554 r
F
.79892 .821 m .79978 .82033 L .79854 .82065 L .653 .817 .962 r
F
.79991 .82073 m .79978 .82033 L .79892 .821 L F
.79892 .821 m .79854 .82065 L .79788 .82129 L F
.79874 .82105 m .79873 .82106 L .79878 .82169 L .585 .369 .554 r
F
.79637 .81884 m .79698 .81826 L .79603 .81876 L .654 .816 .961 r
F
.79754 .81851 m .79698 .81826 L .79637 .81884 L F
.79698 .81826 m .79693 .81823 L .79687 .81827 L F
.79698 .81826 m .79687 .81827 L .79603 .81876 L F
.79554 .75009 m .7944 .7501 L .7998 .81788 L .664 .428 .553 r
F
.79554 .75009 m .7998 .81788 L .79986 .81787 L F
.79623 .8194 m .79637 .81884 L .7954 .81935 L .654 .816 .961 r
F
.79705 .81898 m .79637 .81884 L .79623 .8194 L F
.79637 .81884 m .79603 .81876 L .79577 .819 L F
.79637 .81884 m .79577 .819 L .7954 .81935 L F
.79689 .82226 m .79642 .82223 L .79645 .82274 L .653 .817 .962 r
F
.79642 .82223 m .79587 .8222 L .79564 .82263 L F
.79642 .82223 m .79564 .82263 L .79555 .82281 L F
.79718 .81891 m .79735 .82176 L .79718 .81891 L .454 .273 .545 r
F
.79735 .82176 m .79739 .82234 L .79735 .82176 L F
.79735 .82176 m .79735 .82176 L .79718 .81891 L F
.79658 .8226 m .79655 .82387 L .79662 .82319 L 0 0 .196 r
F
.79652 .82311 m .79655 .82387 L .79658 .8226 L F
.79654 .82288 m .79645 .82274 L .7963 .82291 L .653 .817 .962 r
F
.79656 .82274 m .79645 .82274 L .79654 .82288 L F
.79649 .82321 m .7963 .82291 L .79593 .82332 L F
.79645 .82274 m .79555 .82281 L .79593 .82332 L F
.79658 .8226 m .79658 .8226 L .79662 .82319 L .159 .061 .485 r
F
.79628 .81987 m .79623 .8194 L .79516 .81995 L .654 .816 .961 r
F
.79669 .81942 m .79623 .8194 L .79628 .81987 L F
.79623 .8194 m .7954 .81935 L .79516 .81995 L F
.79986 .81787 m .79986 .81787 L .79555 .75009 L .664 .428 .553 r
F
.79669 .75023 m .79563 .75009 L .79562 .75009 L .597 .767 .96 r
F
.79673 .75023 m .79563 .75009 L .80133 .82134 L .734 .481 .546 r
F
.80046 .81771 m .80181 .81731 L .80057 .81732 L .654 .816 .961 r
F
.80149 .81771 m .80181 .81731 L .80046 .81771 L F
.8011 .81771 m .80133 .82134 L .8011 .81771 L .734 .481 .546 r
F
.79942 .81793 m .80057 .81732 L .79928 .81749 L .654 .816 .961 r
F
.80044 .81779 m .80057 .81732 L .79942 .81793 L F
.80097 .82057 m .80127 .82053 L .80098 .82053 L .653 .817 .962 r
F
.80046 .82246 m .80127 .82053 L .80097 .82057 L F
.80127 .82053 m .80008 .82141 L .80133 .82134 L .664 .428 .553 r
F
.80004 .82069 m .80008 .82141 L .80127 .82053 L F
.8011 .81771 m .80133 .82134 L .80224 .81771 L .734 .481 .546 r
F
.80098 .82053 m .80233 .82015 L .80108 .82016 L .653 .817 .962 r
F
.80202 .82053 m .80233 .82015 L .80098 .82053 L F
.8011 .81771 m .80128 .82053 L .8011 .81771 L .734 .481 .546 r
F
.80128 .82053 m .80133 .82134 L .80128 .82053 L F
.80128 .82053 m .80128 .82053 L .8011 .81771 L F
.80154 .82053 m .80133 .82134 L .80247 .82053 L F
.8023 .81772 m .80254 .82144 L .80338 .8179 L .811 .54 .528 r
F
.8023 .81772 m .80254 .82144 L .8023 .81772 L F
.8023 .81772 m .80224 .81771 L .80254 .82144 L F
.80208 .82046 m .80345 .8203 L .80233 .82015 L .653 .817 .962 r
F
.80301 .82062 m .80345 .8203 L .80208 .82046 L F
.80361 .82072 m .80254 .82144 L .8037 .82176 L .811 .54 .528 r
F
.80275 .82057 m .80254 .82144 L .80361 .82072 L F
.8023 .81772 m .8023 .81772 L .79787 .75056 L F
.80335 .8179 m .80384 .81775 L .80372 .81771 L .654 .816 .961 r
F
.80348 .81792 m .80384 .81775 L .80335 .8179 L F
.80258 .81771 m .80372 .81771 L .80293 .81745 L F
.80149 .81771 m .80224 .81771 L .80158 .8176 L F
.80158 .8176 m .80293 .81745 L .80181 .81731 L F
.80252 .81775 m .80293 .81745 L .80158 .8176 L F
.79915 .74707 m .80894 .74649 L .7994 .7465 L .598 .766 .96 r
F
.79849 .74667 m .80798 .74488 L .79794 .74631 L F
.7967 .75021 m .8036 .74695 L .80041 .74611 L .597 .767 .96 r
F
.79669 .75023 m .79671 .75021 L .7967 .75021 L F
.79671 .75021 m .8036 .74695 L .7967 .75021 L F
.79782 .75037 m .8036 .74695 L .79669 .75023 L F
.79849 .74667 m .79915 .74707 L .7994 .7465 L .598 .766 .96 r
F
.79912 .74707 m .79915 .74707 L .79849 .74667 L F
.79794 .74631 m .80798 .74488 L .80615 .74344 L F
.79562 .75009 m .80041 .74611 L .79686 .74568 L .597 .767 .96 r
F
.79669 .75023 m .79682 .75008 L .79563 .75009 L F
.79644 .74574 m .79526 .74559 L .79563 .75009 L .734 .481 .546 r
F
.79554 .75009 m .79555 .75009 L .79526 .74559 L .664 .428 .553 r
F
.79894 .74754 m .79894 .74755 L .79894 .74754 L .598 .766 .96 r
F
.79682 .75008 m .80041 .74611 L .79562 .75009 L .597 .767 .96 r
F
.7964 .74514 m .79526 .74559 L .79644 .74574 L .734 .481 .546 r
F
.7964 .74514 m .79644 .74574 L .79645 .74574 L F
.79647 .74574 m .80036 .74143 L .79552 .74562 L .598 .766 .96 r
F
.79453 .7501 m .79686 .74568 L .79318 .74568 L .597 .767 .96 r
F
.79562 .75009 m .79686 .74568 L .79453 .7501 L F
.79522 .74503 m .79526 .74559 L .79526 .74559 L .664 .428 .553 r
F
.79497 .7411 m .7949 .7411 L .79522 .74503 L .734 .481 .546 r
F
.79497 .7411 m .79522 .74503 L .79609 .74125 L F
.7945 .74549 m .79681 .741 L .79314 .741 L .598 .766 .96 r
F
.79552 .74562 m .79681 .741 L .7945 .74549 L F
.79552 .74562 m .80036 .74143 L .79681 .741 L F
.80011 .75122 m .809 .75116 L .8083 .74998 L .597 .767 .96 r
F
.80141 .75161 m .809 .75116 L .80011 .75122 L F
.80565 .75001 m .8083 .74998 L .80804 .74956 L F
.79928 .752 m .80443 .81844 L .80445 .81848 L .919 .662 .17 r
F
.80445 .81848 m .80445 .81848 L .79931 .75205 L F
.79928 .752 m .80445 .81848 L .79929 .752 L F
.80445 .81848 m .80445 .81848 L .79929 .752 L F
.80412 .81828 m .80479 .81863 L .80449 .81817 L .654 .816 .961 r
F
.80467 .82127 m .80476 .82244 L .80467 .82127 L .919 .662 .17 r
F
.80498 .82204 m .80499 .82202 L .80509 .82331 L 0 0 .362 r
F
.80494 .82214 m .80494 .82245 L .80503 .82214 L .653 .817 .962 r
F
.80046 .82246 m .80481 .82245 L .80494 .82214 L F
.80481 .82245 m .80494 .82245 L .80494 .82214 L F
.80494 .82245 m .80517 .82245 L .8051 .8223 L F
.80494 .82245 m .8051 .8223 L .80503 .82214 L F
.80046 .82246 m .80468 .8227 L .80494 .82245 L F
.80468 .8227 m .80502 .82272 L .80494 .82245 L F
.80498 .82204 m .80509 .82331 L .80498 .82204 L 0 0 .362 r
F
.80502 .82272 m .80503 .82272 L .80504 .82271 L .653 .817 .962 r
F
.80498 .82204 m .80509 .82331 L .8049 .82222 L 0 0 .362 r
F
.8049 .82222 m .80509 .82331 L .80472 .82266 L F
.80499 .82202 m .80476 .82244 L .80509 .82331 L .919 .662 .17 r
F
.80476 .82149 m .80476 .82244 L .80499 .82202 L F
.80548 .82317 m .8096 .82297 L .80529 .82273 L .653 .817 .962 r
F
.80548 .82317 m .80529 .82273 L .80503 .82272 L F
.80439 .8233 m .80445 .8233 L .80449 .82322 L F
.80471 .82267 m .80483 .82398 L .80471 .82267 L .231 .113 .505 r
F
.80467 .82127 m .80466 .82126 L .80476 .82244 L .919 .662 .17 r
F
.80503 .82214 m .80517 .82245 L .80536 .82211 L .653 .817 .962 r
F
.80502 .82272 m .80504 .82271 L .80536 .82211 L F
.8041 .82323 m .80412 .82322 L .80423 .82455 L .424 .252 .542 r
F
.80471 .82267 m .80472 .82266 L .80483 .82398 L .231 .113 .505 r
F
.80046 .82246 m .80409 .82324 L .80412 .82322 L .653 .817 .962 r
F
.80046 .82246 m .80412 .82322 L .80468 .8227 L F
.80046 .82246 m .80324 .82372 L .80409 .82324 L F
.80321 .82373 m .80334 .82502 L .80321 .82373 L .544 .339 .553 r
F
.80198 .82416 m .80211 .82538 L .80198 .82416 L .648 .416 .554 r
F
.80046 .82246 m .80104 .82432 L .80219 .82409 L .653 .817 .962 r
F
.80104 .82432 m .80201 .82416 L .80219 .82409 L F
.7958 .82039 m .79516 .81995 L .79508 .82053 L .654 .816 .961 r
F
.79628 .81987 m .79516 .81995 L .7958 .82039 L F
.79516 .81995 m .79507 .81995 L .79507 .81999 L F
.79516 .81995 m .79507 .81999 L .79508 .82053 L F
.79681 .82372 m .79687 .82445 L .79681 .82372 L .966 .687 .262 r
F
.79724 .82399 m .79696 .82397 L .79704 .82409 L .653 .817 .962 r
F
.79783 .82435 m .79704 .82409 L .79747 .82461 L F
.79745 .82412 m .79752 .82494 L .79745 .82412 L .941 .646 .452 r
F
.79616 .82142 m .79607 .82146 L .79615 .82149 L .654 .816 .961 r
F
.80046 .82246 m .79724 .82399 L .79746 .82412 L .653 .817 .962 r
F
.80046 .82246 m .79746 .82412 L .79796 .82426 L F
.79847 .8244 m .79856 .82533 L .79847 .82439 L .848 .57 .516 r
F
.80046 .82246 m .79887 .82441 L .79992 .82445 L .653 .817 .962 r
F
.80018 .82446 m .8002 .82446 L .80029 .82555 L .75 .494 .544 r
F
.79724 .82399 m .79704 .82409 L .79783 .82435 L .653 .817 .962 r
F
.79704 .82409 m .79655 .82432 L .79733 .82457 L F
.79704 .82409 m .79733 .82457 L .79747 .82461 L F
.79675 .82363 m .79687 .82445 L .7965 .82323 L .966 .687 .262 r
F
.79681 .82373 m .79752 .82494 L .79687 .82445 L .941 .646 .452 r
F
.79745 .82412 m .79752 .82494 L .79681 .82373 L F
.80017 .82446 m .80029 .82555 L .79972 .82444 L .75 .494 .544 r
F
.80046 .82246 m .79992 .82445 L .8011 .82449 L .653 .817 .962 r
F
.80018 .82446 m .80029 .82555 L .80017 .82446 L .75 .494 .544 r
F
.79354 .74568 m .79341 .74554 L .79276 .7458 L .598 .766 .96 r
F
.78807 .75442 m .78273 .75429 L .78407 .75581 L .597 .767 .96 r
F
.78949 .75303 m .78273 .75429 L .78807 .75442 L F
.78273 .75429 m .78222 .75439 L .78231 .75446 L F
.78273 .75429 m .78231 .75446 L .78407 .75581 L F
.79061 .75464 m .78807 .75442 L .78667 .75697 L F
.79075 .75349 m .78807 .75442 L .79061 .75464 L F
.78807 .75442 m .78407 .75581 L .78584 .7566 L F
.78807 .75442 m .78584 .7566 L .78667 .75697 L F
.80198 .82416 m .80211 .82538 L .8002 .82446 L .648 .416 .554 r
F
.80219 .82409 m .80208 .82414 L .80222 .82412 L .653 .817 .962 r
F
.80046 .82246 m .80219 .82409 L .80324 .82372 L F
.80321 .82373 m .80323 .82373 L .80334 .82502 L .544 .339 .553 r
F
.80472 .82266 m .80509 .82331 L .80483 .82398 L 0 0 .362 r
F
.80412 .82322 m .80483 .82398 L .80423 .82455 L .231 .113 .505 r
F
.80453 .82284 m .80483 .82398 L .80412 .82322 L F
.79836 .75085 m .80804 .74956 L .8062 .74812 L .597 .767 .96 r
F
.79899 .75125 m .80804 .74956 L .79836 .75085 L F
.8053 .82049 m .80777 .82129 L .80856 .82057 L .654 .816 .961 r
F
.80543 .82078 m .80777 .82129 L .8053 .82049 L F
.80784 .8202 m .80856 .82057 L .80905 .82012 L F
.80558 .82115 m .80607 .82228 L .80777 .82129 L F
.79996 .75366 m .80623 .75582 L .79962 .75283 L .597 .767 .96 r
F
.80057 .75518 m .80366 .75698 L .79996 .75366 L F
0 g
.33748 .54201 m
.35873 .54297 L
s
.62191 .39997 m .62214 .39188 L .60715 .37804 L .939 .671 .502 r
F
0 g
.62214 .39188 m
.63072 .4073 L
s
.77029 .65017 m .75409 .64646 L .74897 .65136 L .655 .809 .957 r
F
.77398 .64797 m .75409 .64646 L .77029 .65017 L F
.27512 .51383 m .27521 .50736 L .29447 .50256 L .596 .385 .566 r
F
.2541 .51578 m .27521 .50736 L .27512 .51383 L .671 .446 .571 r
F
0 g
.25423 .50931 m
.27521 .50736 L
s
.50469 .50554 m .47833 .50988 L .48357 .5167 L .656 .78 .94 r
F
.37485 .65878 m .38798 .64844 L .3705 .6544 L .658 .806 .954 r
F
.37485 .65878 m .39441 .65505 L .38798 .64844 L F
.39406 .64967 m .38729 .63764 L .38763 .64303 L .981 .703 .418 r
F
.39441 .65505 m .39406 .64967 L .38763 .64303 L F
0 g
.39406 .64967 m
.39643 .65699 L
s
.79156 .54026 m .76946 .53568 L .77022 .5422 L .673 .451 .576 r
F
0 g
.74975 .54689 m
.77022 .5422 L
s
.79156 .54026 m .79076 .53374 L .76946 .53568 L .673 .451 .576 r
F
0 g
.74902 .54038 m
.76946 .53568 L
s
.26632 .49323 m .27507 .50715 L .29424 .50238 L .657 .779 .938 r
F
.25226 .49455 m .27507 .50715 L .26632 .49323 L F
.75044 .66213 m .73146 .6609 L .72773 .66846 L .654 .811 .959 r
F
0 g
.72773 .66846 m
.72815 .67566 L
s
.80595 .65331 m .81954 .64374 L .80331 .65152 L .655 .81 .958 r
F
.80595 .65331 m .82479 .64737 L .81954 .64374 L F
.3175 .65715 m .29926 .65345 L .29571 .65836 L .659 .806 .954 r
F
.32055 .65496 m .29926 .65345 L .3175 .65715 L F
0 g
.33877 .67481 m
.33932 .66503 L
s
.32037 .6496 m .30525 .64368 L .29921 .64809 L .659 .805 .953 r
F
.32443 .64781 m .30525 .64368 L .32037 .6496 L F
.69121 .38293 m .67828 .4038 L .69784 .38665 L .643 .737 .917 r
F
.69121 .38293 m .66506 .39648 L .67828 .4038 L F
0 g
.33169 .67471 m
.33224 .66546 L
s
.58263 .78018 m .56995 .78409 L .58322 .78333 L .595 .768 .962 r
F
.58263 .78018 m .56901 .77937 L .56995 .78409 L F
0 g
.56995 .78409 m
.57357 .78863 L
s
.22115 .39501 m .19101 .40408 L .22303 .40045 L .642 .739 .919 r
F
.22115 .39501 m .18703 .39322 L .19101 .40408 L F
.73213 .38845 m .74613 .40736 L .76139 .40153 L .643 .737 .917 r
F
.72352 .39011 m .74613 .40736 L .73213 .38845 L F
.80232 .64617 m .81099 .63585 L .7986 .6449 L .655 .809 .957 r
F
.80232 .64617 m .81845 .63843 L .81099 .63585 L F
.35313 .66032 m .36374 .6508 L .34973 .65854 L .658 .806 .954 r
F
.35313 .66032 m .3705 .6544 L .36374 .6508 L F
.59643 .77639 m .58342 .77874 L .59671 .77797 L .596 .768 .961 r
F
.59643 .77639 m .58283 .77558 L .58342 .77874 L F
.64856 .78879 m .65084 .77964 L .65072 .78425 L 0 0 .283 r
F
.63569 .78647 m .64856 .78879 L .65072 .78425 L .595 .768 .962 r
F
0 g
.64381 .79283 m
.64856 .78879 L
s
.32201 .41096 m .35765 .40217 L .32352 .40038 L .642 .739 .919 r
F
.28875 .4039 m .32201 .41096 L .32352 .40038 L F
.28583 .4087 m .32201 .41096 L .28875 .4039 L F
.81216 .54123 m .79076 .53374 L .79156 .54026 L .734 .495 .567 r
F
0 g
.76946 .53568 m
.79076 .53374 L
s
.79076 .53374 m
.81133 .53471 L
s
.81216 .54123 m
.83053 .54501 L
s
.61582 .38045 m .62479 .38806 L .62457 .39615 L .992 .739 .407 r
F
.61582 .38045 m .61607 .37233 L .62479 .38806 L F
.64976 .36857 m .62479 .38806 L .65541 .37914 L .644 .736 .916 r
F
.64976 .36857 m .61607 .37233 L .62479 .38806 L F
0 g
.62479 .38806 m
.63138 .39418 L
s
.63584 .78187 m .65084 .77964 L .63724 .77882 L .596 .768 .961 r
F
.62295 .77954 m .63584 .78187 L .63724 .77882 L F
.75409 .64646 m .73013 .6501 L .74897 .65136 L .655 .809 .957 r
F
0 g
.59552 .6694 m
.61137 .66742 L
s
.31644 .54394 m
.33748 .54201 L
s
.62304 .77493 m .63724 .77421 L .62372 .77341 L .597 .767 .961 r
F
.34475 .64654 m .34429 .63617 L .33977 .64588 L .659 .805 .953 r
F
.34475 .64654 m .3543 .63751 L .34429 .63617 L F
.21217 .51087 m .23283 .5083 L .23268 .51477 L .79 .547 .569 r
F
.21217 .51087 m .21236 .50438 L .23283 .5083 L F
0 g
.23283 .5083 m
.25423 .50931 L
s
.34944 .65314 m .3547 .64282 L .34509 .65188 L .659 .806 .954 r
F
.34944 .65314 m .36342 .64539 L .3547 .64282 L F
.77193 .66093 m .75044 .66213 L .76933 .66336 L .654 .811 .959 r
F
0 g
.79156 .54026 m
.81216 .54123 L
s
.33515 .73845 m
.33877 .67481 L
s
.80113 .39731 m .81426 .37462 L .81451 .38273 L .203 .077 .476 r
F
.80135 .40542 m .80113 .39731 L .81451 .38273 L F
.7737 .38534 m .80113 .39731 L .81451 .38273 L .644 .736 .916 r
F
.76127 .39342 m .80113 .39731 L .7737 .38534 L F
0 g
.79013 .40433 m
.80113 .39731 L
s
.22425 .4912 m .23291 .50808 L .23794 .49386 L .657 .779 .938 r
F
.22425 .4912 m .21254 .50418 L .23291 .50808 L F
0 g
.32797 .73794 m
.33169 .67471 L
s
.82836 .65716 m .84471 .64679 L .82572 .65276 L .654 .811 .959 r
F
.82836 .65716 m .84857 .65342 L .84471 .64679 L F
.29926 .65345 m .27561 .65711 L .29571 .65836 L .659 .806 .954 r
F
.8476 .64804 m .84278 .63599 L .84375 .64139 L .932 .628 .163 r
F
.84857 .65342 m .8476 .64804 L .84375 .64139 L F
0 g
.84746 .65152 m
.8475 .65074 L
s
.36968 .64368 m .37699 .63227 L .36296 .64007 L .659 .805 .953 r
F
.36968 .64368 m .38702 .63773 L .37699 .63227 L F
.25398 .52227 m .2541 .51578 L .27512 .51383 L .671 .446 .571 r
F
.23252 .52127 m .2541 .51578 L .25398 .52227 L .733 .498 .572 r
F
.23252 .52127 m .23268 .51477 L .2541 .51578 L F
.25216 .5012 m .2541 .51578 L .27512 .51383 L .657 .779 .939 r
F
.23773 .50052 m .2541 .51578 L .25216 .5012 L F
.23773 .50052 m .23268 .51477 L .2541 .51578 L F
.48554 .3946 m .46163 .37854 L .44536 .39071 L .643 .737 .917 r
F
.49978 .38873 m .46163 .37854 L .48554 .3946 L F
.58154 .39964 m .5864 .37495 L .56793 .3923 L F
.58154 .39964 m .60688 .38615 L .5864 .37495 L F
.77107 .65553 m .75477 .65182 L .74961 .65673 L .655 .81 .958 r
F
.77479 .65333 m .75477 .65182 L .77107 .65553 L F
.28979 .39579 m .32448 .39225 L .29044 .39047 L .642 .738 .918 r
F
.60952 .51721 m .6131 .49936 L .6136 .50587 L 0 0 .37 r
F
.61001 .5237 m .60952 .51721 L .6136 .50587 L F
.58368 .51406 m .60952 .51721 L .6136 .50587 L .655 .781 .941 r
F
0 g
.60308 .52455 m
.60952 .51721 L
s
.79186 .66342 m
.79265 .6732 L
s
.77398 .64797 m .76147 .64203 L .75409 .64646 L .655 .809 .957 r
F
.77853 .64618 m .76147 .64203 L .77398 .64797 L F
.39441 .65505 m .38763 .64303 L .38798 .64844 L .981 .703 .418 r
F
0 g
.39441 .65505 m
.39679 .66235 L
s
.57804 .52763 m .61001 .5237 L .58413 .52057 L .655 .782 .942 r
F
.55508 .52097 m .57804 .52763 L .58413 .52057 L F
.55052 .52406 m .57804 .52763 L .55508 .52097 L F
.32443 .64781 m .31339 .64006 L .30525 .64368 L .659 .805 .953 r
F
.32925 .64654 m .31339 .64006 L .32443 .64781 L F
0 g
.78487 .66385 m
.7856 .6731 L
s
.80686 .6587 m .82048 .64916 L .80421 .65691 L .654 .811 .959 r
F
.80686 .6587 m .82572 .65276 L .82048 .64916 L F
0 g
.61134 .85337 m
.61137 .85445 L
s
.31776 .66255 m .29949 .65887 L .29593 .66375 L .658 .806 .954 r
F
.32081 .66036 m .29949 .65887 L .31776 .66255 L F
.50486 .51207 m .47833 .51643 L .48361 .52327 L .655 .781 .941 r
F
.27512 .51383 m .29447 .50256 L .29441 .50904 L .596 .385 .566 r
F
.27503 .52032 m .27512 .51383 L .29441 .50904 L F
.25398 .52227 m .27512 .51383 L .27503 .52032 L .671 .446 .571 r
F
.26631 .49988 m .27512 .51383 L .29441 .50904 L .657 .779 .939 r
F
.25216 .5012 m .27512 .51383 L .26631 .49988 L F
0 g
.2541 .51578 m
.27512 .51383 L
s
.33977 .64588 m .33363 .63616 L .33448 .64588 L .659 .805 .953 r
F
.33977 .64588 m .34429 .63617 L .33363 .63616 L F
.32055 .65496 m .30533 .64903 L .29926 .65345 L .659 .806 .954 r
F
.32464 .65316 m .30533 .64903 L .32055 .65496 L F
.59624 .781 m .58322 .78333 L .59652 .78257 L .595 .768 .962 r
F
.59624 .781 m .58263 .78018 L .58322 .78333 L F
0 g
.77022 .5422 m
.79156 .54026 L
s
.68642 .37011 m .66518 .38838 L .69127 .37479 L .644 .736 .916 r
F
.68642 .37011 m .65541 .37914 L .66518 .38838 L F
.15497 .36709 m .15567 .37526 L .1543 .38333 L .833 .751 .234 r
F
.15497 .36709 m .15635 .35899 L .15567 .37526 L F
0 g
.15567 .37526 m
.15883 .38357 L
s
.19063 .36631 m .15618 .37529 L .18996 .37706 L .643 .737 .917 r
F
.19063 .36631 m .15686 .3591 L .15618 .37529 L F
.7986 .6449 m .8018 .63451 L .79402 .64425 L .655 .809 .957 r
F
.7986 .6449 m .81099 .63585 L .8018 .63451 L F
.22418 .37348 m .18996 .37706 L .22374 .37883 L .643 .737 .917 r
F
.22418 .37348 m .19063 .36631 L .18996 .37706 L F
.63569 .78647 m .65072 .78425 L .6371 .78343 L .595 .768 .962 r
F
.62279 .78414 m .63569 .78647 L .6371 .78343 L F
.62123 .7855 m .63569 .78647 L .62279 .78414 L F
.80331 .65152 m .81204 .64117 L .79956 .65025 L .655 .81 .958 r
F
.80331 .65152 m .81954 .64374 L .81204 .64117 L F
.73973 .37733 m .76127 .39342 L .7737 .38534 L .644 .736 .916 r
F
.73209 .38032 m .76127 .39342 L .73973 .37733 L F
0 g
.79265 .6732 m
.79778 .73648 L
s
.62295 .77954 m .63724 .77882 L .62363 .77801 L .596 .768 .961 r
F
.58443 .76793 m .56965 .77018 L .58317 .77099 L .597 .767 .961 r
F
.57108 .77016 m .56945 .77017 L .56923 .77476 L 0 0 .221 r
F
0 g
.56998 .77289 m
.57036 .77483 L
s
.58443 .76793 m .57149 .76558 L .56965 .77018 L .597 .767 .961 r
F
.57108 .77016 m .5713 .76555 L .56945 .77017 L 0 0 .221 r
F
.29131 .38238 m .32199 .3732 L .28965 .37691 L .643 .737 .917 r
F
.29131 .38238 m .3251 .38415 L .32199 .3732 L F
.59733 .77027 m .58317 .77099 L .59669 .77179 L .597 .767 .961 r
F
.59733 .77027 m .58443 .76793 L .58317 .77099 L F
0 g
.7856 .6731 m
.79062 .73667 L
s
.32925 .64654 m .32308 .63749 L .31339 .64006 L .659 .805 .953 r
F
.33448 .64588 m .32308 .63749 L .32925 .64654 L F
.3251 .38415 m .35453 .36946 L .32199 .3732 L .643 .737 .917 r
F
.3251 .38415 m .35889 .38592 L .35453 .36946 L F
.75477 .65182 m .73065 .65548 L .74961 .65673 L .655 .81 .958 r
F
.35811 .39112 m .3594 .38595 L .35502 .36941 L .975 .786 .363 r
F
.35853 .39404 m .35502 .36941 L .35413 .37753 L F
.35394 .36674 m .3768 .36539 L .37596 .37346 L .794 .541 .555 r
F
.35085 .36579 m .35405 .36574 L .35394 .36674 L F
.35405 .36574 m .3768 .36539 L .35394 .36674 L F
.35085 .36579 m .35175 .35771 L .3768 .36539 L F
.32199 .3732 m .35453 .36946 L .35316 .3675 L .643 .737 .917 r
F
.37287 .37352 m .35085 .36579 L .37596 .37346 L .794 .541 .555 r
F
.35074 .36676 m .35085 .36579 L .37287 .37352 L F
.36815 .33971 m .35199 .35744 L .37692 .36509 L .644 .737 .916 r
F
.36711 .34802 m .35085 .36579 L .37596 .37346 L .643 .737 .917 r
F
.3288 .35444 m .35175 .35771 L .35085 .36579 L .856 .601 .552 r
F
.3288 .35444 m .32976 .34633 L .35175 .35771 L F
.33437 .36177 m .35074 .36676 L .33675 .35956 L .643 .737 .917 r
F
.32199 .3732 m .35243 .36763 L .33437 .36177 L F
.35243 .36763 m .35316 .3675 L .35074 .36676 L F
.35243 .36763 m .35074 .36676 L .33437 .36177 L F
.34812 .36541 m .3288 .35444 L .35085 .36579 L .856 .601 .552 r
F
.32869 .35541 m .3288 .35444 L .34812 .36541 L F
.3535 .33203 m .33011 .34612 L .35199 .35744 L .644 .737 .916 r
F
.35235 .34031 m .3288 .35444 L .35085 .36579 L .643 .737 .917 r
F
.32199 .3732 m .33534 .36087 L .31439 .36263 L F
.33534 .36087 m .34335 .35347 L .33106 .35735 L F
.33534 .36087 m .33106 .35735 L .31439 .36263 L F
.31126 .34004 m .32976 .34633 L .3288 .35444 L .92 .668 .54 r
F
.31126 .34004 m .31227 .3319 L .32976 .34633 L F
.34194 .32232 m .31271 .33176 L .33011 .34612 L .644 .737 .916 r
F
.31439 .36263 m .32104 .34913 L .30276 .35318 L .643 .737 .917 r
F
.3266 .3537 m .31126 .34004 L .3288 .35444 L .92 .668 .54 r
F
.31114 .34101 m .31126 .34004 L .3266 .3537 L F
.34194 .32232 m .33011 .34612 L .3535 .33203 L .644 .737 .916 r
F
.34071 .33058 m .31126 .34004 L .3288 .35444 L .643 .737 .917 r
F
.32104 .34913 m .32598 .33911 L .31611 .34509 L F
.32104 .34913 m .31611 .34509 L .30276 .35318 L F
.3266 .3537 m .3288 .35444 L .32869 .35541 L .92 .668 .54 r
F
.34071 .33058 m .3288 .35444 L .35235 .34031 L .643 .737 .917 r
F
.31439 .36263 m .34335 .35347 L .32598 .33911 L F
.30073 .32524 m .31227 .3319 L .31126 .34004 L .981 .742 .502 r
F
.29946 .32346 m .30084 .32437 L .30073 .32524 L F
.30084 .32437 m .31227 .3319 L .30073 .32524 L F
.30974 .33905 m .29946 .32346 L .31126 .34004 L F
.30276 .35318 m .30363 .33046 L .30347 .33023 L .643 .737 .917 r
F
.29934 .32443 m .29946 .32346 L .30974 .33905 L .981 .742 .502 r
F
.3343 .31121 m .31271 .33176 L .34194 .32232 L .644 .737 .916 r
F
.33299 .31943 m .31126 .34004 L .34071 .33058 L .643 .737 .917 r
F
.29946 .32346 m .30051 .31529 L .31227 .3319 L .981 .742 .502 r
F
.3343 .31121 m .30101 .31523 L .31271 .33176 L .644 .737 .916 r
F
.33299 .31943 m .29946 .32346 L .31126 .34004 L .643 .737 .917 r
F
.30363 .33046 m .32598 .33911 L .30374 .32757 L F
.30276 .35318 m .31467 .34596 L .30363 .33046 L F
.30974 .33905 m .31126 .34004 L .31114 .34101 L .981 .742 .502 r
F
.31467 .34596 m .32598 .33911 L .30363 .33046 L .643 .737 .917 r
F
.30276 .35318 m .30355 .32747 L .28788 .34557 L F
.28788 .34557 m .30105 .33036 L .27766 .31948 L F
.30105 .33036 m .30355 .32747 L .29989 .32634 L F
.30105 .33036 m .29989 .32634 L .27766 .31948 L F
.29968 .33341 m .30061 .32621 L .29978 .32596 L .796 .54 .552 r
F
.29889 .3329 m .29978 .32596 L .27776 .31916 L F
.29968 .33341 m .29978 .32596 L .29889 .3329 L F
.29326 .31397 m .29873 .32234 L .29841 .33166 L .984 .793 .39 r
F
.29873 .32234 m .29946 .32346 L .29934 .32443 L F
.29873 .32234 m .29934 .32443 L .29841 .33166 L F
.28788 .34557 m .27766 .31948 L .27078 .34034 L .643 .737 .917 r
F
.29955 .33442 m .27776 .31916 L .27665 .32738 L .796 .54 .552 r
F
.29968 .33344 m .30974 .33905 L .31025 .34821 L .981 .742 .502 r
F
.29841 .33166 m .29979 .33256 L .29968 .33344 L F
.29979 .33256 m .30974 .33905 L .29968 .33344 L F
.29841 .33166 m .29934 .32443 L .30974 .33905 L F
.30974 .33905 m .31114 .34101 L .31025 .34821 L F
.31025 .34821 m .31114 .34101 L .3266 .3537 L .92 .668 .54 r
F
.31707 .34177 m .29968 .33344 L .31025 .34821 L .643 .738 .918 r
F
.32278 .34472 m .32633 .3389 L .30379 .3272 L .857 .601 .55 r
F
.30287 .33442 m .29968 .33344 L .31707 .34177 L .643 .738 .918 r
F
.30347 .33023 m .30374 .32757 L .30349 .32959 L .643 .737 .917 r
F
.30363 .33046 m .30374 .32757 L .30347 .33023 L F
.32278 .34472 m .30379 .3272 L .30287 .33442 L .857 .601 .55 r
F
.32547 .3461 m .32633 .3389 L .32278 .34472 L F
.31025 .34821 m .3266 .3537 L .32784 .36258 L .92 .668 .54 r
F
.3266 .3537 m .32869 .35541 L .32784 .36258 L F
.32784 .36258 m .32869 .35541 L .34812 .36541 L .856 .601 .552 r
F
.33299 .3523 m .31025 .34821 L .32784 .36258 L .643 .738 .918 r
F
.34812 .36541 m .35085 .36579 L .35074 .36676 L .856 .601 .552 r
F
.3535 .33203 m .35199 .35744 L .36815 .33971 L .644 .737 .916 r
F
.35235 .34031 m .35085 .36579 L .36711 .34802 L .643 .737 .917 r
F
.33675 .35956 m .35316 .3675 L .34335 .35347 L F
.34089 .35881 m .34379 .35333 L .32633 .3389 L .922 .668 .537 r
F
.32305 .34412 m .31025 .34821 L .33299 .3523 L .643 .738 .918 r
F
.32784 .36258 m .34812 .36541 L .34994 .37392 L .856 .601 .552 r
F
.34812 .36541 m .35074 .36676 L .34994 .37392 L F
.35074 .36676 m .35316 .3675 L .33675 .35956 L .643 .737 .917 r
F
.33806 .35648 m .32784 .36258 L .3468 .36597 L .643 .738 .918 r
F
.35413 .37753 m .35502 .36941 L .35383 .36771 L .983 .743 .496 r
F
.35413 .37753 m .35409 .37636 L .35303 .37497 L F
.35409 .37636 m .35383 .36771 L .35304 .37487 L F
.35409 .37636 m .35304 .37487 L .35303 .37497 L F
.34994 .37392 m .35074 .36676 L .35383 .36771 L .794 .541 .555 r
F
.34994 .37392 m .35383 .36771 L .35315 .37387 L F
.35304 .37487 m .37596 .37346 L .37512 .38158 L F
.34994 .37392 m .35315 .37387 L .35304 .37487 L F
.35315 .37387 m .37596 .37346 L .35304 .37487 L F
.32448 .39225 m .35413 .37753 L .32134 .38127 L .642 .738 .918 r
F
.32448 .39225 m .35853 .39404 L .35413 .37753 L F
.35088 .37291 m .34994 .37392 L .35204 .37456 L .643 .738 .918 r
F
.35088 .37291 m .35204 .37456 L .35304 .37487 L F
.35133 .37242 m .35088 .37291 L .35304 .37487 L F
.33806 .35648 m .3468 .36597 L .34297 .36052 L F
.35013 .37072 m .32784 .36258 L .34994 .37392 L F
.35185 .37316 m .34379 .35333 L .34297 .36052 L .983 .743 .496 r
F
.35303 .37497 m .3529 .37466 L .35294 .37584 L F
.3529 .37466 m .34379 .35333 L .35185 .37316 L F
.3529 .37466 m .35185 .37316 L .35294 .37584 L F
.34876 .36498 m .35058 .36305 L .34379 .35333 L F
.3529 .37466 m .35058 .36305 L .34876 .36498 L F
.3529 .37466 m .35383 .36771 L .35058 .36305 L F
.34297 .36052 m .34379 .35333 L .34089 .35881 L .922 .668 .537 r
F
.35144 .3485 m .33952 .35561 L .35037 .36661 L .643 .738 .918 r
F
.34089 .35881 m .32633 .3389 L .32547 .3461 L .922 .668 .537 r
F
.33952 .35561 m .33806 .35648 L .34297 .36052 L .643 .738 .918 r
F
.33952 .35561 m .34297 .36052 L .35037 .36661 L F
.35037 .36661 m .3468 .36597 L .35013 .37072 L F
.3468 .36597 m .32784 .36258 L .35013 .37072 L F
.35315 .37387 m .35383 .36771 L .37287 .37352 L .794 .541 .555 r
F
.35304 .37487 m .35383 .36771 L .3529 .37466 L .983 .743 .496 r
F
.35144 .3485 m .34994 .37392 L .36624 .35619 L .643 .738 .918 r
F
.35294 .37584 m .35185 .37316 L .34286 .36149 L .983 .743 .496 r
F
.35185 .37316 m .34297 .36052 L .34286 .36149 L F
.32134 .38127 m .35413 .37753 L .34286 .36149 L .642 .738 .918 r
F
.35323 .3857 m .35413 .37753 L .35294 .37584 L .983 .743 .496 r
F
.35213 .38314 m .35294 .37584 L .34286 .36149 L F
.35323 .3857 m .35294 .37584 L .35213 .38314 L F
.35413 .37753 m .35303 .37497 L .35294 .37584 L F
.35351 .37386 m .35269 .37387 L .35385 .37511 L .643 .738 .918 r
F
.35272 .3709 m .35269 .37387 L .35351 .37386 L F
.35272 .3709 m .35133 .37242 L .35269 .37387 L F
.35133 .37242 m .35304 .37487 L .35385 .37511 L F
.34297 .36052 m .3468 .36597 L .35037 .36661 L F
.35303 .37497 m .35304 .37487 L .3529 .37466 L .983 .743 .496 r
F
.33976 .33878 m .32784 .36258 L .35144 .3485 L .643 .738 .918 r
F
.34286 .36149 m .34089 .35881 L .32535 .34708 L .922 .668 .537 r
F
.34089 .35881 m .32547 .3461 L .32535 .34708 L F
.33976 .33878 m .32305 .34412 L .33299 .3523 L .643 .738 .918 r
F
.34286 .36149 m .34297 .36052 L .34089 .35881 L .922 .668 .537 r
F
.33202 .32766 m .31025 .34821 L .33976 .33878 L .643 .738 .918 r
F
.32535 .34708 m .32278 .34472 L .30275 .33541 L .857 .601 .55 r
F
.32278 .34472 m .30287 .33442 L .30275 .33541 L F
.30349 .32959 m .30374 .32757 L .30355 .32747 L .643 .737 .917 r
F
.30249 .33431 m .30379 .3272 L .30061 .32621 L .796 .54 .552 r
F
.30275 .33541 m .30287 .33442 L .30249 .33431 L F
.30287 .33442 m .30379 .3272 L .30249 .33431 L F
.30275 .33541 m .30061 .32621 L .29968 .33341 L F
.33202 .32766 m .30064 .33327 L .31945 .33953 L .643 .738 .918 r
F
.29976 .33347 m .29968 .33341 L .29968 .33344 L .796 .54 .552 r
F
.30064 .33327 m .29968 .33344 L .30287 .33442 L .643 .738 .918 r
F
.30064 .33327 m .30287 .33442 L .31945 .33953 L F
.31945 .33953 m .30287 .33442 L .31707 .34177 L F
.32535 .34708 m .32547 .3461 L .32278 .34472 L .857 .601 .55 r
F
.33202 .32766 m .29841 .33166 L .29968 .33344 L .643 .738 .918 r
F
.30275 .33541 m .29976 .33347 L .29955 .33442 L .796 .54 .552 r
F
.29976 .33347 m .29968 .33344 L .29955 .33442 L F
.29968 .33341 m .27776 .31916 L .29955 .33442 L F
.36624 .35619 m .35272 .3709 L .37512 .38158 L .643 .738 .918 r
F
.35272 .3709 m .35385 .37511 L .37512 .38158 L F
.35853 .39404 m .35863 .39307 L .35811 .39112 L .975 .786 .363 r
F
.35863 .39307 m .3594 .38595 L .35811 .39112 L F
.82366 .64204 m .83474 .6306 L .81845 .63843 L .655 .809 .957 r
F
.82366 .64204 m .8425 .63608 L .83474 .6306 L F
.62372 .77341 m .63679 .77105 L .62348 .77183 L .597 .767 .961 r
F
.62372 .77341 m .63724 .77421 L .63679 .77105 L F
.461 .38668 m .44536 .39071 L .44469 .39882 L .308 .127 .466 r
F
.461 .38668 m .46163 .37854 L .44536 .39071 L F
0 g
.43532 .40511 m
.44536 .39071 L
s
.63724 .77421 m .65014 .77028 L .63679 .77105 L .597 .767 .961 r
F
.63724 .77421 m .65076 .77502 L .65014 .77028 L F
.33448 .64588 m .33363 .63616 L .32308 .63749 L .659 .805 .953 r
F
.65084 .77964 m .65097 .77503 L .65034 .77026 L .842 .682 .144 r
F
0 g
.64886 .77952 m
.65063 .77574 L
s
.34509 .65188 m .34463 .64148 L .34008 .65122 L .659 .806 .954 r
F
.34509 .65188 m .3547 .64282 L .34463 .64148 L F
.34973 .65854 m .35501 .64824 L .34538 .65727 L .658 .806 .954 r
F
.34973 .65854 m .36374 .6508 L .35501 .64824 L F
.29921 .64809 m .28093 .64436 L .27572 .65173 L .659 .805 .953 r
F
.28085 .64972 m .27542 .65171 L .27561 .65711 L .064 0 .456 r
F
.28085 .64972 m .28065 .64431 L .27542 .65171 L F
0 g
.27433 .6593 m
.27542 .65171 L
s
.62191 .39997 m .60715 .37804 L .60688 .38615 L .939 .671 .502 r
F
.62168 .4081 m .62191 .39997 L .60688 .38615 L F
0 g
.62191 .39997 m
.63051 .41535 L
s
.29949 .65887 m .27581 .66252 L .29593 .66375 L .658 .806 .954 r
F
.84857 .65342 m .84375 .64139 L .84471 .64679 L .932 .628 .163 r
F
0 g
.84827 .66074 m
.84857 .65342 L
s
.37017 .649 m .37754 .63756 L .36342 .64539 L .659 .806 .954 r
F
.37017 .649 m .38763 .64303 L .37754 .63756 L F
.77853 .64618 m .7706 .63841 L .76147 .64203 L .655 .809 .957 r
F
.78363 .64491 m .7706 .63841 L .77853 .64618 L F
.50047 .38083 m .48391 .3617 L .46261 .37069 L .644 .737 .916 r
F
.51694 .37752 m .48391 .3617 L .50047 .38083 L F
.56811 .38438 m .56212 .35939 L .55204 .37936 L F
.56811 .38438 m .58644 .36707 L .56212 .35939 L F
.21197 .51738 m .23268 .51477 L .23252 .52127 L .79 .547 .569 r
F
.21197 .51738 m .21217 .51087 L .23268 .51477 L F
.22396 .49786 m .23268 .51477 L .23773 .50052 L .657 .779 .939 r
F
.22396 .49786 m .21217 .51087 L .23268 .51477 L F
0 g
.23268 .51477 m
.2541 .51578 L
s
.29441 .50904 m .29447 .50256 L .31079 .4952 L .494 .304 .551 r
F
0 g
.28316 .50538 m
.29447 .50256 L
s
.77193 .66093 m .75561 .65724 L .75044 .66213 L .654 .811 .959 r
F
.77565 .65873 m .75561 .65724 L .77193 .66093 L F
.2792 .49 m .29424 .50238 L .31048 .49505 L .657 .779 .938 r
F
.26632 .49323 m .29424 .50238 L .2792 .49 L F
.79402 .64425 m .79151 .6345 L .78891 .64425 L .655 .809 .957 r
F
.79402 .64425 m .8018 .63451 L .79151 .6345 L F
.77479 .65333 m .76219 .64738 L .75477 .65182 L .655 .81 .958 r
F
.77937 .65153 m .76219 .64738 L .77479 .65333 L F
.25203 .50774 m .25398 .52227 L .27503 .52032 L .656 .78 .94 r
F
.23758 .50705 m .25398 .52227 L .25203 .50774 L F
.23758 .50705 m .23252 .52127 L .25398 .52227 L F
.32464 .65316 m .31353 .6454 L .30533 .64903 L .659 .806 .954 r
F
.32948 .65189 m .31353 .6454 L .32464 .65316 L F
.44913 .50954 m .45169 .51427 L .4519 .52077 L .888 .675 .157 r
F
.44913 .50954 m .44892 .50301 L .45169 .51427 L F
0 g
.45169 .51427 m
.45626 .52005 L
s
.47664 .50239 m .45208 .5142 L .47833 .50988 L .656 .78 .94 r
F
.47664 .50239 m .44933 .503 L .45208 .5142 L F
.61001 .5237 m .6136 .50587 L .61409 .51239 L 0 0 .37 r
F
.58413 .52057 m .61001 .5237 L .61409 .51239 L .655 .782 .942 r
F
0 g
.60075 .53421 m
.61001 .5237 L
s
.78363 .64491 m .78086 .63583 L .7706 .63841 L .655 .809 .957 r
F
.78891 .64425 m .78086 .63583 L .78363 .64491 L F
.32081 .66036 m .30557 .65445 L .29949 .65887 L .658 .806 .954 r
F
.3249 .65856 m .30557 .65445 L .32081 .66036 L F
.34008 .65122 m .3339 .64148 L .33475 .65123 L .659 .806 .954 r
F
.34008 .65122 m .34463 .64148 L .3339 .64148 L F
.62279 .78414 m .6371 .78343 L .62348 .78262 L .595 .768 .962 r
F
.5841 .77251 m .56923 .77476 L .58283 .77558 L .596 .768 .961 r
F
.57086 .77477 m .56923 .77476 L .56901 .77937 L 0 0 .221 r
F
0 g
.56977 .77749 m
.57015 .77944 L
s
.5841 .77251 m .57108 .77016 L .56923 .77476 L .596 .768 .961 r
F
.57086 .77477 m .57108 .77016 L .56923 .77476 L 0 0 .221 r
F
.6496 .3767 m .62457 .39615 L .65527 .38726 L .643 .737 .917 r
F
.6496 .3767 m .61582 .38045 L .62457 .39615 L F
0 g
.62457 .39615 m
.63936 .4098 L
s
.78891 .64425 m .79151 .6345 L .78086 .63583 L .655 .809 .957 r
F
.59708 .77486 m .58283 .77558 L .59643 .77639 L .596 .768 .961 r
F
.59708 .77486 m .5841 .77251 L .58283 .77558 L F
.30525 .64368 m .28093 .64436 L .29921 .64809 L .659 .805 .953 r
F
.79956 .65025 m .80279 .63983 L .79495 .64959 L .655 .81 .958 r
F
.79956 .65025 m .81204 .64117 L .80279 .63983 L F
.80421 .65691 m .81297 .64659 L .80046 .65565 L .654 .811 .959 r
F
.80421 .65691 m .82048 .64916 L .81297 .64659 L F
.75409 .64646 m .73775 .64271 L .73013 .6501 L .655 .809 .957 r
F
.62363 .77801 m .63679 .77565 L .62339 .77643 L .596 .768 .961 r
F
.62363 .77801 m .63724 .77882 L .63679 .77565 L F
.73832 .64808 m .72984 .65008 L .73065 .65548 L .276 .182 .564 r
F
.73832 .64808 m .7375 .64266 L .72984 .65008 L F
0 g
.72613 .65768 m
.72984 .65008 L
s
.63724 .77882 m .65022 .77488 L .63679 .77565 L .596 .768 .961 r
F
.63724 .77882 m .65084 .77964 L .65022 .77488 L F
.65084 .77964 m .65034 .77026 L .65022 .77488 L .842 .682 .144 r
F
.65072 .78425 m .65084 .77964 L .65022 .77488 L F
0 g
.64872 .78413 m
.65051 .78034 L
s
.59886 .7689 m .58443 .76793 L .59733 .77027 L .597 .767 .961 r
F
.62348 .77183 m .63452 .76798 L .62233 .7703 L F
.62348 .77183 m .63679 .77105 L .63452 .76798 L F
.50517 .51861 m .48388 .52977 L .50776 .52204 L .655 .782 .942 r
F
.50517 .51861 m .47859 .52296 L .48388 .52977 L F
.80135 .40542 m .81451 .38273 L .81475 .39088 L .203 .077 .476 r
F
.77384 .39347 m .80135 .40542 L .81475 .39088 L .643 .737 .917 r
F
.76139 .40153 m .80135 .40542 L .77384 .39347 L F
0 g
.78261 .41731 m
.80135 .40542 L
s
.27503 .52032 m .29441 .50904 L .29436 .51554 L .596 .385 .566 r
F
.2662 .50642 m .27503 .52032 L .29436 .51554 L .656 .78 .94 r
F
.25203 .50774 m .27503 .52032 L .2662 .50642 L F
0 g
.25398 .52227 m
.27503 .52032 L
s
.32948 .65189 m .32328 .64282 L .31353 .6454 L .659 .806 .954 r
F
.33475 .65123 m .32328 .64282 L .32948 .65189 L F
.75561 .65724 m .73146 .6609 L .75044 .66213 L .654 .811 .959 r
F
.82479 .64737 m .83594 .6359 L .81954 .64374 L .655 .81 .958 r
F
.82479 .64737 m .84375 .64139 L .83594 .6359 L F
.33475 .65123 m .3339 .64148 L .32328 .64282 L .659 .806 .954 r
F
.34538 .65727 m .34492 .64691 L .34036 .65662 L .658 .806 .954 r
F
.34538 .65727 m .35501 .64824 L .34492 .64691 L F
.48497 .40271 m .461 .38668 L .44469 .39882 L .642 .738 .918 r
F
0 g
.43463 .41318 m
.44469 .39882 L
s
.49925 .39685 m .461 .38668 L .48497 .40271 L .642 .738 .918 r
F
.29926 .65345 m .28085 .64972 L .27561 .65711 L .659 .806 .954 r
F
.28106 .65515 m .27561 .65711 L .27581 .66252 L .064 0 .456 r
F
.28106 .65515 m .28085 .64972 L .27561 .65711 L F
0 g
.27453 .66467 m
.27561 .65711 L
s
.61531 .8503 m
.61534 .85147 L
s
.61353 .78111 m
.61523 .84724 L
s
.61342 .7769 m
.61342 .7769 L
s
.58121 .40776 m .58608 .38312 L .56757 .40043 L .642 .738 .918 r
F
.58121 .40776 m .60662 .39431 L .58608 .38312 L F
.28875 .4039 m .32352 .40038 L .28939 .39859 L .642 .739 .919 r
F
0 g
.6081 .8508 m
.60811 .85137 L
s
.60803 .84802 m
.60808 .85015 L
s
.60643 .7807 m
.60801 .84723 L
s
.3705 .6544 m .37788 .64298 L .36374 .6508 L .658 .806 .954 r
F
.3705 .6544 m .38798 .64844 L .37788 .64298 L F
.77937 .65153 m .77139 .64374 L .76219 .64738 L .655 .81 .958 r
F
.78449 .65025 m .77139 .64374 L .77937 .65153 L F
.77565 .65873 m .76305 .65281 L .75561 .65724 L .654 .811 .959 r
F
.78024 .65694 m .76305 .65281 L .77565 .65873 L F
.79495 .64959 m .79243 .63982 L .78981 .64959 L .655 .81 .958 r
F
.79495 .64959 m .80279 .63983 L .79243 .63982 L F
.3249 .65856 m .31378 .65082 L .30557 .65445 L .658 .806 .954 r
F
.32975 .65729 m .31378 .65082 L .3249 .65856 L F
.76147 .64203 m .73775 .64271 L .75409 .64646 L .655 .809 .957 r
F
.68635 .37825 m .66506 .39648 L .69121 .38293 L .643 .737 .917 r
F
.68635 .37825 m .65527 .38726 L .66506 .39648 L F
.15357 .37523 m .1543 .38333 L .15292 .39143 L .833 .751 .234 r
F
.15357 .37523 m .15497 .36709 L .1543 .38333 L F
.18899 .37433 m .1543 .38333 L .18833 .38511 L .642 .738 .918 r
F
.18899 .37433 m .15497 .36709 L .1543 .38333 L F
0 g
.1543 .38333 m
.15749 .39167 L
s
.19389 .50428 m .21236 .50438 L .21217 .51087 L .848 .597 .56 r
F
.19389 .50428 m .19412 .49777 L .21236 .50438 L F
0 g
.21236 .50438 m
.21721 .50531 L
s
.22378 .50441 m .23252 .52127 L .23758 .50705 L .656 .78 .94 r
F
.22378 .50441 m .21197 .51738 L .23252 .52127 L F
0 g
.23252 .52127 m
.25398 .52227 L
s
.29441 .50904 m .31079 .4952 L .31076 .5017 L .494 .304 .551 r
F
.29436 .51554 m .29441 .50904 L .31076 .5017 L F
.27927 .49664 m .29441 .50904 L .31076 .5017 L .657 .779 .939 r
F
.26631 .49988 m .29441 .50904 L .27927 .49664 L F
0 g
.28302 .51187 m
.29441 .50904 L
s
.58389 .77712 m .56901 .77937 L .58263 .78018 L .595 .768 .962 r
F
.58389 .77712 m .57086 .77477 L .56901 .77937 L F
0 g
.56901 .77937 m
.56995 .78409 L
s
.2228 .38153 m .18833 .38511 L .22236 .3869 L .642 .738 .918 r
F
.2228 .38153 m .18899 .37433 L .18833 .38511 L F
.59689 .77947 m .58263 .78018 L .59624 .781 L .595 .768 .962 r
F
.59689 .77947 m .58389 .77712 L .58263 .78018 L F
.38763 .64303 m .38729 .63764 L .3772 .63215 L .919 .647 .51 r
F
0 g
.38729 .63764 m
.39371 .6443 L
s
.73979 .38547 m .76139 .40153 L .77384 .39347 L .643 .737 .917 r
F
.73213 .38845 m .76139 .40153 L .73979 .38547 L F
.36296 .64007 m .36398 .62836 L .3543 .63751 L .659 .805 .953 r
F
.36296 .64007 m .37699 .63227 L .36398 .62836 L F
.21211 .48674 m .21254 .50418 L .22425 .4912 L .657 .779 .938 r
F
.21211 .48674 m .19438 .4976 L .21254 .50418 L F
.62348 .78262 m .63665 .78027 L .62324 .78104 L .595 .768 .962 r
F
.62348 .78262 m .6371 .78343 L .63665 .78027 L F
.68393 .35665 m .65587 .37098 L .68665 .36196 L .645 .736 .915 r
F
.68393 .35665 m .65026 .36043 L .65587 .37098 L F
.58368 .51406 m .6136 .50587 L .58626 .50648 L .655 .781 .941 r
F
.78449 .65025 m .78171 .64116 L .77139 .64374 L .655 .81 .958 r
F
.78981 .64959 m .78171 .64116 L .78449 .65025 L F
.34036 .65662 m .33418 .64691 L .33503 .65663 L .658 .806 .954 r
F
.34036 .65662 m .34492 .64691 L .33418 .64691 L F
.29044 .39047 m .32134 .38127 L .28877 .38499 L .642 .738 .918 r
F
.29044 .39047 m .32448 .39225 L .32134 .38127 L F
.6371 .78343 m .65009 .7795 L .63665 .78027 L .595 .768 .962 r
F
.6371 .78343 m .65072 .78425 L .65009 .7795 L F
.65072 .78425 m .65022 .77488 L .65009 .7795 L .842 .682 .144 r
F
0 g
.64856 .78879 m
.65072 .78425 L
s
.59862 .77348 m .5841 .77251 L .59708 .77486 L .596 .768 .961 r
F
.71278 .34072 m .7138 .34123 L .71472 .35559 L .857 .566 .495 r
F
.72004 .36114 m .71685 .36868 L .72345 .3738 L .645 .736 .915 r
F
.71685 .36868 m .71541 .37403 L .72345 .3738 L F
.71978 .33948 m .72 .33861 L .72097 .3533 L 0 0 .297 r
F
.72021 .35611 m .72345 .3738 L .72772 .37296 L .645 .736 .915 r
F
.72345 .36051 m .72772 .37296 L .73197 .37213 L F
.72021 .35611 m .72772 .37296 L .72345 .36051 L F
.72006 .35667 m .72345 .3738 L .72021 .35611 L F
.7195 .35566 m .72345 .3738 L .71986 .35563 L F
.71896 .35631 m .72345 .3738 L .7195 .35566 L F
.71862 .35584 m .7188 .35652 L .71881 .35571 L F
.7188 .35652 m .72345 .3738 L .71896 .35631 L F
.7188 .35652 m .71896 .35631 L .71881 .35571 L F
.71924 .34021 m .71978 .33948 L .72075 .35413 L .157 .044 .463 r
F
.71924 .34021 m .72032 .35465 L .72019 .35481 L F
.7184 .34082 m .71954 .35524 L .71935 .35536 L .379 .203 .512 r
F
.71549 .34151 m .71724 .34129 L .71818 .35577 L .638 .394 .533 r
F
.71978 .33948 m .72097 .3533 L .7208 .35394 L 0 0 .297 r
F
.71978 .33948 m .7208 .35394 L .72075 .35413 L F
.72 .33861 m .71963 .33748 L .72059 .35222 L .925 .667 .181 r
F
.7206 .35493 m .72253 .35785 L .72185 .35586 L .645 .736 .915 r
F
.7196 .35527 m .73197 .37213 L .7206 .35493 L F
.71724 .34129 m .71844 .35568 L .71818 .35577 L .519 .305 .529 r
F
.71881 .35571 m .71896 .35631 L .7195 .35566 L .645 .736 .915 r
F
.71859 .35573 m .71862 .35584 L .71881 .35571 L F
.71724 .34129 m .7184 .34082 L .71935 .35536 L .519 .305 .529 r
F
.7196 .35527 m .71922 .35545 L .71986 .35563 L .645 .736 .915 r
F
.71922 .35545 m .71859 .35573 L .71881 .35571 L F
.71922 .35545 m .71881 .35571 L .71986 .35563 L F
.7184 .34082 m .71924 .34021 L .72019 .35481 L .379 .203 .512 r
F
.7184 .34082 m .72019 .35481 L .71954 .35524 L F
.71724 .34129 m .71935 .35536 L .71844 .35568 L .519 .305 .529 r
F
.71781 .35283 m .71856 .35563 L .7196 .35527 L .645 .736 .915 r
F
.71856 .35563 m .71859 .35573 L .7196 .35527 L F
.72032 .35472 m .7196 .35527 L .7206 .35493 L F
.71781 .35283 m .71956 .35522 L .72032 .35472 L F
.71956 .35522 m .7196 .35527 L .72032 .35472 L F
.71986 .35563 m .72006 .35667 L .72021 .35611 L F
.71915 .35783 m .71861 .35976 L .72004 .36114 L F
.71861 .35976 m .71457 .37405 L .72004 .36114 L F
.71924 .34021 m .72075 .35413 L .72032 .35465 L .157 .044 .463 r
F
.71781 .35283 m .73956 .36915 L .74041 .36858 L .645 .736 .915 r
F
.72533 .35613 m .74041 .36858 L .74571 .36506 L F
.71781 .35283 m .74041 .36858 L .72533 .35613 L F
.71849 .3575 m .71807 .35926 L .71915 .35783 L F
.71807 .35926 m .71457 .37405 L .71861 .35976 L F
.71807 .35926 m .71861 .35976 L .71915 .35783 L F
.72048 .37091 m .72021 .36774 L .72536 .36644 L .59 .365 .542 r
F
.71685 .36868 m .71457 .37405 L .71541 .37403 L .645 .736 .915 r
F
.71846 .35631 m .71823 .35736 L .71876 .35637 L F
.71823 .35736 m .71457 .37405 L .71849 .3575 L F
.71823 .35736 m .71849 .3575 L .71876 .35637 L F
.71735 .35584 m .71731 .35609 L .71859 .35573 L F
.71731 .35609 m .71457 .37405 L .71846 .35631 L F
.71731 .35609 m .71846 .35631 L .71859 .35573 L F
.7151 .37134 m .72021 .36774 L .72048 .37091 L .663 .419 .54 r
F
.72131 .37387 m .71981 .37572 L .7235 .38199 L .644 .736 .916 r
F
.71981 .37572 m .71455 .38224 L .72276 .38201 L F
.71981 .37572 m .72276 .38201 L .7235 .38199 L F
.71178 .33933 m .71212 .34008 L .71302 .35444 L .965 .686 .26 r
F
.71178 .33933 m .71302 .35444 L .7129 .35418 L F
.71471 .35805 m .71236 .362 L .71644 .36176 L .645 .736 .915 r
F
.71236 .362 m .7059 .37288 L .71219 .36624 L F
.71236 .362 m .71219 .36624 L .71644 .36176 L F
.71178 .33933 m .7129 .35418 L .71276 .35387 L .965 .686 .26 r
F
.71212 .34008 m .71317 .35458 L .71302 .35444 L .947 .644 .431 r
F
.71212 .34008 m .71278 .34072 L .71368 .35507 L F
.71212 .34008 m .71368 .35507 L .71317 .35458 L F
.7125 .33735 m .71181 .33846 L .71272 .35288 L .076 0 .438 r
F
.71471 .35805 m .70377 .36611 L .7059 .37288 L .645 .736 .915 r
F
.71389 .3563 m .7052 .364 L .71471 .35805 L F
.7052 .364 m .69802 .37035 L .70377 .36611 L F
.7052 .364 m .70377 .36611 L .71471 .35805 L F
.71644 .36176 m .71219 .36624 L .71457 .37405 L F
.71219 .36624 m .7119 .37369 L .71457 .37405 L F
.71964 .37536 m .71455 .38224 L .71981 .37572 L .644 .736 .916 r
F
.71745 .37453 m .71455 .38224 L .72073 .37388 L F
.7151 .37134 m .71484 .36817 L .72021 .36774 L .663 .419 .54 r
F
.71549 .36371 m .71485 .3681 L .7202 .36768 L .668 .747 .91 r
F
.71607 .37402 m .7151 .37134 L .72048 .37091 L .663 .419 .54 r
F
.71575 .36693 m .7151 .37134 L .72048 .37091 L .667 .747 .91 r
F
.71661 .374 m .71455 .38224 L .71766 .37397 L .644 .736 .916 r
F
.72073 .37388 m .71964 .37536 L .72131 .37387 L F
.71766 .37397 m .71745 .37453 L .72073 .37388 L F
.7164 .37401 m .71455 .38224 L .71661 .374 L F
.71607 .37402 m .72048 .37091 L .72073 .37388 L .663 .419 .54 r
F
.71533 .37404 m .7151 .37134 L .71607 .37402 L F
.71549 .36371 m .7202 .36768 L .71906 .36342 L .668 .747 .91 r
F
.71549 .34151 m .71818 .35577 L .7168 .35588 L .638 .394 .533 r
F
.7138 .34123 m .71549 .34151 L .71641 .35592 L .753 .483 .523 r
F
.7138 .34123 m .71641 .35592 L .71509 .35566 L F
.71549 .34151 m .7168 .35588 L .71641 .35592 L .638 .394 .533 r
F
.71781 .35283 m .71471 .35805 L .71644 .36176 L .645 .736 .915 r
F
.71613 .35929 m .71549 .36371 L .71906 .36342 L .668 .747 .91 r
F
.7164 .36249 m .71575 .36693 L .71934 .36664 L .667 .747 .91 r
F
.7164 .36249 m .71934 .36664 L .7182 .36235 L F
.7172 .36498 m .71709 .36571 L .71841 .36507 L .644 .736 .916 r
F
.71575 .36693 m .72048 .37091 L .71934 .36664 L .667 .747 .91 r
F
.71709 .36571 m .71455 .38224 L .71806 .36663 L .644 .736 .916 r
F
.71709 .36571 m .71806 .36663 L .71841 .36507 L F
.71389 .3563 m .69146 .36663 L .69802 .37035 L .645 .736 .915 r
F
.7138 .34123 m .71509 .35566 L .71472 .35559 L .753 .483 .523 r
F
.71278 .34072 m .71391 .35518 L .71368 .35507 L .857 .566 .495 r
F
.71278 .34072 m .71472 .35559 L .71391 .35518 L F
.71781 .35283 m .71336 .35516 L .71389 .3563 L .645 .736 .915 r
F
.71336 .35516 m .69146 .36663 L .71389 .3563 L F
.71781 .35283 m .70537 .35648 L .69146 .36663 L F
.70537 .35648 m .68665 .36196 L .69007 .36528 L F
.70537 .35648 m .69007 .36528 L .69146 .36663 L F
.71381 .33651 m .7125 .33735 L .71342 .35185 L .414 .228 .517 r
F
.71781 .35283 m .71389 .3563 L .71471 .35805 L .645 .736 .915 r
F
.71439 .35913 m .71549 .36371 L .71613 .35929 L .668 .747 .91 r
F
.712 .36339 m .71485 .3681 L .71549 .36371 L F
.71439 .35913 m .712 .36339 L .71549 .36371 L F
.71464 .36233 m .71575 .36693 L .7164 .36249 L .667 .747 .91 r
F
.71391 .35518 m .71472 .35559 L .71483 .35735 L .857 .566 .495 r
F
.71631 .35805 m .71439 .35913 L .71613 .35929 L .668 .747 .91 r
F
.71598 .35789 m .71439 .35913 L .71631 .35805 L F
.71534 .35743 m .71439 .35913 L .71638 .35758 L F
.7128 .35868 m .712 .36339 L .71439 .35913 L F
.71219 .36624 m .7059 .37288 L .7119 .37369 L .645 .736 .915 r
F
.712 .36339 m .70963 .36763 L .71485 .3681 L .668 .747 .91 r
F
.71304 .36188 m .71224 .36661 L .71464 .36233 L .667 .747 .91 r
F
.71502 .358 m .7128 .35868 L .71439 .35913 L .668 .747 .91 r
F
.71391 .35518 m .71483 .35735 L .71405 .35698 L .857 .566 .495 r
F
.71509 .35566 m .71525 .35741 L .71472 .35559 L .753 .483 .523 r
F
.71525 .35741 m .71496 .35737 L .71472 .35559 L F
.71534 .35743 m .71425 .35729 L .71502 .358 L .668 .747 .91 r
F
.71425 .35729 m .71382 .35771 L .71502 .358 L F
.71382 .35771 m .7128 .35868 L .71409 .35829 L F
.71382 .35771 m .71409 .35829 L .71502 .358 L F
.71178 .33933 m .71276 .35387 L .71269 .35371 L .965 .686 .26 r
F
.71181 .33846 m .71178 .33933 L .71269 .35371 L 0 0 .132 r
F
.71181 .33846 m .71269 .35371 L .71271 .35306 L F
.70537 .35648 m .68393 .35665 L .68665 .36196 L .645 .736 .915 r
F
.71781 .35283 m .71021 .35369 L .70537 .35648 L F
.71021 .35369 m .68393 .35665 L .70537 .35648 L F
.71658 .36123 m .71464 .36233 L .7164 .36249 L .667 .747 .91 r
F
.71665 .36074 m .71624 .36106 L .71658 .36123 L F
.71624 .36106 m .71464 .36233 L .71658 .36123 L F
.71427 .35727 m .71425 .35729 L .71534 .35743 L .668 .747 .91 r
F
.71496 .35737 m .71489 .35736 L .71472 .35559 L .753 .483 .523 r
F
.71317 .35458 m .71368 .35507 L .7138 .35686 L .947 .644 .431 r
F
.71317 .35458 m .7138 .35686 L .7134 .35649 L F
.71425 .35729 m .71149 .35797 L .7128 .35868 L .668 .747 .91 r
F
.71391 .35518 m .71405 .35698 L .71368 .35507 L .857 .566 .495 r
F
.7138 .35686 m .71341 .35684 L .71425 .35729 L .668 .747 .91 r
F
.71341 .35684 m .71369 .35743 L .71425 .35729 L F
.70985 .37086 m .71484 .36817 L .7151 .37134 L .731 .47 .533 r
F
.70985 .37086 m .7096 .36769 L .71484 .36817 L F
.71115 .37348 m .7151 .37134 L .71533 .37404 L F
.71115 .37348 m .70985 .37086 L .7151 .37134 L F
.71041 .37338 m .71037 .37343 L .7127 .37368 L .644 .736 .916 r
F
.71037 .37343 m .70582 .38106 L .71235 .37406 L F
.71037 .37343 m .71235 .37406 L .7127 .37368 L F
.70377 .36611 m .70039 .37111 L .7059 .37288 L .645 .736 .915 r
F
.70655 .37221 m .70985 .37086 L .71005 .37333 L .8 .522 .518 r
F
.71005 .37333 m .70985 .37086 L .71115 .37348 L .731 .47 .533 r
F
.70509 .36952 m .7096 .36769 L .70985 .37086 L .8 .522 .518 r
F
.71224 .36661 m .70985 .37086 L .7151 .37134 L .667 .747 .91 r
F
.70655 .37221 m .70509 .36952 L .70985 .37086 L .8 .522 .518 r
F
.70527 .3718 m .70509 .36952 L .70655 .37221 L F
.71224 .36661 m .7151 .37134 L .71575 .36693 L .667 .747 .91 r
F
.70509 .36952 m .70483 .36634 L .7096 .36769 L .8 .522 .518 r
F
.70884 .36249 m .70963 .36763 L .712 .36339 L .668 .747 .91 r
F
.70884 .36249 m .70489 .36629 L .70963 .36763 L F
.70906 .36571 m .70985 .37086 L .71224 .36661 L .667 .747 .91 r
F
.70906 .36571 m .70509 .36952 L .70985 .37086 L F
.71464 .36233 m .71224 .36661 L .71575 .36693 L F
.71299 .36637 m .70584 .37212 L .71288 .36924 L .644 .736 .916 r
F
.70584 .37212 m .70507 .37274 L .70611 .37227 L F
.70584 .37212 m .70611 .37227 L .71288 .36924 L F
.71341 .35684 m .71149 .35797 L .71369 .35743 L .668 .747 .91 r
F
.71276 .35387 m .71288 .3557 L .71269 .35371 L .965 .686 .26 r
F
.71288 .3557 m .71283 .35558 L .71269 .35371 L F
.71341 .35684 m .71053 .35705 L .71149 .35797 L .668 .747 .91 r
F
.71317 .35458 m .7133 .3564 L .71302 .35444 L .947 .644 .431 r
F
.71314 .35625 m .71277 .35626 L .71341 .35684 L .668 .747 .91 r
F
.71309 .35615 m .71305 .35616 L .71314 .35625 L F
.7133 .3564 m .71319 .3563 L .71302 .35444 L .947 .644 .431 r
F
.71269 .35371 m .71283 .35558 L .7128 .35552 L .965 .686 .26 r
F
.71277 .35626 m .71 .35597 L .71053 .35705 L .668 .747 .91 r
F
.71405 .35698 m .71383 .35688 L .71368 .35507 L .857 .566 .495 r
F
.71368 .35507 m .71383 .35688 L .7138 .35686 L F
.71317 .35458 m .7134 .35649 L .7133 .3564 L .947 .644 .431 r
F
.7129 .35418 m .71302 .35444 L .71314 .35625 L .965 .686 .26 r
F
.7129 .35418 m .71314 .35625 L .71305 .35605 L F
.71468 .36227 m .71304 .36188 L .71464 .36233 L .667 .747 .91 r
F
.71431 .36149 m .71304 .36188 L .71468 .36227 L F
.7145 .36048 m .71405 .36092 L .71527 .3612 L F
.71405 .36092 m .71304 .36188 L .71431 .36149 L F
.71405 .36092 m .71431 .36149 L .71527 .3612 L F
.71319 .3563 m .71316 .35627 L .71302 .35444 L .947 .644 .431 r
F
.71276 .35387 m .71293 .35581 L .71288 .3557 L .965 .686 .26 r
F
.71309 .35615 m .71278 .35592 L .71305 .35616 L .668 .747 .91 r
F
.71405 .36092 m .71292 .36087 L .71304 .36188 L .667 .747 .91 r
F
.71391 .36063 m .71292 .36087 L .71405 .36092 L F
.71405 .35698 m .7143 .36015 L .71383 .35688 L .857 .566 .495 r
F
.7143 .36015 m .71454 .36312 L .7142 .3601 L F
.7143 .36015 m .7142 .3601 L .71383 .35688 L F
.714 .36001 m .71364 .36004 L .7145 .36048 L .667 .747 .91 r
F
.71388 .3599 m .71383 .35993 L .714 .36001 L F
.71383 .35993 m .71364 .36004 L .714 .36001 L F
.71364 .36004 m .71293 .36045 L .71391 .36063 L F
.71293 .36045 m .71292 .36087 L .71391 .36063 L F
.71277 .35626 m .71275 .35689 L .71341 .35684 L .668 .747 .91 r
F
.71296 .35587 m .71278 .35592 L .71309 .35615 L F
.71293 .35581 m .71324 .35918 L .71288 .3557 L .965 .686 .26 r
F
.7128 .35868 m .70884 .36249 L .712 .36339 L .668 .747 .91 r
F
.71149 .35797 m .70884 .36249 L .7128 .35868 L F
.71293 .36045 m .71076 .36024 L .71172 .36117 L .667 .747 .91 r
F
.71364 .36004 m .71294 .36009 L .71293 .36045 L F
.71294 .36009 m .71076 .36024 L .71293 .36045 L F
.71302 .35444 m .71316 .35627 L .71314 .35625 L .947 .644 .431 r
F
.7129 .35418 m .71305 .35605 L .71276 .35387 L .965 .686 .26 r
F
.71305 .35605 m .71295 .35585 L .71276 .35387 L F
.71305 .35616 m .71277 .35626 L .71314 .35625 L .668 .747 .91 r
F
.71329 .3593 m .71324 .35918 L .71293 .35581 L .965 .686 .26 r
F
.71295 .35585 m .71293 .35581 L .71276 .35387 L F
.71329 .3593 m .71293 .35581 L .71295 .35585 L F
.7128 .35551 m .70993 .35482 L .71 .35597 L .668 .747 .91 r
F
.7125 .33735 m .71272 .35288 L .71326 .35208 L .076 0 .438 r
F
.71181 .33846 m .71271 .35306 L .71272 .35288 L 0 0 .132 r
F
.6987 .35498 m .6835 .35104 L .68393 .35665 L .645 .736 .915 r
F
.71781 .35283 m .70936 .35239 L .6987 .35498 L F
.70936 .35239 m .6835 .35104 L .6987 .35498 L F
.71505 .33614 m .71381 .33651 L .71474 .35109 L .566 .34 .531 r
F
.71678 .35486 m .71282 .35484 L .7128 .35551 L .668 .747 .91 r
F
.71678 .35486 m .7128 .35551 L .7128 .35552 L F
.71381 .33651 m .71342 .35185 L .71444 .35126 L .414 .228 .517 r
F
.7125 .33735 m .71326 .35208 L .71342 .35185 L .076 0 .438 r
F
.71781 .35283 m .71249 .35163 L .70936 .35239 L .645 .736 .915 r
F
.71314 .35625 m .71339 .35944 L .71334 .35939 L .947 .644 .431 r
F
.71359 .35993 m .71295 .36 L .71364 .36004 L .667 .747 .91 r
F
.71295 .36 m .71076 .36024 L .71294 .36009 L F
.71295 .36 m .71294 .36009 L .71364 .36004 L F
.71297 .35946 m .71295 .36 L .71359 .35993 L F
.71283 .35558 m .71307 .35882 L .7128 .35552 L .965 .686 .26 r
F
.71307 .35882 m .71306 .35879 L .7128 .35552 L F
.71316 .35627 m .7134 .35945 L .71314 .35625 L .947 .644 .431 r
F
.71329 .35935 m .71359 .35993 L .71334 .35939 L .667 .747 .91 r
F
.7134 .35945 m .71362 .36241 L .71339 .35944 L .947 .644 .431 r
F
.7134 .35945 m .71339 .35944 L .71314 .35625 L F
.71678 .35486 m .71296 .35587 L .71309 .35615 L .668 .747 .91 r
F
.71678 .35486 m .7128 .35552 L .71296 .35587 L F
.71272 .35484 m .71033 .35367 L .70993 .35482 L F
.71329 .35935 m .71209 .35928 L .71169 .35991 L .667 .747 .91 r
F
.71296 .35587 m .7128 .35552 L .71278 .35592 L .668 .747 .91 r
F
.71288 .3557 m .7131 .35888 L .71283 .35558 L .965 .686 .26 r
F
.71149 .35797 m .70621 .36108 L .70884 .36249 L .668 .747 .91 r
F
.71266 .35876 m .71022 .35916 L .71329 .35935 L .667 .747 .91 r
F
.7131 .35888 m .7133 .36184 L .71307 .35882 L .965 .686 .26 r
F
.71305 .35616 m .71278 .35592 L .71277 .35626 L .668 .747 .91 r
F
.7131 .35888 m .71307 .35882 L .71283 .35558 L .965 .686 .26 r
F
.71331 .35934 m .71266 .35876 L .71329 .35935 L .667 .747 .91 r
F
.71324 .35918 m .71321 .35913 L .71288 .3557 L .965 .686 .26 r
F
.71288 .3557 m .71321 .35913 L .7131 .35888 L F
.71305 .35605 m .71329 .3593 L .71295 .35585 L F
.71346 .35951 m .7134 .35945 L .71316 .35627 L .947 .644 .431 r
F
.7128 .35552 m .71306 .35879 L .713 .35866 L .965 .686 .26 r
F
.71329 .35935 m .71297 .35946 L .71359 .35993 L .667 .747 .91 r
F
.71334 .35939 m .71359 .35993 L .71388 .3599 L F
.71348 .35952 m .71316 .35627 L .71319 .3563 L .947 .644 .431 r
F
.71375 .36253 m .71346 .35951 L .71348 .35952 L F
.71346 .35951 m .71316 .35627 L .71348 .35952 L F
.71053 .35705 m .70621 .36108 L .71149 .35797 L .668 .747 .91 r
F
.71266 .35876 m .71015 .358 L .71022 .35916 L .667 .747 .91 r
F
.71282 .35487 m .71301 .35835 L .71302 .35806 L 0 0 .132 r
F
.71282 .35487 m .71302 .35806 L .71283 .35475 L F
.71302 .35806 m .71302 .35799 L .71283 .35473 L F
.71283 .35475 m .71283 .35473 L .71272 .35288 L F
.71302 .35806 m .71283 .35473 L .71283 .35475 L F
.71283 .35466 m .71033 .35367 L .71272 .35484 L .668 .747 .91 r
F
.71326 .35208 m .71283 .35466 L .71318 .35411 L .076 0 .438 r
F
.71313 .35419 m .71285 .35413 L .71283 .35466 L .668 .747 .91 r
F
.71282 .35487 m .71283 .35475 L .71272 .35288 L 0 0 .132 r
F
.71271 .35306 m .71282 .355 L .71282 .35487 L F
.71271 .35306 m .71269 .35371 L .7128 .35552 L F
.71271 .35306 m .7128 .35552 L .71282 .355 L F
.71678 .35486 m .71283 .35466 L .71282 .35484 L .668 .747 .91 r
F
.71283 .35466 m .71303 .35783 L .71303 .3578 L 0 0 .132 r
F
.71272 .35288 m .71283 .35467 L .71283 .35466 L F
.71283 .35467 m .71303 .35783 L .71283 .35466 L F
.71288 .35329 m .71239 .35168 L .71116 .3526 L .668 .747 .91 r
F
.71326 .35208 m .71272 .35288 L .71283 .35466 L .076 0 .438 r
F
.71326 .35208 m .71318 .35411 L .71335 .35384 L F
.71326 .35208 m .71335 .35384 L .71342 .35185 L F
.71678 .35486 m .71354 .35356 L .71313 .35419 L .668 .747 .91 r
F
.71354 .35356 m .71352 .35357 L .71313 .35419 L F
.70982 .35103 m .68956 .34046 L .68541 .34552 L .645 .736 .915 r
F
.71781 .35283 m .71336 .35089 L .70982 .35103 L F
.71336 .35089 m .68956 .34046 L .70982 .35103 L F
.71626 .33605 m .71505 .33614 L .71599 .35078 L .657 .408 .532 r
F
.71505 .33614 m .71474 .35109 L .71571 .35085 L .566 .34 .531 r
F
.71381 .33651 m .71444 .35126 L .71474 .35109 L .414 .228 .517 r
F
.71336 .35089 m .69567 .33623 L .68956 .34046 L .645 .736 .915 r
F
.71781 .35283 m .71512 .35082 L .71336 .35089 L F
.71512 .35082 m .69567 .33623 L .71336 .35089 L F
.71527 .3612 m .71431 .36149 L .71468 .36227 L .667 .747 .91 r
F
.71562 .36058 m .71553 .36073 L .71665 .36074 L F
.71553 .36073 m .71464 .36233 L .71624 .36106 L F
.71553 .36073 m .71624 .36106 L .71665 .36074 L F
.7143 .36015 m .71522 .36347 L .71454 .36312 L .857 .566 .495 r
F
.71405 .35698 m .71465 .36032 L .7143 .36015 L F
.71465 .36032 m .71522 .36347 L .7143 .36015 L F
.71465 .36032 m .71503 .36049 L .71522 .36347 L F
.7158 .36358 m .71548 .36352 L .71519 .36052 L .753 .483 .523 r
F
.7144 .35715 m .7138 .35686 L .71425 .35729 L .668 .747 .91 r
F
.71405 .35698 m .71483 .35735 L .71503 .36049 L .857 .566 .495 r
F
.71405 .35698 m .71503 .36049 L .71465 .36032 L F
.71535 .36054 m .71519 .36052 L .71489 .35736 L .753 .483 .523 r
F
.71562 .36058 m .7145 .36048 L .71527 .3612 L .667 .747 .91 r
F
.71539 .36055 m .71489 .35736 L .71496 .35737 L .753 .483 .523 r
F
.71535 .36054 m .71489 .35736 L .71539 .36055 L F
.71456 .36042 m .7145 .36048 L .71562 .36058 L .667 .747 .91 r
F
.71525 .35741 m .71553 .36057 L .71496 .35737 L .753 .483 .523 r
F
.71553 .36057 m .7158 .36358 L .71539 .36055 L F
.71553 .36057 m .71539 .36055 L .71496 .35737 L F
.7145 .36048 m .71391 .36063 L .71405 .36092 L .667 .747 .91 r
F
.71454 .36312 m .71434 .36303 L .7141 .36006 L .857 .566 .495 r
F
.7142 .3601 m .7141 .36006 L .71383 .35688 L F
.71454 .36312 m .7141 .36006 L .7142 .3601 L F
.71364 .36004 m .71391 .36063 L .7145 .36048 L .667 .747 .91 r
F
.7138 .35686 m .71434 .36303 L .71418 .36295 L .857 .566 .495 r
F
.71456 .36027 m .714 .36001 L .71442 .3604 L .667 .747 .91 r
F
.71383 .35688 m .71434 .36303 L .7138 .35686 L .857 .566 .495 r
F
.71472 .35559 m .71548 .36352 L .71522 .36347 L .753 .483 .523 r
F
.71638 .35758 m .71598 .35789 L .71631 .35805 L .668 .747 .91 r
F
.71613 .35929 m .71906 .36342 L .71792 .35915 L F
.71509 .35566 m .71641 .35592 L .71652 .3576 L .753 .483 .523 r
F
.71755 .35776 m .71613 .35929 L .71792 .35915 L .668 .747 .91 r
F
.71652 .3576 m .71613 .35929 L .71755 .35776 L F
.71638 .35758 m .71638 .35762 L .71652 .3576 L F
.71638 .35762 m .71613 .35929 L .71652 .3576 L F
.7168 .35588 m .71818 .35577 L .71828 .35737 L .638 .394 .533 r
F
.7168 .35588 m .71828 .35737 L .71695 .35754 L F
.71641 .35592 m .71658 .3576 L .71652 .3576 L F
.71748 .35747 m .71652 .3576 L .71755 .35776 L .668 .747 .91 r
F
.71727 .3645 m .71659 .36523 L .71709 .36571 L .644 .736 .916 r
F
.71737 .36388 m .71697 .36435 L .71727 .3645 L F
.71697 .36435 m .71288 .36924 L .71727 .3645 L F
.71549 .35745 m .71652 .3576 L .71672 .36075 L .753 .483 .523 r
F
.71781 .36091 m .7164 .36249 L .7182 .36235 L .667 .747 .91 r
F
.71755 .36087 m .7164 .36249 L .71781 .36091 L F
.71665 .36076 m .7164 .36249 L .71755 .36087 L F
.71672 .36075 m .71755 .36087 L .71773 .36061 L F
.71665 .36076 m .71755 .36087 L .71672 .36075 L F
.71553 .36057 m .71692 .36379 L .7158 .36358 L .753 .483 .523 r
F
.71509 .35566 m .71621 .36067 L .71553 .36057 L F
.71621 .36067 m .71692 .36379 L .71553 .36057 L F
.71621 .36067 m .71672 .36075 L .71692 .36379 L F
.71549 .35745 m .71672 .36075 L .71621 .36067 L F
.71773 .36061 m .71755 .36087 L .71781 .36091 L .667 .747 .91 r
F
.7168 .35588 m .71724 .36068 L .71641 .35592 L .638 .394 .533 r
F
.71724 .36068 m .71709 .3607 L .71641 .35592 L F
.71752 .36374 m .71719 .36377 L .71641 .35592 L F
.71739 .36375 m .71692 .36379 L .71737 .36388 L .644 .736 .916 r
F
.71709 .36571 m .71288 .36924 L .71346 .37379 L F
.71709 .36571 m .71346 .37379 L .7158 .3741 L F
.71659 .36523 m .71288 .36924 L .71709 .36571 L F
.71692 .36379 m .71288 .36924 L .71737 .36388 L F
.7158 .3741 m .71346 .37379 L .71455 .38224 L F
.71537 .37452 m .71607 .37402 L .72075 .37409 L .663 .419 .54 r
F
.71607 .37402 m .72073 .37388 L .72075 .37409 L F
.71828 .36564 m .7164 .37401 L .71888 .36491 L .644 .736 .916 r
F
.7164 .37401 m .71661 .374 L .71888 .36491 L F
.71838 .36693 m .71661 .374 L .71979 .36828 L F
.71661 .374 m .71766 .37397 L .71979 .36828 L F
.72105 .37382 m .72048 .37091 L .72563 .36962 L .59 .365 .542 r
F
.72073 .37388 m .72048 .37091 L .72105 .37382 L F
.72048 .37091 m .72536 .36644 L .72563 .36962 L F
.71906 .36342 m .7202 .36768 L .72532 .36639 L .668 .747 .91 r
F
.71934 .36664 m .72048 .37091 L .72563 .36962 L .667 .747 .91 r
F
.71979 .36828 m .71766 .37397 L .72073 .37388 L .644 .736 .916 r
F
.72128 .37378 m .72073 .37388 L .72131 .37387 L F
.72105 .37382 m .72563 .36962 L .72458 .37313 L .59 .365 .542 r
F
.71979 .36828 m .72073 .37388 L .72128 .37378 L .644 .736 .916 r
F
.72458 .37313 m .72563 .36962 L .72591 .3728 L .59 .365 .542 r
F
.71964 .37536 m .71981 .37572 L .72131 .37387 L .644 .736 .916 r
F
.72267 .35393 m .74571 .36506 L .75 .36011 L .645 .736 .915 r
F
.71781 .35283 m .72533 .35613 L .72267 .35393 L F
.72533 .35613 m .74571 .36506 L .72267 .35393 L F
.71963 .33748 m .71856 .33659 L .71952 .35133 L .928 .626 .449 r
F
.71934 .36664 m .72563 .36962 L .72278 .36577 L .667 .747 .91 r
F
.72366 .37154 m .7235 .38199 L .72833 .38105 L .644 .736 .916 r
F
.72072 .36651 m .7235 .38199 L .72366 .37154 L F
.71892 .36289 m .71906 .36342 L .71949 .36332 L .668 .747 .91 r
F
.71892 .36289 m .71949 .36332 L .72248 .36256 L F
.71792 .35915 m .71892 .36289 L .72248 .36256 L F
.71906 .36342 m .72532 .36639 L .72248 .36256 L F
.7182 .36235 m .71934 .36664 L .72278 .36577 L .667 .747 .91 r
F
.72021 .36591 m .7235 .38199 L .72072 .36651 L .644 .736 .916 r
F
.72038 .36526 m .72306 .36895 L .72404 .36851 L .667 .747 .91 r
F
.72036 .36533 m .72306 .36895 L .72038 .36526 L F
.72185 .35586 m .73197 .37213 L .73956 .36915 L .645 .736 .915 r
F
.72253 .35785 m .73197 .37213 L .72185 .35586 L F
.72563 .36962 m .72536 .36644 L .72993 .36436 L .502 .301 .539 r
F
.72248 .36256 m .72532 .36639 L .72987 .36431 L .668 .747 .91 r
F
.72563 .36962 m .72993 .36436 L .73021 .36753 L .502 .301 .539 r
F
.72278 .36577 m .72563 .36962 L .73021 .36753 L .667 .747 .91 r
F
.7204 .36518 m .72404 .36851 L .72332 .3664 L F
.72019 .3651 m .72038 .36526 L .7204 .36518 L F
.72038 .36526 m .72404 .36851 L .7204 .36518 L F
.71964 .35872 m .72248 .36256 L .72552 .36117 L .668 .747 .91 r
F
.71792 .35915 m .72248 .36256 L .71964 .35872 L F
.71964 .35872 m .72552 .36117 L .72116 .35802 L F
.72248 .36256 m .72987 .36431 L .72552 .36117 L F
.72027 .36176 m .72584 .36438 L .72145 .36121 L .667 .747 .91 r
F
.71992 .36191 m .7202 .36203 L .72027 .36176 L F
.7202 .36203 m .72584 .36438 L .72027 .36176 L F
.71954 .35524 m .72019 .35481 L .72029 .35628 L .379 .203 .512 r
F
.72036 .35744 m .72009 .35851 L .72116 .35802 L .668 .747 .91 r
F
.71952 .35684 m .72009 .35851 L .72036 .35744 L F
.71844 .35568 m .71935 .35536 L .71945 .35689 L .519 .305 .529 r
F
.71884 .35714 m .71895 .35726 L .71945 .35689 L .668 .747 .91 r
F
.71895 .35726 m .72009 .35851 L .71952 .35684 L F
.71895 .35726 m .71964 .35872 L .72009 .35851 L F
.71876 .35637 m .71849 .3575 L .71915 .35783 L .645 .736 .915 r
F
.71859 .35573 m .71846 .35631 L .71876 .35637 L F
.71844 .35568 m .71945 .35689 L .71857 .35725 L .519 .305 .529 r
F
.71884 .35714 m .71869 .35744 L .71895 .35726 L .668 .747 .91 r
F
.71818 .35577 m .71832 .35735 L .71828 .35737 L .519 .305 .529 r
F
.71856 .35726 m .71869 .35744 L .71884 .35714 L .668 .747 .91 r
F
.72226 .36915 m .72591 .3728 L .72306 .36895 L .667 .747 .91 r
F
.72381 .37181 m .72591 .3728 L .72226 .36915 L F
.72381 .37181 m .72458 .37313 L .72591 .3728 L F
.72591 .3728 m .72563 .36962 L .73021 .36753 L .502 .301 .539 r
F
.72591 .3728 m .73021 .36753 L .73049 .37071 L F
.72306 .36895 m .72591 .3728 L .73049 .37071 L .667 .747 .91 r
F
.72306 .36895 m .73049 .37071 L .72611 .36756 L F
.71828 .36233 m .72278 .36577 L .71992 .36191 L F
.7182 .36235 m .71824 .36238 L .71828 .36233 L F
.71824 .36238 m .72278 .36577 L .71828 .36233 L F
.72062 .3564 m .72116 .35802 L .72238 .35711 L .668 .747 .91 r
F
.72032 .35465 m .72042 .3561 L .72019 .35481 L .157 .044 .463 r
F
.72042 .3561 m .72034 .35622 L .72019 .35481 L F
.72083 .3556 m .72238 .35711 L .72322 .35604 L .668 .747 .91 r
F
.7203 .35627 m .72062 .3564 L .72081 .3556 L F
.72062 .3564 m .72238 .35711 L .72083 .35561 L F
.72062 .3564 m .72083 .35561 L .72081 .3556 L F
.72054 .35675 m .72116 .35802 L .72062 .3564 L F
.71974 .357 m .72116 .35802 L .7203 .35627 L F
.71844 .35568 m .71857 .35725 L .71818 .35577 L .519 .305 .529 r
F
.71869 .35744 m .71792 .35915 L .71964 .35872 L .668 .747 .91 r
F
.71856 .35726 m .71843 .35763 L .71869 .35744 L F
.71843 .35763 m .71792 .35915 L .71869 .35744 L F
.71912 .36043 m .71992 .36191 L .72027 .36176 L .667 .747 .91 r
F
.71901 .3603 m .71909 .36045 L .71912 .36043 L F
.71909 .36045 m .71992 .36191 L .71912 .36043 L F
.71879 .36039 m .71892 .36057 L .71901 .3603 L F
.71892 .36057 m .71992 .36191 L .71909 .36045 L F
.71892 .36057 m .71909 .36045 L .71901 .3603 L F
.71948 .35687 m .71973 .35998 L .71945 .35689 L .379 .203 .512 r
F
.71973 .35998 m .71971 .36 L .71945 .35689 L F
.71945 .35689 m .71971 .36 L .71965 .36004 L F
.71883 .36037 m .71873 .36041 L .71836 .35733 L .519 .305 .529 r
F
.71883 .36037 m .71836 .35733 L .7184 .35732 L F
.71753 .35767 m .71792 .35915 L .71856 .35726 L .668 .747 .91 r
F
.71857 .35725 m .71883 .36037 L .7184 .35732 L .519 .305 .529 r
F
.71976 .35999 m .72027 .36176 L .72057 .36058 L .667 .747 .91 r
F
.71873 .36041 m .71859 .36047 L .71818 .35577 L .519 .305 .529 r
F
.72057 .36058 m .72027 .36176 L .72145 .36121 L .667 .747 .91 r
F
.71992 .36191 m .72278 .36577 L .72584 .36438 L F
.71869 .36364 m .71877 .36395 L .7191 .36374 L .644 .736 .916 r
F
.71998 .36314 m .72019 .3651 L .72172 .3644 L .667 .747 .91 r
F
.71869 .36364 m .7191 .36374 L .71903 .36362 L .644 .736 .916 r
F
.71869 .36364 m .71877 .36363 L .71869 .36366 L .519 .305 .529 r
F
.71828 .35737 m .71856 .36048 L .71848 .36051 L F
.71695 .35754 m .71828 .35737 L .71848 .36051 L .638 .394 .533 r
F
.71892 .36057 m .7182 .36235 L .71992 .36191 L .667 .747 .91 r
F
.71885 .36046 m .71877 .36068 L .71892 .36057 L F
.71877 .36068 m .7182 .36235 L .71892 .36057 L F
.71954 .35524 m .71966 .35674 L .71935 .35536 L .379 .203 .512 r
F
.71966 .35674 m .71953 .35683 L .71935 .35536 L F
.7199 .35986 m .71973 .35998 L .71935 .35536 L F
.71935 .35536 m .71948 .35687 L .71945 .35689 L F
.72083 .35956 m .72145 .36121 L .72084 .35956 L .667 .747 .91 r
F
.7203 .35627 m .72054 .35675 L .72062 .3564 L .668 .747 .91 r
F
.72042 .3561 m .72087 .35894 L .72066 .35922 L .157 .044 .463 r
F
.72032 .35465 m .72049 .35602 L .72042 .3561 L F
.72049 .35602 m .72087 .35894 L .72042 .3561 L F
.72136 .35488 m .72322 .35604 L .72363 .35489 L .668 .747 .91 r
F
.72029 .35628 m .72054 .35936 L .72049 .35943 L .157 .044 .463 r
F
.72019 .35481 m .7203 .35626 L .72029 .35628 L F
.7203 .35626 m .72054 .35936 L .72029 .35628 L F
.72 .33861 m .72059 .35222 L .72088 .35306 L .925 .667 .181 r
F
.72 .33861 m .72088 .35306 L .72097 .3533 L F
.72445 .35318 m .75 .36011 L .75212 .35463 L .645 .736 .915 r
F
.71781 .35283 m .73219 .35608 L .72445 .35318 L F
.73219 .35608 m .75 .36011 L .72445 .35318 L F
.72075 .35413 m .72085 .35554 L .72084 .35556 L 0 0 .297 r
F
.72085 .3555 m .72085 .35554 L .72075 .35413 L F
.72034 .35622 m .7203 .35626 L .72019 .35481 L .157 .044 .463 r
F
.72086 .35548 m .72085 .3555 L .72075 .35413 L 0 0 .297 r
F
.7208 .35394 m .72089 .35535 L .72075 .35413 L F
.72089 .35535 m .72086 .35548 L .72075 .35413 L F
.71963 .33748 m .72035 .35202 L .72059 .35222 L .928 .626 .449 r
F
.72102 .35189 m .75191 .349 L .74936 .34359 L .645 .736 .915 r
F
.71781 .35283 m .72221 .35234 L .72102 .35189 L F
.72221 .35234 m .75191 .349 L .72102 .35189 L F
.71856 .33659 m .71743 .33619 L .71838 .35091 L .818 .533 .507 r
F
.7208 .35394 m .7209 .35356 L .72095 .35513 L 0 0 .297 r
F
.7208 .35394 m .72095 .35513 L .72089 .35535 L F
.72099 .35498 m .72097 .3533 L .72106 .3547 L F
.7209 .35356 m .72099 .35498 L .72095 .35513 L F
.72032 .35465 m .72075 .35413 L .72084 .35556 L .157 .044 .463 r
F
.72081 .3556 m .72083 .3556 L .72084 .35556 L .668 .747 .91 r
F
.72032 .35465 m .72084 .35556 L .72049 .35602 L .157 .044 .463 r
F
.71781 .35283 m .71735 .35584 L .71859 .35573 L .645 .736 .915 r
F
.71678 .35486 m .72101 .35488 L .72088 .35418 L .668 .747 .91 r
F
.7209 .35356 m .72097 .3533 L .72099 .35498 L 0 0 .297 r
F
.71954 .35524 m .71976 .35667 L .71966 .35674 L .379 .203 .512 r
F
.71954 .35524 m .72029 .35628 L .71976 .35667 L F
.71678 .35486 m .72081 .3556 L .72119 .35509 L .668 .747 .91 r
F
.72112 .35488 m .72119 .35509 L .72136 .35488 L F
.71678 .35486 m .72119 .35509 L .72112 .35488 L F
.72103 .35877 m .72184 .35953 L .72162 .35887 L .667 .747 .91 r
F
.721 .35876 m .72103 .35878 L .72103 .35877 L F
.72103 .35878 m .72184 .35953 L .72103 .35877 L F
.72083 .3556 m .7214 .3557 L .72084 .35556 L .668 .747 .91 r
F
.7214 .3557 m .72322 .35604 L .72139 .35567 L F
.7214 .3557 m .72139 .35567 L .72084 .35556 L F
.72088 .35306 m .72097 .35443 L .72097 .3533 L .925 .667 .181 r
F
.72083 .35561 m .72238 .35711 L .72083 .3556 L .668 .747 .91 r
F
.72101 .35703 m .72099 .35498 L .72123 .35799 L 0 0 .297 r
F
.72101 .35488 m .72112 .35488 L .72106 .3547 L .668 .747 .91 r
F
.72099 .35498 m .72106 .3547 L .72127 .35785 L 0 0 .297 r
F
.72083 .35955 m .72201 .36003 L .72102 .35879 L .667 .747 .91 r
F
.72201 .36003 m .72184 .35953 L .72103 .35878 L F
.72102 .35879 m .72103 .35878 L .721 .35876 L F
.72201 .36003 m .72103 .35878 L .72102 .35879 L F
.72057 .36058 m .72145 .36121 L .72083 .35956 L F
.72084 .35956 m .72145 .36121 L .72222 .36064 L F
.72201 .36003 m .72222 .36064 L .72268 .3603 L F
.72084 .35956 m .72222 .36064 L .72201 .36003 L F
.72116 .35802 m .72552 .36117 L .72797 .35935 L .668 .747 .91 r
F
.72116 .35802 m .72797 .35935 L .72238 .35711 L F
.72109 .35855 m .72107 .35863 L .72085 .35554 L 0 0 .297 r
F
.72101 .35703 m .72123 .35799 L .72115 .35828 L F
.72134 .35806 m .72353 .35923 L .72394 .35807 L .667 .747 .91 r
F
.72081 .3556 m .72083 .35561 L .72083 .3556 L .668 .747 .91 r
F
.72049 .35602 m .72084 .35556 L .72105 .3587 L .157 .044 .463 r
F
.72049 .35602 m .72105 .3587 L .72087 .35894 L F
.72085 .35554 m .72107 .35863 L .72084 .35556 L 0 0 .297 r
F
.72107 .35863 m .72106 .35864 L .72084 .35556 L F
.71966 .35674 m .7199 .35986 L .71953 .35683 L .379 .203 .512 r
F
.71695 .35754 m .71848 .36051 L .71782 .3606 L .638 .394 .533 r
F
.71832 .35735 m .71859 .36047 L .71828 .35737 L .519 .305 .529 r
F
.71859 .36047 m .71856 .36048 L .71828 .35737 L F
.72084 .35556 m .72106 .35864 L .72105 .3587 L 0 0 .297 r
F
.72109 .35853 m .72085 .35554 L .72085 .3555 L F
.72133 .36156 m .72109 .35855 L .72109 .35853 L F
.72109 .35855 m .72085 .35554 L .72109 .35853 L F
.72121 .35806 m .72162 .35887 L .72134 .35806 L .667 .747 .91 r
F
.72066 .35922 m .72054 .35936 L .7203 .35626 L .157 .044 .463 r
F
.72066 .35922 m .7203 .35626 L .72034 .35622 L F
.72111 .35845 m .72109 .35853 L .72085 .3555 L 0 0 .297 r
F
.72111 .35845 m .72085 .3555 L .72086 .35548 L F
.72042 .3561 m .72066 .35922 L .72034 .35622 L .157 .044 .463 r
F
.71876 .36047 m .7182 .36235 L .71885 .36046 L .667 .747 .91 r
F
.71986 .36319 m .72019 .3651 L .71998 .36314 L F
.71902 .36353 m .71915 .3637 L .71986 .36319 L F
.71915 .3637 m .72019 .3651 L .71986 .36319 L F
.71965 .36004 m .72027 .36176 L .71976 .35999 L F
.71901 .3603 m .71912 .36043 L .71965 .36004 L F
.71912 .36043 m .72027 .36176 L .71965 .36004 L F
.72103 .35877 m .72162 .35887 L .72121 .35806 L F
.72119 .35813 m .72123 .35799 L .72125 .3583 L 0 0 .297 r
F
.72552 .36117 m .72987 .36431 L .73354 .36159 L .668 .747 .91 r
F
.72552 .36117 m .73354 .36159 L .72797 .35935 L F
.72268 .3603 m .7283 .36255 L .73 .36041 L .667 .747 .91 r
F
.72145 .36121 m .7283 .36255 L .72268 .3603 L F
.72268 .3603 m .73 .36041 L .72353 .35923 L F
.7216 .36052 m .72421 .36126 L .72415 .3601 L F
.72119 .35813 m .72125 .3583 L .72147 .36101 L 0 0 .297 r
F
.72119 .35813 m .72147 .36101 L .72147 .36102 L F
.72115 .35828 m .72119 .35813 L .72147 .36102 L F
.72141 .36124 m .72421 .36126 L .7216 .36052 L .667 .747 .91 r
F
.72147 .36102 m .72147 .36102 L .72148 .36119 L 0 0 .297 r
F
.72115 .35828 m .72147 .36102 L .72147 .36102 L F
.71966 .35674 m .72017 .35966 L .7199 .35986 L .379 .203 .512 r
F
.71869 .35744 m .71964 .35872 L .71895 .35726 L .668 .747 .91 r
F
.71857 .35725 m .71945 .35689 L .71965 .36004 L .519 .305 .529 r
F
.71957 .36334 m .71869 .36364 L .71973 .36356 L .644 .736 .916 r
F
.72145 .36121 m .72584 .36438 L .7283 .36255 L .667 .747 .91 r
F
.72241 .36216 m .72295 .36348 L .7238 .36241 L F
.71883 .36037 m .71965 .36004 L .71986 .36319 L .519 .305 .529 r
F
.71883 .36037 m .71986 .36319 L .71985 .36319 L F
.71883 .36037 m .71986 .36324 L .71909 .36351 L F
.7199 .35986 m .72068 .36259 L .72015 .36298 L .379 .203 .512 r
F
.71976 .35999 m .71996 .36014 L .7202 .35982 L .667 .747 .91 r
F
.71996 .36014 m .72057 .36058 L .7202 .35982 L F
.72017 .35966 m .72069 .36259 L .7199 .35986 L .379 .203 .512 r
F
.71995 .36312 m .72172 .3644 L .7207 .36258 L .667 .747 .91 r
F
.72069 .36259 m .72071 .36269 L .72068 .36259 L .379 .203 .512 r
F
.72069 .36259 m .72068 .36259 L .7199 .35986 L F
.72151 .36199 m .72103 .36271 L .72241 .36216 L .667 .747 .91 r
F
.7199 .35986 m .72015 .36298 L .71973 .35998 L .379 .203 .512 r
F
.72015 .36298 m .71999 .36309 L .71973 .35998 L F
.72083 .35955 m .72102 .35879 L .721 .35876 L .667 .747 .91 r
F
.72087 .35894 m .72105 .3587 L .72125 .36186 L .157 .044 .463 r
F
.72087 .35894 m .72125 .36186 L .72124 .36187 L F
.72133 .36156 m .72129 .36173 L .72107 .35863 L 0 0 .297 r
F
.72133 .36156 m .72107 .35863 L .72109 .35855 L F
.72172 .36125 m .7238 .36241 L .72421 .36126 L .667 .747 .91 r
F
.72066 .35922 m .72123 .36188 L .72089 .36233 L .157 .044 .463 r
F
.7205 .35942 m .72083 .35955 L .721 .35876 L .667 .747 .91 r
F
.72087 .35894 m .72126 .36201 L .72066 .35922 L .157 .044 .463 r
F
.72107 .35863 m .72129 .36173 L .72106 .35864 L 0 0 .297 r
F
.7202 .35982 m .72057 .36058 L .72083 .35956 L .667 .747 .91 r
F
.72049 .35943 m .72079 .36258 L .72071 .36269 L .157 .044 .463 r
F
.7205 .35942 m .7202 .35982 L .72084 .35956 L .667 .747 .91 r
F
.7205 .35942 m .72049 .35943 L .7205 .35942 L F
.72049 .35943 m .7202 .35982 L .7205 .35942 L F
.71954 .35685 m .71999 .35667 L .7203 .35627 L .668 .747 .91 r
F
.71976 .35667 m .72029 .35628 L .72049 .35943 L .379 .203 .512 r
F
.72023 .35962 m .72049 .35943 L .72071 .36269 L F
.71976 .35667 m .72049 .35943 L .72023 .35962 L F
.72054 .35936 m .72079 .36258 L .72049 .35943 L .157 .044 .463 r
F
.71778 .3608 m .7182 .36235 L .71876 .36047 L .667 .747 .91 r
F
.71848 .36051 m .71876 .36047 L .71879 .36039 L F
.71778 .3608 m .71876 .36047 L .71848 .36051 L F
.71724 .36068 m .71869 .36364 L .71752 .36374 L .638 .394 .533 r
F
.71695 .35754 m .71782 .3606 L .71724 .36068 L F
.71782 .3606 m .71869 .36364 L .71724 .36068 L F
.71782 .3606 m .71848 .36051 L .71869 .36364 L F
.7207 .36258 m .72172 .3644 L .72245 .36386 L .667 .747 .91 r
F
.72332 .3664 m .72404 .36851 L .72611 .36756 L F
.73049 .37071 m .73021 .36753 L .73391 .3648 L .383 .215 .525 r
F
.72278 .36577 m .73021 .36753 L .72584 .36438 L .667 .747 .91 r
F
.73049 .37071 m .73391 .3648 L .73419 .36798 L .383 .215 .525 r
F
.72611 .36756 m .73049 .37071 L .73419 .36798 L .667 .747 .91 r
F
.73021 .36753 m .72993 .36436 L .73362 .36162 L .383 .215 .525 r
F
.73021 .36753 m .73362 .36162 L .73391 .3648 L F
.72584 .36438 m .73021 .36753 L .73391 .3648 L .667 .747 .91 r
F
.72611 .36756 m .73419 .36798 L .72858 .36573 L F
.72172 .3644 m .72611 .36756 L .72858 .36573 L F
.72019 .3651 m .72611 .36756 L .72172 .3644 L F
.72172 .3644 m .72858 .36573 L .72295 .36348 L F
.72055 .363 m .73209 .38032 L .73973 .37733 L .644 .736 .916 r
F
.71859 .36047 m .71887 .36358 L .71856 .36048 L .519 .305 .529 r
F
.71887 .36359 m .71884 .3636 L .71884 .36359 L F
.71887 .36358 m .71884 .36359 L .71856 .36048 L F
.71887 .36359 m .71884 .36359 L .71887 .36358 L F
.72103 .36271 m .72295 .36348 L .72241 .36216 L .667 .747 .91 r
F
.72222 .36319 m .72245 .36386 L .72295 .36348 L F
.73419 .36798 m .73391 .3648 L .73647 .3616 L .196 .082 .489 r
F
.73419 .36798 m .73647 .3616 L .73676 .36478 L F
.72858 .36573 m .73419 .36798 L .73676 .36478 L .667 .747 .91 r
F
.73391 .3648 m .73362 .36162 L .73618 .35842 L .196 .082 .489 r
F
.73391 .3648 m .73618 .35842 L .73647 .3616 L F
.7283 .36255 m .73391 .3648 L .73647 .3616 L .667 .747 .91 r
F
.72584 .36438 m .73391 .3648 L .7283 .36255 L F
.72858 .36573 m .73676 .36478 L .73028 .3636 L F
.72295 .36348 m .72858 .36573 L .73028 .3636 L F
.72295 .36348 m .73028 .3636 L .7238 .36241 L F
.72163 .36263 m .73973 .37733 L .74593 .37323 L .644 .736 .916 r
F
.71848 .36051 m .71877 .36362 L .71869 .36364 L .519 .305 .529 r
F
.72119 .36193 m .7238 .36241 L .72172 .36125 L .667 .747 .91 r
F
.73956 .36915 m .77328 .37713 L .74571 .36506 L .645 .736 .915 r
F
.72797 .35935 m .73354 .36159 L .73609 .3584 L .668 .747 .91 r
F
.7283 .36255 m .73647 .3616 L .73 .36041 L .667 .747 .91 r
F
.7238 .36241 m .73028 .3636 L .73111 .36129 L F
.7238 .36241 m .73111 .36129 L .72421 .36126 L F
.72304 .36214 m .74593 .37323 L .75025 .36826 L .644 .736 .916 r
F
.71856 .36048 m .71884 .36359 L .71848 .36051 L .519 .305 .529 r
F
.71884 .36359 m .71884 .36359 L .71848 .36051 L F
.71884 .3636 m .71877 .36363 L .71877 .36362 L F
.71884 .36359 m .71877 .36362 L .71848 .36051 L F
.71884 .3636 m .71877 .36362 L .71884 .36359 L F
.74571 .36506 m .77328 .37713 L .78199 .36733 L .645 .736 .915 r
F
.74571 .36506 m .78199 .36733 L .75 .36011 L F
.73676 .36478 m .73647 .3616 L .73772 .35814 L 0 0 .382 r
F
.73676 .36478 m .73772 .35814 L .738 .36133 L F
.73028 .3636 m .73676 .36478 L .738 .36133 L .667 .747 .91 r
F
.73647 .3616 m .73618 .35842 L .73743 .35496 L 0 0 .382 r
F
.73647 .3616 m .73743 .35496 L .73772 .35814 L F
.73 .36041 m .73647 .3616 L .73772 .35814 L .667 .747 .91 r
F
.73028 .3636 m .738 .36133 L .73111 .36129 L F
.72532 .36136 m .75025 .36826 L .75239 .36277 L .644 .736 .916 r
F
.72066 .35922 m .7209 .36245 L .72054 .35936 L .157 .044 .463 r
F
.7207 .36258 m .7207 .36258 L .72119 .36193 L .667 .747 .91 r
F
.7209 .36245 m .72079 .36258 L .72054 .35936 L .157 .044 .463 r
F
.71973 .35998 m .71999 .36315 L .71971 .36 L .379 .203 .512 r
F
.71999 .36315 m .71997 .36317 L .71971 .36 L F
.71909 .36351 m .71887 .36358 L .71859 .36047 L .519 .305 .529 r
F
.71909 .36351 m .71859 .36047 L .71873 .36041 L F
.71915 .3637 m .71993 .36516 L .72019 .3651 L .667 .747 .91 r
F
.71902 .36353 m .71913 .36372 L .71915 .3637 L F
.71913 .36372 m .71993 .36516 L .71915 .3637 L F
.71971 .36 m .71997 .36311 L .71965 .36004 L .379 .203 .512 r
F
.71898 .36354 m .71993 .36516 L .71902 .36353 L .667 .747 .91 r
F
.71993 .36516 m .72306 .36895 L .72019 .3651 L F
.71952 .36447 m .7235 .38199 L .72013 .3655 L .644 .736 .916 r
F
.71877 .36395 m .7235 .38199 L .71932 .36359 L F
.71855 .36369 m .7235 .38199 L .71869 .36364 L F
.72021 .36591 m .72072 .36651 L .72026 .36573 L F
.71888 .36491 m .71838 .36693 L .71979 .36828 L F
.71846 .36553 m .72144 .36775 L .71993 .36516 L .667 .747 .91 r
F
.72144 .36775 m .72306 .36895 L .71993 .36516 L F
.71946 .36421 m .71952 .36447 L .71978 .36382 L .644 .736 .916 r
F
.71952 .36447 m .72013 .3655 L .71978 .36382 L F
.71879 .36039 m .71876 .36047 L .71885 .36046 L .667 .747 .91 r
F
.71883 .36037 m .71909 .36351 L .71873 .36041 L .519 .305 .529 r
F
.71788 .36166 m .71902 .36353 L .71986 .36319 L .667 .747 .91 r
F
.71965 .36004 m .71992 .36315 L .71986 .36319 L .379 .203 .512 r
F
.71785 .36161 m .71986 .36319 L .71995 .36312 L .667 .747 .91 r
F
.71997 .36311 m .71992 .36315 L .71965 .36004 L .379 .203 .512 r
F
.72105 .3587 m .72129 .36173 L .72125 .36186 L 0 0 .297 r
F
.72106 .35864 m .72129 .36173 L .72105 .3587 L F
.71952 .35684 m .71954 .35685 L .72017 .35637 L .668 .747 .91 r
F
.71954 .35685 m .71974 .357 L .71999 .35667 L F
.71976 .35667 m .72023 .35962 L .71966 .35674 L .379 .203 .512 r
F
.72023 .35962 m .72071 .36269 L .72017 .35966 L F
.72023 .35962 m .72017 .35966 L .71966 .35674 L F
.71857 .35725 m .71965 .36004 L .71883 .36037 L .519 .305 .529 r
F
.72097 .35443 m .72104 .35718 L .72115 .35752 L .925 .667 .181 r
F
.72106 .3547 m .72124 .35776 L .72127 .35785 L F
.72099 .35498 m .72127 .35785 L .72123 .35799 L 0 0 .297 r
F
.72101 .35488 m .72106 .3547 L .72088 .35418 L .668 .747 .91 r
F
.72084 .35556 m .72139 .35567 L .72119 .35509 L F
.72097 .35443 m .72115 .35752 L .72105 .35467 L .925 .667 .181 r
F
.72115 .35752 m .72123 .35775 L .72105 .35467 L F
.72095 .35513 m .72099 .35498 L .72101 .35703 L 0 0 .297 r
F
.72092 .3543 m .72101 .35711 L .72097 .35443 L .925 .667 .181 r
F
.72089 .35535 m .72111 .35845 L .72086 .35548 L 0 0 .297 r
F
.72101 .35703 m .72115 .35828 L .72111 .35845 L F
.71705 .35804 m .72121 .35806 L .7211 .35737 L .667 .747 .91 r
F
.72121 .35806 m .72134 .35806 L .72127 .35785 L F
.72121 .35806 m .72127 .35785 L .7211 .35737 L F
.71763 .36123 m .72119 .36193 L .72125 .36186 L F
.72141 .36124 m .72125 .36186 L .72172 .36125 L F
.72111 .35845 m .72146 .36103 L .72133 .36156 L 0 0 .297 r
F
.72111 .35845 m .72133 .36156 L .72109 .35853 L F
.71763 .36123 m .72125 .36186 L .72141 .36124 L .667 .747 .91 r
F
.72133 .36156 m .72148 .36119 L .72134 .36172 L 0 0 .297 r
F
.72146 .36103 m .72148 .36119 L .72133 .36156 L F
.72214 .35839 m .72362 .35902 L .72266 .35809 L .667 .747 .91 r
F
.72115 .35828 m .72147 .36102 L .72111 .35845 L 0 0 .297 r
F
.72147 .36102 m .72146 .36103 L .72111 .35845 L F
.71705 .35804 m .72103 .35877 L .72121 .35806 L .667 .747 .91 r
F
.72101 .35711 m .72104 .35718 L .72097 .35443 L .925 .667 .181 r
F
.72097 .35443 m .72105 .35467 L .72097 .3533 L F
.72088 .35306 m .72092 .3543 L .72097 .35443 L F
.72559 .35196 m .75212 .35463 L .75191 .349 L .645 .736 .915 r
F
.71781 .35283 m .73931 .35396 L .72559 .35196 L F
.73931 .35396 m .75212 .35463 L .72559 .35196 L F
.72088 .35306 m .72059 .35222 L .72068 .3536 L .925 .667 .181 r
F
.72088 .35306 m .72068 .3536 L .72092 .3543 L F
.72097 .3533 m .72105 .35467 L .72106 .3547 L F
.71678 .35486 m .72088 .35418 L .72068 .3536 L .668 .747 .91 r
F
.72089 .35535 m .72095 .35513 L .72101 .35703 L 0 0 .297 r
F
.72092 .3543 m .72089 .35675 L .72101 .35711 L .925 .667 .181 r
F
.72119 .35509 m .72322 .35604 L .72136 .35488 L .668 .747 .91 r
F
.72139 .35567 m .72322 .35604 L .72119 .35509 L F
.72105 .35467 m .72123 .35775 L .72106 .3547 L .925 .667 .181 r
F
.72123 .35799 m .72124 .35793 L .7213 .35886 L 0 0 .297 r
F
.72124 .35793 m .72127 .35785 L .7213 .35886 L F
.72162 .35887 m .72268 .3603 L .72353 .35923 L .667 .747 .91 r
F
.72184 .35953 m .72268 .3603 L .72162 .35887 L F
.72797 .35935 m .73609 .3584 L .72966 .35722 L .668 .747 .91 r
F
.72238 .35711 m .72797 .35935 L .72966 .35722 L F
.72353 .35923 m .73 .36041 L .73083 .35811 L .667 .747 .91 r
F
.72353 .35923 m .73083 .35811 L .72394 .35807 L F
.72182 .35965 m .72415 .3601 L .72362 .35902 L F
.7213 .35886 m .72127 .35785 L .72147 .361 L 0 0 .297 r
F
.7213 .35886 m .72147 .361 L .72147 .36101 L F
.72123 .35775 m .72142 .36083 L .72124 .35776 L .925 .667 .181 r
F
.72115 .35752 m .72134 .36062 L .72123 .35775 L F
.72127 .36041 m .7216 .36052 L .72164 .36034 L .667 .747 .91 r
F
.71652 .3576 m .71714 .36377 L .71692 .36379 L .638 .394 .533 r
F
.71724 .36068 m .71752 .36374 L .71709 .3607 L F
.7172 .36498 m .71841 .36507 L .71767 .3647 L .644 .736 .916 r
F
.7172 .36498 m .71863 .36412 L .71854 .3641 L F
.71658 .3576 m .71719 .36377 L .71652 .3576 L .638 .394 .533 r
F
.71854 .36366 m .7172 .36498 L .71865 .36404 L .644 .736 .916 r
F
.71739 .36375 m .7172 .36498 L .71854 .36366 L F
.71986 .36324 m .73209 .38032 L .72055 .363 L F
.71957 .36334 m .71961 .3634 L .71986 .36324 L F
.71961 .3634 m .73209 .38032 L .71986 .36324 L F
.72015 .36298 m .72015 .36305 L .71999 .36309 L .379 .203 .512 r
F
.72149 .36116 m .72193 .36189 L .72293 .36123 L .644 .736 .916 r
F
.72133 .36156 m .72134 .36172 L .72129 .36173 L 0 0 .297 r
F
.71759 .36117 m .72132 .36057 L .72127 .36041 L .667 .747 .91 r
F
.7176 .36118 m .72132 .36057 L .71759 .36117 L F
.72134 .36062 m .72142 .36083 L .72123 .35775 L .925 .667 .181 r
F
.72134 .36062 m .72111 .3601 L .72136 .36081 L F
.72115 .35752 m .72111 .35995 L .72134 .36062 L F
.71757 .36113 m .72127 .36041 L .7211 .3599 L .667 .747 .91 r
F
.72127 .36041 m .7211 .3599 L .7211 .3599 L F
.72111 .35995 m .72111 .3601 L .72134 .36062 L .925 .667 .181 r
F
.72127 .36041 m .72164 .36034 L .7211 .3599 L .667 .747 .91 r
F
.72127 .35785 m .72142 .36083 L .72147 .361 L .925 .667 .181 r
F
.72124 .35776 m .72142 .36083 L .72127 .35785 L F
.71759 .36117 m .72164 .36034 L .71757 .36113 L .667 .747 .91 r
F
.71719 .36377 m .71714 .36377 L .71652 .3576 L .638 .394 .533 r
F
.71678 .35486 m .71309 .35615 L .71314 .35625 L .668 .747 .91 r
F
.71363 .35671 m .71314 .35625 L .71341 .35684 L F
.71509 .35566 m .71652 .3576 L .71549 .35745 L .753 .483 .523 r
F
.71678 .35486 m .71314 .35625 L .71363 .35671 L .668 .747 .91 r
F
.71363 .35671 m .71356 .35675 L .7138 .35686 L F
.71356 .35675 m .71341 .35684 L .7138 .35686 L F
.7134 .35649 m .7138 .35686 L .71418 .36295 L .947 .644 .431 r
F
.70253 .37024 m .70509 .36952 L .70527 .3718 L .874 .581 .489 r
F
.70377 .36611 m .69802 .37035 L .70039 .37111 L .645 .736 .915 r
F
.70112 .36739 m .70483 .36634 L .70509 .36952 L .874 .581 .489 r
F
.70253 .37024 m .70112 .36739 L .70509 .36952 L F
.70175 .36981 m .70162 .36987 L .70542 .37188 L .644 .736 .916 r
F
.70162 .36987 m .69127 .37479 L .70399 .37218 L F
.70162 .36987 m .70399 .37218 L .70542 .37188 L F
.70129 .36954 m .70112 .36739 L .70253 .37024 L .874 .581 .489 r
F
.70621 .36108 m .70489 .36629 L .70884 .36249 L .668 .747 .91 r
F
.70641 .36428 m .70509 .36952 L .70906 .36571 L .667 .747 .91 r
F
.70112 .36739 m .70087 .36422 L .70483 .36634 L .874 .581 .489 r
F
.70621 .36108 m .70095 .36417 L .70489 .36629 L .668 .747 .91 r
F
.70641 .36428 m .70112 .36739 L .70509 .36952 L .667 .747 .91 r
F
.71304 .36188 m .70906 .36571 L .71224 .36661 L F
.71172 .36117 m .70906 .36571 L .71304 .36188 L F
.71172 .36117 m .70641 .36428 L .70906 .36571 L F
.71417 .36293 m .69127 .37479 L .71485 .36358 L .644 .736 .916 r
F
.7158 .36358 m .71535 .36054 L .71539 .36055 L .753 .483 .523 r
F
.7158 .36358 m .71519 .36052 L .71535 .36054 L F
.71388 .3599 m .71359 .35993 L .71364 .36004 L .667 .747 .91 r
F
.71353 .35957 m .71418 .36295 L .71375 .36253 L .947 .644 .431 r
F
.7133 .3564 m .71376 .35978 L .71353 .35957 L F
.71376 .35978 m .71418 .36295 L .71353 .35957 L F
.71185 .35801 m .71055 .35685 L .71015 .358 L .667 .747 .91 r
F
.71444 .35126 m .71352 .35357 L .71451 .35293 L .414 .228 .517 r
F
.71354 .35356 m .71399 .35284 L .71353 .35355 L .668 .747 .91 r
F
.71678 .35486 m .7143 .35307 L .71354 .35356 L F
.7143 .35307 m .71399 .35284 L .71354 .35356 L F
.71678 .35486 m .71313 .35419 L .71283 .35466 L F
.71678 .35486 m .71363 .35671 L .7138 .35686 L F
.71282 .355 m .71301 .35842 L .71282 .35487 L 0 0 .132 r
F
.71301 .35842 m .71301 .35835 L .71282 .35487 L F
.71282 .355 m .7128 .35552 L .713 .35866 L F
.71282 .355 m .713 .35866 L .71301 .35842 L F
.71305 .35605 m .71314 .35625 L .71334 .35939 L .965 .686 .26 r
F
.71305 .35605 m .71334 .35939 L .71329 .3593 L F
.7133 .3564 m .71353 .35957 L .71319 .3563 L .947 .644 .431 r
F
.71353 .35957 m .71348 .35952 L .71319 .3563 L F
.7134 .35649 m .71418 .36295 L .7133 .3564 L F
.71705 .35804 m .71332 .35735 L .71303 .3578 L .667 .747 .91 r
F
.71302 .35802 m .71303 .3578 L .71289 .35802 L F
.71705 .35804 m .71303 .3578 L .71302 .35802 L F
.71705 .35804 m .71302 .35802 L .713 .3587 L F
.71705 .35804 m .71301 .3587 L .71331 .35934 L F
.71301 .3587 m .71266 .35876 L .71331 .35934 L F
.71303 .35783 m .71321 .36089 L .71307 .3585 L 0 0 .132 r
F
.71297 .35697 m .71302 .35789 L .71303 .35783 L F
.71302 .35789 m .71321 .36089 L .71303 .35783 L F
.71367 .35922 m .71329 .35935 L .71367 .35971 L .667 .747 .91 r
F
.71367 .35922 m .71367 .35971 L .71388 .3599 L F
.71705 .35804 m .71367 .35922 L .71388 .3599 L F
.71358 .35694 m .71366 .35682 L .71342 .35185 L .076 0 .438 r
F
.71678 .35486 m .7138 .35686 L .7144 .35715 L .668 .747 .91 r
F
.71678 .35486 m .71427 .35727 L .71534 .35743 L F
.71678 .35486 m .71534 .35743 L .71638 .35758 L F
.71705 .35804 m .71373 .35671 L .71372 .35671 L .667 .747 .91 r
F
.71335 .35384 m .71303 .3578 L .71352 .35704 L .076 0 .438 r
F
.71318 .35411 m .71303 .3578 L .71335 .35384 L F
.71318 .35411 m .71283 .35466 L .71303 .3578 L F
.71705 .35804 m .71372 .35671 L .71332 .35735 L .667 .747 .91 r
F
.71372 .35671 m .71381 .35989 L .71391 .35973 L .076 0 .438 r
F
.71342 .35185 m .71366 .35682 L .71372 .35671 L F
.71366 .35682 m .71381 .35989 L .71372 .35671 L F
.71335 .35384 m .71352 .35704 L .71347 .35365 L F
.71352 .35704 m .71358 .35694 L .71347 .35365 L F
.71283 .35467 m .71297 .35697 L .71303 .35783 L 0 0 .132 r
F
.71283 .35469 m .71297 .35697 L .71283 .35467 L F
.71302 .35799 m .71302 .35789 L .71283 .35469 L F
.71302 .35799 m .71283 .35469 L .71283 .35473 L F
.7128 .35551 m .71 .35597 L .71277 .35626 L .668 .747 .91 r
F
.71277 .35626 m .71053 .35705 L .71275 .35689 L F
.71372 .35671 m .71173 .3559 L .71285 .35727 L .667 .747 .91 r
F
.71444 .35126 m .71342 .35185 L .71352 .35357 L .414 .228 .517 r
F
.71444 .35126 m .71451 .35293 L .71474 .35109 L F
.71678 .35486 m .71484 .35272 L .7143 .35307 L .668 .747 .91 r
F
.71755 .3611 m .7136 .36316 L .71759 .36116 L .644 .736 .916 r
F
.7136 .36316 m .7137 .36318 L .71759 .36116 L F
.71759 .36116 m .71417 .36293 L .71485 .36358 L F
.7136 .36316 m .69127 .37479 L .7137 .36318 L F
.71485 .36358 m .70175 .36981 L .70542 .37188 L F
.71609 .36386 m .71288 .36924 L .71692 .36379 L F
.71506 .36339 m .71304 .36517 L .71607 .36389 L F
.71304 .36517 m .713 .36617 L .71607 .36389 L F
.706 .37137 m .70507 .37274 L .71607 .36389 L F
.71607 .36389 m .71299 .36637 L .71288 .36924 L F
.69936 .36767 m .70112 .36739 L .70129 .36954 L .949 .646 .426 r
F
.71705 .35804 m .71976 .35999 L .7202 .35982 L .667 .747 .91 r
F
.71705 .35804 m .7202 .35982 L .7205 .35942 L F
.71705 .35804 m .71901 .3603 L .71976 .35999 L F
.71705 .35804 m .71879 .36039 L .71901 .3603 L F
.71755 .36109 m .7211 .3599 L .72045 .35939 L F
.72123 .35775 m .72124 .35776 L .72106 .3547 L .925 .667 .181 r
F
.71705 .35804 m .72157 .35729 L .72084 .35671 L .667 .747 .91 r
F
.71678 .35486 m .72068 .3536 L .72058 .35352 L .668 .747 .91 r
F
.71705 .35804 m .7205 .35942 L .721 .35876 L .667 .747 .91 r
F
.71678 .35486 m .7203 .35627 L .72081 .3556 L .668 .747 .91 r
F
.72066 .35358 m .7208 .35667 L .72068 .3536 L .928 .626 .449 r
F
.7208 .35667 m .72081 .35668 L .72068 .3536 L F
.72081 .35668 m .72082 .35669 L .72068 .3536 L F
.72068 .3536 m .72082 .35669 L .72089 .35675 L F
.72096 .35574 m .72335 .35583 L .72239 .3549 L .667 .747 .91 r
F
.71856 .33659 m .71927 .35124 L .71952 .35133 L .818 .533 .507 r
F
.71963 .33748 m .71952 .35133 L .72035 .35202 L .928 .626 .449 r
F
.71781 .35283 m .74462 .33879 L .73802 .33494 L .645 .736 .915 r
F
.71781 .35283 m .74936 .34359 L .74462 .33879 L F
.71743 .33619 m .71812 .35087 L .71838 .35091 L .735 .468 .525 r
F
.71856 .33659 m .71838 .35091 L .71927 .35124 L .818 .533 .507 r
F
.71743 .33619 m .7172 .35073 L .71812 .35087 L .735 .468 .525 r
F
.71781 .35283 m .73 .33231 L .72113 .33109 L .645 .736 .915 r
F
.71781 .35283 m .73802 .33494 L .73 .33231 L F
.71838 .35091 m .71844 .35236 L .71848 .35236 L .735 .468 .525 r
F
.71678 .35486 m .71929 .35244 L .71819 .35233 L .668 .747 .91 r
F
.72092 .3543 m .72068 .3536 L .72089 .35675 L .925 .667 .181 r
F
.71678 .35486 m .71952 .35684 L .7203 .35627 L .668 .747 .91 r
F
.71952 .35684 m .72017 .35637 L .7203 .35627 L F
.71678 .35486 m .71753 .35767 L .71856 .35726 L F
.71857 .35725 m .7184 .35732 L .71818 .35577 L .519 .305 .529 r
F
.7184 .35732 m .71836 .35733 L .71818 .35577 L F
.71678 .35486 m .71856 .35726 L .71884 .35714 L .668 .747 .91 r
F
.71678 .35486 m .71884 .35714 L .71952 .35684 L F
.71884 .35714 m .71945 .35689 L .71952 .35684 L F
.71927 .35124 m .71838 .35091 L .71848 .35236 L .818 .533 .507 r
F
.71927 .35124 m .71848 .35236 L .71933 .35265 L F
.71705 .35804 m .72084 .35671 L .72019 .35619 L .667 .747 .91 r
F
.71705 .35804 m .72019 .35619 L .71982 .35589 L F
.71705 .35804 m .71982 .35589 L .71942 .35576 L F
.71952 .35133 m .71958 .35274 L .71962 .35275 L .818 .533 .507 r
F
.72035 .35202 m .71952 .35133 L .71962 .35275 L .928 .626 .449 r
F
.72035 .35202 m .71962 .35275 L .72019 .35321 L F
.72035 .35202 m .72019 .35321 L .72042 .35339 L F
.71927 .35124 m .71933 .35265 L .71952 .35133 L .818 .533 .507 r
F
.71678 .35486 m .71993 .353 L .71962 .35275 L .668 .747 .91 r
F
.71678 .35486 m .71962 .35275 L .71914 .35259 L F
.71812 .35087 m .71819 .35233 L .71838 .35091 L .735 .468 .525 r
F
.71819 .35233 m .71837 .35235 L .71838 .35091 L F
.72059 .35222 m .72066 .35358 L .72068 .3536 L .928 .626 .449 r
F
.72035 .35202 m .72042 .35339 L .72059 .35222 L F
.72042 .35339 m .72066 .35358 L .72059 .35222 L F
.71993 .353 m .72267 .35279 L .72064 .35258 L .668 .747 .91 r
F
.71678 .35486 m .72058 .35352 L .71993 .353 L F
.72058 .35352 m .72267 .35279 L .71993 .353 L F
.71757 .36113 m .7211 .3599 L .71755 .36109 L .667 .747 .91 r
F
.71766 .36129 m .72119 .36193 L .71763 .36123 L F
.72119 .36193 m .7207 .36258 L .72151 .36199 L F
.7176 .36117 m .71506 .36339 L .71522 .36347 L .644 .736 .916 r
F
.71759 .36116 m .71506 .36339 L .7176 .36117 L F
.71764 .36125 m .71621 .36366 L .71769 .36134 L F
.71766 .36129 m .7207 .36258 L .72119 .36193 L .667 .747 .91 r
F
.7176 .36117 m .71522 .36347 L .71764 .36125 L .644 .736 .916 r
F
.71731 .36122 m .71772 .36139 L .71766 .36129 L .667 .747 .91 r
F
.71772 .36139 m .7207 .36258 L .71766 .36129 L F
.71764 .36125 m .71522 .36347 L .71621 .36366 L .644 .736 .916 r
F
.71781 .36096 m .7176 .36117 L .71764 .36125 L F
.7207 .36258 m .72103 .36271 L .72151 .36199 L .667 .747 .91 r
F
.71731 .36122 m .72141 .36124 L .7216 .36052 L F
.71774 .36142 m .71739 .36375 L .71811 .36205 L .644 .736 .916 r
F
.71774 .36142 m .71692 .36379 L .71739 .36375 L F
.71769 .36134 m .71692 .36379 L .71774 .36142 L F
.71769 .36134 m .71621 .36366 L .71692 .36379 L F
.71731 .36122 m .71995 .36312 L .7207 .36258 L .667 .747 .91 r
F
.72068 .36259 m .72071 .36269 L .72015 .36298 L .379 .203 .512 r
F
.72115 .36242 m .72104 .36283 L .72163 .36263 L .644 .736 .916 r
F
.72115 .36242 m .72163 .36263 L .72133 .36176 L F
.71991 .37683 m .71626 .39032 L .72352 .39011 L .643 .737 .917 r
F
.7207 .36258 m .72245 .36386 L .72222 .36319 L .667 .747 .91 r
F
.72055 .363 m .73973 .37733 L .72163 .36263 L .644 .736 .916 r
F
.71846 .36553 m .71961 .36982 L .72226 .36915 L .667 .747 .91 r
F
.72144 .36775 m .72226 .36915 L .72306 .36895 L F
.71846 .36553 m .72226 .36915 L .72144 .36775 L F
.71985 .36373 m .7238 .37179 L .72457 .37012 L .644 .736 .916 r
F
.71983 .36376 m .72833 .38105 L .71985 .36373 L F
.71961 .36982 m .72184 .37088 L .72174 .36929 L .667 .747 .91 r
F
.72184 .37088 m .72381 .37181 L .72174 .36929 L F
.72174 .36929 m .72381 .37181 L .72226 .36915 L F
.7238 .37179 m .72833 .38105 L .72707 .37739 L .644 .736 .916 r
F
.72075 .37409 m .72105 .37382 L .72458 .37313 L .59 .365 .542 r
F
.72075 .37409 m .72073 .37388 L .72105 .37382 L F
.71961 .36982 m .72075 .37409 L .72458 .37313 L .667 .747 .91 r
F
.71961 .36982 m .72458 .37313 L .72381 .37181 L F
.72045 .36503 m .72072 .36651 L .72366 .37154 L .644 .736 .916 r
F
.72133 .36176 m .72163 .36263 L .72304 .36214 L F
.72088 .37326 m .72352 .39011 L .72891 .38907 L .643 .737 .917 r
F
.72088 .37326 m .72891 .38907 L .72569 .37976 L F
.71537 .37452 m .71533 .37404 L .71607 .37402 L .663 .419 .54 r
F
.71601 .37011 m .71537 .37452 L .72075 .37409 L .667 .747 .91 r
F
.71601 .37011 m .72075 .37409 L .71961 .36982 L F
.71991 .37683 m .72352 .39011 L .72088 .37326 L .643 .737 .917 r
F
.72129 .36173 m .72185 .36968 L .72125 .36186 L 0 0 .297 r
F
.7238 .37179 m .72707 .37739 L .72457 .37012 L .644 .736 .916 r
F
.72457 .37012 m .72833 .38105 L .73209 .38032 L F
.72347 .37333 m .73213 .38845 L .73979 .38547 L .643 .737 .917 r
F
.7213 .37172 m .72476 .37706 L .72347 .37333 L F
.72476 .37706 m .73213 .38845 L .72347 .37333 L F
.72088 .37326 m .72569 .37976 L .7213 .37172 L F
.72569 .37976 m .73213 .38845 L .72476 .37706 L F
.72569 .37976 m .72476 .37706 L .7213 .37172 L F
.71781 .36096 m .72133 .36176 L .72148 .36119 L .644 .736 .916 r
F
.72147 .36116 m .72148 .36119 L .72149 .36116 L F
.71781 .36096 m .72148 .36119 L .72147 .36116 L F
.72142 .36083 m .72143 .36102 L .72147 .361 L .925 .667 .181 r
F
.72148 .36119 m .72193 .36189 L .72149 .36116 L .644 .736 .916 r
F
.72133 .36176 m .72171 .36184 L .72148 .36119 L F
.72171 .36184 m .72193 .36189 L .72148 .36119 L F
.72134 .36172 m .72148 .36119 L .72201 .36911 L 0 0 .297 r
F
.72125 .36186 m .72126 .36201 L .72126 .36201 L F
.72156 .37076 m .72297 .37189 L .72289 .37166 L .643 .737 .917 r
F
.72156 .37076 m .74153 .38433 L .7288 .3739 L F
.7213 .37172 m .73979 .38547 L .72156 .37076 L F
.72126 .36201 m .72182 .36978 L .72126 .36201 L 0 0 .297 r
F
.73973 .37733 m .7737 .38534 L .74593 .37323 L .644 .736 .916 r
F
.72176 .37002 m .74601 .38138 L .75034 .37643 L .643 .737 .917 r
F
.72156 .37076 m .74601 .38138 L .72176 .37002 L F
.72182 .36978 m .72182 .36978 L .72126 .36201 L 0 0 .297 r
F
.72134 .36172 m .72201 .36911 L .72189 .36955 L F
.72185 .36968 m .72182 .36978 L .72125 .36186 L F
.72126 .36201 m .72182 .36978 L .72178 .36993 L F
.72163 .36263 m .74593 .37323 L .72304 .36214 L .644 .736 .916 r
F
.77328 .37713 m .81378 .37452 L .78199 .36733 L .645 .736 .915 r
F
.74593 .37323 m .7737 .38534 L .78248 .37552 L .644 .736 .916 r
F
.74593 .37323 m .78248 .37552 L .75025 .36826 L F
.72333 .36942 m .75034 .37643 L .75248 .37095 L .643 .737 .917 r
F
.72189 .36955 m .72185 .36968 L .7213 .36188 L 0 0 .297 r
F
.72189 .36955 m .7213 .36188 L .7213 .36188 L F
.72134 .36172 m .72189 .36955 L .7213 .36188 L F
.71781 .36096 m .72055 .363 L .72104 .36283 L .644 .736 .916 r
F
.71781 .36096 m .72104 .36283 L .72115 .36242 L F
.7209 .36245 m .72148 .37029 L .72079 .36258 L .157 .044 .463 r
F
.72148 .37029 m .7214 .3704 L .72079 .36258 L F
.72019 .3651 m .72036 .36533 L .72038 .36526 L .667 .747 .91 r
F
.72026 .36573 m .72072 .36651 L .72045 .36503 L .644 .736 .916 r
F
.71973 .36356 m .72021 .36591 L .72045 .36503 L F
.72015 .36305 m .72077 .3709 L .71999 .36315 L .379 .203 .512 r
F
.72077 .3709 m .72064 .37099 L .71999 .36315 L F
.71997 .36317 m .72062 .371 L .71992 .3632 L F
.72062 .371 m .72058 .37103 L .71992 .3632 L F
.72122 .37061 m .7213 .37172 L .72156 .37076 L .643 .737 .917 r
F
.72071 .36269 m .72133 .37048 L .72123 .37061 L .157 .044 .463 r
F
.71986 .36324 m .72053 .37106 L .72038 .37116 L .379 .203 .512 r
F
.71992 .3632 m .72058 .37103 L .71986 .36324 L F
.72058 .37103 m .72053 .37106 L .71986 .36324 L F
.71865 .36404 m .71828 .36564 L .71888 .36491 L .644 .736 .916 r
F
.7188 .36396 m .71846 .36553 L .71894 .36541 L .667 .747 .91 r
F
.7188 .36396 m .71894 .36541 L .71993 .36516 L F
.71888 .36358 m .7188 .36396 L .71993 .36516 L F
.71666 .36568 m .71601 .37011 L .71961 .36982 L F
.71666 .36568 m .71961 .36982 L .71846 .36553 L F
.71884 .3636 m .71954 .37145 L .71877 .36363 L .519 .305 .529 r
F
.71954 .37145 m .71948 .37147 L .71877 .36363 L F
.71999 .36315 m .72064 .37099 L .71997 .36317 L .379 .203 .512 r
F
.71967 .37162 m .71991 .37683 L .72088 .37326 L .643 .737 .917 r
F
.72049 .37112 m .72088 .37326 L .7213 .37172 L F
.71954 .37145 m .72088 .37326 L .72049 .37112 L F
.72047 .3711 m .7213 .37172 L .72122 .37061 L F
.72064 .37099 m .72357 .40639 L .72062 .371 L .379 .203 .512 r
F
.72064 .37099 m .72062 .371 L .71997 .36317 L F
.71954 .37145 m .71955 .3717 L .71967 .37162 L .643 .737 .917 r
F
.71955 .3717 m .71991 .37683 L .71967 .37162 L F
.71854 .37179 m .71991 .37683 L .71954 .37154 L F
.7192 .37156 m .71954 .37154 L .71954 .37145 L F
.71854 .37179 m .71954 .37154 L .7192 .37156 L F
.71767 .3647 m .71841 .36507 L .71863 .36412 L .644 .736 .916 r
F
.71854 .3641 m .71863 .36412 L .71865 .36404 L F
.71804 .36393 m .71846 .36553 L .71887 .36364 L .667 .747 .91 r
F
.71869 .36366 m .71887 .36364 L .71888 .36358 L F
.71804 .36393 m .71887 .36364 L .71869 .36366 L F
.71854 .36366 m .71855 .36369 L .71869 .36364 L .644 .736 .916 r
F
.71752 .36374 m .71869 .36364 L .71869 .36366 L .638 .394 .533 r
F
.71752 .36374 m .71869 .36366 L .71754 .36382 L F
.71621 .36366 m .71609 .36386 L .71692 .36379 L .644 .736 .916 r
F
.7158 .36358 m .71692 .36379 L .71692 .3639 L .753 .483 .523 r
F
.71807 .36407 m .71666 .36568 L .71846 .36553 L .667 .747 .91 r
F
.7178 .36403 m .71666 .36568 L .71807 .36407 L F
.71692 .3639 m .71666 .36568 L .71799 .36376 L F
.71809 .37887 m .71455 .39036 L .71626 .39032 L .643 .737 .917 r
F
.71875 .37472 m .7178 .37826 L .71809 .37887 L F
.7178 .37826 m .71455 .39036 L .71809 .37887 L F
.71864 .37461 m .71773 .37812 L .71875 .37472 L F
.71773 .37812 m .71455 .39036 L .7178 .37826 L F
.71773 .37812 m .7178 .37826 L .71875 .37472 L F
.71352 .35704 m .71303 .3578 L .71321 .36076 L .076 0 .438 r
F
.71324 .35918 m .71352 .36232 L .71321 .35913 L .965 .686 .26 r
F
.71334 .35939 m .71362 .36241 L .71352 .36232 L .947 .644 .431 r
F
.71339 .35944 m .71362 .36241 L .71334 .35939 L F
.7131 .35888 m .71352 .36232 L .7133 .36184 L .965 .686 .26 r
F
.71321 .35913 m .71352 .36232 L .7131 .35888 L F
.71329 .3593 m .71352 .36232 L .71324 .35918 L F
.71375 .36253 m .71362 .36241 L .7134 .35945 L .947 .644 .431 r
F
.71375 .36253 m .7134 .35945 L .71346 .35951 L F
.71329 .3593 m .71334 .35939 L .71352 .36232 L .965 .686 .26 r
F
.71353 .35957 m .71375 .36253 L .71348 .35952 L .947 .644 .431 r
F
.71311 .36342 m .71188 .36272 L .71048 .36479 L .644 .736 .916 r
F
.71755 .3611 m .71315 .36236 L .71311 .36342 L F
.71315 .36236 m .71188 .36272 L .71311 .36342 L F
.71752 .36105 m .70549 .36455 L .71755 .3611 L F
.72042 .35339 m .72073 .35961 L .72066 .35358 L .928 .626 .449 r
F
.72073 .35961 m .72074 .35961 L .72066 .35358 L F
.72074 .3598 m .72094 .35996 L .72094 .35977 L F
.72074 .35961 m .72094 .35977 L .72066 .35358 L F
.72074 .3598 m .72094 .35977 L .72074 .35961 L F
.71705 .35804 m .71778 .3608 L .71879 .36039 L .667 .747 .91 r
F
.71755 .36109 m .72045 .35939 L .71751 .36103 L F
.72045 .35939 m .72043 .35937 L .71751 .36103 L F
.71751 .36103 m .72043 .35937 L .72003 .35905 L F
.71963 .35892 m .71985 .35899 L .71972 .35586 L .818 .533 .507 r
F
.71751 .36103 m .72003 .35905 L .7197 .35894 L .667 .747 .91 r
F
.71972 .35586 m .71985 .35899 L .71975 .35587 L .818 .533 .507 r
F
.71897 .37335 m .71626 .39032 L .71991 .37683 L .643 .737 .917 r
F
.71869 .36366 m .71942 .37149 L .7192 .37156 L .519 .305 .529 r
F
.7213 .36188 m .7213 .36188 L .72129 .36173 L 0 0 .297 r
F
.72134 .36172 m .7213 .36188 L .72129 .36173 L F
.72089 .36233 m .72126 .36201 L .7209 .36245 L .157 .044 .463 r
F
.72123 .36188 m .72126 .36201 L .72089 .36233 L F
.72124 .36187 m .72125 .36186 L .72126 .36201 L F
.71781 .36096 m .72115 .36242 L .72133 .36176 L .644 .736 .916 r
F
.72015 .36305 m .71999 .36315 L .71999 .36309 L .379 .203 .512 r
F
.71995 .36312 m .71986 .36319 L .71998 .36314 L .667 .747 .91 r
F
.71986 .36319 m .71992 .3632 L .71986 .36324 L .379 .203 .512 r
F
.71992 .36315 m .71992 .3632 L .71986 .36319 L F
.71997 .36311 m .71997 .36317 L .71992 .36315 L F
.71997 .36317 m .71992 .3632 L .71992 .36315 L F
.71985 .36319 m .71986 .36319 L .71986 .36324 L .519 .305 .529 r
F
.72015 .36298 m .72071 .36269 L .72015 .36305 L .379 .203 .512 r
F
.71781 .36096 m .71957 .36334 L .72055 .363 L .644 .736 .916 r
F
.72123 .37061 m .72156 .37076 L .72168 .37031 L .643 .737 .917 r
F
.72122 .37061 m .72122 .37061 L .72123 .37061 L F
.72122 .37061 m .72156 .37076 L .72123 .37061 L F
.72079 .36258 m .7214 .3704 L .72071 .36269 L .157 .044 .463 r
F
.7214 .3704 m .72413 .40567 L .72133 .37048 L F
.7214 .3704 m .72133 .37048 L .72071 .36269 L F
.72122 .37061 m .72122 .37061 L .72122 .37061 L .643 .737 .917 r
F
.72122 .37061 m .7213 .37172 L .72122 .37061 L F
.72015 .36305 m .72071 .36269 L .72123 .37061 L .379 .203 .512 r
F
.72077 .3709 m .72123 .37061 L .72357 .40639 L F
.72015 .36305 m .72123 .37061 L .72077 .3709 L F
.72057 .3565 m .72057 .35948 L .72073 .35961 L .928 .626 .449 r
F
.71781 .36096 m .72102 .36003 L .72047 .35958 L .644 .736 .916 r
F
.72057 .35948 m .72057 .35966 L .72073 .35961 L .928 .626 .449 r
F
.72132 .36057 m .7216 .36052 L .72127 .36041 L .667 .747 .91 r
F
.71781 .36096 m .72164 .36054 L .72102 .36003 L .644 .736 .916 r
F
.7209 .36245 m .72126 .36201 L .72178 .36993 L .157 .044 .463 r
F
.72122 .37061 m .72168 .37031 L .72176 .37002 L .643 .737 .917 r
F
.7209 .36245 m .72178 .36993 L .72148 .37029 L .157 .044 .463 r
F
.71753 .36382 m .7192 .37156 L .71824 .37164 L .638 .394 .533 r
F
.71754 .36382 m .7192 .37156 L .71753 .36382 L F
.71799 .36376 m .7178 .36403 L .71807 .36407 L .667 .747 .91 r
F
.71754 .36382 m .71869 .36366 L .7192 .37156 L .638 .394 .533 r
F
.71887 .36359 m .71956 .37144 L .71884 .3636 L .519 .305 .529 r
F
.71956 .37144 m .71954 .37145 L .71884 .3636 L F
.71903 .36362 m .7191 .36374 L .71932 .36359 L .644 .736 .916 r
F
.71811 .36205 m .71739 .36375 L .71854 .36366 L F
.71824 .36228 m .71869 .36364 L .71898 .36354 L F
.71811 .36205 m .71854 .36366 L .71824 .36228 L F
.71731 .36122 m .71888 .36358 L .71878 .3632 L .667 .747 .91 r
F
.71888 .36358 m .71993 .36516 L .71898 .36354 L F
.71898 .36354 m .71887 .36359 L .71887 .36358 L .519 .305 .529 r
F
.71888 .36358 m .71898 .36354 L .71878 .3632 L .667 .747 .91 r
F
.72304 .36214 m .75025 .36826 L .72532 .36136 L .644 .736 .916 r
F
.78199 .36733 m .81378 .37452 L .82075 .35823 L .645 .736 .915 r
F
.78199 .36733 m .82075 .35823 L .78644 .35643 L F
.75 .36011 m .78199 .36733 L .78644 .35643 L F
.75025 .36826 m .78248 .37552 L .78696 .36459 L .644 .736 .916 r
F
.75025 .36826 m .78696 .36459 L .75239 .36277 L F
.73032 .36775 m .75248 .37095 L .75227 .36531 L .643 .737 .917 r
F
.71909 .36351 m .71975 .37138 L .71887 .36359 L .519 .305 .529 r
F
.71975 .37138 m .71956 .37144 L .71887 .36359 L F
.71932 .36359 m .71946 .36421 L .71973 .36356 L .644 .736 .916 r
F
.71946 .36421 m .71978 .36382 L .71973 .36356 L F
.71973 .36356 m .71983 .36376 L .71985 .36373 L F
.71909 .36351 m .71986 .36324 L .72038 .37116 L .519 .305 .529 r
F
.71975 .37138 m .72038 .37116 L .72271 .40699 L F
.71909 .36351 m .72038 .37116 L .71975 .37138 L F
.71781 .36096 m .72047 .35958 L .72004 .35922 L .644 .736 .916 r
F
.71781 .36096 m .72004 .35922 L .71987 .35916 L F
.72303 .36918 m .72516 .36952 L .72608 .3692 L .643 .737 .917 r
F
.71877 .36363 m .72271 .40699 L .71869 .36366 L .519 .305 .529 r
F
.71752 .36374 m .71824 .37164 L .71719 .36377 L .638 .394 .533 r
F
.71867 .37227 m .71822 .37426 L .71897 .37335 L .643 .737 .917 r
F
.71288 .36924 m .70638 .37215 L .71037 .37343 L .644 .736 .916 r
F
.71288 .36924 m .71041 .37338 L .7127 .37368 L F
.7127 .37368 m .70582 .38106 L .71237 .38195 L F
.71288 .36924 m .71237 .38195 L .71455 .38224 L F
.71115 .37348 m .71533 .37404 L .71537 .37452 L .731 .47 .533 r
F
.7125 .36979 m .71537 .37452 L .71601 .37011 L .667 .747 .91 r
F
.7149 .36552 m .7125 .36979 L .71601 .37011 L F
.71331 .36506 m .7125 .36979 L .7149 .36552 L F
.71553 .3644 m .71331 .36506 L .7149 .36552 L F
.71621 .36366 m .71522 .36347 L .71607 .36389 L .644 .736 .916 r
F
.7158 .36358 m .71692 .3639 L .71581 .36373 L .753 .483 .523 r
F
.71454 .36312 m .71522 .36347 L .71523 .36364 L .857 .566 .495 r
F
.7158 .36391 m .71475 .36368 L .71553 .3644 L .667 .747 .91 r
F
.71523 .36364 m .71475 .36368 L .7158 .36391 L F
.71493 .36351 m .71485 .36359 L .71523 .36364 L F
.71485 .36359 m .71475 .36368 L .71523 .36364 L F
.7158 .36358 m .71581 .36373 L .71548 .36352 L .753 .483 .523 r
F
.71581 .36373 m .7155 .36368 L .71548 .36352 L F
.71522 .36347 m .71523 .36365 L .71523 .36364 L F
.7159 .36374 m .71523 .36364 L .7158 .36391 L .667 .747 .91 r
F
.71475 .36368 m .71331 .36506 L .71553 .3644 L F
.71822 .37426 m .71747 .37756 L .71864 .37461 L .643 .737 .917 r
F
.71747 .37756 m .71455 .39036 L .71773 .37812 L F
.71747 .37756 m .71773 .37812 L .71864 .37461 L F
.71831 .3725 m .71828 .37267 L .71867 .37227 L F
.718 .374 m .71455 .39036 L .71823 .37422 L F
.7149 .36552 m .71601 .37011 L .71666 .36568 L .667 .747 .91 r
F
.71692 .3639 m .7149 .36552 L .71666 .36568 L F
.71743 .37171 m .71743 .37171 L .7185 .37162 L .643 .737 .917 r
F
.71743 .37171 m .71735 .3722 L .71844 .37191 L F
.71475 .36368 m .71198 .36435 L .71331 .36506 L .667 .747 .91 r
F
.71454 .36312 m .71523 .36364 L .71455 .36333 L .857 .566 .495 r
F
.7142 .36316 m .71198 .36435 L .71475 .36368 L .667 .747 .91 r
F
.71413 .36309 m .71409 .36311 L .7142 .36316 L F
.71409 .36311 m .71198 .36435 L .7142 .36316 L F
.71454 .36312 m .71455 .36333 L .71434 .36303 L .857 .566 .495 r
F
.71455 .36333 m .71516 .37111 L .71436 .36324 L F
.71455 .36333 m .71436 .36324 L .71434 .36303 L F
.71375 .36253 m .71418 .36295 L .7142 .36316 L .947 .644 .431 r
F
.70449 .36243 m .70112 .36739 L .70641 .36428 L .667 .747 .91 r
F
.71188 .36272 m .70549 .36455 L .71048 .36479 L .644 .736 .916 r
F
.71413 .36309 m .71102 .36342 L .71198 .36435 L .667 .747 .91 r
F
.71354 .36254 m .71354 .36254 L .71413 .36309 L F
.71354 .36254 m .71102 .36342 L .71381 .36313 L F
.71354 .36254 m .71381 .36313 L .71413 .36309 L F
.69823 .36462 m .70087 .36422 L .70112 .36739 L .949 .646 .426 r
F
.69823 .36462 m .69798 .36145 L .70087 .36422 L F
.70429 .35923 m .70095 .36417 L .70621 .36108 L .668 .747 .91 r
F
.70429 .35923 m .69807 .36142 L .70095 .36417 L F
.69936 .36767 m .69823 .36462 L .70112 .36739 L .949 .646 .426 r
F
.69839 .36672 m .69823 .36462 L .69936 .36767 L F
.70449 .36243 m .69823 .36462 L .70112 .36739 L .667 .747 .91 r
F
.69913 .36819 m .68642 .37011 L .6899 .37348 L .644 .736 .916 r
F
.70549 .36455 m .69835 .36663 L .69913 .36819 L F
.69835 .36663 m .68642 .37011 L .69913 .36819 L F
.69831 .36664 m .68368 .36478 L .68642 .37011 L F
.69732 .3646 m .69823 .36462 L .69839 .36672 L .968 .682 .269 r
F
.6966 .3614 m .69798 .36145 L .69823 .36462 L F
.69835 .36663 m .69537 .36378 L .69831 .36664 L .644 .736 .916 r
F
.69732 .3646 m .6966 .3614 L .69823 .36462 L .968 .682 .269 r
F
.69676 .36351 m .6966 .3614 L .69732 .3646 L F
.70341 .36028 m .69823 .36462 L .70449 .36243 L .667 .747 .91 r
F
.6966 .3614 m .69636 .35822 L .69798 .36145 L .968 .682 .269 r
F
.70323 .35709 m .69807 .36142 L .70429 .35923 L .668 .747 .91 r
F
.70323 .35709 m .69646 .3582 L .69807 .36142 L F
.70341 .36028 m .6966 .3614 L .69823 .36462 L .667 .747 .91 r
F
.71076 .36024 m .70641 .36428 L .71172 .36117 L F
.71076 .36024 m .70449 .36243 L .70641 .36428 L F
.71348 .36223 m .69684 .36365 L .69835 .36663 L .644 .736 .916 r
F
.69684 .36365 m .69537 .36378 L .69835 .36663 L F
.71292 .36087 m .71172 .36117 L .71288 .36179 L .667 .747 .91 r
F
.71292 .36087 m .71288 .36179 L .71304 .36188 L F
.71313 .36149 m .69675 .36332 L .71348 .36223 L .644 .736 .916 r
F
.69675 .36332 m .68368 .36478 L .69677 .36366 L F
.69675 .36332 m .69677 .36366 L .71348 .36223 L F
.69661 .36121 m .6966 .3614 L .69676 .36351 L 0 0 .062 r
F
.71307 .3585 m .71321 .3608 L .71321 .36076 L 0 0 .132 r
F
.71678 .35486 m .71513 .35263 L .71484 .35272 L .668 .747 .91 r
F
.71705 .35804 m .71388 .3599 L .714 .36001 L .667 .747 .91 r
F
.71705 .35804 m .714 .36001 L .71456 .36027 L F
.71451 .35293 m .7148 .35275 L .71474 .35109 L .414 .228 .517 r
F
.71626 .33605 m .71599 .35078 L .71693 .35074 L .657 .408 .532 r
F
.71505 .33614 m .71571 .35085 L .71599 .35078 L .566 .34 .531 r
F
.71781 .35283 m .70334 .33312 L .69567 .33623 L .645 .736 .915 r
F
.71571 .35085 m .71578 .35244 L .71599 .35078 L .566 .34 .531 r
F
.71578 .35244 m .71605 .35236 L .71599 .35078 L F
.71474 .35109 m .7148 .35275 L .71484 .35272 L .414 .228 .517 r
F
.71571 .35085 m .71474 .35109 L .71484 .35272 L .566 .34 .531 r
F
.71571 .35085 m .71484 .35272 L .71578 .35244 L F
.71678 .35486 m .71563 .35054 L .71391 .35098 L .668 .747 .91 r
F
.7128 .35551 m .71248 .35484 L .7128 .35551 L F
.71248 .35484 m .70993 .35482 L .7128 .35551 L F
.71309 .35645 m .71263 .35485 L .7114 .35577 L .667 .747 .91 r
F
.71451 .35293 m .71465 .35612 L .7148 .35275 L .414 .228 .517 r
F
.71705 .35804 m .71451 .35621 L .71373 .35671 L .667 .747 .91 r
F
.71465 .35612 m .71479 .35603 L .7148 .35275 L .414 .228 .517 r
F
.71451 .35293 m .71372 .35671 L .71465 .35612 L F
.71433 .35608 m .71419 .35448 L .71392 .35578 L .667 .747 .91 r
F
.71451 .35293 m .71352 .35357 L .71372 .35671 L .414 .228 .517 r
F
.71419 .35448 m .71416 .35414 L .71392 .35578 L .667 .747 .91 r
F
.71282 .35484 m .71283 .35466 L .71272 .35484 L .668 .747 .91 r
F
.71392 .35578 m .71416 .35414 L .71263 .35485 L .667 .747 .91 r
F
.71678 .35486 m .71638 .35758 L .71652 .3576 L .668 .747 .91 r
F
.71678 .35486 m .71652 .3576 L .71748 .35747 L F
.71705 .35804 m .71504 .35587 L .71451 .35621 L .667 .747 .91 r
F
.71478 .35923 m .71503 .35909 L .71492 .35595 L .414 .228 .517 r
F
.71479 .35603 m .71492 .35595 L .7148 .35275 L F
.71478 .35923 m .71492 .35595 L .71479 .35603 L F
.71705 .35804 m .71537 .35577 L .71504 .35587 L .667 .747 .91 r
F
.7148 .35275 m .71492 .35595 L .71484 .35272 L .414 .228 .517 r
F
.71022 .35916 m .70449 .36243 L .71076 .36024 L .667 .747 .91 r
F
.71053 .35705 m .70429 .35923 L .70621 .36108 L .668 .747 .91 r
F
.71022 .35916 m .70341 .36028 L .70449 .36243 L .667 .747 .91 r
F
.71029 .3618 m .70879 .36053 L .6977 .36321 L .644 .736 .916 r
F
.71307 .35882 m .7133 .36184 L .71306 .35879 L .965 .686 .26 r
F
.71313 .36149 m .7122 .36071 L .71029 .3618 L .644 .736 .916 r
F
.71306 .35879 m .7133 .36184 L .713 .35866 L .965 .686 .26 r
F
.7132 .36104 m .71321 .36089 L .71302 .35789 L 0 0 .132 r
F
.7132 .36104 m .71302 .35789 L .71302 .35799 L F
.713 .35866 m .7133 .36184 L .71318 .36159 L .965 .686 .26 r
F
.71302 .35806 m .71318 .36159 L .7132 .36104 L 0 0 .132 r
F
.71301 .35835 m .71318 .36159 L .71302 .35806 L F
.71302 .35806 m .7132 .36104 L .71302 .35799 L F
.71301 .35842 m .71318 .36159 L .71301 .35835 L F
.71301 .35842 m .713 .35866 L .71318 .36159 L F
.71321 .36089 m .71321 .3608 L .71307 .3585 L F
.7175 .361 m .71278 .36075 L .71313 .36149 L .644 .736 .916 r
F
.71293 .36045 m .71172 .36117 L .71292 .36087 L .667 .747 .91 r
F
.71278 .36075 m .7122 .36071 L .71313 .36149 L .644 .736 .916 r
F
.7122 .36071 m .70879 .36053 L .71029 .3618 L F
.71465 .35612 m .71372 .35671 L .71391 .35973 L .414 .228 .517 r
F
.71352 .35704 m .71321 .36076 L .71367 .36008 L .076 0 .438 r
F
.71746 .36095 m .71227 .36067 L .7175 .361 L .644 .736 .916 r
F
.69637 .35793 m .69636 .35822 L .6966 .3614 L 0 0 .062 r
F
.70308 .35479 m .69646 .3582 L .70323 .35709 L .668 .747 .91 r
F
.70308 .35479 m .69622 .35475 L .69646 .3582 L F
.70326 .35797 m .69637 .35793 L .6966 .3614 L .667 .747 .91 r
F
.69661 .36121 m .69637 .35793 L .6966 .3614 L 0 0 .062 r
F
.69653 .36013 m .69637 .35793 L .69661 .36121 L F
.70326 .35797 m .6966 .3614 L .70341 .36028 L .667 .747 .91 r
F
.71015 .358 m .70341 .36028 L .71022 .35916 L F
.71 .35597 m .70429 .35923 L .71053 .35705 L .668 .747 .91 r
F
.71 .35597 m .70323 .35709 L .70429 .35923 L F
.71015 .358 m .70326 .35797 L .70341 .36028 L .667 .747 .91 r
F
.70879 .36053 m .69663 .35987 L .6977 .36321 L .644 .736 .916 r
F
.70993 .35482 m .70323 .35709 L .71 .35597 L .668 .747 .91 r
F
.70993 .35482 m .70308 .35479 L .70323 .35709 L F
.70405 .35566 m .69637 .35793 L .70326 .35797 L .667 .747 .91 r
F
.69739 .35773 m .69637 .35793 L .69653 .36013 L 0 0 .358 r
F
.69663 .35987 m .68325 .35915 L .69564 .36263 L .644 .736 .916 r
F
.69663 .35987 m .69564 .36263 L .6977 .36321 L F
.71227 .36067 m .69652 .35985 L .7122 .36071 L F
.69652 .35985 m .69652 .35987 L .7122 .36071 L F
.71705 .35804 m .71942 .35576 L .71868 .35551 L .667 .747 .91 r
F
.71833 .35547 m .71857 .3555 L .71844 .35236 L .735 .468 .525 r
F
.71848 .35549 m .71868 .35551 L .7185 .35545 L .667 .747 .91 r
F
.71705 .35804 m .71868 .35551 L .71848 .35549 L F
.71626 .33605 m .71693 .35074 L .7172 .35073 L .657 .408 .532 r
F
.71743 .33619 m .71626 .33605 L .7172 .35073 L .735 .468 .525 r
F
.71781 .35283 m .71203 .33137 L .70334 .33312 L .645 .736 .915 r
F
.71781 .35283 m .72113 .33109 L .71203 .33137 L F
.71678 .35486 m .71819 .35233 L .7173 .35224 L .668 .747 .91 r
F
.71678 .35486 m .7173 .35224 L .71716 .35225 L F
.71747 .36095 m .7197 .35894 L .71951 .35887 L .667 .747 .91 r
F
.71747 .36095 m .71964 .35874 L .71876 .35865 L F
.69237 .35963 m .68517 .35362 L .68325 .35915 L .644 .736 .916 r
F
.71751 .36103 m .71979 .35885 L .71747 .36095 L .667 .747 .91 r
F
.71352 .35704 m .71367 .36008 L .71358 .35694 L .076 0 .438 r
F
.71367 .36008 m .71381 .35989 L .71366 .35682 L F
.71367 .36008 m .71366 .35682 L .71358 .35694 L F
.71705 .35804 m .71665 .36076 L .71773 .36061 L .667 .747 .91 r
F
.71456 .36042 m .71442 .3604 L .7145 .36048 L F
.71705 .35804 m .71442 .3604 L .71456 .36042 L F
.71705 .35804 m .71456 .36042 L .71562 .36058 L F
.71705 .35804 m .71562 .36058 L .71665 .36074 L F
.71746 .36095 m .71347 .35999 L .71227 .36067 L .644 .736 .916 r
F
.71781 .36096 m .71742 .36088 L .71746 .36095 L F
.71742 .36088 m .71347 .35999 L .71746 .36095 L F
.71504 .35587 m .71515 .35902 L .71524 .35897 L .414 .228 .517 r
F
.71227 .36067 m .7122 .36071 L .7175 .361 L .644 .736 .916 r
F
.71492 .35595 m .71503 .35909 L .71496 .35592 L .414 .228 .517 r
F
.71503 .35909 m .71507 .35907 L .71496 .35592 L F
.71465 .35612 m .71391 .35973 L .71478 .35923 L F
.71465 .35612 m .71478 .35923 L .71479 .35603 L F
.71752 .36105 m .71313 .36149 L .71348 .36223 L .644 .736 .916 r
F
.71781 .36096 m .7175 .361 L .71752 .36105 L F
.7175 .361 m .71313 .36149 L .71752 .36105 L F
.71725 .35541 m .71725 .35541 L .71722 .35225 L .657 .408 .532 r
F
.71705 .35804 m .71743 .35539 L .71637 .35549 L .667 .747 .91 r
F
.71725 .35541 m .71722 .35225 L .71722 .35225 L .657 .408 .532 r
F
.71705 .35804 m .71859 .35529 L .71743 .35539 L .667 .747 .91 r
F
.71729 .35858 m .71725 .35541 L .71725 .35541 L .657 .408 .532 r
F
.71725 .35541 m .71722 .35225 L .71725 .35541 L F
.71781 .36096 m .71746 .36095 L .7175 .361 L .644 .736 .916 r
F
.71735 .3722 m .71719 .37324 L .71828 .37267 L .643 .737 .917 r
F
.71719 .37324 m .718 .374 L .71828 .37267 L F
.71735 .3722 m .71828 .37267 L .71844 .37191 L F
.71719 .37324 m .71455 .39036 L .718 .374 L F
.71743 .37171 m .71844 .37191 L .7185 .37162 L F
.71735 .3722 m .71334 .37784 L .71455 .39036 L F
.71716 .37211 m .71334 .37784 L .71735 .3722 L F
.71354 .36254 m .71048 .36235 L .71102 .36342 L .667 .747 .91 r
F
.71323 .36189 m .71319 .3619 L .71354 .36254 L F
.71319 .3619 m .71048 .36235 L .71317 .36252 L F
.71319 .3619 m .71317 .36252 L .71354 .36254 L F
.7132 .36104 m .71318 .36159 L .71319 .36182 L 0 0 .132 r
F
.7133 .36184 m .71331 .36206 L .71327 .36179 L .965 .686 .26 r
F
.71331 .36206 m .71353 .36596 L .71329 .36201 L F
.71331 .36206 m .71329 .36201 L .71327 .36179 L F
.71331 .36206 m .71384 .36985 L .71353 .36596 L F
.7133 .36184 m .71331 .36207 L .71331 .36206 L F
.71331 .36207 m .71384 .36985 L .71331 .36206 L F
.71323 .36189 m .71041 .36119 L .71048 .36235 L .667 .747 .91 r
F
.7132 .36104 m .71319 .36182 L .71322 .36125 L 0 0 .132 r
F
.71327 .36179 m .71329 .36201 L .71318 .36159 L .965 .686 .26 r
F
.71329 .36201 m .7132 .36183 L .71318 .36159 L F
.7133 .36184 m .71402 .37024 L .71384 .36985 L F
.7132 .36104 m .71322 .36125 L .71321 .36089 L 0 0 .132 r
F
.71731 .36122 m .71322 .3612 L .71323 .36189 L .667 .747 .91 r
F
.7133 .36184 m .71352 .36232 L .71353 .36254 L .965 .686 .26 r
F
.7133 .36184 m .71353 .36254 L .71332 .36208 L F
.71362 .36241 m .71364 .36264 L .71352 .36232 L .947 .644 .431 r
F
.71364 .36264 m .71354 .36255 L .71352 .36232 L F
.71731 .36122 m .71323 .36189 L .71353 .36254 L .667 .747 .91 r
F
.71433 .37053 m .71422 .37043 L .71364 .36264 L .947 .644 .431 r
F
.71364 .36264 m .71364 .36264 L .71362 .36241 L F
.71433 .37053 m .71364 .36264 L .71364 .36264 L F
.71011 .37404 m .71115 .37348 L .71537 .37452 L .731 .47 .533 r
F
.71011 .37404 m .71005 .37333 L .71115 .37348 L F
.7125 .36979 m .71011 .37404 L .71537 .37452 L .667 .747 .91 r
F
.71622 .37181 m .7134 .37651 L .71711 .37208 L .643 .737 .917 r
F
.71652 .37179 m .71711 .37208 L .71742 .37171 L F
.71622 .37181 m .71711 .37208 L .71652 .37179 L F
.71434 .36303 m .71436 .36324 L .71418 .36295 L .857 .566 .495 r
F
.71436 .36324 m .7142 .36316 L .71418 .36295 L F
.715 .37103 m .71487 .37096 L .71418 .36295 L F
.71418 .36295 m .71487 .37096 L .71468 .37087 L F
.71516 .37111 m .715 .37103 L .71434 .36303 L F
.71731 .36122 m .71413 .36309 L .7142 .36316 L .667 .747 .91 r
F
.71493 .36351 m .7142 .36316 L .71475 .36368 L F
.71731 .36122 m .7142 .36316 L .71493 .36351 L F
.71436 .36324 m .715 .37103 L .7142 .36316 L .857 .566 .495 r
F
.7134 .37651 m .71334 .37784 L .71742 .37171 L .643 .737 .917 r
F
.7134 .37651 m .69784 .38665 L .7058 .38918 L F
.7159 .36374 m .7149 .36552 L .71692 .3639 L .667 .747 .91 r
F
.71523 .36365 m .71603 .37144 L .71523 .36364 L .753 .483 .523 r
F
.71603 .37144 m .71603 .37144 L .71523 .36364 L F
.71523 .36364 m .71603 .37144 L .71572 .37139 L F
.71692 .36379 m .71775 .37168 L .71742 .37171 L .638 .394 .533 r
F
.7155 .36368 m .71625 .37149 L .71524 .36365 L .753 .483 .523 r
F
.71625 .37149 m .71603 .37144 L .71522 .36347 L F
.71455 .36333 m .71523 .36364 L .71572 .37139 L .857 .566 .495 r
F
.71455 .36333 m .71572 .37139 L .71516 .37111 L F
.71581 .36373 m .71651 .37154 L .7155 .36368 L .753 .483 .523 r
F
.71639 .37151 m .71354 .37288 L .7134 .37651 L .643 .737 .917 r
F
.71534 .37131 m .71354 .37288 L .71639 .37151 L F
.71651 .37154 m .71625 .37149 L .7155 .36368 L .753 .483 .523 r
F
.71824 .37164 m .71797 .37167 L .71719 .36377 L .638 .394 .533 r
F
.71581 .36373 m .71692 .3639 L .71742 .37171 L .753 .483 .523 r
F
.71581 .36373 m .71742 .37171 L .71651 .37154 L F
.71719 .36377 m .71797 .37167 L .71714 .36377 L .638 .394 .533 r
F
.71797 .37167 m .71793 .37167 L .71714 .36377 L F
.71828 .37267 m .718 .374 L .71855 .3728 L .643 .737 .917 r
F
.718 .374 m .71823 .37422 L .71855 .3728 L F
.71714 .36377 m .71793 .37167 L .71692 .36379 L .638 .394 .533 r
F
.71793 .37167 m .72152 .40745 L .71775 .37168 L F
.71793 .37167 m .71775 .37168 L .71692 .36379 L F
.71322 .3612 m .71319 .36182 L .71323 .36189 L .667 .747 .91 r
F
.71291 .3612 m .71041 .36119 L .71323 .36189 L F
.71384 .36985 m .71374 .36965 L .71318 .36159 L .965 .686 .26 r
F
.71322 .36125 m .71319 .36182 L .71368 .36951 L 0 0 .132 r
F
.71462 .37194 m .71356 .37244 L .71354 .37288 L .643 .737 .917 r
F
.71377 .36277 m .7142 .36316 L .71468 .37087 L .947 .644 .431 r
F
.71375 .36253 m .71468 .37087 L .71433 .37053 L F
.71782 .36913 m .71361 .37132 L .71462 .37194 L .643 .737 .917 r
F
.71361 .37132 m .71198 .37216 L .71358 .37203 L F
.71361 .37132 m .71358 .37203 L .71462 .37194 L F
.71329 .36201 m .71353 .36596 L .7132 .36183 L .965 .686 .26 r
F
.71169 .35991 m .71022 .35916 L .71076 .36024 L .667 .747 .91 r
F
.71297 .35946 m .71076 .36024 L .71295 .36 L F
.71227 .36067 m .70895 .35897 L .69237 .35963 L .644 .736 .916 r
F
.71322 .3612 m .71081 .36004 L .71041 .36119 L .667 .747 .91 r
F
.71367 .36008 m .71321 .36076 L .71323 .36096 L .076 0 .438 r
F
.71731 .36122 m .7135 .36053 L .71322 .3612 L .667 .747 .91 r
F
.7135 .36053 m .71323 .36096 L .71322 .3612 L F
.71198 .37216 m .71098 .37268 L .71462 .37194 L .643 .737 .917 r
F
.71037 .37343 m .70507 .37274 L .70582 .38106 L .644 .736 .916 r
F
.70638 .37215 m .70507 .37274 L .71037 .37343 L F
.70507 .37274 m .69788 .37852 L .70056 .37938 L F
.70507 .37274 m .70056 .37938 L .70582 .38106 L F
.70534 .3727 m .70655 .37221 L .71011 .37404 L .8 .522 .518 r
F
.70655 .37221 m .71005 .37333 L .71011 .37404 L F
.71304 .36517 m .706 .37137 L .713 .36617 L .644 .736 .916 r
F
.70932 .36889 m .71011 .37404 L .7125 .36979 L .667 .747 .91 r
F
.70542 .37188 m .69127 .37479 L .69788 .37852 L .644 .736 .916 r
F
.706 .37137 m .69788 .37852 L .70507 .37274 L F
.70534 .3727 m .70527 .3718 L .70655 .37221 L .8 .522 .518 r
F
.70932 .36889 m .70534 .3727 L .71011 .37404 L .667 .747 .91 r
F
.71098 .37268 m .69121 .38293 L .71001 .3741 L .643 .737 .917 r
F
.71098 .37268 m .71001 .3741 L .71462 .37194 L F
.71332 .36208 m .71353 .36254 L .71402 .37024 L .965 .686 .26 r
F
.71375 .36253 m .7142 .36316 L .71377 .36277 L .947 .644 .431 r
F
.71375 .36253 m .71376 .36276 L .71362 .36241 L F
.71376 .36276 m .71364 .36264 L .71362 .36241 L F
.71731 .36122 m .71354 .36254 L .71413 .36309 L .667 .747 .91 r
F
.71364 .36264 m .71422 .37043 L .71354 .36255 L .947 .644 .431 r
F
.71422 .37043 m .71414 .37035 L .71352 .36232 L F
.71352 .36232 m .71414 .37035 L .71402 .37024 L F
.71376 .36276 m .71433 .37053 L .71364 .36264 L F
.71367 .36008 m .71323 .36096 L .71368 .36024 L .076 0 .438 r
F
.71209 .35928 m .71022 .35916 L .71169 .35991 L .667 .747 .91 r
F
.71347 .35999 m .70895 .35897 L .71227 .36067 L .644 .736 .916 r
F
.70936 .35239 m .69261 .34714 L .6835 .35104 L .645 .736 .915 r
F
.69637 .35793 m .69612 .35475 L .69636 .35822 L 0 0 .062 r
F
.70386 .35249 m .69622 .35475 L .70308 .35479 L .668 .747 .91 r
F
.70386 .35249 m .69739 .3513 L .69622 .35475 L F
.69754 .35446 m .69612 .35475 L .69637 .35793 L 0 0 .358 r
F
.69754 .35446 m .69729 .35128 L .69612 .35475 L F
.71055 .35685 m .70326 .35797 L .71015 .358 L .667 .747 .91 r
F
.71055 .35685 m .70405 .35566 L .70326 .35797 L F
.70405 .35566 m .69754 .35446 L .69637 .35793 L F
.69739 .35773 m .69754 .35446 L .69637 .35793 L 0 0 .358 r
F
.69772 .35681 m .69754 .35446 L .69739 .35773 L F
.69547 .35951 m .68517 .35362 L .69237 .35963 L .644 .736 .916 r
F
.70895 .35897 m .69799 .3565 L .69547 .35951 L F
.71033 .35367 m .70308 .35479 L .70993 .35482 L .668 .747 .91 r
F
.71033 .35367 m .70386 .35249 L .70308 .35479 L F
.70573 .3535 m .69754 .35446 L .70405 .35566 L .667 .747 .91 r
F
.69972 .35443 m .69754 .35446 L .69772 .35681 L .176 .064 .477 r
F
.69799 .3565 m .68517 .35362 L .69547 .35951 L .644 .736 .916 r
F
.71249 .35163 m .69261 .34714 L .70936 .35239 L .645 .736 .915 r
F
.70553 .35034 m .69739 .3513 L .70386 .35249 L .668 .747 .91 r
F
.70573 .3535 m .70005 .35122 L .69754 .35446 L .667 .747 .91 r
F
.69972 .35443 m .70005 .35122 L .69754 .35446 L .176 .064 .477 r
F
.69799 .3565 m .69887 .35361 L .69785 .35647 L .644 .736 .916 r
F
.70895 .35897 m .69993 .35417 L .69799 .3565 L F
.69993 .35417 m .69887 .35361 L .69799 .3565 L F
.70025 .35379 m .70005 .35122 L .69972 .35443 L .176 .064 .477 r
F
.71185 .35801 m .71015 .358 L .71266 .35876 L .667 .747 .91 r
F
.7114 .35577 m .70405 .35566 L .71055 .35685 L F
.70005 .35122 m .69729 .35128 L .69754 .35446 L .176 .064 .477 r
F
.7114 .35577 m .70573 .3535 L .70405 .35566 L .667 .747 .91 r
F
.71288 .35881 m .70069 .35349 L .70895 .35897 L .644 .736 .916 r
F
.71116 .3526 m .70386 .35249 L .71033 .35367 L .668 .747 .91 r
F
.71116 .3526 m .70553 .35034 L .70386 .35249 L F
.70819 .35165 m .70005 .35122 L .70573 .3535 L .667 .747 .91 r
F
.70349 .35158 m .70005 .35122 L .70025 .35379 L .373 .203 .519 r
F
.70069 .35349 m .68935 .34855 L .69979 .3541 L .644 .736 .916 r
F
.70069 .35349 m .69979 .3541 L .70895 .35897 L F
.71289 .35802 m .71285 .35727 L .71185 .35801 L .667 .747 .91 r
F
.71285 .35727 m .71062 .35686 L .71179 .35795 L F
.71285 .35727 m .71179 .35795 L .71185 .35801 L F
.71302 .35802 m .71185 .35801 L .713 .3587 L F
.69261 .34714 m .68541 .34552 L .68522 .34606 L .645 .736 .915 r
F
.69261 .34714 m .68522 .34606 L .6835 .35104 L F
.70553 .35034 m .69989 .34807 L .69739 .3513 L .668 .747 .91 r
F
.70005 .35122 m .6998 .34804 L .69729 .35128 L .176 .064 .477 r
F
.71263 .35485 m .70573 .3535 L .7114 .35577 L .667 .747 .91 r
F
.70798 .3485 m .69989 .34807 L .70553 .35034 L .668 .747 .91 r
F
.71283 .35473 m .71283 .35469 L .71272 .35288 L 0 0 .132 r
F
.71285 .35413 m .71116 .3526 L .71033 .35367 L .668 .747 .91 r
F
.71285 .35413 m .71033 .35367 L .71283 .35466 L F
.71263 .35485 m .70819 .35165 L .70573 .3535 L .667 .747 .91 r
F
.70798 .3485 m .70355 .3453 L .69989 .34807 L .668 .747 .91 r
F
.70374 .34844 m .6998 .34804 L .70005 .35122 L .373 .203 .519 r
F
.70374 .34844 m .70349 .34525 L .6998 .34804 L F
.71239 .35168 m .70553 .35034 L .71116 .3526 L .668 .747 .91 r
F
.71239 .35168 m .70798 .3485 L .70553 .35034 L F
.70819 .35165 m .70374 .34844 L .70005 .35122 L .667 .747 .91 r
F
.70349 .35158 m .70374 .34844 L .70005 .35122 L .373 .203 .519 r
F
.71288 .35881 m .70389 .3513 L .70069 .35349 L .644 .736 .916 r
F
.70396 .35126 m .70374 .34844 L .70349 .35158 L .373 .203 .519 r
F
.71332 .35735 m .71372 .35671 L .71285 .35727 L .667 .747 .91 r
F
.71285 .35727 m .71173 .3559 L .71055 .35685 L F
.71173 .3559 m .71126 .35595 L .71055 .35685 L F
.71332 .35735 m .71285 .35727 L .71289 .35802 L F
.71062 .35686 m .71055 .35685 L .71185 .35801 L F
.71303 .3578 m .71303 .35783 L .71307 .3585 L 0 0 .132 r
F
.713 .3587 m .71185 .35801 L .71266 .35876 L .667 .747 .91 r
F
.71483 .35873 m .70452 .35103 L .71288 .35881 L .644 .736 .916 r
F
.71391 .35098 m .70798 .3485 L .71239 .35168 L .668 .747 .91 r
F
.71126 .35023 m .70374 .34844 L .70819 .35165 L .667 .747 .91 r
F
.71391 .35098 m .71103 .34709 L .70798 .3485 L .668 .747 .91 r
F
.71103 .34709 m .70355 .3453 L .70798 .3485 L F
.71103 .34709 m .70813 .34318 L .70355 .3453 L F
.71126 .35023 m .70835 .34631 L .70374 .34844 L .667 .747 .91 r
F
.70844 .34947 m .70374 .34844 L .70396 .35126 L .497 .293 .534 r
F
.70452 .35103 m .69551 .34431 L .70388 .35129 L .644 .736 .916 r
F
.70452 .35103 m .70388 .35129 L .71288 .35881 L F
.71373 .35671 m .71433 .35608 L .71309 .35645 L .667 .747 .91 r
F
.71282 .35484 m .71248 .35484 L .7128 .35551 L .668 .747 .91 r
F
.71433 .35608 m .71263 .35485 L .71309 .35645 L .667 .747 .91 r
F
.71373 .35671 m .71173 .3559 L .71372 .35671 L F
.71173 .3559 m .7114 .35577 L .71126 .35595 L F
.71353 .35355 m .7129 .3533 L .71305 .35387 L .668 .747 .91 r
F
.71352 .35357 m .71305 .35387 L .71313 .35419 L F
.71335 .35384 m .71347 .35365 L .71342 .35185 L .076 0 .438 r
F
.71313 .35419 m .7129 .3533 L .71285 .35413 L .668 .747 .91 r
F
.7129 .3533 m .71288 .35331 L .71285 .35413 L F
.71272 .35288 m .71283 .35469 L .71283 .35467 L 0 0 .132 r
F
.71271 .35306 m .71282 .35487 L .71272 .35288 L F
.71288 .35329 m .71116 .3526 L .71285 .35413 L .668 .747 .91 r
F
.71416 .35414 m .70819 .35165 L .71263 .35485 L .667 .747 .91 r
F
.71353 .35355 m .71305 .35387 L .71352 .35357 L .668 .747 .91 r
F
.71354 .35356 m .71353 .35355 L .71352 .35357 L F
.7129 .3533 m .71288 .35329 L .71288 .35331 L F
.71353 .35355 m .71292 .35207 L .71288 .35329 L F
.71399 .35284 m .71292 .35207 L .71353 .35355 L F
.71292 .35207 m .71239 .35168 L .71288 .35329 L F
.71416 .35414 m .71126 .35023 L .70819 .35165 L .667 .747 .91 r
F
.70835 .34631 m .70349 .34525 L .70374 .34844 L .497 .293 .534 r
F
.70835 .34631 m .70809 .34312 L .70349 .34525 L F
.70844 .34947 m .70835 .34631 L .70374 .34844 L F
.71483 .35873 m .70865 .34939 L .70452 .35103 L .644 .736 .916 r
F
.71563 .35054 m .71103 .34709 L .71391 .35098 L .668 .747 .91 r
F
.71563 .35054 m .71447 .34621 L .71103 .34709 L F
.71473 .34935 m .70835 .34631 L .71126 .35023 L .667 .747 .91 r
F
.71447 .34621 m .70813 .34318 L .71103 .34709 L .668 .747 .91 r
F
.71447 .34621 m .71331 .34185 L .70813 .34318 L F
.71473 .34935 m .71356 .34498 L .70835 .34631 L .667 .747 .91 r
F
.71383 .34817 m .70835 .34631 L .7086 .3494 L .587 .36 .538 r
F
.70865 .34939 m .70865 .34938 L .7086 .3494 L .644 .736 .916 r
F
.70865 .34939 m .7086 .3494 L .70452 .35103 L F
.71383 .34817 m .7086 .3494 L .7105 .34902 L .587 .36 .538 r
F
.7086 .3494 m .70835 .34631 L .70844 .34947 L .497 .293 .534 r
F
.71492 .35595 m .71496 .35592 L .71484 .35272 L .414 .228 .517 r
F
.71606 .35557 m .71617 .35553 L .71605 .35236 L .566 .34 .531 r
F
.71592 .35561 m .71606 .35557 L .71605 .35236 L F
.71484 .35272 m .71496 .35592 L .71504 .35587 L .414 .228 .517 r
F
.71678 .35486 m .71716 .35225 L .71611 .35235 L .668 .747 .91 r
F
.717 .35227 m .71609 .35235 L .71629 .3555 L .657 .408 .532 r
F
.717 .35227 m .71629 .3555 L .71714 .35542 L F
.71705 .35804 m .71636 .35548 L .71537 .35577 L .667 .747 .91 r
F
.71578 .35244 m .71484 .35272 L .71524 .35897 L .566 .34 .531 r
F
.71738 .3608 m .71771 .35854 L .71705 .36024 L .667 .747 .91 r
F
.71771 .35854 m .71749 .35856 L .71705 .36024 L F
.71705 .36024 m .71749 .35856 L .71662 .35864 L F
.71833 .35547 m .7175 .35539 L .71771 .35854 L .735 .468 .525 r
F
.71738 .3608 m .71869 .35864 L .71771 .35854 L .667 .747 .91 r
F
.71948 .35578 m .71868 .35551 L .71889 .35866 L .818 .533 .507 r
F
.71948 .35578 m .71889 .35866 L .71963 .35892 L F
.71948 .35578 m .71963 .35892 L .71972 .35586 L F
.71747 .36095 m .71876 .35865 L .71738 .3608 L .667 .747 .91 r
F
.71876 .35865 m .71869 .35864 L .71738 .3608 L F
.71742 .37171 m .72152 .40745 L .71973 .40767 L .638 .394 .533 r
F
.71775 .37168 m .72152 .40745 L .71742 .37171 L F
.71828 .37267 m .71855 .3728 L .71867 .37227 L .643 .737 .917 r
F
.71824 .37423 m .71864 .37461 L .71897 .37335 L F
.71822 .37426 m .71864 .37461 L .71824 .37423 L F
.7185 .37162 m .71831 .3725 L .71867 .37227 L F
.71824 .37164 m .72152 .40745 L .71797 .37167 L .638 .394 .533 r
F
.71782 .36913 m .7185 .37162 L .71954 .37145 L .643 .737 .917 r
F
.7185 .37162 m .7192 .37156 L .71954 .37145 L F
.71782 .36913 m .72333 .36942 L .72303 .36918 L F
.72189 .36877 m .72194 .36891 L .72148 .36118 L .925 .667 .181 r
F
.72189 .36877 m .72148 .36118 L .72148 .36118 L F
.71857 .3555 m .71871 .35877 L .71868 .35551 L .735 .468 .525 r
F
.72966 .35722 m .73609 .3584 L .73732 .35496 L .668 .747 .91 r
F
.73 .36041 m .73772 .35814 L .73083 .35811 L .667 .747 .91 r
F
.73772 .35814 m .73743 .35496 L .73727 .35148 L 0 0 .105 r
F
.73772 .35814 m .73727 .35148 L .73756 .35466 L F
.738 .36133 m .73772 .35814 L .73756 .35466 L F
.72966 .35722 m .73732 .35496 L .73048 .35493 L .668 .747 .91 r
F
.73048 .35493 m .73732 .35496 L .73717 .3515 L F
.73083 .35811 m .73772 .35814 L .73756 .35466 L .667 .747 .91 r
F
.738 .36133 m .73756 .35466 L .73785 .35785 L 0 0 .105 r
F
.73111 .36129 m .738 .36133 L .73785 .35785 L .667 .747 .91 r
F
.73111 .36129 m .73785 .35785 L .73099 .35898 L F
.72421 .36126 m .73111 .36129 L .73099 .35898 L F
.72421 .36126 m .73099 .35898 L .72415 .3601 L F
.72164 .36054 m .7428 .36227 L .72687 .35995 L .644 .736 .916 r
F
.72147 .36102 m .72147 .36101 L .72148 .36119 L 0 0 .297 r
F
.72148 .36118 m .72148 .36118 L .72147 .361 L .925 .667 .181 r
F
.72147 .36101 m .72147 .361 L .72148 .36119 L 0 0 .297 r
F
.72147 .36102 m .72148 .36119 L .72146 .36103 L F
.72143 .36102 m .72148 .36118 L .72147 .361 L .925 .667 .181 r
F
.72148 .36119 m .72194 .36891 L .72201 .36911 L F
.72147 .361 m .72148 .36118 L .72148 .36119 L F
.72148 .36118 m .72194 .36891 L .72148 .36119 L F
.72127 .36058 m .72245 .36121 L .72164 .36054 L .644 .736 .916 r
F
.71781 .36096 m .72147 .36116 L .72127 .36058 L F
.72147 .36116 m .72245 .36121 L .72127 .36058 L F
.72245 .36121 m .7428 .36227 L .72164 .36054 L F
.72094 .35977 m .72094 .35996 L .72096 .35979 L .928 .626 .449 r
F
.72094 .35996 m .7213 .36775 L .72097 .35998 L F
.72094 .35996 m .72097 .35998 L .72096 .35979 L F
.72143 .36102 m .72189 .36877 L .72148 .36118 L .925 .667 .181 r
F
.72183 .36861 m .72189 .36877 L .72142 .36083 L F
.72186 .36869 m .72608 .3692 L .72404 .36844 L .643 .737 .917 r
F
.71782 .36913 m .72203 .36917 L .72186 .36869 L F
.72203 .36917 m .72608 .3692 L .72186 .36869 L F
.71788 .36166 m .71986 .36319 L .71785 .36161 L .667 .747 .91 r
F
.71781 .36096 m .71824 .36228 L .71957 .36334 L .644 .736 .916 r
F
.71878 .3632 m .71902 .36353 L .71788 .36166 L .667 .747 .91 r
F
.71878 .3632 m .71898 .36354 L .71902 .36353 L F
.71824 .36228 m .71898 .36354 L .71957 .36334 L .644 .736 .916 r
F
.71871 .35877 m .71881 .35878 L .71868 .35551 L .735 .468 .525 r
F
.71876 .35865 m .71974 .35691 L .71869 .35864 L .667 .747 .91 r
F
.71868 .35551 m .71881 .35865 L .71889 .35866 L .735 .468 .525 r
F
.71833 .35547 m .71771 .35854 L .71848 .35862 L F
.71771 .35854 m .71881 .35844 L .71771 .35854 L .667 .747 .91 r
F
.71869 .35864 m .71881 .35844 L .71771 .35854 L F
.71833 .35547 m .71848 .35862 L .71857 .3555 L .735 .468 .525 r
F
.71848 .35862 m .71871 .35864 L .71857 .3555 L F
.71771 .35854 m .71974 .35691 L .71797 .35675 L .667 .747 .91 r
F
.71881 .35844 m .71974 .35691 L .71771 .35854 L F
.7173 .35224 m .71755 .35856 L .71771 .35854 L .657 .408 .532 r
F
.71812 .35087 m .7172 .35073 L .7175 .35539 L .735 .468 .525 r
F
.71812 .35087 m .7175 .35539 L .71833 .35547 L F
.71833 .35547 m .71844 .35236 L .71837 .35235 L F
.71819 .35233 m .71833 .35547 L .71837 .35235 L F
.71933 .35265 m .71948 .35578 L .71958 .35274 L .818 .533 .507 r
F
.71848 .35236 m .71857 .3555 L .71868 .35551 L .735 .468 .525 r
F
.71844 .35236 m .71857 .3555 L .71848 .35236 L F
.71933 .35265 m .71848 .35236 L .71868 .35551 L .818 .533 .507 r
F
.71933 .35265 m .71868 .35551 L .71948 .35578 L F
.71743 .35539 m .71947 .35372 L .7177 .35356 L .667 .747 .91 r
F
.71859 .35529 m .71947 .35372 L .71743 .35539 L F
.71975 .37138 m .72271 .40699 L .71956 .37144 L .519 .305 .529 r
F
.71782 .36913 m .72204 .37008 L .72307 .36941 L .643 .737 .917 r
F
.7213 .36775 m .72132 .36777 L .72096 .35979 L .928 .626 .449 r
F
.7211 .3599 m .7214 .36728 L .72158 .36719 L F
.7214 .36728 m .72143 .36786 L .72158 .36719 L F
.72158 .36719 m .72143 .36786 L .72163 .36803 L F
.72113 .36762 m .7213 .36775 L .72094 .35996 L F
.72136 .36081 m .72111 .3601 L .72163 .36803 L .925 .667 .181 r
F
.72136 .36081 m .72163 .36803 L .72183 .36861 L F
.72134 .36062 m .72183 .36861 L .72142 .36083 L F
.72096 .35979 m .72132 .36777 L .72102 .35984 L .928 .626 .449 r
F
.71782 .36913 m .72163 .36803 L .72098 .3675 L .643 .737 .917 r
F
.71782 .36913 m .72237 .36863 L .72163 .36803 L F
.71782 .36913 m .72122 .37061 L .72176 .37002 L F
.72058 .37103 m .72357 .40639 L .72053 .37106 L .379 .203 .512 r
F
.72123 .37061 m .72413 .40567 L .72357 .40639 L .157 .044 .463 r
F
.72133 .37048 m .72413 .40567 L .72123 .37061 L F
.72038 .37116 m .72357 .40639 L .72271 .40699 L .379 .203 .512 r
F
.72053 .37106 m .72357 .40639 L .72038 .37116 L F
.72077 .3709 m .72357 .40639 L .72064 .37099 L F
.72148 .37029 m .72413 .40567 L .7214 .3704 L .157 .044 .463 r
F
.72062 .371 m .72357 .40639 L .72058 .37103 L .379 .203 .512 r
F
.72132 .36777 m .72288 .40282 L .72137 .36781 L .928 .626 .449 r
F
.72132 .36777 m .72137 .36781 L .72102 .35984 L F
.72148 .37029 m .72178 .36993 L .72413 .40567 L .157 .044 .463 r
F
.72102 .35984 m .72137 .36781 L .7211 .3599 L .928 .626 .449 r
F
.72137 .36781 m .72288 .40282 L .72143 .36786 L F
.72137 .36781 m .72143 .36786 L .7211 .3599 L F
.71996 .35919 m .72028 .36704 L .72004 .35922 L .818 .533 .507 r
F
.72028 .36704 m .72035 .36707 L .72004 .35922 L F
.72004 .35922 m .72035 .36707 L .72056 .36715 L F
.71982 .35589 m .71996 .35919 L .72004 .35922 L F
.72057 .3565 m .71982 .35589 L .72004 .35922 L .928 .626 .449 r
F
.71985 .35899 m .71988 .359 L .71975 .35587 L .818 .533 .507 r
F
.72064 .35258 m .72304 .35266 L .72209 .35173 L .668 .747 .91 r
F
.72267 .35279 m .72304 .35266 L .72064 .35258 L F
.7185 .35545 m .71892 .35553 L .71874 .35502 L .667 .747 .91 r
F
.71892 .35553 m .71953 .35566 L .71944 .35559 L F
.71892 .35553 m .71944 .35559 L .71874 .35502 L F
.71942 .35576 m .71953 .35566 L .7185 .35545 L F
.71948 .35578 m .71972 .35586 L .71958 .35274 L .818 .533 .507 r
F
.71933 .35265 m .71958 .35274 L .71952 .35133 L F
.71914 .35259 m .71962 .35275 L .71927 .35247 L .668 .747 .91 r
F
.71927 .35247 m .72209 .35173 L .72077 .35101 L F
.71993 .353 m .72209 .35173 L .71927 .35247 L F
.72042 .35339 m .71982 .35589 L .72057 .3565 L .928 .626 .449 r
F
.72019 .35321 m .71982 .35589 L .72042 .35339 L F
.71958 .35274 m .71972 .35586 L .71962 .35275 L .818 .533 .507 r
F
.71972 .35586 m .71975 .35587 L .71962 .35275 L F
.71962 .35275 m .71975 .35587 L .71982 .35589 L F
.72019 .35321 m .71962 .35275 L .71982 .35589 L .928 .626 .449 r
F
.71982 .35589 m .72239 .3549 L .71953 .35566 L .667 .747 .91 r
F
.72019 .35619 m .72038 .35608 L .71982 .35589 L F
.72038 .35608 m .72239 .3549 L .71982 .35589 L F
.71942 .35576 m .71982 .35589 L .71953 .35566 L F
.71975 .35587 m .71989 .35916 L .71982 .35589 L .818 .533 .507 r
F
.7192 .37156 m .72271 .40699 L .72152 .40745 L .519 .305 .529 r
F
.71942 .37149 m .72271 .40699 L .7192 .37156 L F
.71956 .37144 m .72271 .40699 L .71954 .37145 L F
.71954 .37145 m .72271 .40699 L .71948 .37147 L F
.71782 .36913 m .71954 .37145 L .72049 .37112 L .643 .737 .917 r
F
.71782 .36913 m .72047 .3711 L .72122 .37061 L F
.71989 .35916 m .72022 .36702 L .71996 .35919 L .818 .533 .507 r
F
.72022 .36702 m .72028 .36704 L .71996 .35919 L F
.71782 .36913 m .72023 .36702 L .71941 .36672 L .643 .737 .917 r
F
.7185 .37162 m .71854 .37179 L .7192 .37156 L F
.71897 .37335 m .71864 .37461 L .71875 .37472 L F
.71824 .37164 m .7192 .37156 L .72152 .40745 L .638 .394 .533 r
F
.71797 .37167 m .72152 .40745 L .71793 .37167 L F
.75 .36011 m .78644 .35643 L .75212 .35463 L .645 .736 .915 r
F
.72687 .35995 m .75239 .36277 L .75217 .35712 L .644 .736 .916 r
F
.7428 .36227 m .75239 .36277 L .72687 .35995 L F
.7211 .3599 m .72164 .36034 L .72182 .35965 L .667 .747 .91 r
F
.72201 .36003 m .72268 .3603 L .72184 .35953 L F
.7216 .36052 m .72415 .3601 L .72182 .35965 L F
.72104 .35718 m .72111 .3601 L .72115 .35752 L .925 .667 .181 r
F
.72101 .35711 m .72089 .35675 L .72111 .3601 L F
.73083 .35811 m .73756 .35466 L .73071 .35579 L .667 .747 .91 r
F
.72322 .35604 m .72966 .35722 L .73048 .35493 L .668 .747 .91 r
F
.72238 .35711 m .72966 .35722 L .72322 .35604 L F
.72394 .35807 m .73083 .35811 L .73071 .35579 L .667 .747 .91 r
F
.72415 .3601 m .72995 .35681 L .72362 .35902 L F
.72415 .3601 m .73099 .35898 L .72995 .35681 L F
.73048 .35493 m .73717 .3515 L .73036 .35262 L .668 .747 .91 r
F
.73036 .35262 m .73717 .3515 L .73561 .34825 L F
.73071 .35579 m .73756 .35466 L .736 .3514 L .667 .747 .91 r
F
.73785 .35785 m .73756 .35466 L .736 .3514 L .959 .671 .239 r
F
.73099 .35898 m .73628 .3546 L .72995 .35681 L .667 .747 .91 r
F
.73099 .35898 m .73785 .35785 L .73628 .3546 L F
.73785 .35785 m .736 .3514 L .73628 .3546 L .959 .671 .239 r
F
.72102 .36003 m .75217 .35712 L .7496 .3517 L .644 .736 .916 r
F
.72164 .36054 m .75217 .35712 L .72102 .36003 L F
.72057 .35966 m .72004 .35922 L .72056 .36715 L .928 .626 .449 r
F
.72057 .35966 m .72056 .36715 L .72073 .35978 L F
.72057 .3565 m .72004 .35922 L .72057 .35966 L F
.72094 .35977 m .72096 .35979 L .72082 .35669 L F
.72094 .35977 m .72082 .35669 L .72081 .35668 L F
.7208 .35667 m .72094 .35977 L .72081 .35668 L F
.72045 .35939 m .7211 .3599 L .72084 .35916 L .667 .747 .91 r
F
.7211 .3599 m .7211 .3599 L .72045 .35939 L F
.72082 .35669 m .72096 .35979 L .72089 .35675 L .928 .626 .449 r
F
.72096 .35979 m .72102 .35984 L .72089 .35675 L F
.72089 .35675 m .72102 .35984 L .7211 .3599 L F
.72101 .35711 m .7211 .35992 L .72104 .35718 L .925 .667 .181 r
F
.7211 .35992 m .72111 .35993 L .72104 .35718 L F
.72084 .35916 m .72182 .35965 L .72214 .35839 L .667 .747 .91 r
F
.7211 .3599 m .72182 .35965 L .72084 .35916 L F
.72162 .35887 m .72353 .35923 L .72134 .35806 L F
.72182 .35965 m .72362 .35902 L .72214 .35839 L F
.72238 .35806 m .72394 .35807 L .72388 .35698 L F
.72322 .35604 m .73048 .35493 L .72363 .35489 L .668 .747 .91 r
F
.72363 .35489 m .73048 .35493 L .73036 .35262 L F
.72394 .35807 m .73071 .35579 L .72388 .35691 L .667 .747 .91 r
F
.72388 .35691 m .73071 .35579 L .72966 .35362 L F
.73756 .35466 m .73727 .35148 L .73571 .34822 L .959 .671 .239 r
F
.73071 .35579 m .736 .3514 L .72966 .35362 L .667 .747 .91 r
F
.73756 .35466 m .73571 .34822 L .736 .3514 L .959 .671 .239 r
F
.72362 .35902 m .72803 .35494 L .72266 .35809 L .667 .747 .91 r
F
.72362 .35902 m .72995 .35681 L .72803 .35494 L F
.73036 .35262 m .73561 .34825 L .72932 .35046 L .668 .747 .91 r
F
.72932 .35046 m .73561 .34825 L .73276 .34545 L F
.72966 .35362 m .736 .3514 L .73313 .34859 L .667 .747 .91 r
F
.72995 .35681 m .73342 .35178 L .72803 .35494 L F
.72995 .35681 m .73628 .3546 L .73342 .35178 L F
.73628 .3546 m .736 .3514 L .73313 .34859 L .952 .644 .412 r
F
.73628 .3546 m .73313 .34859 L .73342 .35178 L F
.72047 .35958 m .7496 .3517 L .74483 .34689 L .644 .736 .916 r
F
.72057 .35966 m .72073 .35978 L .72073 .35961 L .928 .626 .449 r
F
.72073 .35961 m .72073 .35978 L .72074 .3598 L F
.72073 .35961 m .72074 .3598 L .72074 .35961 L F
.7211 .35992 m .72111 .3601 L .72111 .35993 L .925 .667 .181 r
F
.72102 .36003 m .7496 .3517 L .72047 .35958 L .644 .736 .916 r
F
.72074 .3598 m .72056 .36715 L .72113 .36762 L .928 .626 .449 r
F
.72073 .35978 m .72056 .36715 L .72074 .3598 L F
.72074 .3598 m .72113 .36762 L .72094 .35996 L F
.72041 .36687 m .74491 .3551 L .73824 .35123 L .643 .737 .917 r
F
.71781 .36096 m .71907 .35886 L .71816 .35869 L .644 .736 .916 r
F
.71963 .35892 m .71889 .35879 L .71963 .35907 L .818 .533 .507 r
F
.71907 .35886 m .71909 .35882 L .71889 .35879 L .644 .736 .916 r
F
.71907 .35886 m .71889 .35879 L .71816 .35869 L F
.71963 .35892 m .71889 .35866 L .71889 .35879 L .818 .533 .507 r
F
.71989 .35916 m .71996 .35919 L .71982 .35589 L F
.71876 .35865 m .71964 .35874 L .719 .35823 L .667 .747 .91 r
F
.719 .35823 m .72134 .35737 L .71974 .35691 L F
.71979 .35885 m .72134 .35737 L .719 .35823 L F
.72019 .35619 m .72087 .3567 L .72038 .35608 L F
.72084 .35671 m .72087 .3567 L .72019 .35619 L F
.72087 .3567 m .72153 .35647 L .7207 .35619 L F
.72087 .3567 m .7207 .35619 L .72038 .35608 L F
.72038 .35608 m .72301 .35595 L .72096 .35574 L F
.72153 .35647 m .72301 .35595 L .72038 .35608 L F
.72301 .35595 m .72335 .35583 L .72096 .35574 L F
.72088 .35418 m .72111 .35451 L .7212 .35413 L .668 .747 .91 r
F
.72111 .35451 m .72136 .35488 L .7212 .35413 L F
.72112 .35488 m .72136 .35488 L .72088 .35418 L F
.71953 .35566 m .72239 .3549 L .72107 .35418 L .667 .747 .91 r
F
.72087 .3567 m .72388 .35691 L .72335 .35583 L F
.72084 .35671 m .72088 .35671 L .72087 .3567 L F
.72088 .35671 m .72388 .35691 L .72087 .3567 L F
.72157 .35729 m .72388 .35691 L .72084 .35671 L F
.72065 .3535 m .72288 .35385 L .72124 .35329 L .668 .747 .91 r
F
.72088 .35418 m .72288 .35385 L .72065 .3535 L F
.72124 .35329 m .72357 .35374 L .72304 .35266 L F
.72288 .35385 m .72357 .35374 L .72124 .35329 L F
.7212 .35413 m .72136 .35488 L .72203 .35399 L F
.72203 .35399 m .72363 .35489 L .72357 .35374 L F
.72136 .35488 m .72363 .35489 L .72203 .35399 L F
.72363 .35489 m .73036 .35262 L .72357 .35374 L F
.72357 .35374 m .72932 .35046 L .72304 .35266 L F
.72357 .35374 m .73036 .35262 L .72932 .35046 L F
.72304 .35266 m .72742 .3486 L .72209 .35173 L F
.72304 .35266 m .72932 .35046 L .72742 .3486 L F
.72209 .35173 m .72742 .3486 L .72479 .34716 L F
.72335 .35583 m .72775 .35175 L .72239 .3549 L .667 .747 .91 r
F
.72932 .35046 m .73276 .34545 L .72742 .3486 L .668 .747 .91 r
F
.72239 .3549 m .7251 .3503 L .72107 .35418 L .667 .747 .91 r
F
.72239 .3549 m .72775 .35175 L .7251 .3503 L F
.72209 .35173 m .72479 .34716 L .72077 .35101 L .668 .747 .91 r
F
.72077 .35101 m .72479 .34716 L .7216 .34624 L F
.72107 .35418 m .7251 .3503 L .7219 .34939 L .667 .747 .91 r
F
.72742 .3486 m .72881 .34328 L .72479 .34716 L .668 .747 .91 r
F
.72742 .3486 m .73276 .34545 L .72881 .34328 L F
.736 .3514 m .73571 .34822 L .73285 .3454 L .952 .644 .412 r
F
.7211 .35737 m .72238 .35806 L .72388 .35691 L .667 .747 .91 r
F
.72388 .35691 m .72966 .35362 L .72335 .35583 L F
.72335 .35583 m .72966 .35362 L .72775 .35175 L F
.72266 .35809 m .72538 .3535 L .72134 .35737 L F
.72238 .35806 m .72388 .35698 L .72388 .35691 L F
.72266 .35809 m .72803 .35494 L .72538 .3535 L F
.72479 .34716 m .72881 .34328 L .72403 .34191 L .668 .747 .91 r
F
.72134 .35737 m .72217 .35258 L .71974 .35691 L .667 .747 .91 r
F
.72134 .35737 m .72538 .3535 L .72217 .35258 L F
.72775 .35175 m .72915 .34641 L .7251 .3503 L F
.72775 .35175 m .73313 .34859 L .72915 .34641 L F
.736 .3514 m .73285 .3454 L .73313 .34859 L .952 .644 .412 r
F
.73313 .34859 m .73285 .3454 L .72887 .34323 L .877 .58 .482 r
F
.72479 .34716 m .72403 .34191 L .7216 .34624 L .668 .747 .91 r
F
.7251 .3503 m .72434 .34503 L .7219 .34939 L .667 .747 .91 r
F
.7251 .3503 m .72915 .34641 L .72434 .34503 L F
.72966 .35362 m .73313 .34859 L .72775 .35175 L F
.72803 .35494 m .72944 .34961 L .72538 .3535 L F
.72803 .35494 m .73342 .35178 L .72944 .34961 L F
.73313 .34859 m .72887 .34323 L .72915 .34641 L .877 .58 .482 r
F
.73342 .35178 m .73313 .34859 L .72915 .34641 L F
.72915 .34641 m .72887 .34323 L .72406 .34184 L .801 .52 .513 r
F
.72538 .3535 m .72462 .34823 L .72217 .35258 L .667 .747 .91 r
F
.72538 .3535 m .72944 .34961 L .72462 .34823 L F
.72915 .34641 m .72406 .34184 L .72434 .34503 L .801 .52 .513 r
F
.73342 .35178 m .72915 .34641 L .72944 .34961 L .877 .58 .482 r
F
.72944 .34961 m .72915 .34641 L .72434 .34503 L .801 .52 .513 r
F
.72944 .34961 m .72434 .34503 L .72462 .34823 L F
.71907 .35886 m .73818 .34302 L .7301 .34038 L .644 .736 .916 r
F
.71781 .36096 m .71987 .35916 L .71907 .35886 L F
.71963 .35892 m .71963 .35907 L .71964 .35907 L .818 .533 .507 r
F
.71951 .35887 m .71979 .35885 L .71964 .35874 L .667 .747 .91 r
F
.7197 .35894 m .71979 .35885 L .71951 .35887 L F
.71985 .35899 m .71986 .35915 L .71988 .359 L .818 .533 .507 r
F
.71986 .35915 m .71989 .35916 L .71988 .359 L F
.7202 .36701 m .72022 .36702 L .71988 .359 L F
.72022 .36702 m .72022 .36702 L .71988 .359 L F
.72003 .35905 m .72214 .35839 L .71979 .35885 L .667 .747 .91 r
F
.7197 .35894 m .72003 .35905 L .71979 .35885 L F
.71782 .36913 m .7212 .36739 L .72023 .36702 L .643 .737 .917 r
F
.71963 .35892 m .72173 .40242 L .71985 .35899 L .818 .533 .507 r
F
.72134 .35806 m .72238 .35806 L .7211 .35737 L .667 .747 .91 r
F
.71979 .35885 m .72214 .35839 L .72134 .35737 L F
.72214 .35839 m .72227 .35788 L .72134 .35737 L F
.71987 .35916 m .73818 .34302 L .71907 .35886 L .644 .736 .916 r
F
.71964 .35907 m .71941 .36672 L .72002 .36695 L .818 .533 .507 r
F
.71963 .35907 m .71941 .36672 L .71964 .35907 L F
.71963 .35907 m .71889 .35879 L .71941 .36672 L F
.72002 .36695 m .71941 .36672 L .72173 .40242 L F
.72023 .36702 m .72181 .36707 L .72041 .36687 L .643 .737 .917 r
F
.7212 .36739 m .72181 .36707 L .72023 .36702 L F
.72181 .36707 m .74491 .3551 L .72041 .36687 L F
.71889 .35879 m .71919 .36669 L .71889 .35879 L .735 .468 .525 r
F
.71782 .36913 m .71941 .36672 L .71928 .3667 L .643 .737 .917 r
F
.71919 .36669 m .71919 .36669 L .71889 .35879 L .735 .468 .525 r
F
.71889 .35879 m .71919 .36669 L .71941 .36672 L F
.71871 .35877 m .71904 .36667 L .71881 .35878 L F
.71909 .36351 m .71887 .36359 L .71898 .36354 L .519 .305 .529 r
F
.71904 .36667 m .71912 .36668 L .71881 .35878 L .735 .468 .525 r
F
.71881 .35865 m .71912 .36668 L .71889 .35866 L F
.71912 .36668 m .71919 .36669 L .71889 .35866 L F
.71782 .36913 m .71928 .3667 L .71822 .36655 L .643 .737 .917 r
F
.71705 .36024 m .71662 .35864 L .71618 .35874 L .667 .747 .91 r
F
.71714 .35542 m .71649 .35865 L .71729 .35858 L .657 .408 .532 r
F
.71662 .35864 m .71662 .35861 L .71649 .35865 L .667 .747 .91 r
F
.71662 .35864 m .71649 .35865 L .71618 .35874 L F
.71714 .35542 m .71629 .3555 L .71649 .35865 L .657 .408 .532 r
F
.71781 .36096 m .71618 .35874 L .71618 .35874 L .644 .736 .916 r
F
.71729 .35858 m .71649 .35865 L .71649 .35867 L .657 .408 .532 r
F
.71721 .36051 m .71618 .35874 L .71517 .35899 L .644 .736 .916 r
F
.71781 .36096 m .71618 .35874 L .71721 .36051 L F
.71731 .36122 m .71747 .36095 L .71738 .3608 L .667 .747 .91 r
F
.71396 .35928 m .71483 .35873 L .71288 .35881 L .644 .736 .916 r
F
.71496 .35592 m .71507 .35907 L .71504 .35587 L .414 .228 .517 r
F
.71781 .36096 m .71519 .359 L .71438 .35946 L .644 .736 .916 r
F
.71221 .3597 m .71288 .35881 L .70895 .35897 L F
.71781 .36096 m .71396 .35928 L .71221 .3597 L F
.71396 .35928 m .71288 .35881 L .71221 .3597 L F
.71621 .35552 m .71633 .35871 L .71629 .3555 L .566 .34 .531 r
F
.71367 .36008 m .71368 .36024 L .71381 .35989 L .076 0 .438 r
F
.71368 .36024 m .71381 .36004 L .71381 .35989 L F
.71731 .36122 m .71392 .35987 L .7135 .36053 L .667 .747 .91 r
F
.71782 .36913 m .71232 .37073 L .71098 .37268 L .643 .737 .917 r
F
.71654 .40125 m .71696 .40689 L .71659 .40211 L .947 .644 .431 r
F
.71654 .40125 m .71659 .40211 L .71414 .37035 L F
.71422 .37043 m .71654 .40125 L .71414 .37035 L F
.71402 .37024 m .71696 .40689 L .71629 .40626 L F
.71414 .37035 m .71696 .40689 L .71402 .37024 L F
.71048 .36479 m .70549 .36455 L .69127 .37479 L .644 .736 .916 r
F
.70549 .36455 m .6899 .37348 L .69127 .37479 L F
.70137 .37057 m .70253 .37024 L .70534 .3727 L .874 .581 .489 r
F
.70253 .37024 m .70527 .3718 L .70534 .3727 L F
.70667 .36747 m .70534 .3727 L .70932 .36889 L .667 .747 .91 r
F
.70137 .37057 m .70129 .36954 L .70253 .37024 L .874 .581 .489 r
F
.70667 .36747 m .70137 .37057 L .70534 .3727 L .667 .747 .91 r
F
.71232 .37073 m .6836 .37293 L .68635 .37825 L .643 .737 .917 r
F
.71318 .36159 m .71374 .36965 L .71368 .36951 L .965 .686 .26 r
F
.71782 .36913 m .71304 .36966 L .71232 .37073 L .643 .737 .917 r
F
.71331 .36506 m .70932 .36889 L .7125 .36979 L .667 .747 .91 r
F
.71304 .36966 m .6836 .37293 L .71232 .37073 L .643 .737 .917 r
F
.71368 .36024 m .71409 .36813 L .71381 .36004 L .076 0 .438 r
F
.68368 .36478 m .65541 .37914 L .68642 .37011 L .644 .736 .916 r
F
.69669 .37148 m .68317 .36732 L .6836 .37293 L .643 .737 .917 r
F
.71731 .36122 m .71493 .36351 L .71523 .36364 L .667 .747 .91 r
F
.71548 .36352 m .7155 .36368 L .71522 .36347 L .753 .483 .523 r
F
.7155 .36368 m .71524 .36365 L .71522 .36347 L F
.71731 .36122 m .71523 .36364 L .7159 .36374 L .667 .747 .91 r
F
.71381 .35989 m .71381 .36004 L .71391 .35973 L .076 0 .438 r
F
.71304 .36966 m .71233 .36885 L .71037 .36996 L .643 .737 .917 r
F
.71322 .36109 m .7137 .36894 L .71322 .36101 L 0 0 .132 r
F
.7137 .36894 m .71371 .36887 L .71321 .3608 L F
.71322 .36125 m .71368 .36951 L .7137 .36907 L F
.71322 .36125 m .7137 .36907 L .71322 .36109 L F
.7137 .36907 m .7137 .36894 L .71322 .36109 L F
.71782 .36913 m .71356 .36891 L .71304 .36966 L .643 .737 .917 r
F
.71356 .36891 m .71233 .36885 L .71304 .36966 L F
.71381 .36004 m .7142 .36797 L .71392 .35987 L .076 0 .438 r
F
.71368 .36951 m .71629 .40626 L .71594 .40552 L .965 .686 .26 r
F
.71374 .36965 m .71629 .40626 L .71368 .36951 L F
.71433 .37053 m .71696 .40689 L .71422 .37043 L .947 .644 .431 r
F
.71384 .36985 m .71629 .40626 L .71374 .36965 L .965 .686 .26 r
F
.71384 .36985 m .71402 .37024 L .71629 .40626 L F
.71433 .37053 m .71468 .37087 L .71696 .40689 L .947 .644 .431 r
F
.6977 .36321 m .68325 .35915 L .68368 .36478 L .644 .736 .916 r
F
.69537 .36378 m .68368 .36478 L .69831 .36664 L F
.69685 .36459 m .69732 .3646 L .69847 .36781 L .968 .682 .269 r
F
.69732 .3646 m .69839 .36672 L .69847 .36781 L F
.69847 .36781 m .69839 .36672 L .69936 .36767 L .949 .646 .426 r
F
.69847 .36781 m .69936 .36767 L .70137 .37057 L F
.69936 .36767 m .70129 .36954 L .70137 .37057 L F
.70474 .36562 m .70137 .37057 L .70667 .36747 L .667 .747 .91 r
F
.70474 .36562 m .69847 .36781 L .70137 .37057 L F
.70366 .36347 m .69847 .36781 L .70474 .36562 L F
.69685 .36459 m .69676 .36351 L .69732 .3646 L .968 .682 .269 r
F
.70366 .36347 m .69685 .36459 L .69847 .36781 L .667 .747 .91 r
F
.70848 .36864 m .6851 .36179 L .68317 .36732 L .643 .737 .917 r
F
.71368 .36024 m .71323 .36096 L .71371 .36868 L .076 0 .438 r
F
.71368 .36024 m .71371 .36868 L .71409 .36813 L F
.71321 .3608 m .71371 .36887 L .71321 .36076 L 0 0 .132 r
F
.71371 .36887 m .71371 .36883 L .71321 .36076 L F
.71321 .36076 m .71371 .36883 L .71371 .36868 L F
.71782 .36913 m .71352 .36817 L .71233 .36885 L .643 .737 .917 r
F
.71782 .36913 m .71534 .37131 L .71639 .37151 L F
.715 .37103 m .71801 .40739 L .71487 .37096 L .857 .566 .495 r
F
.71603 .37144 m .71973 .40767 L .71603 .37144 L .753 .483 .523 r
F
.71468 .37087 m .71801 .40739 L .71696 .40689 L .857 .566 .495 r
F
.71487 .37096 m .71801 .40739 L .71468 .37087 L F
.71572 .37139 m .71973 .40767 L .71801 .40739 L .753 .483 .523 r
F
.71603 .37144 m .71973 .40767 L .71572 .37139 L F
.71516 .37111 m .71801 .40739 L .715 .37103 L .857 .566 .495 r
F
.71639 .37151 m .71622 .37181 L .71742 .37171 L .643 .737 .917 r
F
.71625 .37149 m .71973 .40767 L .71603 .37144 L .753 .483 .523 r
F
.71516 .37111 m .71572 .37139 L .71801 .40739 L .857 .566 .495 r
F
.7142 .36797 m .71429 .36784 L .71392 .35987 L .076 0 .438 r
F
.71409 .36813 m .7142 .36797 L .71381 .36004 L F
.71391 .35973 m .71429 .36784 L .71441 .36766 L F
.69779 .35765 m .69739 .35773 L .69661 .36112 L 0 0 .358 r
F
.69739 .35773 m .69653 .36013 L .69661 .36112 L F
.69661 .36112 m .69653 .36013 L .69661 .36121 L 0 0 .062 r
F
.69652 .35985 m .68325 .35915 L .69652 .35987 L .644 .736 .916 r
F
.69661 .36112 m .69661 .36121 L .69685 .36459 L 0 0 .062 r
F
.69661 .36121 m .69676 .36351 L .69685 .36459 L F
.71198 .36435 m .70932 .36889 L .71331 .36506 L .667 .747 .91 r
F
.71198 .36435 m .70667 .36747 L .70932 .36889 L F
.71102 .36342 m .70667 .36747 L .71198 .36435 L F
.71102 .36342 m .70474 .36562 L .70667 .36747 L F
.71048 .36235 m .70474 .36562 L .71102 .36342 L F
.71048 .36235 m .70366 .36347 L .70474 .36562 L F
.70351 .36116 m .69685 .36459 L .70366 .36347 L F
.70351 .36116 m .69661 .36112 L .69685 .36459 L F
.70431 .35885 m .69661 .36112 L .70351 .36116 L F
.70431 .35885 m .69779 .35765 L .69661 .36112 L F
.71194 .36781 m .68929 .35674 L .6851 .36179 L .643 .737 .917 r
F
.71731 .36122 m .71472 .35936 L .71392 .35987 L .667 .747 .91 r
F
.71507 .35907 m .71507 .35913 L .71515 .35902 L .414 .228 .517 r
F
.71507 .35913 m .71515 .35908 L .71515 .35902 L F
.71517 .35899 m .71483 .35873 L .71396 .35928 L .644 .736 .916 r
F
.71507 .35907 m .71515 .35902 L .71504 .35587 L .414 .228 .517 r
F
.71578 .35244 m .71524 .35897 L .71606 .35877 L .566 .34 .531 r
F
.71606 .35877 m .71618 .35874 L .71617 .35553 L F
.71606 .35877 m .71617 .35553 L .71606 .35557 L F
.71451 .35621 m .71433 .35608 L .71373 .35671 L .667 .747 .91 r
F
.71592 .35561 m .71606 .35877 L .71606 .35557 L .566 .34 .531 r
F
.71373 .35671 m .71373 .35671 L .71372 .35671 L .667 .747 .91 r
F
.71613 .35868 m .70323 .34119 L .71483 .35873 L .644 .736 .916 r
F
.71457 .35834 m .71442 .35733 L .71403 .35752 L .667 .747 .91 r
F
.71457 .35834 m .71403 .35752 L .71289 .35804 L F
.71472 .35936 m .71457 .35834 L .71289 .35804 L F
.71606 .35877 m .71524 .35897 L .71524 .35902 L .566 .34 .531 r
F
.71731 .36122 m .7156 .35892 L .71472 .35936 L .667 .747 .91 r
F
.7156 .35892 m .71524 .35902 L .71472 .35936 L F
.71782 .36913 m .71442 .36765 L .71352 .36817 L .643 .737 .917 r
F
.71782 .36913 m .71639 .37151 L .71743 .37171 L F
.71639 .37151 m .71742 .37171 L .71743 .37171 L F
.71743 .37171 m .71716 .37211 L .71735 .3722 L F
.71651 .37154 m .71742 .37171 L .71973 .40767 L .753 .483 .523 r
F
.71651 .37154 m .71973 .40767 L .71625 .37149 L F
.71731 .36122 m .71705 .36024 L .7158 .35886 L .667 .747 .91 r
F
.71731 .36122 m .7158 .35886 L .7156 .35892 L F
.71606 .35877 m .71524 .35902 L .71606 .35878 L .566 .34 .531 r
F
.71517 .35899 m .71613 .35868 L .71483 .35873 L .644 .736 .916 r
F
.71618 .35874 m .71613 .35868 L .71517 .35899 L F
.71606 .35877 m .71606 .35878 L .71618 .35874 L .566 .34 .531 r
F
.71605 .35236 m .71617 .35553 L .71609 .35235 L F
.71617 .35553 m .7163 .35871 L .71619 .35553 L F
.71617 .35553 m .71619 .35553 L .71609 .35235 L F
.7163 .35871 m .71633 .3587 L .71609 .35235 L F
.71726 .35224 m .71752 .35856 L .7173 .35224 L .657 .408 .532 r
F
.71752 .35856 m .71755 .35856 L .7173 .35224 L F
.71609 .35235 m .71621 .35552 L .71629 .3555 L .566 .34 .531 r
F
.717 .35227 m .71729 .35858 L .71722 .35225 L .657 .408 .532 r
F
.71729 .35864 m .71752 .35863 L .7172 .35073 L F
.71578 .35244 m .71592 .35561 L .71605 .35236 L .566 .34 .531 r
F
.71636 .35548 m .7177 .35356 L .71589 .3537 L .667 .747 .91 r
F
.71637 .35549 m .71638 .35547 L .71636 .35548 L F
.71638 .35547 m .7177 .35356 L .71636 .35548 L F
.71537 .35577 m .71589 .3537 L .71416 .35414 L F
.71636 .35548 m .71589 .3537 L .71537 .35577 L F
.71618 .35874 m .71616 .35689 L .71523 .35713 L F
.71504 .35587 m .71416 .35414 L .71433 .35608 L F
.71537 .35577 m .71531 .3557 L .71504 .35587 L F
.71531 .3557 m .71416 .35414 L .71504 .35587 L F
.71451 .35621 m .71504 .35587 L .71433 .35608 L F
.7143 .35307 m .71484 .35272 L .71412 .35294 L .668 .747 .91 r
F
.71412 .35294 m .715 .35245 L .71362 .35257 L F
.71513 .35263 m .715 .35245 L .71412 .35294 L F
.71362 .35257 m .71391 .35098 L .71239 .35168 L F
.715 .35245 m .71391 .35098 L .71362 .35257 L F
.71589 .3537 m .71126 .35023 L .71416 .35414 L .667 .747 .91 r
F
.71589 .3537 m .71473 .34935 L .71126 .35023 L F
.71356 .34498 m .70809 .34312 L .70835 .34631 L .587 .36 .538 r
F
.71383 .34817 m .71356 .34498 L .70835 .34631 L F
.71618 .35874 m .70564 .34071 L .70323 .34119 L .644 .736 .916 r
F
.71523 .35713 m .71152 .35343 L .71442 .35733 L .667 .747 .91 r
F
.71616 .35689 m .71427 .35549 L .71523 .35713 L F
.71427 .35549 m .71152 .35343 L .71523 .35713 L F
.71616 .35689 m .71499 .35254 L .71152 .35343 L F
.71499 .35254 m .70861 .3495 L .71152 .35343 L F
.71356 .34498 m .7133 .34179 L .70809 .34312 L .587 .36 .538 r
F
.71499 .35254 m .71383 .34817 L .70861 .3495 L .667 .747 .91 r
F
.71722 .35225 m .71722 .35225 L .7172 .35073 L .657 .408 .532 r
F
.71693 .35074 m .71599 .35078 L .71609 .35235 L F
.71599 .35078 m .71605 .35236 L .71609 .35235 L .566 .34 .531 r
F
.71611 .35235 m .71743 .3504 L .71563 .35054 L .668 .747 .91 r
F
.71693 .35074 m .717 .35227 L .7172 .35073 L .657 .408 .532 r
F
.717 .35227 m .71722 .35225 L .7172 .35073 L F
.71693 .35074 m .71609 .35235 L .717 .35227 L F
.71716 .35225 m .71743 .3504 L .71611 .35235 L .668 .747 .91 r
F
.71837 .35235 m .71844 .35236 L .71838 .35091 L .735 .468 .525 r
F
.7173 .35224 m .71918 .35056 L .71716 .35223 L .668 .747 .91 r
F
.71819 .35233 m .71829 .35215 L .7173 .35224 L F
.71829 .35215 m .71918 .35056 L .7173 .35224 L F
.71716 .35225 m .7173 .35224 L .71716 .35223 L F
.7172 .35073 m .71726 .35224 L .7173 .35224 L .657 .408 .532 r
F
.71716 .35223 m .71918 .35056 L .71743 .3504 L .668 .747 .91 r
F
.71929 .35244 m .72077 .35101 L .71827 .35229 L F
.71743 .3504 m .71447 .34621 L .71563 .35054 L F
.71848 .35236 m .71827 .35229 L .71819 .35233 L F
.71929 .35244 m .71827 .35229 L .71848 .35236 L F
.71847 .35183 m .72077 .35101 L .71918 .35056 L F
.71819 .35233 m .71875 .35205 L .71847 .35183 L F
.71875 .35205 m .72077 .35101 L .71847 .35183 L F
.71918 .35056 m .71808 .34592 L .71743 .3504 L F
.71947 .35372 m .71836 .34906 L .7177 .35356 L .667 .747 .91 r
F
.7177 .35356 m .71473 .34935 L .71589 .3537 L F
.71743 .3504 m .71808 .34592 L .71447 .34621 L .668 .747 .91 r
F
.7177 .35356 m .71836 .34906 L .71473 .34935 L .667 .747 .91 r
F
.71808 .34592 m .71331 .34185 L .71447 .34621 L .668 .747 .91 r
F
.71836 .34906 m .71356 .34498 L .71473 .34935 L .667 .747 .91 r
F
.71863 .35226 m .71383 .34817 L .71499 .35254 L F
.71918 .35056 m .7216 .34624 L .71808 .34592 L .668 .747 .91 r
F
.72077 .35101 m .7216 .34624 L .71918 .35056 L F
.71947 .35372 m .7219 .34939 L .71836 .34906 L .667 .747 .91 r
F
.7216 .34624 m .71874 .34142 L .71808 .34592 L .668 .747 .91 r
F
.7219 .34939 m .71902 .34454 L .71836 .34906 L .667 .747 .91 r
F
.71808 .34592 m .71874 .34142 L .71331 .34185 L .668 .747 .91 r
F
.71836 .34906 m .71902 .34454 L .71356 .34498 L .667 .747 .91 r
F
.71863 .35226 m .71929 .34774 L .71383 .34817 L F
.71929 .34774 m .71356 .34498 L .71383 .34817 L .662 .415 .536 r
F
.71618 .35874 m .71199 .33943 L .70564 .34071 L .644 .736 .916 r
F
.71618 .35874 m .70564 .34071 L .71618 .35874 L F
.71729 .35858 m .71649 .35867 L .71729 .35864 L .657 .408 .532 r
F
.71752 .35856 m .71752 .35863 L .71755 .35856 L F
.71781 .36096 m .71719 .35864 L .71618 .35874 L .644 .736 .916 r
F
.71781 .36096 m .71752 .36105 L .71755 .3611 L F
.71752 .36374 m .71754 .36382 L .71753 .36382 L .638 .394 .533 r
F
.71731 .36122 m .71692 .3639 L .71799 .36376 L .667 .747 .91 r
F
.71731 .36122 m .71788 .36166 L .71785 .36161 L F
.71731 .36122 m .71878 .3632 L .71788 .36166 L F
.71731 .36122 m .71766 .36129 L .71763 .36123 L F
.71884 .36359 m .71884 .3636 L .71884 .36359 L .519 .305 .529 r
F
.71824 .36228 m .71854 .36366 L .71869 .36364 L .644 .736 .916 r
F
.71877 .36362 m .71877 .36363 L .71869 .36364 L .519 .305 .529 r
F
.71731 .36122 m .71804 .36393 L .71888 .36358 L .667 .747 .91 r
F
.71752 .35863 m .71755 .35863 L .71755 .35856 L .657 .408 .532 r
F
.71743 .35539 m .7177 .35356 L .71637 .35549 L .667 .747 .91 r
F
.71729 .35858 m .71729 .35858 L .71725 .35541 L .657 .408 .532 r
F
.71729 .35858 m .71725 .35541 L .71725 .35541 L F
.71633 .35871 m .71641 .35869 L .71629 .3555 L .566 .34 .531 r
F
.71629 .3555 m .71641 .35868 L .71649 .35865 L F
.71662 .35861 m .71797 .35675 L .71616 .35689 L .667 .747 .91 r
F
.71662 .35864 m .71665 .3586 L .71662 .35861 L F
.71665 .3586 m .71797 .35675 L .71662 .35861 L F
.71649 .35865 m .71641 .35869 L .71649 .35867 L .566 .34 .531 r
F
.71641 .35868 m .71641 .35869 L .71649 .35865 L F
.71749 .35856 m .71797 .35675 L .71662 .35864 L .667 .747 .91 r
F
.71797 .35675 m .71499 .35254 L .71616 .35689 L F
.71797 .35675 m .71863 .35226 L .71499 .35254 L F
.7216 .34624 m .72403 .34191 L .71874 .34142 L .668 .747 .91 r
F
.7219 .34939 m .72434 .34503 L .71902 .34454 L .667 .747 .91 r
F
.72058 .35352 m .72068 .3536 L .72065 .3535 L .668 .747 .91 r
F
.72107 .35418 m .7219 .34939 L .71947 .35372 L .667 .747 .91 r
F
.72217 .35258 m .71929 .34774 L .71863 .35226 L F
.72217 .35258 m .72462 .34823 L .71929 .34774 L F
.72434 .34503 m .72406 .34184 L .71875 .34135 L .731 .467 .528 r
F
.71902 .34454 m .7133 .34179 L .71356 .34498 L .662 .415 .536 r
F
.71902 .34454 m .71875 .34135 L .7133 .34179 L F
.72434 .34503 m .71875 .34135 L .71902 .34454 L .731 .467 .528 r
F
.72462 .34823 m .72434 .34503 L .71902 .34454 L F
.71929 .34774 m .71902 .34454 L .71356 .34498 L .662 .415 .536 r
F
.72462 .34823 m .71902 .34454 L .71929 .34774 L .731 .467 .528 r
F
.71719 .35864 m .72116 .33915 L .71199 .33943 L .644 .736 .916 r
F
.71848 .35862 m .71771 .35854 L .71771 .35862 L .735 .468 .525 r
F
.71781 .36096 m .71816 .35869 L .71719 .35864 L .644 .736 .916 r
F
.71816 .35869 m .71771 .35862 L .71719 .35864 L F
.71781 .36096 m .71774 .36142 L .71811 .36205 L F
.71781 .36096 m .71811 .36205 L .71824 .36228 L F
.71849 .35873 m .71771 .35862 L .71822 .36655 L .735 .468 .525 r
F
.71849 .35873 m .71822 .36655 L .71886 .36664 L F
.71848 .35862 m .71771 .35862 L .71849 .35873 L F
.71816 .35869 m .71818 .3586 L .71771 .35862 L .644 .736 .916 r
F
.71755 .35863 m .71755 .35863 L .71755 .35856 L .657 .408 .532 r
F
.71755 .35856 m .71755 .35863 L .71771 .35854 L F
.71755 .35863 m .71771 .35862 L .71771 .35854 L F
.71771 .35854 m .71771 .35862 L .71771 .35862 L F
.71771 .35854 m .71771 .35862 L .71771 .35862 L F
.71771 .35854 m .71797 .35675 L .71749 .35856 L .667 .747 .91 r
F
.71729 .35858 m .71729 .35864 L .71729 .35858 L .657 .408 .532 r
F
.71874 .35502 m .72107 .35418 L .71947 .35372 L .667 .747 .91 r
F
.71953 .35566 m .72107 .35418 L .71874 .35502 L F
.71974 .35691 m .71863 .35226 L .71797 .35675 L F
.71974 .35691 m .72217 .35258 L .71863 .35226 L F
.71818 .3586 m .72116 .33915 L .71719 .35864 L .644 .736 .916 r
F
.71784 .36656 m .71787 .36656 L .71755 .35863 L .657 .408 .532 r
F
.71784 .36656 m .71755 .35863 L .71755 .35863 L F
.71752 .35863 m .71784 .36656 L .71755 .35863 L F
.71719 .35864 m .71715 .35851 L .71649 .35867 L .644 .736 .916 r
F
.71719 .35864 m .71649 .35867 L .71618 .35874 L F
.7163 .35871 m .7163 .35872 L .71633 .3587 L .566 .34 .531 r
F
.7163 .35872 m .71633 .35871 L .71633 .3587 L F
.71618 .35874 m .7163 .35872 L .7163 .35871 L F
.71618 .35874 m .7163 .35871 L .71617 .35553 L F
.71662 .35861 m .71616 .35689 L .71618 .35874 L .667 .747 .91 r
F
.71715 .35851 m .71199 .33943 L .71618 .35874 L .644 .736 .916 r
F
.71705 .36024 m .71618 .35874 L .7158 .35886 L .667 .747 .91 r
F
.71731 .36122 m .7159 .36374 L .71692 .3639 L F
.7163 .35872 m .71661 .36669 L .71633 .35871 L .566 .34 .531 r
F
.71782 .36913 m .71522 .3672 L .71442 .36765 L .643 .737 .917 r
F
.71478 .35923 m .71391 .35973 L .71441 .36766 L .414 .228 .517 r
F
.71513 .36725 m .71441 .36766 L .71668 .40357 L F
.71478 .35923 m .71441 .36766 L .71513 .36725 L F
.70452 .35103 m .70323 .34119 L .69551 .34431 L .644 .736 .916 r
F
.70861 .3495 m .70844 .34947 L .70399 .35163 L .497 .293 .534 r
F
.70844 .34947 m .70396 .35126 L .70399 .35163 L F
.70399 .35163 m .70396 .35126 L .70349 .35158 L .373 .203 .519 r
F
.70069 .35349 m .69551 .34431 L .68935 .34855 L .644 .736 .916 r
F
.70389 .3513 m .69551 .34431 L .70069 .35349 L F
.70399 .35163 m .70349 .35158 L .7003 .35442 L .373 .203 .519 r
F
.70349 .35158 m .70025 .35379 L .7003 .35442 L F
.7003 .35442 m .70025 .35379 L .69972 .35443 L .176 .064 .477 r
F
.7003 .35442 m .69972 .35443 L .69779 .35765 L F
.69972 .35443 m .69772 .35681 L .69779 .35765 L F
.69887 .35361 m .68935 .34855 L .69785 .35647 L .644 .736 .916 r
F
.71782 .36913 m .7161 .36681 L .71522 .3672 L .643 .737 .917 r
F
.71606 .35878 m .71574 .3669 L .71642 .36674 L .566 .34 .531 r
F
.7161 .36681 m .71604 .36673 L .71574 .3669 L .643 .737 .917 r
F
.7161 .36681 m .71574 .3669 L .71522 .3672 L F
.71606 .35878 m .71524 .35902 L .71574 .3669 L .566 .34 .531 r
F
.71478 .35923 m .71513 .36725 L .71503 .35909 L .414 .228 .517 r
F
.71513 .36725 m .71668 .40357 L .71533 .36713 L F
.71513 .36725 m .71533 .36713 L .71503 .35909 L F
.71515 .35902 m .71543 .36708 L .71524 .35897 L F
.71543 .36708 m .7155 .36704 L .71524 .35897 L F
.71536 .36712 m .71543 .36708 L .71515 .35908 L F
.71536 .36712 m .71515 .35908 L .71515 .35908 L F
.71524 .35902 m .7155 .36704 L .71524 .35902 L F
.7155 .36704 m .7155 .36704 L .71524 .35902 L F
.71524 .35902 m .7155 .36704 L .71574 .3669 L F
.71381 .36004 m .71392 .35987 L .71391 .35973 L .076 0 .438 r
F
.71392 .35987 m .71289 .35804 L .71392 .35987 L .667 .747 .91 r
F
.71438 .35946 m .71517 .35899 L .71396 .35928 L .644 .736 .916 r
F
.71472 .35936 m .7144 .35912 L .71392 .35987 L .667 .747 .91 r
F
.7144 .35912 m .71289 .35804 L .71392 .35987 L F
.71392 .35987 m .71289 .35804 L .71166 .35896 L F
.71507 .35913 m .71536 .36712 L .71515 .35908 L .414 .228 .517 r
F
.7135 .36053 m .71392 .35987 L .71302 .36044 L .667 .747 .91 r
F
.71392 .35987 m .71392 .35987 L .7135 .36053 L F
.71519 .359 m .71517 .35899 L .71438 .35946 L .644 .736 .916 r
F
.7105 .34902 m .7086 .3494 L .70861 .3495 L .587 .36 .538 r
F
.70861 .3495 m .7086 .3494 L .70844 .34947 L .497 .293 .534 r
F
.70865 .34938 m .70323 .34119 L .70452 .35103 L .644 .736 .916 r
F
.71302 .36044 m .71166 .35896 L .71081 .36004 L .667 .747 .91 r
F
.71392 .35987 m .71166 .35896 L .71302 .36044 L F
.7135 .36053 m .71324 .36048 L .71323 .36096 L F
.71321 .36089 m .71322 .36109 L .71321 .3608 L 0 0 .132 r
F
.71322 .36109 m .71322 .36101 L .71321 .3608 L F
.71322 .36125 m .71322 .36109 L .71321 .36089 L F
.71324 .36048 m .71081 .36004 L .71322 .3612 L .667 .747 .91 r
F
.71322 .3612 m .71291 .3612 L .71319 .36182 L F
.71503 .35909 m .71668 .40357 L .71507 .35907 L .414 .228 .517 r
F
.71166 .35896 m .70431 .35885 L .71081 .36004 L .667 .747 .91 r
F
.71166 .35896 m .70599 .35669 L .70431 .35885 L F
.71289 .35804 m .70599 .35669 L .71166 .35896 L F
.71289 .35804 m .70845 .35484 L .70599 .35669 L F
.71442 .35733 m .70845 .35484 L .71289 .35804 L F
.71442 .35733 m .71152 .35343 L .70845 .35484 L F
.70845 .35484 m .7003 .35442 L .70599 .35669 L F
.70845 .35484 m .70399 .35163 L .7003 .35442 L F
.71152 .35343 m .70399 .35163 L .70845 .35484 L F
.71152 .35343 m .70861 .3495 L .70399 .35163 L F
.71604 .36673 m .71198 .34764 L .70321 .3494 L .643 .737 .917 r
F
.71661 .36669 m .71664 .36668 L .71633 .35871 L .566 .34 .531 r
F
.71641 .35869 m .7167 .36667 L .71649 .35867 L F
.7167 .36667 m .71677 .36665 L .71649 .35867 L F
.71649 .35867 m .71677 .36665 L .717 .3666 L F
.71633 .35871 m .71664 .36668 L .71641 .35869 L F
.71664 .36668 m .7167 .36667 L .71641 .35869 L F
.71729 .35864 m .71649 .35867 L .717 .3666 L .657 .408 .532 r
F
.71782 .36913 m .71713 .36659 L .7169 .36662 L .643 .737 .917 r
F
.71782 .36913 m .7169 .36662 L .7161 .36681 L F
.71606 .35878 m .71642 .36674 L .71618 .35874 L .566 .34 .531 r
F
.71642 .36674 m .71802 .40273 L .71651 .36671 L F
.71642 .36674 m .71651 .36671 L .71618 .35874 L F
.71651 .36671 m .71661 .36669 L .7163 .35872 L F
.717 .3666 m .71702 .36617 L .71622 .36663 L .643 .737 .917 r
F
.71731 .36122 m .71738 .3608 L .71705 .36024 L .667 .747 .91 r
F
.71729 .35864 m .717 .3666 L .71765 .36657 L .657 .408 .532 r
F
.71713 .36659 m .71712 .36657 L .717 .3666 L .643 .737 .917 r
F
.71712 .36657 m .71702 .36617 L .717 .3666 L F
.7161 .36681 m .7169 .36662 L .71604 .36673 L F
.71618 .35874 m .71651 .36671 L .7163 .35872 L .566 .34 .531 r
F
.71651 .36671 m .71802 .40273 L .71661 .36669 L F
.71782 .36913 m .71822 .36655 L .71713 .36659 L .643 .737 .917 r
F
.71781 .36096 m .71755 .3611 L .71759 .36116 L .644 .736 .916 r
F
.71782 .36913 m .71743 .37171 L .7185 .37162 L .643 .737 .917 r
F
.71781 .36096 m .71759 .36116 L .7176 .36117 L .644 .736 .916 r
F
.71781 .36096 m .71769 .36134 L .71774 .36142 L F
.71781 .36096 m .71764 .36125 L .71769 .36134 L F
.71771 .35862 m .7193 .40237 L .71939 .40237 L .657 .408 .532 r
F
.71771 .35862 m .7193 .40237 L .71771 .35862 L F
.71822 .36655 m .71939 .40237 L .71982 .39134 L F
.71771 .35862 m .71802 .36656 L .71822 .36655 L F
.71802 .36656 m .71939 .40237 L .71822 .36655 L F
.71848 .35862 m .72053 .40228 L .71871 .35864 L .735 .468 .525 r
F
.71822 .36655 m .71952 .3663 L .71822 .36655 L .643 .737 .917 r
F
.71928 .3667 m .7194 .3665 L .71822 .36655 L F
.7194 .3665 m .71952 .3663 L .71822 .36655 L F
.71771 .35862 m .71939 .40237 L .71771 .35862 L .657 .408 .532 r
F
.71731 .36122 m .71751 .36103 L .71747 .36095 L .667 .747 .91 r
F
.71731 .36122 m .71755 .36109 L .71751 .36103 L F
.71731 .36122 m .71757 .36113 L .71755 .36109 L F
.71731 .36122 m .71759 .36117 L .71757 .36113 L F
.71731 .36122 m .7176 .36118 L .71759 .36117 L F
.71729 .35864 m .7193 .40237 L .71752 .35863 L .657 .408 .532 r
F
.71713 .36659 m .71822 .36655 L .71707 .36638 L .643 .737 .917 r
F
.71822 .36655 m .71822 .36655 L .71713 .36659 L F
.71755 .35863 m .71787 .36656 L .71771 .35862 L .657 .408 .532 r
F
.71787 .36656 m .7193 .40237 L .718 .36656 L F
.71787 .36656 m .718 .36656 L .71771 .35862 L F
.71765 .36657 m .717 .3666 L .7193 .40237 L F
.71713 .36659 m .71622 .36663 L .71604 .36673 L .643 .737 .917 r
F
.7158 .35886 m .71523 .35713 L .71442 .35733 L .667 .747 .91 r
F
.71515 .35908 m .71515 .35908 L .71515 .35902 L .414 .228 .517 r
F
.71524 .35897 m .71524 .35902 L .71524 .35902 L F
.71554 .35883 m .71442 .35733 L .71472 .35936 L .667 .747 .91 r
F
.7156 .35892 m .7158 .35886 L .71442 .35733 L F
.71702 .36617 m .71198 .34764 L .71604 .36673 L .643 .737 .917 r
F
.71642 .36674 m .71574 .3669 L .71802 .40273 L .566 .34 .531 r
F
.71041 .36119 m .70366 .36347 L .71048 .36235 L .667 .747 .91 r
F
.71041 .36119 m .70351 .36116 L .70366 .36347 L F
.71081 .36004 m .70351 .36116 L .71041 .36119 L F
.71081 .36004 m .70431 .35885 L .70351 .36116 L F
.70599 .35669 m .69779 .35765 L .70431 .35885 L F
.70599 .35669 m .7003 .35442 L .69779 .35765 L F
.71522 .3672 m .70321 .3494 L .69546 .35251 L .643 .737 .917 r
F
.71604 .36673 m .70321 .3494 L .71522 .3672 L F
.71442 .36765 m .71504 .36707 L .71377 .36737 L F
.71522 .3672 m .71504 .36707 L .71442 .36765 L F
.71543 .36708 m .71668 .40357 L .7155 .36704 L .414 .228 .517 r
F
.71661 .36669 m .71802 .40273 L .71664 .36668 L .566 .34 .531 r
F
.69779 .35765 m .69772 .35681 L .69739 .35773 L 0 0 .358 r
F
.69785 .35647 m .68935 .34855 L .68517 .35362 L .644 .736 .916 r
F
.71377 .36737 m .69546 .35251 L .68929 .35674 L .643 .737 .917 r
F
.71504 .36707 m .69546 .35251 L .71377 .36737 L F
.71618 .35874 m .71523 .35713 L .7158 .35886 L .667 .747 .91 r
F
.7156 .35892 m .71554 .35883 L .71524 .35902 L F
.71889 .35866 m .71889 .35879 L .71889 .35879 L .735 .468 .525 r
F
.71909 .35882 m .7301 .34038 L .71825 .35855 L .644 .736 .916 r
F
.71889 .35879 m .71825 .35855 L .71816 .35869 L F
.71909 .35882 m .71825 .35855 L .71889 .35879 L F
.71819 .35853 m .71905 .35721 L .71989 .34741 L F
.71905 .35721 m .7301 .34038 L .71989 .34741 L F
.71989 .34741 m .7301 .34038 L .72116 .33915 L F
.71816 .35869 m .71825 .35855 L .71819 .35853 L F
.71825 .35855 m .7301 .34038 L .71819 .35853 L F
.71707 .36638 m .72118 .34737 L .71198 .34764 L .643 .737 .917 r
F
.71822 .36655 m .72118 .34737 L .71707 .36638 L F
.71886 .36664 m .71822 .36655 L .72053 .40228 L .735 .468 .525 r
F
.7155 .36704 m .71668 .40357 L .7155 .36704 L .414 .228 .517 r
F
.71352 .36817 m .71377 .36737 L .71194 .36781 L .643 .737 .917 r
F
.71442 .36765 m .71377 .36737 L .71352 .36817 L F
.71377 .36737 m .68929 .35674 L .71194 .36781 L F
.7167 .36667 m .71802 .40273 L .71677 .36665 L .566 .34 .531 r
F
.71574 .3669 m .71668 .40357 L .71802 .40273 L .414 .228 .517 r
F
.7155 .36704 m .71668 .40357 L .71574 .3669 L F
.71233 .36885 m .71194 .36781 L .70848 .36864 L .643 .737 .917 r
F
.71352 .36817 m .71194 .36781 L .71233 .36885 L F
.71194 .36781 m .6851 .36179 L .70848 .36864 L F
.717 .3666 m .71802 .40273 L .7193 .40237 L .566 .34 .531 r
F
.71677 .36665 m .71802 .40273 L .717 .3666 L F
.7142 .36797 m .71598 .40466 L .71429 .36784 L .076 0 .438 r
F
.71536 .36712 m .71668 .40357 L .71543 .36708 L .414 .228 .517 r
F
.71037 .36996 m .70848 .36864 L .69669 .37148 L .643 .737 .917 r
F
.71233 .36885 m .70848 .36864 L .71037 .36996 L F
.70848 .36864 m .68317 .36732 L .69669 .37148 L F
.71664 .36668 m .71802 .40273 L .7167 .36667 L .566 .34 .531 r
F
.71545 .3944 m .71598 .40466 L .71555 .39584 L .076 0 .438 r
F
.71545 .3944 m .71555 .39584 L .7142 .36797 L F
.71409 .36813 m .71545 .3944 L .7142 .36797 L F
.71441 .36766 m .71598 .40466 L .71668 .40357 L F
.71429 .36784 m .71598 .40466 L .71441 .36766 L F
.71098 .37268 m .68635 .37825 L .69121 .38293 L .643 .737 .917 r
F
.71232 .37073 m .68635 .37825 L .71098 .37268 L F
.71784 .36656 m .7193 .40237 L .71787 .36656 L .657 .408 .532 r
F
.71822 .36655 m .71952 .3663 L .7184 .36538 L .643 .737 .917 r
F
.71912 .36668 m .72053 .40228 L .71919 .36669 L .735 .468 .525 r
F
.71919 .36669 m .72053 .40228 L .71919 .36669 L F
.71941 .36672 m .72053 .40228 L .72173 .40242 L F
.71919 .36669 m .72053 .40228 L .71941 .36672 L F
.71928 .3667 m .71941 .36672 L .71929 .36668 L .643 .737 .917 r
F
.71986 .35915 m .7202 .36701 L .71989 .35916 L .818 .533 .507 r
F
.72214 .35839 m .72266 .35809 L .72227 .35788 L .667 .747 .91 r
F
.71991 .35912 m .74483 .34689 L .73818 .34302 L .644 .736 .916 r
F
.72043 .35937 m .72064 .35925 L .72003 .35905 L .667 .747 .91 r
F
.72064 .35925 m .72214 .35839 L .72003 .35905 L F
.72045 .35939 m .72214 .35839 L .72043 .35937 L F
.72047 .35958 m .74483 .34689 L .71991 .35912 L .644 .736 .916 r
F
.72293 .36123 m .72304 .36214 L .72532 .36136 L F
.72193 .36189 m .72304 .36214 L .72293 .36123 L F
.71929 .36668 m .73824 .35123 L .73014 .3486 L .643 .737 .917 r
F
.72023 .36702 m .73824 .35123 L .71929 .36668 L F
.72022 .36702 m .72173 .40242 L .72028 .36704 L .818 .533 .507 r
F
.71987 .35916 m .72004 .35922 L .71991 .35912 L .644 .736 .916 r
F
.7184 .36538 m .73014 .3486 L .72118 .34737 L .643 .737 .917 r
F
.71952 .3663 m .73014 .3486 L .7184 .36538 L F
.72098 .3675 m .72236 .36782 L .7212 .36739 L F
.72163 .36803 m .72236 .36782 L .72098 .3675 L F
.7212 .36739 m .72389 .36738 L .72588 .36496 L F
.72236 .36782 m .72389 .36738 L .7212 .36739 L F
.72028 .36704 m .72173 .40242 L .72035 .36707 L .818 .533 .507 r
F
.72056 .36715 m .72173 .40242 L .72288 .40282 L F
.72035 .36707 m .72173 .40242 L .72056 .36715 L F
.71904 .36667 m .72053 .40228 L .71912 .36668 L .735 .468 .525 r
F
.71409 .36813 m .71371 .36868 L .71598 .40466 L .076 0 .438 r
F
.7137 .36894 m .71594 .40552 L .71371 .36887 L 0 0 .132 r
F
.7137 .36907 m .71368 .36951 L .71594 .40552 L F
.71354 .37288 m .69121 .38293 L .69784 .38665 L .643 .737 .917 r
F
.71356 .37244 m .69121 .38293 L .71354 .37288 L F
.71354 .37288 m .69784 .38665 L .7134 .37651 L F
.7137 .36907 m .71594 .40552 L .7137 .36894 L 0 0 .132 r
F
.71371 .36887 m .71594 .40552 L .71371 .36883 L F
.7134 .37651 m .7058 .38918 L .71334 .37784 L .643 .737 .917 r
F
.71334 .37784 m .7058 .38918 L .71285 .39013 L F
.71334 .37784 m .71285 .39013 L .71455 .39036 L F
.71371 .36868 m .71594 .40552 L .71598 .40466 L 0 0 .132 r
F
.71371 .36883 m .71594 .40552 L .71371 .36868 L F
.71982 .39134 m .71939 .40237 L .72053 .40228 L .657 .408 .532 r
F
.72333 .36942 m .72516 .36952 L .72303 .36918 L .643 .737 .917 r
F
.7213 .36775 m .72288 .40282 L .72132 .36777 L .928 .626 .449 r
F
.7202 .36701 m .72124 .39113 L .72022 .36702 L .818 .533 .507 r
F
.72404 .36844 m .72608 .3692 L .73032 .36775 L .643 .737 .917 r
F
.72516 .36952 m .75248 .37095 L .73032 .36775 L F
.72588 .36496 m .72805 .36617 L .74491 .3551 L F
.72389 .36738 m .72805 .36617 L .72588 .36496 L F
.72805 .36617 m .74969 .3599 L .74497 .35516 L F
.72805 .36617 m .74497 .35516 L .74491 .3551 L F
.72113 .36762 m .72056 .36715 L .72288 .40282 L .928 .626 .449 r
F
.72163 .36803 m .72404 .36844 L .72236 .36782 L .643 .737 .917 r
F
.72237 .36863 m .72404 .36844 L .72163 .36803 L F
.72124 .39113 m .72125 .39127 L .72022 .36702 L .818 .533 .507 r
F
.72124 .39113 m .72022 .36702 L .72022 .36702 L F
.72236 .36782 m .73032 .36775 L .74969 .3599 L .643 .737 .917 r
F
.72404 .36844 m .73032 .36775 L .72236 .36782 L F
.73032 .36775 m .75227 .36531 L .75018 .36093 L F
.73032 .36775 m .75018 .36093 L .74969 .3599 L F
.72124 .39113 m .72173 .40242 L .72125 .39127 L .818 .533 .507 r
F
.72307 .36941 m .72492 .37073 L .72333 .36942 L .643 .737 .917 r
F
.72204 .37008 m .72492 .37073 L .72307 .36941 L F
.72492 .37073 m .75034 .37643 L .72333 .36942 L F
.72113 .36762 m .72288 .40282 L .7213 .36775 L .928 .626 .449 r
F
.72182 .36978 m .72435 .4048 L .72182 .36978 L 0 0 .297 r
F
.72216 .37404 m .72435 .4048 L .72233 .37678 L F
.72216 .37404 m .72233 .37678 L .72182 .36978 L F
.72185 .36968 m .72216 .37404 L .72182 .36978 L F
.72178 .36993 m .72435 .4048 L .72413 .40567 L F
.72182 .36978 m .72435 .4048 L .72178 .36993 L F
.72189 .36955 m .72435 .4048 L .72185 .36968 L F
.72183 .36861 m .72163 .36803 L .72397 .40369 L .925 .667 .181 r
F
.72289 .37166 m .73979 .38547 L .74153 .38433 L .643 .737 .917 r
F
.72297 .37189 m .73979 .38547 L .72289 .37166 L F
.7288 .3739 m .74153 .38433 L .74601 .38138 L F
.72163 .36803 m .72288 .40282 L .72397 .40369 L .928 .626 .449 r
F
.72143 .36786 m .72288 .40282 L .72163 .36803 L F
.72189 .36955 m .72201 .36911 L .72435 .4048 L 0 0 .297 r
F
.72189 .36877 m .72397 .40369 L .72194 .36891 L .925 .667 .181 r
F
.72201 .36911 m .72397 .40369 L .72435 .4048 L F
.72194 .36891 m .72397 .40369 L .72201 .36911 L F
.72183 .36861 m .72397 .40369 L .72189 .36877 L F
.72569 .37976 m .72891 .38907 L .73213 .38845 L .643 .737 .917 r
F
.59886 .7689 m .58746 .76517 L .58443 .76793 L .597 .767 .961 r
F
.60117 .76778 m .58746 .76517 L .59886 .7689 L F
.78981 .64959 m .79243 .63982 L .78171 .64116 L .655 .81 .958 r
F
.35765 .40217 m .35853 .39404 L .35413 .37753 L .975 .786 .363 r
F
0 g
.35721 .40215 m
.35744 .40072 L
s
.62339 .77643 m .6345 .77258 L .62224 .77489 L .596 .768 .961 r
F
.62339 .77643 m .63679 .77565 L .6345 .77258 L F
.80046 .65565 m .8037 .64526 L .79585 .65499 L .654 .811 .959 r
F
.80046 .65565 m .81297 .64659 L .8037 .64526 L F
.44935 .5161 m .4519 .52077 L .45212 .52729 L .888 .675 .157 r
F
.44935 .5161 m .44913 .50954 L .4519 .52077 L F
.47662 .50893 m .4519 .52077 L .47833 .51643 L .655 .781 .941 r
F
.47662 .50893 m .44913 .50954 L .4519 .52077 L F
0 g
.4519 .52077 m
.45651 .52657 L
s
.30533 .64903 m .28085 .64972 L .29926 .65345 L .659 .806 .954 r
F
.62233 .7703 m .63057 .76521 L .62035 .76892 L .597 .767 .961 r
F
.62233 .7703 m .63452 .76798 L .63057 .76521 L F
.58746 .76517 m .57149 .76558 L .58443 .76793 L F
.75477 .65182 m .73832 .64808 L .73065 .65548 L .655 .81 .958 r
F
.73915 .65351 m .73065 .65548 L .73146 .6609 L .276 .182 .564 r
F
.73915 .65351 m .73832 .64808 L .73065 .65548 L F
0 g
.72693 .66306 m
.73065 .65548 L
s
.63679 .77105 m .64678 .76566 L .63452 .76798 L .597 .767 .961 r
F
.63679 .77105 m .65014 .77028 L .64678 .76566 L F
.32975 .65729 m .32355 .64825 L .31378 .65082 L .658 .806 .954 r
F
.33503 .65663 m .32355 .64825 L .32975 .65729 L F
.62168 .4081 m .60688 .38615 L .60662 .39431 L .939 .671 .502 r
F
0 g
.62168 .4081 m
.63031 .42345 L
s
.82572 .65276 m .8369 .64132 L .82048 .64916 L .654 .811 .959 r
F
.82572 .65276 m .84471 .64679 L .8369 .64132 L F
.33503 .65663 m .33418 .64691 L .32355 .64825 L .658 .806 .954 r
F
.51694 .37752 m .50885 .3566 L .48391 .3617 L .644 .737 .916 r
F
.53456 .37701 m .50885 .3566 L .51694 .37752 L F
.50391 .50179 m .47833 .50988 L .50469 .50554 L .656 .78 .94 r
F
.50391 .50179 m .47664 .50239 L .47833 .50988 L F
.29949 .65887 m .28106 .65515 L .27581 .66252 L .658 .806 .954 r
F
0 g
.27472 .67006 m
.27581 .66252 L
s
.55204 .37936 m .53559 .3558 L .53456 .37701 L .644 .737 .916 r
F
.55204 .37936 m .56212 .35939 L .53559 .3558 L F
.49978 .38873 m .48308 .36953 L .46163 .37854 L .643 .737 .917 r
F
.51638 .3854 m .48308 .36953 L .49978 .38873 L F
.22691 .36858 m .19063 .36631 L .22418 .37348 L F
.56793 .3923 m .56189 .36723 L .55174 .38726 L F
.56793 .3923 m .5864 .37495 L .56189 .36723 L F
.28965 .37691 m .31439 .36263 L .28578 .37167 L F
.28965 .37691 m .32199 .3732 L .31439 .36263 L F
.78024 .65694 m .77226 .64918 L .76305 .65281 L .654 .811 .959 r
F
.78538 .65566 m .77226 .64918 L .78024 .65694 L F
.40258 .37702 m .40335 .36894 L .42978 .36816 L .664 .424 .546 r
F
.37596 .37346 m .40335 .36894 L .40258 .37702 L .732 .484 .553 r
F
.37596 .37346 m .3768 .36539 L .40335 .36894 L F
.84375 .64139 m .84278 .63599 L .83498 .63048 L .949 .641 .416 r
F
0 g
.84278 .63599 m
.84664 .64267 L
s
.81845 .63843 m .82354 .62669 L .81099 .63585 L .655 .809 .957 r
F
.81845 .63843 m .83474 .6306 L .82354 .62669 L F
.79585 .65499 m .79334 .64526 L .7907 .655 L .654 .811 .959 r
F
.79585 .65499 m .8037 .64526 L .79334 .64526 L F
.40275 .34731 m .40334 .36862 L .42965 .36785 L .644 .737 .916 r
F
.38492 .34491 m .40334 .36862 L .40275 .34731 L F
.38492 .34491 m .37692 .36509 L .40334 .36862 L F
0 g
.3768 .36539 m
.40335 .36894 L
s
.60117 .76778 m .59207 .76292 L .58746 .76517 L .597 .767 .961 r
F
.6041 .76698 m .59207 .76292 L .60117 .76778 L F
.76219 .64738 m .73832 .64808 L .75477 .65182 L .655 .81 .958 r
F
.62035 .76892 m .62521 .76294 L .61767 .76779 L .597 .767 .961 r
F
.62035 .76892 m .63057 .76521 L .62521 .76294 L F
.59843 .7781 m .58389 .77712 L .59689 .77947 L .595 .768 .962 r
F
.38763 .64303 m .3772 .63215 L .37754 .63756 L .919 .647 .51 r
F
.38798 .64844 m .38763 .64303 L .37754 .63756 L F
0 g
.38763 .64303 m
.39406 .64967 L
s
.59862 .77348 m .58715 .76975 L .5841 .77251 L .596 .768 .961 r
F
.60094 .77236 m .58715 .76975 L .59862 .77348 L F
.62324 .78104 m .63436 .7772 L .62208 .77951 L .595 .768 .962 r
F
.62324 .78104 m .63665 .78027 L .63436 .7772 L F
.53456 .37701 m .53559 .3558 L .50885 .3566 L .644 .737 .916 r
F
.62224 .77489 m .63053 .7698 L .62024 .77351 L .596 .768 .961 r
F
.62224 .77489 m .6345 .77258 L .63053 .7698 L F
.58715 .76975 m .57108 .77016 L .5841 .77251 L F
.36342 .64539 m .36444 .63365 L .3547 .64282 L .659 .806 .954 r
F
.36342 .64539 m .37754 .63756 L .36444 .63365 L F
.78538 .65566 m .7826 .6466 L .77226 .64918 L .654 .811 .959 r
F
.7907 .655 m .7826 .6466 L .78538 .65566 L F
.58746 .76517 m .57601 .76143 L .57149 .76558 L .597 .767 .961 r
F
.57562 .766 m .5713 .76555 L .57108 .77016 L .149 .027 .446 r
F
.57562 .766 m .57583 .76138 L .5713 .76555 L F
0 g
.56945 .77017 m
.5713 .76555 L
s
.63679 .77565 m .64683 .77025 L .6345 .77258 L .596 .768 .961 r
F
.63679 .77565 m .65022 .77488 L .64683 .77025 L F
.7907 .655 m .79334 .64526 L .7826 .6466 L .654 .811 .959 r
F
.30557 .65445 m .28106 .65515 L .29949 .65887 L .658 .806 .954 r
F
.75561 .65724 m .73915 .65351 L .73146 .6609 L .654 .811 .959 r
F
0 g
.72773 .66846 m
.73146 .6609 L
s
.19366 .51082 m .21217 .51087 L .21197 .51738 L .848 .597 .56 r
F
.19366 .51082 m .19389 .50428 L .21217 .51087 L F
.21173 .49339 m .21217 .51087 L .22396 .49786 L .657 .779 .939 r
F
.21173 .49339 m .19389 .50428 L .21217 .51087 L F
0 g
.21217 .51087 m
.21705 .5118 L
s
.2662 .50642 m .29436 .51554 L .27919 .50318 L .656 .78 .94 r
F
.29436 .51554 m .31076 .5017 L .31073 .50821 L .494 .304 .551 r
F
.27919 .50318 m .29436 .51554 L .31073 .50821 L .656 .78 .94 r
F
0 g
.27503 .52032 m
.29436 .51554 L
s
.65022 .77488 m .65034 .77026 L .64696 .76562 L .994 .75 .44 r
F
0 g
.65034 .77026 m
.65097 .77503 L
s
.30525 .64368 m .28995 .63769 L .28093 .64436 L .659 .805 .953 r
F
.31339 .64006 m .28995 .63769 L .30525 .64368 L F
.58413 .52057 m .61409 .51239 L .58671 .51301 L .655 .782 .942 r
F
.55808 .51742 m .58413 .52057 L .58671 .51301 L F
.55508 .52097 m .58413 .52057 L .55808 .51742 L F
.47688 .51548 m .45212 .52729 L .47859 .52296 L F
.47688 .51548 m .44935 .5161 L .45212 .52729 L F
0 g
.45212 .52729 m
.46021 .53744 L
s
.6041 .76698 m .59794 .76132 L .59207 .76292 L .597 .767 .961 r
F
.60745 .76657 m .59794 .76132 L .6041 .76698 L F
.61767 .76779 m .6188 .76133 L .61448 .76699 L F
.61767 .76779 m .62521 .76294 L .6188 .76133 L F
.34369 .76741 m .34417 .7628 L .35389 .76156 L .6 .386 .562 r
F
0 g
.34061 .7628 m
.34417 .7628 L
s
.50408 .50831 m .47833 .51643 L .50486 .51207 L .655 .781 .941 r
F
.50408 .50831 m .47662 .50893 L .47833 .51643 L F
.42908 .37625 m .42978 .36816 L .45449 .36309 L .583 .353 .533 r
F
.40258 .37702 m .42978 .36816 L .42908 .37625 L .664 .424 .546 r
F
0 g
.40335 .36894 m
.42978 .36816 L
s
.18769 .38247 m .15292 .39143 L .18703 .39322 L .642 .739 .919 r
F
.18769 .38247 m .15357 .37523 L .15292 .39143 L F
0 g
.15292 .39143 m
.15918 .40769 L
s
.84375 .64139 m .83498 .63048 L .83594 .6359 L .949 .641 .416 r
F
.84471 .64679 m .84375 .64139 L .83594 .6359 L F
0 g
.84375 .64139 m
.8476 .64804 L
s
.36815 .33971 m .37692 .36509 L .38492 .34491 L .644 .737 .916 r
F
0 g
.37272 .36413 m
.3768 .36539 L
s
.60094 .77236 m .59178 .76749 L .58715 .76975 L .596 .768 .961 r
F
.60389 .77157 m .59178 .76749 L .60094 .77236 L F
.22158 .38966 m .18703 .39322 L .22115 .39501 L .642 .739 .919 r
F
.22158 .38966 m .18769 .38247 L .18703 .39322 L F
.62024 .77351 m .62513 .76752 L .61755 .77238 L .596 .768 .961 r
F
.62024 .77351 m .63053 .7698 L .62513 .76752 L F
.81954 .64374 m .82468 .63198 L .81204 .64117 L .655 .81 .958 r
F
.81954 .64374 m .83594 .6359 L .82468 .63198 L F
.4205 .34677 m .42965 .36785 L .45423 .3628 L .644 .737 .916 r
F
.40275 .34731 m .42965 .36785 L .4205 .34677 L F
.68368 .36478 m .64976 .36857 L .65541 .37914 L .644 .736 .916 r
F
.60745 .76657 m .60467 .76049 L .59794 .76132 L .597 .767 .961 r
F
.61099 .76658 m .60467 .76049 L .60745 .76657 L F
.59843 .7781 m .58695 .77437 L .58389 .77712 L .595 .768 .962 r
F
.60076 .77698 m .58695 .77437 L .59843 .7781 L F
.61448 .76699 m .61179 .76049 L .61099 .76658 L .597 .767 .961 r
F
.61448 .76699 m .6188 .76133 L .61179 .76049 L F
.28939 .39859 m .32036 .38943 L .28771 .39313 L .642 .739 .919 r
F
.28939 .39859 m .32352 .40038 L .32036 .38943 L F
.62208 .77951 m .63038 .77443 L .62008 .77813 L .595 .768 .962 r
F
.62208 .77951 m .63436 .7772 L .63038 .77443 L F
.58695 .77437 m .57086 .77477 L .58389 .77712 L F
.76305 .65281 m .73915 .65351 L .75561 .65724 L .654 .811 .959 r
F
.32352 .40038 m .35323 .3857 L .32036 .38943 L .642 .739 .919 r
F
.32352 .40038 m .35765 .40217 L .35323 .3857 L F
.59207 .76292 m .57601 .76143 L .58746 .76517 L .597 .767 .961 r
F
.7737 .38534 m .81451 .38273 L .78248 .37552 L .644 .736 .916 r
F
.31076 .5017 m .31079 .4952 L .32309 .48571 L .333 .178 .516 r
F
0 g
.30016 .49999 m
.31079 .4952 L
s
.35765 .40217 m .35413 .37753 L .35323 .3857 L .975 .786 .363 r
F
0 g
.35677 .376 m
.3594 .38595 L
s
.35508 .41797 m
.35765 .40217 L
s
.35413 .37753 m
.35853 .39404 L
s
.57541 .77063 m .57108 .77016 L .57086 .77477 L .149 .027 .446 r
F
.58715 .76975 m .57562 .766 L .57108 .77016 L .596 .768 .961 r
F
.57541 .77063 m .57562 .766 L .57108 .77016 L .149 .027 .446 r
F
0 g
.56923 .77476 m
.57108 .77016 L
s
.3543 .63751 m .34888 .62632 L .34429 .63617 L .659 .805 .953 r
F
.3543 .63751 m .36398 .62836 L .34888 .62632 L F
.63665 .78027 m .6467 .77488 L .63436 .7772 L .595 .768 .962 r
F
.63665 .78027 m .65009 .7795 L .6467 .77488 L F
.61099 .76658 m .61179 .76049 L .60467 .76049 L .597 .767 .961 r
F
.61412 .35553 m .61631 .36425 L .61607 .37233 L .855 .686 .154 r
F
.61412 .35553 m .61437 .34742 L .61631 .36425 L F
0 g
.61631 .36425 m
.62049 .37184 L
s
.38798 .64844 m .37754 .63756 L .37788 .64298 L .919 .647 .51 r
F
0 g
.38798 .64844 m
.39441 .65505 L
s
.63452 .76798 m .64087 .76148 L .63057 .76521 L .597 .767 .961 r
F
.63452 .76798 m .64678 .76566 L .64087 .76148 L F
.64919 .34924 m .61681 .3642 L .65026 .36043 L .645 .736 .915 r
F
.64919 .34924 m .61489 .34744 L .61681 .3642 L F
.29006 .48504 m .31048 .49505 L .32272 .48561 L .657 .779 .938 r
F
.2792 .49 m .31048 .49505 L .29006 .48504 L F
.36374 .6508 m .36476 .63909 L .35501 .64824 L .658 .806 .954 r
F
.36374 .6508 m .37788 .64298 L .36476 .63909 L F
.76147 .64203 m .74881 .63603 L .73775 .64271 L .655 .809 .957 r
F
.7706 .63841 m .74881 .63603 L .76147 .64203 L F
.65022 .77488 m .64696 .76562 L .64683 .77025 L .994 .75 .44 r
F
.65009 .7795 m .65022 .77488 L .64683 .77025 L F
0 g
.65022 .77488 m
.65084 .77964 L
s
.48308 .36953 m .46225 .37044 L .46163 .37854 L .476 .264 .512 r
F
.48308 .36953 m .48366 .36141 L .46225 .37044 L F
0 g
.44601 .38265 m
.46225 .37044 L
s
.6136 .50587 m .6131 .49936 L .6116 .48794 L .761 .569 0 r
F
0 g
.61076 .50593 m
.61293 .49985 L
s
.81451 .38273 m .81426 .37462 L .82127 .35825 L 0 0 .354 r
F
0 g
.80816 .3813 m
.81426 .37462 L
s
.58554 .49998 m .61269 .49937 L .6112 .488 L .656 .78 .94 r
F
.60688 .38615 m .60715 .37804 L .58672 .36681 L .866 .6 .534 r
F
0 g
.60715 .37804 m
.62214 .39188 L
s
.49925 .39685 m .48251 .37769 L .461 .38668 L .642 .738 .918 r
F
.51589 .39354 m .48251 .37769 L .49925 .39685 L F
.51638 .3854 m .50821 .36442 L .48308 .36953 L .643 .737 .917 r
F
.53413 .3849 m .50821 .36442 L .51638 .3854 L F
.22554 .37662 m .18899 .37433 L .2228 .38153 L .642 .738 .918 r
F
.30533 .64903 m .28994 .64303 L .28085 .64972 L .659 .806 .954 r
F
.31353 .6454 m .28994 .64303 L .30533 .64903 L F
.55174 .38726 m .53515 .36362 L .53413 .3849 L .643 .737 .917 r
F
.55174 .38726 m .56189 .36723 L .53515 .36362 L F
.60389 .77157 m .59769 .76588 L .59178 .76749 L .596 .768 .961 r
F
.60726 .77116 m .59769 .76588 L .60389 .77157 L F
.28994 .64303 m .28065 .64431 L .28085 .64972 L .355 .21 .542 r
F
.28994 .64303 m .28972 .6376 L .28065 .64431 L F
0 g
.27542 .65171 m
.28065 .64431 L
s
.77002 .76219 m .77942 .76001 L .77944 .76462 L .794 .551 .57 r
F
.77002 .76219 m .77001 .75758 L .77942 .76001 L F
0 g
.77942 .76001 m
.78604 .76081 L
s
.56757 .40043 m .56151 .37542 L .55134 .3954 L .642 .738 .918 r
F
.56757 .40043 m .58608 .38312 L .56151 .37542 L F
.61755 .77238 m .61868 .76591 L .61433 .77158 L .596 .768 .961 r
F
.61755 .77238 m .62513 .76752 L .61868 .76591 L F
.28877 .38499 m .31368 .37067 L .28486 .37973 L .642 .738 .918 r
F
.28877 .38499 m .32134 .38127 L .31368 .37067 L F
.31187 .76834 m .32249 .76614 L .32198 .77076 L .787 .554 .584 r
F
.31187 .76834 m .3124 .76372 L .32249 .76614 L F
.31865 .75882 m .3124 .76372 L .32249 .76614 L .594 .768 .963 r
F
0 g
.32249 .76614 m
.32424 .76635 L
s
.21153 .49995 m .21197 .51738 L .22378 .50441 L .656 .78 .94 r
F
.21153 .49995 m .19366 .51082 L .21197 .51738 L F
0 g
.21197 .51738 m
.23252 .52127 L
s
.34369 .76741 m .35389 .76156 L .35342 .76617 L .6 .386 .562 r
F
.34321 .77203 m .34369 .76741 L .35342 .76617 L F
.33961 .76129 m .34369 .76741 L .35342 .76617 L .594 .768 .963 r
F
0 g
.34011 .7674 m
.34369 .76741 L
s
.40181 .38513 m .40258 .37702 L .42908 .37625 L .664 .424 .546 r
F
.37512 .38158 m .40258 .37702 L .40181 .38513 L .732 .484 .553 r
F
.37512 .38158 m .37596 .37346 L .40258 .37702 L F
.40198 .35565 m .40258 .37702 L .42908 .37625 L .643 .737 .917 r
F
.38402 .35324 m .40258 .37702 L .40198 .35565 L F
.38402 .35324 m .37596 .37346 L .40258 .37702 L F
.58554 .49998 m .6112 .488 L .58441 .49241 L .656 .78 .94 r
F
.55836 .50058 m .58554 .49998 L .58441 .49241 L F
.60076 .77698 m .59159 .77212 L .58695 .77437 L .595 .768 .962 r
F
.60371 .77619 m .59159 .77212 L .60076 .77698 L F
.62008 .77813 m .62497 .77216 L .61738 .77701 L F
.62008 .77813 m .63038 .77443 L .62497 .77216 L F
.22691 .36858 m .19591 .35642 L .19063 .36631 L .643 .737 .917 r
F
.23175 .36449 m .19591 .35642 L .22691 .36858 L F
.30354 .76029 m .31292 .75911 L .3124 .76372 L .844 .608 .582 r
F
.30354 .76029 m .30408 .75568 L .31292 .75911 L F
0 g
.31292 .75911 m
.31702 .7601 L
s
.60726 .77116 m .60446 .76506 L .59769 .76588 L .596 .768 .961 r
F
.61082 .77116 m .60446 .76506 L .60726 .77116 L F
.28578 .37167 m .30276 .35318 L .27994 .36701 L .643 .737 .917 r
F
.28578 .37167 m .31439 .36263 L .30276 .35318 L F
.81099 .63585 m .80969 .62463 L .8018 .63451 L .655 .809 .957 r
F
.81099 .63585 m .82354 .62669 L .80969 .62463 L F
.61433 .77158 m .61162 .76506 L .61082 .77116 L .596 .768 .961 r
F
.61433 .77158 m .61868 .76591 L .61162 .76506 L F
.84471 .64679 m .83594 .6359 L .8369 .64132 L .949 .641 .416 r
F
0 g
.84471 .64679 m
.84857 .65342 L
s
.35342 .76617 m .35389 .76156 L .36217 .75914 L .5 .3 .539 r
F
0 g
.34417 .7628 m
.35389 .76156 L
s
.19591 .35642 m .15686 .3591 L .19063 .36631 L .643 .737 .917 r
F
.82048 .64916 m .82563 .63742 L .81297 .64659 L .654 .811 .959 r
F
.82048 .64916 m .8369 .64132 L .82563 .63742 L F
.59178 .76749 m .57562 .766 L .58715 .76975 L .596 .768 .961 r
F
.58695 .77437 m .57541 .77063 L .57086 .77477 L .595 .768 .962 r
F
0 g
.56901 .77937 m
.57086 .77477 L
s
.77947 .76924 m .78989 .76587 L .78993 .77049 L .733 .5 .576 r
F
.77947 .76924 m .77944 .76462 L .78989 .76587 L F
.7846 .75891 m .77944 .76462 L .78989 .76587 L .598 .766 .96 r
F
0 g
.78989 .76587 m
.79122 .76588 L
s
.61082 .77116 m .61162 .76506 L .60446 .76506 L .596 .768 .961 r
F
.31339 .64006 m .30221 .6322 L .28995 .63769 L .659 .805 .953 r
F
.32308 .63749 m .30221 .6322 L .31339 .64006 L F
.6345 .77258 m .64089 .76606 L .63053 .7698 L .596 .768 .961 r
F
.6345 .77258 m .64683 .77025 L .64089 .76606 L F
.53413 .3849 m .53515 .36362 L .50821 .36442 L .643 .737 .917 r
F
.50439 .51486 m .47859 .52296 L .50517 .51861 L .655 .782 .942 r
F
.50439 .51486 m .47688 .51548 L .47859 .52296 L F
.65009 .7795 m .64683 .77025 L .6467 .77488 L .994 .75 .44 r
F
0 g
.65009 .7795 m
.65072 .78425 L
s
.3547 .64282 m .34925 .6316 L .34463 .64148 L .659 .806 .954 r
F
.3547 .64282 m .36444 .63365 L .34925 .6316 L F
.55836 .50058 m .58441 .49241 L .55772 .49681 L .656 .78 .94 r
F
.76219 .64738 m .74946 .64137 L .73832 .64808 L .655 .81 .958 r
F
.77139 .64374 m .74946 .64137 L .76219 .64738 L F
.74946 .64137 m .7375 .64266 L .73832 .64808 L .437 .293 .587 r
F
.74946 .64137 m .74861 .63593 L .7375 .64266 L F
0 g
.72984 .65008 m
.7375 .64266 L
s
.60371 .77619 m .5975 .77052 L .59159 .77212 L .595 .768 .962 r
F
.60708 .77578 m .5975 .77052 L .60371 .77619 L F
.31076 .5017 m .32309 .48571 L .32309 .49223 L .333 .178 .516 r
F
.31073 .50821 m .31076 .5017 L .32309 .49223 L F
.29021 .49167 m .31076 .5017 L .32309 .49223 L .657 .779 .939 r
F
.27927 .49664 m .31076 .5017 L .29021 .49167 L F
0 g
.30005 .50651 m
.31076 .5017 L
s
.77004 .76682 m .77944 .76462 L .77947 .76924 L .794 .551 .57 r
F
.77004 .76682 m .77002 .76219 L .77944 .76462 L F
.77829 .75728 m .77944 .76462 L .7846 .75891 L .598 .766 .96 r
F
.77829 .75728 m .77002 .76219 L .77944 .76462 L F
0 g
.77944 .76462 m
.78989 .76587 L
s
.61738 .77701 m .61851 .77055 L .61417 .7762 L .595 .768 .962 r
F
.61738 .77701 m .62497 .77216 L .61851 .77055 L F
.34429 .63617 m .33277 .62629 L .33363 .63616 L .659 .805 .953 r
F
.34429 .63617 m .34888 .62632 L .33277 .62629 L F
.31813 .76345 m .32198 .77076 L .3249 .76508 L .593 .769 .963 r
F
.31813 .76345 m .31187 .76834 L .32198 .77076 L F
0 g
.32198 .77076 m
.32559 .77118 L
s
.30557 .65445 m .29016 .64847 L .28106 .65515 L .658 .806 .954 r
F
.31378 .65082 m .29016 .64847 L .30557 .65445 L F
.29016 .64847 m .28085 .64972 L .28106 .65515 L .355 .21 .542 r
F
0 g
.27581 .66252 m
.28106 .65515 L
s
.29016 .64847 m .28994 .64303 L .28085 .64972 L .355 .21 .542 r
F
0 g
.27561 .65711 m
.28085 .64972 L
s
.34321 .77203 m .35342 .76617 L .35295 .7708 L .6 .386 .562 r
F
.33912 .76592 m .34321 .77203 L .35295 .7708 L .593 .769 .963 r
F
0 g
.33391 .77201 m
.34321 .77203 L
s
.36711 .34802 m .37596 .37346 L .38402 .35324 L .643 .737 .917 r
F
0 g
.37184 .37221 m
.37596 .37346 L
s
.37596 .37346 m
.40258 .37702 L
s
.76225 .75876 m .77001 .75758 L .77002 .76219 L .862 .609 .555 r
F
.76225 .75876 m .76225 .75414 L .77001 .75758 L F
0 g
.77001 .75758 m
.77543 .75898 L
s
.6136 .50587 m .6116 .48794 L .6121 .49447 L .761 .569 0 r
F
.58626 .50648 m .6136 .50587 L .6121 .49447 L .655 .781 .941 r
F
.61409 .51239 m .6136 .50587 L .6121 .49447 L .761 .569 0 r
F
0 g
.61123 .51246 m
.61342 .50635 L
s
.59207 .76292 m .5829 .75802 L .57601 .76143 L .597 .767 .961 r
F
.59794 .76132 m .5829 .75802 L .59207 .76292 L F
.42908 .37625 m .45449 .36309 L .45384 .37119 L .583 .353 .533 r
F
.42837 .38437 m .42908 .37625 L .45384 .37119 L F
.40181 .38513 m .42908 .37625 L .42837 .38437 L .664 .424 .546 r
F
.41985 .35512 m .42908 .37625 L .45384 .37119 L .643 .737 .917 r
F
.40198 .35565 m .42908 .37625 L .41985 .35512 L F
0 g
.40258 .37702 m
.42908 .37625 L
s
.81113 .76465 m .81107 .76003 L .82046 .75761 L .532 .34 .566 r
F
0 g
.80727 .76048 m
.81107 .76003 L
s
.63057 .76521 m .63281 .75805 L .62521 .76294 L .597 .767 .961 r
F
.63057 .76521 m .64087 .76148 L .63281 .75805 L F
.30301 .76492 m .3124 .76372 L .31187 .76834 L .844 .608 .582 r
F
.30301 .76492 m .30354 .76029 L .3124 .76372 L F
.31274 .75652 m .3124 .76372 L .31865 .75882 L .594 .768 .963 r
F
.31274 .75652 m .30354 .76029 L .3124 .76372 L F
0 g
.3124 .76372 m
.31652 .76471 L
s
.60708 .77578 m .60428 .7697 L .5975 .77052 L .595 .768 .962 r
F
.61065 .77579 m .60428 .7697 L .60708 .77578 L F
.61417 .7762 m .61145 .76971 L .61065 .77579 L F
.61417 .7762 m .61851 .77055 L .61145 .76971 L F
.35342 .76617 m .36217 .75914 L .3617 .76377 L .5 .3 .539 r
F
.35295 .7708 m .35342 .76617 L .3617 .76377 L F
.34612 .76046 m .35342 .76617 L .3617 .76377 L .594 .768 .963 r
F
.33961 .76129 m .35342 .76617 L .34612 .76046 L F
0 g
.34369 .76741 m
.35342 .76617 L
s
.7706 .63841 m .76256 .63053 L .74881 .63603 L .655 .809 .957 r
F
.78086 .63583 m .76256 .63053 L .7706 .63841 L F
.6836 .37293 m .65527 .38726 L .68635 .37825 L .643 .737 .917 r
F
.6836 .37293 m .6496 .3767 L .65527 .38726 L F
.55808 .51742 m .58671 .51301 L .5593 .51362 L .655 .782 .942 r
F
.59159 .77212 m .57541 .77063 L .58695 .77437 L .595 .768 .962 r
F
.37754 .63756 m .3772 .63215 L .36412 .62822 L .851 .592 .547 r
F
0 g
.3772 .63215 m
.38729 .63764 L
s
.78463 .76354 m .78993 .77049 L .79164 .76439 L .597 .767 .96 r
F
.78463 .76354 m .77947 .76924 L .78993 .77049 L F
0 g
.78993 .77049 m
.79235 .7705 L
s
.61065 .77579 m .61145 .76971 L .60428 .7697 L .595 .768 .962 r
F
.17904 .49539 m .19412 .49777 L .19389 .50428 L .909 .654 .541 r
F
.17904 .49539 m .17929 .48885 L .19412 .49777 L F
0 g
.19412 .49777 m
.20067 .50014 L
s
.63436 .7772 m .64075 .77071 L .63038 .77443 L .595 .768 .962 r
F
.63436 .7772 m .6467 .77488 L .64075 .77071 L F
.77384 .39347 m .81475 .39088 L .78265 .38367 L .643 .737 .917 r
F
.74601 .38138 m .77384 .39347 L .78265 .38367 L F
.73979 .38547 m .77384 .39347 L .74601 .38138 L F
.32308 .63749 m .31683 .6283 L .30221 .6322 L .659 .805 .953 r
F
.33363 .63616 m .31683 .6283 L .32308 .63749 L F
.81204 .64117 m .81074 .62993 L .80279 .63983 L .655 .81 .958 r
F
.81204 .64117 m .82468 .63198 L .81074 .62993 L F
.58256 .76258 m .57583 .76138 L .57562 .766 L .386 .214 .523 r
F
.58256 .76258 m .58276 .75795 L .57583 .76138 L F
0 g
.5713 .76555 m
.57583 .76138 L
s
.20231 .48075 m .19438 .4976 L .21211 .48674 L .657 .779 .938 r
F
.20231 .48075 m .17963 .48873 L .19438 .4976 L F
.61387 .36369 m .61607 .37233 L .61582 .38045 L .855 .686 .154 r
F
.61387 .36369 m .61412 .35553 L .61607 .37233 L F
.64868 .35734 m .61607 .37233 L .64976 .36857 L .644 .736 .916 r
F
.64868 .35734 m .61412 .35553 L .61607 .37233 L F
0 g
.61607 .37233 m
.62029 .37995 L
s
.25029 .47971 m .25226 .49455 L .25349 .49443 L .657 .779 .938 r
F
.25029 .47971 m .25349 .49443 L .25341 .48234 L F
.24533 .47946 m .25226 .49455 L .25029 .47971 L F
.24306 .47935 m .24425 .48132 L .24533 .47946 L F
.24425 .48132 m .25226 .49455 L .24533 .47946 L F
.24425 .48132 m .23794 .49386 L .25226 .49455 L F
.24306 .47935 m .23944 .4896 L .24425 .48132 L F
.23944 .4896 m .23794 .49386 L .24425 .48132 L F
.25581 .43381 m .25619 .43311 L .2533 .46574 L 0 0 .268 r
F
.25339 .47942 m .26632 .49323 L .25739 .47904 L .657 .779 .938 r
F
.25029 .47971 m .25341 .48234 L .25339 .47942 L F
.25341 .48234 m .26632 .49323 L .25339 .47942 L F
.25581 .43381 m .2533 .46574 L .25311 .46607 L 0 0 .268 r
F
.25619 .43311 m .25619 .43227 L .2533 .46499 L .796 .683 .137 r
F
.25341 .48234 m .25349 .49443 L .26632 .49323 L .657 .779 .938 r
F
.25017 .48633 m .25216 .5012 L .26631 .49988 L .657 .779 .939 r
F
.24289 .48598 m .25216 .5012 L .25199 .49998 L F
.24831 .48624 m .25199 .49998 L .25017 .48633 L F
.24289 .48598 m .25199 .49998 L .24831 .48624 L F
.2479 .43213 m .24809 .43297 L .24509 .4659 L .952 .765 .308 r
F
.2479 .43213 m .24509 .4659 L .24506 .46579 L F
.24626 .47028 m .24087 .4744 L .24306 .47935 L .657 .779 .938 r
F
.24555 .4676 m .24224 .47127 L .24626 .47028 L F
.24224 .47127 m .23616 .478 L .24087 .4744 L F
.24224 .47127 m .24087 .4744 L .24626 .47028 L F
.24456 .47172 m .24453 .47213 L .24452 .47211 L .952 .765 .308 r
F
.24456 .47172 m .24452 .47211 L .24444 .47182 L F
.24555 .4676 m .23007 .47573 L .23616 .478 L .657 .779 .938 r
F
.24289 .48598 m .23773 .50052 L .25216 .5012 L .657 .779 .939 r
F
.24274 .49255 m .25203 .50774 L .25004 .49291 L .656 .78 .94 r
F
.24274 .49255 m .23758 .50705 L .25187 .50773 L F
.25175 .50728 m .25187 .50773 L .25203 .50774 L F
.24274 .49255 m .25187 .50773 L .25175 .50728 L F
.23616 .478 m .23794 .49386 L .24306 .47935 L .657 .779 .938 r
F
.23616 .478 m .22425 .4912 L .23794 .49386 L F
.23595 .48462 m .23773 .50052 L .24289 .48598 L .657 .779 .939 r
F
.23595 .48462 m .22396 .49786 L .23773 .50052 L F
.23579 .4912 m .23758 .50705 L .24274 .49255 L .656 .78 .94 r
F
.25059 .43478 m .24851 .46751 L .24765 .46742 L .751 .492 .54 r
F
.24878 .46833 m .24626 .47028 L .25029 .47971 L .657 .779 .938 r
F
.2487 .46771 m .24768 .46878 L .24878 .46833 L F
.24768 .46878 m .24626 .47028 L .24878 .46833 L F
.24626 .47028 m .24875 .47963 L .25029 .47971 L F
.25236 .43505 m .25027 .46748 L .24944 .4676 L .636 .39 .528 r
F
.25407 .43484 m .25512 .43439 L .25224 .46691 L .487 .263 .5 r
F
.25058 .46822 m .25029 .47971 L .25739 .47904 L .657 .779 .938 r
F
.25027 .46772 m .25027 .46846 L .25058 .46822 L F
.25027 .46846 m .25029 .47971 L .25058 .46822 L F
.25017 .48633 m .26631 .49988 L .25732 .48567 L .657 .779 .939 r
F
.25004 .49291 m .25203 .50774 L .2662 .50642 L .656 .78 .94 r
F
.25004 .49291 m .2662 .50642 L .2572 .49224 L F
.25236 .43505 m .25407 .43484 L .25118 .46735 L .636 .39 .528 r
F
.25236 .43505 m .25118 .46735 L .25027 .46748 L F
.25407 .43484 m .25169 .46714 L .25118 .46735 L .487 .263 .5 r
F
.25231 .46788 m .25739 .47904 L .2625 .47775 L .657 .779 .938 r
F
.25231 .46788 m .2625 .47775 L .25987 .4741 L F
.25116 .46777 m .25739 .47904 L .25231 .46788 L F
.25024 .46768 m .25058 .46822 L .25116 .46777 L F
.25058 .46822 m .25739 .47904 L .25116 .46777 L F
.25512 .43439 m .25581 .43381 L .25294 .46637 L .269 .086 .437 r
F
.25059 .43478 m .25236 .43505 L .24944 .4676 L .751 .492 .54 r
F
.25059 .43478 m .24944 .4676 L .24851 .46751 L F
.25512 .43439 m .25257 .46665 L .25224 .46691 L .269 .086 .437 r
F
.25407 .43484 m .25224 .46691 L .25169 .46714 L .487 .263 .5 r
F
.25557 .46814 m .26388 .4774 L .26933 .47488 L .657 .779 .938 r
F
.24828 .46457 m .25987 .4741 L .25557 .46814 L F
.25987 .4741 m .26388 .4774 L .25557 .46814 L F
.25512 .43439 m .25294 .46637 L .25257 .46665 L .269 .086 .437 r
F
.25581 .43381 m .25311 .46607 L .25294 .46637 L 0 0 .268 r
F
.25619 .43227 m .25554 .43119 L .25263 .46406 L .991 .745 .452 r
F
.24828 .46457 m .26933 .47488 L .27071 .47379 L .657 .779 .938 r
F
.25942 .46772 m .27071 .47379 L .27337 .47166 L F
.24828 .46457 m .27071 .47379 L .25942 .46772 L F
.25013 .46778 m .25029 .47971 L .25027 .46772 L F
.2487 .46771 m .25029 .47971 L .25013 .4675 L F
.25619 .43311 m .2533 .46499 L .2533 .46538 L .796 .683 .137 r
F
.25619 .43311 m .2533 .46538 L .2533 .46574 L F
.25513 .46541 m .27337 .47166 L .27573 .46794 L .657 .779 .938 r
F
.24828 .46457 m .25942 .46772 L .25513 .46541 L F
.25942 .46772 m .27337 .47166 L .25513 .46541 L F
.25554 .43119 m .25425 .43034 L .25131 .46335 L .896 .63 .527 r
F
.25016 .47434 m .25016 .47641 L .25079 .47534 L .657 .779 .939 r
F
.25016 .47641 m .25017 .48633 L .25079 .47534 L F
.24872 .47546 m .25017 .48633 L .25016 .47434 L F
.24828 .46457 m .25024 .46768 L .25231 .46788 L .657 .779 .938 r
F
.25027 .46748 m .25118 .46735 L .25062 .47357 L .636 .39 .528 r
F
.24989 .47392 m .24872 .47546 L .25016 .47434 L .657 .779 .939 r
F
.24975 .4737 m .24964 .4739 L .24989 .47392 L F
.24964 .4739 m .24872 .47546 L .24989 .47392 L F
.24943 .43429 m .25059 .43478 L .24765 .46742 L .839 .573 .538 r
F
.24943 .43429 m .24765 .46742 L .24704 .46722 L F
.24828 .46457 m .24731 .46731 L .2487 .46771 L .657 .779 .938 r
F
.24731 .46731 m .24709 .46793 L .24856 .46772 L F
.24731 .46731 m .24856 .46772 L .2487 .46771 L F
.24709 .46793 m .24626 .47028 L .24865 .46776 L F
.24856 .46772 m .24865 .46776 L .2487 .46771 L F
.24709 .46793 m .24865 .46776 L .24856 .46772 L F
.24626 .47028 m .24306 .47935 L .24875 .47963 L F
.24943 .43429 m .24704 .46722 L .24647 .46703 L .839 .573 .538 r
F
.24724 .46751 m .24555 .4676 L .24626 .47028 L .657 .779 .938 r
F
.24861 .43368 m .24943 .43429 L .24647 .46703 L .913 .647 .523 r
F
.24861 .43368 m .24647 .46703 L .24604 .46677 L F
.24828 .46457 m .2462 .46687 L .24724 .46751 L .657 .779 .938 r
F
.2462 .46687 m .24555 .4676 L .24724 .46751 L F
.24809 .43297 m .24861 .43368 L .24563 .46652 L .98 .727 .476 r
F
.24607 .46702 m .24544 .46721 L .24586 .46725 L .657 .779 .938 r
F
.24601 .46695 m .24544 .46721 L .24607 .46702 L F
.24596 .46672 m .24544 .46721 L .2462 .46687 L F
.24809 .43297 m .24563 .46652 L .24536 .4662 L .98 .727 .476 r
F
.24861 .43368 m .24604 .46677 L .24563 .46652 L .913 .647 .523 r
F
.24588 .4668 m .24524 .46643 L .24544 .46721 L .657 .779 .938 r
F
.24828 .46457 m .24545 .46631 L .24588 .4668 L F
.24545 .46631 m .24524 .46643 L .24588 .4668 L F
.24524 .46643 m .23007 .47573 L .24555 .4676 L F
.24895 .47716 m .24289 .48598 L .25017 .48633 L .657 .779 .939 r
F
.24704 .46722 m .24765 .46742 L .24709 .47365 L .839 .573 .538 r
F
.24854 .47413 m .24686 .47478 L .24895 .47716 L .657 .779 .939 r
F
.24724 .4737 m .24686 .47478 L .24854 .47413 L F
.24686 .47478 m .24289 .48598 L .24895 .47716 L F
.24704 .46722 m .24709 .47365 L .24658 .47348 L .839 .573 .538 r
F
.24087 .4744 m .23906 .47857 L .24306 .47935 L .657 .779 .938 r
F
.24686 .47478 m .23595 .48462 L .24289 .48598 L .657 .779 .939 r
F
.24724 .4737 m .24588 .47366 L .24686 .47478 L F
.24709 .47365 m .24588 .47366 L .24724 .4737 L F
.24617 .47334 m .24599 .47354 L .24709 .47365 L F
.24599 .47354 m .24588 .47366 L .24709 .47365 L F
.24883 .4839 m .24274 .49255 L .25004 .49291 L .656 .78 .94 r
F
.24838 .4805 m .2475 .48239 L .24883 .4839 L F
.2475 .48239 m .24274 .49255 L .24883 .4839 L F
.24588 .47366 m .24515 .47446 L .24686 .47478 L .657 .779 .939 r
F
.24515 .47446 m .23595 .48462 L .24555 .47596 L F
.24515 .47446 m .24555 .47596 L .24686 .47478 L F
.24765 .46742 m .2474 .47368 L .24709 .47365 L .751 .492 .54 r
F
.24647 .46703 m .24611 .47332 L .24591 .47326 L .839 .573 .538 r
F
.24809 .43297 m .24536 .4662 L .24509 .4659 L .98 .727 .476 r
F
.2479 .43213 m .24506 .46579 L .24499 .46552 L .952 .765 .308 r
F
.24828 .46457 m .24101 .46713 L .23007 .47573 L .657 .779 .938 r
F
.24101 .46713 m .22519 .47269 L .22916 .47516 L F
.24101 .46713 m .22916 .47516 L .23007 .47573 L F
.24944 .43026 m .24833 .43107 L .24531 .46421 L .329 .133 .455 r
F
.24087 .4744 m .23616 .478 L .23906 .47857 L .657 .779 .938 r
F
.23007 .47573 m .22425 .4912 L .23616 .478 L F
.24515 .47446 m .22981 .48235 L .23595 .48462 L .657 .779 .939 r
F
.24506 .47411 m .24255 .47546 L .24515 .47446 L F
.24255 .47546 m .22981 .48235 L .24236 .4759 L F
.24255 .47546 m .24236 .4759 L .24515 .47446 L F
.2479 .43213 m .24499 .46552 L .2449 .46516 L .952 .765 .308 r
F
.24833 .43107 m .2479 .43213 L .2449 .46516 L 0 0 .188 r
F
.24833 .43107 m .2449 .46516 L .24511 .46467 L F
.24101 .46713 m .22185 .46909 L .22519 .47269 L .657 .779 .938 r
F
.24828 .46457 m .2436 .46537 L .24101 .46713 L F
.2436 .46537 m .22185 .46909 L .24101 .46713 L F
.24588 .47366 m .24506 .47411 L .24515 .47446 L .657 .779 .939 r
F
.24704 .46722 m .24658 .47348 L .24647 .46703 L .839 .573 .538 r
F
.24531 .47289 m .24523 .47293 L .24612 .47339 L .657 .779 .939 r
F
.24816 .48043 m .24788 .48105 L .24838 .4805 L .656 .78 .94 r
F
.24523 .47293 m .24308 .47425 L .24588 .47366 L .657 .779 .939 r
F
.24308 .47425 m .22981 .48235 L .24255 .47546 L F
.24308 .47425 m .24255 .47546 L .24588 .47366 L F
.24735 .48223 m .24274 .49255 L .2475 .48239 L .656 .78 .94 r
F
.24669 .48147 m .24274 .49255 L .24735 .48223 L F
.24658 .47348 m .24613 .47976 L .24611 .47332 L .839 .573 .538 r
F
.24669 .48147 m .2397 .48691 L .24274 .49255 L .656 .78 .94 r
F
.24718 .48011 m .24624 .48096 L .24669 .48147 L F
.24658 .47348 m .24611 .47332 L .24647 .46703 L .839 .573 .538 r
F
.24604 .46677 m .24555 .47304 L .24563 .46652 L .913 .647 .523 r
F
.24586 .46725 m .24544 .46721 L .24555 .4676 L .657 .779 .938 r
F
.24555 .47304 m .24522 .47283 L .24563 .46652 L .913 .647 .523 r
F
.24536 .4662 m .24563 .46652 L .24507 .47275 L .98 .727 .476 r
F
.24536 .4662 m .24507 .47275 L .24484 .47248 L F
.24536 .4662 m .24484 .47248 L .24509 .4659 L F
.24484 .47248 m .24462 .47224 L .24509 .4659 L F
.24308 .47425 m .23887 .47441 L .22981 .48235 L .657 .779 .939 r
F
.24531 .47289 m .24349 .47332 L .24308 .47425 L F
.24349 .47332 m .23887 .47441 L .24308 .47425 L F
.24506 .46579 m .24456 .47172 L .24499 .46552 L .952 .765 .308 r
F
.24833 .43107 m .24511 .46467 L .24531 .46421 L 0 0 .188 r
F
.23522 .4668 m .2203 .46516 L .22185 .46909 L .657 .779 .938 r
F
.24828 .46457 m .24227 .4647 L .23522 .4668 L F
.24227 .4647 m .2203 .46516 L .23522 .4668 L F
.2506 .42991 m .24944 .43026 L .24643 .46345 L .55 .315 .512 r
F
.24454 .47242 m .23887 .47441 L .24531 .47289 L .657 .779 .939 r
F
.24497 .48212 m .2397 .48691 L .24512 .48269 L .656 .78 .94 r
F
.24604 .47993 m .2397 .48691 L .24684 .48041 L F
.22981 .48235 m .22396 .49786 L .23595 .48462 L .657 .779 .939 r
F
.2397 .48691 m .22964 .48894 L .23579 .4912 L .656 .78 .94 r
F
.24522 .47283 m .2448 .47917 L .24507 .47275 L .913 .647 .523 r
F
.24604 .47993 m .24214 .48134 L .2397 .48691 L .656 .78 .94 r
F
.24534 .47951 m .24214 .48134 L .24604 .47993 L F
.24525 .47945 m .24522 .47947 L .24534 .47951 L F
.24522 .47947 m .24214 .48134 L .24534 .47951 L F
.24612 .47339 m .24579 .47322 L .24588 .47366 L .657 .779 .939 r
F
.24611 .47332 m .24575 .47964 L .24591 .47326 L .839 .573 .538 r
F
.24575 .47964 m .24559 .47959 L .24591 .47326 L F
.24613 .47976 m .24575 .47964 L .24611 .47332 L F
.24591 .47326 m .24559 .47959 L .24534 .47951 L F
.24709 .47365 m .2469 .47993 L .24653 .4799 L .751 .492 .54 r
F
.2474 .47368 m .24715 .47996 L .24709 .47365 L F
.24715 .47996 m .2469 .47993 L .24709 .47365 L F
.24658 .47348 m .24709 .47365 L .24653 .4799 L .839 .573 .538 r
F
.24658 .47348 m .24653 .4799 L .24613 .47976 L F
.24851 .46751 m .24889 .47382 L .24811 .47375 L .751 .492 .54 r
F
.2485 .47378 m .24724 .4737 L .24854 .47413 L .657 .779 .939 r
F
.24851 .46751 m .24811 .47375 L .24765 .46742 L .751 .492 .54 r
F
.24811 .47375 m .2474 .47368 L .24765 .46742 L F
.24815 .47116 m .24726 .47366 L .2485 .47378 L .657 .779 .939 r
F
.24726 .47366 m .24724 .4737 L .2485 .47378 L F
.24723 .47996 m .24653 .4799 L .24718 .48011 L .656 .78 .94 r
F
.24653 .4799 m .24604 .47993 L .24718 .48011 L F
.24618 .47978 m .24611 .47986 L .24653 .4799 L F
.24611 .47986 m .24604 .47993 L .24653 .4799 L F
.24811 .47375 m .24771 .48001 L .2474 .47368 L .751 .492 .54 r
F
.24604 .47993 m .24684 .48041 L .24718 .48011 L .656 .78 .94 r
F
.24723 .47996 m .24669 .48147 L .24832 .48007 L F
.24669 .48147 m .24735 .48223 L .24832 .48007 L F
.24788 .48105 m .24735 .48223 L .24807 .48116 L F
.24735 .48223 m .2475 .48239 L .24807 .48116 L F
.24771 .48001 m .2462 .5038 L .24715 .47996 L .751 .492 .54 r
F
.24771 .48001 m .24715 .47996 L .2474 .47368 L F
.24811 .47375 m .24889 .47382 L .24833 .48007 L F
.24788 .48105 m .24807 .48116 L .24838 .4805 L .656 .78 .94 r
F
.24832 .48007 m .24816 .48043 L .24838 .4805 L F
.24832 .48007 m .24832 .48007 L .24832 .48007 L F
.24832 .48007 m .24816 .48043 L .24832 .48007 L F
.24851 .47388 m .24872 .47546 L .24975 .4737 L .657 .779 .939 r
F
.24889 .47382 m .24893 .47998 L .24833 .48007 L .636 .39 .528 r
F
.24944 .4676 m .24919 .47378 L .24889 .47382 L F
.24919 .47378 m .24893 .47998 L .24889 .47382 L F
.25257 .46665 m .25294 .46637 L .25238 .4726 L .269 .086 .437 r
F
.25257 .46665 m .25238 .4726 L .25209 .47283 L F
.25257 .46665 m .25209 .47283 L .25224 .46691 L F
.25739 .47904 m .26632 .49323 L .2792 .49 L .657 .779 .938 r
F
.25278 .47521 m .25732 .48567 L .26231 .4844 L .657 .779 .939 r
F
.25155 .47402 m .25279 .47686 L .25278 .47521 L F
.25143 .47423 m .25279 .47686 L .25155 .47402 L F
.25108 .47362 m .25141 .47426 L .25111 .47359 L F
.25141 .47426 m .25279 .47692 L .25143 .47423 L F
.25279 .47692 m .25279 .47686 L .25143 .47423 L F
.25311 .46607 m .2533 .46574 L .25275 .47196 L 0 0 .268 r
F
.2533 .46538 m .25275 .47154 L .2533 .46574 L .796 .683 .137 r
F
.25111 .47359 m .25278 .47519 L .25278 .47495 L .657 .779 .939 r
F
.25111 .47359 m .26231 .4844 L .25111 .47359 L F
.25079 .47534 m .25017 .48633 L .25732 .48567 L F
.25033 .48142 m .25004 .49291 L .2572 .49224 L .656 .78 .94 r
F
.24811 .47375 m .24833 .48007 L .24771 .48001 L .751 .492 .54 r
F
.25062 .47357 m .25732 .48567 L .25103 .47352 L .657 .779 .939 r
F
.24975 .4737 m .24987 .47388 L .25062 .47357 L F
.24987 .47388 m .25732 .48567 L .25062 .47357 L F
.25169 .46714 m .25224 .46691 L .25169 .47314 L .487 .263 .5 r
F
.24884 .48396 m .25004 .49291 L .25033 .48142 L .656 .78 .94 r
F
.25141 .47426 m .25143 .47423 L .25111 .47359 L .657 .779 .939 r
F
.25111 .47359 m .25143 .47423 L .25155 .47402 L F
.25169 .46714 m .25169 .47314 L .25123 .47333 L .487 .263 .5 r
F
.25224 .46691 m .25181 .47304 L .25169 .47314 L .269 .086 .437 r
F
.25209 .47283 m .25181 .47304 L .25224 .46691 L F
.24851 .46751 m .24944 .4676 L .24889 .47382 L .751 .492 .54 r
F
.25027 .46748 m .25062 .47357 L .24987 .47368 L .636 .39 .528 r
F
.26388 .4774 m .2792 .49 L .29006 .48504 L .657 .779 .938 r
F
.25739 .47904 m .2792 .49 L .26388 .4774 L F
.2552 .4746 m .26385 .48402 L .26934 .48149 L .657 .779 .939 r
F
.24947 .48007 m .24884 .48396 L .25033 .48142 L .656 .78 .94 r
F
.24937 .47992 m .24935 .48011 L .24947 .48007 L F
.24935 .48011 m .24884 .48396 L .24947 .48007 L F
.25062 .47357 m .25029 .47973 L .25007 .47982 L .487 .263 .5 r
F
.25197 .47302 m .25936 .48034 L .2552 .4746 L .657 .779 .939 r
F
.25094 .47345 m .25936 .48034 L .25197 .47302 L F
.25099 .48029 m .25224 .48269 L .25223 .48149 L .656 .78 .94 r
F
.25084 .48055 m .25224 .48313 L .25099 .48029 L F
.25224 .48313 m .2572 .49224 L .25224 .48269 L F
.25224 .48313 m .25224 .48269 L .25099 .48029 L F
.25118 .46735 m .25081 .4735 L .25062 .47357 L .487 .263 .5 r
F
.2526 .47223 m .25245 .47249 L .25294 .46637 L 0 0 .268 r
F
.25294 .46637 m .25245 .47249 L .25238 .4726 L F
.25311 .46607 m .2526 .47223 L .25294 .46637 L F
.25619 .43227 m .25263 .46406 L .25297 .46454 L .991 .745 .452 r
F
.25619 .43227 m .25297 .46454 L .2533 .46499 L F
.25573 .46441 m .27573 .46794 L .27623 .46397 L .657 .779 .938 r
F
.24828 .46457 m .26497 .46662 L .25573 .46441 L F
.26497 .46662 m .27573 .46794 L .25573 .46441 L F
.25237 .47286 m .2552 .4746 L .25459 .47376 L .657 .779 .939 r
F
.25169 .46714 m .25123 .47333 L .25118 .46735 L .487 .263 .5 r
F
.25123 .47333 m .25081 .4735 L .25118 .46735 L F
.25013 .4675 m .25013 .46778 L .25027 .46772 L .657 .779 .938 r
F
.25027 .46748 m .24987 .47368 L .24944 .4676 L .636 .39 .528 r
F
.24987 .47368 m .24947 .47991 L .24919 .47378 L F
.24947 .47991 m .24893 .47998 L .24919 .47378 L F
.25044 .47967 m .25029 .47973 L .25062 .47357 L .487 .263 .5 r
F
.24987 .47368 m .25062 .47357 L .25007 .47982 L .636 .39 .528 r
F
.24987 .47368 m .25007 .47982 L .24947 .47991 L F
.24801 .47777 m .24937 .47992 L .25037 .4797 L .656 .78 .94 r
F
.24937 .47992 m .24947 .48007 L .25007 .47982 L F
.24937 .47992 m .25007 .47982 L .25037 .4797 L F
.24832 .48007 m .24884 .48396 L .24937 .47992 L F
.24947 .47991 m .24795 .50359 L .24893 .47998 L .636 .39 .528 r
F
.24987 .47368 m .24919 .47378 L .24944 .4676 L F
.25987 .4741 m .2625 .47775 L .26388 .4774 L .657 .779 .938 r
F
.26388 .4774 m .29006 .48504 L .26933 .47488 L F
.25469 .473 m .27081 .48032 L .25984 .47444 L .657 .779 .939 r
F
.24815 .47116 m .25321 .47321 L .25469 .473 L F
.25321 .47321 m .27081 .48032 L .25469 .473 L F
.24815 .47116 m .25197 .47302 L .25237 .47286 L F
.25197 .47302 m .2552 .4746 L .25237 .47286 L F
.25037 .4797 m .25099 .48029 L .25102 .48023 L .656 .78 .94 r
F
.25037 .4797 m .25084 .48055 L .25099 .48029 L F
.24947 .48007 m .25033 .48142 L .25037 .4797 L F
.2533 .46574 m .25275 .47183 L .25275 .47196 L .796 .683 .137 r
F
.25311 .46607 m .25275 .47196 L .2526 .47223 L 0 0 .268 r
F
.24815 .47116 m .25984 .47444 L .25599 .47239 L .657 .779 .939 r
F
.25275 .47154 m .25275 .47183 L .2533 .46574 L .796 .683 .137 r
F
.26933 .47488 m .29818 .47867 L .27337 .47166 L .657 .779 .938 r
F
.25534 .47204 m .27523 .4754 L .26711 .47347 L .657 .779 .939 r
F
.24815 .47116 m .25599 .47239 L .25534 .47204 L F
.25599 .47239 m .27523 .4754 L .25534 .47204 L F
.25554 .43119 m .25199 .46372 L .25263 .46406 L .896 .63 .527 r
F
.25301 .46376 m .27623 .46397 L .27482 .46002 L .657 .779 .938 r
F
.24828 .46457 m .25573 .46441 L .25301 .46376 L F
.25573 .46441 m .27623 .46397 L .25301 .46376 L F
.25425 .43034 m .25301 .42995 L .25005 .46305 L .807 .543 .539 r
F
.24815 .47116 m .25094 .47345 L .25197 .47302 L .657 .779 .939 r
F
.24801 .47777 m .24832 .48007 L .24937 .47992 L .656 .78 .94 r
F
.24815 .47116 m .24975 .4737 L .25103 .47352 L .657 .779 .939 r
F
.24833 .48007 m .24795 .50359 L .2462 .5038 L .636 .39 .528 r
F
.24893 .47998 m .24795 .50359 L .24833 .48007 L F
.24815 .47116 m .24851 .47388 L .24975 .4737 L .657 .779 .939 r
F
.24828 .46457 m .2487 .46771 L .25013 .4675 L .657 .779 .938 r
F
.25279 .47692 m .25732 .48567 L .25279 .47686 L .657 .779 .939 r
F
.25279 .47686 m .25732 .48567 L .25278 .47521 L F
.25148 .47945 m .25797 .48539 L .25482 .48108 L .656 .78 .94 r
F
.25125 .47934 m .25144 .47952 L .25148 .47945 L F
.25144 .47952 m .25797 .48539 L .25148 .47945 L F
.25209 .47283 m .2516 .47903 L .25181 .47304 L .269 .086 .437 r
F
.25245 .47249 m .25196 .47863 L .25238 .4726 L 0 0 .268 r
F
.25732 .48567 m .27927 .49664 L .26385 .48402 L .657 .779 .939 r
F
.25139 .47961 m .2581 .48558 L .25144 .47952 L .656 .78 .94 r
F
.2581 .48558 m .25797 .48539 L .25125 .47934 L F
.25732 .48567 m .26631 .49988 L .27927 .49664 L .657 .779 .939 r
F
.25055 .47984 m .25885 .48661 L .25114 .47939 L .656 .78 .94 r
F
.25885 .48661 m .26374 .49059 L .2581 .48558 L F
.25885 .48661 m .2581 .48558 L .25114 .47939 L F
.2516 .47903 m .25138 .4792 L .25181 .47304 L .269 .086 .437 r
F
.25114 .47939 m .25139 .47961 L .25125 .47934 L .656 .78 .94 r
F
.25139 .47961 m .25144 .47952 L .25125 .47934 L F
.25033 .48142 m .25225 .48445 L .25084 .48055 L F
.25225 .48445 m .25224 .48313 L .25084 .48055 L F
.25102 .48023 m .25223 .4814 L .25222 .48121 L F
.25099 .48029 m .26206 .49101 L .25102 .48023 L F
.25181 .47304 m .25138 .4792 L .25169 .47314 L .269 .086 .437 r
F
.25278 .47495 m .26231 .4844 L .25936 .48034 L .657 .779 .939 r
F
.25278 .47519 m .26231 .4844 L .25278 .47495 L F
.25936 .48034 m .26231 .4844 L .26385 .48402 L F
.26385 .48402 m .27927 .49664 L .29021 .49167 L F
.25121 .47933 m .26924 .48807 L .25184 .47884 L .656 .78 .94 r
F
.25138 .4792 m .24973 .50257 L .25128 .47927 L .269 .086 .437 r
F
.25138 .4792 m .25128 .47927 L .25169 .47314 L F
.25936 .48034 m .26385 .48402 L .2552 .4746 L .657 .779 .939 r
F
.26385 .48402 m .29021 .49167 L .26934 .48149 L F
.25184 .47884 m .26924 .48807 L .27332 .48485 L .656 .78 .94 r
F
.25103 .47352 m .25111 .47359 L .25111 .47359 L .657 .779 .939 r
F
.25103 .47352 m .25108 .47362 L .25111 .47359 L F
.25123 .47333 m .25077 .47954 L .25081 .4735 L .487 .263 .5 r
F
.25077 .47954 m .25044 .47967 L .25081 .4735 L F
.25081 .4735 m .25044 .47967 L .25062 .47357 L F
.25037 .4797 m .25055 .47984 L .25114 .47939 L .656 .78 .94 r
F
.25033 .48142 m .25084 .48055 L .25037 .4797 L F
.25123 .47333 m .25169 .47314 L .25114 .47939 L .487 .263 .5 r
F
.25077 .47954 m .25114 .47939 L .24903 .50315 L F
.25123 .47333 m .25114 .47939 L .25077 .47954 L F
.25459 .47376 m .26934 .48149 L .27081 .48032 L .657 .779 .939 r
F
.2552 .4746 m .26934 .48149 L .25459 .47376 L F
.29006 .48504 m .32272 .48561 L .29818 .47867 L .657 .779 .938 r
F
.26933 .47488 m .29006 .48504 L .29818 .47867 L F
.26934 .48149 m .29021 .49167 L .29839 .48528 L .657 .779 .939 r
F
.26934 .48149 m .29839 .48528 L .27341 .47826 L F
.25348 .47843 m .27332 .48485 L .27569 .48113 L .656 .78 .94 r
F
.25196 .47863 m .25191 .47871 L .25238 .4726 L 0 0 .268 r
F
.25238 .4726 m .25191 .47871 L .25183 .47885 L F
.2526 .47223 m .25208 .47843 L .25245 .47249 L F
.25208 .47843 m .25198 .47859 L .25245 .47249 L F
.2526 .47223 m .2522 .47821 L .25208 .47843 L F
.25198 .47859 m .25196 .47863 L .25245 .47249 L F
.25114 .47939 m .24973 .50257 L .24903 .50315 L .269 .086 .437 r
F
.25169 .47314 m .25128 .47927 L .25114 .47939 L F
.25128 .47927 m .24973 .50257 L .25114 .47939 L F
.25251 .47832 m .25222 .47895 L .25348 .47843 L .656 .78 .94 r
F
.25209 .47283 m .25238 .4726 L .25183 .47885 L .269 .086 .437 r
F
.2516 .47903 m .25183 .47885 L .24973 .50257 L F
.25209 .47283 m .25183 .47885 L .2516 .47903 L F
.25599 .47239 m .27341 .47826 L .27523 .4754 L .657 .779 .939 r
F
.25984 .47444 m .27341 .47826 L .25599 .47239 L F
.25984 .47444 m .27081 .48032 L .27341 .47826 L F
.29818 .47867 m .32272 .48561 L .3301 .47462 L .657 .779 .938 r
F
.29818 .47867 m .3301 .47462 L .303 .47129 L F
.27337 .47166 m .29818 .47867 L .303 .47129 L F
.27341 .47826 m .29839 .48528 L .30324 .47788 L .657 .779 .939 r
F
.27341 .47826 m .30324 .47788 L .27578 .47453 L F
.25336 .47766 m .27569 .48113 L .27619 .47716 L .656 .78 .94 r
F
.25241 .47508 m .25275 .47196 L .2522 .47821 L 0 0 .268 r
F
.25267 .4721 m .25275 .47196 L .25241 .47508 L F
.27337 .47166 m .303 .47129 L .27573 .46794 L .657 .779 .938 r
F
.25661 .47098 m .27578 .47453 L .27628 .47055 L .657 .779 .939 r
F
.2533 .46499 m .25263 .47106 L .25275 .47122 L .991 .745 .452 r
F
.2533 .46538 m .2533 .46499 L .25275 .47122 L .796 .683 .137 r
F
.2533 .46538 m .25275 .47122 L .25275 .47154 L F
.24815 .47116 m .26711 .47347 L .25661 .47098 L .657 .779 .939 r
F
.26711 .47347 m .27578 .47453 L .25661 .47098 L F
.25425 .43034 m .25005 .46305 L .2507 .4632 L .807 .543 .539 r
F
.25425 .43034 m .2507 .4632 L .25131 .46335 L F
.25554 .43119 m .25131 .46335 L .25199 .46372 L .896 .63 .527 r
F
.25301 .42995 m .24945 .46301 L .25005 .46305 L .734 .476 .538 r
F
.24967 .46303 m .26674 .45325 L .26061 .4509 L .657 .779 .938 r
F
.24828 .46457 m .25069 .46309 L .24967 .46303 L F
.25069 .46309 m .26674 .45325 L .24967 .46303 L F
.25275 .47154 m .2522 .47747 L .2522 .47772 L .796 .683 .137 r
F
.2522 .47796 m .2522 .47806 L .25275 .47196 L F
.25275 .47196 m .2522 .47806 L .2522 .47821 L F
.2522 .47768 m .25251 .47832 L .25336 .47766 L .656 .78 .94 r
F
.24801 .47777 m .2522 .47828 L .2522 .47768 L F
.2522 .47828 m .25251 .47832 L .2522 .47768 L F
.24801 .47777 m .25184 .47884 L .25251 .47832 L F
.24801 .47777 m .25121 .47933 L .25184 .47884 L F
.24801 .47777 m .25037 .4797 L .25125 .47934 L F
.24771 .48001 m .24833 .48007 L .2462 .5038 L .751 .492 .54 r
F
.24715 .47996 m .2462 .5038 L .2469 .47993 L F
.24801 .47777 m .24723 .47996 L .24832 .48007 L .656 .78 .94 r
F
.24624 .48096 m .24497 .48212 L .24669 .48147 L F
.24497 .48212 m .24512 .48269 L .24669 .48147 L F
.24653 .4799 m .2462 .5038 L .2444 .50353 L .751 .492 .54 r
F
.2469 .47993 m .2462 .5038 L .24653 .4799 L F
.25069 .46309 m .27159 .45636 L .26674 .45325 L .657 .779 .938 r
F
.24828 .46457 m .25222 .46318 L .25069 .46309 L F
.25222 .46318 m .27159 .45636 L .25069 .46309 L F
.25301 .42995 m .25179 .42982 L .24881 .46297 L .734 .476 .538 r
F
.24801 .47777 m .24618 .47978 L .24653 .4799 L .656 .78 .94 r
F
.24801 .47777 m .24653 .4799 L .24723 .47996 L F
.24801 .47777 m .24588 .47983 L .24611 .47986 L F
.24563 .46652 m .24522 .47283 L .24507 .47275 L .913 .647 .523 r
F
.24579 .47322 m .24523 .47293 L .24536 .47308 L .657 .779 .939 r
F
.24579 .47322 m .24536 .47308 L .24588 .47366 L F
.2462 .46687 m .24601 .46695 L .24607 .46702 L .657 .779 .938 r
F
.23007 .47573 m .21211 .48674 L .22425 .4912 L F
.22519 .47269 m .21211 .48674 L .23007 .47573 L F
.22519 .47269 m .20231 .48075 L .21211 .48674 L F
.24454 .47242 m .22154 .4757 L .2249 .47931 L .657 .779 .939 r
F
.24604 .46677 m .24647 .46703 L .24591 .47326 L .913 .647 .523 r
F
.24604 .46677 m .24591 .47326 L .24569 .47312 L F
.24555 .47304 m .24534 .47951 L .24506 .47933 L F
.24604 .46677 m .24569 .47312 L .24555 .47304 L F
.24569 .47312 m .24534 .47951 L .24555 .47304 L F
.22185 .46909 m .20231 .48075 L .22519 .47269 L .657 .779 .938 r
F
.24371 .47192 m .21998 .47176 L .22154 .4757 L .657 .779 .939 r
F
.24944 .43026 m .24531 .46421 L .24589 .46382 L .329 .133 .455 r
F
.24227 .4647 m .22066 .46117 L .2203 .46516 L .657 .779 .938 r
F
.24828 .46457 m .24432 .46408 L .24227 .4647 L F
.24432 .46408 m .22066 .46117 L .24227 .4647 L F
.24499 .46552 m .24444 .47182 L .2449 .46516 L .952 .765 .308 r
F
.24444 .47179 m .24354 .47126 L .24371 .47192 L .657 .779 .939 r
F
.2449 .46516 m .2444 .47164 L .24433 .47139 L .952 .765 .308 r
F
.24511 .46467 m .2449 .46516 L .24433 .47139 L 0 0 .188 r
F
.24444 .47182 m .2444 .47164 L .2449 .46516 L .952 .765 .308 r
F
.24511 .46467 m .24433 .47139 L .24451 .47099 L 0 0 .188 r
F
.24509 .4659 m .24462 .47224 L .24453 .47213 L .98 .727 .476 r
F
.24499 .46552 m .24456 .47172 L .24444 .47182 L .952 .765 .308 r
F
.24506 .46579 m .24509 .4659 L .24453 .47213 L F
.24815 .47116 m .24429 .47124 L .24444 .47179 L .657 .779 .939 r
F
.24429 .47124 m .24354 .47126 L .24444 .47179 L F
.24815 .47116 m .24371 .47192 L .24454 .47242 L F
.22981 .48235 m .21173 .49339 L .22396 .49786 L F
.24214 .48134 m .22472 .48591 L .22964 .48894 L .656 .78 .94 r
F
.24525 .47945 m .24261 .48028 L .24214 .48134 L F
.24261 .48028 m .22472 .48591 L .24214 .48134 L F
.24371 .47192 m .22154 .4757 L .24454 .47242 L .657 .779 .939 r
F
.24453 .47213 m .24407 .47851 L .24396 .47838 L .98 .727 .476 r
F
.22185 .46909 m .19554 .4736 L .20231 .48075 L .657 .779 .938 r
F
.2203 .46516 m .19554 .4736 L .22185 .46909 L F
.24036 .47132 m .22033 .46776 L .21998 .47176 L .657 .779 .939 r
F
.24511 .46467 m .24451 .47099 L .24531 .46421 L 0 0 .188 r
F
.24451 .47099 m .24467 .47061 L .24531 .46421 L F
.24145 .46373 m .22291 .45739 L .22066 .46117 L .657 .779 .938 r
F
.24828 .46457 m .24429 .46344 L .24145 .46373 L F
.24429 .46344 m .22291 .45739 L .24145 .46373 L F
.25179 .42982 m .2506 .42991 L .24761 .4631 L .656 .407 .53 r
F
.24815 .47116 m .24437 .4707 L .24354 .47126 L .657 .779 .939 r
F
.24569 .47312 m .24591 .47326 L .24534 .47951 L .913 .647 .523 r
F
.2448 .47917 m .24468 .4791 L .24507 .47275 L F
.24507 .47275 m .24468 .4791 L .2445 .479 L F
.24555 .47304 m .24506 .47933 L .24522 .47283 L F
.24506 .47933 m .2448 .47917 L .24522 .47283 L F
.24801 .47777 m .2445 .479 L .24525 .47945 L .656 .78 .94 r
F
.24815 .47116 m .24454 .47242 L .24531 .47289 L .657 .779 .939 r
F
.24828 .46457 m .24596 .46672 L .2462 .46687 L .657 .779 .938 r
F
.24944 .43026 m .24589 .46382 L .24643 .46345 L .329 .133 .455 r
F
.24429 .46344 m .22691 .45409 L .22291 .45739 L .657 .779 .938 r
F
.24828 .46457 m .24569 .46329 L .24429 .46344 L F
.24569 .46329 m .22691 .45409 L .24429 .46344 L F
.24613 .47976 m .24653 .4799 L .2444 .50353 L .839 .573 .538 r
F
.24801 .47777 m .24525 .47945 L .24534 .47951 L .656 .78 .94 r
F
.24801 .47777 m .24534 .47951 L .246 .47972 L F
.246 .47972 m .24534 .47951 L .24588 .47983 L F
.24575 .47964 m .2444 .50353 L .24559 .47959 L .839 .573 .538 r
F
.24611 .47986 m .24588 .47983 L .24604 .47993 L .656 .78 .94 r
F
.24613 .47976 m .2444 .50353 L .24575 .47964 L .839 .573 .538 r
F
.24815 .47116 m .24531 .47289 L .24612 .47339 L .657 .779 .939 r
F
.24534 .47951 m .2444 .50353 L .24321 .50305 L .839 .573 .538 r
F
.24559 .47959 m .2444 .50353 L .24534 .47951 L F
.24815 .47116 m .24617 .47334 L .24724 .4737 L .657 .779 .939 r
F
.23887 .47441 m .22841 .48148 L .22981 .48235 L F
.2249 .47931 m .21173 .49339 L .22981 .48235 L F
.2249 .47931 m .20186 .48739 L .21173 .49339 L F
.23672 .48171 m .22135 .48231 L .22472 .48591 L .656 .78 .94 r
F
.24462 .47224 m .24415 .4786 L .24453 .47213 L .98 .727 .476 r
F
.24415 .4786 m .24407 .47851 L .24453 .47213 L F
.24484 .47248 m .24507 .47275 L .2445 .479 L F
.24484 .47248 m .2445 .479 L .24432 .47879 L F
.24433 .47139 m .24389 .47814 L .24376 .47765 L .952 .765 .308 r
F
.24451 .47099 m .24433 .47139 L .24376 .47765 L 0 0 .188 r
F
.24484 .47248 m .24432 .47879 L .24462 .47224 L .98 .727 .476 r
F
.24432 .47879 m .24415 .4786 L .24462 .47224 L F
.24801 .47777 m .24336 .47856 L .24293 .47955 L .656 .78 .94 r
F
.2445 .479 m .23672 .48171 L .24525 .47945 L F
.23672 .48171 m .22472 .48591 L .23556 .4825 L F
.23672 .48171 m .23556 .4825 L .24525 .47945 L F
.2395 .4701 m .2226 .46397 L .22033 .46776 L .657 .779 .939 r
F
.24589 .46382 m .24531 .46421 L .24475 .47044 L .329 .133 .455 r
F
.24589 .46382 m .24475 .47044 L .24522 .47012 L F
.2506 .42991 m .24643 .46345 L .24703 .46327 L .55 .315 .512 r
F
.24828 .46457 m .2324 .4515 L .22691 .45409 L .657 .779 .938 r
F
.2506 .42991 m .24703 .46327 L .24761 .4631 L .55 .315 .512 r
F
.24828 .46457 m .23899 .4498 L .2324 .4515 L .657 .779 .938 r
F
.25179 .42982 m .24761 .4631 L .24822 .46304 L .656 .407 .53 r
F
.24828 .46457 m .24623 .44911 L .23899 .4498 L .657 .779 .938 r
F
.24703 .46327 m .24636 .46953 L .24761 .4631 L .55 .315 .512 r
F
.24531 .46421 m .24467 .47061 L .24475 .47044 L 0 0 .188 r
F
.24815 .47116 m .24443 .47011 L .24302 .47053 L .657 .779 .939 r
F
.2453 .47948 m .24534 .47951 L .24462 .48754 L .913 .647 .523 r
F
.2453 .47948 m .24462 .48754 L .24321 .50305 L F
.24506 .47933 m .2453 .47948 L .24321 .50305 L F
.2448 .47917 m .24321 .50305 L .24468 .4791 L F
.2445 .479 m .24321 .50305 L .24237 .50245 L F
.24468 .4791 m .24321 .50305 L .2445 .479 L F
.24506 .47933 m .24321 .50305 L .2448 .47917 L F
.22154 .4757 m .20186 .48739 L .2249 .47931 L .657 .779 .939 r
F
.22724 .48131 m .21979 .47838 L .22135 .48231 L .656 .78 .94 r
F
.23887 .47441 m .2249 .47931 L .22841 .48148 L .657 .779 .939 r
F
.24444 .47182 m .24453 .47213 L .24396 .47838 L .952 .765 .308 r
F
.24444 .47182 m .24396 .47838 L .24389 .47814 L F
.24444 .47182 m .24389 .47814 L .2444 .47164 L F
.2444 .47164 m .24389 .47814 L .24433 .47139 L F
.24801 .47777 m .2424 .47789 L .24074 .47901 L .656 .78 .94 r
F
.24415 .4786 m .24237 .50245 L .24407 .47851 L .98 .727 .476 r
F
.2397 .48691 m .23766 .49157 L .24274 .49255 L .656 .78 .94 r
F
.24396 .47838 m .24237 .50245 L .24183 .50175 L .98 .727 .476 r
F
.24407 .47851 m .24237 .50245 L .24396 .47838 L F
.24432 .47879 m .2445 .479 L .24237 .50245 L F
.24432 .47879 m .24237 .50245 L .24415 .4786 L F
.24451 .47099 m .24376 .47765 L .2439 .47733 L 0 0 .188 r
F
.24451 .47099 m .2439 .47733 L .24467 .47061 L F
.2439 .47733 m .24403 .47703 L .24467 .47061 L F
.2424 .47789 m .24171 .47701 L .23844 .47798 L .656 .78 .94 r
F
.24801 .47777 m .24341 .47721 L .2424 .47789 L F
.24341 .47721 m .24171 .47701 L .2424 .47789 L F
.24309 .46974 m .22662 .46066 L .2226 .46397 L .657 .779 .939 r
F
.24589 .46382 m .24522 .47012 L .24643 .46345 L .329 .133 .455 r
F
.24522 .47012 m .24567 .46982 L .24643 .46345 L F
.24703 .46327 m .24643 .46345 L .24587 .46968 L .55 .315 .512 r
F
.24815 .47116 m .2454 .46982 L .24443 .47011 L .657 .779 .939 r
F
.24703 .46327 m .24587 .46968 L .24636 .46953 L .55 .315 .512 r
F
.24358 .46893 m .23215 .45806 L .22662 .46066 L .657 .779 .939 r
F
.24643 .46345 m .24567 .46982 L .24587 .46968 L .329 .133 .455 r
F
.24815 .47116 m .24557 .46905 L .24358 .46893 L .657 .779 .939 r
F
.24557 .46905 m .23215 .45806 L .24358 .46893 L F
.25179 .42982 m .24822 .46304 L .24881 .46297 L .656 .407 .53 r
F
.25301 .42995 m .24881 .46297 L .24945 .46301 L .734 .476 .538 r
F
.24828 .46457 m .25361 .44949 L .24623 .44911 L .657 .779 .938 r
F
.24828 .46457 m .26061 .4509 L .25361 .44949 L F
.24828 .46457 m .27482 .46002 L .27159 .45636 L F
.24945 .46301 m .24881 .46297 L .24825 .46921 L .734 .476 .538 r
F
.25664 .46971 m .27628 .47055 L .27487 .4666 L .657 .779 .939 r
F
.2507 .4632 m .25002 .46941 L .25131 .46335 L .807 .543 .539 r
F
.25297 .46454 m .25236 .47069 L .2533 .46499 L .991 .745 .452 r
F
.25236 .47069 m .25263 .47106 L .2533 .46499 L F
.25297 .46454 m .25207 .47029 L .25236 .47069 L F
.24815 .47116 m .25661 .47098 L .25352 .47024 L .657 .779 .939 r
F
.25002 .46941 m .25053 .46953 L .25131 .46335 L .807 .543 .539 r
F
.2507 .4632 m .24949 .46928 L .25002 .46941 L F
.25199 .46372 m .25132 .46988 L .25263 .46406 L .896 .63 .527 r
F
.25132 .46988 m .25184 .47017 L .25263 .46406 L F
.25263 .46406 m .25184 .47017 L .25207 .47029 L F
.25131 .46335 m .25053 .46953 L .25075 .46958 L .807 .543 .539 r
F
.25199 .46372 m .25131 .46335 L .25075 .46958 L .896 .63 .527 r
F
.25199 .46372 m .25075 .46958 L .25132 .46988 L F
.25297 .46454 m .25263 .46406 L .25207 .47029 L .991 .745 .452 r
F
.24983 .4693 m .26673 .45981 L .26056 .45746 L .657 .779 .939 r
F
.24815 .47116 m .25106 .46938 L .24983 .4693 L F
.25106 .46938 m .26673 .45981 L .24983 .4693 L F
.25005 .46305 m .24927 .46927 L .24949 .46928 L .734 .476 .538 r
F
.24877 .46924 m .24927 .46927 L .25005 .46305 L F
.2507 .4632 m .25005 .46305 L .24949 .46928 L .807 .543 .539 r
F
.24882 .46924 m .26056 .45746 L .25351 .45604 L .657 .779 .939 r
F
.24815 .47116 m .24983 .4693 L .24882 .46924 L F
.24983 .4693 m .26056 .45746 L .24882 .46924 L F
.24945 .46301 m .24877 .46924 L .25005 .46305 L .734 .476 .538 r
F
.24945 .46301 m .24857 .46923 L .24877 .46924 L F
.24945 .46301 m .24825 .46921 L .24857 .46923 L F
.24822 .46304 m .24755 .46928 L .24881 .46297 L .656 .407 .53 r
F
.24755 .46928 m .24804 .46923 L .24881 .46297 L F
.24636 .46953 m .24684 .46939 L .24761 .4631 L .55 .315 .512 r
F
.24881 .46297 m .24804 .46923 L .24825 .46921 L .656 .407 .53 r
F
.24822 .46304 m .24761 .4631 L .24704 .46933 L F
.24822 .46304 m .24704 .46933 L .24755 .46928 L F
.24761 .4631 m .24684 .46939 L .24704 .46933 L .55 .315 .512 r
F
.24815 .47116 m .25351 .45604 L .24608 .45566 L .657 .779 .939 r
F
.24815 .47116 m .27161 .46293 L .26673 .45981 L F
.24815 .47116 m .27487 .4666 L .27161 .46293 L F
.25002 .46941 m .24935 .47564 L .25053 .46953 L .807 .543 .539 r
F
.25359 .47765 m .2575 .47757 L .25748 .47756 L .656 .78 .94 r
F
.25275 .47183 m .2522 .47796 L .25275 .47196 L .796 .683 .137 r
F
.25275 .47154 m .2522 .47772 L .25275 .47183 L F
.2522 .47772 m .2522 .47796 L .25275 .47183 L F
.24801 .47777 m .2536 .47765 L .25359 .47765 L .656 .78 .94 r
F
.2536 .47765 m .2575 .47757 L .25359 .47765 L F
.25132 .46988 m .25064 .47608 L .25184 .47017 L .896 .63 .527 r
F
.25403 .47675 m .27619 .47715 L .25798 .47607 L .656 .78 .94 r
F
.25263 .47106 m .25196 .47715 L .25275 .47122 L .991 .745 .452 r
F
.25196 .47715 m .25205 .47728 L .25275 .47122 L F
.25175 .47686 m .25196 .47715 L .25263 .47106 L F
.25275 .47154 m .25275 .47122 L .2522 .47747 L .796 .683 .137 r
F
.2526 .47223 m .25267 .4721 L .25241 .47508 L 0 0 .268 r
F
.25275 .47122 m .25205 .47728 L .2522 .47747 L .991 .745 .452 r
F
.24801 .47777 m .25359 .47765 L .25242 .47702 L .656 .78 .94 r
F
.25077 .47954 m .24903 .50315 L .25044 .47967 L .487 .263 .5 r
F
.25044 .47967 m .24903 .50315 L .25029 .47973 L F
.25007 .47982 m .24903 .50315 L .24795 .50359 L F
.25029 .47973 m .24903 .50315 L .25007 .47982 L F
.24947 .47991 m .25007 .47982 L .24795 .50359 L .636 .39 .528 r
F
.25207 .47029 m .25124 .47639 L .25152 .47654 L .896 .63 .527 r
F
.25064 .47608 m .25106 .4763 L .25184 .47017 L F
.25352 .47024 m .27228 .47064 L .25664 .46971 L .657 .779 .939 r
F
.25661 .47098 m .27228 .47064 L .25352 .47024 L F
.27228 .47064 m .27628 .47055 L .25664 .46971 L F
.25236 .47069 m .25207 .47029 L .25152 .47654 L .991 .745 .452 r
F
.25236 .47069 m .25152 .47654 L .25175 .47686 L F
.25236 .47069 m .25175 .47686 L .25263 .47106 L F
.25144 .47569 m .27152 .46956 L .26663 .46645 L .656 .78 .94 r
F
.25184 .47017 m .25106 .4763 L .25207 .47029 L .896 .63 .527 r
F
.24801 .47777 m .25152 .47654 L .25072 .47612 L .656 .78 .94 r
F
.26711 .47347 m .27523 .4754 L .27578 .47453 L .657 .779 .939 r
F
.25361 .47582 m .27478 .47322 L .27152 .46956 L .656 .78 .94 r
F
.25152 .47654 m .25403 .47675 L .25219 .47631 L F
.24801 .47777 m .25242 .47702 L .25152 .47654 L F
.25242 .47702 m .25403 .47675 L .25152 .47654 L F
.25132 .46988 m .25075 .46958 L .2502 .47584 L .896 .63 .527 r
F
.25132 .46988 m .2502 .47584 L .25064 .47608 L F
.25075 .46958 m .24993 .47577 L .2502 .47584 L .807 .543 .539 r
F
.25106 .4763 m .25124 .47639 L .25207 .47029 L .896 .63 .527 r
F
.24975 .47573 m .24993 .47577 L .25075 .46958 L .807 .543 .539 r
F
.24984 .47576 m .26663 .46645 L .26044 .46411 L .656 .78 .94 r
F
.24801 .47777 m .25091 .47601 L .24984 .47576 L F
.25091 .47601 m .26663 .46645 L .24984 .47576 L F
.25053 .46953 m .24975 .47573 L .25075 .46958 L .807 .543 .539 r
F
.24949 .46928 m .24866 .47552 L .24893 .47554 L .734 .476 .538 r
F
.25002 .46941 m .24949 .46928 L .24893 .47554 L .807 .543 .539 r
F
.25002 .46941 m .24893 .47554 L .24935 .47564 L F
.24935 .47564 m .24975 .47573 L .25053 .46953 L F
.24801 .47777 m .26044 .46411 L .25338 .46269 L .656 .78 .94 r
F
.24975 .47573 m .24685 .49878 L .24993 .47577 L .807 .543 .539 r
F
.25064 .47608 m .2502 .47584 L .24812 .49917 L .896 .63 .527 r
F
.2502 .47584 m .24685 .49878 L .24812 .49917 L .807 .543 .539 r
F
.24993 .47577 m .24685 .49878 L .2502 .47584 L F
.25219 .47631 m .25798 .47607 L .25361 .47582 L .656 .78 .94 r
F
.25403 .47675 m .25798 .47607 L .25219 .47631 L F
.25798 .47607 m .27478 .47322 L .25361 .47582 L F
.24927 .46927 m .24849 .47551 L .24949 .46928 L .734 .476 .538 r
F
.24849 .47551 m .24866 .47552 L .24949 .46928 L F
.24877 .46924 m .2481 .47549 L .24927 .46927 L F
.2481 .47549 m .24849 .47551 L .24927 .46927 L F
.24877 .46924 m .24769 .47547 L .2481 .47549 L F
.24857 .46923 m .24769 .47547 L .24877 .46924 L F
.24815 .47116 m .23879 .45635 L .23215 .45806 L .657 .779 .939 r
F
.24815 .47116 m .24608 .45566 L .23879 .45635 L F
.24857 .46923 m .24825 .46921 L .24769 .47547 L .734 .476 .538 r
F
.24755 .46928 m .24688 .47555 L .24804 .46923 L .656 .407 .53 r
F
.24688 .47555 m .24726 .47551 L .24804 .46923 L F
.24704 .46933 m .24623 .47566 L .24648 .47559 L .55 .315 .512 r
F
.24825 .46921 m .24743 .47549 L .24769 .47547 L .656 .407 .53 r
F
.24804 .46923 m .24726 .47551 L .24825 .46921 L F
.24171 .47701 m .24188 .47606 L .23753 .4765 L .656 .78 .94 r
F
.24467 .47061 m .24403 .47703 L .24475 .47044 L 0 0 .188 r
F
.24403 .47703 m .24409 .4769 L .24475 .47044 L F
.24475 .47044 m .24409 .4769 L .24418 .47669 L F
.24801 .47777 m .24344 .47649 L .24171 .47701 L .656 .78 .94 r
F
.24344 .47649 m .24188 .47606 L .24171 .47701 L F
.24636 .46953 m .24587 .46968 L .2453 .47594 L .55 .315 .512 r
F
.24522 .47012 m .24455 .47644 L .24567 .46982 L .329 .133 .455 r
F
.24455 .47644 m .2449 .47621 L .24567 .46982 L F
.24522 .47012 m .24475 .47044 L .24418 .47669 L F
.24522 .47012 m .24418 .47669 L .24455 .47644 L F
.24302 .47053 m .22033 .46776 L .24036 .47132 L .657 .779 .939 r
F
.24266 .47128 m .21998 .47176 L .24371 .47192 L F
.24188 .47606 m .22645 .46731 L .22241 .47061 L .656 .78 .94 r
F
.24684 .46939 m .24606 .47571 L .24704 .46933 L .55 .315 .512 r
F
.24801 .47777 m .24464 .47614 L .24344 .47649 L .656 .78 .94 r
F
.24636 .46953 m .2453 .47594 L .24569 .47582 L .55 .315 .512 r
F
.24567 .46982 m .2449 .47621 L .24587 .46968 L .329 .133 .455 r
F
.2449 .47621 m .24506 .4761 L .24587 .46968 L F
.24587 .46968 m .24506 .4761 L .2453 .47594 L F
.24309 .46974 m .2226 .46397 L .2395 .4701 L .657 .779 .939 r
F
.24801 .47777 m .23198 .46471 L .22645 .46731 L .656 .78 .94 r
F
.24606 .47571 m .24623 .47566 L .24704 .46933 L .55 .315 .512 r
F
.24755 .46928 m .24704 .46933 L .24648 .47559 L .656 .407 .53 r
F
.24755 .46928 m .24648 .47559 L .24688 .47555 L F
.24486 .46955 m .22662 .46066 L .24309 .46974 L .657 .779 .939 r
F
.24636 .46953 m .24569 .47582 L .24684 .46939 L .55 .315 .512 r
F
.24569 .47582 m .24606 .47571 L .24684 .46939 L F
.24302 .47053 m .24309 .46974 L .2395 .4701 L .657 .779 .939 r
F
.24443 .47011 m .24309 .46974 L .24302 .47053 L F
.24354 .47126 m .24302 .47053 L .24036 .47132 L F
.24437 .4707 m .24302 .47053 L .24354 .47126 L F
.24354 .47126 m .24266 .47128 L .2431 .47155 L F
.24354 .47126 m .2431 .47155 L .24371 .47192 L F
.24801 .47777 m .23863 .46301 L .23198 .46471 L .656 .78 .94 r
F
.24606 .47571 m .2432 .49909 L .24623 .47566 L .55 .315 .512 r
F
.24344 .47649 m .24403 .47584 L .24188 .47606 L .656 .78 .94 r
F
.24464 .47614 m .24403 .47584 L .24344 .47649 L F
.24403 .47584 m .22645 .46731 L .24188 .47606 L F
.24726 .47551 m .24743 .47549 L .24825 .46921 L .656 .407 .53 r
F
.24443 .47011 m .24486 .46955 L .24309 .46974 L .657 .779 .939 r
F
.2454 .46982 m .24486 .46955 L .24443 .47011 L F
.24801 .47777 m .24593 .46232 L .23863 .46301 L .656 .78 .94 r
F
.24688 .47555 m .24648 .47559 L .24439 .49874 L .656 .407 .53 r
F
.24569 .47582 m .2453 .47594 L .2432 .49909 L .55 .315 .512 r
F
.24726 .47551 m .24439 .49874 L .24743 .47549 L .656 .407 .53 r
F
.19554 .4736 m .17963 .48873 L .20231 .48075 L .657 .779 .938 r
F
.21998 .47176 m .19504 .48022 L .22154 .4757 L .657 .779 .939 r
F
.23753 .4765 m .22241 .47061 L .22015 .47439 L .656 .78 .94 r
F
.24188 .47606 m .22241 .47061 L .23753 .4765 L F
.2477 .47546 m .25338 .46269 L .24593 .46232 L F
.24801 .47777 m .24887 .47535 L .2477 .47546 L F
.24887 .47535 m .25338 .46269 L .2477 .47546 L F
.24688 .47555 m .24439 .49874 L .24726 .47551 L .656 .407 .53 r
F
.24849 .47551 m .24561 .49865 L .24866 .47552 L .734 .476 .538 r
F
.25106 .4763 m .24812 .49917 L .25124 .47639 L .896 .63 .527 r
F
.25072 .47612 m .25361 .47582 L .25144 .47569 L .656 .78 .94 r
F
.25152 .47654 m .25361 .47582 L .25072 .47612 L F
.25361 .47582 m .27152 .46956 L .25144 .47569 L F
.24893 .47554 m .24561 .49865 L .24685 .49878 L .734 .476 .538 r
F
.24866 .47552 m .24561 .49865 L .24893 .47554 L F
.25152 .47654 m .24812 .49917 L .24944 .5 L .896 .63 .527 r
F
.25124 .47639 m .24812 .49917 L .25152 .47654 L F
.25242 .47702 m .25748 .47756 L .25403 .47675 L .656 .78 .94 r
F
.25359 .47765 m .25748 .47756 L .25242 .47702 L F
.25748 .47756 m .27619 .47715 L .25403 .47675 L F
.24935 .47564 m .24893 .47554 L .24685 .49878 L .807 .543 .539 r
F
.25064 .47608 m .24812 .49917 L .25106 .4763 L .896 .63 .527 r
F
.24935 .47564 m .24685 .49878 L .24975 .47573 L .807 .543 .539 r
F
.25748 .47756 m .27619 .47716 L .27619 .47715 L .656 .78 .94 r
F
.2575 .47757 m .27619 .47716 L .25748 .47756 L F
.25798 .47607 m .27619 .47715 L .27478 .47322 L F
.2481 .47549 m .24561 .49865 L .24849 .47551 L .734 .476 .538 r
F
.2449 .47621 m .24207 .49988 L .24506 .4761 L .329 .133 .455 r
F
.24648 .47559 m .2432 .49909 L .24439 .49874 L .55 .315 .512 r
F
.24623 .47566 m .2432 .49909 L .24648 .47559 L F
.23844 .47798 m .23753 .4765 L .21979 .47838 L .656 .78 .94 r
F
.24171 .47701 m .23753 .4765 L .23844 .47798 L F
.22154 .4757 m .19504 .48022 L .20186 .48739 L .657 .779 .939 r
F
.23753 .4765 m .22015 .47439 L .2198 .47831 L .656 .78 .94 r
F
.23753 .4765 m .2198 .47831 L .21979 .47838 L F
.24769 .47547 m .24439 .49874 L .24561 .49865 L .656 .407 .53 r
F
.24743 .47549 m .24439 .49874 L .24769 .47547 L F
.2453 .47594 m .24207 .49988 L .2432 .49909 L .329 .133 .455 r
F
.24506 .4761 m .24207 .49988 L .2453 .47594 L F
.24074 .47901 m .23844 .47798 L .22724 .48131 L .656 .78 .94 r
F
.2424 .47789 m .23844 .47798 L .24074 .47901 L F
.23844 .47798 m .21979 .47838 L .22724 .48131 L F
.24569 .47582 m .2432 .49909 L .24606 .47571 L .55 .315 .512 r
F
.24455 .47644 m .24207 .49988 L .2449 .47621 L .329 .133 .455 r
F
.24376 .47765 m .24183 .50175 L .24164 .50092 L .952 .765 .308 r
F
.24389 .47814 m .24183 .50175 L .24376 .47765 L F
.2439 .47733 m .24376 .47765 L .24164 .50092 L 0 0 .188 r
F
.24293 .47955 m .24074 .47901 L .23672 .48171 L .656 .78 .94 r
F
.24336 .47856 m .24074 .47901 L .24293 .47955 L F
.24074 .47901 m .22135 .48231 L .23672 .48171 L F
.24455 .47644 m .24418 .47669 L .24207 .49988 L .329 .133 .455 r
F
.24389 .47814 m .24396 .47838 L .24183 .50175 L .952 .765 .308 r
F
.24403 .47703 m .24164 .50092 L .24409 .4769 L 0 0 .188 r
F
.2481 .47549 m .24769 .47547 L .24561 .49865 L .734 .476 .538 r
F
.25251 .47832 m .27569 .48113 L .25336 .47766 L .656 .78 .94 r
F
.25184 .47884 m .25222 .47895 L .25251 .47832 L F
.25222 .47895 m .27332 .48485 L .25348 .47843 L F
.2516 .47903 m .24973 .50257 L .25138 .4792 L .269 .086 .437 r
F
.25175 .47686 m .25152 .47654 L .24944 .5 L .991 .745 .452 r
F
.25196 .47863 m .25011 .50188 L .25191 .47871 L 0 0 .268 r
F
.2581 .48558 m .26374 .49059 L .25797 .48539 L .656 .78 .94 r
F
.25183 .47885 m .25011 .50188 L .24973 .50257 L 0 0 .268 r
F
.25191 .47871 m .25011 .50188 L .25183 .47885 L F
.25196 .47715 m .24944 .5 L .25205 .47728 L .991 .745 .452 r
F
.25175 .47686 m .24944 .5 L .25196 .47715 L F
.25482 .48108 m .26374 .49059 L .26924 .48807 L .656 .78 .94 r
F
.25797 .48539 m .26374 .49059 L .25482 .48108 L F
.25208 .47843 m .2522 .47821 L .25011 .50188 L 0 0 .268 r
F
.25104 .49079 m .25065 .49516 L .25196 .47863 L F
.25104 .49079 m .25196 .47863 L .25198 .47859 L F
.2522 .47772 m .2522 .47747 L .25011 .50106 L .796 .683 .137 r
F
.25225 .48445 m .2572 .49224 L .25224 .48313 L .656 .78 .94 r
F
.25208 .47843 m .25104 .49079 L .25198 .47859 L 0 0 .268 r
F
.2522 .47796 m .25011 .50106 L .2522 .47806 L .796 .683 .137 r
F
.25222 .48121 m .26206 .49101 L .25885 .48661 L .656 .78 .94 r
F
.25223 .4814 m .26206 .49101 L .25222 .48121 L F
.25104 .49079 m .25011 .50188 L .25065 .49516 L 0 0 .268 r
F
.2522 .47821 m .25011 .50106 L .25011 .50188 L .796 .683 .137 r
F
.2522 .47806 m .25011 .50106 L .2522 .47821 L F
.2522 .47772 m .25011 .50106 L .2522 .47796 L F
.25223 .48149 m .2572 .49224 L .26206 .49101 L .656 .78 .94 r
F
.25224 .48269 m .2572 .49224 L .25223 .48149 L F
.2522 .47747 m .24944 .5 L .25011 .50106 L .991 .745 .452 r
F
.25205 .47728 m .24944 .5 L .2522 .47747 L F
.25885 .48661 m .26206 .49101 L .26374 .49059 L .656 .78 .94 r
F
.24214 .48134 m .22964 .48894 L .2397 .48691 L F
.2439 .47733 m .24164 .50092 L .24403 .47703 L 0 0 .188 r
F
.2397 .48691 m .23579 .4912 L .23766 .49157 L .656 .78 .94 r
F
.24418 .47669 m .24164 .50092 L .24207 .49988 L 0 0 .188 r
F
.24409 .4769 m .24164 .50092 L .24418 .47669 L F
.50499 .49797 m .47664 .50239 L .50391 .50179 L .656 .78 .94 r
F
.58626 .50648 m .6121 .49447 L .58512 .4989 L .655 .781 .941 r
F
.5589 .50709 m .58626 .50648 L .58512 .4989 L F
.64683 .77025 m .64696 .76562 L .64102 .76143 L .931 .678 .533 r
F
0 g
.64696 .76562 m
.65034 .77026 L
s
.33363 .63616 m .33277 .62629 L .31683 .6283 L .659 .805 .953 r
F
.31353 .6454 m .30227 .63752 L .28994 .64303 L .659 .806 .954 r
F
.32328 .64282 m .30227 .63752 L .31353 .6454 L F
.48251 .37769 m .46163 .37854 L .461 .38668 L .476 .264 .512 r
F
0 g
.44469 .39882 m
.461 .38668 L
s
.48251 .37769 m .48308 .36953 L .46163 .37854 L .476 .264 .512 r
F
0 g
.44536 .39071 m
.46163 .37854 L
s
.81451 .38273 m .82127 .35825 L .82154 .3664 L 0 0 .354 r
F
.81475 .39088 m .81451 .38273 L .82154 .3664 L F
.78248 .37552 m .81451 .38273 L .82154 .3664 L .644 .736 .916 r
F
0 g
.80835 .38944 m
.81451 .38273 L
s
.35501 .64824 m .34955 .63706 L .34492 .64691 L .658 .806 .954 r
F
.35501 .64824 m .36476 .63909 L .34955 .63706 L F
.8018 .63451 m .79415 .62461 L .79151 .6345 L .655 .809 .957 r
F
.8018 .63451 m .80969 .62463 L .79415 .62461 L F
.77832 .76192 m .77947 .76924 L .78463 .76354 L .597 .767 .96 r
F
.77832 .76192 m .77004 .76682 L .77947 .76924 L F
0 g
.77947 .76924 m
.78993 .77049 L
s
.76305 .65281 m .7503 .64682 L .73915 .65351 L .654 .811 .959 r
F
.77226 .64918 m .7503 .64682 L .76305 .65281 L F
.60688 .38615 m .58672 .36681 L .5864 .37495 L .866 .6 .534 r
F
.60662 .39431 m .60688 .38615 L .5864 .37495 L F
0 g
.60688 .38615 m
.62191 .39997 L
s
.7503 .64682 m .73832 .64808 L .73915 .65351 L .437 .293 .587 r
F
0 g
.73146 .6609 m
.73915 .65351 L
s
.7503 .64682 m .74946 .64137 L .73832 .64808 L .437 .293 .587 r
F
0 g
.73065 .65548 m
.73832 .64808 L
s
.8008 .7705 m
.8065 .76983 L
s
.51589 .39354 m .50769 .3726 L .48251 .37769 L .642 .738 .918 r
F
.53368 .39304 m .50769 .3726 L .51589 .39354 L F
.22433 .38476 m .18769 .38247 L .22158 .38966 L .642 .739 .919 r
F
.55134 .3954 m .5347 .37181 L .53368 .39304 L .642 .738 .918 r
F
.55134 .3954 m .56151 .37542 L .5347 .37181 L F
.28771 .39313 m .31268 .37884 L .2838 .38788 L .642 .739 .919 r
F
.28771 .39313 m .32036 .38943 L .31268 .37884 L F
.47866 .49475 m .44933 .503 L .47664 .50239 L .656 .78 .94 r
F
.50499 .49797 m .47866 .49475 L .47664 .50239 L F
.5589 .50709 m .58512 .4989 L .55826 .50331 L .655 .781 .941 r
F
.76226 .76339 m .77002 .76219 L .77004 .76682 L .862 .609 .555 r
F
.76226 .76339 m .76225 .75876 L .77002 .76219 L F
.77311 .75497 m .77002 .76219 L .77829 .75728 L .598 .766 .96 r
F
.77311 .75497 m .76225 .75876 L .77002 .76219 L F
0 g
.77002 .76219 m
.77548 .7636 L
s
.34463 .64148 m .33304 .63159 L .3339 .64148 L .659 .806 .954 r
F
.34463 .64148 m .34925 .6316 L .33304 .63159 L F
.59178 .76749 m .58256 .76258 L .57562 .766 L .596 .768 .961 r
F
.59769 .76588 m .58256 .76258 L .59178 .76749 L F
.40119 .36382 m .40181 .38513 L .42837 .38437 L .643 .738 .918 r
F
.38319 .3614 m .40181 .38513 L .40119 .36382 L F
.38319 .3614 m .37512 .38158 L .40181 .38513 L F
.81113 .76465 m .82046 .75761 L .82053 .76223 L .532 .34 .566 r
F
.81119 .76927 m .81113 .76465 L .82053 .76223 L F
.80582 .75892 m .81113 .76465 L .82053 .76223 L .598 .766 .96 r
F
0 g
.80731 .7651 m
.81113 .76465 L
s
.6835 .35104 m .65026 .36043 L .68393 .35665 L .645 .736 .915 r
F
.6835 .35104 m .64919 .34924 L .65026 .36043 L F
.31221 .76116 m .31187 .76834 L .31813 .76345 L .593 .769 .963 r
F
.31221 .76116 m .30301 .76492 L .31187 .76834 L F
0 g
.31187 .76834 m
.32198 .77076 L
s
.45384 .37119 m .45449 .36309 L .47591 .35398 L .474 .261 .51 r
F
0 g
.44209 .36564 m
.45449 .36309 L
s
.63053 .7698 m .63278 .76262 L .62513 .76752 L .596 .768 .961 r
F
.63053 .7698 m .64089 .76606 L .63278 .76262 L F
.29652 .75607 m .30408 .75568 L .30354 .76029 L .906 .671 .572 r
F
.29652 .75607 m .29706 .75145 L .30408 .75568 L F
0 g
.30408 .75568 m
.30958 .75781 L
s
.83594 .6359 m .83498 .63048 L .82373 .62655 L .87 .588 .508 r
F
0 g
.83498 .63048 m
.84278 .63599 L
s
.35295 .7708 m .3617 .76377 L .36124 .7684 L .5 .3 .539 r
F
.34564 .7651 m .35295 .7708 L .36124 .7684 L .593 .769 .963 r
F
.33912 .76592 m .35295 .7708 L .34564 .7651 L F
0 g
.34321 .77203 m
.35295 .7708 L
s
.30871 .74903 m .29724 .75141 L .30421 .75562 L .595 .768 .962 r
F
.31073 .50821 m .32309 .49223 L .32308 .49877 L .333 .178 .516 r
F
.29014 .49822 m .31073 .50821 L .32308 .49877 L .656 .78 .94 r
F
.27919 .50318 m .31073 .50821 L .29014 .49822 L F
0 g
.29436 .51554 m
.31073 .50821 L
s
.22554 .37662 m .19431 .36441 L .18899 .37433 L .642 .738 .918 r
F
.23042 .37251 m .19431 .36441 L .22554 .37662 L F
.4205 .34677 m .45423 .3628 L .43704 .34332 L .644 .737 .916 r
F
.43704 .34332 m .45423 .3628 L .47555 .35374 L F
.78086 .63583 m .77805 .62662 L .76256 .63053 L .655 .809 .957 r
F
.79151 .6345 m .77805 .62662 L .78086 .63583 L F
.3617 .76377 m .36217 .75914 L .36843 .75571 L .339 .164 .492 r
F
0 g
.35389 .76156 m
.36217 .75914 L
s
.23175 .36449 m .20553 .34809 L .19591 .35642 L .643 .737 .917 r
F
.2384 .36148 m .20553 .34809 L .23175 .36449 L F
.28486 .37973 m .30196 .3612 L .27898 .37506 L .642 .738 .918 r
F
.28486 .37973 m .31368 .37067 L .30196 .3612 L F
.27994 .36701 m .28788 .34557 L .27254 .36327 L .643 .737 .917 r
F
.27994 .36701 m .30276 .35318 L .28788 .34557 L F
.19431 .36441 m .15497 .36709 L .18899 .37433 L .642 .738 .918 r
F
.58235 .76722 m .57562 .766 L .57541 .77063 L .386 .214 .523 r
F
.58235 .76722 m .58256 .76258 L .57562 .766 L F
0 g
.57108 .77016 m
.57562 .766 L
s
.59794 .76132 m .59172 .7556 L .5829 .75802 L .597 .767 .961 r
F
.60467 .76049 m .59172 .7556 L .59794 .76132 L F
.79151 .6345 m .79415 .62461 L .77805 .62662 L .655 .809 .957 r
F
.77139 .64374 m .7633 .63585 L .74946 .64137 L .655 .81 .958 r
F
.78171 .64116 m .7633 .63585 L .77139 .64374 L F
.37754 .63756 m .36412 .62822 L .36444 .63365 L .851 .592 .547 r
F
.37788 .64298 m .37754 .63756 L .36444 .63365 L F
0 g
.37754 .63756 m
.38763 .64303 L
s
.47866 .49475 m .45217 .4915 L .44933 .503 L .656 .78 .94 r
F
.62521 .76294 m .62316 .75562 L .6188 .76133 L .597 .767 .961 r
F
.62521 .76294 m .63281 .75805 L .62316 .75562 L F
.45199 .49801 m .44892 .50301 L .44913 .50954 L 0 0 .252 r
F
0 g
.44983 .50672 m
.45052 .50951 L
s
.45199 .49801 m .45177 .49145 L .44892 .50301 L 0 0 .252 r
F
.61409 .51239 m .6121 .49447 L .6126 .50103 L .761 .569 0 r
F
.58671 .51301 m .61409 .51239 L .6126 .50103 L .655 .782 .942 r
F
0 g
.61001 .5237 m
.61409 .51239 L
s
.53368 .39304 m .5347 .37181 L .50769 .3726 L .642 .738 .918 r
F
.64683 .77025 m .64102 .76143 L .64089 .76606 L .931 .678 .533 r
F
.6467 .77488 m .64683 .77025 L .64089 .76606 L F
0 g
.64683 .77025 m
.65022 .77488 L
s
.32134 .38127 m .34286 .36149 L .31368 .37067 L .642 .738 .918 r
F
.81297 .64659 m .81167 .63538 L .8037 .64526 L .654 .811 .959 r
F
.81297 .64659 m .82563 .63742 L .81167 .63538 L F
.32328 .64282 m .31699 .63361 L .30227 .63752 L .659 .806 .954 r
F
.3339 .64148 m .31699 .63361 L .32328 .64282 L F
.31378 .65082 m .30251 .64298 L .29016 .64847 L .658 .806 .954 r
F
.32355 .64825 m .30251 .64298 L .31378 .65082 L F
.55772 .49681 m .5796 .48538 L .55526 .49332 L .656 .78 .94 r
F
.55772 .49681 m .58441 .49241 L .5796 .48538 L F
.3339 .64148 m .33304 .63159 L .31699 .63361 L .659 .806 .954 r
F
.17878 .50195 m .19389 .50428 L .19366 .51082 L .909 .654 .541 r
F
.17878 .50195 m .17904 .49539 L .19389 .50428 L F
.20186 .48739 m .19389 .50428 L .21173 .49339 L .657 .779 .939 r
F
.20186 .48739 m .17904 .49539 L .19389 .50428 L F
0 g
.19389 .50428 m
.2005 .50666 L
s
.19591 .35642 m .16454 .3441 L .15686 .3591 L .643 .737 .917 r
F
.80279 .63983 m .7951 .62991 L .79243 .63982 L .655 .81 .958 r
F
.80279 .63983 m .81074 .62993 L .7951 .62991 L F
.16269 .35205 m .15635 .35899 L .15497 .36709 L 0 0 .16 r
F
0 g
.15602 .36702 m
.15611 .36487 L
s
.16269 .35205 m .16407 .34391 L .15635 .35899 L 0 0 .16 r
F
.50517 .50449 m .47662 .50893 L .50408 .50831 L .655 .781 .941 r
F
.58671 .51301 m .6126 .50103 L .58557 .50545 L .655 .782 .942 r
F
.5593 .51362 m .58671 .51301 L .58557 .50545 L F
.77312 .75961 m .77004 .76682 L .77832 .76192 L .597 .767 .96 r
F
.77312 .75961 m .76226 .76339 L .77004 .76682 L F
0 g
.77004 .76682 m
.77947 .76924 L
s
.75666 .75453 m .76225 .75414 L .76225 .75876 L .941 .68 .514 r
F
.75666 .75453 m .75666 .7499 L .76225 .75414 L F
0 g
.76225 .75414 m
.76808 .75673 L
s
.59159 .77212 m .58235 .76722 L .57541 .77063 L .595 .768 .962 r
F
0 g
.57086 .77477 m
.57541 .77063 L
s
.5975 .77052 m .58235 .76722 L .59159 .77212 L .595 .768 .962 r
F
.81119 .76927 m .82053 .76223 L .8206 .76687 L .532 .34 .566 r
F
.80587 .76356 m .81119 .76927 L .8206 .76687 L .597 .767 .96 r
F
0 g
.8065 .76983 m
.81119 .76927 L
s
.7695 .74747 m .76241 .75408 L .7732 .7503 L .599 .766 .959 r
F
.7695 .74747 m .75685 .74986 L .76241 .75408 L F
.36624 .35619 m .37512 .38158 L .38319 .3614 L .643 .738 .918 r
F
0 g
.35385 .37511 m
.37512 .38158 L
s
.37512 .38158 m
.40181 .38513 L
s
.63038 .77443 m .63263 .76727 L .62497 .77216 L .595 .768 .962 r
F
.63038 .77443 m .64075 .77071 L .63263 .76727 L F
.82053 .76223 m .82046 .75761 L .82817 .75416 L .426 .258 .549 r
F
0 g
.81107 .76003 m
.82046 .75761 L
s
.29598 .76071 m .30354 .76029 L .30301 .76492 L .906 .671 .572 r
F
.29598 .76071 m .29652 .75607 L .30354 .76029 L F
.30806 .75369 m .30354 .76029 L .31274 .75652 L .594 .768 .963 r
F
.30806 .75369 m .29652 .75607 L .30354 .76029 L F
0 g
.30354 .76029 m
.30908 .76244 L
s
.42837 .38437 m .45384 .37119 L .45319 .37934 L .583 .353 .533 r
F
.41911 .36329 m .42837 .38437 L .45319 .37934 L .643 .738 .918 r
F
.40119 .36382 m .42837 .38437 L .41911 .36329 L F
0 g
.40181 .38513 m
.42837 .38437 L
s
.71547 .27411 m
.71921 .33115 L
s
.34492 .64691 m .33331 .63705 L .33418 .64691 L .658 .806 .954 r
F
.34492 .64691 m .34955 .63706 L .33331 .63705 L F
.3617 .76377 m .36843 .75571 L .36797 .76034 L .339 .164 .492 r
F
.36124 .7684 m .3617 .76377 L .36797 .76034 L F
.35165 .75884 m .3617 .76377 L .36797 .76034 L .594 .768 .963 r
F
.34612 .76046 m .3617 .76377 L .35165 .75884 L F
0 g
.35342 .76617 m
.3617 .76377 L
s
.60467 .76049 m .60186 .75435 L .59172 .7556 L .597 .767 .961 r
F
.61179 .76049 m .60186 .75435 L .60467 .76049 L F
0 g
.70849 .27398 m
.71212 .33136 L
s
.6188 .76133 m .61259 .75435 L .61179 .76049 L .597 .767 .961 r
F
.6188 .76133 m .62316 .75562 L .61259 .75435 L F
.83594 .6359 m .82373 .62655 L .82468 .63198 L .87 .588 .508 r
F
.8369 .64132 m .83594 .6359 L .82468 .63198 L F
0 g
.83594 .6359 m
.84375 .64139 L
s
.59769 .76588 m .59143 .76015 L .58256 .76258 L .596 .768 .961 r
F
.60446 .76506 m .59143 .76015 L .59769 .76588 L F
.47866 .50126 m .44913 .50954 L .47662 .50893 L .655 .781 .941 r
F
.50517 .50449 m .47866 .50126 L .47662 .50893 L F
.5593 .51362 m .58557 .50545 L .55866 .50986 L .655 .782 .942 r
F
.78171 .64116 m .77889 .63193 L .7633 .63585 L .655 .81 .958 r
F
.79243 .63982 m .77889 .63193 L .78171 .64116 L F
.62513 .76752 m .62306 .76018 L .61868 .76591 L .596 .768 .961 r
F
.62513 .76752 m .63278 .76262 L .62306 .76018 L F
.30227 .63752 m .28972 .6376 L .28994 .64303 L .506 .325 .569 r
F
.30227 .63752 m .30204 .63208 L .28972 .6376 L F
0 g
.28065 .64431 m
.28972 .6376 L
s
.64852 .3655 m .61582 .38045 L .6496 .3767 L .643 .737 .917 r
F
.64852 .3655 m .61387 .36369 L .61582 .38045 L F
0 g
.61582 .38045 m
.62457 .39615 L
s
.6467 .77488 m .64089 .76606 L .64075 .77071 L .931 .678 .533 r
F
0 g
.6467 .77488 m
.65009 .7795 L
s
.61179 .76049 m .61259 .75435 L .60186 .75435 L .597 .767 .961 r
F
.77226 .64918 m .76417 .64131 L .7503 .64682 L .654 .811 .959 r
F
.7826 .6466 m .76417 .64131 L .77226 .64918 L F
.37788 .64298 m .36444 .63365 L .36476 .63909 L .851 .592 .547 r
F
0 g
.37788 .64298 m
.38798 .64844 L
s
.79243 .63982 m .7951 .62991 L .77889 .63193 L .655 .81 .958 r
F
.50787 .49436 m .47866 .49475 L .50499 .49797 L .656 .78 .94 r
F
.32355 .64825 m .31725 .63907 L .30251 .64298 L .658 .806 .954 r
F
.33418 .64691 m .31725 .63907 L .32355 .64825 L F
.81475 .39088 m .82154 .3664 L .8218 .37458 L 0 0 .354 r
F
.78265 .38367 m .81475 .39088 L .8218 .37458 L .643 .737 .917 r
F
0 g
.80135 .40542 m
.81475 .39088 L
s
.60662 .39431 m .5864 .37495 L .58608 .38312 L .866 .6 .534 r
F
0 g
.60662 .39431 m
.62168 .4081 L
s
.33418 .64691 m .33331 .63705 L .31725 .63907 L .658 .806 .954 r
F
.47866 .50126 m .45199 .49801 L .44913 .50954 L .655 .781 .941 r
F
.45221 .5046 m .44913 .50954 L .44935 .5161 L 0 0 .252 r
F
0 g
.45005 .51327 m
.45074 .51606 L
s
.45221 .5046 m .45199 .49801 L .44913 .50954 L 0 0 .252 r
F
.2384 .36148 m .21886 .34195 L .20553 .34809 L .643 .737 .917 r
F
.24638 .35979 m .21886 .34195 L .2384 .36148 L F
.27254 .36327 m .27078 .34034 L .26408 .36071 L F
.27254 .36327 m .28788 .34557 L .27078 .34034 L F
.75665 .75917 m .76225 .75876 L .76226 .76339 L .941 .68 .514 r
F
.75665 .75917 m .75666 .75453 L .76225 .75876 L F
.76939 .75214 m .76225 .75876 L .77311 .75497 L .598 .766 .96 r
F
.76939 .75214 m .75666 .75453 L .76225 .75876 L F
0 g
.76225 .75876 m
.76812 .76135 L
s
.59143 .76015 m .58276 .75795 L .58256 .76258 L .517 .32 .553 r
F
.59143 .76015 m .59163 .75552 L .58276 .75795 L F
0 g
.57583 .76138 m
.58276 .75795 L
s
.8037 .64526 m .79601 .63537 L .79334 .64526 L .654 .811 .959 r
F
.8037 .64526 m .81167 .63538 L .79601 .63537 L F
.82053 .76223 m .82817 .75416 L .82826 .7588 L .426 .258 .549 r
F
.8206 .76687 m .82053 .76223 L .82826 .7588 L F
.8121 .7573 m .82053 .76223 L .82826 .7588 L .598 .766 .96 r
F
.80582 .75892 m .82053 .76223 L .8121 .7573 L F
0 g
.81113 .76465 m
.82053 .76223 L
s
.30753 .75833 m .30301 .76492 L .31221 .76116 L .593 .769 .963 r
F
.30753 .75833 m .29598 .76071 L .30301 .76492 L F
0 g
.30301 .76492 m
.31187 .76834 L
s
.68325 .35915 m .64976 .36857 L .68368 .36478 L .644 .736 .916 r
F
.68325 .35915 m .64868 .35734 L .64976 .36857 L F
.64089 .76606 m .64102 .76143 L .63292 .75798 L .857 .609 .563 r
F
0 g
.64102 .76143 m
.64696 .76562 L
s
.55826 .50331 m .58029 .49185 L .55578 .49981 L .655 .781 .941 r
F
.55826 .50331 m .58512 .4989 L .58029 .49185 L F
.45384 .37119 m .47591 .35398 L .47532 .36211 L .474 .261 .51 r
F
.45319 .37934 m .45384 .37119 L .47532 .36211 L F
.43652 .35166 m .45384 .37119 L .47532 .36211 L .643 .737 .917 r
F
.41985 .35512 m .45384 .37119 L .43652 .35166 L F
0 g
.44133 .37375 m
.45384 .37119 L
s
.36124 .7684 m .36797 .76034 L .36752 .76498 L .339 .164 .492 r
F
.35117 .76348 m .36124 .7684 L .36752 .76498 L .593 .769 .963 r
F
.34564 .7651 m .36124 .7684 L .35117 .76348 L F
0 g
.35295 .7708 m
.36124 .7684 L
s
.20165 .49397 m .19366 .51082 L .21153 .49995 L .656 .78 .94 r
F
.20165 .49397 m .17878 .50195 L .19366 .51082 L F
0 g
.19366 .51082 m
.21197 .51738 L
s
.60446 .76506 m .60163 .7589 L .59143 .76015 L .596 .768 .961 r
F
.61162 .76506 m .60163 .7589 L .60446 .76506 L F
.78248 .37552 m .82154 .3664 L .78696 .36459 L .644 .736 .916 r
F
.61868 .76591 m .61243 .7589 L .61162 .76506 L .596 .768 .961 r
F
.61868 .76591 m .62306 .76018 L .61243 .7589 L F
.22433 .38476 m .19301 .37257 L .18769 .38247 L .642 .739 .919 r
F
.22922 .38066 m .19301 .37257 L .22433 .38476 L F
.32309 .49223 m .32309 .48571 L .33051 .47467 L .033 0 .419 r
F
0 g
.31482 .49209 m
.32309 .48571 L
s
.7633 .63585 m .74861 .63593 L .74946 .64137 L .537 .362 .591 r
F
.7633 .63585 m .76244 .63041 L .74861 .63593 L F
0 g
.7375 .64266 m
.74861 .63593 L
s
.23042 .37251 m .20399 .35606 L .19431 .36441 L .642 .738 .918 r
F
.23711 .3695 m .20399 .35606 L .23042 .37251 L F
.2838 .38788 m .30092 .36939 L .2779 .38321 L .642 .739 .919 r
F
.2838 .38788 m .31268 .37884 L .30092 .36939 L F
.50548 .51105 m .47688 .51548 L .50439 .51486 L .655 .782 .942 r
F
.5975 .77052 m .59124 .7648 L .58235 .76722 L .595 .768 .962 r
F
.60428 .7697 m .59124 .7648 L .5975 .77052 L F
.27898 .37506 m .28696 .35355 L .27152 .3713 L .642 .738 .918 r
F
.27898 .37506 m .30196 .3612 L .28696 .35355 L F
.8369 .64132 m .82468 .63198 L .82563 .63742 L .87 .588 .508 r
F
0 g
.8369 .64132 m
.84471 .64679 L
s
.62497 .77216 m .6229 .76483 L .61851 .77055 L .595 .768 .962 r
F
.62497 .77216 m .63263 .76727 L .6229 .76483 L F
.19301 .37257 m .15357 .37523 L .18769 .38247 L .642 .739 .919 r
F
.58441 .49241 m .60415 .47737 L .5796 .48538 L .656 .78 .94 r
F
.58441 .49241 m .6112 .488 L .60415 .47737 L F
.50821 .36442 m .48366 .36141 L .48308 .36953 L .583 .354 .534 r
F
.50821 .36442 m .50872 .35628 L .48366 .36141 L F
0 g
.46741 .36827 m
.48366 .36141 L
s
.52952 .624 m .52897 .61859 L .545 .61657 L .673 .454 .58 r
F
.51358 .62398 m .52897 .61859 L .52952 .624 L .733 .498 .572 r
F
.51358 .62398 m .51306 .61856 L .52897 .61859 L F
.61162 .76506 m .61243 .7589 L .60163 .7589 L .596 .768 .961 r
F
.52962 .6084 m .52898 .61844 L .54493 .61643 L .659 .806 .953 r
F
.52778 .53719 m .52784 .53798 L .52787 .58909 L .781 .623 .061 r
F
.51898 .60837 m .52898 .61844 L .52956 .60922 L .659 .806 .953 r
F
.51898 .60837 m .52956 .60922 L .52949 .6084 L F
.52864 .59819 m .52962 .6084 L .53026 .5982 L F
.5249 .59818 m .52947 .60808 L .52864 .59819 L F
.52947 .60808 m .52962 .6084 L .52864 .59819 L F
.5249 .59818 m .51898 .60837 L .52962 .6084 L F
.52949 .6084 m .52956 .60922 L .52962 .6084 L F
.53219 .60807 m .54493 .61643 L .54033 .60705 L F
.52962 .6084 m .53189 .60959 L .53219 .60807 L F
.53189 .60959 m .54493 .61643 L .53219 .60807 L F
.53026 .5982 m .52962 .6084 L .53219 .60807 L F
.53358 .60112 m .53219 .60807 L .54033 .60705 L F
.53026 .5982 m .53219 .60807 L .53358 .60112 L F
.53592 .53811 m .53606 .53732 L .53622 .58793 L 0 0 .15 r
F
.53565 .59752 m .54033 .60705 L .54664 .60539 L .659 .806 .953 r
F
.54437 .60158 m .54664 .60539 L .55042 .60441 L F
.53565 .59752 m .54664 .60539 L .54437 .60158 L F
.53026 .5982 m .54033 .60705 L .53565 .59752 L F
.53081 .60372 m .53016 .61394 L .54094 .61258 L .658 .806 .954 r
F
.53565 .59752 m .54437 .60158 L .54073 .59618 L .659 .806 .953 r
F
.54437 .60158 m .55042 .60441 L .54157 .59689 L F
.54437 .60158 m .54157 .59689 L .54073 .59618 L F
.53592 .53811 m .53622 .58793 L .53618 .58813 L 0 0 .15 r
F
.53592 .53811 m .53618 .58813 L .53609 .58861 L F
.53081 .60372 m .54094 .61258 L .53624 .60303 L .658 .806 .954 r
F
.52952 .624 m .545 .61657 L .54556 .62198 L .673 .454 .58 r
F
.53016 .61394 m .54556 .62198 L .54094 .61258 L .658 .806 .954 r
F
.53136 .6092 m .5415 .61803 L .5368 .60852 L .658 .807 .955 r
F
.53308 .59228 m .53026 .5982 L .53565 .59752 L .659 .806 .953 r
F
.53544 .53877 m .53592 .53811 L .53609 .58861 L .08 0 .418 r
F
.53433 .59075 m .53565 .59752 L .54073 .59618 L .659 .806 .953 r
F
.53466 .53932 m .53537 .58936 L .5348 .58973 L .358 .18 .498 r
F
.53353 .53974 m .53447 .58986 L .53366 .59018 L .517 .303 .528 r
F
.53179 .53994 m .53315 .59026 L .53188 .59047 L .641 .401 .54 r
F
.53542 .58988 m .54073 .59618 L .54516 .59428 L .659 .806 .953 r
F
.53179 .53994 m .53353 .53974 L .53366 .59018 L .641 .401 .54 r
F
.53179 .53994 m .53366 .59018 L .53315 .59026 L F
.53006 .53969 m .53179 .53994 L .53188 .59047 L .751 .491 .539 r
F
.53221 .59049 m .53043 .59552 L .53308 .59228 L .659 .806 .953 r
F
.53075 .59041 m .53043 .59552 L .53221 .59049 L F
.53043 .59552 m .53026 .5982 L .53308 .59228 L F
.53016 .61394 m .52952 .624 L .54556 .62198 L .658 .806 .954 r
F
.53136 .6092 m .53071 .61939 L .5415 .61803 L .658 .807 .955 r
F
.53466 .53932 m .53544 .53877 L .5356 .58921 L .358 .18 .498 r
F
.5343 .59007 m .54073 .59618 L .53542 .58988 L .659 .806 .953 r
F
.53387 .59035 m .54073 .59618 L .5343 .59007 L F
.53336 .59718 m .53081 .60372 L .53624 .60303 L .658 .806 .954 r
F
.53353 .53974 m .53466 .53932 L .5348 .58973 L .517 .303 .528 r
F
.53353 .53974 m .5348 .58973 L .53447 .58986 L F
.53006 .53969 m .53188 .59047 L .53138 .59045 L .751 .491 .539 r
F
.53191 .59895 m .53081 .60372 L .53336 .59718 L .658 .806 .954 r
F
.53189 .5957 m .53081 .60372 L .53265 .59574 L F
.53132 .59567 m .53131 .5958 L .53189 .5957 L F
.53131 .5958 m .53081 .60372 L .53189 .5957 L F
.53265 .59574 m .53191 .59895 L .53336 .59718 L F
.53405 .5911 m .53565 .59752 L .53433 .59075 L .659 .806 .953 r
F
.53373 .59044 m .53565 .59752 L .53387 .59035 L F
.53217 .59042 m .53565 .59752 L .53366 .59018 L F
.53552 .59676 m .53624 .60303 L .54135 .60169 L .658 .806 .954 r
F
.53445 .59586 m .53514 .59863 L .53552 .59676 L F
.53514 .59863 m .53624 .60303 L .53552 .59676 L F
.53421 .59615 m .53506 .59904 L .53445 .59586 L F
.53506 .59904 m .53624 .60303 L .53514 .59863 L F
.53506 .59904 m .53514 .59863 L .53445 .59586 L F
.54525 .59116 m .54516 .59428 L .54862 .59193 L .659 .806 .953 r
F
.53006 .53969 m .53138 .59045 L .53013 .59038 L .751 .491 .539 r
F
.53466 .53932 m .5356 .58921 L .53537 .58936 L .358 .18 .498 r
F
.53544 .53877 m .53595 .58878 L .5356 .58921 L .08 0 .418 r
F
.53091 .58784 m .53734 .59075 L .54356 .59107 L .659 .806 .953 r
F
.53091 .58784 m .54356 .59107 L .54245 .59051 L F
.53289 .59623 m .53336 .59718 L .53401 .59549 L .658 .806 .954 r
F
.53336 .59718 m .53624 .60303 L .53421 .59615 L F
.53336 .59718 m .53421 .59615 L .53401 .59549 L F
.53544 .53877 m .53609 .58861 L .53595 .58878 L .08 0 .418 r
F
.53825 .58838 m .54862 .59193 L .5509 .5893 L .659 .806 .953 r
F
.53091 .58784 m .54245 .59051 L .53825 .58838 L F
.54245 .59051 m .54862 .59193 L .53825 .58838 L F
.53557 .5363 m .53441 .5355 L .53455 .58651 L .911 .629 .497 r
F
.53581 .59529 m .54135 .60169 L .53814 .59634 L .658 .806 .954 r
F
.53552 .59676 m .54135 .60169 L .53581 .59529 L F
.54135 .60169 m .54135 .60169 L .54135 .60169 L F
.54135 .60169 m .54135 .60169 L .53581 .59529 L F
.53595 .58878 m .53609 .58861 L .5361 .59384 L .08 0 .418 r
F
.53595 .58878 m .5361 .59384 L .536 .59397 L F
.53606 .53732 m .53587 .58734 L .53622 .58793 L .983 .725 .332 r
F
.53901 .58735 m .5509 .5893 L .55182 .58656 L .659 .806 .953 r
F
.53091 .58784 m .54843 .58912 L .53901 .58735 L F
.54843 .58912 m .5509 .5893 L .53901 .58735 L F
.53492 .59489 m .53552 .59676 L .53581 .59529 L .658 .806 .954 r
F
.53188 .59047 m .53234 .59562 L .53189 .5957 L .641 .401 .54 r
F
.53091 .58784 m .53366 .59018 L .53366 .59018 L .659 .806 .953 r
F
.53496 .58967 m .53366 .59018 L .53542 .58988 L F
.53091 .58784 m .53366 .59018 L .53496 .58967 L F
.53447 .58986 m .5348 .58973 L .53482 .59496 L .517 .303 .528 r
F
.53401 .59549 m .53552 .59676 L .53493 .59492 L .658 .806 .954 r
F
.53482 .59496 m .53493 .59492 L .53492 .59489 L F
.53401 .59549 m .53493 .59492 L .53482 .59496 L F
.53366 .59018 m .53387 .59035 L .5343 .59007 L .659 .806 .953 r
F
.53387 .59035 m .53405 .5911 L .53433 .59075 L F
.53366 .59018 m .53373 .59044 L .53387 .59035 L F
.53447 .58986 m .53457 .59506 L .53366 .59018 L .517 .303 .528 r
F
.53383 .59534 m .53401 .59549 L .53482 .59496 L .658 .806 .954 r
F
.53497 .6048 m .53415 .60885 L .5368 .60852 L .658 .807 .955 r
F
.53363 .6021 m .53415 .60885 L .53497 .6048 L F
.53401 .59549 m .53421 .59615 L .53445 .59586 L .658 .806 .954 r
F
.53138 .59045 m .53188 .59047 L .53189 .5957 L .751 .491 .539 r
F
.53138 .59045 m .53189 .5957 L .53152 .59568 L F
.53387 .59537 m .53289 .59623 L .53401 .59549 L .658 .806 .954 r
F
.53315 .59026 m .53366 .59018 L .53367 .5954 L .641 .401 .54 r
F
.53315 .59026 m .53367 .5954 L .53329 .59547 L F
.53257 .59559 m .53289 .59623 L .53387 .59537 L .658 .806 .954 r
F
.53363 .6021 m .53136 .6092 L .53415 .60885 L .658 .807 .955 r
F
.53366 .59018 m .53396 .59529 L .53367 .5954 L .517 .303 .528 r
F
.53457 .59506 m .53396 .59529 L .53366 .59018 L F
.53447 .58986 m .53482 .59496 L .53457 .59506 L F
.53537 .58936 m .5355 .59451 L .53544 .59455 L .358 .18 .498 r
F
.54073 .59618 m .55042 .60441 L .55924 .60064 L .659 .806 .953 r
F
.54073 .59618 m .55924 .60064 L .54516 .59428 L F
.53599 .59438 m .5458 .59978 L .54929 .59743 L .658 .806 .954 r
F
.5356 .58921 m .53574 .59429 L .53561 .59444 L .08 0 .418 r
F
.53537 .58936 m .5356 .58921 L .53561 .59444 L .358 .18 .498 r
F
.53537 .58936 m .53561 .59444 L .5355 .59451 L F
.54033 .60705 m .54493 .61643 L .55998 .61251 L .659 .806 .953 r
F
.54033 .60705 m .55998 .61251 L .55042 .60441 L F
.53624 .60303 m .54094 .61258 L .5511 .60993 L .658 .806 .954 r
F
.53624 .60303 m .5511 .60993 L .54135 .60169 L F
.53555 .60189 m .5368 .60852 L .54158 .60727 L .658 .807 .955 r
F
.53455 .601 m .53526 .60337 L .53555 .60189 L F
.53526 .60337 m .5368 .60852 L .53555 .60189 L F
.53581 .59529 m .53814 .59634 L .53599 .59438 L .658 .806 .954 r
F
.53814 .59634 m .5458 .59978 L .53745 .59518 L F
.53814 .59634 m .53745 .59518 L .53599 .59438 L F
.53557 .5363 m .53488 .58668 L .53573 .5871 L .911 .629 .497 r
F
.53606 .53732 m .53557 .5363 L .53573 .5871 L .983 .725 .332 r
F
.53606 .53732 m .53573 .5871 L .53587 .58734 L F
.53621 .58682 m .55182 .58656 L .55132 .5839 L .659 .806 .953 r
F
.53091 .58784 m .53901 .58735 L .53621 .58682 L F
.53901 .58735 m .55182 .58656 L .53621 .58682 L F
.53441 .5355 m .53322 .53514 L .53335 .58628 L .81 .54 .53 r
F
.5348 .58973 m .53502 .59483 L .53482 .59496 L .358 .18 .498 r
F
.53492 .59489 m .53581 .59529 L .53578 .59433 L .658 .806 .954 r
F
.53429 .60131 m .53516 .60382 L .53455 .601 L .658 .807 .955 r
F
.53516 .60382 m .5368 .60852 L .53526 .60337 L F
.53516 .60382 m .53526 .60337 L .53455 .601 L F
.54516 .59428 m .55924 .60064 L .56618 .59599 L .659 .806 .953 r
F
.54516 .59428 m .56618 .59599 L .54862 .59193 L F
.5367 .59372 m .54929 .59743 L .55158 .59479 L .658 .806 .954 r
F
.53537 .58936 m .53544 .59455 L .5348 .58973 L .358 .18 .498 r
F
.53544 .59455 m .53516 .59474 L .5348 .58973 L F
.53552 .59976 m .53524 .59994 L .53502 .59483 L F
.53516 .59474 m .53502 .59483 L .5348 .58973 L F
.53552 .59976 m .53502 .59483 L .53516 .59474 L F
.53734 .59075 m .54516 .59428 L .54525 .59116 L .659 .806 .953 r
F
.54862 .59193 m .56618 .59599 L .57079 .59076 L F
.53787 .59295 m .55158 .59479 L .55251 .59205 L .658 .806 .954 r
F
.53618 .58813 m .53622 .59326 L .53621 .59331 L 0 0 .15 r
F
.53618 .58813 m .53622 .58793 L .53624 .59316 L F
.53618 .58813 m .53624 .59316 L .53622 .59326 L F
.53618 .58813 m .53621 .59331 L .53609 .58861 L F
.53621 .59331 m .53614 .59367 L .53609 .58861 L F
.53622 .58793 m .53611 .59295 L .53624 .59316 L .983 .725 .332 r
F
.53441 .5355 m .53335 .58628 L .53368 .58634 L .81 .54 .53 r
F
.53441 .5355 m .53368 .58634 L .53455 .58651 L F
.53557 .5363 m .53455 .58651 L .53488 .58668 L .911 .629 .497 r
F
.53378 .58629 m .54942 .5815 L .54625 .57952 L .659 .806 .953 r
F
.53091 .58784 m .53538 .58631 L .53378 .58629 L F
.53538 .58631 m .54942 .5815 L .53378 .58629 L F
.53595 .58878 m .536 .59397 L .5356 .58921 L .08 0 .418 r
F
.536 .59397 m .53574 .59429 L .5356 .58921 L F
.53609 .58861 m .53614 .59367 L .5361 .59384 L 0 0 .15 r
F
.53315 .59026 m .53343 .60069 L .53188 .59047 L .641 .401 .54 r
F
.53297 .60077 m .53304 .6009 L .53368 .60065 L .658 .807 .955 r
F
.53329 .59547 m .53367 .5954 L .53368 .60065 L .641 .401 .54 r
F
.53304 .6009 m .53322 .60127 L .53392 .60061 L .658 .807 .955 r
F
.53304 .6009 m .53392 .60061 L .53368 .60065 L F
.53363 .6021 m .53497 .6048 L .53429 .60131 L F
.53497 .6048 m .5368 .60852 L .53516 .60382 L F
.53497 .6048 m .53516 .60382 L .53429 .60131 L F
.53343 .60069 m .5328 .60079 L .53234 .59562 L .641 .401 .54 r
F
.53266 .59557 m .53234 .59562 L .53188 .59047 L F
.53257 .59559 m .53189 .5957 L .53265 .59574 L .658 .806 .954 r
F
.53343 .60069 m .53234 .59562 L .53266 .59557 L .641 .401 .54 r
F
.52825 .53865 m .52898 .53923 L .52903 .59007 L .929 .648 .487 r
F
.53061 .59262 m .5249 .59818 L .53026 .5982 L .659 .806 .953 r
F
.53071 .59106 m .53004 .59188 L .53061 .59262 L F
.53004 .59188 m .5249 .59818 L .53061 .59262 L F
.52784 .53798 m .52825 .53865 L .52829 .58963 L .988 .719 .384 r
F
.53046 .59092 m .52988 .59168 L .53071 .59106 L .659 .806 .953 r
F
.52988 .59168 m .5249 .59818 L .53004 .59188 L F
.52988 .59168 m .53004 .59188 L .53071 .59106 L F
.52953 .59021 m .52947 .59033 L .53074 .59055 L F
.52947 .59033 m .5249 .59818 L .53046 .59092 L F
.52947 .59033 m .53046 .59092 L .53074 .59055 L F
.52542 .6037 m .53016 .61394 L .53081 .60372 L .658 .806 .954 r
F
.51898 .60837 m .51315 .61841 L .52898 .61844 L .659 .806 .953 r
F
.51946 .61391 m .52952 .624 L .53016 .61394 L .658 .806 .954 r
F
.52542 .6037 m .51946 .61391 L .53016 .61394 L F
.52597 .60919 m .53071 .61939 L .53136 .6092 L .658 .807 .955 r
F
.52825 .53865 m .52882 .58995 L .52829 .58963 L .929 .648 .487 r
F
.52825 .53865 m .52903 .59007 L .52882 .58995 L F
.52898 .53923 m .53006 .53969 L .53013 .59038 L .845 .571 .524 r
F
.52898 .53923 m .53013 .59038 L .52982 .59029 L F
.52784 .53798 m .52818 .58948 L .52787 .58909 L .988 .719 .384 r
F
.52784 .53798 m .52829 .58963 L .52818 .58948 L F
.52778 .53719 m .52786 .5889 L .52782 .58842 L .781 .623 .061 r
F
.52778 .53719 m .52787 .58909 L .52786 .5889 L F
.52837 .53619 m .52778 .53719 L .52782 .58842 L 0 0 .377 r
F
.52953 .59021 m .52363 .59467 L .5249 .59818 L .659 .806 .953 r
F
.52853 .58993 m .52436 .59359 L .52953 .59021 L F
.52436 .59359 m .51995 .59746 L .52363 .59467 L F
.52436 .59359 m .52363 .59467 L .52953 .59021 L F
.52898 .53923 m .52982 .59029 L .52903 .59007 L .845 .571 .524 r
F
.53091 .58784 m .51572 .59609 L .51995 .59746 L .659 .806 .953 r
F
.52818 .58948 m .52829 .58963 L .5283 .59487 L .988 .719 .384 r
F
.53114 .59852 m .52542 .6037 L .53081 .60372 L .658 .806 .954 r
F
.53043 .59761 m .52542 .6037 L .53114 .59852 L F
.52999 .59586 m .5296 .59654 L .53126 .59661 L F
.5296 .59654 m .52542 .6037 L .53043 .59761 L F
.5296 .59654 m .53043 .59761 L .53126 .59661 L F
.51995 .59746 m .51898 .60837 L .5249 .59818 L .659 .806 .953 r
F
.5296 .59654 m .52315 .60061 L .52542 .6037 L .658 .806 .954 r
F
.53014 .59561 m .52933 .59619 L .5296 .59654 L F
.53091 .58784 m .52361 .59035 L .51572 .59609 L .659 .806 .953 r
F
.52361 .59035 m .51252 .59415 L .51479 .59552 L F
.52361 .59035 m .51479 .59552 L .51572 .59609 L F
.52961 .53543 m .52837 .53619 L .52841 .58753 L .4 .211 .506 r
F
.52933 .59619 m .52811 .59707 L .5296 .59654 L .658 .806 .954 r
F
.52811 .59707 m .52814 .59746 L .5296 .59654 L F
.52918 .59534 m .52915 .59537 L .53014 .59561 L F
.52804 .59633 m .52315 .60061 L .52811 .59707 L F
.52811 .59707 m .52315 .60061 L .52814 .59746 L F
.52882 .58995 m .52903 .59007 L .52904 .5953 L .929 .648 .487 r
F
.52882 .58995 m .52904 .5953 L .52888 .59521 L F
.52903 .59007 m .52932 .59538 L .52904 .5953 L .845 .571 .524 r
F
.51995 .59746 m .50913 .60696 L .51898 .60837 L .659 .806 .953 r
F
.52315 .60061 m .51618 .60161 L .52043 .60298 L .658 .806 .954 r
F
.52363 .59467 m .52161 .5977 L .5249 .59818 L .659 .806 .953 r
F
.52982 .59029 m .52991 .59554 L .52903 .59007 L .845 .571 .524 r
F
.52915 .59537 m .52804 .59633 L .52988 .5958 L .658 .806 .954 r
F
.52804 .59633 m .52811 .59707 L .52988 .5958 L F
.52915 .59537 m .52988 .5958 L .53014 .59561 L F
.52804 .59633 m .52607 .59626 L .52315 .60061 L F
.52918 .59534 m .52799 .59569 L .52804 .59633 L F
.52799 .59569 m .52607 .59626 L .52804 .59633 L F
.52361 .59035 m .51055 .59178 L .51252 .59415 L .659 .806 .953 r
F
.53091 .58784 m .52639 .58872 L .52361 .59035 L F
.52639 .58872 m .51055 .59178 L .52361 .59035 L F
.52825 .59508 m .52607 .59626 L .52918 .59534 L .658 .806 .954 r
F
.52888 .59521 m .52904 .5953 L .52904 .60055 L .929 .648 .487 r
F
.53181 .60217 m .52597 .60919 L .53136 .6092 L .658 .807 .955 r
F
.52991 .59554 m .52932 .59538 L .52903 .59007 L .845 .571 .524 r
F
.52882 .58995 m .52888 .59521 L .52829 .58963 L .929 .648 .487 r
F
.52888 .59521 m .52849 .59498 L .52829 .58963 L F
.53059 .60304 m .52597 .60919 L .53083 .60335 L .658 .807 .955 r
F
.52888 .59521 m .52894 .60049 L .52849 .59498 L .929 .648 .487 r
F
.53052 .60142 m .52835 .60512 L .53135 .6019 L .658 .807 .955 r
F
.52835 .60512 m .52842 .60593 L .53142 .60194 L F
.53135 .6019 m .53142 .60194 L .53187 .60134 L F
.52835 .60512 m .53142 .60194 L .53135 .6019 L F
.52835 .60512 m .52597 .60919 L .52842 .60593 L F
.5313 .59594 m .52999 .59586 L .53126 .59661 L .658 .806 .954 r
F
.53074 .59055 m .53046 .59092 L .53071 .59106 L .659 .806 .953 r
F
.53138 .59045 m .53152 .59568 L .53013 .59038 L .751 .491 .539 r
F
.53132 .59567 m .53014 .59561 L .5313 .59594 L .658 .806 .954 r
F
.53014 .59561 m .52999 .59586 L .5313 .59594 L F
.53126 .59661 m .53043 .59761 L .53114 .59852 L F
.53152 .59568 m .53166 .60093 L .53089 .59565 L .751 .491 .539 r
F
.53152 .59568 m .53089 .59565 L .53013 .59038 L F
.53014 .59561 m .53014 .59561 L .53132 .59567 L .658 .806 .954 r
F
.53014 .59561 m .53166 .60093 L .53015 .60086 L .751 .491 .539 r
F
.53013 .59038 m .53089 .59565 L .53014 .59561 L F
.53014 .59561 m .53014 .59561 L .53014 .59561 L .658 .806 .954 r
F
.53089 .59565 m .53166 .60093 L .53014 .59561 L .751 .491 .539 r
F
.52982 .59029 m .53013 .59038 L .53014 .59561 L .845 .571 .524 r
F
.52982 .59029 m .53014 .59561 L .52998 .59557 L F
.52991 .59554 m .53015 .60086 L .52999 .60081 L F
.52982 .59029 m .52998 .59557 L .52991 .59554 L F
.52998 .59557 m .53015 .60086 L .52991 .59554 L F
.52837 .53619 m .52798 .58818 L .52841 .58753 L 0 0 .377 r
F
.52837 .53619 m .52782 .58842 L .52798 .58818 L F
.51729 .59048 m .50997 .58913 L .51055 .59178 L .659 .806 .953 r
F
.53091 .58784 m .52489 .58821 L .51729 .59048 L F
.52489 .58821 m .50997 .58913 L .51729 .59048 L F
.53082 .5351 m .52961 .53543 L .52967 .58679 L .567 .342 .533 r
F
.52818 .58948 m .52821 .59475 L .52787 .58909 L .988 .719 .384 r
F
.52821 .59475 m .52798 .59446 L .52787 .58909 L F
.52818 .58948 m .5283 .59487 L .52821 .59475 L F
.52829 .58963 m .52849 .59498 L .5283 .59487 L .929 .648 .487 r
F
.53147 .59334 m .52723 .59479 L .52825 .59508 L .658 .806 .954 r
F
.53147 .59334 m .52918 .59534 L .53014 .59561 L F
.52043 .60298 m .51946 .61391 L .52542 .6037 L F
.52835 .60512 m .52097 .60847 L .52597 .60919 L .658 .807 .955 r
F
.52825 .59508 m .52651 .5956 L .52607 .59626 L .658 .806 .954 r
F
.52363 .59467 m .51995 .59746 L .52161 .5977 L .659 .806 .953 r
F
.51572 .59609 m .50913 .60696 L .51995 .59746 L F
.51572 .59609 m .50069 .60425 L .50913 .60696 L F
.52723 .59479 m .51296 .59967 L .52825 .59508 L .658 .806 .954 r
F
.52786 .5889 m .52786 .59419 L .52782 .58842 L .781 .623 .061 r
F
.51252 .59415 m .50069 .60425 L .51572 .59609 L .659 .806 .953 r
F
.5279 .59456 m .51375 .59676 L .51296 .59967 L .658 .806 .954 r
F
.52786 .5889 m .52787 .58909 L .52788 .59432 L .781 .623 .061 r
F
.52786 .5889 m .52788 .59432 L .52786 .59419 L F
.52787 .58909 m .52798 .59446 L .52788 .59432 L .988 .719 .384 r
F
.53147 .59334 m .52785 .59404 L .5279 .59456 L .658 .806 .954 r
F
.52785 .59404 m .51375 .59676 L .5279 .59456 L F
.51375 .59676 m .51098 .59729 L .51117 .59752 L F
.51375 .59676 m .51117 .59752 L .51296 .59967 L F
.53091 .58784 m .52853 .58993 L .52953 .59021 L .659 .806 .953 r
F
.53091 .58784 m .52953 .59021 L .53074 .59055 L F
.52489 .58821 m .51081 .58638 L .50997 .58913 L F
.53091 .58784 m .52707 .58756 L .52489 .58821 L F
.52707 .58756 m .51081 .58638 L .52489 .58821 L F
.53001 .6023 m .52817 .60299 L .52835 .60512 L .658 .807 .955 r
F
.53075 .60103 m .52966 .60186 L .53001 .6023 L F
.52966 .60186 m .52817 .60299 L .53001 .6023 L F
.53147 .59334 m .53014 .59561 L .53014 .59561 L .658 .806 .954 r
F
.53147 .59334 m .53014 .59561 L .53132 .59567 L F
.52998 .59557 m .53014 .59561 L .53015 .60086 L .845 .571 .524 r
F
.52811 .60226 m .52195 .60762 L .52817 .60296 L .658 .807 .955 r
F
.52195 .60762 m .5218 .60784 L .52966 .60186 L F
.52966 .60185 m .52966 .60186 L .53075 .60103 L F
.52195 .60762 m .52966 .60186 L .52966 .60185 L F
.52817 .60299 m .52097 .60847 L .52835 .60512 L F
.52888 .59521 m .52904 .60055 L .52894 .60049 L .929 .648 .487 r
F
.52991 .59554 m .52999 .60081 L .52932 .59538 L .845 .571 .524 r
F
.52999 .60081 m .52961 .6007 L .52932 .59538 L F
.50913 .60696 m .51315 .61841 L .51898 .60837 L .659 .806 .953 r
F
.50913 .60696 m .49844 .61633 L .51315 .61841 L F
.52043 .60298 m .50954 .6125 L .51946 .61391 L .658 .806 .954 r
F
.52195 .60762 m .51672 .6071 L .52097 .60847 L .658 .807 .955 r
F
.51252 .59415 m .49425 .60042 L .50069 .60425 L .659 .806 .953 r
F
.51055 .59178 m .49425 .60042 L .51252 .59415 L F
.51375 .59676 m .51039 .59463 L .51098 .59729 L .658 .806 .954 r
F
.52786 .59419 m .52783 .59383 L .52782 .58842 L .781 .623 .061 r
F
.52782 .58842 m .52783 .59383 L .52782 .59366 L F
.52798 .58818 m .52782 .58842 L .52782 .59366 L 0 0 .377 r
F
.52798 .58818 m .52782 .59366 L .52794 .59347 L F
.53147 .59334 m .52696 .59362 L .52545 .5945 L .658 .806 .954 r
F
.52798 .59446 m .5281 .59985 L .52788 .59432 L .988 .719 .384 r
F
.52922 .60129 m .528 .60102 L .52811 .60226 L .658 .807 .955 r
F
.52891 .60089 m .528 .60102 L .52922 .60129 L F
.52894 .60052 m .528 .60102 L .5295 .60081 L F
.52904 .60055 m .5295 .60081 L .52983 .60077 L F
.52894 .60052 m .5295 .60081 L .52904 .60055 L F
.53147 .59334 m .52847 .59496 L .52918 .59534 L .658 .806 .954 r
F
.52847 .59496 m .52825 .59508 L .52904 .5953 L F
.52847 .59496 m .52904 .5953 L .52918 .59534 L F
.52849 .59498 m .52868 .60034 L .5283 .59487 L .929 .648 .487 r
F
.52983 .60077 m .52811 .60226 L .53075 .60103 L .658 .807 .955 r
F
.52811 .60226 m .52817 .60296 L .53075 .60103 L F
.52868 .60034 m .52856 .60026 L .5283 .59487 L .929 .648 .487 r
F
.52904 .5953 m .52942 .60065 L .52904 .60055 L .845 .571 .524 r
F
.5283 .59487 m .52856 .60026 L .5283 .60011 L .929 .648 .487 r
F
.52894 .60049 m .52868 .60034 L .52849 .59498 L F
.52932 .59538 m .52961 .6007 L .52904 .5953 L .845 .571 .524 r
F
.52983 .60077 m .52891 .60089 L .52922 .60129 L .658 .807 .955 r
F
.52961 .6007 m .53016 .61089 L .52942 .60065 L .845 .571 .524 r
F
.52961 .6007 m .52942 .60065 L .52904 .5953 L F
.52315 .60061 m .52043 .60298 L .52146 .60313 L .658 .806 .954 r
F
.52315 .60061 m .52146 .60313 L .52542 .6037 L F
.51618 .60161 m .50954 .6125 L .52043 .60298 L F
.52894 .60052 m .51991 .60298 L .51672 .6071 L .658 .807 .955 r
F
.53189 .5957 m .53251 .60084 L .5319 .60094 L .641 .401 .54 r
F
.53152 .59568 m .53189 .5957 L .5319 .60094 L .751 .491 .539 r
F
.53075 .60103 m .53052 .60142 L .53187 .60134 L .658 .807 .955 r
F
.53052 .60142 m .53135 .6019 L .53187 .60134 L F
.53142 .60194 m .53059 .60304 L .53181 .60217 L F
.53059 .60304 m .53083 .60335 L .53181 .60217 L F
.53187 .60134 m .53142 .60194 L .53181 .60217 L F
.53152 .59568 m .5319 .60094 L .53166 .60093 L .751 .491 .539 r
F
.53203 .59885 m .53075 .60103 L .53187 .60134 L .658 .807 .955 r
F
.53278 .60313 m .53136 .6092 L .53363 .6021 L F
.53301 .60141 m .53136 .6092 L .53322 .60127 L F
.53293 .60099 m .53136 .6092 L .53309 .601 L F
.53189 .60095 m .53136 .6092 L .53297 .60077 L F
.53166 .60093 m .5319 .60094 L .53192 .61114 L .751 .491 .539 r
F
.53203 .59885 m .52983 .60077 L .53015 .60086 L .658 .807 .955 r
F
.53083 .60089 m .53015 .60086 L .53075 .60103 L F
.53203 .59885 m .53015 .60086 L .53083 .60089 L F
.53203 .59885 m .52795 .60024 L .52894 .60052 L F
.52364 .59382 m .51124 .59188 L .51039 .59463 L .658 .806 .954 r
F
.52961 .53543 m .52841 .58753 L .52876 .58733 L .4 .211 .506 r
F
.53091 .58784 m .51304 .58372 L .51081 .58638 L .659 .806 .953 r
F
.52961 .53543 m .52876 .58733 L .52967 .58679 L .4 .211 .506 r
F
.53091 .58784 m .51649 .58133 L .51304 .58372 L .659 .806 .953 r
F
.53091 .58784 m .52095 .57939 L .51649 .58133 L F
.52876 .58733 m .52867 .59262 L .52967 .58679 L .4 .211 .506 r
F
.52798 .58818 m .52794 .59347 L .52841 .58753 L 0 0 .377 r
F
.52794 .59347 m .52826 .593 L .52841 .58753 L F
.53147 .59334 m .52788 .59308 L .52696 .59362 L .658 .806 .954 r
F
.52795 .60024 m .52662 .6007 L .52894 .60052 L .658 .807 .955 r
F
.52662 .6007 m .52624 .60125 L .52894 .60052 L F
.52868 .60034 m .52905 .61044 L .52856 .60026 L .929 .648 .487 r
F
.50069 .60425 m .49844 .61633 L .50913 .60696 L .659 .806 .953 r
F
.51618 .60161 m .50105 .60979 L .50954 .6125 L .658 .806 .954 r
F
.51296 .59967 m .50105 .60979 L .51618 .60161 L F
.51991 .60298 m .51151 .6028 L .51349 .60517 L .658 .807 .955 r
F
.5281 .59985 m .52803 .59976 L .52788 .59432 L .988 .719 .384 r
F
.52788 .59432 m .52803 .59976 L .52788 .59957 L F
.52821 .59475 m .52824 .60004 L .52798 .59446 L F
.52824 .60004 m .5281 .59985 L .52798 .59446 L F
.52821 .59475 m .5283 .59487 L .5283 .60011 L F
.52821 .59475 m .5283 .60011 L .52824 .60004 L F
.53203 .59885 m .52724 .59977 L .52662 .6007 L .658 .807 .955 r
F
.5283 .60011 m .52905 .61044 L .52831 .60988 L .929 .648 .487 r
F
.52842 .6018 m .52831 .60766 L .52843 .60746 L 0 0 .377 r
F
.52856 .60026 m .52905 .61044 L .5283 .60011 L .929 .648 .487 r
F
.52788 .59308 m .51348 .58921 L .51124 .59188 L .658 .806 .954 r
F
.53147 .59334 m .52857 .59268 L .52788 .59308 L F
.52876 .58733 m .52841 .58753 L .52842 .59277 L .4 .211 .506 r
F
.52876 .58733 m .52842 .59277 L .52867 .59262 L F
.52841 .58753 m .52826 .593 L .52842 .59277 L 0 0 .377 r
F
.52857 .59268 m .51348 .58921 L .52788 .59308 L .658 .806 .954 r
F
.52783 .59383 m .52785 .59925 L .52782 .59366 L .781 .623 .061 r
F
.52785 .59925 m .52784 .59914 L .52782 .59366 L F
.52782 .59366 m .52784 .59914 L .52782 .59891 L F
.52786 .59419 m .52788 .59432 L .52788 .59957 L F
.52786 .59419 m .52788 .59957 L .52787 .59948 L F
.52786 .59419 m .52787 .59948 L .52783 .59383 L F
.52787 .59948 m .52785 .59925 L .52783 .59383 L F
.53203 .59885 m .5264 .5992 L .52451 .6003 L .658 .807 .955 r
F
.52867 .59262 m .52934 .59222 L .52967 .58679 L .4 .211 .506 r
F
.52661 .59222 m .51696 .58682 L .51348 .58921 L .658 .806 .954 r
F
.53147 .59334 m .52845 .59198 L .52661 .59222 L F
.52845 .59198 m .51696 .58682 L .52661 .59222 L F
.53091 .58784 m .53075 .59041 L .53221 .59049 L .659 .806 .953 r
F
.53091 .58784 m .53217 .59042 L .53366 .59018 L F
.53203 .53501 m .53082 .5351 L .53091 .58642 L .66 .416 .54 r
F
.53203 .53501 m .53091 .58642 L .53102 .58641 L F
.53091 .58784 m .5318 .58631 L .531 .58641 L .659 .806 .953 r
F
.53322 .53514 m .53247 .58627 L .53335 .58628 L .734 .477 .539 r
F
.53322 .53514 m .53203 .53501 L .53213 .58626 L F
.53322 .53514 m .53213 .58626 L .53247 .58627 L F
.53091 .58784 m .5327 .58627 L .53213 .58626 L .659 .806 .953 r
F
.53203 .59885 m .52894 .60052 L .52983 .60077 L .658 .807 .955 r
F
.53147 .59334 m .53132 .59567 L .53189 .5957 L .658 .806 .954 r
F
.53147 .59334 m .53189 .5957 L .53257 .59559 L F
.53147 .59334 m .53578 .59433 L .5367 .59372 L F
.53329 .59547 m .53368 .60065 L .53343 .60069 L .641 .401 .54 r
F
.53367 .5954 m .53407 .6005 L .53368 .60065 L .517 .303 .528 r
F
.53322 .60127 m .53278 .60313 L .53363 .6021 L .658 .807 .955 r
F
.53234 .59562 m .5328 .60079 L .53189 .5957 L .641 .401 .54 r
F
.5328 .60079 m .53371 .61095 L .53251 .60084 L F
.5328 .60079 m .53251 .60084 L .53189 .5957 L F
.53541 .60036 m .54087 .60607 L .53817 .6016 L .658 .807 .955 r
F
.53578 .59433 m .54929 .59743 L .5367 .59372 L .658 .806 .954 r
F
.53619 .59874 m .53617 .59886 L .5361 .59384 L 0 0 .15 r
F
.53628 .59324 m .5367 .59372 L .53747 .59321 L .658 .806 .954 r
F
.53147 .59334 m .53657 .59371 L .53628 .59324 L F
.53657 .59371 m .5367 .59372 L .53628 .59324 L F
.53147 .59334 m .53747 .59321 L .53705 .593 L F
.536 .59397 m .5361 .59384 L .53612 .59909 L .08 0 .418 r
F
.53091 .58784 m .54625 .57952 L .54201 .5781 L .659 .806 .953 r
F
.53091 .58784 m .55132 .5839 L .54942 .5815 L F
.53368 .58634 m .53335 .58628 L .53336 .59152 L .81 .54 .53 r
F
.53694 .59294 m .54022 .5928 L .53983 .59273 L .658 .806 .954 r
F
.53147 .59334 m .53705 .593 L .53694 .59294 L F
.53705 .593 m .54022 .5928 L .53694 .59294 L F
.53587 .58734 m .53574 .59234 L .53585 .59251 L .983 .725 .332 r
F
.54862 .59193 m .57079 .59076 L .5509 .5893 L .659 .806 .953 r
F
.53719 .59224 m .55247 .59181 L .54037 .59162 L .658 .806 .954 r
F
.53587 .58734 m .53585 .59251 L .53622 .58793 L .983 .725 .332 r
F
.53585 .59251 m .53611 .59295 L .53622 .58793 L F
.53488 .58668 m .53481 .59187 L .53573 .5871 L .911 .629 .497 r
F
.53147 .59334 m .53694 .59294 L .536 .59247 L .658 .806 .954 r
F
.53502 .60043 m .5411 .60646 L .53541 .60036 L .658 .807 .955 r
F
.53432 .60054 m .53467 .60085 L .53502 .60043 L F
.53467 .60085 m .5411 .60646 L .53502 .60043 L F
.53147 .59334 m .53492 .59489 L .53561 .59444 L .658 .806 .954 r
F
.53571 .59432 m .53561 .59444 L .53578 .59433 L F
.53147 .59334 m .53561 .59444 L .53571 .59432 L F
.53574 .59429 m .53588 .59938 L .53561 .59444 L .08 0 .418 r
F
.5411 .60646 m .54087 .60607 L .53541 .60036 L .658 .807 .955 r
F
.53416 .60065 m .54192 .60718 L .53432 .60054 L F
.53416 .60065 m .54158 .60727 L .54113 .60651 L F
.53416 .60065 m .54158 .60727 L .53416 .60065 L F
.53502 .59483 m .53524 .59994 L .53482 .59496 L .358 .18 .498 r
F
.53524 .59994 m .5351 .60003 L .53482 .59496 L F
.53482 .59496 m .5351 .60003 L .53483 .60021 L F
.53481 .59187 m .53544 .59218 L .53573 .5871 L .911 .629 .497 r
F
.53573 .5871 m .53544 .59218 L .53574 .59234 L F
.53684 .59217 m .54037 .59162 L .53941 .59161 L .658 .806 .954 r
F
.53147 .59334 m .53719 .59224 L .53684 .59217 L F
.53719 .59224 m .54037 .59162 L .53684 .59217 L F
.53368 .58634 m .53361 .59156 L .53455 .58651 L .81 .54 .53 r
F
.54245 .59051 m .54356 .59107 L .54525 .59116 L .659 .806 .953 r
F
.5509 .5893 m .57271 .58529 L .55182 .58656 L F
.53665 .59157 m .55166 .58894 L .53978 .5905 L .658 .806 .954 r
F
.53587 .58734 m .53573 .5871 L .53574 .59234 L .983 .725 .332 r
F
.53147 .59334 m .53941 .59161 L .53665 .59157 L .658 .806 .954 r
F
.53941 .59161 m .55166 .58894 L .53665 .59157 L F
.53247 .58627 m .53239 .5915 L .53335 .58628 L .734 .477 .539 r
F
.53553 .59994 m .53817 .6016 L .53755 .60056 L .658 .807 .955 r
F
.53383 .59534 m .53367 .5954 L .53387 .59537 L .658 .806 .954 r
F
.53396 .59529 m .53426 .60043 L .53367 .5954 L .517 .303 .528 r
F
.53426 .60043 m .53407 .6005 L .53367 .5954 L F
.53457 .59506 m .53467 .60027 L .53396 .59529 L F
.53467 .60027 m .53426 .60043 L .53396 .59529 L F
.53495 .60016 m .53408 .60058 L .53541 .60036 L .658 .807 .955 r
F
.53457 .59506 m .53482 .59496 L .53483 .60021 L .517 .303 .528 r
F
.53457 .59506 m .53483 .60021 L .53467 .60027 L F
.53203 .59885 m .53401 .60052 L .53495 .60016 L .658 .807 .955 r
F
.53401 .60052 m .53408 .60058 L .53495 .60016 L F
.53467 .60027 m .53483 .60021 L .53486 .61053 L .517 .303 .528 r
F
.53467 .60027 m .53486 .61053 L .53426 .60043 L F
.53814 .59634 m .54135 .60169 L .5458 .59978 L .658 .806 .954 r
F
.54135 .60169 m .54135 .60169 L .53814 .59634 L F
.55042 .60441 m .55998 .61251 L .57315 .60692 L .659 .806 .953 r
F
.55042 .60441 m .57315 .60692 L .55924 .60064 L F
.54135 .60169 m .5511 .60993 L .55997 .60615 L .658 .806 .954 r
F
.54135 .60169 m .55997 .60615 L .5458 .59978 L F
.536 .59976 m .54839 .60392 L .5435 .60147 L .658 .807 .955 r
F
.53544 .59455 m .53552 .59976 L .53516 .59474 L .358 .18 .498 r
F
.53544 .59455 m .53563 .59968 L .53552 .59976 L F
.53203 .59885 m .53553 .59994 L .536 .59976 L .658 .807 .955 r
F
.53553 .59994 m .54839 .60392 L .536 .59976 L F
.53203 .59885 m .53495 .60016 L .53553 .59994 L F
.53495 .60016 m .53817 .6016 L .53553 .59994 L F
.53408 .60058 m .53416 .60065 L .53432 .60054 L F
.53363 .6021 m .53429 .60131 L .53408 .6007 L F
.53401 .60052 m .53416 .60065 L .53416 .60065 L F
.53401 .60052 m .53429 .60131 L .53455 .601 L F
.53426 .60043 m .53486 .61053 L .53407 .6005 L .517 .303 .528 r
F
.53203 .59885 m .53297 .60077 L .53401 .60052 L .658 .807 .955 r
F
.53147 .59334 m .53257 .59559 L .53367 .5954 L .658 .806 .954 r
F
.53147 .59334 m .53367 .5954 L .53383 .59534 L F
.53147 .59334 m .53383 .59534 L .53492 .59489 L F
.53239 .5915 m .53304 .59151 L .53335 .58628 L .734 .477 .539 r
F
.53361 .59156 m .53425 .59168 L .53455 .58651 L .81 .54 .53 r
F
.53335 .58628 m .53304 .59151 L .53336 .59152 L .734 .477 .539 r
F
.53091 .58784 m .53213 .58626 L .5318 .58631 L .659 .806 .953 r
F
.53125 .58638 m .53117 .59163 L .53213 .58626 L .66 .416 .54 r
F
.53117 .59163 m .53182 .59154 L .53213 .58626 L F
.53455 .58651 m .53425 .59168 L .53456 .59174 L .81 .54 .53 r
F
.53368 .58634 m .53336 .59152 L .53361 .59156 L F
.53247 .58627 m .53213 .58626 L .53214 .5915 L .734 .477 .539 r
F
.53247 .58627 m .53214 .5915 L .53239 .5915 L F
.53213 .58626 m .53182 .59154 L .53214 .5915 L .66 .416 .54 r
F
.53203 .53501 m .53125 .58638 L .53213 .58626 L F
.5318 .58631 m .53213 .58626 L .53183 .58626 L .659 .806 .953 r
F
.53183 .58626 m .54201 .5781 L .537 .57736 L F
.5327 .58627 m .54201 .5781 L .53183 .58626 L F
.53203 .53501 m .53102 .58641 L .53125 .58638 L .66 .416 .54 r
F
.531 .58641 m .537 .57736 L .53157 .57733 L .659 .806 .953 r
F
.5318 .58631 m .537 .57736 L .531 .58641 L F
.53488 .58668 m .53455 .58651 L .53456 .59174 L .911 .629 .497 r
F
.53488 .58668 m .53456 .59174 L .53481 .59187 L F
.53147 .59334 m .53761 .58282 L .53214 .5828 L .658 .806 .954 r
F
.53147 .59334 m .54265 .58357 L .53761 .58282 L F
.53147 .59334 m .54691 .58499 L .54265 .58357 L F
.53147 .59334 m .5501 .58697 L .54691 .58499 L F
.53239 .5915 m .53231 .59676 L .53304 .59151 L .734 .477 .539 r
F
.53203 .59885 m .53189 .60095 L .53297 .60077 L .658 .807 .955 r
F
.5319 .60094 m .53371 .61095 L .53192 .61114 L .641 .401 .54 r
F
.53251 .60084 m .53371 .61095 L .5319 .60094 L F
.53588 .59938 m .5358 .59948 L .53561 .59444 L .08 0 .418 r
F
.55924 .60064 m .57315 .60692 L .58359 .60001 L .659 .806 .953 r
F
.5458 .59978 m .55997 .60615 L .56696 .60149 L .658 .806 .954 r
F
.55924 .60064 m .58359 .60001 L .56618 .59599 L .659 .806 .953 r
F
.5458 .59978 m .56696 .60149 L .54929 .59743 L .658 .806 .954 r
F
.53932 .59937 m .54988 .60292 L .55217 .60029 L .658 .807 .955 r
F
.53561 .59444 m .5358 .59948 L .53563 .59968 L .08 0 .418 r
F
.53578 .59433 m .53581 .59529 L .53599 .59438 L .658 .806 .954 r
F
.536 .59397 m .53605 .59917 L .53574 .59429 L .08 0 .418 r
F
.53605 .59917 m .53588 .59938 L .53574 .59429 L F
.5355 .59451 m .53563 .59968 L .53544 .59455 L .358 .18 .498 r
F
.5355 .59451 m .53561 .59444 L .53563 .59968 L F
.536 .59397 m .53612 .59909 L .53605 .59917 L .08 0 .418 r
F
.53203 .59885 m .5435 .60147 L .53932 .59937 L .658 .807 .955 r
F
.5435 .60147 m .54988 .60292 L .53932 .59937 L F
.53524 .59994 m .53566 .60999 L .5351 .60003 L .358 .18 .498 r
F
.53563 .59968 m .53615 .60935 L .53566 .60999 L .08 0 .418 r
F
.5358 .59948 m .53615 .60935 L .53563 .59968 L F
.53483 .60021 m .53566 .60999 L .53486 .61053 L .358 .18 .498 r
F
.5351 .60003 m .53566 .60999 L .53483 .60021 L F
.53552 .59976 m .53566 .60999 L .53524 .59994 L F
.53552 .59976 m .53563 .59968 L .53566 .60999 L F
.53544 .59218 m .53515 .59728 L .53574 .59234 L .911 .629 .497 r
F
.53203 .59885 m .53932 .59937 L .5393 .59936 L .658 .807 .955 r
F
.53614 .59367 m .53619 .59874 L .5361 .59384 L 0 0 .15 r
F
.53759 .59851 m .55218 .60027 L .54143 .59827 L .658 .807 .955 r
F
.5361 .59384 m .53617 .59886 L .53612 .59909 L 0 0 .15 r
F
.53624 .59851 m .53619 .59874 L .53614 .59367 L F
.53203 .59885 m .5393 .59936 L .53759 .59851 L .658 .807 .955 r
F
.5393 .59936 m .55218 .60027 L .53759 .59851 L F
.53383 .59534 m .53482 .59496 L .53492 .59489 L .658 .806 .954 r
F
.53481 .59187 m .53456 .59174 L .53458 .597 L .911 .629 .497 r
F
.53621 .59331 m .53624 .59851 L .53614 .59367 L 0 0 .15 r
F
.53621 .59331 m .53626 .59841 L .53624 .59851 L F
.53203 .59885 m .54143 .59827 L .54061 .59812 L .658 .807 .955 r
F
.56618 .59599 m .58359 .60001 L .59057 .5922 L .659 .806 .953 r
F
.56618 .59599 m .59057 .5922 L .57079 .59076 L F
.54929 .59743 m .5716 .59624 L .55158 .59479 L .658 .806 .954 r
F
.53818 .59767 m .55301 .59706 L .54217 .5969 L .658 .807 .955 r
F
.536 .59799 m .53608 .59813 L .53624 .59316 L .983 .725 .332 r
F
.53622 .59326 m .53626 .59841 L .53621 .59331 L 0 0 .15 r
F
.53622 .59326 m .53624 .59316 L .53626 .59841 L F
.53624 .59316 m .53608 .59813 L .53626 .59841 L .983 .725 .332 r
F
.53203 .59885 m .54061 .59812 L .53818 .59767 L .658 .807 .955 r
F
.54061 .59812 m .55301 .59706 L .53818 .59767 L F
.53425 .59168 m .53395 .59688 L .53456 .59174 L .81 .54 .53 r
F
.53322 .60127 m .53363 .6021 L .53408 .6007 L .658 .807 .955 r
F
.53322 .60127 m .53408 .6007 L .53401 .60052 L F
.53343 .60069 m .53368 .60065 L .53371 .61095 L .641 .401 .54 r
F
.53368 .60065 m .53392 .60061 L .53401 .60052 L .658 .807 .955 r
F
.53309 .601 m .53301 .60141 L .53322 .60127 L F
.53297 .60077 m .53293 .60099 L .53309 .601 L F
.53343 .60069 m .53371 .61095 L .5328 .60079 L .641 .401 .54 r
F
.53297 .60077 m .53368 .60065 L .53401 .60052 L .658 .807 .955 r
F
.53368 .60065 m .53486 .61053 L .53371 .61095 L .517 .303 .528 r
F
.53407 .6005 m .53486 .61053 L .53368 .60065 L F
.53395 .59688 m .53415 .59692 L .53456 .59174 L .81 .54 .53 r
F
.53456 .59174 m .53415 .59692 L .53458 .597 L F
.53336 .59152 m .53294 .59677 L .53337 .59677 L .734 .477 .539 r
F
.53481 .59187 m .53458 .597 L .53474 .59708 L .911 .629 .497 r
F
.53515 .59728 m .53535 .59738 L .53574 .59234 L F
.53361 .59156 m .53353 .5968 L .53425 .59168 L .81 .54 .53 r
F
.53353 .5968 m .53395 .59688 L .53425 .59168 L F
.53574 .59234 m .53535 .59738 L .53576 .59759 L .911 .629 .497 r
F
.5509 .5893 m .57079 .59076 L .57271 .58529 L .659 .806 .953 r
F
.53941 .59161 m .55201 .58938 L .55166 .58894 L .658 .806 .954 r
F
.54037 .59162 m .55201 .58938 L .53941 .59161 L F
.53978 .5905 m .55166 .58894 L .5501 .58697 L F
.53585 .59251 m .53574 .59234 L .53576 .59759 L .983 .725 .332 r
F
.53585 .59251 m .53576 .59759 L .53583 .5977 L F
.53481 .59187 m .53474 .59708 L .53544 .59218 L .911 .629 .497 r
F
.53474 .59708 m .53515 .59728 L .53544 .59218 L F
.536 .59247 m .53983 .59273 L .53719 .59224 L .658 .806 .954 r
F
.53694 .59294 m .53983 .59273 L .536 .59247 L F
.53983 .59273 m .55247 .59181 L .53719 .59224 L F
.53361 .59156 m .53336 .59152 L .53337 .59677 L .81 .54 .53 r
F
.53203 .59885 m .5344 .59679 L .53325 .59677 L .658 .807 .955 r
F
.53983 .59273 m .55251 .59205 L .55247 .59181 L .658 .806 .954 r
F
.54022 .5928 m .55251 .59205 L .53983 .59273 L F
.54037 .59162 m .55247 .59181 L .55201 .58938 L F
.53611 .59295 m .536 .59799 L .53624 .59316 L .983 .725 .332 r
F
.5367 .59372 m .55158 .59479 L .53787 .59295 L .658 .806 .954 r
F
.53585 .59251 m .53583 .5977 L .53611 .59295 L .983 .725 .332 r
F
.53583 .5977 m .536 .59799 L .53611 .59295 L F
.5344 .59679 m .54749 .59052 L .54323 .58911 L .658 .807 .955 r
F
.53203 .59885 m .53582 .59681 L .5344 .59679 L F
.53582 .59681 m .54749 .59052 L .5344 .59679 L F
.53239 .5915 m .53214 .5915 L .53215 .59675 L .734 .477 .539 r
F
.53239 .5915 m .53215 .59675 L .53231 .59676 L F
.53361 .59156 m .53337 .59677 L .53353 .5968 L .81 .54 .53 r
F
.53304 .59151 m .53273 .59676 L .53336 .59152 L .734 .477 .539 r
F
.53273 .59676 m .53294 .59677 L .53336 .59152 L F
.53231 .59676 m .53273 .59676 L .53304 .59151 L F
.53216 .59675 m .53818 .58836 L .5327 .58834 L .658 .807 .955 r
F
.53203 .59885 m .53335 .5966 L .53216 .59675 L F
.53335 .5966 m .53818 .58836 L .53216 .59675 L F
.53015 .60086 m .53192 .61114 L .53016 .61089 L .751 .491 .539 r
F
.53166 .60093 m .53192 .61114 L .53015 .60086 L F
.52867 .59262 m .52842 .59277 L .52842 .59802 L .4 .211 .506 r
F
.52794 .59347 m .5279 .59879 L .52826 .593 L 0 0 .377 r
F
.5279 .59879 m .52811 .59848 L .52826 .593 L F
.52794 .59347 m .52782 .59366 L .52782 .59891 L F
.52794 .59347 m .52782 .59891 L .5279 .59879 L F
.53203 .59885 m .52754 .59853 L .5264 .5992 L .658 .807 .955 r
F
.52545 .5945 m .52364 .59382 L .51375 .59676 L .658 .806 .954 r
F
.52364 .59382 m .51039 .59463 L .51375 .59676 L F
.52607 .59626 m .51296 .59967 L .51618 .60161 L F
.52651 .5956 m .51296 .59967 L .52607 .59626 L F
.52175 .59812 m .51402 .59474 L .51178 .5974 L .658 .807 .955 r
F
.52842 .59277 m .52821 .59833 L .52842 .59802 L 0 0 .377 r
F
.52826 .593 m .52811 .59848 L .52842 .59277 L F
.52811 .59848 m .52821 .59833 L .52842 .59277 L F
.53203 .59885 m .52771 .59787 L .52587 .59841 L .658 .807 .955 r
F
.52904 .60055 m .53016 .61089 L .52905 .61044 L .845 .571 .524 r
F
.52942 .60065 m .53016 .61089 L .52904 .60055 L F
.53009 .60662 m .53015 .6066 L .53016 .61089 L F
.52999 .60081 m .53015 .6066 L .53009 .60662 L F
.52999 .60081 m .53015 .60086 L .53015 .6066 L F
.52999 .60081 m .53016 .61089 L .52961 .6007 L F
.52867 .59262 m .52842 .59802 L .52858 .59792 L .4 .211 .506 r
F
.52647 .59298 m .51124 .59188 L .52364 .59382 L .658 .806 .954 r
F
.52607 .59626 m .51618 .60161 L .52315 .60061 L F
.52623 .59753 m .5175 .59235 L .51402 .59474 L .658 .807 .955 r
F
.52967 .58679 m .52934 .59222 L .52968 .59203 L .4 .211 .506 r
F
.53082 .5351 m .53001 .58669 L .53091 .58642 L .567 .342 .533 r
F
.53082 .5351 m .52967 .58679 L .53001 .58669 L F
.53091 .58784 m .52609 .57802 L .52095 .57939 L .659 .806 .953 r
F
.53001 .58669 m .52967 .58679 L .52968 .59203 L .567 .342 .533 r
F
.53001 .58669 m .52968 .59203 L .52993 .59195 L F
.53147 .59334 m .52144 .58487 L .51696 .58682 L .658 .806 .954 r
F
.52934 .59222 m .52902 .59767 L .52968 .59203 L .4 .211 .506 r
F
.52902 .59767 m .52923 .59755 L .52968 .59203 L F
.52867 .59262 m .52858 .59792 L .52934 .59222 L F
.52858 .59792 m .52902 .59767 L .52934 .59222 L F
.53091 .58784 m .531 .58641 L .53025 .58651 L .659 .806 .953 r
F
.53001 .58669 m .52993 .59195 L .53091 .58642 L .567 .342 .533 r
F
.52993 .59195 m .53059 .59176 L .53091 .58642 L F
.53091 .58642 m .53059 .59176 L .53092 .59166 L F
.53147 .59334 m .52662 .5835 L .52144 .58487 L .658 .806 .954 r
F
.53125 .58638 m .53092 .59166 L .53117 .59163 L .66 .416 .54 r
F
.53102 .58641 m .53092 .59166 L .53125 .58638 L F
.53025 .58651 m .53157 .57733 L .52609 .57802 L .659 .806 .953 r
F
.531 .58641 m .53157 .57733 L .53025 .58651 L F
.53102 .58641 m .53091 .58642 L .53092 .59166 L .66 .416 .54 r
F
.53147 .59334 m .53214 .5828 L .52662 .5835 L .658 .806 .954 r
F
.53059 .59176 m .53027 .59711 L .53092 .59166 L .567 .342 .533 r
F
.53203 .59885 m .52898 .59749 L .52771 .59787 L .658 .807 .955 r
F
.52993 .59195 m .52984 .59723 L .53059 .59176 L .567 .342 .533 r
F
.52984 .59723 m .53027 .59711 L .53059 .59176 L F
.52696 .59362 m .52647 .59298 L .52364 .59382 L .658 .806 .954 r
F
.52968 .59203 m .52923 .59755 L .52968 .59728 L .4 .211 .506 r
F
.52696 .59362 m .52364 .59382 L .52545 .5945 L .658 .806 .954 r
F
.52898 .59749 m .52199 .59041 L .5175 .59235 L .658 .807 .955 r
F
.53203 .59885 m .53004 .59718 L .52898 .59749 L F
.52993 .59195 m .52968 .59203 L .52968 .59728 L .567 .342 .533 r
F
.52993 .59195 m .52968 .59728 L .52984 .59723 L F
.53004 .59718 m .52199 .59041 L .52898 .59749 L .658 .807 .955 r
F
.52984 .59723 m .52968 .59728 L .52969 .60672 L .567 .342 .533 r
F
.53027 .59711 m .53048 .59705 L .53092 .59166 L F
.53117 .59163 m .53092 .59166 L .53092 .59691 L .66 .416 .54 r
F
.53117 .59163 m .53092 .59691 L .53108 .59689 L F
.53092 .59166 m .53048 .59705 L .53092 .59691 L .567 .342 .533 r
F
.52788 .59308 m .52647 .59298 L .52696 .59362 L .658 .806 .954 r
F
.53203 .59885 m .52718 .58904 L .52199 .59041 L .658 .807 .955 r
F
.53027 .59711 m .52969 .60672 L .53048 .59705 L .567 .342 .533 r
F
.52771 .59787 m .52843 .59724 L .52623 .59753 L .658 .807 .955 r
F
.52898 .59749 m .52843 .59724 L .52771 .59787 L F
.52843 .59724 m .5175 .59235 L .52623 .59753 L F
.53182 .59154 m .53151 .59684 L .53214 .5915 L .66 .416 .54 r
F
.53151 .59684 m .53171 .59681 L .53214 .5915 L F
.53117 .59163 m .53108 .59689 L .53182 .59154 L F
.53108 .59689 m .53151 .59684 L .53182 .59154 L F
.53214 .5915 m .53171 .59681 L .53215 .59675 L F
.53203 .59885 m .5327 .58834 L .52718 .58904 L .658 .807 .955 r
F
.53108 .59689 m .53092 .59691 L .53094 .60639 L .66 .416 .54 r
F
.53092 .59691 m .52969 .60672 L .53094 .60639 L .567 .342 .533 r
F
.53048 .59705 m .52969 .60672 L .53092 .59691 L F
.52587 .59841 m .52623 .59753 L .52175 .59812 L .658 .807 .955 r
F
.52771 .59787 m .52623 .59753 L .52587 .59841 L F
.52623 .59753 m .51402 .59474 L .52175 .59812 L F
.53151 .59684 m .53094 .60639 L .53171 .59681 L .66 .416 .54 r
F
.52858 .59792 m .52842 .59802 L .52843 .60746 L .4 .211 .506 r
F
.50069 .60425 m .48581 .61233 L .49844 .61633 L .659 .806 .953 r
F
.49425 .60042 m .48581 .61233 L .50069 .60425 L F
.51296 .59967 m .49457 .60596 L .50105 .60979 L .658 .806 .954 r
F
.51098 .59729 m .49457 .60596 L .51296 .59967 L F
.5264 .5992 m .52175 .59812 L .51093 .60015 L .658 .807 .955 r
F
.52754 .59853 m .52175 .59812 L .5264 .5992 L F
.52175 .59812 m .51178 .5974 L .51113 .59951 L F
.52175 .59812 m .51113 .59951 L .51093 .60015 L F
.53108 .59689 m .53094 .60639 L .53151 .59684 L .66 .416 .54 r
F
.53203 .59885 m .55069 .59249 L .54749 .59052 L .658 .807 .955 r
F
.57079 .59076 m .59057 .5922 L .59357 .58401 L .659 .806 .953 r
F
.55158 .59479 m .5716 .59624 L .57353 .59076 L .658 .806 .954 r
F
.55158 .59479 m .57353 .59076 L .55251 .59205 L F
.53203 .59885 m .5526 .59489 L .55069 .59249 L .658 .807 .955 r
F
.53215 .59675 m .53094 .60639 L .53217 .60631 L .66 .416 .54 r
F
.53171 .59681 m .53094 .60639 L .53215 .59675 L F
.53231 .59676 m .53215 .59675 L .53217 .60631 L .734 .477 .539 r
F
.53353 .5968 m .53337 .59677 L .5334 .60643 L .81 .54 .53 r
F
.53705 .593 m .53747 .59321 L .53787 .59295 L .658 .806 .954 r
F
.53326 .59675 m .54323 .58911 L .53818 .58836 L .658 .807 .955 r
F
.53325 .59677 m .53327 .59675 L .53326 .59675 L F
.53327 .59675 m .54323 .58911 L .53326 .59675 L F
.5344 .59679 m .54323 .58911 L .53325 .59677 L F
.53273 .59676 m .53217 .60631 L .53294 .59677 L .734 .477 .539 r
F
.53395 .59688 m .5334 .60643 L .53415 .59692 L .81 .54 .53 r
F
.53458 .597 m .5334 .60643 L .53461 .60679 L F
.53415 .59692 m .5334 .60643 L .53458 .597 L F
.54929 .59743 m .56696 .60149 L .5716 .59624 L .658 .806 .954 r
F
.54061 .59812 m .5531 .59755 L .55301 .59706 L .658 .807 .955 r
F
.54143 .59827 m .5531 .59755 L .54061 .59812 L F
.54217 .5969 m .55301 .59706 L .5526 .59489 L F
.53337 .59677 m .53217 .60631 L .5334 .60643 L .734 .477 .539 r
F
.53294 .59677 m .53217 .60631 L .53337 .59677 L F
.53474 .59708 m .53458 .597 L .53461 .60679 L .911 .629 .497 r
F
.53515 .59728 m .53461 .60679 L .53535 .59738 L F
.5393 .59936 m .55217 .60029 L .55218 .60027 L .658 .807 .955 r
F
.53932 .59937 m .55217 .60029 L .5393 .59936 L F
.54143 .59827 m .55218 .60027 L .5531 .59755 L F
.53353 .5968 m .5334 .60643 L .53395 .59688 L .81 .54 .53 r
F
.53576 .59759 m .53461 .60679 L .53579 .60758 L .911 .629 .497 r
F
.53535 .59738 m .53461 .60679 L .53576 .59759 L F
.53231 .59676 m .53217 .60631 L .53273 .59676 L .734 .477 .539 r
F
.53583 .5977 m .53576 .59759 L .53579 .60758 L .983 .725 .332 r
F
.53755 .60056 m .54638 .60527 L .54839 .60392 L .658 .807 .955 r
F
.53817 .6016 m .54638 .60527 L .53755 .60056 L F
.5435 .60147 m .54839 .60392 L .54988 .60292 L F
.53474 .59708 m .53461 .60679 L .53515 .59728 L .911 .629 .497 r
F
.53588 .59938 m .53615 .60935 L .5358 .59948 L .08 0 .418 r
F
.53605 .59917 m .53615 .60935 L .53588 .59938 L F
.536 .59799 m .53579 .60758 L .53608 .59813 L .983 .725 .332 r
F
.5411 .60646 m .54192 .60718 L .54087 .60607 L .658 .807 .955 r
F
.53619 .59874 m .53629 .60857 L .53617 .59886 L 0 0 .15 r
F
.53612 .59909 m .53629 .60857 L .53615 .60935 L F
.53617 .59886 m .53629 .60857 L .53612 .59909 L F
.53624 .59851 m .53629 .60857 L .53619 .59874 L F
.53624 .59851 m .53626 .59841 L .53629 .60857 L F
.53605 .59917 m .53612 .59909 L .53615 .60935 L .08 0 .418 r
F
.53626 .59841 m .53579 .60758 L .53629 .60857 L .983 .725 .332 r
F
.53608 .59813 m .53579 .60758 L .53626 .59841 L F
.53817 .6016 m .54192 .60718 L .54638 .60527 L .658 .807 .955 r
F
.54087 .60607 m .54192 .60718 L .53817 .6016 L F
.52894 .60049 m .52905 .61044 L .52868 .60034 L .929 .648 .487 r
F
.52894 .60049 m .52899 .60052 L .52895 .60106 L F
.52899 .60052 m .52904 .60055 L .52895 .60106 L F
.52895 .60106 m .52904 .60055 L .52905 .61044 L F
.52902 .59767 m .52843 .60746 L .52923 .59755 L .4 .211 .506 r
F
.52451 .6003 m .52238 .59945 L .51151 .6028 L .658 .807 .955 r
F
.5264 .5992 m .52238 .59945 L .52451 .6003 L F
.52238 .59945 m .51093 .60015 L .51148 .60267 L F
.52238 .59945 m .51148 .60267 L .51151 .6028 L F
.52984 .59723 m .52969 .60672 L .53027 .59711 L .567 .342 .533 r
F
.52842 .59802 m .52831 .60766 L .52842 .6018 L 0 0 .377 r
F
.52811 .60226 m .52548 .60238 L .52195 .60762 L .658 .807 .955 r
F
.528 .60102 m .52548 .60238 L .52811 .60226 L F
.5281 .59985 m .52831 .60988 L .52803 .59976 L .988 .719 .384 r
F
.52785 .59925 m .52789 .60922 L .52784 .59914 L .781 .623 .061 r
F
.52788 .59957 m .52831 .60988 L .52789 .60922 L .988 .719 .384 r
F
.52803 .59976 m .52831 .60988 L .52788 .59957 L F
.52782 .59891 m .52789 .60922 L .52783 .60844 L .781 .623 .061 r
F
.52784 .59914 m .52789 .60922 L .52782 .59891 L F
.52824 .60004 m .52831 .60988 L .5281 .59985 L .988 .719 .384 r
F
.52787 .59948 m .52788 .59957 L .52789 .60922 L .781 .623 .061 r
F
.52787 .59948 m .52789 .60922 L .52785 .59925 L F
.52824 .60004 m .5283 .60011 L .52831 .60988 L .988 .719 .384 r
F
.52842 .59802 m .52783 .60844 L .52831 .60766 L 0 0 .377 r
F
.52821 .59833 m .52783 .60844 L .52842 .59802 L F
.52662 .6007 m .52451 .6003 L .51991 .60298 L .658 .807 .955 r
F
.52724 .59977 m .52451 .6003 L .52662 .6007 L F
.52451 .6003 m .51151 .6028 L .51991 .60298 L F
.52858 .59792 m .52843 .60746 L .52902 .59767 L .4 .211 .506 r
F
.52811 .59848 m .52783 .60844 L .52821 .59833 L 0 0 .377 r
F
.52662 .6007 m .51991 .60298 L .52624 .60125 L .658 .807 .955 r
F
.51991 .60298 m .51349 .60517 L .51481 .60596 L F
.51991 .60298 m .51481 .60596 L .51672 .6071 L F
.52968 .59728 m .52843 .60746 L .52969 .60672 L .4 .211 .506 r
F
.52923 .59755 m .52843 .60746 L .52968 .59728 L F
.52548 .60238 m .51672 .6071 L .52195 .60762 L .658 .807 .955 r
F
.5279 .59879 m .52783 .60844 L .52811 .59848 L 0 0 .377 r
F
.52195 .60762 m .52097 .60847 L .5218 .60784 L .658 .807 .955 r
F
.5279 .59879 m .52782 .59891 L .52783 .60844 L 0 0 .377 r
F
.53583 .5977 m .53579 .60758 L .536 .59799 L .983 .725 .332 r
F
.54113 .60651 m .54158 .60727 L .54192 .60718 L .658 .807 .955 r
F
.2572 .49224 m .2662 .50642 L .27919 .50318 L .656 .78 .94 r
F
.5864 .37495 m .58672 .36681 L .56227 .35908 L .798 .539 .546 r
F
0 g
.58672 .36681 m
.60715 .37804 L
s
.7826 .6466 m .77978 .6374 L .76417 .64131 L .654 .811 .959 r
F
.79334 .64526 m .77978 .6374 L .7826 .6466 L F
.32036 .38943 m .34192 .3697 L .31268 .37884 L .642 .739 .919 r
F
.32036 .38943 m .35323 .3857 L .34192 .3697 L F
0 g
.35304 .37487 m
.35385 .37511 L
s
.30251 .64298 m .28994 .64303 L .29016 .64847 L .506 .325 .569 r
F
0 g
.28106 .65515 m
.29016 .64847 L
s
.30251 .64298 m .30227 .63752 L .28994 .64303 L .506 .325 .569 r
F
0 g
.28085 .64972 m
.28994 .64303 L
s
.36444 .63365 m .36412 .62822 L .34895 .62617 L .791 .544 .565 r
F
0 g
.36412 .62822 m
.3772 .63215 L
s
.54556 .62198 m .545 .61657 L .56012 .61264 L .607 .406 .583 r
F
0 g
.54302 .61682 m
.545 .61657 L
s
.79334 .64526 m .79601 .63537 L .77978 .6374 L .654 .811 .959 r
F
.29181 .75134 m .29706 .75145 L .29652 .75607 L .972 .745 .537 r
F
.29181 .75134 m .29236 .7467 L .29706 .75145 L F
0 g
.29706 .75145 m
.30264 .75481 L
s
.30561 .74587 m .29724 .75141 L .30871 .74903 L .595 .768 .962 r
F
.30561 .74587 m .29256 .74669 L .29724 .75141 L F
.55526 .49332 m .5714 .47937 L .55114 .49035 L .656 .78 .94 r
F
.55526 .49332 m .5796 .48538 L .5714 .47937 L F
.47893 .50783 m .44935 .5161 L .47688 .51548 L .655 .782 .942 r
F
.50548 .51105 m .47893 .50783 L .47688 .51548 L F
.36797 .76034 m .36843 .75571 L .37226 .75147 L .024 0 .368 r
F
0 g
.36217 .75914 m
.36843 .75571 L
s
.35617 .75186 m .36825 .75565 L .37206 .75143 L .595 .768 .962 r
F
.24638 .35979 m .23497 .33847 L .21886 .34195 L .643 .737 .917 r
F
.25515 .35952 m .23497 .33847 L .24638 .35979 L F
.40402 .22794 m .40306 .29157 L .40129 .2918 L .631 .379 .518 r
F
.40402 .22794 m .40575 .22771 L .40306 .29157 L F
.40229 .22764 m .40402 .22794 L .40129 .2918 L .753 .483 .524 r
F
0 g
.40402 .22794 m
.40402 .22794 L
s
.32445 .75852 m .31813 .76345 L .3249 .76508 L .593 .769 .963 r
F
.26408 .36071 m .25271 .33791 L .25515 .35952 L .643 .737 .917 r
F
.26408 .36071 m .27078 .34034 L .25271 .33791 L F
.33499 .75976 m .33912 .76592 L .34564 .7651 L .593 .769 .963 r
F
.7694 .75679 m .76226 .76339 L .77312 .75961 L .597 .767 .96 r
F
.7694 .75679 m .75665 .75917 L .76226 .76339 L F
0 g
.76226 .76339 m
.77004 .76682 L
s
.19431 .36441 m .16269 .35205 L .15497 .36709 L .642 .738 .918 r
F
.1613 .36023 m .15497 .36709 L .15357 .37523 L 0 0 .16 r
F
0 g
.15463 .37516 m
.15472 .373 L
s
.1613 .36023 m .16269 .35205 L .15497 .36709 L 0 0 .16 r
F
.59124 .7648 m .58256 .76258 L .58235 .76722 L .517 .32 .553 r
F
0 g
.57541 .77063 m
.58235 .76722 L
s
.59124 .7648 m .59143 .76015 L .58256 .76258 L .517 .32 .553 r
F
0 g
.57562 .766 m
.58256 .76258 L
s
.40575 .22771 m .40417 .29108 L .40306 .29157 L .484 .259 .497 r
F
.40575 .22771 m .40684 .22721 L .40417 .29108 L F
0 g
.40402 .22794 m
.40575 .22771 L
s
.40229 .22764 m .40129 .2918 L .39952 .2915 L .753 .483 .524 r
F
.40117 .2271 m .40229 .22764 L .39952 .2915 L .849 .569 .514 r
F
0 g
.40229 .22764 m
.40402 .22794 L
s
.23579 .4912 m .22378 .50441 L .23758 .50705 L .656 .78 .94 r
F
.8206 .76687 m .82826 .7588 L .82834 .76345 L .426 .258 .549 r
F
.81216 .76194 m .8206 .76687 L .82834 .76345 L .597 .767 .96 r
F
.80587 .76356 m .8206 .76687 L .81216 .76194 L F
0 g
.81119 .76927 m
.8206 .76687 L
s
.50807 .50087 m .47866 .50126 L .50517 .50449 L .655 .781 .941 r
F
.64089 .76606 m .63292 .75798 L .63278 .76262 L .857 .609 .563 r
F
.64075 .77071 m .64089 .76606 L .63278 .76262 L F
0 g
.64089 .76606 m
.64683 .77025 L
s
.20553 .34809 m .16454 .3441 L .19591 .35642 L .643 .737 .917 r
F
0 g
.35294 .37584 m
.35365 .37685 L
s
.35365 .37685 m
.35413 .37753 L
s
.40684 .22721 m .40492 .29043 L .40417 .29108 L .286 .104 .449 r
F
.40684 .22721 m .40757 .22656 L .40492 .29043 L F
0 g
.40575 .22771 m
.40684 .22721 L
s
.60428 .7697 m .60145 .76355 L .59124 .7648 L .595 .768 .962 r
F
.61145 .76971 m .60145 .76355 L .60428 .7697 L F
.61851 .77055 m .61226 .76356 L .61145 .76971 L F
.61851 .77055 m .6229 .76483 L .61226 .76356 L F
.40117 .2271 m .39952 .2915 L .39838 .29097 L .849 .569 .514 r
F
.40041 .22642 m .40117 .2271 L .39838 .29097 L .929 .648 .486 r
F
0 g
.40117 .2271 m
.40229 .22764 L
s
.25515 .35952 m .25271 .33791 L .23497 .33847 L .643 .737 .917 r
F
.71394 .49004 m .71327 .48352 L .73483 .48153 L .671 .447 .572 r
F
.69287 .48899 m .71327 .48352 L .71394 .49004 L .734 .493 .564 r
F
.69287 .48899 m .69224 .48246 L .71327 .48352 L F
.47893 .50783 m .45221 .5046 L .44935 .5161 L .655 .782 .942 r
F
0 g
.44935 .5161 m
.45212 .52729 L
s
.71603 .46827 m .71331 .4833 L .73477 .48131 L .656 .78 .94 r
F
.70194 .46755 m .71331 .4833 L .71603 .46827 L F
.70194 .46755 m .69238 .48224 L .71331 .4833 L F
.76417 .64131 m .74946 .64137 L .7503 .64682 L .537 .362 .591 r
F
0 g
.73915 .65351 m
.7503 .64682 L
s
.76417 .64131 m .7633 .63585 L .74946 .64137 L .537 .362 .591 r
F
0 g
.73832 .64808 m
.74946 .64137 L
s
.40757 .22656 m .40536 .28966 L .40492 .29043 L 0 0 .327 r
F
.40757 .22656 m .408 .22578 L .40536 .28966 L F
0 g
.40684 .22721 m
.40757 .22656 L
s
.49878 .6219 m .51306 .61856 L .51358 .62398 L .793 .543 .559 r
F
.49878 .6219 m .49828 .61647 L .51306 .61856 L F
0 g
.51306 .61856 m
.52411 .61858 L
s
.82468 .63198 m .82373 .62655 L .80981 .62448 L .797 .539 .548 r
F
0 g
.82373 .62655 m
.83498 .63048 L
s
.78984 .75779 m .78463 .76354 L .79164 .76439 L .597 .767 .96 r
F
.61145 .76971 m .61226 .76356 L .60145 .76355 L .595 .768 .962 r
F
.40041 .22642 m .39838 .29097 L .3976 .2903 L .929 .648 .486 r
F
.39995 .22563 m .40041 .22642 L .3976 .2903 L .989 .724 .411 r
F
0 g
.40041 .22642 m
.40117 .2271 L
s
.53006 .62943 m .52952 .624 L .54556 .62198 L .673 .454 .58 r
F
.51411 .62941 m .52952 .624 L .53006 .62943 L .733 .498 .572 r
F
.51411 .62941 m .51358 .62398 L .52952 .624 L F
.51946 .61391 m .51358 .62398 L .52952 .624 L .658 .806 .954 r
F
.75363 .74978 m .75666 .7499 L .75666 .75453 L .992 .743 .391 r
F
.75363 .74978 m .75364 .74514 L .75666 .7499 L F
0 g
.75666 .7499 m
.76155 .75361 L
s
.55866 .50986 m .58073 .49842 L .55618 .50637 L .655 .782 .942 r
F
.55866 .50986 m .58557 .50545 L .58073 .49842 L F
.50787 .49436 m .48433 .48746 L .47866 .49475 L .656 .78 .94 r
F
.51236 .4912 m .48433 .48746 L .50787 .49436 L F
.76753 .74431 m .75685 .74986 L .7695 .74747 L .599 .766 .959 r
F
.76753 .74431 m .75384 .74513 L .75685 .74986 L F
.29126 .75599 m .29652 .75607 L .29598 .76071 L .972 .745 .537 r
F
.29126 .75599 m .29181 .75134 L .29652 .75607 L F
.30495 .75052 m .29652 .75607 L .30806 .75369 L .594 .768 .963 r
F
.30495 .75052 m .29181 .75134 L .29652 .75607 L F
0 g
.29652 .75607 m
.30213 .75945 L
s
.82826 .7588 m .82817 .75416 L .83369 .74991 L .254 .126 .507 r
F
0 g
.82046 .75761 m
.82817 .75416 L
s
.32148 .75736 m .31813 .76345 L .32445 .75852 L .593 .769 .963 r
F
.32148 .75736 m .31221 .76116 L .31813 .76345 L F
.81707 .75031 m .82801 .75411 L .8335 .74988 L .599 .766 .959 r
F
.32309 .49223 m .33051 .47467 L .33052 .48122 L .033 0 .419 r
F
.32308 .49877 m .32309 .49223 L .33052 .48122 L F
.29839 .48528 m .32309 .49223 L .33052 .48122 L .657 .779 .939 r
F
.29021 .49167 m .32309 .49223 L .29839 .48528 L F
0 g
.31475 .49863 m
.32309 .49223 L
s
.73554 .48805 m .73483 .48153 L .75559 .47659 L .604 .398 .575 r
F
.71394 .49004 m .73483 .48153 L .73554 .48805 L .671 .447 .572 r
F
0 g
.71327 .48352 m
.73483 .48153 L
s
.36444 .63365 m .34895 .62617 L .34925 .6316 L .791 .544 .565 r
F
.36476 .63909 m .36444 .63365 L .34925 .6316 L F
0 g
.36444 .63365 m
.37754 .63756 L
s
.78667 .75697 m .78463 .76354 L .78984 .75779 L .597 .767 .96 r
F
.78667 .75697 m .77832 .76192 L .78463 .76354 L F
.408 .22578 m .40543 .28874 L .40536 .28966 L 0 0 .006 r
F
.408 .22578 m .40808 .22485 L .40543 .28874 L F
0 g
.40757 .22656 m
.408 .22578 L
s
.33826 .75934 m .34564 .7651 L .35117 .76348 L .593 .769 .963 r
F
.33499 .75976 m .34564 .7651 L .33826 .75934 L F
.54556 .62198 m .56012 .61264 L .56071 .61805 L .607 .406 .583 r
F
.54613 .62741 m .54556 .62198 L .56071 .61805 L F
.53006 .62943 m .54556 .62198 L .54613 .62741 L .673 .454 .58 r
F
.54094 .61258 m .54556 .62198 L .56071 .61805 L .658 .806 .954 r
F
0 g
.52952 .624 m
.54556 .62198 L
s
.36797 .76034 m .37226 .75147 L .3718 .75611 L .024 0 .368 r
F
.36752 .76498 m .36797 .76034 L .3718 .75611 L F
.35582 .75654 m .36797 .76034 L .3718 .75611 L .594 .768 .963 r
F
.35165 .75884 m .36797 .76034 L .35582 .75654 L F
0 g
.3617 .76377 m
.36797 .76034 L
s
.39995 .22563 m .3976 .2903 L .39712 .28951 L .989 .724 .411 r
F
.39983 .2247 m .39995 .22563 L .39712 .28951 L .875 .7 .179 r
F
0 g
.39995 .22563 m
.40041 .22642 L
s
.73048 .46693 m .73477 .48131 L .75542 .4764 L .656 .78 .94 r
F
.71603 .46827 m .73477 .48131 L .73048 .46693 L F
.58512 .4989 m .60501 .48381 L .58029 .49185 L .655 .781 .941 r
F
.58512 .4989 m .6121 .49447 L .60501 .48381 L F
.23711 .3695 m .21741 .3499 L .20399 .35606 L .642 .738 .918 r
F
.24516 .3678 m .21741 .3499 L .23711 .3695 L F
.2572 .49224 m .27919 .50318 L .26374 .49059 L .656 .78 .94 r
F
.26374 .49059 m .27919 .50318 L .29014 .49822 L F
.27152 .3713 m .26973 .34831 L .26299 .36874 L .642 .738 .918 r
F
.27152 .3713 m .28696 .35355 L .26973 .34831 L F
.60163 .7589 m .59163 .75552 L .59143 .76015 L .604 .392 .567 r
F
.60163 .7589 m .60182 .75425 L .59163 .75552 L F
0 g
.58276 .75795 m
.59163 .75552 L
s
.64075 .77071 m .63278 .76262 L .63263 .76727 L .857 .609 .563 r
F
0 g
.64075 .77071 m
.6467 .77488 L
s
.63278 .76262 m .63292 .75798 L .62322 .75553 L .792 .552 .574 r
F
0 g
.63292 .75798 m
.64102 .76143 L
s
.68317 .36732 m .6496 .3767 L .6836 .37293 L .643 .737 .917 r
F
.68317 .36732 m .64852 .3655 L .6496 .3767 L F
.6121 .49447 m .6116 .48794 L .60453 .47724 L .983 .702 .336 r
F
0 g
.6116 .48794 m
.6131 .49936 L
s
.40808 .22485 m .40486 .28756 L .40543 .28874 L .99 .735 .374 r
F
.40808 .22485 m .40752 .22366 L .40486 .28756 L F
.31699 .63361 m .30204 .63208 L .30227 .63752 L .602 .398 .577 r
F
.31699 .63361 m .31673 .62816 L .30204 .63208 L F
0 g
.28972 .6376 m
.30204 .63208 L
s
.56071 .61805 m .56012 .61264 L .57336 .60702 L .524 .346 .582 r
F
0 g
.55034 .61518 m
.56012 .61264 L
s
.45319 .37934 m .47532 .36211 L .47472 .37028 L .474 .261 .51 r
F
.43582 .35984 m .45319 .37934 L .47472 .37028 L .643 .738 .918 r
F
.41911 .36329 m .45319 .37934 L .43582 .35984 L F
0 g
.42837 .38437 m
.45319 .37934 L
s
.39983 .2247 m .39712 .28951 L .397 .28859 L .875 .7 .179 r
F
.40034 .22352 m .39983 .2247 L .397 .28859 L 0 0 .269 r
F
.55578 .49981 m .57203 .48582 L .55163 .49684 L .655 .781 .941 r
F
.55578 .49981 m .58029 .49185 L .57203 .48582 L F
.48433 .48746 m .45217 .4915 L .47866 .49475 L .656 .78 .94 r
F
.78265 .38367 m .8218 .37458 L .78714 .37277 L .643 .737 .917 r
F
.75034 .37643 m .78265 .38367 L .78714 .37277 L F
.74601 .38138 m .78265 .38367 L .75034 .37643 L F
.22922 .38066 m .20271 .36424 L .19301 .37257 L .642 .739 .919 r
F
.23592 .37766 m .20271 .36424 L .22922 .38066 L F
.2779 .38321 m .28588 .36176 L .27041 .37947 L F
.2779 .38321 m .30092 .36939 L .28588 .36176 L F
.67366 .48494 m .69224 .48246 L .69287 .48899 L .798 .541 .549 r
F
.67366 .48494 m .67306 .47839 L .69224 .48246 L F
0 g
.69224 .48246 m
.71327 .48352 L
s
.50769 .3726 m .48308 .36953 L .48251 .37769 L .583 .354 .534 r
F
0 g
.461 .38668 m
.48251 .37769 L
s
.50769 .3726 m .50821 .36442 L .48308 .36953 L .583 .354 .534 r
F
0 g
.46163 .37854 m
.48308 .36953 L
s
.50838 .50743 m .47893 .50783 L .50548 .51105 L .655 .782 .942 r
F
.75362 .75443 m .75666 .75453 L .75665 .75917 L .992 .743 .391 r
F
.75362 .75443 m .75363 .74978 L .75666 .75453 L F
.7674 .74896 m .75666 .75453 L .76939 .75214 L .598 .766 .96 r
F
.7674 .74896 m .75363 .74978 L .75666 .75453 L F
0 g
.75666 .75453 m
.76158 .75825 L
s
.55114 .49035 m .56034 .47482 L .54562 .48811 L .656 .78 .94 r
F
.55114 .49035 m .5714 .47937 L .56034 .47482 L F
.78407 .75581 m .77832 .76192 L .78667 .75697 L .597 .767 .96 r
F
.78407 .75581 m .77312 .75961 L .77832 .76192 L F
.68913 .46479 m .69238 .48224 L .70194 .46755 L .656 .78 .94 r
F
.68913 .46479 m .67329 .47819 L .69238 .48224 L F
.5864 .37495 m .56227 .35908 L .56189 .36723 L .798 .539 .546 r
F
.58608 .38312 m .5864 .37495 L .56189 .36723 L F
0 g
.5864 .37495 m
.60688 .38615 L
s
.49929 .62735 m .51358 .62398 L .51411 .62941 L .793 .543 .559 r
F
.49929 .62735 m .49878 .6219 L .51358 .62398 L F
.50954 .6125 m .51358 .62398 L .51946 .61391 L .658 .806 .954 r
F
.50954 .6125 m .49878 .6219 L .51358 .62398 L F
0 g
.51358 .62398 m
.52952 .624 L
s
.82468 .63198 m .80981 .62448 L .81074 .62993 L .797 .539 .548 r
F
.82563 .63742 m .82468 .63198 L .81074 .62993 L F
0 g
.82468 .63198 m
.83594 .6359 L
s
.80051 .7578 m .80587 .76356 L .81216 .76194 L .597 .767 .96 r
F
.40752 .22366 m .40362 .28662 L .40486 .28756 L .912 .629 .494 r
F
.40752 .22366 m .4063 .22271 L .40362 .28662 L F
0 g
.40752 .22366 m
.40808 .22485 L
s
.40752 .22366 m
.40752 .22366 L
s
.30441 .75517 m .29598 .76071 L .30753 .75833 L .593 .769 .963 r
F
.30441 .75517 m .29126 .75599 L .29598 .76071 L F
0 g
.29598 .76071 m
.30301 .76492 L
s
.82826 .7588 m .83369 .74991 L .83378 .75456 L .254 .126 .507 r
F
.82834 .76345 m .82826 .7588 L .83378 .75456 L F
.81724 .75499 m .82826 .7588 L .83378 .75456 L .598 .766 .96 r
F
.8121 .7573 m .82826 .7588 L .81724 .75499 L F
0 g
.82053 .76223 m
.82826 .7588 L
s
.53071 .61939 m .53006 .62943 L .54613 .62741 L .658 .807 .955 r
F
.51999 .61937 m .53006 .62943 L .53071 .61939 L F
.51999 .61937 m .51411 .62941 L .53006 .62943 L F
.71461 .49659 m .71394 .49004 L .73554 .48805 L .671 .447 .572 r
F
.69351 .49554 m .71394 .49004 L .71461 .49659 L .734 .493 .564 r
F
.69351 .49554 m .69287 .48899 L .71394 .49004 L F
.71668 .47499 m .71394 .49004 L .73554 .48805 L .655 .781 .941 r
F
.70251 .47426 m .71394 .49004 L .71668 .47499 L F
.70251 .47426 m .69287 .48899 L .71394 .49004 L F
.40152 .22262 m .40034 .22352 L .39752 .28742 L .339 .143 .462 r
F
.40034 .22352 m .397 .28859 L .39752 .28742 L 0 0 .269 r
F
0 g
.39983 .2247 m
.40034 .22352 L
s
.40034 .22352 m
.40034 .22352 L
s
.16866 .48473 m .17929 .48885 L .17904 .49539 L .972 .719 .493 r
F
.16866 .48473 m .16893 .47815 L .17929 .48885 L F
0 g
.17929 .48885 m
.18607 .49292 L
s
.36752 .76498 m .3718 .75611 L .37135 .76077 L .024 0 .368 r
F
.35535 .76119 m .36752 .76498 L .37135 .76077 L .593 .769 .963 r
F
.35117 .76348 m .36752 .76498 L .35535 .76119 L F
0 g
.36124 .7684 m
.36752 .76498 L
s
.19554 .4736 m .16933 .47809 L .17963 .48873 L .657 .779 .938 r
F
.31871 .74505 m .30561 .74587 L .30871 .74903 L .595 .768 .962 r
F
.36476 .63909 m .34925 .6316 L .34955 .63706 L .791 .544 .565 r
F
0 g
.36476 .63909 m
.37788 .64298 L
s
.34925 .6316 m .34895 .62617 L .33276 .62614 L .733 .499 .574 r
F
0 g
.34895 .62617 m
.36412 .62822 L
s
.54613 .62741 m .56071 .61805 L .56129 .62348 L .607 .406 .583 r
F
.5415 .61803 m .54613 .62741 L .56129 .62348 L .658 .807 .955 r
F
.53071 .61939 m .54613 .62741 L .5415 .61803 L F
0 g
.53006 .62943 m
.54613 .62741 L
s
.22964 .48894 m .22378 .50441 L .23579 .4912 L .656 .78 .94 r
F
.22964 .48894 m .21153 .49995 L .22378 .50441 L F
.35617 .75186 m .37206 .75143 L .35868 .74903 L .595 .768 .962 r
F
.60145 .76355 m .59143 .76015 L .59124 .7648 L .604 .392 .567 r
F
0 g
.58235 .76722 m
.59124 .7648 L
s
.60145 .76355 m .60163 .7589 L .59143 .76015 L .604 .392 .567 r
F
0 g
.58256 .76258 m
.59143 .76015 L
s
.24516 .3678 m .23364 .34642 L .21741 .3499 L .642 .738 .918 r
F
.25399 .36754 m .23364 .34642 L .24516 .3678 L F
.47532 .36211 m .47591 .35398 L .49266 .34135 L .306 .125 .464 r
F
0 g
.46398 .35906 m
.47591 .35398 L
s
.19301 .37257 m .1613 .36023 L .15357 .37523 L .642 .739 .919 r
F
0 g
.15292 .39143 m
.15357 .37523 L
s
.26299 .36874 m .25152 .34587 L .25399 .36754 L .642 .738 .918 r
F
.26299 .36874 m .26973 .34831 L .25152 .34587 L F
.77889 .63193 m .76244 .63041 L .7633 .63585 L .611 .412 .588 r
F
.77889 .63193 m .77801 .62648 L .76244 .63041 L F
0 g
.74861 .63593 m
.76244 .63041 L
s
.4063 .22271 m .40238 .2862 L .40362 .28662 L .814 .537 .519 r
F
.4063 .22271 m .4051 .22228 L .40238 .2862 L F
0 g
.4063 .22271 m
.40752 .22366 L
s
.50807 .50087 m .48437 .49396 L .47866 .50126 L .655 .781 .941 r
F
.51259 .4977 m .48437 .49396 L .50807 .50087 L F
.31915 .75594 m .31221 .76116 L .32148 .75736 L .593 .769 .963 r
F
.31915 .75594 m .30753 .75833 L .31221 .76116 L F
.63278 .76262 m .62322 .75553 L .62306 .76018 L .792 .552 .574 r
F
.63263 .76727 m .63278 .76262 L .62306 .76018 L F
0 g
.63278 .76262 m
.64089 .76606 L
s
.40152 .22262 m .39752 .28742 L .39872 .28653 L .339 .143 .462 r
F
.4027 .22223 m .40152 .22262 L .39872 .28653 L .545 .308 .506 r
F
0 g
.40034 .22352 m
.40152 .22262 L
s
.45131 .33715 m .47555 .35374 L .49221 .34116 L .644 .737 .916 r
F
.43704 .34332 m .47555 .35374 L .45131 .33715 L F
.34103 .75853 m .35117 .76348 L .35535 .76119 L .593 .769 .963 r
F
.33826 .75934 m .35117 .76348 L .34103 .75853 L F
.32308 .49877 m .33052 .48122 L .33052 .48778 L .033 0 .419 r
F
.29834 .49185 m .32308 .49877 L .33052 .48778 L .656 .78 .94 r
F
.29014 .49822 m .32308 .49877 L .29834 .49185 L F
0 g
.31073 .50821 m
.32308 .49877 L
s
.73554 .48805 m .75559 .47659 L .75634 .48312 L .604 .398 .575 r
F
.73625 .49459 m .73554 .48805 L .75634 .48312 L F
.71461 .49659 m .73554 .48805 L .73625 .49459 L .671 .447 .572 r
F
.73123 .47364 m .73554 .48805 L .75634 .48312 L .655 .781 .941 r
F
.71668 .47499 m .73554 .48805 L .73123 .47364 L F
0 g
.71394 .49004 m
.73554 .48805 L
s
.4051 .22228 m .40116 .28605 L .40238 .2862 L .735 .467 .523 r
F
.4051 .22228 m .4039 .22213 L .40116 .28605 L F
0 g
.4051 .22228 m
.4063 .22271 L
s
.4027 .22223 m .39872 .28653 L .39994 .28615 L .545 .308 .506 r
F
.4039 .22213 m .4027 .22223 L .39994 .28615 L .652 .396 .519 r
F
0 g
.40152 .22262 m
.4027 .22223 L
s
.35323 .3857 m .34286 .36149 L .34192 .3697 L .983 .743 .496 r
F
0 g
.35323 .3857 m
.35765 .40217 L
s
.35275 .38502 m
.35323 .3857 L
s
.51236 .4912 m .49328 .48107 L .48433 .48746 L .656 .78 .94 r
F
.51816 .48872 m .49328 .48107 L .51236 .4912 L F
.4039 .22213 m .39994 .28615 L .40116 .28605 L .652 .396 .519 r
F
0 g
.4039 .22213 m
.4051 .22228 L
s
.4027 .22223 m
.4039 .22213 L
s
.65281 .33815 m .61489 .34744 L .64919 .34924 L .645 .736 .915 r
F
.65281 .33815 m .62001 .33074 L .61489 .34744 L F
.61927 .33878 m .61437 .34742 L .61412 .35553 L 0 0 .21 r
F
0 g
.61498 .35273 m
.61531 .35559 L
s
.61927 .33878 m .61951 .33063 L .61437 .34742 L 0 0 .21 r
F
.20399 .35606 m .16269 .35205 L .19431 .36441 L .642 .738 .918 r
F
.61243 .7589 m .60182 .75425 L .60163 .7589 L .672 .449 .574 r
F
.61243 .7589 m .6126 .75426 L .60182 .75425 L F
0 g
.59163 .75552 m
.60182 .75425 L
s
.31725 .63907 m .30227 .63752 L .30251 .64298 L .602 .398 .577 r
F
0 g
.29016 .64847 m
.30251 .64298 L
s
.31725 .63907 m .31699 .63361 L .30227 .63752 L .602 .398 .577 r
F
0 g
.28994 .64303 m
.30227 .63752 L
s
.58557 .50545 m .6055 .4904 L .58073 .49842 L .655 .782 .942 r
F
.58557 .50545 m .6126 .50103 L .6055 .4904 L F
.68541 .34552 m .64919 .34924 L .6835 .35104 L .645 .736 .915 r
F
.68541 .34552 m .65281 .33815 L .64919 .34924 L F
.62306 .76018 m .62322 .75553 L .6126 .75426 L .732 .5 .576 r
F
0 g
.62322 .75553 m
.63292 .75798 L
s
.56071 .61805 m .57336 .60702 L .57397 .61244 L .524 .346 .582 r
F
.56129 .62348 m .56071 .61805 L .57397 .61244 L F
.5511 .60993 m .56071 .61805 L .57397 .61244 L .658 .806 .954 r
F
.54094 .61258 m .56071 .61805 L .5511 .60993 L F
0 g
.55086 .62061 m
.56071 .61805 L
s
.25399 .36754 m .25152 .34587 L .23364 .34642 L .642 .738 .918 r
F
.31368 .37067 m .32535 .34708 L .30196 .3612 L F
.31368 .37067 m .34286 .36149 L .32535 .34708 L F
.75212 .35463 m .78623 .34514 L .75191 .349 L .645 .736 .915 r
F
.75212 .35463 m .78644 .35643 L .78623 .34514 L F
.78644 .35643 m .82078 .34125 L .78623 .34514 L F
.78644 .35643 m .82075 .35823 L .82078 .34125 L F
.53515 .36362 m .50872 .35628 L .50821 .36442 L .664 .422 .544 r
F
.53515 .36362 m .5356 .35548 L .50872 .35628 L F
0 g
.48366 .36141 m
.50872 .35628 L
s
.82154 .3664 m .82127 .35825 L .8213 .34119 L 0 0 .055 r
F
0 g
.81787 .3662 m
.82127 .35825 L
s
.76741 .75362 m .75665 .75917 L .7694 .75679 L .597 .767 .96 r
F
.76741 .75362 m .75362 .75443 L .75665 .75917 L F
0 g
.75665 .75917 m
.76226 .76339 L
s
.56189 .36723 m .56227 .35908 L .5356 .35548 L .732 .481 .548 r
F
0 g
.56227 .35908 m
.58672 .36681 L
s
.6121 .49447 m .60453 .47724 L .60501 .48381 L .983 .702 .336 r
F
.6126 .50103 m .6121 .49447 L .60501 .48381 L F
0 g
.6121 .49447 m
.6136 .50587 L
s
.82834 .76345 m .83378 .75456 L .83387 .75922 L .254 .126 .507 r
F
.81731 .75964 m .82834 .76345 L .83387 .75922 L .597 .767 .96 r
F
.81216 .76194 m .82834 .76345 L .81731 .75964 L F
0 g
.8206 .76687 m
.82834 .76345 L
s
.55618 .50637 m .57246 .49242 L .55202 .5034 L .655 .782 .942 r
F
.55618 .50637 m .58073 .49842 L .57246 .49242 L F
.33304 .63159 m .31673 .62816 L .31699 .63361 L .673 .452 .578 r
F
.33304 .63159 m .33276 .62614 L .31673 .62816 L F
0 g
.30204 .63208 m
.31673 .62816 L
s
.48437 .49396 m .45199 .49801 L .47866 .50126 L .655 .781 .941 r
F
.78125 .74348 m .76753 .74431 L .7695 .74747 L .599 .766 .959 r
F
.51006 .61797 m .51411 .62941 L .51999 .61937 L .658 .807 .955 r
F
.51006 .61797 m .49929 .62735 L .51411 .62941 L F
0 g
.51411 .62941 m
.53006 .62943 L
s
.82563 .63742 m .81074 .62993 L .81167 .63538 L .797 .539 .548 r
F
0 g
.82563 .63742 m
.8369 .64132 L
s
.62306 .76018 m .6126 .75426 L .61243 .7589 L .732 .5 .576 r
F
0 g
.6126 .75426 m
.62322 .75553 L
s
.60182 .75425 m
.6126 .75426 L
s
.28976 .7464 m .29236 .7467 L .29181 .75134 L .989 .803 .414 r
F
.28976 .7464 m .29032 .74175 L .29236 .7467 L F
0 g
.29236 .7467 m
.29665 .75104 L
s
.48607 .6179 m .49828 .61647 L .49878 .6219 L .857 .591 .536 r
F
.48607 .6179 m .48559 .61245 L .49828 .61647 L F
0 g
.49828 .61647 m
.50406 .61729 L
s
.81074 .62993 m .80981 .62448 L .79419 .62446 L .734 .496 .569 r
F
0 g
.80981 .62448 m
.82373 .62655 L
s
.30429 .74258 m .29256 .74669 L .30561 .74587 L .595 .768 .962 r
F
.30429 .74258 m .29052 .74176 L .29256 .74669 L F
.81707 .75031 m .8335 .74988 L .8207 .74748 L .599 .766 .959 r
F
.31812 .7497 m .30495 .75052 L .30806 .75369 L .594 .768 .963 r
F
.3718 .75611 m .37226 .75147 L .37336 .7467 L 0 0 .034 r
F
0 g
.36843 .75571 m
.37226 .75147 L
s
.35582 .75654 m .3718 .75611 L .35834 .75371 L .594 .768 .963 r
F
.35868 .74903 m .37206 .75143 L .37315 .74669 L .595 .768 .962 r
F
.78222 .75439 m .77312 .75961 L .78407 .75581 L .597 .767 .96 r
F
.78222 .75439 m .7694 .75679 L .77312 .75961 L F
.67427 .4915 m .69287 .48899 L .69351 .49554 L .798 .541 .549 r
F
.67427 .4915 m .67366 .48494 L .69287 .48899 L F
.68961 .4715 m .69287 .48899 L .70251 .47426 L .655 .781 .941 r
F
.68961 .4715 m .67366 .48494 L .69287 .48899 L F
0 g
.69287 .48899 m
.71394 .49004 L
s
.75634 .48312 m .75559 .47659 L .77424 .46901 L .525 .342 .575 r
F
0 g
.74544 .479 m
.75559 .47659 L
s
.34925 .6316 m .33276 .62614 L .33304 .63159 L .733 .499 .574 r
F
0 g
.31673 .62816 m
.33276 .62614 L
s
.33276 .62614 m
.34895 .62617 L
s
.80366 .75698 m .81216 .76194 L .81731 .75964 L .597 .767 .96 r
F
.80051 .7578 m .81216 .76194 L .80366 .75698 L F
.54562 .48811 m .54719 .47208 L .53909 .48677 L .656 .78 .94 r
F
.54562 .48811 m .56034 .47482 L .54719 .47208 L F
.34955 .63706 m .34925 .6316 L .33304 .63159 L .733 .499 .574 r
F
0 g
.34925 .6316 m
.36444 .63365 L
s
.23592 .37766 m .21616 .3581 L .20271 .36424 L .642 .739 .919 r
F
.24399 .37596 m .21616 .3581 L .23592 .37766 L F
.74437 .4636 m .75542 .4764 L .77398 .46885 L .656 .78 .94 r
F
.73048 .46693 m .75542 .4764 L .74437 .4636 L F
.63263 .76727 m .62306 .76018 L .6229 .76483 L .792 .552 .574 r
F
0 g
.63263 .76727 m
.64075 .77071 L
s
.55163 .49684 m .5609 .48127 L .54608 .4946 L .655 .781 .941 r
F
.55163 .49684 m .57203 .48582 L .5609 .48127 L F
.27041 .37947 m .26861 .35652 L .26186 .3769 L .642 .739 .919 r
F
.27041 .37947 m .28588 .36176 L .26861 .35652 L F
.71737 .48157 m .71461 .49659 L .73625 .49459 L .655 .782 .942 r
F
.70317 .48085 m .71461 .49659 L .71737 .48157 L F
.70317 .48085 m .69351 .49554 L .71461 .49659 L F
.77978 .6374 m .7633 .63585 L .76417 .64131 L .611 .412 .588 r
F
0 g
.7503 .64682 m
.76417 .64131 L
s
.77978 .6374 m .77889 .63193 L .7633 .63585 L .611 .412 .588 r
F
0 g
.74946 .64137 m
.7633 .63585 L
s
.16838 .49132 m .17904 .49539 L .17878 .50195 L .972 .719 .493 r
F
.16838 .49132 m .16866 .48473 L .17904 .49539 L F
.19504 .48022 m .17904 .49539 L .20186 .48739 L .657 .779 .939 r
F
.19504 .48022 m .16866 .48473 L .17904 .49539 L F
0 g
.17904 .49539 m
.18587 .49948 L
s
.40215 .32547 m .40275 .34731 L .4205 .34677 L .644 .737 .916 r
F
.39312 .32425 m .40275 .34731 L .40215 .32547 L F
.39312 .32425 m .38492 .34491 L .40275 .34731 L F
.61226 .76356 m .60163 .7589 L .60145 .76355 L .672 .449 .574 r
F
0 g
.59124 .7648 m
.60145 .76355 L
s
.61226 .76356 m .61243 .7589 L .60163 .7589 L .672 .449 .574 r
F
0 g
.59143 .76015 m
.60163 .7589 L
s
.6229 .76483 m .62306 .76018 L .61243 .7589 L .732 .5 .576 r
F
0 g
.62306 .76018 m
.63278 .76262 L
s
.26924 .48807 m .29014 .49822 L .29834 .49185 L .656 .78 .94 r
F
.26374 .49059 m .29014 .49822 L .26924 .48807 L F
.5415 .61803 m .56129 .62348 L .55168 .61539 L .658 .807 .955 r
F
.56129 .62348 m .57397 .61244 L .57458 .61788 L .524 .346 .582 r
F
.55168 .61539 m .56129 .62348 L .57458 .61788 L .658 .807 .955 r
F
0 g
.54613 .62741 m
.56129 .62348 L
s
.51816 .48872 m .50493 .47602 L .49328 .48107 L .656 .78 .94 r
F
.52486 .48708 m .50493 .47602 L .51816 .48872 L F
.50838 .50743 m .48464 .50055 L .47893 .50783 L .655 .782 .942 r
F
.51291 .50427 m .48464 .50055 L .50838 .50743 L F
.5796 .48538 m .59193 .46824 L .5714 .47937 L .656 .78 .94 r
F
.5796 .48538 m .60415 .47737 L .59193 .46824 L F
.7951 .62991 m .77801 .62648 L .77889 .63193 L .674 .455 .581 r
F
.7951 .62991 m .79419 .62446 L .77801 .62648 L F
0 g
.76244 .63041 m
.77801 .62648 L
s
.56189 .36723 m .5356 .35548 L .53515 .36362 L .732 .481 .548 r
F
0 g
.5356 .35548 m
.56227 .35908 L
s
.50872 .35628 m
.5356 .35548 L
s
.7534 .74483 m .75364 .74514 L .75363 .74978 L .752 .608 .039 r
F
.7534 .74483 m .75341 .74018 L .75364 .74514 L F
0 g
.75364 .74514 m
.75648 .74961 L
s
.73625 .49459 m .75634 .48312 L .75709 .48967 L .604 .398 .575 r
F
.73194 .48022 m .73625 .49459 L .75709 .48967 L .655 .782 .942 r
F
.71737 .48157 m .73625 .49459 L .73194 .48022 L F
0 g
.71461 .49659 m
.73625 .49459 L
s
.76741 .74101 m .75384 .74513 L .76753 .74431 L .599 .766 .959 r
F
.76741 .74101 m .75362 .74019 L .75384 .74513 L F
.58608 .38312 m .56189 .36723 L .56151 .37542 L .798 .539 .546 r
F
0 g
.58608 .38312 m
.60662 .39431 L
s
.78121 .74814 m .7674 .74896 L .76939 .75214 L .598 .766 .96 r
F
.6229 .76483 m .61243 .7589 L .61226 .76356 L .732 .5 .576 r
F
0 g
.61243 .7589 m
.62306 .76018 L
s
.6229 .76483 m
.63263 .76727 L
s
.60163 .7589 m
.61243 .7589 L
s
.28921 .75106 m .29181 .75134 L .29126 .75599 L .989 .803 .414 r
F
.28921 .75106 m .28976 .7464 L .29181 .75134 L F
.30362 .74722 m .29181 .75134 L .30495 .75052 L .594 .768 .963 r
F
.30362 .74722 m .28976 .7464 L .29181 .75134 L F
0 g
.29181 .75134 m
.29613 .75568 L
s
.51259 .4977 m .49338 .48755 L .48437 .49396 L .655 .781 .941 r
F
.51843 .49521 m .49338 .48755 L .51259 .4977 L F
.83378 .75456 m .83369 .74991 L .83662 .74514 L 0 0 .387 r
F
0 g
.82817 .75416 m
.83369 .74991 L
s
.81724 .75499 m .83378 .75456 L .82091 .75215 L .598 .766 .96 r
F
.8207 .74748 m .8335 .74988 L .83641 .74512 L .599 .766 .959 r
F
.3176 .75436 m .30753 .75833 L .31915 .75594 L .593 .769 .963 r
F
.3176 .75436 m .30441 .75517 L .30753 .75833 L F
.81074 .62993 m .79419 .62446 L .7951 .62991 L .734 .496 .569 r
F
0 g
.77801 .62648 m
.79419 .62446 L
s
.79419 .62446 m
.80981 .62448 L
s
.33331 .63705 m .31699 .63361 L .31725 .63907 L .673 .452 .578 r
F
0 g
.30251 .64298 m
.31725 .63907 L
s
.33331 .63705 m .33304 .63159 L .31699 .63361 L .673 .452 .578 r
F
0 g
.30227 .63752 m
.31699 .63361 L
s
.3718 .75611 m .37336 .7467 L .3729 .75136 L 0 0 .034 r
F
.37135 .76077 m .3718 .75611 L .3729 .75136 L F
.35834 .75371 m .3718 .75611 L .3729 .75136 L .594 .768 .963 r
F
0 g
.36797 .76034 m
.3718 .75611 L
s
.31806 .7434 m .30561 .74587 L .31871 .74505 L .595 .768 .962 r
F
.31806 .7434 m .30429 .74258 L .30561 .74587 L F
.48433 .48746 m .46052 .48049 L .45217 .4915 L .656 .78 .94 r
F
.35535 .76119 m .37135 .76077 L .35787 .75836 L .593 .769 .963 r
F
.34311 .75737 m .35535 .76119 L .35787 .75836 L F
.34103 .75853 m .35535 .76119 L .34311 .75737 L F
.48656 .62336 m .49878 .6219 L .49929 .62735 L .857 .591 .536 r
F
.48656 .62336 m .48607 .6179 L .49878 .6219 L F
.50105 .60979 m .49878 .6219 L .50954 .6125 L .658 .806 .954 r
F
.50105 .60979 m .48607 .6179 L .49878 .6219 L F
0 g
.49878 .6219 m
.50461 .62272 L
s
.81167 .63538 m .81074 .62993 L .7951 .62991 L .734 .496 .569 r
F
0 g
.81074 .62993 m
.82468 .63198 L
s
.4604 .48698 m .45177 .49145 L .45199 .49801 L .111 .021 .463 r
F
.4604 .48698 m .46016 .48038 L .45177 .49145 L F
0 g
.44892 .50301 m
.45177 .49145 L
s
.57397 .61244 m .57336 .60702 L .58385 .60007 L .406 .262 .57 r
F
0 g
.56333 .61127 m
.57336 .60702 L
s
.75034 .37643 m .78714 .37277 L .75248 .37095 L .643 .737 .917 r
F
.38465 .3216 m .38492 .34491 L .39312 .32425 L .644 .737 .916 r
F
.38465 .3216 m .36815 .33971 L .38492 .34491 L F
.35868 .74903 m .37315 .74669 L .35938 .74587 L .595 .768 .962 r
F
.34527 .74663 m .35868 .74903 L .35938 .74587 L F
.53909 .48677 m .53289 .47135 L .53201 .48642 L .656 .78 .94 r
F
.53909 .48677 m .54719 .47208 L .53289 .47135 L F
.41112 .32519 m .4205 .34677 L .43704 .34332 L .644 .737 .916 r
F
.40215 .32547 m .4205 .34677 L .41112 .32519 L F
0 g
.25554 .43119 m
.25868 .39573 L
s
.6126 .50103 m .60501 .48381 L .6055 .4904 L .983 .702 .336 r
F
0 g
.6126 .50103 m
.61409 .51239 L
s
.24399 .37596 m .23243 .35462 L .21616 .3581 L .642 .739 .919 r
F
.25284 .37571 m .23243 .35462 L .24399 .37596 L F
.47532 .36211 m .49266 .34135 L .4921 .34951 L .306 .125 .464 r
F
.47472 .37028 m .47532 .36211 L .4921 .34951 L F
.45089 .34547 m .47532 .36211 L .4921 .34951 L .643 .737 .917 r
F
.43652 .35166 m .47532 .36211 L .45089 .34547 L F
0 g
.46327 .36721 m
.47532 .36211 L
s
.34955 .63706 m .33304 .63159 L .33331 .63705 L .733 .499 .574 r
F
0 g
.31699 .63361 m
.33304 .63159 L
s
.33304 .63159 m
.34925 .6316 L
s
.34955 .63706 m
.36476 .63909 L
s
.26186 .3769 m .25035 .35408 L .25284 .37571 L .642 .739 .919 r
F
.26186 .3769 m .26861 .35652 L .25035 .35408 L F
0 g
.24833 .43107 m
.25157 .39537 L
s
.48464 .50055 m .45221 .5046 L .47893 .50783 L .655 .782 .942 r
F
0 g
.33331 .63705 m
.34955 .63706 L
s
.52486 .48708 m .51845 .4727 L .50493 .47602 L .656 .78 .94 r
F
.53201 .48642 m .51845 .4727 L .52486 .48708 L F
0 g
.60145 .76355 m
.61226 .76356 L
s
.61226 .76356 m
.6229 .76483 L
s
.65233 .34622 m .61412 .35553 L .64868 .35734 L .644 .736 .916 r
F
.65233 .34622 m .61927 .33878 L .61412 .35553 L F
.61903 .34697 m .61412 .35553 L .61387 .36369 L 0 0 .21 r
F
0 g
.61474 .36087 m
.61507 .36375 L
s
.61903 .34697 m .61927 .33878 L .61412 .35553 L 0 0 .21 r
F
.65753 .47811 m .67306 .47839 L .67366 .48494 L .869 .595 .521 r
F
.65753 .47811 m .65695 .47154 L .67306 .47839 L F
0 g
.67306 .47839 m
.67975 .47981 L
s
.20271 .36424 m .1613 .36023 L .19301 .37257 L .642 .739 .919 r
F
.69025 .4781 m .69351 .49554 L .70317 .48085 L .655 .782 .942 r
F
.69025 .4781 m .67427 .4915 L .69351 .49554 L F
0 g
.69351 .49554 m
.71461 .49659 L
s
.75634 .48312 m .77424 .46901 L .77502 .47555 L .525 .342 .575 r
F
.75709 .48967 m .75634 .48312 L .77502 .47555 L F
.74522 .4703 m .75634 .48312 L .77502 .47555 L .655 .781 .941 r
F
.73123 .47364 m .75634 .48312 L .74522 .4703 L F
0 g
.7461 .48555 m
.75634 .48312 L
s
.53201 .48642 m .53289 .47135 L .51845 .4727 L .656 .78 .94 r
F
.68517 .35362 m .64868 .35734 L .68325 .35915 L .644 .736 .916 r
F
.68517 .35362 m .65233 .34622 L .64868 .35734 L F
.20553 .34809 m .17885 .3314 L .16454 .3441 L .643 .737 .917 r
F
.21886 .34195 m .17885 .3314 L .20553 .34809 L F
.25284 .37571 m .25035 .35408 L .23243 .35462 L .642 .739 .919 r
F
.67843 .46017 m .67329 .47819 L .68913 .46479 L .656 .78 .94 r
F
.67843 .46017 m .65727 .47138 L .67329 .47819 L F
.54608 .4946 m .54767 .47853 L .53951 .49325 L .655 .781 .941 r
F
.54608 .4946 m .5609 .48127 L .54767 .47853 L F
.55202 .5034 m .56132 .48788 L .54646 .50117 L .655 .782 .942 r
F
.55202 .5034 m .57246 .49242 L .56132 .48788 L F
.31268 .37884 m .32436 .35531 L .30092 .36939 L .642 .739 .919 r
F
.31268 .37884 m .34192 .3697 L .32436 .35531 L F
.75239 .36277 m .78676 .35326 L .75217 .35712 L .644 .736 .916 r
F
.75239 .36277 m .78696 .36459 L .78676 .35326 L F
0 g
.25391 .44955 m
.25554 .43119 L
s
.82154 .3664 m .8213 .34119 L .82157 .34937 L 0 0 .055 r
F
.78696 .36459 m .82157 .34937 L .78676 .35326 L .644 .736 .916 r
F
.78696 .36459 m .82154 .3664 L .82157 .34937 L F
0 g
.24668 .44913 m
.24833 .43107 L
s
.7534 .74949 m .75363 .74978 L .75362 .75443 L .752 .608 .039 r
F
.7534 .74949 m .7534 .74483 L .75363 .74978 L F
.76729 .74566 m .75363 .74978 L .7674 .74896 L .598 .766 .96 r
F
.76729 .74566 m .7534 .74483 L .75363 .74978 L F
0 g
.75363 .74978 m
.75649 .75426 L
s
.5347 .37181 m .50821 .36442 L .50769 .3726 L .664 .422 .544 r
F
0 g
.48251 .37769 m
.50769 .3726 L
s
.5347 .37181 m .53515 .36362 L .50821 .36442 L .664 .422 .544 r
F
0 g
.48308 .36953 m
.50821 .36442 L
s
.8218 .37458 m .82154 .3664 L .82157 .34937 L 0 0 .055 r
F
0 g
.8181 .37439 m
.82154 .3664 L
s
.56151 .37542 m .56189 .36723 L .53515 .36362 L .732 .481 .548 r
F
0 g
.56189 .36723 m
.5864 .37495 L
s
.78124 .7528 m .7694 .75679 L .78222 .75439 L .597 .767 .96 r
F
.78124 .7528 m .76741 .75362 L .7694 .75679 L F
.19481 .48683 m .17878 .50195 L .20165 .49397 L .656 .78 .94 r
F
.19481 .48683 m .16838 .49132 L .17878 .50195 L F
0 g
.17878 .50195 m
.19366 .51082 L
s
.79601 .63537 m .77889 .63193 L .77978 .6374 L .674 .455 .581 r
F
0 g
.76417 .64131 m
.77978 .6374 L
s
.79601 .63537 m .7951 .62991 L .77889 .63193 L .674 .455 .581 r
F
0 g
.7633 .63585 m
.77889 .63193 L
s
.30308 .75189 m .29126 .75599 L .30441 .75517 L .593 .769 .963 r
F
.30308 .75189 m .28921 .75106 L .29126 .75599 L F
0 g
.29126 .75599 m
.29598 .76071 L
s
.61082 .86082 m .61047 .85801 L .61424 .85752 L .672 .447 .572 r
F
.60711 .86086 m .61047 .85801 L .61082 .86082 L .73 .489 .563 r
F
.60711 .86086 m .60676 .85805 L .61047 .85801 L F
.61075 .85583 m .61047 .85801 L .61424 .85752 L .655 .815 .96 r
F
.60827 .85586 m .61047 .85801 L .61075 .85583 L F
.60827 .85586 m .60676 .85805 L .61047 .85801 L F
.83378 .75456 m .83662 .74514 L .83671 .7498 L 0 0 .387 r
F
.83387 .75922 m .83378 .75456 L .83671 .7498 L F
.82091 .75215 m .83378 .75456 L .83671 .7498 L .598 .766 .96 r
F
0 g
.82826 .7588 m
.83378 .75456 L
s
.78121 .74183 m .76753 .74431 L .78125 .74348 L .599 .766 .959 r
F
.78121 .74183 m .76741 .74101 L .76753 .74431 L F
.81731 .75964 m .83387 .75922 L .82098 .75681 L .597 .767 .96 r
F
.80623 .75582 m .81731 .75964 L .82098 .75681 L F
.80366 .75698 m .81731 .75964 L .80623 .75582 L F
.61459 .86033 m .61424 .85752 L .6178 .85662 L .609 .402 .576 r
F
.61082 .86082 m .61424 .85752 L .61459 .86033 L .672 .447 .572 r
F
.61326 .85551 m .61424 .85752 L .6178 .85662 L .655 .815 .96 r
F
.61075 .85583 m .61424 .85752 L .61326 .85551 L F
0 g
.61047 .85801 m
.61424 .85752 L
s
.22472 .48591 m .21153 .49995 L .22964 .48894 L .656 .78 .94 r
F
.22472 .48591 m .20165 .49397 L .21153 .49995 L F
.8207 .74748 m .83641 .74512 L .82261 .7443 L .599 .766 .959 r
F
.31747 .74805 m .30495 .75052 L .31812 .7497 L .594 .768 .963 r
F
.31747 .74805 m .30362 .74722 L .30495 .75052 L F
.37135 .76077 m .3729 .75136 L .37244 .75603 L 0 0 .034 r
F
.35787 .75836 m .37135 .76077 L .37244 .75603 L .593 .769 .963 r
F
0 g
.36752 .76498 m
.37135 .76077 L
s
.60049 .85683 m .60302 .85484 L .60336 .85765 L .855 .58 .521 r
F
.60049 .85683 m .60015 .85402 L .60302 .85484 L F
0 g
.60302 .85484 m
.60626 .85523 L
s
.60378 .85221 m .60306 .85481 L .60568 .85276 L .656 .815 .96 r
F
.60378 .85221 m .6002 .85399 L .60306 .85481 L F
.35834 .75371 m .3729 .75136 L .35904 .75053 L .594 .768 .963 r
F
.34485 .75129 m .35834 .75371 L .35904 .75053 L F
.81167 .63538 m .7951 .62991 L .79601 .63537 L .734 .496 .569 r
F
0 g
.77889 .63193 m
.7951 .62991 L
s
.7951 .62991 m
.81074 .62993 L
s
.81167 .63538 m
.82563 .63742 L
s
.6037 .86046 m .60676 .85805 L .60711 .86086 L .789 .532 .548 r
F
.6037 .86046 m .60336 .85765 L .60676 .85805 L F
.606 .85559 m .60676 .85805 L .60827 .85586 L .655 .815 .96 r
F
.606 .85559 m .60336 .85765 L .60676 .85805 L F
0 g
.60676 .85805 m
.61047 .85801 L
s
.31725 .63907 m
.33331 .63705 L
s
.51843 .49521 m .50511 .48249 L .49338 .48755 L .655 .781 .941 r
F
.52518 .49357 m .50511 .48249 L .51843 .49521 L F
.68956 .34046 m .65281 .33815 L .68541 .34552 L .645 .736 .915 r
F
.50157 .61527 m .49929 .62735 L .51006 .61797 L .658 .807 .955 r
F
.50157 .61527 m .48656 .62336 L .49929 .62735 L F
0 g
.49929 .62735 m
.51411 .62941 L
s
.79601 .63537 m
.81167 .63538 L
s
.34527 .74663 m .35938 .74587 L .3456 .74504 L .595 .768 .962 r
F
.58029 .49185 m .59271 .47466 L .57203 .48582 L .655 .781 .941 r
F
.58029 .49185 m .60501 .48381 L .59271 .47466 L F
.57397 .61244 m .58385 .60007 L .58447 .60551 L .406 .262 .57 r
F
.57458 .61788 m .57397 .61244 L .58447 .60551 L F
.55997 .60615 m .57397 .61244 L .58447 .60551 L .658 .806 .954 r
F
.5511 .60993 m .57397 .61244 L .55997 .60615 L F
0 g
.56386 .61672 m
.57397 .61244 L
s
.5355 .51306 m
.53557 .5363 L
s
.62093 .85537 m .62058 .85256 L .62306 .85104 L .42 .27 .569 r
F
.6178 .85662 m .62058 .85256 L .62093 .85537 L .531 .347 .577 r
F
0 g
.61941 .85302 m
.62058 .85256 L
s
.75191 .349 m .7813 .33424 L .74936 .34359 L .645 .736 .915 r
F
.75191 .349 m .78623 .34514 L .7813 .33424 L F
.61816 .85943 m .6178 .85662 L .62093 .85537 L .531 .347 .577 r
F
.61459 .86033 m .6178 .85662 L .61816 .85943 L .609 .402 .576 r
F
.61564 .8549 m .6178 .85662 L .62093 .85537 L .655 .815 .96 r
F
.61326 .85551 m .6178 .85662 L .61564 .8549 L F
0 g
.61424 .85752 m
.6178 .85662 L
s
.52835 .51322 m
.52837 .53619 L
s
.51291 .50427 m .49368 .49415 L .48464 .50055 L .655 .782 .942 r
F
.51876 .50179 m .49368 .49415 L .51291 .50427 L F
.49328 .48107 m .46052 .48049 L .48433 .48746 L .656 .78 .94 r
F
.40136 .33376 m .40198 .35565 L .41985 .35512 L .643 .737 .917 r
F
.39227 .33252 m .40198 .35565 L .40136 .33376 L F
.39227 .33252 m .38402 .35324 L .40198 .35565 L F
.33052 .48122 m .33051 .47467 L .33244 .46277 L 0 0 .144 r
F
0 g
.3257 .48182 m
.33051 .47467 L
s
.303 .47129 m .3301 .47462 L .33202 .46278 L .657 .779 .938 r
F
.1771 .33932 m .16407 .34391 L .16269 .35205 L .194 .008 .386 r
F
.1771 .33932 m .17845 .33115 L .16407 .34391 L F
0 g
.15635 .35899 m
.16407 .34391 L
s
.6111 .85865 m .61082 .86082 L .61459 .86033 L .655 .815 .961 r
F
.60862 .85868 m .61082 .86082 L .6111 .85865 L F
.60862 .85868 m .60711 .86086 L .61082 .86082 L F
.48437 .49396 m .4604 .48698 L .45199 .49801 L .655 .781 .941 r
F
.46063 .49359 m .45199 .49801 L .45221 .5046 L .111 .021 .463 r
F
.46063 .49359 m .4604 .48698 L .45199 .49801 L F
0 g
.44913 .50954 m
.45199 .49801 L
s
.29839 .48528 m .33052 .48122 L .30324 .47788 L .657 .779 .939 r
F
.61361 .85832 m .61459 .86033 L .61816 .85943 L .655 .815 .961 r
F
.6111 .85865 m .61459 .86033 L .61361 .85832 L F
0 g
.61082 .86082 m
.61459 .86033 L
s
.53951 .49325 m .53326 .4778 L .53237 .4929 L .655 .781 .941 r
F
.53951 .49325 m .54767 .47853 L .53326 .4778 L F
.60083 .85964 m .60336 .85765 L .6037 .86046 L .855 .58 .521 r
F
.60083 .85964 m .60049 .85683 L .60336 .85765 L F
.60409 .85504 m .60336 .85765 L .606 .85559 L .655 .815 .96 r
F
.60409 .85504 m .60049 .85683 L .60336 .85765 L F
0 g
.60336 .85765 m
.60676 .85805 L
s
.7673 .75032 m .75362 .75443 L .76741 .75362 L .597 .767 .96 r
F
.7673 .75032 m .7534 .74949 L .75362 .75443 L F
0 g
.75362 .75443 m
.75665 .75917 L
s
.53557 .5363 m
.5357 .57735 L
s
.60635 .85841 m .60711 .86086 L .60862 .85868 L .655 .815 .961 r
F
.60635 .85841 m .6037 .86046 L .60711 .86086 L F
0 g
.60711 .86086 m
.61082 .86082 L
s
.59835 .85564 m .60015 .85402 L .60049 .85683 L .928 .635 .466 r
F
.59835 .85564 m .59801 .85282 L .60015 .85402 L F
0 g
.60015 .85402 m
.60302 .85484 L
s
.52837 .53619 m
.5284 .57773 L
s
.60236 .85142 m .6002 .85399 L .60378 .85221 L .656 .815 .96 r
F
.60236 .85142 m .59807 .8528 L .6002 .85399 L F
.56151 .37542 m .53515 .36362 L .5347 .37181 L .732 .481 .548 r
F
0 g
.53515 .36362 m
.56189 .36723 L
s
.56151 .37542 m
.58608 .38312 L
s
.50821 .36442 m
.53515 .36362 L
s
.32687 .82706 m
.32694 .82597 L
s
.62093 .85537 m .62306 .85104 L .62341 .85385 L .42 .27 .569 r
F
.62129 .85818 m .62093 .85537 L .62341 .85385 L F
.61816 .85943 m .62093 .85537 L .62129 .85818 L .531 .347 .577 r
F
.61773 .85407 m .62093 .85537 L .62341 .85385 L .655 .815 .96 r
F
.61564 .8549 m .62093 .85537 L .61773 .85407 L F
0 g
.6178 .85662 m
.62093 .85537 L
s
.52518 .49357 m .51872 .47915 L .50511 .48249 L .655 .781 .941 r
F
.53237 .4929 m .51872 .47915 L .52518 .49357 L F
.78117 .74649 m .7674 .74896 L .78121 .74814 L .598 .766 .96 r
F
.78117 .74649 m .76729 .74566 L .7674 .74896 L F
.83387 .75922 m .83671 .7498 L .83681 .75447 L 0 0 .387 r
F
.82098 .75681 m .83387 .75922 L .83681 .75447 L .597 .767 .96 r
F
0 g
.82834 .76345 m
.83387 .75922 L
s
.616 .85772 m .61816 .85943 L .62129 .85818 L .655 .815 .961 r
F
.61361 .85832 m .61816 .85943 L .616 .85772 L F
0 g
.61459 .86033 m
.61816 .85943 L
s
.82091 .75215 m .83671 .7498 L .82283 .74897 L .598 .766 .96 r
F
.808 .74974 m .82091 .75215 L .82283 .74897 L F
.65811 .4847 m .67366 .48494 L .67427 .4915 L .869 .595 .521 r
F
.65811 .4847 m .65753 .47811 L .67366 .48494 L F
.67884 .46687 m .67366 .48494 L .68961 .4715 L .655 .781 .941 r
F
.67884 .46687 m .65753 .47811 L .67366 .48494 L F
0 g
.67366 .48494 m
.68041 .48636 L
s
.75709 .48967 m .77502 .47555 L .77581 .48212 L .525 .342 .575 r
F
.74596 .47689 m .75709 .48967 L .77581 .48212 L .655 .782 .942 r
F
.73194 .48022 m .75709 .48967 L .74596 .47689 L F
0 g
.73625 .49459 m
.75709 .48967 L
s
.31695 .75271 m .30441 .75517 L .3176 .75436 L .593 .769 .963 r
F
.31695 .75271 m .30308 .75189 L .30441 .75517 L F
0 g
.77978 .6374 m
.79601 .63537 L
s
.53237 .4929 m .53326 .4778 L .51872 .47915 L .655 .781 .941 r
F
.38373 .32986 m .38402 .35324 L .39227 .33252 L .643 .737 .917 r
F
.38373 .32986 m .36711 .34802 L .38402 .35324 L F
.35787 .75836 m .37244 .75603 L .35857 .7552 L .593 .769 .963 r
F
.34436 .75596 m .35787 .75836 L .35857 .7552 L F
.34311 .75737 m .35787 .75836 L .34436 .75596 L F
.62341 .85385 m .62306 .85104 L .62472 .84935 L .236 .141 .538 r
F
0 g
.62058 .85256 m
.62306 .85104 L
s
.61899 .85023 m .623 .85103 L .62465 .84935 L .656 .815 .96 r
F
.61735 .85124 m .623 .85103 L .61899 .85023 L F
.54646 .50117 m .54806 .48514 L .53988 .49983 L .655 .782 .942 r
F
.54646 .50117 m .56132 .48788 L .54806 .48514 L F
.4104 .33347 m .41985 .35512 L .43652 .35166 L .643 .737 .917 r
F
.40136 .33376 m .41985 .35512 L .4104 .33347 L F
.3773 .31768 m .36815 .33971 L .38465 .3216 L .644 .737 .916 r
F
.3773 .31768 m .3535 .33203 L .36815 .33971 L F
.34485 .75129 m .35904 .75053 L .34518 .7497 L .594 .768 .963 r
F
.29054 .74159 m .29032 .74175 L .28976 .7464 L 0 0 0 r
F
0 g
.29046 .74209 m
.2923 .74655 L
s
.29054 .74159 m .29109 .73692 L .29032 .74175 L 0 0 0 r
F
.30484 .73939 m .29052 .74176 L .30429 .74258 L .595 .768 .962 r
F
.30484 .73939 m .2913 .73696 L .29052 .74176 L F
.31836 .74181 m .30429 .74258 L .31806 .7434 L F
.31836 .74181 m .30484 .73939 L .30429 .74258 L F
.41112 .32519 m .43704 .34332 L .41947 .32342 L .644 .737 .916 r
F
.41947 .32342 m .43704 .34332 L .45131 .33715 L F
.60736 .85043 m .60378 .85221 L .60568 .85276 L .656 .815 .96 r
F
.60443 .85786 m .6037 .86046 L .60635 .85841 L .655 .815 .961 r
F
.60443 .85786 m .60083 .85964 L .6037 .86046 L F
0 g
.6037 .86046 m
.60711 .86086 L
s
.3456 .74504 m .35819 .74257 L .34499 .7434 L .595 .768 .962 r
F
.3456 .74504 m .35938 .74587 L .35819 .74257 L F
.47631 .6122 m .48559 .61245 L .48607 .6179 L .928 .647 .488 r
F
.47631 .6122 m .47583 .60673 L .48559 .61245 L F
0 g
.48559 .61245 m
.49224 .61456 L
s
.35938 .74587 m .37142 .74174 L .35819 .74257 L .595 .768 .962 r
F
.35938 .74587 m .37315 .74669 L .37142 .74174 L F
.47472 .37028 m .4921 .34951 L .49154 .35771 L .306 .125 .464 r
F
.45022 .35367 m .47472 .37028 L .49154 .35771 L .643 .738 .918 r
F
.43582 .35984 m .47472 .37028 L .45022 .35367 L F
0 g
.45319 .37934 m
.47472 .37028 L
s
.3729 .75136 m .37336 .7467 L .37162 .74173 L .973 .79 .365 r
F
0 g
.37229 .75132 m
.37267 .74966 L
s
.49425 .60042 m .47611 .60664 L .48581 .61233 L .659 .806 .953 r
F
.57458 .61788 m .58447 .60551 L .5851 .61096 L .406 .262 .57 r
F
.56056 .61161 m .57458 .61788 L .5851 .61096 L .658 .807 .955 r
F
.55168 .61539 m .57458 .61788 L .56056 .61161 L F
0 g
.56129 .62348 m
.57458 .61788 L
s
.59869 .85846 m .60049 .85683 L .60083 .85964 L .928 .635 .466 r
F
.59869 .85846 m .59835 .85564 L .60049 .85683 L F
.60266 .85425 m .60049 .85683 L .60409 .85504 L .655 .815 .96 r
F
.60266 .85425 m .59835 .85564 L .60049 .85683 L F
0 g
.60049 .85683 m
.60336 .85765 L
s
.62129 .85818 m .62341 .85385 L .62377 .85666 L .42 .27 .569 r
F
.61809 .85688 m .62129 .85818 L .62377 .85666 L .655 .815 .961 r
F
.616 .85772 m .62129 .85818 L .61809 .85688 L F
0 g
.61816 .85943 m
.62129 .85818 L
s
.51876 .50179 m .50542 .4891 L .49368 .49415 L .655 .782 .942 r
F
.52553 .50015 m .50542 .4891 L .51876 .50179 L F
.65217 .35441 m .61387 .36369 L .64852 .3655 L .643 .737 .917 r
F
.65217 .35441 m .61903 .34697 L .61387 .36369 L F
0 g
.61387 .36369 m
.61582 .38045 L
s
.6851 .36179 m .64852 .3655 L .68317 .36732 L .643 .737 .917 r
F
.6851 .36179 m .65217 .35441 L .64852 .3655 L F
.58073 .49842 m .59319 .48128 L .57246 .49242 L .655 .782 .942 r
F
.58073 .49842 m .6055 .4904 L .59319 .48128 L F
.62341 .85385 m .62472 .84935 L .62508 .85216 L .236 .141 .538 r
F
.62377 .85666 m .62341 .85385 L .62508 .85216 L F
.61939 .85305 m .62341 .85385 L .62508 .85216 L .655 .815 .96 r
F
.61773 .85407 m .62341 .85385 L .61939 .85305 L F
0 g
.62093 .85537 m
.62341 .85385 L
s
.8002 .82446 m
.80029 .82555 L
s
.60665 .85003 m .60378 .85221 L .60736 .85043 L .656 .815 .96 r
F
.60665 .85003 m .60236 .85142 L .60378 .85221 L F
.20399 .35606 m .1771 .33932 L .16269 .35205 L .642 .738 .918 r
F
.21741 .3499 m .1771 .33932 L .20399 .35606 L F
.59708 .85416 m .59801 .85282 L .59835 .85564 L .977 .678 .323 r
F
.59708 .85416 m .59674 .85135 L .59801 .85282 L F
0 g
.59801 .85282 m
.60015 .85402 L
s
.60153 .85044 m .59807 .8528 L .60236 .85142 L .656 .815 .96 r
F
.60153 .85044 m .59682 .85133 L .59807 .8528 L F
.75248 .37095 m .78694 .36147 L .75227 .36531 L .643 .737 .917 r
F
.75248 .37095 m .78714 .37277 L .78694 .36147 L F
.8218 .37458 m .82157 .34937 L .82184 .35759 L 0 0 .055 r
F
.78714 .37277 m .82184 .35759 L .78694 .36147 L .643 .737 .917 r
F
.78714 .37277 m .8218 .37458 L .82184 .35759 L F
0 g
.81475 .39088 m
.8218 .37458 L
s
.60769 .85325 m .60409 .85504 L .606 .85559 L .655 .815 .96 r
F
.77502 .47555 m .77424 .46901 L .78956 .45921 L .419 .266 .566 r
F
0 g
.76325 .47348 m
.77424 .46901 L
s
.50769 .3726 m
.5347 .37181 L
s
.30196 .3612 m .30275 .33541 L .28696 .35355 L .642 .738 .918 r
F
.30196 .3612 m .32535 .34708 L .30275 .33541 L F
.7812 .75115 m .76741 .75362 L .78124 .7528 L .597 .767 .96 r
F
.7812 .75115 m .7673 .75032 L .76741 .75362 L F
.49338 .48755 m .4604 .48698 L .48437 .49396 L .655 .781 .941 r
F
.33052 .48122 m .33244 .46277 L .33246 .46935 L 0 0 .144 r
F
.33052 .48778 m .33052 .48122 L .33246 .46935 L F
.30324 .47788 m .33052 .48122 L .33246 .46935 L .657 .779 .939 r
F
0 g
.32567 .4884 m
.33052 .48122 L
s
.5347 .37181 m
.56151 .37542 L
s
.61899 .85023 m .62465 .84935 L .62009 .84911 L .656 .815 .96 r
F
.7568 .45849 m .77398 .46885 L .78922 .45911 L .656 .78 .94 r
F
.74437 .4636 m .77398 .46885 L .7568 .45849 L F
.61138 .85647 m .6111 .85865 L .61361 .85832 L .655 .815 .961 r
F
.61013 .85648 m .6111 .85865 L .61138 .85647 L F
.61013 .85648 m .60862 .85868 L .6111 .85865 L F
.82098 .75681 m .83681 .75447 L .8229 .75364 L .597 .767 .96 r
F
.80806 .7544 m .82098 .75681 L .8229 .75364 L F
.80623 .75582 m .82098 .75681 L .80806 .7544 L F
.61264 .8563 m .61361 .85832 L .616 .85772 L .655 .815 .961 r
F
.61138 .85647 m .61361 .85832 L .61264 .8563 L F
.48464 .50055 m .46063 .49359 L .45221 .5046 L .655 .782 .942 r
F
0 g
.44935 .5161 m
.45221 .5046 L
s
.29834 .49185 m .33052 .48778 L .3032 .48447 L .656 .78 .94 r
F
.27332 .48485 m .29834 .49185 L .3032 .48447 L F
.26924 .48807 m .29834 .49185 L .27332 .48485 L F
.603 .85707 m .60083 .85964 L .60443 .85786 L .655 .815 .961 r
F
.603 .85707 m .59869 .85846 L .60083 .85964 L F
0 g
.60083 .85964 m
.6037 .86046 L
s
.808 .74974 m .82283 .74897 L .80894 .74814 L .598 .766 .96 r
F
.76918 .73781 m .75362 .74019 L .76741 .74101 L .599 .766 .959 r
F
.75602 .74001 m .75341 .74018 L .7534 .74483 L 0 0 .341 r
F
0 g
.7536 .74446 m
.75362 .74484 L
s
.76918 .73781 m .75622 .73538 L .75362 .74019 L .599 .766 .959 r
F
.75602 .74001 m .75603 .73534 L .75341 .74018 L 0 0 .341 r
F
.53988 .49983 m .53363 .48442 L .53273 .49948 L .655 .782 .942 r
F
.53988 .49983 m .54806 .48514 L .53363 .48442 L F
.78211 .74024 m .76741 .74101 L .78121 .74183 L .599 .766 .959 r
F
.78211 .74024 m .76918 .73781 L .76741 .74101 L F
.62508 .85216 m .62472 .84935 L .62544 .84761 L 0 0 .423 r
F
0 g
.62306 .85104 m
.62472 .84935 L
s
.62009 .84911 m .62465 .84935 L .62537 .84762 L .656 .815 .96 r
F
.609 .85635 m .60862 .85868 L .61013 .85648 L .655 .815 .961 r
F
.609 .85635 m .60635 .85841 L .60862 .85868 L F
.80881 .74348 m .82264 .741 L .80881 .74183 L .599 .766 .959 r
F
.80881 .74348 m .82261 .7443 L .82264 .741 L F
.34436 .75596 m .35857 .7552 L .34469 .75437 L .593 .769 .963 r
F
.30417 .74402 m .28976 .7464 L .30362 .74722 L .594 .768 .963 r
F
.30417 .74402 m .29054 .74159 L .28976 .7464 L F
.28998 .74626 m .28976 .7464 L .28921 .75106 L 0 0 0 r
F
0 g
.2899 .74674 m
.29176 .75121 L
s
.28998 .74626 m .29054 .74159 L .28976 .7464 L 0 0 0 r
F
.82261 .7443 m .83651 .74016 L .82264 .741 L .599 .766 .959 r
F
.82261 .7443 m .83641 .74512 L .83651 .74016 L F
.31777 .74645 m .30362 .74722 L .31747 .74805 L .594 .768 .963 r
F
.31777 .74645 m .30417 .74402 L .30362 .74722 L F
.61383 .856 m .616 .85772 L .61809 .85688 L .655 .815 .961 r
F
.61264 .8563 m .616 .85772 L .61383 .856 L F
.83671 .7498 m .83662 .74514 L .83672 .74015 L 0 0 .046 r
F
0 g
.83387 .74963 m
.83662 .74514 L
s
.34518 .7497 m .35785 .74723 L .34457 .74805 L .594 .768 .963 r
F
.34518 .7497 m .35904 .75053 L .35785 .74723 L F
.68935 .34855 m .65233 .34622 L .68517 .35362 L .644 .736 .916 r
F
.35904 .75053 m .37116 .7464 L .35785 .74723 L .594 .768 .963 r
F
.35904 .75053 m .3729 .75136 L .37116 .7464 L F
.3729 .75136 m .37162 .74173 L .37116 .7464 L .973 .79 .365 r
F
.37244 .75603 m .3729 .75136 L .37116 .7464 L F
0 g
.37183 .75599 m
.37222 .75432 L
s
.52553 .50015 m .51906 .48578 L .50542 .4891 L .655 .782 .942 r
F
.53273 .49948 m .51906 .48578 L .52553 .50015 L F
.31957 .74038 m .30484 .73939 L .31836 .74181 L .595 .768 .962 r
F
.62377 .85666 m .62508 .85216 L .62544 .85498 L .236 .141 .538 r
F
.61974 .85587 m .62377 .85666 L .62544 .85498 L .655 .815 .961 r
F
.61809 .85688 m .62377 .85666 L .61974 .85587 L F
0 g
.62129 .85818 m
.62377 .85666 L
s
.60698 .85286 m .60409 .85504 L .60769 .85325 L .655 .815 .96 r
F
.60698 .85286 m .60266 .85425 L .60409 .85504 L F
.75217 .35712 m .78179 .34233 L .7496 .3517 L .644 .736 .916 r
F
.75217 .35712 m .78676 .35326 L .78179 .34233 L F
.60624 .84954 m .60236 .85142 L .60665 .85003 L .656 .815 .96 r
F
.60624 .84954 m .60153 .85044 L .60236 .85142 L F
.59742 .85698 m .59835 .85564 L .59869 .85846 L .977 .678 .323 r
F
.59742 .85698 m .59708 .85416 L .59835 .85564 L F
.60182 .85326 m .59835 .85564 L .60266 .85425 L .655 .815 .96 r
F
.60182 .85326 m .59708 .85416 L .59835 .85564 L F
0 g
.59835 .85564 m
.60049 .85683 L
s
.5714 .47937 m .57531 .4613 L .56034 .47482 L .656 .78 .94 r
F
.5714 .47937 m .59193 .46824 L .57531 .4613 L F
.34499 .7434 m .35519 .73937 L .34348 .7418 L .595 .768 .962 r
F
.34499 .7434 m .35819 .74257 L .35519 .73937 L F
.67946 .47349 m .67427 .4915 L .69025 .4781 L .655 .782 .942 r
F
.67946 .47349 m .65811 .4847 L .67427 .4915 L F
0 g
.67427 .4915 m
.69351 .49554 L
s
.47679 .61768 m .48607 .6179 L .48656 .62336 L .928 .647 .488 r
F
.47679 .61768 m .47631 .6122 L .48607 .6179 L F
.49457 .60596 m .48607 .6179 L .50105 .60979 L .658 .806 .954 r
F
.49457 .60596 m .47631 .6122 L .48607 .6179 L F
0 g
.48607 .6179 m
.49278 .62001 L
s
.60804 .85607 m .60635 .85841 L .609 .85635 L .655 .815 .961 r
F
.60804 .85607 m .60443 .85786 L .60635 .85841 L F
.40056 .34197 m .40119 .36382 L .41911 .36329 L .643 .738 .918 r
F
.39145 .34074 m .40119 .36382 L .40056 .34197 L F
.39145 .34074 m .38319 .3614 L .40119 .36382 L F
.53273 .49948 m .53363 .48442 L .51906 .48578 L .655 .782 .942 r
F
.61939 .85305 m .62508 .85216 L .62049 .85193 L .655 .815 .96 r
F
.17573 .34753 m .16269 .35205 L .1613 .36023 L .194 .008 .386 r
F
.17573 .34753 m .1771 .33932 L .16269 .35205 L F
0 g
.15497 .36709 m
.16269 .35205 L
s
.60501 .48381 m .60453 .47724 L .59224 .46807 L .941 .656 .473 r
F
0 g
.60453 .47724 m
.6116 .48794 L
s
.62009 .84911 m .62537 .84762 L .62057 .84796 L .656 .815 .96 r
F
.61488 .85558 m .61809 .85688 L .61974 .85587 L .655 .815 .961 r
F
.61383 .856 m .61809 .85688 L .61488 .85558 L F
0 g
.3303 .82396 m
.33037 .82278 L
s
.68956 .34046 m .66096 .32794 L .65281 .33815 L .645 .736 .915 r
F
.69567 .33623 m .66096 .32794 L .68956 .34046 L F
0 g
.32291 .82386 m
.32294 .82328 L
s
.32299 .82251 m
.32311 .82047 L
s
.32316 .81953 m
.32712 .75239 L
s
.62508 .85216 m .62544 .84761 L .62581 .85043 L 0 0 .423 r
F
.62544 .85498 m .62508 .85216 L .62581 .85043 L F
.62049 .85193 m .62508 .85216 L .62581 .85043 L .655 .815 .96 r
F
0 g
.62341 .85385 m
.62508 .85216 L
s
.74936 .34359 m .77191 .3245 L .74462 .33879 L .645 .736 .915 r
F
.74936 .34359 m .7813 .33424 L .77191 .3245 L F
.34192 .3697 m .34286 .36149 L .32535 .34708 L .922 .668 .537 r
F
0 g
.34286 .36149 m
.35294 .37584 L
s
.66096 .32794 m .62001 .33074 L .65281 .33815 L .645 .736 .915 r
F
.58447 .60551 m .58385 .60007 L .59086 .59222 L .21 .123 .533 r
F
0 g
.57528 .60575 m
.58385 .60007 L
s
.59679 .8525 m .59674 .85135 L .59708 .85416 L .753 .538 0 r
F
.59679 .8525 m .59645 .84968 L .59674 .85135 L F
0 g
.59674 .85135 m
.59801 .85282 L
s
.60133 .84933 m .59682 .85133 L .60153 .85044 L .656 .815 .96 r
F
.60133 .84933 m .59652 .84967 L .59682 .85133 L F
.21886 .34195 m .1989 .32199 L .17885 .3314 L .643 .737 .917 r
F
.23497 .33847 m .1989 .32199 L .21886 .34195 L F
.78623 .34514 m .81365 .32476 L .7813 .33424 L .645 .736 .915 r
F
.78623 .34514 m .82078 .34125 L .81365 .32476 L F
.60733 .85567 m .60443 .85786 L .60804 .85607 L .655 .815 .961 r
F
.60733 .85567 m .603 .85707 L .60443 .85786 L F
.60656 .85236 m .60266 .85425 L .60698 .85286 L .655 .815 .96 r
F
.60656 .85236 m .60182 .85326 L .60266 .85425 L F
.60217 .85608 m .59869 .85846 L .603 .85707 L .655 .815 .961 r
F
.60217 .85608 m .59742 .85698 L .59869 .85846 L F
0 g
.59869 .85846 m
.60083 .85964 L
s
.80806 .7544 m .8229 .75364 L .809 .75281 L .597 .767 .96 r
F
.76907 .74245 m .7534 .74483 L .76729 .74566 L .598 .766 .96 r
F
.75602 .74469 m .7534 .74483 L .7534 .74949 L 0 0 .341 r
F
0 g
.7536 .74912 m
.75362 .74951 L
s
.76907 .74245 m .75602 .74001 L .7534 .74483 L .598 .766 .96 r
F
.75602 .74469 m .75602 .74001 L .7534 .74483 L 0 0 .341 r
F
.78208 .74488 m .76729 .74566 L .78117 .74649 L .598 .766 .96 r
F
.78208 .74488 m .76907 .74245 L .76729 .74566 L F
.60614 .84899 m .60153 .85044 L .60624 .84954 L .656 .815 .96 r
F
.60614 .84899 m .60133 .84933 L .60153 .85044 L F
.303 .47129 m .33202 .46278 L .30414 .46338 L .657 .779 .938 r
F
.27573 .46794 m .303 .47129 L .30414 .46338 L F
.37632 .32594 m .36711 .34802 L .38373 .32986 L .643 .737 .917 r
F
.37632 .32594 m .35235 .34031 L .36711 .34802 L F
.80894 .74814 m .82286 .74566 L .80894 .74649 L .598 .766 .96 r
F
.80894 .74814 m .82283 .74897 L .82286 .74566 L F
.30363 .74869 m .28921 .75106 L .30308 .75189 L .593 .769 .963 r
F
.30363 .74869 m .28998 .74626 L .28921 .75106 L F
0 g
.28921 .75106 m
.29126 .75599 L
s
.83671 .7498 m .83672 .74015 L .83681 .74482 L 0 0 .046 r
F
.82283 .74897 m .83681 .74482 L .82286 .74566 L .598 .766 .96 r
F
0 g
.83662 .74514 m
.83662 .74488 L
s
.82283 .74897 m .83671 .7498 L .83681 .74482 L .598 .766 .96 r
F
.61974 .85587 m .62544 .85498 L .62085 .85475 L .655 .815 .961 r
F
.6157 .85508 m .61974 .85587 L .62085 .85475 L F
.61488 .85558 m .61974 .85587 L .6157 .85508 L F
.38289 .33808 m .38319 .3614 L .39145 .34074 L .643 .738 .918 r
F
.38289 .33808 m .36624 .35619 L .38319 .3614 L F
.31724 .75112 m .30308 .75189 L .31695 .75271 L .593 .769 .963 r
F
.31724 .75112 m .30363 .74869 L .30308 .75189 L F
0 g
.61137 .85445 m
.61314 .85429 L
s
.61137 .85445 m
.61137 .85445 L
s
.60965 .85424 m
.61137 .85445 L
s
.83681 .75447 m .83671 .7498 L .83681 .74482 L 0 0 .046 r
F
0 g
.83395 .7543 m
.83671 .7498 L
s
.7839 .7388 m .76918 .73781 L .78211 .74024 L .599 .766 .959 r
F
.62581 .85043 m .62544 .84761 L .62518 .84594 L .725 .515 0 r
F
0 g
.62472 .84935 m
.62542 .84766 L
s
.62057 .84796 m .62537 .84762 L .62511 .84595 L .656 .815 .96 r
F
.40963 .34169 m .41911 .36329 L .43582 .35984 L .643 .738 .918 r
F
.40056 .34197 m .41911 .36329 L .40963 .34169 L F
.41881 .3317 m .43652 .35166 L .45089 .34547 L .643 .737 .917 r
F
.4104 .33347 m .43652 .35166 L .41881 .3317 L F
.62049 .85193 m .62581 .85043 L .62097 .85077 L .655 .815 .96 r
F
.6159 .8517 m .62049 .85193 L .62097 .85077 L F
.16354 .47297 m .16893 .47815 L .16866 .48473 L .985 .761 .361 r
F
.16354 .47297 m .16383 .46637 L .16893 .47815 L F
0 g
.16893 .47815 m
.17436 .48375 L
s
.19229 .46576 m .16933 .47809 L .19554 .4736 L .657 .779 .938 r
F
.19229 .46576 m .16425 .46636 L .16933 .47809 L F
.52597 .60919 m .51999 .61937 L .53071 .61939 L .658 .807 .955 r
F
.80881 .74183 m .82078 .73779 L .80786 .74023 L .599 .766 .959 r
F
.80881 .74183 m .82264 .741 L .82078 .73779 L F
.34469 .75437 m .35737 .7519 L .34408 .75272 L .593 .769 .963 r
F
.34469 .75437 m .35857 .7552 L .35737 .7519 L F
.35857 .7552 m .3707 .75108 L .35737 .7519 L F
.35857 .7552 m .37244 .75603 L .3707 .75108 L F
.77502 .47555 m .78956 .45921 L .79037 .46578 L .419 .266 .566 r
F
.77581 .48212 m .77502 .47555 L .79037 .46578 L F
.75773 .46517 m .77502 .47555 L .79037 .46578 L .655 .781 .941 r
F
.74522 .4703 m .77502 .47555 L .75773 .46517 L F
0 g
.76394 .48004 m
.77502 .47555 L
s
.37244 .75603 m .37116 .7464 L .3707 .75108 L .973 .79 .365 r
F
0 g
.37135 .76077 m
.37244 .75603 L
s
.60858 .85387 m
.60965 .85424 L
s
.31899 .74502 m .30417 .74402 L .31777 .74645 L .594 .768 .963 r
F
.49368 .49415 m .46063 .49359 L .48464 .50055 L .655 .782 .942 r
F
.62057 .84796 m .62511 .84595 L .62039 .84685 L .656 .815 .96 r
F
.61576 .8483 m .62057 .84796 L .62039 .84685 L F
.62544 .85498 m .62581 .85043 L .62617 .85325 L 0 0 .423 r
F
.62085 .85475 m .62544 .85498 L .62617 .85325 L .655 .815 .961 r
F
0 g
.62377 .85666 m
.62544 .85498 L
s
.33052 .48778 m .33246 .46935 L .33247 .47595 L 0 0 .144 r
F
.3032 .48447 m .33052 .48778 L .33247 .47595 L .656 .78 .94 r
F
0 g
.32308 .49877 m
.33052 .48778 L
s
.31957 .74038 m .30725 .73651 L .30484 .73939 L .595 .768 .962 r
F
.32163 .7392 m .30725 .73651 L .31957 .74038 L F
.34457 .74805 m .35483 .74402 L .34305 .74645 L .594 .768 .963 r
F
.34457 .74805 m .35785 .74723 L .35483 .74402 L F
.61165 .85428 m .61138 .85647 L .61264 .8563 L .655 .815 .961 r
F
.61165 .85428 m .61013 .85648 L .61138 .85647 L F
.34348 .7418 m .35058 .73649 L .34117 .74037 L .595 .768 .962 r
F
.34348 .7418 m .35519 .73937 L .35058 .73649 L F
.30725 .73651 m .2913 .73696 L .30484 .73939 L F
.61165 .85428 m .61264 .8563 L .61383 .856 L .655 .815 .961 r
F
0 g
.61314 .85429 m
.61429 .85394 L
s
.5368 .60852 m .5415 .61803 L .55168 .61539 L .658 .807 .955 r
F
.59713 .85532 m .59708 .85416 L .59742 .85698 L .753 .538 0 r
F
.59713 .85532 m .59679 .8525 L .59708 .85416 L F
.60163 .85215 m .59708 .85416 L .60182 .85326 L .655 .815 .96 r
F
.60163 .85215 m .59679 .8525 L .59708 .85416 L F
0 g
.59708 .85416 m
.59835 .85564 L
s
.61576 .8483 m .62039 .84685 L .61567 .84775 L .656 .815 .96 r
F
.61165 .85428 m .609 .85635 L .61013 .85648 L .655 .815 .961 r
F
0 g
.61429 .85394 m
.6151 .85349 L
s
.35819 .74257 m .36696 .73692 L .35519 .73937 L .595 .768 .962 r
F
.35819 .74257 m .37142 .74174 L .36696 .73692 L F
0 g
.80466 .82126 m
.80476 .82244 L
s
.79898 .75125 m
.8044 .81811 L
s
.79868 .74755 m
.79868 .74755 L
s
.61165 .85428 m .61383 .856 L .61488 .85558 L .655 .815 .961 r
F
0 g
.60788 .85339 m
.60858 .85387 L
s
.79734 .82176 m
.79739 .82234 L
s
.79712 .81894 m
.79729 .82116 L
s
.79174 .75083 m
.79706 .81819 L
s
.49508 .61145 m .48656 .62336 L .50157 .61527 L .658 .807 .955 r
F
.49508 .61145 m .47679 .61768 L .48656 .62336 L F
0 g
.48656 .62336 m
.49929 .62735 L
s
.4921 .34951 m .49266 .34135 L .50353 .32592 L .013 0 .358 r
F
0 g
.48302 .34862 m
.49266 .34135 L
s
.60691 .85518 m .603 .85707 L .60733 .85567 L .655 .815 .961 r
F
.60691 .85518 m .60217 .85608 L .603 .85707 L F
.61165 .85428 m .60804 .85607 L .609 .85635 L F
.22135 .48231 m .20165 .49397 L .22472 .48591 L .656 .78 .94 r
F
.22135 .48231 m .19481 .48683 L .20165 .49397 L F
.46236 .32863 m .49221 .34116 L .50303 .32581 L .644 .737 .916 r
F
.45131 .33715 m .49221 .34116 L .46236 .32863 L F
.60647 .85181 m .60182 .85326 L .60656 .85236 L .655 .815 .96 r
F
.60647 .85181 m .60163 .85215 L .60182 .85326 L F
.6159 .8517 m .62097 .85077 L .61614 .85112 L F
.60638 .84841 m .60133 .84933 L .60614 .84899 L .656 .815 .96 r
F
.61165 .85428 m .61488 .85558 L .6157 .85508 L .655 .815 .961 r
F
.49328 .48107 m .47391 .47078 L .46052 .48049 L .656 .78 .94 r
F
.50493 .47602 m .47391 .47078 L .49328 .48107 L F
0 g
.6151 .85349 m
.61561 .85295 L
s
.60749 .85284 m
.60788 .85339 L
s
.20271 .36424 m .17573 .34753 L .1613 .36023 L .642 .739 .919 r
F
0 g
.15357 .37523 m
.1613 .36023 L
s
.21616 .3581 m .17573 .34753 L .20271 .36424 L .642 .739 .919 r
F
.62581 .85043 m .62518 .84594 L .62555 .84876 L .725 .515 0 r
F
.62097 .85077 m .62581 .85043 L .62555 .84876 L .655 .815 .96 r
F
.62617 .85325 m .62581 .85043 L .62555 .84876 L .725 .515 0 r
F
0 g
.62508 .85216 m
.62578 .85048 L
s
.61567 .84775 m .61957 .84586 L .61526 .84725 L .656 .815 .96 r
F
0 g
.61524 .84752 m
.6153 .84988 L
s
.61567 .84775 m .62039 .84685 L .61957 .84586 L .656 .815 .96 r
F
.62085 .85475 m .62617 .85325 L .62133 .85359 L .655 .815 .961 r
F
.61625 .85451 m .62085 .85475 L .62133 .85359 L F
.6157 .85508 m .62085 .85475 L .61625 .85451 L F
.60179 .84817 m .59652 .84967 L .60133 .84933 L .656 .815 .96 r
F
.60638 .84841 m .60179 .84817 L .60133 .84933 L F
.64556 .46891 m .65695 .47154 L .65753 .47811 L .944 .656 .461 r
F
.64556 .46891 m .645 .46231 L .65695 .47154 L F
0 g
.65695 .47154 m
.66417 .47461 L
s
.57203 .48582 m .57598 .46771 L .5609 .48127 L .655 .781 .941 r
F
.57203 .48582 m .59271 .47466 L .57598 .46771 L F
.61165 .85428 m .60733 .85567 L .60804 .85607 L .655 .815 .961 r
F
.30092 .36939 m .3017 .34365 L .28588 .36176 L .642 .739 .919 r
F
.30092 .36939 m .32436 .35531 L .3017 .34365 L F
.52097 .60847 m .51999 .61937 L .52597 .60919 L .658 .807 .955 r
F
.52097 .60847 m .51006 .61797 L .51999 .61937 L F
.62097 .85077 m .62555 .84876 L .6208 .84966 L .655 .815 .96 r
F
.61614 .85112 m .62097 .85077 L .6208 .84966 L F
.58447 .60551 m .59086 .59222 L .5915 .59768 L .21 .123 .533 r
F
.5851 .61096 m .58447 .60551 L .5915 .59768 L F
.56696 .60149 m .58447 .60551 L .5915 .59768 L .658 .806 .954 r
F
.55997 .60615 m .58447 .60551 L .56696 .60149 L F
0 g
.57584 .61121 m
.58447 .60551 L
s
.67056 .45397 m .65727 .47138 L .67843 .46017 L .656 .78 .94 r
F
.67056 .45397 m .64538 .46219 L .65727 .47138 L F
.60179 .84817 m .59721 .84794 L .59652 .84967 L .656 .815 .96 r
F
.59748 .85076 m .59645 .84968 L .59679 .8525 L 0 0 .408 r
F
.59748 .85076 m .59714 .84794 L .59645 .84968 L F
.72108 .45566 m .71729 .46816 L .73048 .46693 L .656 .78 .94 r
F
.7261 .45226 m .73048 .46693 L .7372 .46532 L F
.73405 .45719 m .7372 .46532 L .74437 .4636 L F
.7261 .45226 m .7372 .46532 L .73405 .45719 L F
.72413 .40567 m .72435 .4048 L .72651 .43773 L 0 0 .297 r
F
.72163 .45385 m .73048 .46693 L .72711 .45562 L .656 .78 .94 r
F
.72108 .45566 m .73048 .46693 L .72163 .45385 L F
.7188 .45294 m .71729 .46816 L .72108 .45566 L F
.71949 .45962 m .71692 .47372 L .73123 .47364 L .655 .781 .941 r
F
.71692 .47372 m .71668 .47499 L .71685 .47497 L F
.71692 .47372 m .71685 .47497 L .73123 .47364 L F
.71594 .40552 m .71629 .40626 L .71837 .4393 L .965 .686 .26 r
F
.71594 .40552 m .71837 .4393 L .7182 .43897 L F
.7188 .45294 m .72108 .45566 L .72163 .45385 L .656 .78 .94 r
F
.7188 .45294 m .72711 .45562 L .72534 .45233 L F
.7188 .45294 m .71603 .46827 L .71729 .46816 L F
.7117 .45256 m .71603 .46827 L .7188 .45294 L F
.7117 .45256 m .70194 .46755 L .71603 .46827 L F
.71233 .45924 m .71668 .47499 L .71692 .47372 L .655 .781 .941 r
F
.71766 .45952 m .71692 .47372 L .71949 .45962 L F
.71233 .45924 m .71692 .47372 L .71766 .45952 L F
.71949 .45962 m .73123 .47364 L .72795 .46266 L F
.72599 .45901 m .72795 .46266 L .72684 .45893 L F
.71949 .45962 m .72795 .46266 L .72599 .45901 L F
.72019 .46624 m .71737 .48157 L .73194 .48022 L .655 .782 .942 r
F
.71233 .45924 m .70251 .47426 L .71668 .47499 L .655 .781 .941 r
F
.71302 .46587 m .71737 .48157 L .72019 .46624 L .655 .782 .942 r
F
.71801 .40739 m .71973 .40767 L .72183 .44042 L .753 .483 .523 r
F
.71696 .40689 m .71801 .40739 L .7201 .44024 L .857 .566 .495 r
F
.72343 .4433 m .7188 .45294 L .7261 .45226 L .656 .78 .94 r
F
.72284 .44129 m .72242 .4425 L .72343 .4433 L F
.72242 .4425 m .7188 .45294 L .72343 .4433 L F
.71629 .40626 m .71696 .40689 L .71904 .43983 L .947 .644 .431 r
F
.72243 .44114 m .72209 .44224 L .72284 .44129 L .656 .78 .94 r
F
.72209 .44224 m .7188 .45294 L .72242 .4425 L F
.72209 .44224 m .72242 .4425 L .72284 .44129 L F
.72258 .44056 m .72241 .44113 L .72261 .44055 L F
.72241 .44113 m .7188 .45294 L .72243 .44114 L F
.72241 .44113 m .72243 .44114 L .72261 .44055 L F
.72249 .44049 m .7188 .45294 L .7226 .4405 L F
.72105 .44053 m .7188 .45294 L .72249 .44049 L F
.72183 .44042 m .72249 .44049 L .72255 .44032 L F
.72105 .44053 m .72249 .44049 L .72183 .44042 L F
.72019 .46624 m .73194 .48022 L .72755 .46556 L .655 .782 .942 r
F
.71801 .40739 m .72093 .44033 L .7201 .44024 L .753 .483 .523 r
F
.71696 .40689 m .7201 .44024 L .71955 .44003 L .857 .566 .495 r
F
.71801 .40739 m .72183 .44042 L .72093 .44033 L .753 .483 .523 r
F
.71973 .40767 m .7227 .4403 L .72183 .44042 L .638 .394 .533 r
F
.72054 .44336 m .7117 .45256 L .7188 .45294 L .656 .78 .94 r
F
.72164 .43729 m .71925 .44095 L .72054 .44336 L F
.71925 .44095 m .71779 .44319 L .72054 .44336 L F
.71779 .44319 m .71763 .44639 L .72054 .44336 L F
.71696 .40689 m .71955 .44003 L .71904 .43983 L .857 .566 .495 r
F
.71629 .40626 m .71904 .43983 L .7187 .43956 L .947 .644 .431 r
F
.71779 .44319 m .70525 .45116 L .7117 .45256 L .656 .78 .94 r
F
.72164 .43729 m .71794 .44042 L .71779 .44319 L F
.71794 .44042 m .70525 .45116 L .71779 .44319 L F
.71594 .40552 m .7182 .43897 L .71803 .43866 L .965 .686 .26 r
F
.71598 .40466 m .71594 .40552 L .71803 .43866 L 0 0 .132 r
F
.71629 .40626 m .7187 .43956 L .71837 .4393 L .947 .644 .431 r
F
.71794 .44042 m .69989 .44881 L .70525 .45116 L .656 .78 .94 r
F
.72164 .43729 m .718 .43921 L .71794 .44042 L F
.718 .43921 m .69989 .44881 L .71794 .44042 L F
.71598 .40466 m .71804 .43854 L .71805 .43827 L 0 0 .132 r
F
.71598 .40466 m .71803 .43866 L .71804 .43854 L F
.71655 .43998 m .69598 .44567 L .69989 .44881 L .656 .78 .94 r
F
.72164 .43729 m .71754 .43863 L .71655 .43998 L F
.71754 .43863 m .69598 .44567 L .71655 .43998 L F
.71668 .40357 m .71598 .40466 L .71807 .4379 L .076 0 .438 r
F
.71833 .44202 m .71862 .4453 L .71852 .44512 L .965 .686 .26 r
F
.71833 .44202 m .71852 .44512 L .71842 .44493 L F
.71807 .43914 m .71833 .44202 L .71842 .44493 L F
.7182 .43897 m .71862 .4453 L .71803 .43866 L F
.72409 .44975 m .71949 .45962 L .72684 .45893 L .655 .781 .941 r
F
.72164 .44783 m .72122 .45013 L .72409 .44975 L F
.72122 .45013 m .71949 .45962 L .72266 .45282 L F
.72122 .45013 m .72266 .45282 L .72409 .44975 L F
.7182 .43897 m .71837 .4393 L .71877 .44557 L .965 .686 .26 r
F
.72164 .44783 m .71233 .45924 L .71949 .45962 L .655 .781 .941 r
F
.72179 .447 m .72133 .44759 L .72164 .44783 L F
.72133 .44759 m .71233 .45924 L .72164 .44783 L F
.7187 .43956 m .71915 .44587 L .71837 .4393 L .947 .644 .431 r
F
.72163 .44694 m .72121 .44749 L .72179 .447 L .655 .781 .941 r
F
.72121 .44749 m .71233 .45924 L .72133 .44759 L F
.72121 .44749 m .72133 .44759 L .72179 .447 L F
.7187 .43956 m .71904 .43983 L .71944 .4461 L .947 .644 .431 r
F
.72066 .44652 m .72063 .44655 L .72185 .44664 L .655 .781 .941 r
F
.72063 .44655 m .71233 .45924 L .72163 .44694 L F
.72063 .44655 m .72163 .44694 L .72185 .44664 L F
.71955 .44003 m .72004 .44633 L .71904 .43983 L .857 .566 .495 r
F
.72004 .44633 m .71962 .44617 L .71904 .43983 L F
.7201 .44024 m .7208 .44653 L .72049 .4465 L .753 .483 .523 r
F
.72093 .44033 m .72148 .44661 L .7201 .44024 L F
.72063 .44655 m .71264 .45211 L .71233 .45924 L .655 .781 .941 r
F
.72066 .44652 m .72061 .44655 L .72063 .44655 L F
.72061 .44655 m .71264 .45211 L .72063 .44655 L F
.71955 .44003 m .7201 .44024 L .72049 .4465 L .857 .566 .495 r
F
.72475 .45623 m .72019 .46624 L .72755 .46556 L .655 .782 .942 r
F
.72408 .45401 m .72365 .45537 L .72475 .45623 L F
.72365 .45537 m .72019 .46624 L .72475 .45623 L F
.71955 .44003 m .72049 .4465 L .72004 .44633 L .857 .566 .495 r
F
.72148 .44661 m .7208 .44653 L .7201 .44024 L .753 .483 .523 r
F
.72361 .45383 m .72327 .45507 L .72408 .45401 L .655 .782 .942 r
F
.72327 .45507 m .72019 .46624 L .72365 .45537 L F
.72327 .45507 m .72365 .45537 L .72408 .45401 L F
.71943 .44639 m .71264 .45211 L .72066 .44652 L .655 .781 .941 r
F
.72093 .44033 m .72183 .44042 L .72223 .44668 L .753 .483 .523 r
F
.72263 .45297 m .72254 .45342 L .72381 .4531 L .655 .782 .942 r
F
.72254 .45342 m .72237 .45437 L .72361 .45383 L F
.72237 .45437 m .72019 .46624 L .72327 .45507 L F
.72237 .45437 m .72327 .45507 L .72361 .45383 L F
.72314 .44656 m .72164 .44783 L .72409 .44975 L .655 .781 .941 r
F
.72184 .44674 m .72164 .44783 L .72314 .44656 L F
.72223 .44668 m .72326 .45288 L .72263 .45297 L .638 .394 .533 r
F
.72183 .44042 m .72254 .44664 L .72223 .44668 L F
.72254 .44664 m .72326 .45288 L .72223 .44668 L F
.72093 .44033 m .72223 .44668 L .72148 .44661 L .753 .483 .523 r
F
.7219 .45693 m .71302 .46587 L .72019 .46624 L .655 .782 .942 r
F
.72254 .45342 m .72105 .45537 L .7219 .45693 L F
.72105 .45537 m .71302 .46587 L .7219 .45693 L F
.71779 .44319 m .7117 .45256 L .71763 .44639 L .656 .78 .94 r
F
.70525 .45116 m .70194 .46755 L .7117 .45256 L F
.70525 .45116 m .68913 .46479 L .70194 .46755 L F
.71264 .45211 m .70044 .45548 L .70584 .45784 L .655 .781 .941 r
F
.71943 .44639 m .71543 .4483 L .71264 .45211 L F
.71543 .4483 m .70044 .45548 L .71264 .45211 L F
.72235 .45335 m .72187 .45398 L .72254 .45342 L .655 .782 .942 r
F
.72097 .4552 m .71302 .46587 L .72105 .45537 L F
.72383 .45281 m .72326 .45288 L .72254 .44664 L .638 .394 .533 r
F
.72283 .4466 m .72254 .44664 L .72183 .44042 L F
.72383 .45281 m .72254 .44664 L .72283 .4466 L F
.72152 .40745 m .72422 .43995 L .72364 .44017 L .519 .305 .529 r
F
.72413 .40567 m .72651 .43773 L .72639 .43813 L 0 0 .297 r
F
.72413 .40567 m .72639 .43813 L .72628 .4385 L F
.72448 .44057 m .7261 .45226 L .73162 .45092 L .656 .78 .94 r
F
.72448 .44057 m .73162 .45092 L .73016 .44715 L F
.72534 .45233 m .72711 .45562 L .7261 .45226 L F
.7261 .45226 m .74437 .4636 L .73311 .45056 L F
.72575 .44785 m .72684 .45893 L .73389 .45724 L .655 .781 .941 r
F
.72684 .45893 m .73123 .47364 L .74522 .4703 L F
.72755 .46556 m .73194 .48022 L .74596 .47689 L .655 .782 .942 r
F
.72684 .45893 m .74522 .4703 L .73389 .45724 L .655 .781 .941 r
F
.72755 .46556 m .74596 .47689 L .73461 .46386 L .655 .782 .942 r
F
.72357 .40639 m .72413 .40567 L .72628 .4385 L .157 .044 .463 r
F
.72538 .43954 m .73311 .45056 L .73936 .44797 L .656 .78 .94 r
F
.72448 .44057 m .73311 .45056 L .72538 .43954 L F
.72357 .40639 m .72628 .4385 L .72598 .43884 L .157 .044 .463 r
F
.72357 .40639 m .72598 .43884 L .72571 .43916 L F
.72271 .40699 m .72526 .43945 L .72484 .43972 L .379 .203 .512 r
F
.71973 .40767 m .72152 .40745 L .72364 .44017 L .638 .394 .533 r
F
.71973 .40767 m .72364 .44017 L .7227 .4403 L F
.72685 .43897 m .73936 .44797 L .74442 .44464 L .656 .78 .94 r
F
.72152 .40745 m .72271 .40699 L .72484 .43972 L .519 .305 .529 r
F
.72152 .40745 m .72484 .43972 L .72422 .43995 L F
.72271 .40699 m .72357 .40639 L .72571 .43916 L .379 .203 .512 r
F
.72628 .43878 m .72535 .43953 L .72685 .43897 L .656 .78 .94 r
F
.72524 .43946 m .72535 .43953 L .72628 .43878 L F
.72535 .43953 m .73936 .44797 L .72685 .43897 L F
.72164 .43729 m .72448 .44057 L .72538 .43954 L F
.72424 .44084 m .7261 .45226 L .72448 .44057 L F
.72409 .4402 m .7261 .45226 L .72414 .44018 L F
.72255 .44032 m .7261 .45226 L .72408 .44011 L F
.72513 .44989 m .72684 .45893 L .72575 .44785 L .655 .781 .941 r
F
.72404 .44643 m .72333 .44722 L .72447 .44637 L F
.72333 .44722 m .72684 .45893 L .72449 .44647 L F
.72333 .44722 m .72449 .44647 L .72447 .44637 L F
.72364 .44017 m .72425 .44635 L .72404 .44643 L .519 .305 .529 r
F
.72271 .40699 m .72571 .43916 L .72526 .43945 L .379 .203 .512 r
F
.72821 .43816 m .74442 .44464 L .74797 .4408 L .656 .78 .94 r
F
.72164 .43729 m .73176 .44055 L .72821 .43816 L F
.73176 .44055 m .74442 .44464 L .72821 .43816 L F
.72598 .43884 m .72628 .4385 L .72669 .44477 L .157 .044 .463 r
F
.73016 .44715 m .73162 .45092 L .73311 .45056 L .656 .78 .94 r
F
.73311 .45056 m .74437 .4636 L .7568 .45849 L F
.73311 .45056 m .7568 .45849 L .73936 .44797 L F
.72828 .44749 m .73389 .45724 L .74018 .45463 L .655 .781 .941 r
F
.72624 .44626 m .72998 .45185 L .72828 .44749 L F
.72614 .44657 m .72998 .45185 L .72624 .44626 L F
.72639 .43813 m .72683 .44433 L .72628 .4385 L 0 0 .297 r
F
.72613 .44662 m .73001 .45193 L .72614 .44657 L .655 .781 .941 r
F
.73001 .45193 m .72998 .45185 L .72568 .44593 L F
.72525 .44598 m .72488 .44684 L .72557 .44586 L F
.72488 .44684 m .73059 .45344 L .72564 .44596 L F
.73059 .45344 m .73389 .45724 L .73001 .45193 L F
.73059 .45344 m .73001 .45193 L .72564 .44596 L F
.72435 .4048 m .72614 .43677 L .72633 .43727 L .925 .667 .181 r
F
.72435 .4048 m .72633 .43727 L .72651 .43773 L F
.72675 .43718 m .74797 .4408 L .74974 .4367 L .656 .78 .94 r
F
.72164 .43729 m .72821 .43816 L .72675 .43718 L F
.72821 .43816 m .74797 .4408 L .72675 .43718 L F
.72397 .40369 m .72288 .40282 L .72505 .43603 L .928 .626 .449 r
F
.72488 .44684 m .72564 .44596 L .72557 .44586 L .655 .781 .941 r
F
.72607 .45442 m .72755 .46556 L .7328 .4643 L .655 .782 .942 r
F
.72523 .45319 m .7257 .45566 L .72607 .45442 L F
.7257 .45566 m .72755 .46556 L .72607 .45442 L F
.72484 .43972 m .7254 .44588 L .72525 .44598 L .379 .203 .512 r
F
.72422 .43995 m .72484 .43972 L .72525 .44598 L .519 .305 .529 r
F
.72414 .44018 m .72424 .44084 L .72448 .44057 L .656 .78 .94 r
F
.72422 .43995 m .72525 .44598 L .72473 .44617 L .519 .305 .529 r
F
.72526 .43945 m .72612 .44542 L .72575 .44566 L .379 .203 .512 r
F
.72598 .43884 m .72645 .44505 L .72571 .43916 L .157 .044 .463 r
F
.72592 .44565 m .74018 .45463 L .74203 .45342 L .655 .781 .941 r
F
.72568 .44593 m .74018 .45463 L .72592 .44565 L F
.72645 .44505 m .72622 .44531 L .72571 .43916 L .157 .044 .463 r
F
.72571 .43916 m .72622 .44531 L .72612 .44542 L F
.72526 .43945 m .72571 .43916 L .72612 .44542 L .379 .203 .512 r
F
.72641 .44523 m .74203 .45342 L .73296 .44734 L .655 .781 .941 r
F
.72526 .43945 m .72575 .44566 L .72484 .43972 L .379 .203 .512 r
F
.72575 .44566 m .7254 .44588 L .72484 .43972 L F
.72314 .44656 m .72319 .44675 L .72404 .44643 L .655 .781 .941 r
F
.72319 .44675 m .72333 .44722 L .72404 .44643 L F
.73936 .44797 m .7568 .45849 L .76695 .45191 L .656 .78 .94 r
F
.73936 .44797 m .76695 .45191 L .74442 .44464 L F
.7324 .44526 m .74528 .4513 L .74885 .44744 L .655 .781 .941 r
F
.7227 .4403 m .72364 .44017 L .72404 .44643 L .638 .394 .533 r
F
.7227 .4403 m .72404 .44643 L .72357 .4465 L F
.72261 .44055 m .72243 .44114 L .72284 .44129 L .656 .78 .94 r
F
.72326 .44654 m .72445 .45272 L .72383 .45281 L .638 .394 .533 r
F
.7227 .4403 m .72357 .4465 L .72326 .44654 L F
.72357 .4465 m .72445 .45272 L .72326 .44654 L F
.74442 .44464 m .76695 .45191 L .77413 .44429 L .656 .78 .94 r
F
.74442 .44464 m .77413 .44429 L .74797 .4408 L F
.7454 .44344 m .74885 .44744 L .75064 .44333 L .655 .781 .941 r
F
.72639 .43813 m .72651 .43773 L .72693 .444 L 0 0 .297 r
F
.72698 .44383 m .7324 .44526 L .7454 .44344 L .655 .781 .941 r
F
.72683 .44433 m .72673 .44463 L .72628 .4385 L 0 0 .297 r
F
.72651 .43773 m .72686 .44383 L .72693 .444 L .925 .667 .181 r
F
.72628 .4385 m .72673 .44463 L .72669 .44477 L 0 0 .297 r
F
.72598 .43884 m .72669 .44477 L .72645 .44505 L .157 .044 .463 r
F
.72639 .43813 m .72693 .444 L .72683 .44433 L 0 0 .297 r
F
.7226 .4405 m .72258 .44056 L .72261 .44055 L .656 .78 .94 r
F
.72255 .44032 m .72249 .44049 L .7226 .4405 L F
.7227 .4403 m .72326 .44654 L .72183 .44042 L .638 .394 .533 r
F
.72326 .44654 m .72383 .45281 L .72283 .4466 L F
.72326 .44654 m .72283 .4466 L .72183 .44042 L F
.72633 .43727 m .72671 .44345 L .72651 .43773 L .925 .667 .181 r
F
.72671 .44345 m .72686 .44383 L .72651 .43773 L F
.72633 .43727 m .72655 .44304 L .72671 .44345 L F
.72408 .44011 m .72409 .4402 L .72414 .44018 L .656 .78 .94 r
F
.72422 .43995 m .72473 .44617 L .72364 .44017 L .519 .305 .529 r
F
.72493 .45274 m .72506 .45338 L .72523 .45319 L .655 .782 .942 r
F
.72506 .45338 m .72755 .46556 L .72523 .45319 L F
.72616 .45415 m .7328 .4643 L .73103 .45974 L F
.7261 .45435 m .7328 .4643 L .72616 .45415 L F
.72523 .45319 m .72607 .45442 L .72528 .45314 L F
.72607 .45442 m .7328 .4643 L .7261 .45435 L F
.72607 .45442 m .7261 .45435 L .72528 .45314 L F
.72473 .44617 m .72425 .44635 L .72364 .44017 L .519 .305 .529 r
F
.72235 .44393 m .72686 .44538 L .72855 .44475 L .655 .781 .941 r
F
.72583 .44561 m .74203 .45342 L .72641 .44523 L F
.72673 .44463 m .72719 .45079 L .72669 .44477 L 0 0 .297 r
F
.72622 .44531 m .72673 .45148 L .72612 .44542 L .157 .044 .463 r
F
.73001 .45193 m .73389 .45724 L .72998 .45185 L .655 .781 .941 r
F
.72998 .45185 m .73389 .45724 L .72828 .44749 L F
.73389 .45724 m .74522 .4703 L .75773 .46517 L F
.73389 .45724 m .75773 .46517 L .74018 .45463 L F
.72879 .45402 m .73461 .46386 L .74092 .46127 L .655 .782 .942 r
F
.72686 .44538 m .72829 .44584 L .72855 .44475 L .655 .781 .941 r
F
.72677 .44452 m .7324 .44526 L .72698 .44383 L F
.72683 .44433 m .72693 .444 L .72734 .45029 L 0 0 .297 r
F
.7266 .45271 m .73048 .45835 L .72879 .45402 L .655 .782 .942 r
F
.7265 .45303 m .73048 .45835 L .7266 .45271 L F
.72592 .4524 m .73054 .45849 L .72598 .45234 L F
.73054 .45849 m .73461 .46386 L .73048 .45835 L F
.73054 .45849 m .73048 .45835 L .72598 .45234 L F
.72686 .44383 m .72721 .44996 L .72693 .444 L .925 .667 .181 r
F
.72662 .44322 m .72771 .44382 L .72678 .44319 L .655 .781 .941 r
F
.72235 .44393 m .72686 .44383 L .72662 .44322 L F
.72686 .44383 m .72771 .44382 L .72662 .44322 L F
.72235 .44393 m .72677 .44452 L .72698 .44383 L F
.72667 .44479 m .72669 .44477 L .72691 .44811 L .157 .044 .463 r
F
.72566 .45227 m .72584 .4525 L .72578 .45222 L .655 .782 .942 r
F
.72584 .4525 m .73061 .45868 L .72592 .45241 L F
.72584 .4525 m .72592 .45241 L .72578 .45222 L F
.72667 .44479 m .72691 .44811 L .72711 .45106 L .157 .044 .463 r
F
.73061 .45868 m .73054 .45849 L .72592 .4524 L .655 .782 .942 r
F
.72592 .45241 m .72592 .4524 L .72578 .45222 L F
.73061 .45868 m .72592 .4524 L .72592 .45241 L F
.72645 .44505 m .72667 .44479 L .72709 .45108 L .157 .044 .463 r
F
.72493 .45274 m .73461 .46386 L .72566 .45227 L .655 .782 .942 r
F
.72557 .44586 m .72564 .44596 L .72568 .44593 L .655 .781 .941 r
F
.72447 .44637 m .72513 .44989 L .72575 .44785 L F
.72575 .44566 m .72623 .4519 L .7254 .44588 L .379 .203 .512 r
F
.72623 .4519 m .72596 .45208 L .7254 .44588 L F
.7244 .4463 m .72453 .44645 L .72525 .44598 L .655 .781 .941 r
F
.72473 .44617 m .72525 .45242 L .72425 .44635 L .519 .305 .529 r
F
.72525 .45242 m .72487 .45256 L .72425 .44635 L F
.72357 .4465 m .72404 .44643 L .72445 .45272 L .638 .394 .533 r
F
.72528 .45314 m .7261 .45435 L .72616 .45415 L .655 .782 .942 r
F
.72484 .4528 m .72755 .46556 L .72493 .45274 L F
.72377 .45297 m .7239 .4534 L .7248 .45259 L F
.7239 .4534 m .72755 .46556 L .72484 .4528 L F
.7239 .4534 m .72484 .4528 L .7248 .45259 L F
.7254 .44588 m .72596 .45208 L .72525 .44598 L .379 .203 .512 r
F
.72576 .45221 m .74092 .46127 L .72606 .45201 L .655 .782 .942 r
F
.72598 .45234 m .7265 .45303 L .7266 .45271 L F
.72578 .45222 m .72592 .4524 L .72598 .45234 L F
.72596 .45208 m .72809 .47559 L .72584 .45215 L .379 .203 .512 r
F
.72596 .45208 m .72584 .45215 L .72525 .44598 L F
.72566 .45227 m .72809 .47559 L .72722 .47619 L F
.72525 .44598 m .72584 .45215 L .72566 .45227 L F
.72584 .45215 m .72809 .47559 L .72566 .45227 L F
.72606 .45201 m .74092 .46127 L .7429 .45998 L .655 .782 .942 r
F
.72453 .44645 m .72488 .44684 L .72525 .44598 L .655 .781 .941 r
F
.72473 .44617 m .72525 .44598 L .72566 .45227 L .519 .305 .529 r
F
.7248 .45259 m .72493 .45274 L .72566 .45227 L .655 .782 .942 r
F
.72525 .45242 m .72566 .45227 L .72722 .47619 L .519 .305 .529 r
F
.72473 .44617 m .72566 .45227 L .72525 .45242 L F
.72688 .45182 m .7429 .45998 L .73417 .45415 L .655 .782 .942 r
F
.72575 .44566 m .72653 .45171 L .72623 .4519 L .379 .203 .512 r
F
.72404 .44643 m .72471 .45262 L .72445 .45272 L .519 .305 .529 r
F
.7248 .45259 m .72484 .4528 L .72493 .45274 L .655 .782 .942 r
F
.72235 .44393 m .72314 .44656 L .72447 .44637 L .655 .781 .941 r
F
.72425 .44635 m .72487 .45256 L .72404 .44643 L .519 .305 .529 r
F
.72487 .45256 m .72722 .47619 L .72471 .45262 L F
.72487 .45256 m .72471 .45262 L .72404 .44643 L F
.73296 .44734 m .74203 .45342 L .74528 .4513 L .655 .781 .941 r
F
.7568 .45849 m .78922 .45911 L .76695 .45191 L .656 .78 .94 r
F
.74018 .45463 m .75773 .46517 L .76796 .45858 L .655 .781 .941 r
F
.74018 .45463 m .76796 .45858 L .74528 .4513 L F
.72831 .45129 m .74603 .45794 L .74961 .4541 L .655 .782 .942 r
F
.72645 .44505 m .72709 .45108 L .72691 .45128 L .157 .044 .463 r
F
.72673 .45148 m .72665 .45157 L .72612 .44542 L F
.72645 .44505 m .72691 .45128 L .72622 .44531 L F
.72691 .45128 m .72673 .45148 L .72622 .44531 L F
.72612 .44542 m .72665 .45157 L .72653 .45171 L F
.72564 .44596 m .72613 .44662 L .72568 .44593 L .655 .781 .941 r
F
.72613 .44662 m .72614 .44657 L .72568 .44593 L F
.72568 .44593 m .72614 .44657 L .72624 .44626 L F
.72575 .44566 m .72612 .44542 L .72653 .45171 L .379 .203 .512 r
F
.72306 .4506 m .72688 .45182 L .72831 .45129 L .655 .782 .942 r
F
.72688 .45182 m .74603 .45794 L .72831 .45129 L F
.72306 .4506 m .72619 .45207 L .72688 .45182 L F
.72619 .45207 m .7429 .45998 L .72688 .45182 L F
.72306 .4506 m .72576 .45221 L .72606 .45201 L F
.73417 .45415 m .7429 .45998 L .74603 .45794 L F
.72667 .44479 m .72711 .45106 L .72709 .45108 L .157 .044 .463 r
F
.72683 .44433 m .72734 .45029 L .72726 .45055 L 0 0 .297 r
F
.72719 .45079 m .72716 .4509 L .72669 .44477 L F
.72669 .44477 m .72716 .4509 L .72711 .45106 L F
.72829 .44584 m .74528 .4513 L .7324 .44526 L .655 .781 .941 r
F
.76695 .45191 m .78922 .45911 L .80011 .44776 L .656 .78 .94 r
F
.76695 .45191 m .80011 .44776 L .77413 .44429 L F
.74528 .4513 m .76796 .45858 L .77519 .45094 L .655 .781 .941 r
F
.74528 .4513 m .77519 .45094 L .74885 .44744 L F
.72868 .45048 m .74961 .4541 L .7514 .44999 L .655 .782 .942 r
F
.72683 .44433 m .72726 .45055 L .72673 .44463 L 0 0 .297 r
F
.72726 .45055 m .72719 .45079 L .72673 .44463 L F
.72306 .4506 m .73028 .45155 L .72868 .45048 L .655 .782 .942 r
F
.73028 .45155 m .74961 .4541 L .72868 .45048 L F
.72164 .43729 m .72524 .43946 L .72628 .43878 L .656 .78 .94 r
F
.72397 .40369 m .72561 .43641 L .72614 .43677 L .928 .626 .449 r
F
.72435 .4048 m .72397 .40369 L .72614 .43677 L .925 .667 .181 r
F
.72662 .43645 m .74974 .4367 L .7496 .43261 L .656 .78 .94 r
F
.72164 .43729 m .72913 .43713 L .72662 .43645 L F
.72913 .43713 m .74974 .4367 L .72662 .43645 L F
.72614 .43677 m .72636 .44291 L .72655 .44304 L .928 .626 .449 r
F
.7265 .44258 m .72652 .44258 L .72652 .44257 L .655 .781 .941 r
F
.72633 .43727 m .72614 .43677 L .72655 .44304 L .925 .667 .181 r
F
.74797 .4408 m .7778 .43611 L .74974 .4367 L .656 .78 .94 r
F
.72652 .44258 m .7505 .43924 L .72652 .44257 L .655 .781 .941 r
F
.72652 .44257 m .7505 .43924 L .74843 .43544 L F
.72397 .40369 m .72505 .43603 L .72561 .43641 L .928 .626 .449 r
F
.72529 .4361 m .7496 .43261 L .74754 .42883 L .656 .78 .94 r
F
.72164 .43729 m .72662 .43645 L .72529 .4361 L F
.72662 .43645 m .7496 .43261 L .72529 .4361 L F
.72288 .40282 m .72173 .40242 L .72389 .43572 L .818 .533 .507 r
F
.72235 .44393 m .72678 .44319 L .72608 .44272 L .655 .781 .941 r
F
.72306 .4506 m .7248 .45259 L .72578 .45222 L .655 .782 .942 r
F
.72493 .45274 m .72523 .45319 L .72528 .45314 L F
.72525 .45242 m .72722 .47619 L .72487 .45256 L .519 .305 .529 r
F
.72235 .44393 m .72583 .44561 L .72641 .44523 L .655 .781 .941 r
F
.72235 .44393 m .72568 .44593 L .72592 .44565 L F
.72235 .44393 m .7244 .4463 L .72557 .44586 L F
.72445 .45272 m .72722 .47619 L .726 .47664 L .519 .305 .529 r
F
.72471 .45262 m .72722 .47619 L .72445 .45272 L F
.72288 .40282 m .72389 .43572 L .72449 .43588 L .818 .533 .507 r
F
.72288 .40282 m .72449 .43588 L .72505 .43603 L F
.72173 .40242 m .7233 .43568 L .72389 .43572 L .735 .468 .525 r
F
.72352 .43569 m .7437 .4256 L .73832 .42317 L .656 .78 .94 r
F
.72164 .43729 m .72452 .43576 L .72352 .43569 L F
.72452 .43576 m .7437 .4256 L .72352 .43569 L F
.72373 .45282 m .72377 .45297 L .72445 .45272 L .655 .782 .942 r
F
.72381 .4531 m .72361 .45383 L .72408 .45401 L F
.72383 .45281 m .72445 .45272 L .726 .47664 L .638 .394 .533 r
F
.72306 .4506 m .72373 .45282 L .7248 .45259 L .655 .782 .942 r
F
.72373 .45282 m .72445 .45272 L .7248 .45259 L F
.72164 .43729 m .72255 .44032 L .72408 .44011 L .656 .78 .94 r
F
.72254 .45342 m .72361 .45383 L .72381 .4531 L .655 .782 .942 r
F
.72138 .45315 m .72055 .45442 L .72235 .45335 L F
.72055 .45442 m .72097 .4552 L .72235 .45335 L F
.72171 .4531 m .72235 .45335 L .72262 .45297 L F
.72138 .45315 m .72235 .45335 L .72171 .4531 L F
.72187 .45398 m .72202 .4541 L .72254 .45342 L F
.72262 .45297 m .72235 .45335 L .72254 .45342 L F
.72185 .44664 m .72163 .44694 L .72179 .447 L .655 .781 .941 r
F
.72148 .44661 m .72223 .44668 L .72263 .45297 L .753 .483 .523 r
F
.72262 .45297 m .72138 .45315 L .72262 .45297 L .655 .782 .942 r
F
.72157 .45286 m .72138 .45315 L .72262 .45297 L F
.72262 .45297 m .72262 .45297 L .72263 .45297 L F
.72262 .45297 m .72254 .45342 L .72263 .45297 L F
.72204 .45291 m .72263 .45297 L .72416 .47686 L .753 .483 .523 r
F
.72148 .44661 m .72263 .45297 L .72204 .45291 L F
.72148 .44661 m .72204 .45291 L .7208 .44653 L F
.72204 .45291 m .7215 .45285 L .7208 .44653 L F
.72306 .4506 m .72157 .45286 L .72262 .45297 L .655 .782 .942 r
F
.72306 .4506 m .72262 .45297 L .72381 .4531 L F
.72383 .45281 m .726 .47664 L .72326 .45288 L .638 .394 .533 r
F
.72263 .45297 m .726 .47664 L .72416 .47686 L F
.72326 .45288 m .726 .47664 L .72263 .45297 L F
.72452 .43576 m .74754 .42883 L .7437 .4256 L .656 .78 .94 r
F
.72164 .43729 m .72602 .43586 L .72452 .43576 L F
.72602 .43586 m .74754 .42883 L .72452 .43576 L F
.72173 .40242 m .72053 .40228 L .72268 .43564 L .735 .468 .525 r
F
.72173 .40242 m .72268 .43564 L .7233 .43568 L F
.72053 .40228 m .72144 .43577 L .72207 .4357 L .657 .408 .532 r
F
.72164 .43729 m .72271 .43564 L .72192 .43572 L .656 .78 .94 r
F
.72235 .44393 m .72184 .44674 L .72314 .44656 L .655 .781 .941 r
F
.72164 .43729 m .72105 .44053 L .72255 .44032 L .656 .78 .94 r
F
.72004 .44633 m .72049 .4465 L .72089 .45279 L .857 .566 .495 r
F
.72004 .44633 m .72089 .45279 L .72054 .45265 L F
.70584 .45784 m .70251 .47426 L .71233 .45924 L .655 .781 .941 r
F
.71849 .45756 m .71181 .46003 L .71302 .46587 L .655 .782 .942 r
F
.72157 .45286 m .71862 .45503 L .71849 .45756 L F
.71862 .45503 m .71181 .46003 L .71849 .45756 L F
.72049 .45275 m .71866 .45429 L .72157 .45286 L F
.71866 .45429 m .71181 .46003 L .71862 .45503 L F
.71866 .45429 m .71862 .45503 L .72157 .45286 L F
.7187 .43956 m .71944 .4461 L .71915 .44587 L .947 .644 .431 r
F
.71915 .44587 m .71888 .44566 L .71837 .4393 L F
.71904 .43983 m .71962 .44617 L .71944 .4461 L .857 .566 .495 r
F
.72235 .44393 m .71837 .44603 L .71943 .44639 L .655 .781 .941 r
F
.71837 .44603 m .71797 .44624 L .71835 .44628 L F
.71837 .44603 m .71835 .44628 L .71943 .44639 L F
.71797 .44624 m .70044 .45548 L .71943 .44639 L F
.7182 .43897 m .71877 .44557 L .71862 .4453 L .965 .686 .26 r
F
.71837 .4393 m .71888 .44566 L .71877 .44557 L .947 .644 .431 r
F
.69989 .44881 m .68913 .46479 L .70525 .45116 L .656 .78 .94 r
F
.69989 .44881 m .67843 .46017 L .68913 .46479 L F
.72235 .44393 m .71204 .44728 L .70044 .45548 L .655 .781 .941 r
F
.71204 .44728 m .69651 .45233 L .69932 .45458 L F
.71204 .44728 m .69932 .45458 L .70044 .45548 L F
.71356 .43992 m .6938 .44194 L .69598 .44567 L .656 .78 .94 r
F
.71598 .40466 m .71805 .43827 L .71807 .4379 L 0 0 .132 r
F
.72164 .43729 m .71808 .43788 L .71754 .43863 L .656 .78 .94 r
F
.71668 .40357 m .71844 .43739 L .71879 .43691 L .076 0 .438 r
F
.71671 .43811 m .69351 .43788 L .6938 .44194 L .656 .78 .94 r
F
.71668 .40357 m .71807 .4379 L .71844 .43739 L .076 0 .438 r
F
.72164 .43729 m .71801 .43736 L .71671 .43811 L .656 .78 .94 r
F
.71801 .43736 m .69351 .43788 L .71671 .43811 L F
.71802 .40273 m .71668 .40357 L .71879 .43691 L .414 .228 .517 r
F
.71802 .40273 m .71879 .43691 L .719 .43679 L F
.71801 .43736 m .69514 .43375 L .69351 .43788 L .656 .78 .94 r
F
.72164 .43729 m .7188 .43691 L .71801 .43736 L F
.7188 .43691 m .69514 .43375 L .71801 .43736 L F
.72187 .45398 m .72097 .4552 L .72202 .4541 L .655 .782 .942 r
F
.72097 .4552 m .72105 .45537 L .72202 .4541 L F
.72089 .45279 m .72416 .47686 L .72241 .47658 L .753 .483 .523 r
F
.72049 .4465 m .72126 .45283 L .72089 .45279 L F
.72126 .45283 m .72416 .47686 L .72089 .45279 L F
.7208 .44653 m .7215 .45285 L .72049 .4465 L F
.7215 .45285 m .72416 .47686 L .72126 .45283 L F
.7215 .45285 m .72126 .45283 L .72049 .4465 L F
.71888 .44566 m .7194 .45204 L .71877 .44557 L .947 .644 .431 r
F
.7194 .45204 m .71931 .45197 L .71877 .44557 L F
.71915 .44587 m .71961 .45221 L .71888 .44566 L F
.71961 .45221 m .7194 .45204 L .71888 .44566 L F
.69598 .44567 m .67843 .46017 L .69989 .44881 L .656 .78 .94 r
F
.71204 .44728 m .69432 .4486 L .69651 .45233 L .655 .781 .941 r
F
.71805 .43827 m .71842 .44493 L .71844 .44461 L 0 0 .132 r
F
.71804 .43854 m .71842 .44493 L .71805 .43827 L F
.71804 .43854 m .71803 .43866 L .71842 .44493 L F
.71807 .4379 m .71844 .44461 L .71846 .44417 L F
.71805 .43827 m .71844 .44461 L .71807 .4379 L F
.72235 .44393 m .71606 .44498 L .71204 .44728 L .655 .781 .941 r
F
.71606 .44498 m .69432 .4486 L .71204 .44728 L F
.72235 .44393 m .71967 .44619 L .72066 .44652 L F
.71967 .44619 m .71943 .44639 L .72049 .4465 L F
.71967 .44619 m .72049 .4465 L .72066 .44652 L F
.71962 .44617 m .7202 .45253 L .71944 .4461 L .857 .566 .495 r
F
.7202 .45253 m .72006 .45247 L .71944 .4461 L F
.71944 .4461 m .72006 .45247 L .71984 .45239 L F
.71915 .44587 m .71944 .4461 L .71984 .45239 L .947 .644 .431 r
F
.71915 .44587 m .71984 .45239 L .71961 .45221 L F
.72004 .44633 m .72054 .45265 L .71962 .44617 L .857 .566 .495 r
F
.72054 .45265 m .7202 .45253 L .71962 .44617 L F
.72306 .4506 m .71922 .45262 L .72049 .45275 L .655 .782 .942 r
F
.72306 .4506 m .72049 .45275 L .72157 .45286 L F
.71866 .45429 m .71534 .45524 L .71181 .46003 L F
.72049 .45275 m .71869 .45362 L .71866 .45429 L F
.71869 .45362 m .71534 .45524 L .71866 .45429 L F
.71842 .44493 m .71889 .45136 L .71882 .45122 L .965 .686 .26 r
F
.71844 .44461 m .71842 .44493 L .71882 .45122 L 0 0 .132 r
F
.71264 .45211 m .70808 .45832 L .71233 .45924 L .655 .781 .941 r
F
.71922 .45262 m .71605 .45428 L .72049 .45275 L .655 .782 .942 r
F
.70584 .45784 m .68961 .4715 L .70251 .47426 L .655 .781 .941 r
F
.71605 .45428 m .70111 .46212 L .71534 .45524 L .655 .782 .942 r
F
.71605 .45428 m .71534 .45524 L .72049 .45275 L F
.71862 .4453 m .71883 .44846 L .71852 .44512 L .965 .686 .26 r
F
.71883 .44846 m .71905 .45165 L .71852 .44512 L F
.71852 .44512 m .71905 .45165 L .71842 .44493 L F
.71905 .45165 m .71889 .45136 L .71842 .44493 L F
.71862 .4453 m .71877 .44557 L .71916 .45186 L F
.71862 .4453 m .71916 .45186 L .71905 .45165 L F
.69598 .44567 m .67056 .45397 L .67843 .46017 L .656 .78 .94 r
F
.6938 .44194 m .67056 .45397 L .69598 .44567 L F
.71606 .44498 m .69403 .44453 L .69432 .4486 L .655 .781 .941 r
F
.71844 .43739 m .71807 .4379 L .71846 .44417 L .076 0 .438 r
F
.71844 .43739 m .71846 .44417 L .71877 .44375 L F
.72235 .44393 m .71772 .44403 L .71606 .44498 L .655 .781 .941 r
F
.71772 .44403 m .69403 .44453 L .71606 .44498 L F
.71802 .40273 m .719 .43679 L .71949 .43651 L .414 .228 .517 r
F
.71784 .43678 m .69859 .42985 L .69514 .43375 L .656 .78 .94 r
F
.72164 .43729 m .71903 .43644 L .71784 .43678 L F
.71903 .43644 m .69859 .42985 L .71784 .43678 L F
.7193 .40237 m .71802 .40273 L .72015 .43613 L .566 .34 .531 r
F
.72204 .45291 m .72416 .47686 L .7215 .45285 L .753 .483 .523 r
F
.72235 .44393 m .72066 .44652 L .72185 .44664 L .655 .781 .941 r
F
.71877 .44557 m .71931 .45197 L .71916 .45186 L .947 .644 .431 r
F
.71264 .45211 m .70584 .45784 L .70808 .45832 L .655 .781 .941 r
F
.72306 .4506 m .71052 .45466 L .70111 .46212 L .655 .782 .942 r
F
.70044 .45548 m .68961 .4715 L .70584 .45784 L .655 .781 .941 r
F
.70044 .45548 m .67884 .46687 L .68961 .4715 L F
.71052 .45466 m .69718 .45898 L .69959 .46091 L .655 .782 .942 r
F
.71052 .45466 m .69959 .46091 L .70111 .46212 L F
.71671 .43811 m .6938 .44194 L .71356 .43992 L .656 .78 .94 r
F
.71452 .44409 m .69567 .44039 L .69403 .44453 L .655 .781 .941 r
F
.71879 .43691 m .71877 .44375 L .71919 .44318 L .076 0 .438 r
F
.71844 .43739 m .71877 .44375 L .71879 .43691 L F
.72235 .44393 m .71743 .44328 L .71452 .44409 L .655 .781 .941 r
F
.71743 .44328 m .69567 .44039 L .71452 .44409 L F
.71802 .40273 m .71949 .43651 L .72015 .43613 L .414 .228 .517 r
F
.71903 .43644 m .70365 .42643 L .69859 .42985 L .656 .78 .94 r
F
.72164 .43729 m .71986 .43621 L .71903 .43644 L F
.71986 .43621 m .70365 .42643 L .71903 .43644 L F
.71743 .44328 m .69915 .43648 L .69567 .44039 L .655 .781 .941 r
F
.71949 .43651 m .71919 .44318 L .71976 .44285 L .414 .228 .517 r
F
.719 .43679 m .71919 .44318 L .71949 .43651 L F
.719 .43679 m .71879 .43691 L .71919 .44318 L F
.72235 .44393 m .71897 .44284 L .71743 .44328 L .655 .781 .941 r
F
.71897 .44284 m .69915 .43648 L .71743 .44328 L F
.71754 .43863 m .71671 .43811 L .71356 .43992 L .656 .78 .94 r
F
.71897 .44284 m .70424 .43306 L .69915 .43648 L .655 .781 .941 r
F
.7193 .40237 m .72015 .43613 L .72081 .43594 L .566 .34 .531 r
F
.72164 .43729 m .70996 .42376 L .70365 .42643 L .656 .78 .94 r
F
.71949 .43651 m .71976 .44285 L .72015 .43613 L .414 .228 .517 r
F
.71976 .44285 m .72031 .44254 L .72015 .43613 L F
.72235 .44393 m .72004 .44254 L .71897 .44284 L .655 .781 .941 r
F
.72004 .44254 m .70424 .43306 L .71897 .44284 L F
.7193 .40237 m .72081 .43594 L .72144 .43577 L .566 .34 .531 r
F
.72164 .43729 m .71708 .42201 L .70996 .42376 L .656 .78 .94 r
F
.72164 .43729 m .73832 .42317 L .73178 .4217 L F
.72268 .43564 m .72286 .44194 L .72308 .44191 L .657 .408 .532 r
F
.72053 .40228 m .72207 .4357 L .72268 .43564 L F
.72235 .44393 m .72271 .44195 L .72179 .44204 L .655 .781 .941 r
F
.72306 .4506 m .71541 .45187 L .71052 .45466 L .655 .782 .942 r
F
.69651 .45233 m .67884 .46687 L .70044 .45548 L .655 .781 .941 r
F
.69651 .45233 m .67092 .46066 L .67884 .46687 L F
.69432 .4486 m .67092 .46066 L .69651 .45233 L F
.70118 .45423 m .69469 .4512 L .69498 .45526 L .655 .782 .942 r
F
.71844 .44461 m .71882 .45122 L .71883 .45097 L 0 0 .132 r
F
.71976 .44285 m .71919 .44318 L .71959 .44948 L .414 .228 .517 r
F
.71844 .44461 m .71883 .45097 L .71846 .44417 L 0 0 .132 r
F
.71883 .45097 m .71885 .45062 L .71846 .44417 L F
.72306 .4506 m .71742 .45072 L .71541 .45187 L .655 .782 .942 r
F
.72018 .45252 m .72027 .45468 L .72006 .45247 L .857 .566 .495 r
F
.7202 .45253 m .72027 .45468 L .72018 .45252 L F
.72055 .45442 m .71302 .46587 L .72097 .4552 L .655 .782 .942 r
F
.7202 .45253 m .72241 .47658 L .72027 .45468 L .857 .566 .495 r
F
.7194 .45204 m .72134 .47609 L .71931 .45197 L .947 .644 .431 r
F
.71984 .45239 m .72241 .47658 L .72134 .47609 L .857 .566 .495 r
F
.72006 .45247 m .72241 .47658 L .71984 .45239 L F
.71961 .45221 m .72134 .47609 L .7194 .45204 L .947 .644 .431 r
F
.71961 .45221 m .71984 .45239 L .72134 .47609 L F
.72235 .44393 m .72364 .44195 L .72271 .44195 L .655 .781 .941 r
F
.7233 .43568 m .72308 .44191 L .7236 .44195 L .735 .468 .525 r
F
.72364 .44195 m .72308 .44191 L .72271 .44195 L .655 .781 .941 r
F
.7233 .43568 m .7236 .44195 L .72389 .43572 L .735 .468 .525 r
F
.7236 .44195 m .72408 .44198 L .72389 .43572 L F
.72389 .43572 m .72408 .44198 L .72429 .44199 L F
.72449 .43588 m .72389 .43572 L .72429 .44199 L .818 .533 .507 r
F
.72235 .44393 m .72463 .44201 L .72364 .44195 L .655 .781 .941 r
F
.72449 .43588 m .72429 .44199 L .72479 .44212 L .818 .533 .507 r
F
.72561 .43641 m .72593 .44261 L .72614 .43677 L .928 .626 .449 r
F
.72593 .44261 m .72636 .44291 L .72614 .43677 L F
.72505 .43603 m .72526 .44225 L .72546 .4423 L .818 .533 .507 r
F
.72449 .43588 m .72479 .44212 L .72505 .43603 L F
.72235 .44393 m .72544 .4423 L .72456 .44206 L .655 .781 .941 r
F
.72561 .43641 m .72505 .43603 L .72546 .4423 L .928 .626 .449 r
F
.72561 .43641 m .72546 .4423 L .72593 .44261 L F
.72235 .44393 m .74843 .43544 L .74456 .43221 L .655 .781 .941 r
F
.7324 .44526 m .74885 .44744 L .7454 .44344 L F
.77413 .44429 m .80011 .44776 L .80583 .43552 L .656 .78 .94 r
F
.77413 .44429 m .80583 .43552 L .7778 .43611 L F
.74797 .4408 m .77413 .44429 L .7778 .43611 L F
.74885 .44744 m .77519 .45094 L .77889 .44274 L .655 .781 .941 r
F
.74885 .44744 m .77889 .44274 L .75064 .44333 L F
.72941 .44954 m .7514 .44999 L .75126 .44591 L .655 .782 .942 r
F
.72593 .44261 m .72624 .44884 L .72636 .44291 L .928 .626 .449 r
F
.72721 .44996 m .72726 .45009 L .72693 .444 L .925 .667 .181 r
F
.72693 .444 m .72726 .45009 L .72734 .45029 L F
.72709 .44965 m .72721 .44996 L .72686 .44383 L F
.72306 .4506 m .72868 .45048 L .7277 .44982 L .655 .782 .942 r
F
.72623 .4519 m .72809 .47559 L .72596 .45208 L .379 .203 .512 r
F
.72673 .45148 m .72867 .47488 L .72665 .45157 L .157 .044 .463 r
F
.72653 .45171 m .72867 .47488 L .72809 .47559 L F
.72665 .45157 m .72867 .47488 L .72653 .45171 L F
.72623 .4519 m .72653 .45171 L .72809 .47559 L .379 .203 .512 r
F
.72624 .44884 m .72658 .44907 L .72636 .44291 L .928 .626 .449 r
F
.72801 .44299 m .7505 .43924 L .7265 .44258 L .655 .781 .941 r
F
.72306 .4506 m .72631 .44889 L .72555 .44851 L .655 .782 .942 r
F
.72631 .44889 m .72653 .44877 L .72587 .4486 L F
.72631 .44889 m .72587 .4486 L .72555 .44851 L F
.72593 .44261 m .72546 .4423 L .72587 .4486 L .928 .626 .449 r
F
.72636 .44291 m .72658 .44907 L .72655 .44304 L F
.72658 .44907 m .72673 .44917 L .72655 .44304 L F
.72655 .44304 m .72673 .44917 L .72696 .44933 L F
.72671 .44345 m .72655 .44304 L .72696 .44933 L .925 .667 .181 r
F
.72671 .44345 m .72696 .44933 L .72709 .44965 L F
.72671 .44345 m .72709 .44965 L .72686 .44383 L F
.72306 .4506 m .72771 .44909 L .72653 .44877 L .655 .782 .942 r
F
.72678 .44319 m .7454 .44344 L .7505 .43924 L .655 .781 .941 r
F
.72771 .44382 m .7454 .44344 L .72678 .44319 L F
.7454 .44344 m .75064 .44333 L .75062 .44271 L F
.7454 .44344 m .75062 .44271 L .7505 .43924 L F
.72928 .44858 m .75126 .44591 L .74919 .44213 L .655 .782 .942 r
F
.72526 .44225 m .72546 .44849 L .72546 .4423 L .818 .533 .507 r
F
.72306 .4506 m .72941 .44954 L .72771 .44909 L .655 .782 .942 r
F
.72546 .44849 m .72562 .44853 L .72546 .4423 L .818 .533 .507 r
F
.72429 .44199 m .72444 .44827 L .7247 .44829 L .735 .468 .525 r
F
.72546 .4423 m .72562 .44853 L .72587 .4486 L .818 .533 .507 r
F
.72593 .44261 m .72587 .4486 L .72624 .44884 L .928 .626 .449 r
F
.72479 .44212 m .72429 .44199 L .7247 .44829 L .818 .533 .507 r
F
.72479 .44212 m .7247 .44829 L .72509 .44839 L F
.72479 .44212 m .72509 .44839 L .72526 .44225 L F
.72509 .44839 m .72546 .44849 L .72526 .44225 L F
.72479 .44212 m .72526 .44225 L .72505 .43603 L F
.72497 .44172 m .74456 .43221 L .73915 .42978 L .655 .781 .941 r
F
.72691 .44153 m .74456 .43221 L .72497 .44172 L F
.72855 .44475 m .72829 .44584 L .7324 .44526 L F
.72458 .44828 m .7399 .43648 L .73331 .43501 L .655 .782 .942 r
F
.72306 .4506 m .72574 .44835 L .72458 .44828 L F
.72574 .44835 m .7399 .43648 L .72458 .44828 L F
.72408 .44198 m .72427 .44826 L .72429 .44199 L .735 .468 .525 r
F
.72427 .44826 m .72444 .44827 L .72429 .44199 L F
.72456 .44206 m .72691 .44153 L .72497 .44172 L .655 .781 .941 r
F
.72544 .4423 m .72691 .44153 L .72456 .44206 L F
.72395 .4419 m .72497 .44172 L .72375 .44185 L F
.72463 .44201 m .72497 .44172 L .72364 .44195 L F
.72371 .44185 m .73915 .42978 L .73257 .4283 L F
.72497 .44172 m .73915 .42978 L .72371 .44185 L F
.7236 .44195 m .72389 .44824 L .72408 .44198 L .735 .468 .525 r
F
.72389 .44824 m .72427 .44826 L .72408 .44198 L F
.72267 .44196 m .72286 .44194 L .72268 .43564 L .657 .408 .532 r
F
.7233 .43568 m .72268 .43564 L .72308 .44191 L .735 .468 .525 r
F
.72192 .43572 m .73178 .4217 L .72454 .4213 L .656 .78 .94 r
F
.72271 .43564 m .73178 .4217 L .72192 .43572 L F
.72272 .44189 m .73257 .4283 L .72527 .42791 L .655 .781 .941 r
F
.72275 .44189 m .73257 .4283 L .72272 .44189 L F
.72306 .4506 m .72458 .44828 L .7235 .44821 L .655 .782 .942 r
F
.7236 .44195 m .72308 .44191 L .72349 .44821 L .735 .468 .525 r
F
.72389 .44824 m .72349 .44821 L .725 .47155 L F
.7236 .44195 m .72349 .44821 L .72389 .44824 L F
.72164 .43729 m .72192 .43572 L .72119 .43579 L .656 .78 .94 r
F
.72207 .4357 m .72144 .43577 L .72184 .44204 L .657 .408 .532 r
F
.72081 .43594 m .72015 .43613 L .72055 .4424 L .566 .34 .531 r
F
.72081 .43594 m .72055 .4424 L .72109 .44225 L F
.72015 .43613 m .72031 .44254 L .72055 .4424 L .414 .228 .517 r
F
.71808 .43788 m .71671 .43811 L .71754 .43863 L .656 .78 .94 r
F
.72235 .44393 m .71059 .43037 L .70424 .43306 L .655 .781 .941 r
F
.72081 .43594 m .72109 .44225 L .72144 .43577 L .566 .34 .531 r
F
.72109 .44225 m .72161 .4421 L .72144 .43577 L F
.72144 .43577 m .72161 .4421 L .72184 .44204 L F
.72235 .44393 m .71777 .42861 L .71059 .43037 L .655 .781 .941 r
F
.72236 .44199 m .72184 .44204 L .72224 .44834 L .657 .408 .532 r
F
.72306 .4506 m .72349 .44821 L .72238 .44832 L .655 .782 .942 r
F
.71344 .4508 m .71302 .44927 L .69469 .4512 L F
.71877 .44375 m .71846 .44417 L .71886 .45046 L .076 0 .438 r
F
.71877 .44375 m .71886 .45046 L .7191 .45014 L F
.71877 .44375 m .7191 .45014 L .71919 .44318 L F
.7191 .45014 m .71943 .44969 L .71919 .44318 L F
.71846 .44417 m .71885 .45062 L .71886 .45046 L 0 0 .132 r
F
.72306 .4506 m .71702 .4498 L .71344 .4508 L .655 .782 .942 r
F
.71702 .4498 m .71302 .44927 L .71344 .4508 L F
.72109 .44225 m .72055 .4424 L .72095 .4487 L .566 .34 .531 r
F
.71919 .44318 m .71943 .44969 L .71959 .44948 L .076 0 .438 r
F
.72306 .4506 m .69982 .44317 L .69634 .44707 L .655 .782 .942 r
F
.71976 .44285 m .71959 .44948 L .72004 .44922 L .414 .228 .517 r
F
.71976 .44285 m .72004 .44922 L .72031 .44254 L F
.72004 .44922 m .72047 .44897 L .72031 .44254 L F
.72306 .4506 m .70492 .43976 L .69982 .44317 L .655 .782 .942 r
F
.72109 .44225 m .72095 .4487 L .72138 .44858 L .566 .34 .531 r
F
.72031 .44254 m .72047 .44897 L .72055 .4424 L .414 .228 .517 r
F
.72047 .44897 m .72066 .44887 L .72055 .4424 L F
.72055 .4424 m .72066 .44887 L .72095 .4487 L F
.72306 .4506 m .71129 .43708 L .70492 .43976 L .655 .782 .942 r
F
.72236 .44199 m .72224 .44834 L .72266 .4483 L .657 .408 .532 r
F
.72109 .44225 m .72138 .44858 L .72161 .4421 L .566 .34 .531 r
F
.72138 .44858 m .72179 .44847 L .72161 .4421 L F
.72184 .44204 m .72179 .44847 L .72224 .44834 L F
.72161 .4421 m .72179 .44847 L .72184 .44204 L F
.72306 .4506 m .71848 .43532 L .71129 .43708 L .655 .782 .942 r
F
.72138 .44858 m .72095 .4487 L .72243 .472 L .566 .34 .531 r
F
.72266 .4483 m .72224 .44834 L .72373 .47164 L .657 .408 .532 r
F
.72306 .4506 m .7235 .44821 L .72349 .44821 L .655 .782 .942 r
F
.72266 .4483 m .72305 .44826 L .72286 .44194 L .657 .408 .532 r
F
.72349 .44821 m .72373 .47164 L .725 .47155 L F
.72308 .44191 m .72322 .44824 L .72349 .44821 L F
.72322 .44824 m .72373 .47164 L .72349 .44821 L F
.72266 .4483 m .72286 .44194 L .72267 .44196 L F
.72371 .44185 m .73257 .4283 L .72271 .44195 L .655 .781 .941 r
F
.72236 .44199 m .72266 .4483 L .72267 .44196 L .657 .408 .532 r
F
.72286 .44194 m .72373 .47164 L .72308 .44191 L F
.72349 .44821 m .726 .43462 L .72232 .44814 L .655 .782 .942 r
F
.7235 .44821 m .7235 .44821 L .72349 .44821 L F
.7235 .44821 m .726 .43462 L .72349 .44821 L F
.72238 .44832 m .72349 .44821 L .72232 .44814 L F
.72207 .4357 m .72184 .44204 L .72236 .44199 L .657 .408 .532 r
F
.72364 .44195 m .72395 .4419 L .72371 .44185 L .655 .781 .941 r
F
.72395 .4419 m .72375 .44185 L .72371 .44185 L F
.72271 .44195 m .72275 .44189 L .72272 .44189 L F
.72364 .44195 m .72371 .44185 L .72308 .44191 L F
.72207 .4357 m .72236 .44199 L .72268 .43564 L .657 .408 .532 r
F
.72236 .44199 m .72267 .44196 L .72268 .43564 L F
.72053 .40228 m .7193 .40237 L .72144 .43577 L F
.72119 .43579 m .72454 .4213 L .71708 .42201 L .656 .78 .94 r
F
.72192 .43572 m .72454 .4213 L .72119 .43579 L F
.72179 .44204 m .72527 .42791 L .71777 .42861 L .655 .781 .941 r
F
.72271 .44195 m .72527 .42791 L .72179 .44204 L F
.72232 .44814 m .726 .43462 L .71848 .43532 L .655 .782 .942 r
F
.72608 .44272 m .72801 .44299 L .7265 .44258 L .655 .781 .941 r
F
.72678 .44319 m .72801 .44299 L .72608 .44272 L F
.7235 .44821 m .73331 .43501 L .726 .43462 L .655 .782 .942 r
F
.72458 .44828 m .73331 .43501 L .7235 .44821 L F
.72389 .44824 m .725 .47155 L .72427 .44826 L .735 .468 .525 r
F
.72427 .44826 m .725 .47155 L .72444 .44827 L F
.72546 .44849 m .72622 .47169 L .72562 .44853 L .818 .533 .507 r
F
.72771 .44909 m .73357 .44885 L .72928 .44858 L .655 .782 .942 r
F
.72941 .44954 m .73357 .44885 L .72771 .44909 L F
.73357 .44885 m .75126 .44591 L .72928 .44858 L F
.7247 .44829 m .725 .47155 L .72622 .47169 L .735 .468 .525 r
F
.72444 .44827 m .725 .47155 L .7247 .44829 L F
.72587 .4486 m .72622 .47169 L .7274 .47208 L .818 .533 .507 r
F
.72562 .44853 m .72622 .47169 L .72587 .4486 L F
.72653 .44877 m .74919 .44213 L .74532 .43891 L .655 .782 .942 r
F
.72771 .44909 m .74919 .44213 L .72653 .44877 L F
.72624 .44884 m .72587 .4486 L .7274 .47208 L .928 .626 .449 r
F
.72555 .44851 m .74532 .43891 L .7399 .43648 L .655 .782 .942 r
F
.72653 .44877 m .74532 .43891 L .72555 .44851 L F
.72509 .44839 m .7247 .44829 L .72622 .47169 L .818 .533 .507 r
F
.72624 .44884 m .7274 .47208 L .72658 .44907 L .928 .626 .449 r
F
.7277 .44982 m .7326 .45039 L .72941 .44954 L .655 .782 .942 r
F
.72868 .45048 m .7326 .45039 L .7277 .44982 L F
.7326 .45039 m .7514 .44999 L .72941 .44954 L F
.72509 .44839 m .72622 .47169 L .72546 .44849 L .818 .533 .507 r
F
.72266 .4483 m .72373 .47164 L .72305 .44826 L .657 .408 .532 r
F
.71302 .44927 m .69634 .44707 L .69472 .45112 L .655 .782 .942 r
F
.71302 .44927 m .69472 .45112 L .69469 .4512 L F
.72004 .44922 m .71959 .44948 L .72106 .47282 L .414 .228 .517 r
F
.71541 .45187 m .71344 .4508 L .70118 .45423 L .655 .782 .942 r
F
.71742 .45072 m .71344 .4508 L .71541 .45187 L F
.71344 .4508 m .69469 .4512 L .70118 .45423 L F
.72138 .44858 m .72243 .472 L .72179 .44847 L .566 .34 .531 r
F
.72054 .45265 m .72089 .45279 L .72241 .47658 L .857 .566 .495 r
F
.72054 .45265 m .72241 .47658 L .7202 .45253 L F
.72047 .44897 m .72106 .47282 L .72066 .44887 L .414 .228 .517 r
F
.71052 .45466 m .70118 .45423 L .69718 .45898 L .655 .782 .942 r
F
.71541 .45187 m .70118 .45423 L .71052 .45466 L F
.70118 .45423 m .69498 .45526 L .69534 .45587 L F
.70118 .45423 m .69534 .45587 L .69718 .45898 L F
.72224 .44834 m .72243 .472 L .72373 .47164 L .566 .34 .531 r
F
.72179 .44847 m .72243 .472 L .72224 .44834 L F
.72004 .44922 m .72106 .47282 L .72047 .44897 L .414 .228 .517 r
F
.71905 .45165 m .72065 .47547 L .71889 .45136 L .965 .686 .26 r
F
.71882 .45122 m .72065 .47547 L .7203 .47474 L F
.71889 .45136 m .72065 .47547 L .71882 .45122 L F
.71963 .46025 m .71932 .45439 L .72065 .47547 L F
.71905 .45165 m .71932 .45439 L .71963 .46025 L F
.71905 .45165 m .71916 .45186 L .71932 .45439 L F
.71916 .45186 m .72134 .47609 L .72065 .47547 L .947 .644 .431 r
F
.71931 .45197 m .72134 .47609 L .71916 .45186 L F
.7191 .45014 m .71886 .45046 L .72033 .47389 L .076 0 .438 r
F
.71883 .45097 m .71882 .45122 L .7203 .47474 L 0 0 .132 r
F
.72095 .4487 m .72106 .47282 L .72243 .472 L .414 .228 .517 r
F
.72066 .44887 m .72106 .47282 L .72095 .4487 L F
.7191 .45014 m .72033 .47389 L .71943 .44969 L .076 0 .438 r
F
.71181 .46003 m .70111 .46212 L .70651 .46447 L .655 .782 .942 r
F
.71534 .45524 m .70111 .46212 L .71181 .46003 L F
.71883 .45097 m .7203 .47474 L .71885 .45062 L 0 0 .132 r
F
.71886 .45046 m .7203 .47474 L .72033 .47389 L F
.71885 .45062 m .7203 .47474 L .71886 .45046 L F
.71181 .46003 m .70651 .46447 L .70826 .46485 L .655 .782 .942 r
F
.71181 .46003 m .70826 .46485 L .71302 .46587 L F
.71959 .44948 m .72033 .47389 L .72106 .47282 L .076 0 .438 r
F
.71943 .44969 m .72033 .47389 L .71959 .44948 L F
.72691 .45128 m .72867 .47488 L .72673 .45148 L .157 .044 .463 r
F
.72658 .44907 m .7274 .47208 L .72673 .44917 L .928 .626 .449 r
F
.72691 .45128 m .72709 .45108 L .72867 .47488 L .157 .044 .463 r
F
.72696 .44933 m .7274 .47208 L .72851 .47294 L .928 .626 .449 r
F
.72673 .44917 m .7274 .47208 L .72696 .44933 L F
.72709 .45108 m .72711 .45106 L .72867 .47488 L .157 .044 .463 r
F
.72719 .45079 m .7289 .47404 L .72716 .4509 L 0 0 .297 r
F
.72711 .45106 m .7289 .47404 L .72867 .47488 L F
.72716 .4509 m .7289 .47404 L .72711 .45106 L F
.72709 .44965 m .72696 .44933 L .72851 .47294 L .925 .667 .181 r
F
.73061 .45868 m .73461 .46386 L .73054 .45849 L .655 .782 .942 r
F
.72726 .45055 m .72734 .45029 L .7289 .47404 L 0 0 .297 r
F
.72726 .45055 m .7289 .47404 L .72719 .45079 L F
.72721 .44996 m .72851 .47294 L .72726 .45009 L .925 .667 .181 r
F
.73048 .45835 m .73461 .46386 L .72879 .45402 L .655 .782 .942 r
F
.72734 .45029 m .72851 .47294 L .7289 .47404 L .925 .667 .181 r
F
.72726 .45009 m .72851 .47294 L .72734 .45029 L F
.73103 .45974 m .7328 .4643 L .73461 .46386 L .655 .782 .942 r
F
.72709 .44965 m .72851 .47294 L .72721 .44996 L .925 .667 .181 r
F
.61165 .85428 m .6157 .85508 L .61625 .85451 L .655 .815 .961 r
F
.76908 .74712 m .7534 .74949 L .7673 .75032 L .597 .767 .96 r
F
.76908 .74712 m .75602 .74469 L .7534 .74949 L F
0 g
.7534 .74949 m
.75362 .75443 L
s
.60501 .48381 m .59224 .46807 L .59271 .47466 L .941 .656 .473 r
F
.6055 .4904 m .60501 .48381 L .59271 .47466 L F
0 g
.60501 .48381 m
.6121 .49447 L
s
.78211 .74956 m .7673 .75032 L .7812 .75115 L .597 .767 .96 r
F
.78211 .74956 m .76908 .74712 L .7673 .75032 L F
.60197 .85497 m .59742 .85698 L .60217 .85608 L .655 .815 .961 r
F
.60197 .85497 m .59713 .85532 L .59742 .85698 L F
0 g
.59742 .85698 m
.59869 .85846 L
s
.60692 .84785 m .60179 .84817 L .60638 .84841 L .656 .815 .96 r
F
.61614 .85112 m .6208 .84966 L .61605 .85056 L .655 .815 .96 r
F
0 g
.61561 .85295 m
.61578 .8523 L
s
.62039 .84685 m .62389 .84447 L .61957 .84586 L .656 .815 .96 r
F
.62039 .84685 m .62511 .84595 L .62389 .84447 L F
.809 .75281 m .82293 .75033 L .809 .75116 L .597 .767 .96 r
F
.809 .75281 m .8229 .75364 L .82293 .75033 L F
0 g
.60748 .85219 m
.60749 .85284 L
s
.83681 .75447 m .83681 .74482 L .83691 .74951 L 0 0 .046 r
F
.8229 .75364 m .83691 .74951 L .82293 .75033 L .597 .767 .96 r
F
0 g
.83671 .7498 m
.83672 .74956 L
s
.8229 .75364 m .83681 .75447 L .83691 .74951 L .597 .767 .96 r
F
0 g
.83387 .75922 m
.83681 .75447 L
s
.78387 .74345 m .76907 .74245 L .78208 .74488 L .598 .766 .96 r
F
.61526 .84725 m .61816 .84506 L .61455 .84686 L .656 .815 .96 r
F
.61526 .84725 m .61957 .84586 L .61816 .84506 L F
.7839 .7388 m .77273 .73493 L .76918 .73781 L .599 .766 .959 r
F
.78645 .73763 m .77273 .73493 L .7839 .7388 L F
.61165 .85428 m .60691 .85518 L .60733 .85567 L .655 .815 .961 r
F
.32163 .7392 m .31135 .73415 L .30725 .73651 L .595 .768 .962 r
F
.32439 .73837 m .31135 .73415 L .32163 .7392 L F
.80894 .74649 m .82098 .74244 L .80798 .74488 L .598 .766 .96 r
F
.80894 .74649 m .82286 .74566 L .82098 .74244 L F
.34117 .74037 m .34466 .73413 L .33822 .7392 L .595 .768 .962 r
F
.34117 .74037 m .35058 .73649 L .34466 .73413 L F
.80786 .74023 m .81714 .7349 L .80603 .73879 L .599 .766 .959 r
F
.80786 .74023 m .82078 .73779 L .81714 .7349 L F
.77273 .73493 m .75622 .73538 L .76918 .73781 L F
.31847 .74969 m .30363 .74869 L .31724 .75112 L .593 .769 .963 r
F
.60681 .85463 m .60217 .85608 L .60691 .85518 L .655 .815 .961 r
F
.60681 .85463 m .60197 .85497 L .60217 .85608 L F
.61625 .85451 m .62133 .85359 L .61649 .85394 L F
.61165 .85428 m .61625 .85451 L .61649 .85394 L F
.6067 .85123 m .60163 .85215 L .60647 .85181 L .655 .815 .96 r
F
.62555 .84876 m .62518 .84594 L .62395 .84445 L .975 .673 .307 r
F
0 g
.62518 .84594 m
.62544 .84761 L
s
.31899 .74502 m .30659 .74114 L .30417 .74402 L .594 .768 .963 r
F
.32106 .74384 m .30659 .74114 L .31899 .74502 L F
.34408 .75272 m .35435 .7487 L .34256 .75113 L .593 .769 .963 r
F
.34408 .75272 m .35737 .7519 L .35435 .7487 L F
.82264 .741 m .83376 .73534 L .82078 .73779 L .599 .766 .959 r
F
.82264 .741 m .83651 .74016 L .83376 .73534 L F
.68929 .35674 m .65217 .35441 L .6851 .36179 L .643 .737 .917 r
F
.34305 .74645 m .35019 .74113 L .34072 .74502 L .594 .768 .963 r
F
.34305 .74645 m .35483 .74402 L .35019 .74113 L F
.30659 .74114 m .29054 .74159 L .30417 .74402 L F
.37155 .31276 m .3535 .33203 L .3773 .31768 L .644 .737 .916 r
F
.37155 .31276 m .34194 .32232 L .3535 .33203 L F
.60692 .84785 m .60288 .84705 L .60179 .84817 L .656 .815 .96 r
F
.60774 .84734 m .60288 .84705 L .60692 .84785 L F
.75227 .36531 m .78196 .35055 L .74969 .3599 L .643 .737 .917 r
F
.75227 .36531 m .78694 .36147 L .78196 .35055 L F
.5368 .60852 m .55168 .61539 L .54192 .60718 L .658 .807 .955 r
F
.54192 .60718 m .55168 .61539 L .56056 .61161 L F
.62617 .85325 m .62555 .84876 L .62591 .85158 L .725 .515 0 r
F
.62133 .85359 m .62617 .85325 L .62591 .85158 L .655 .815 .961 r
F
0 g
.62544 .85498 m
.62617 .85325 L
s
.61605 .85056 m .61997 .84867 L .61563 .85006 L .655 .815 .96 r
F
.61605 .85056 m .6208 .84966 L .61997 .84867 L F
.30725 .73651 m .29486 .73262 L .2913 .73696 L .595 .768 .962 r
F
.60209 .85099 m .59679 .8525 L .60163 .85215 L .655 .815 .96 r
F
.6067 .85123 m .60209 .85099 L .60163 .85215 L F
0 g
.61534 .85147 m
.61578 .8523 L
s
.29412 .73724 m .29109 .73692 L .29054 .74159 L 0 0 .325 r
F
.29412 .73724 m .29467 .73256 L .29109 .73692 L F
0 g
.29032 .74175 m
.29109 .73692 L
s
.35785 .74723 m .36667 .74157 L .35483 .74402 L .594 .768 .963 r
F
.35785 .74723 m .37116 .7464 L .36667 .74157 L F
.42663 .32027 m .45131 .33715 L .46236 .32863 L .644 .737 .916 r
F
.41947 .32342 m .45131 .33715 L .42663 .32027 L F
.61455 .84686 m .61625 .84451 L .6136 .84658 L .656 .815 .96 r
F
.61455 .84686 m .61816 .84506 L .61625 .84451 L F
0 g
.60748 .85219 m
.60811 .85137 L
s
.30324 .47788 m .33246 .46935 L .30438 .46995 L .657 .779 .939 r
F
.27578 .47453 m .30324 .47788 L .30438 .46995 L F
.60288 .84705 m .59721 .84794 L .60179 .84817 L .656 .815 .96 r
F
.62133 .85359 m .62591 .85158 L .62115 .85248 L .655 .815 .961 r
F
.61649 .85394 m .62133 .85359 L .62115 .85248 L F
.61165 .85428 m .60681 .85463 L .60691 .85518 L F
.59782 .85358 m .59679 .8525 L .59713 .85532 L 0 0 .408 r
F
.60209 .85099 m .59748 .85076 L .59679 .8525 L .655 .815 .96 r
F
.59782 .85358 m .59748 .85076 L .59679 .8525 L 0 0 .408 r
F
.37116 .7464 m .37162 .74173 L .36714 .73689 L .979 .748 .518 r
F
0 g
.37162 .74173 m
.37336 .7467 L
s
.16325 .4796 m .16866 .48473 L .16838 .49132 L .985 .761 .361 r
F
.16325 .4796 m .16354 .47297 L .16866 .48473 L F
.19177 .47237 m .16866 .48473 L .19504 .48022 L .657 .779 .939 r
F
.19177 .47237 m .16354 .47297 L .16866 .48473 L F
0 g
.16866 .48473 m
.17413 .49035 L
s
.60774 .84734 m .60452 .84603 L .60288 .84705 L .656 .815 .96 r
F
.60878 .84692 m .60452 .84603 L .60774 .84734 L F
.61649 .85394 m .62115 .85248 L .6164 .85338 L .655 .815 .961 r
F
.61165 .85428 m .61649 .85394 L .6164 .85338 L F
.60725 .85066 m .60209 .85099 L .6067 .85123 L .655 .815 .96 r
F
.6208 .84966 m .62431 .84727 L .61997 .84867 L F
.6208 .84966 m .62555 .84876 L .62431 .84727 L F
.77581 .48212 m .79037 .46578 L .79119 .47237 L .419 .266 .566 r
F
.7585 .47177 m .77581 .48212 L .79119 .47237 L .655 .782 .942 r
F
.74596 .47689 m .77581 .48212 L .7585 .47177 L F
0 g
.75709 .48967 m
.77581 .48212 L
s
.6136 .84658 m .61398 .84423 L .61247 .84644 L .656 .815 .96 r
F
.6136 .84658 m .61625 .84451 L .61398 .84423 L F
.68935 .34855 m .66054 .33598 L .65233 .34622 L .644 .736 .916 r
F
.69551 .34431 m .66054 .33598 L .68935 .34855 L F
.61957 .84586 m .62177 .84326 L .61816 .84506 L .656 .815 .96 r
F
.61957 .84586 m .62389 .84447 L .62177 .84326 L F
.69567 .33623 m .67315 .31933 L .66096 .32794 L .645 .736 .915 r
F
.70334 .33312 m .67315 .31933 L .69567 .33623 L F
.61563 .85006 m .61855 .84786 L .61492 .84966 L .655 .815 .96 r
F
.61563 .85006 m .61997 .84867 L .61855 .84786 L F
.61165 .85428 m .60705 .85405 L .60681 .85463 L .655 .815 .961 r
F
.61165 .85428 m .6076 .85349 L .60705 .85405 L F
.61165 .85428 m .60842 .85298 L .6076 .85349 L F
.61165 .85428 m .60947 .85255 L .60842 .85298 L F
.61165 .85428 m .61067 .85225 L .60947 .85255 L F
.61165 .85428 m .61193 .85209 L .61067 .85225 L F
.61165 .85428 m .61318 .85207 L .61193 .85209 L F
.61165 .85428 m .61432 .85221 L .61318 .85207 L F
.61165 .85428 m .61528 .85249 L .61432 .85221 L F
.61165 .85428 m .61599 .85289 L .61528 .85249 L F
.61165 .85428 m .6164 .85338 L .61599 .85289 L F
.7496 .3517 m .77234 .33256 L .74483 .34689 L .644 .736 .916 r
F
.7496 .3517 m .78179 .34233 L .77234 .33256 L F
.74462 .33879 m .75867 .31665 L .73802 .33494 L .645 .736 .915 r
F
.74462 .33879 m .77191 .3245 L .75867 .31665 L F
.34192 .3697 m .32535 .34708 L .32436 .35531 L .922 .668 .537 r
F
0 g
.34192 .3697 m
.35275 .38502 L
s
.60878 .84692 m .60661 .84519 L .60452 .84603 L .656 .815 .96 r
F
.60997 .84662 m .60661 .84519 L .60878 .84692 L F
.32439 .73837 m .31687 .73247 L .31135 .73415 L .595 .768 .962 r
F
.32766 .73794 m .31687 .73247 L .32439 .73837 L F
.66054 .33598 m .61927 .33878 L .65233 .34622 L .644 .736 .916 r
F
.33822 .7392 m .33784 .73245 L .33482 .73837 L .595 .768 .962 r
F
.33822 .7392 m .34466 .73413 L .33784 .73245 L F
.61247 .84644 m .61151 .84426 L .61123 .84646 L .656 .815 .96 r
F
.61247 .84644 m .61398 .84423 L .61151 .84426 L F
.23497 .33847 m .22328 .31663 L .1989 .32199 L .643 .737 .917 r
F
.25271 .33791 m .22328 .31663 L .23497 .33847 L F
.60705 .85405 m .60197 .85497 L .60681 .85463 L .655 .815 .961 r
F
.62555 .84876 m .62395 .84445 L .62431 .84727 L .975 .673 .307 r
F
.62591 .85158 m .62555 .84876 L .62431 .84727 L F
0 g
.62555 .84876 m
.62581 .85043 L
s
.61421 .85081 m
.61534 .85147 L
s
.61534 .85147 m
.61534 .85147 L
s
.2203 .46516 m .19229 .46576 L .19554 .4736 L .657 .779 .938 r
F
.27078 .34034 m .25021 .31576 L .25271 .33791 L .643 .737 .917 r
F
.27078 .34034 m .27766 .31948 L .25021 .31576 L F
.60997 .84662 m .60899 .84459 L .60661 .84519 L .656 .815 .96 r
F
.61123 .84646 m .60899 .84459 L .60997 .84662 L F
0 g
.60811 .85137 m
.60811 .85137 L
s
.60811 .85137 m
.60939 .85075 L
s
.61123 .84646 m .61151 .84426 L .60899 .84459 L .656 .815 .96 r
F
.60725 .85066 m .60319 .84986 L .60209 .85099 L .655 .815 .96 r
F
.60808 .85015 m .60319 .84986 L .60725 .85066 L F
.21741 .3499 m .19728 .32988 L .1771 .33932 L .642 .738 .918 r
F
.23364 .34642 m .19728 .32988 L .21741 .3499 L F
.60288 .84705 m .59884 .84625 L .59721 .84794 L .656 .815 .96 r
F
.78676 .35326 m .81439 .33283 L .78179 .34233 L .644 .736 .916 r
F
.78676 .35326 m .82157 .34937 L .81439 .33283 L F
.59912 .84906 m .59714 .84794 L .59748 .85076 L .223 .129 .532 r
F
.59912 .84906 m .59878 .84624 L .59714 .84794 L F
0 g
.59645 .84968 m
.59714 .84794 L
s
.6164 .85338 m .62033 .85149 L .61599 .85289 L .655 .815 .961 r
F
.6164 .85338 m .62115 .85248 L .62033 .85149 L F
.60244 .85381 m .59713 .85532 L .60197 .85497 L F
.60705 .85405 m .60244 .85381 L .60197 .85497 L F
.47388 .47724 m .46016 .48038 L .4604 .48698 L .36 .206 .532 r
F
.47388 .47724 m .47362 .47062 L .46016 .48038 L F
0 g
.45177 .49145 m
.46016 .48038 L
s
.78645 .73763 m .77783 .73256 L .77273 .73493 L .599 .766 .959 r
F
.78959 .73679 m .77783 .73256 L .78645 .73763 L F
.5851 .61096 m .5915 .59768 L .59214 .60315 L .21 .123 .533 r
F
.56757 .60696 m .5851 .61096 L .59214 .60315 L .658 .807 .955 r
F
.56056 .61161 m .5851 .61096 L .56757 .60696 L F
0 g
.57458 .61788 m
.5851 .61096 L
s
.28696 .35355 m .27665 .32738 L .26973 .34831 L .642 .738 .918 r
F
.28696 .35355 m .30275 .33541 L .27665 .32738 L F
.80603 .73879 m .81196 .73254 L .80345 .73762 L .599 .766 .959 r
F
.80603 .73879 m .81714 .7349 L .81196 .73254 L F
.61492 .84966 m .61664 .84731 L .61397 .84939 L .655 .815 .96 r
F
.61492 .84966 m .61855 .84786 L .61664 .84731 L F
.7839 .74812 m .76908 .74712 L .78211 .74956 L .597 .767 .96 r
F
.60319 .84986 m .59748 .85076 L .60209 .85099 L .655 .815 .96 r
F
.78387 .74345 m .77264 .73956 L .76907 .74245 L .598 .766 .96 r
F
.78644 .74227 m .77264 .73956 L .78387 .74345 L F
.60244 .85381 m .59782 .85358 L .59713 .85532 L .655 .815 .961 r
F
0 g
.59713 .85532 m
.59742 .85698 L
s
.37546 .33416 m .36624 .35619 L .38289 .33808 L .643 .738 .918 r
F
.37546 .33416 m .35144 .3485 L .36624 .35619 L F
.809 .75116 m .82106 .74713 L .80804 .74956 L .597 .767 .96 r
F
.809 .75116 m .82293 .75033 L .82106 .74713 L F
.32106 .74384 m .31071 .73877 L .30659 .74114 L .594 .768 .963 r
F
.32383 .74301 m .31071 .73877 L .32106 .74384 L F
.60452 .84603 m .59884 .84625 L .60288 .84705 L .656 .815 .96 r
F
.49338 .48755 m .47388 .47724 L .4604 .48698 L .655 .781 .941 r
F
.50511 .48249 m .47388 .47724 L .49338 .48755 L F
.80798 .74488 m .81732 .73954 L .80615 .74344 L .598 .766 .96 r
F
.80798 .74488 m .82098 .74244 L .81732 .73954 L F
.34072 .74502 m .34423 .73876 L .33775 .74384 L .594 .768 .963 r
F
.34072 .74502 m .35019 .74113 L .34423 .73876 L F
.77264 .73956 m .75602 .74001 L .76907 .74245 L .598 .766 .96 r
F
.56034 .47482 m .55545 .4571 L .54719 .47208 L .656 .78 .94 r
F
.56034 .47482 m .57531 .4613 L .55545 .4571 L F
.41806 .33992 m .43582 .35984 L .45022 .35367 L .643 .738 .918 r
F
.40963 .34169 m .43582 .35984 L .41806 .33992 L F
.60808 .85015 m .60484 .84884 L .60319 .84986 L .655 .815 .96 r
F
.60912 .84973 m .60484 .84884 L .60808 .85015 L F
.32766 .73794 m .32344 .7316 L .31687 .73247 L .595 .768 .962 r
F
.33122 .73794 m .32344 .7316 L .32766 .73794 L F
.31847 .74969 m .30605 .74582 L .30363 .74869 L .593 .769 .963 r
F
.32054 .74852 m .30605 .74582 L .31847 .74969 L F
.6076 .85349 m .60244 .85381 L .60705 .85405 L .655 .815 .961 r
F
.64613 .47553 m .65753 .47811 L .65811 .4847 L .944 .656 .461 r
F
.64613 .47553 m .64556 .46891 L .65753 .47811 L F
.67092 .46066 m .65753 .47811 L .67884 .46687 L .655 .781 .941 r
F
.67092 .46066 m .64556 .46891 L .65753 .47811 L F
0 g
.65753 .47811 m
.6648 .48119 L
s
.77273 .73493 m .76151 .73103 L .75622 .73538 L .599 .766 .959 r
F
.62115 .85248 m .62468 .85009 L .62033 .85149 L .655 .815 .961 r
F
.62115 .85248 m .62591 .85158 L .62468 .85009 L F
.57246 .49242 m .57643 .47435 L .56132 .48788 L .655 .782 .942 r
F
.57246 .49242 m .59319 .48128 L .57643 .47435 L F
.33482 .73837 m .3306 .73159 L .33122 .73794 L .595 .768 .962 r
F
.33482 .73837 m .33784 .73245 L .3306 .73159 L F
.76134 .73565 m .75603 .73534 L .75602 .74001 L .219 .094 .487 r
F
.76134 .73565 m .76134 .73097 L .75603 .73534 L F
0 g
.75341 .74018 m
.75603 .73534 L
s
.61304 .85051 m
.61421 .85081 L
s
.82286 .74566 m .83405 .73998 L .82098 .74244 L .598 .766 .96 r
F
.82286 .74566 m .83681 .74482 L .83405 .73998 L F
.34256 .75113 m .3497 .74582 L .34023 .74969 L .593 .769 .963 r
F
.34256 .75113 m .35435 .7487 L .3497 .74582 L F
.30605 .74582 m .28998 .74626 L .30363 .74869 L F
0 g
.60939 .85075 m
.61063 .85048 L
s
.61397 .84939 m .61435 .84703 L .61283 .84925 L .655 .815 .96 r
F
.61397 .84939 m .61664 .84731 L .61435 .84703 L F
.62431 .84727 m .62395 .84445 L .62183 .84324 L .931 .634 .459 r
F
0 g
.62395 .84445 m
.62518 .84594 L
s
.61997 .84867 m .62219 .84606 L .61855 .84786 L .655 .815 .96 r
F
.61997 .84867 m .62431 .84727 L .62219 .84606 L F
.31135 .73415 m .29486 .73262 L .30725 .73651 L .595 .768 .962 r
F
.66096 .32794 m .63201 .31526 L .62001 .33074 L .645 .736 .915 r
F
.61816 .84506 m .61892 .84243 L .61625 .84451 L .656 .815 .96 r
F
.61816 .84506 m .62177 .84326 L .61892 .84243 L F
.61599 .85289 m .61891 .85069 L .61528 .85249 L .655 .815 .961 r
F
.61599 .85289 m .62033 .85149 L .61891 .85069 L F
.29357 .74193 m .29054 .74159 L .28998 .74626 L 0 0 .325 r
F
.30659 .74114 m .29412 .73724 L .29054 .74159 L .594 .768 .963 r
F
.29357 .74193 m .29412 .73724 L .29054 .74159 L 0 0 .325 r
F
0 g
.28976 .7464 m
.29054 .74159 L
s
.30073 .32524 m
.30166 .32654 L
s
.35737 .7519 m .36621 .74626 L .35435 .7487 L .593 .769 .963 r
F
.35737 .7519 m .3707 .75108 L .36621 .74626 L F
.63136 .32325 m .61951 .33063 L .61927 .33878 L .091 0 .408 r
F
.62891 .32478 m .63157 .31506 L .61951 .33063 L F
.6314 .32157 m .63157 .31506 L .62891 .32478 L F
.67315 .31933 m .63201 .31526 L .66096 .32794 L .645 .736 .915 r
F
.63236 .32088 m .63157 .31506 L .6314 .32157 L .335 .156 .484 r
F
.64426 .31384 m .63279 .31332 L .64994 .31198 L .662 .418 .54 r
F
.67315 .31933 m .66494 .31318 L .64663 .31434 L .645 .736 .915 r
F
.63888 .31594 m .64663 .31434 L .63201 .31526 L F
.67315 .31933 m .64663 .31434 L .63888 .31594 L F
.67081 .30934 m .64994 .31198 L .67623 .30654 L .583 .353 .533 r
F
.64991 .31366 m .64994 .31198 L .67081 .30934 L F
.63279 .31332 m .63281 .31253 L .64994 .31198 L .662 .418 .54 r
F
.62238 .31453 m .62243 .31286 L .63279 .31332 L F
.63277 .3142 m .63279 .31332 L .64426 .31384 L F
.62238 .31453 m .63279 .31332 L .63277 .3142 L F
.62463 .28985 m .62246 .31252 L .64984 .31165 L .645 .736 .915 r
F
.66494 .31318 m .63351 .31418 L .63201 .31526 L F
.63276 .31474 m .63157 .31506 L .63256 .32239 L .335 .156 .484 r
F
.6326 .32071 m .64994 .31198 L .64978 .32017 L .662 .418 .54 r
F
.62219 .32103 m .63268 .31761 L .6326 .32071 L F
.63268 .31761 m .64994 .31198 L .6326 .32071 L F
.64311 .28925 m .64984 .31165 L .676 .30623 L .645 .736 .915 r
F
.62463 .28985 m .64984 .31165 L .64311 .28925 L F
.66494 .31318 m .66219 .31112 L .64991 .31366 L F
.67081 .30934 m .67623 .30654 L .67621 .30822 L .583 .353 .533 r
F
.68855 .31299 m .67439 .30898 L .67315 .31933 L .645 .736 .915 r
F
.67439 .30898 m .65022 .30214 L .6647 .313 L F
.67439 .30898 m .6647 .313 L .67315 .31933 L F
.69483 .3005 m .67623 .30654 L .69966 .29682 L .484 .274 .519 r
F
.67621 .30822 m .67623 .30654 L .69483 .3005 L F
.66073 .28554 m .676 .30623 L .69931 .29655 L .645 .736 .915 r
F
.64311 .28925 m .676 .30623 L .66073 .28554 L F
.67439 .30898 m .67344 .2924 L .65022 .30214 L F
.68855 .31299 m .68299 .30541 L .67439 .30898 L F
.68299 .30541 m .67344 .2924 L .67439 .30898 L F
.7061 .30938 m .67344 .2924 L .68855 .31299 L F
.69483 .3005 m .69966 .29682 L .69965 .2985 L .484 .274 .519 r
F
.67635 .27894 m .69931 .29655 L .71826 .28314 L .645 .736 .915 r
F
.66073 .28554 m .69931 .29655 L .67635 .27894 L F
.69352 .30284 m .70004 .28684 L .67344 .2924 L F
.7061 .30938 m .70261 .29641 L .69352 .30284 L F
.71478 .28781 m .69966 .29682 L .71744 .28424 L .345 .167 .491 r
F
.71744 .28478 m .71744 .28424 L .7187 .28334 L F
.71478 .28781 m .71744 .28424 L .71744 .28478 L F
.69965 .2985 m .69966 .29682 L .71478 .28781 L F
.70261 .29641 m .70004 .28684 L .69352 .30284 L .645 .736 .915 r
F
.72453 .30879 m .70714 .29321 L .7061 .30938 L F
.70714 .29321 m .70004 .28684 L .70261 .29641 L F
.70714 .29321 m .70261 .29641 L .7061 .30938 L F
.74249 .31128 m .72802 .28592 L .72453 .30879 L F
.71744 .28592 m .7187 .28334 L .7187 .28503 L .345 .167 .491 r
F
.71478 .28781 m .71744 .28478 L .71744 .28592 L F
.71744 .28478 m .7187 .28334 L .71744 .28592 L F
.72694 .29298 m .72802 .28592 L .71789 .28626 L .645 .736 .915 r
F
.72694 .29298 m .71789 .28626 L .70004 .28684 L F
.72453 .30879 m .72694 .29298 L .70004 .28684 L F
.74249 .31128 m .75529 .28973 L .72802 .28592 L F
.72811 .29384 m .72807 .28557 L .71744 .28592 L .661 .414 .536 r
F
.72811 .29384 m .71744 .28592 L .71744 .29106 L F
.72232 .29233 m .71744 .29106 L .71744 .29249 L F
.69962 .30505 m .71478 .28781 L .71744 .29037 L .345 .167 .491 r
F
.71744 .29249 m .71744 .29037 L .71871 .2916 L F
.69962 .30505 m .71744 .29037 L .71744 .29249 L F
.71203 .29093 m .71056 .29078 L .71478 .28781 L F
.69962 .30505 m .71056 .29078 L .71203 .29093 L F
.69962 .30505 m .69965 .2985 L .71056 .29078 L F
.67613 .31475 m .69483 .3005 L .69962 .30505 L .484 .274 .519 r
F
.69483 .3005 m .69965 .2985 L .69962 .30505 L F
.67613 .31475 m .67621 .30822 L .69483 .3005 L F
.69991 .29306 m .69962 .30505 L .71744 .29249 L .644 .736 .916 r
F
.69441 .29421 m .67321 .29209 L .67313 .29864 L .581 .35 .53 r
F
.68735 .29568 m .69962 .30505 L .69991 .29306 L .644 .736 .916 r
F
.69441 .29421 m .69994 .2865 L .67321 .29209 L .581 .35 .53 r
F
.6999 .29476 m .69991 .29306 L .69441 .29421 L F
.69991 .29306 m .69994 .2865 L .69441 .29421 L F
.72232 .29233 m .71744 .29249 L .71744 .29419 L .661 .414 .536 r
F
.71203 .33137 m .7061 .30938 L .68855 .31299 L .645 .736 .915 r
F
.71478 .29607 m .69962 .30505 L .71744 .29249 L .345 .167 .491 r
F
.70602 .31737 m .70279 .30542 L .69362 .31095 L .644 .736 .916 r
F
.70279 .30542 m .70258 .30465 L .69961 .30674 L F
.70279 .30542 m .69961 .30674 L .69362 .31095 L F
.69477 .30873 m .67613 .31475 L .69962 .30505 L .484 .274 .519 r
F
.67611 .31643 m .67613 .31475 L .69477 .30873 L F
.67081 .30934 m .67621 .30822 L .67613 .31475 L .583 .353 .533 r
F
.67474 .29797 m .67613 .31475 L .69962 .30505 L .644 .736 .916 r
F
.64991 .31366 m .65022 .30214 L .63351 .31418 L .645 .736 .915 r
F
.66219 .31112 m .65022 .30214 L .64991 .31366 L F
.66832 .30065 m .64987 .30188 L .64974 .30841 L .48 .27 .516 r
F
.6663 .30149 m .67613 .31475 L .67474 .29797 L .644 .736 .916 r
F
.66832 .30065 m .67321 .29209 L .64987 .30188 L .48 .27 .516 r
F
.67311 .30033 m .67313 .29864 L .66832 .30065 L F
.67313 .29864 m .67321 .29209 L .66832 .30065 L F
.64978 .32017 m .67081 .30934 L .67613 .31475 L .583 .353 .533 r
F
.64978 .32017 m .64991 .31366 L .67081 .30934 L F
.6575 .30517 m .64978 .32017 L .67613 .31475 L .644 .736 .916 r
F
.64621 .31094 m .64986 .3024 L .63384 .31394 L .335 .156 .484 r
F
.64974 .30841 m .64986 .3024 L .64621 .31094 L F
.64974 .30841 m .64978 .32017 L .6575 .30517 L .644 .736 .916 r
F
.64662 .30971 m .64685 .31048 L .64974 .30841 L F
.64685 .31048 m .64978 .32017 L .64974 .30841 L F
.62219 .32103 m .62238 .31453 L .63277 .3142 L .662 .418 .54 r
F
.63268 .31761 m .63277 .3142 L .64426 .31384 L F
.63276 .31474 m .63277 .3142 L .63157 .31506 L .335 .156 .484 r
F
.62219 .32103 m .63277 .3142 L .63268 .31761 L .662 .418 .54 r
F
.64596 .31112 m .63277 .3142 L .63276 .31474 L .335 .156 .484 r
F
.64621 .31094 m .63277 .3142 L .64596 .31112 L F
.64986 .3024 m .64987 .30188 L .63384 .31394 L F
.63384 .31394 m .64987 .30188 L .63277 .3142 L F
.64231 .31374 m .64978 .32017 L .64685 .31048 L .644 .736 .916 r
F
.64336 .31465 m .63501 .32063 L .64978 .32017 L F
.64231 .31374 m .63501 .32063 L .64336 .31465 L F
.64231 .31374 m .6326 .32071 L .63501 .32063 L F
.63256 .32239 m .63236 .32088 L .63136 .32325 L .335 .156 .484 r
F
.63236 .32088 m .6314 .32157 L .63136 .32325 L F
.63136 .32325 m .6314 .32157 L .62891 .32478 L .091 0 .408 r
F
.66054 .33598 m .63136 .32325 L .61927 .33878 L .644 .736 .916 r
F
.62869 .33299 m .63136 .32325 L .61927 .33878 L .091 0 .408 r
F
.63115 .33148 m .63119 .32979 L .62869 .33299 L F
.63119 .32979 m .63136 .32325 L .62869 .33299 L F
.62196 .32925 m .62219 .32103 L .62275 .32102 L .662 .418 .54 r
F
.67281 .32735 m .63136 .32325 L .66054 .33598 L .644 .736 .916 r
F
.6707 .31754 m .64978 .32017 L .67613 .31475 L .583 .353 .533 r
F
.67281 .32735 m .66482 .32138 L .64726 .32236 L .644 .736 .916 r
F
.67281 .32735 m .64726 .32236 L .63917 .32402 L F
.64974 .32185 m .64978 .32017 L .6707 .31754 L .583 .353 .533 r
F
.64409 .32203 m .63259 .3211 L .64978 .32017 L .662 .418 .54 r
F
.63259 .3211 m .62905 .32082 L .6326 .32071 L F
.63259 .3211 m .6326 .32071 L .64978 .32017 L F
.63215 .32911 m .63136 .32325 L .63119 .32979 L .335 .156 .484 r
F
.62962 .32248 m .62905 .32082 L .63259 .3211 L .662 .418 .54 r
F
.63256 .32239 m .63259 .3211 L .64409 .32203 L F
.62962 .32248 m .63259 .3211 L .63256 .32239 L F
.63917 .32402 m .64726 .32236 L .63136 .32325 L .644 .736 .916 r
F
.66482 .32138 m .63256 .32239 L .63136 .32325 L F
.63255 .32293 m .63136 .32325 L .63235 .33062 L .335 .156 .484 r
F
.62196 .32925 m .64978 .32017 L .64961 .3284 L .662 .418 .54 r
F
.64974 .32185 m .64971 .31009 L .63256 .32239 L .644 .736 .916 r
F
.66482 .32138 m .66206 .31932 L .64974 .32185 L F
.66206 .31932 m .64971 .31009 L .64974 .32185 L F
.6707 .31754 m .67613 .31475 L .67611 .31643 L .583 .353 .533 r
F
.70334 .33312 m .68855 .31299 L .67315 .31933 L .645 .736 .915 r
F
.68834 .32099 m .64971 .31009 L .67281 .32735 L .644 .736 .916 r
F
.64961 .3284 m .6707 .31754 L .67603 .32299 L .583 .353 .533 r
F
.643 .2977 m .67613 .31475 L .66074 .29399 L .644 .736 .916 r
F
.68834 .32099 m .67311 .30033 L .64971 .31009 L F
.6707 .31754 m .67611 .31643 L .67603 .32299 L .583 .353 .533 r
F
.64961 .3284 m .64974 .32185 L .6707 .31754 L F
.65736 .31342 m .64961 .3284 L .67603 .32299 L .644 .737 .917 r
F
.6547 .31453 m .64961 .3284 L .65736 .31342 L F
.6682 .30892 m .64971 .31009 L .64957 .31666 L .48 .27 .516 r
F
.64668 .31873 m .64961 .3284 L .65546 .31245 L .644 .737 .917 r
F
.64596 .31112 m .63276 .31474 L .6326 .32071 L .335 .156 .484 r
F
.64231 .31374 m .64685 .31048 L .643 .2977 L .644 .736 .916 r
F
.64971 .31009 m .64974 .30841 L .64621 .31094 L .335 .156 .484 r
F
.643 .2977 m .64662 .30971 L .64974 .30841 L .644 .736 .916 r
F
.65561 .30419 m .64974 .30841 L .6575 .30517 L F
.643 .2977 m .64974 .30841 L .65561 .30419 L F
.67311 .30033 m .66832 .30065 L .64971 .31009 L .48 .27 .516 r
F
.66832 .30065 m .64974 .30841 L .64971 .31009 L F
.6682 .30892 m .67311 .30033 L .64971 .31009 L F
.64281 .30597 m .65736 .31342 L .6606 .30227 L .644 .737 .917 r
F
.65736 .31342 m .67603 .32299 L .66618 .30976 L F
.65736 .31342 m .66618 .30976 L .6606 .30227 L F
.67302 .30692 m .67311 .30033 L .6682 .30892 L .48 .27 .516 r
F
.69362 .31095 m .69443 .30888 L .69175 .30998 L .644 .736 .916 r
F
.69477 .30873 m .69962 .30505 L .69961 .30674 L .484 .274 .519 r
F
.69961 .30674 m .69962 .30505 L .71478 .29607 L .345 .167 .491 r
F
.66074 .29399 m .69962 .30505 L .67648 .28738 L .644 .736 .916 r
F
.70258 .30465 m .6999 .29476 L .69362 .31095 L F
.71203 .33137 m .68855 .31299 L .70334 .33312 L .645 .736 .915 r
F
.70602 .31737 m .67311 .30033 L .68834 .32099 L .644 .736 .916 r
F
.67603 .32299 m .67611 .31643 L .69477 .30873 L .484 .274 .519 r
F
.67603 .32299 m .69477 .30873 L .69958 .31332 L F
.67532 .30644 m .67603 .32299 L .69958 .31332 L .644 .737 .917 r
F
.69175 .30998 m .6999 .29476 L .67311 .30033 L .644 .736 .916 r
F
.69436 .3025 m .67311 .30033 L .67302 .30692 L .581 .35 .53 r
F
.6606 .30227 m .66526 .30852 L .67532 .30644 L .644 .737 .917 r
F
.66526 .30852 m .67603 .32299 L .67532 .30644 L F
.69443 .30888 m .6999 .29476 L .69175 .30998 L .644 .736 .916 r
F
.69477 .30873 m .69961 .30674 L .69958 .31332 L .484 .274 .519 r
F
.72113 .33109 m .7061 .30938 L .71203 .33137 L .645 .736 .915 r
F
.73 .33231 m .72453 .30879 L .72113 .33109 L F
.72113 .33109 m .72453 .30879 L .7061 .30938 L F
.72459 .31679 m .70728 .30134 L .70602 .31737 L .644 .736 .916 r
F
.70728 .30134 m .6999 .29476 L .70258 .30465 L F
.70728 .30134 m .70258 .30465 L .70602 .31737 L F
.73802 .33494 m .74249 .31128 L .73 .33231 L .645 .736 .915 r
F
.73802 .33494 m .75867 .31665 L .74249 .31128 L F
.73 .33231 m .74249 .31128 L .72453 .30879 L F
.74269 .31929 m .72811 .29384 L .72459 .31679 L .644 .736 .916 r
F
.71744 .29419 m .71871 .2916 L .71872 .2933 L .345 .167 .491 r
F
.71478 .29607 m .71744 .29304 L .71744 .29419 L F
.71744 .29304 m .71871 .2916 L .71744 .29419 L F
.71478 .29607 m .71744 .29249 L .71744 .29304 L F
.72933 .28027 m .71871 .2916 L .73208 .27518 L .124 .002 .428 r
F
.72459 .31679 m .72811 .29384 L .718 .29417 L .644 .736 .916 r
F
.72459 .31679 m .718 .29417 L .7101 .30386 L F
.7101 .30386 m .718 .29417 L .6999 .29476 L F
.72814 .30216 m .72811 .29384 L .71744 .29419 L .661 .414 .536 r
F
.72814 .30216 m .71744 .29419 L .71745 .29935 L F
.72234 .30064 m .71745 .29935 L .71745 .30079 L F
.72811 .29384 m .72232 .29233 L .71744 .29419 L F
.71872 .2999 m .71872 .2933 L .72933 .28027 L .124 .002 .428 r
F
.71872 .2933 m .71871 .2916 L .72933 .28027 L F
.69958 .31332 m .71478 .29607 L .71872 .2999 L .345 .167 .491 r
F
.71478 .29607 m .71872 .2933 L .71872 .2999 L F
.69958 .31332 m .71049 .29908 L .71478 .29607 L F
.71745 .29935 m .71744 .29419 L .6999 .29476 L .661 .414 .536 r
F
.72814 .30216 m .72234 .30064 L .71745 .3025 L F
.72234 .30064 m .71745 .30079 L .71745 .3025 L F
.69958 .31332 m .69961 .30674 L .71049 .29908 L .345 .167 .491 r
F
.69987 .30136 m .69958 .31332 L .71745 .30079 L .644 .737 .917 r
F
.69436 .3025 m .6999 .29476 L .67311 .30033 L .581 .35 .53 r
F
.69987 .30136 m .6999 .29476 L .69436 .3025 L F
.6845 .30185 m .68728 .30397 L .69987 .30136 L .644 .737 .917 r
F
.68728 .30397 m .69958 .31332 L .69987 .30136 L F
.69987 .30306 m .69987 .30136 L .69436 .3025 L .581 .35 .53 r
F
.71745 .3025 m .6999 .29476 L .69987 .30306 L .661 .414 .536 r
F
.71745 .29935 m .6999 .29476 L .71745 .3025 L F
.6999 .29476 m .69441 .29421 L .67311 .30033 L .581 .35 .53 r
F
.69441 .29421 m .67313 .29864 L .67311 .30033 L F
.67638 .29568 m .6845 .30185 L .71872 .2999 L .644 .737 .917 r
F
.6845 .30185 m .71745 .30079 L .71872 .2999 L F
.66074 .29399 m .6663 .30149 L .67474 .29797 L .644 .736 .916 r
F
.6606 .30227 m .69958 .31332 L .67638 .29568 L .644 .737 .917 r
F
.69987 .30306 m .69436 .3025 L .673 .30862 L .581 .35 .53 r
F
.69436 .3025 m .67302 .30692 L .673 .30862 L F
.673 .30862 m .67302 .30692 L .6682 .30892 L .48 .27 .516 r
F
.673 .30862 m .6682 .30892 L .64954 .31835 L F
.6682 .30892 m .64957 .31666 L .64954 .31835 L F
.65546 .31245 m .6547 .31453 L .65736 .31342 L .644 .737 .917 r
F
.64603 .31919 m .64971 .31009 L .63256 .32239 L .335 .156 .484 r
F
.64957 .31666 m .64971 .31009 L .64603 .31919 L F
.64971 .31009 m .64596 .31112 L .63256 .32239 L F
.64596 .31112 m .6326 .32071 L .63256 .32239 L F
.64971 .31009 m .64621 .31094 L .64596 .31112 L F
.64281 .30597 m .64668 .31873 L .65546 .31245 L .644 .737 .917 r
F
.63255 .32293 m .63256 .32239 L .63136 .32325 L .335 .156 .484 r
F
.63094 .32632 m .62962 .32248 L .64409 .32203 L .662 .418 .54 r
F
.64578 .31936 m .63256 .32239 L .63255 .32293 L .335 .156 .484 r
F
.64603 .31919 m .63256 .32239 L .64578 .31936 L F
.64212 .32198 m .64961 .3284 L .64668 .31873 L .644 .737 .917 r
F
.64225 .32209 m .6324 .32893 L .64961 .3284 L F
.64954 .31835 m .64578 .31936 L .63235 .33062 L .335 .156 .484 r
F
.64578 .31936 m .63255 .32293 L .6324 .32893 L F
.64212 .32198 m .64196 .32209 L .64225 .32209 L .644 .737 .917 r
F
.64196 .32209 m .6324 .32893 L .64225 .32209 L F
.64578 .31936 m .6324 .32893 L .63235 .33062 L .335 .156 .484 r
F
.62438 .29831 m .64231 .31374 L .643 .2977 L .644 .736 .916 r
F
.63942 .31126 m .63206 .32072 L .6326 .32071 L F
.63942 .31126 m .6326 .32071 L .64231 .31374 L F
.63279 .31332 m .62243 .31286 L .63281 .31253 L .662 .418 .54 r
F
.62438 .29831 m .62219 .32103 L .63206 .32072 L .644 .736 .916 r
F
.62438 .29831 m .63206 .32072 L .63942 .31126 L F
.62414 .30657 m .64212 .32198 L .64281 .30597 L .644 .737 .917 r
F
.64212 .32198 m .64668 .31873 L .64281 .30597 L F
.64954 .31835 m .64603 .31919 L .64578 .31936 L .335 .156 .484 r
F
.64954 .31835 m .64957 .31666 L .64603 .31919 L F
.63923 .3195 m .63185 .32895 L .6324 .32893 L .644 .737 .917 r
F
.63923 .3195 m .6324 .32893 L .64212 .32198 L F
.63235 .33062 m .63215 .32911 L .63115 .33148 L .335 .156 .484 r
F
.63215 .32911 m .63119 .32979 L .63115 .33148 L F
.62414 .30657 m .62196 .32925 L .63185 .32895 L .644 .737 .917 r
F
.62414 .30657 m .63185 .32895 L .63923 .3195 L F
.71744 .29304 m .71744 .29249 L .71871 .2916 L .345 .167 .491 r
F
.71744 .29419 m .71385 .29261 L .6999 .29476 L .661 .414 .536 r
F
.71385 .29261 m .69994 .2865 L .69991 .29306 L F
.71385 .29261 m .69991 .29306 L .6999 .29476 L F
.67648 .28738 m .68458 .29356 L .70246 .29254 L .644 .736 .916 r
F
.71744 .29106 m .69994 .2865 L .71744 .29419 L .661 .414 .536 r
F
.71076 .29081 m .70246 .29254 L .71871 .2916 L .644 .736 .916 r
F
.67648 .28738 m .70246 .29254 L .71076 .29081 L F
.68458 .29356 m .68735 .29568 L .69991 .29306 L F
.68458 .29356 m .71744 .29249 L .71871 .2916 L F
.71478 .28781 m .7187 .28503 L .71871 .2916 L .345 .167 .491 r
F
.71744 .29106 m .71744 .28592 L .69994 .2865 L .661 .414 .536 r
F
0 g
.61437 .34742 m
.61951 .33063 L
s
.61951 .33063 m
.62201 .3274 L
s
.33122 .73794 m .3306 .73159 L .32344 .7316 L .595 .768 .962 r
F
.51672 .6071 m .51006 .61797 L .52097 .60847 L .658 .807 .955 r
F
.51672 .6071 m .50157 .61527 L .51006 .61797 L F
.83681 .74482 m .83672 .74015 L .83396 .7353 L .985 .733 .345 r
F
0 g
.83663 .74451 m
.83664 .74424 L
s
.6055 .4904 m .59271 .47466 L .59319 .48128 L .941 .656 .473 r
F
0 g
.6055 .4904 m
.6126 .50103 L
s
.35519 .73937 m .36005 .73258 L .35058 .73649 L .595 .768 .962 r
F
.35519 .73937 m .36696 .73692 L .36005 .73258 L F
.60912 .84973 m .60693 .848 L .60484 .84884 L .655 .815 .96 r
F
.61032 .84943 m .60693 .848 L .60912 .84973 L F
.47018 .60516 m .47583 .60673 L .47631 .6122 L .983 .697 .373 r
F
.47018 .60516 m .46971 .59967 L .47583 .60673 L F
0 g
.47583 .60673 m
.4819 .61029 L
s
.61185 .85041 m
.61304 .85051 L
s
.61063 .85048 m
.61185 .85041 L
s
.49026 .5957 m .47611 .60664 L .49425 .60042 L .659 .806 .953 r
F
.49026 .5957 m .47002 .59961 L .47611 .60664 L F
.61283 .84925 m .61186 .84706 L .61158 .84926 L .655 .815 .96 r
F
.61283 .84925 m .61435 .84703 L .61186 .84706 L F
.62591 .85158 m .62431 .84727 L .62468 .85009 L .975 .673 .307 r
F
0 g
.62591 .85158 m
.62617 .85325 L
s
.37116 .7464 m .36714 .73689 L .36667 .74157 L .979 .748 .518 r
F
.3707 .75108 m .37116 .7464 L .36667 .74157 L F
0 g
.37116 .7464 m
.3729 .75136 L
s
.61032 .84943 m .60933 .84739 L .60693 .848 L .655 .815 .96 r
F
.61158 .84926 m .60933 .84739 L .61032 .84943 L F
.61158 .84926 m .61186 .84706 L .60933 .84739 L F
.6076 .85349 m .60353 .85269 L .60244 .85381 L .655 .815 .961 r
F
.60842 .85298 m .60353 .85269 L .6076 .85349 L F
.25271 .33791 m .25021 .31576 L .22328 .31663 L .643 .737 .917 r
F
.4921 .34951 m .50353 .32592 L .503 .33411 L .013 0 .358 r
F
.49154 .35771 m .4921 .34951 L .503 .33411 L F
.46202 .33693 m .4921 .34951 L .503 .33411 L .643 .737 .917 r
F
.45089 .34547 m .4921 .34951 L .46202 .33693 L F
0 g
.48237 .35681 m
.4921 .34951 L
s
.59946 .85189 m .59748 .85076 L .59782 .85358 L .223 .129 .532 r
F
.60319 .84986 m .59912 .84906 L .59748 .85076 L .655 .815 .96 r
F
.59946 .85189 m .59912 .84906 L .59748 .85076 L .223 .129 .532 r
F
0 g
.59679 .8525 m
.59748 .85076 L
s
.82157 .34937 m .8213 .34119 L .81414 .32462 L .971 .709 .288 r
F
0 g
.82129 .34872 m
.82129 .34844 L
s
.61528 .85249 m .61699 .85013 L .61432 .85221 L .655 .815 .961 r
F
.61528 .85249 m .61891 .85069 L .61699 .85013 L F
.78959 .73679 m .78412 .73088 L .77783 .73256 L .599 .766 .959 r
F
.79311 .73636 m .78412 .73088 L .78959 .73679 L F
.27573 .46794 m .30414 .46338 L .27623 .46397 L .657 .779 .938 r
F
.80345 .73762 m .80561 .73086 L .80028 .73679 L .599 .766 .959 r
F
.80345 .73762 m .81196 .73254 L .80561 .73086 L F
.60452 .84603 m .6013 .84472 L .59884 .84625 L .656 .815 .96 r
F
.60661 .84519 m .6013 .84472 L .60452 .84603 L F
.60353 .85269 m .59782 .85358 L .60244 .85381 L .655 .815 .961 r
F
.60484 .84884 m .59912 .84906 L .60319 .84986 L .655 .815 .96 r
F
.32383 .74301 m .31627 .73709 L .31071 .73877 L .594 .768 .963 r
F
.32712 .74258 m .31627 .73709 L .32383 .74301 L F
.33775 .74384 m .33737 .73708 L .33433 .74301 L F
.33775 .74384 m .34423 .73876 L .33737 .73708 L F
.60842 .85298 m .60519 .85167 L .60353 .85269 L .655 .815 .961 r
F
.60947 .85255 m .60519 .85167 L .60842 .85298 L F
.61625 .84451 m .61551 .84201 L .61398 .84423 L .656 .815 .96 r
F
.61625 .84451 m .61892 .84243 L .61551 .84201 L F
.3032 .48447 m .33247 .47595 L .30435 .47655 L .656 .78 .94 r
F
.27569 .48113 m .3032 .48447 L .30435 .47655 L F
.27332 .48485 m .3032 .48447 L .27569 .48113 L F
.61432 .85221 m .61471 .84986 L .61318 .85207 L .655 .815 .961 r
F
.61432 .85221 m .61699 .85013 L .61471 .84986 L F
.62431 .84727 m .62183 .84324 L .62219 .84606 L .931 .634 .459 r
F
.62468 .85009 m .62431 .84727 L .62219 .84606 L F
0 g
.62431 .84727 m
.62555 .84876 L
s
.62033 .85149 m .62255 .84888 L .61891 .85069 L .655 .815 .961 r
F
.62033 .85149 m .62468 .85009 L .62255 .84888 L F
.61855 .84786 m .61931 .84522 L .61664 .84731 L .655 .815 .96 r
F
.61855 .84786 m .62219 .84606 L .61931 .84522 L F
.60159 .84752 m .59878 .84624 L .59912 .84906 L .414 .263 .566 r
F
.60159 .84752 m .60125 .8447 L .59878 .84624 L F
0 g
.59714 .84794 m
.59878 .84624 L
s
.78644 .74227 m .77776 .73719 L .77264 .73956 L .598 .766 .96 r
F
.7896 .74143 m .77776 .73719 L .78644 .74227 L F
.19154 .47899 m .16838 .49132 L .19481 .48683 L .656 .78 .94 r
F
.19154 .47899 m .16325 .4796 L .16838 .49132 L F
0 g
.16838 .49132 m
.17878 .50195 L
s
.80615 .74344 m .81211 .73717 L .80355 .74226 L .598 .766 .96 r
F
.80615 .74344 m .81732 .73954 L .81211 .73717 L F
.60947 .85255 m .60728 .85082 L .60519 .85167 L .655 .815 .961 r
F
.61067 .85225 m .60728 .85082 L .60947 .85255 L F
.61318 .85207 m .61221 .84989 L .61193 .85209 L F
.61318 .85207 m .61471 .84986 L .61221 .84989 L F
.79311 .73636 m .79118 .73 L .78412 .73088 L .599 .766 .959 r
F
.79675 .73636 m .79118 .73 L .79311 .73636 L F
.7839 .74812 m .77265 .74424 L .76908 .74712 L .597 .767 .96 r
F
.78647 .74695 m .77265 .74424 L .7839 .74812 L F
.60661 .84519 m .60442 .84346 L .6013 .84472 L .656 .815 .96 r
F
.60899 .84459 m .60442 .84346 L .60661 .84519 L F
.32054 .74852 m .31018 .74346 L .30605 .74582 L .593 .769 .963 r
F
.32331 .74769 m .31018 .74346 L .32054 .74852 L F
.80028 .73679 m .79852 .72999 L .79675 .73636 L .599 .766 .959 r
F
.80028 .73679 m .80561 .73086 L .79852 .72999 L F
.50493 .47602 m .49145 .46309 L .47391 .47078 L .656 .78 .94 r
F
.51845 .4727 m .49145 .46309 L .50493 .47602 L F
.80804 .74956 m .81739 .74424 L .8062 .74812 L .597 .767 .96 r
F
.80804 .74956 m .82106 .74713 L .81739 .74424 L F
.34023 .74969 m .34373 .74345 L .33725 .74852 L .593 .769 .963 r
F
.34023 .74969 m .3497 .74582 L .34373 .74345 L F
.77265 .74424 m .75602 .74469 L .76908 .74712 L .597 .767 .96 r
F
.61067 .85225 m .60968 .85022 L .60728 .85082 L .655 .815 .961 r
F
.61193 .85209 m .60968 .85022 L .61067 .85225 L F
.54638 .60527 m .56056 .61161 L .56757 .60696 L .658 .807 .955 r
F
.54192 .60718 m .56056 .61161 L .54638 .60527 L F
.61193 .85209 m .61221 .84989 L .60968 .85022 L .655 .815 .961 r
F
.61398 .84423 m .61178 .84205 L .61151 .84426 L .656 .815 .96 r
F
.61398 .84423 m .61551 .84201 L .61178 .84205 L F
.77783 .73256 m .76151 .73103 L .77273 .73493 L .599 .766 .959 r
F
.60353 .85269 m .59946 .85189 L .59782 .85358 L .655 .815 .961 r
F
0 g
.59713 .85532 m
.59782 .85358 L
s
.32712 .74258 m .32288 .73622 L .31627 .73709 L .594 .768 .963 r
F
.33071 .74258 m .32288 .73622 L .32712 .74258 L F
.76135 .74034 m .75602 .74001 L .75602 .74469 L .219 .094 .487 r
F
.77264 .73956 m .76134 .73565 L .75602 .74001 L .598 .766 .96 r
F
.76135 .74034 m .76134 .73565 L .75602 .74001 L .219 .094 .487 r
F
0 g
.7534 .74483 m
.75602 .74001 L
s
.82293 .75033 m .83414 .74468 L .82106 .74713 L .597 .767 .96 r
F
.82293 .75033 m .83691 .74951 L .83414 .74468 L F
.33433 .74301 m .33008 .73621 L .33071 .74258 L .594 .768 .963 r
F
.33433 .74301 m .33737 .73708 L .33008 .73621 L F
.79675 .73636 m .79852 .72999 L .79118 .73 L .599 .766 .959 r
F
.62219 .84606 m .62183 .84324 L .61896 .84239 L .856 .579 .517 r
F
0 g
.62183 .84324 m
.62395 .84445 L
s
.82078 .73779 m .82832 .73098 L .81714 .7349 L .599 .766 .959 r
F
.82078 .73779 m .83376 .73534 L .82832 .73098 L F
.37052 .321 m .35235 .34031 L .37632 .32594 L .643 .737 .917 r
F
.37052 .321 m .34071 .33058 L .35235 .34031 L F
.21998 .47176 m .19177 .47237 L .19504 .48022 L .657 .779 .939 r
F
.60899 .84459 m .608 .84255 L .60442 .84346 L .656 .815 .96 r
F
.61151 .84426 m .608 .84255 L .60899 .84459 L F
.60484 .84884 m .60159 .84752 L .59912 .84906 L .655 .815 .96 r
F
.60693 .848 m .60159 .84752 L .60484 .84884 L F
.31071 .73877 m .29412 .73724 L .30659 .74114 L .594 .768 .963 r
F
.30605 .74582 m .29357 .74193 L .28998 .74626 L .593 .769 .963 r
F
0 g
.28921 .75106 m
.28998 .74626 L
s
.61151 .84426 m .61178 .84205 L .608 .84255 L .656 .815 .96 r
F
.83681 .74482 m .83396 .7353 L .83405 .73998 L .985 .733 .345 r
F
.83691 .74951 m .83681 .74482 L .83405 .73998 L F
0 g
.83672 .74919 m
.83673 .74892 L
s
.33071 .74258 m .33008 .73621 L .32288 .73622 L .594 .768 .963 r
F
.60519 .85167 m .59946 .85189 L .60353 .85269 L .655 .815 .961 r
F
.42603 .32854 m .45089 .34547 L .46202 .33693 L .643 .737 .917 r
F
.41881 .3317 m .45089 .34547 L .42603 .32854 L F
.35483 .74402 m .35972 .73721 L .35019 .74113 L .594 .768 .963 r
F
.35483 .74402 m .36667 .74157 L .35972 .73721 L F
.47414 .48388 m .4604 .48698 L .46063 .49359 L .36 .206 .532 r
F
.47414 .48388 m .47388 .47724 L .4604 .48698 L F
0 g
.45199 .49801 m
.4604 .48698 L
s
.61664 .84731 m .61589 .8448 L .61435 .84703 L .655 .815 .96 r
F
.61664 .84731 m .61931 .84522 L .61589 .8448 L F
.3707 .75108 m .36667 .74157 L .36621 .74626 L .979 .748 .518 r
F
0 g
.3707 .75108 m
.37244 .75603 L
s
.47066 .61066 m .47631 .6122 L .47679 .61768 L .983 .697 .373 r
F
.47066 .61066 m .47018 .60516 L .47631 .6122 L F
.49055 .60123 m .47631 .6122 L .49457 .60596 L .658 .806 .954 r
F
.49055 .60123 m .47018 .60516 L .47631 .6122 L F
0 g
.47631 .6122 m
.48242 .61576 L
s
.62468 .85009 m .62219 .84606 L .62255 .84888 L .931 .634 .459 r
F
0 g
.62468 .85009 m
.62591 .85158 L
s
.61891 .85069 m .61967 .84805 L .61699 .85013 L .655 .815 .961 r
F
.61891 .85069 m .62255 .84888 L .61967 .84805 L F
.49368 .49415 m .47414 .48388 L .46063 .49359 L .655 .782 .942 r
F
0 g
.45221 .5046 m
.46063 .49359 L
s
.50542 .4891 m .47414 .48388 L .49368 .49415 L .655 .782 .942 r
F
.60194 .85035 m .59912 .84906 L .59946 .85189 L .414 .263 .566 r
F
.60194 .85035 m .60159 .84752 L .59912 .84906 L F
0 g
.59748 .85076 m
.59912 .84906 L
s
.7896 .74143 m .7841 .7355 L .77776 .73719 L .598 .766 .96 r
F
.79314 .741 m .7841 .7355 L .7896 .74143 L F
.67153 .46729 m .65811 .4847 L .67946 .47349 L .655 .782 .942 r
F
.67153 .46729 m .64613 .47553 L .65811 .4847 L F
0 g
.65811 .4847 m
.67427 .4915 L
s
.5609 .48127 m .55599 .4635 L .54767 .47853 L .655 .781 .941 r
F
.5609 .48127 m .57598 .46771 L .55599 .4635 L F
.71302 .46587 m .70317 .48085 L .71737 .48157 L .655 .782 .942 r
F
.80355 .74226 m .80572 .73549 L .80036 .74143 L .598 .766 .96 r
F
.80355 .74226 m .81211 .73717 L .80572 .73549 L F
.60693 .848 m .60474 .84626 L .60159 .84752 L .655 .815 .96 r
F
.60933 .84739 m .60474 .84626 L .60693 .848 L F
.68929 .35674 m .6604 .34419 L .65217 .35441 L .643 .737 .917 r
F
.69546 .35251 m .6604 .34419 L .68929 .35674 L F
.32331 .74769 m .31574 .74178 L .31018 .74346 L .593 .769 .963 r
F
.32661 .74726 m .31574 .74178 L .32331 .74769 L F
.79037 .46578 m .78956 .45921 L .8005 .44781 L .255 .152 .539 r
F
0 g
.77959 .46558 m
.78956 .45921 L
s
.33725 .74852 m .33686 .74178 L .33383 .74769 L .593 .769 .963 r
F
.33725 .74852 m .34373 .74345 L .33686 .74178 L F
.60474 .84626 m .60125 .8447 L .60159 .84752 L .528 .343 .575 r
F
.60474 .84626 m .60439 .84343 L .60125 .8447 L F
0 g
.59878 .84624 m
.60125 .8447 L
s
.69551 .34431 m .67281 .32735 L .66054 .33598 L .644 .736 .916 r
F
.70323 .34119 m .67281 .32735 L .69551 .34431 L F
.74969 .3599 m .77248 .34081 L .74491 .3551 L .643 .737 .917 r
F
.74969 .3599 m .78196 .35055 L .77248 .34081 L F
.61435 .84703 m .61214 .84485 L .61186 .84706 L .655 .815 .96 r
F
.61435 .84703 m .61589 .8448 L .61214 .84485 L F
.19728 .32988 m .17845 .33115 L .1771 .33932 L .433 .211 .475 r
F
.19728 .32988 m .19859 .32169 L .17845 .33115 L F
0 g
.16407 .34391 m
.17845 .33115 L
s
.74483 .34689 m .75899 .32468 L .73818 .34302 L .644 .736 .916 r
F
.74483 .34689 m .77234 .33256 L .75899 .32468 L F
.30414 .46338 m .33202 .46278 L .32823 .45088 L .657 .779 .938 r
F
.33246 .46935 m .33244 .46277 L .32864 .45081 L .941 .721 .248 r
F
0 g
.33137 .46937 m
.33185 .46641 L
s
.6604 .34419 m .61903 .34697 L .65217 .35441 L .643 .737 .917 r
F
.62219 .84606 m .61896 .84239 L .61931 .84522 L .856 .579 .517 r
F
.62255 .84888 m .62219 .84606 L .61931 .84522 L F
0 g
.62219 .84606 m
.62431 .84727 L
s
.60519 .85167 m .60194 .85035 L .59946 .85189 L .655 .815 .961 r
F
0 g
.59782 .85358 m
.59946 .85189 L
s
.60728 .85082 m .60194 .85035 L .60519 .85167 L .655 .815 .961 r
F
.60933 .84739 m .60834 .84534 L .60474 .84626 L .655 .815 .96 r
F
.61186 .84706 m .60834 .84534 L .60933 .84739 L F
.78647 .74695 m .77779 .74188 L .77265 .74424 L .597 .767 .96 r
F
.78964 .74611 m .77779 .74188 L .78647 .74695 L F
.61186 .84706 m .61214 .84485 L .60834 .84534 L .655 .815 .96 r
F
0 g
.30379 .3272 m
.30978 .33031 L
s
.8062 .74812 m .81218 .74187 L .8036 .74695 L .597 .767 .96 r
F
.8062 .74812 m .81739 .74424 L .81218 .74187 L F
.21616 .3581 m .19597 .33812 L .17573 .34753 L .642 .739 .919 r
F
.23243 .35462 m .19597 .33812 L .21616 .3581 L F
.23364 .34642 m .22185 .32451 L .19728 .32988 L .642 .738 .918 r
F
.25152 .34587 m .22185 .32451 L .23364 .34642 L F
.61931 .84522 m .61896 .84239 L .61553 .84198 L .79 .531 .545 r
F
0 g
.61896 .84239 m
.62183 .84324 L
s
.78694 .36147 m .81465 .34108 L .78196 .35055 L .643 .737 .917 r
F
.78694 .36147 m .82184 .35759 L .81465 .34108 L F
.26973 .34831 m .24898 .32364 L .25152 .34587 L .642 .738 .918 r
F
.26973 .34831 m .27665 .32738 L .24898 .32364 L F
.54719 .47208 m .53378 .45598 L .53289 .47135 L .656 .78 .94 r
F
.54719 .47208 m .55545 .4571 L .53378 .45598 L F
.31135 .73415 m .301 .72906 L .29486 .73262 L .595 .768 .962 r
F
.31687 .73247 m .301 .72906 L .31135 .73415 L F
.79314 .741 m .7912 .73462 L .7841 .7355 L .598 .766 .96 r
F
.79681 .741 m .7912 .73462 L .79314 .741 L F
.61699 .85013 m .61624 .84763 L .61471 .84986 L .655 .815 .961 r
F
.61699 .85013 m .61967 .84805 L .61624 .84763 L F
.28588 .36176 m .27553 .33564 L .26861 .35652 L .642 .739 .919 r
F
.28588 .36176 m .3017 .34365 L .27553 .33564 L F
.80036 .74143 m .79858 .73462 L .79681 .741 L .598 .766 .96 r
F
.80036 .74143 m .80572 .73549 L .79858 .73462 L F
.27578 .47453 m .30438 .46995 L .27628 .47055 L .657 .779 .939 r
F
.35058 .73649 m .35116 .72901 L .34466 .73413 L .595 .768 .962 r
F
.35058 .73649 m .36005 .73258 L .35116 .72901 L F
.5915 .59768 m .59086 .59222 L .59388 .58399 L 0 0 .405 r
F
0 g
.5851 .59867 m
.59086 .59222 L
s
.77776 .73719 m .76134 .73565 L .77264 .73956 L .598 .766 .96 r
F
.32661 .74726 m .32236 .74091 L .31574 .74178 L .593 .769 .963 r
F
.3302 .74726 m .32236 .74091 L .32661 .74726 L F
.77265 .74424 m .76135 .74034 L .75602 .74469 L .597 .767 .96 r
F
0 g
.7534 .74949 m
.75602 .74469 L
s
.33383 .74769 m .32957 .74091 L .3302 .74726 L .593 .769 .963 r
F
.33383 .74769 m .33686 .74178 L .32957 .74091 L F
.79681 .741 m .79858 .73462 L .7912 .73462 L .598 .766 .96 r
F
.82098 .74244 m .82858 .73562 L .81732 .73954 L F
.82098 .74244 m .83405 .73998 L .82858 .73562 L F
.31018 .74346 m .29357 .74193 L .30605 .74582 L .593 .769 .963 r
F
.60728 .85082 m .60509 .84909 L .60194 .85035 L .655 .815 .961 r
F
.60968 .85022 m .60509 .84909 L .60728 .85082 L F
.83691 .74951 m .83405 .73998 L .83414 .74468 L .985 .733 .345 r
F
0 g
.83681 .75447 m
.83691 .74951 L
s
.3302 .74726 m .32957 .74091 L .32236 .74091 L .593 .769 .963 r
F
.30414 .46338 m .32823 .45088 L .30147 .45546 L .657 .779 .938 r
F
.27623 .46397 m .30414 .46338 L .30147 .45546 L F
.35435 .7487 m .35924 .74191 L .3497 .74582 L .593 .769 .963 r
F
.35435 .7487 m .36621 .74626 L .35924 .74191 L F
.60834 .84534 m .60439 .84343 L .60474 .84626 L .607 .4 .574 r
F
.60834 .84534 m .60799 .84252 L .60439 .84343 L F
0 g
.60125 .8447 m
.60439 .84343 L
s
.60509 .84909 m .60159 .84752 L .60194 .85035 L .528 .343 .575 r
F
0 g
.59946 .85189 m
.60194 .85035 L
s
.60509 .84909 m .60474 .84626 L .60159 .84752 L .528 .343 .575 r
F
0 g
.59912 .84906 m
.60159 .84752 L
s
.30029 .73366 m .29467 .73256 L .29412 .73724 L .311 .135 .473 r
F
.30029 .73366 m .30084 .72898 L .29467 .73256 L F
0 g
.29109 .73692 m
.29467 .73256 L
s
.63115 .33148 m .61927 .33878 L .61903 .34697 L .091 0 .408 r
F
0 g
.61412 .35553 m
.61927 .33878 L
s
.61471 .84986 m .6125 .84768 L .61221 .84989 L .655 .815 .961 r
F
.61471 .84986 m .61624 .84763 L .6125 .84768 L F
.56696 .60149 m .5915 .59768 L .5716 .59624 L .658 .806 .954 r
F
.70651 .46447 m .70317 .48085 L .71302 .46587 L .655 .782 .942 r
F
.70651 .46447 m .69025 .4781 L .70317 .48085 L F
.62255 .84888 m .61931 .84522 L .61967 .84805 L .856 .579 .517 r
F
0 g
.62255 .84888 m
.62468 .85009 L
s
.61589 .8448 m .61553 .84198 L .61179 .84202 L .73 .488 .56 r
F
.61931 .84522 m .61553 .84198 L .61589 .8448 L .79 .531 .545 r
F
0 g
.61553 .84198 m
.61896 .84239 L
s
.51845 .4727 m .51191 .45803 L .49145 .46309 L .656 .78 .94 r
F
.53289 .47135 m .51191 .45803 L .51845 .4727 L F
.36667 .74157 m .36714 .73689 L .3602 .73252 L .913 .673 .562 r
F
0 g
.36714 .73689 m
.37162 .74173 L
s
.60968 .85022 m .60869 .84817 L .60509 .84909 L .655 .815 .961 r
F
.61221 .84989 m .60869 .84817 L .60968 .85022 L F
.61221 .84989 m .6125 .84768 L .60869 .84817 L F
.51349 .60517 m .50157 .61527 L .51672 .6071 L .658 .807 .955 r
F
.51349 .60517 m .49508 .61145 L .50157 .61527 L F
.50511 .48249 m .49154 .46953 L .47388 .47724 L .655 .781 .941 r
F
.51872 .47915 m .49154 .46953 L .50511 .48249 L F
.78964 .74611 m .78413 .7402 L .77779 .74188 L .597 .767 .96 r
F
.79318 .74568 m .78413 .7402 L .78964 .74611 L F
.49154 .35771 m .503 .33411 L .50246 .34235 L .013 0 .358 r
F
.46138 .34515 m .49154 .35771 L .50246 .34235 L .643 .738 .918 r
F
.45022 .35367 m .49154 .35771 L .46138 .34515 L F
0 g
.47472 .37028 m
.49154 .35771 L
s
.61967 .84805 m .61931 .84522 L .61589 .8448 L .79 .531 .545 r
F
0 g
.61931 .84522 m
.62219 .84606 L
s
.8036 .74695 m .80578 .74019 L .80041 .74611 L .597 .767 .96 r
F
.8036 .74695 m .81218 .74187 L .80578 .74019 L F
.82157 .34937 m .81414 .32462 L .81439 .33283 L .971 .709 .288 r
F
.82184 .35759 m .82157 .34937 L .81439 .33283 L F
0 g
.82155 .35694 m
.82155 .35665 L
s
.49106 .60674 m .47679 .61768 L .49508 .61145 L .658 .807 .955 r
F
.49106 .60674 m .47066 .61066 L .47679 .61768 L F
0 g
.47679 .61768 m
.48656 .62336 L
s
.25152 .34587 m .24898 .32364 L .22185 .32451 L .642 .738 .918 r
F
.21979 .47838 m .19481 .48683 L .22135 .48231 L .656 .78 .94 r
F
.21979 .47838 m .19154 .47899 L .19481 .48683 L F
.61214 .84485 m .60799 .84252 L .60834 .84534 L .672 .446 .57 r
F
.61214 .84485 m .61179 .84202 L .60799 .84252 L F
0 g
.60439 .84343 m
.60799 .84252 L
s
.7813 .33424 m .79969 .30996 L .77191 .3245 L .645 .736 .915 r
F
.7813 .33424 m .81365 .32476 L .79969 .30996 L F
.61589 .8448 m .61179 .84202 L .61214 .84485 L .73 .488 .56 r
F
0 g
.60799 .84252 m
.61179 .84202 L
s
.61179 .84202 m
.61553 .84198 L
s
.27623 .46397 m .30147 .45546 L .27482 .46002 L .657 .779 .938 r
F
.53289 .47135 m .53378 .45598 L .51191 .45803 L .656 .78 .94 r
F
.77783 .73256 m .76914 .72746 L .76151 .73103 L .599 .766 .959 r
F
.78412 .73088 m .76914 .72746 L .77783 .73256 L F
.59271 .47466 m .59224 .46807 L .57554 .46109 L .866 .595 .526 r
F
0 g
.59224 .46807 m
.60453 .47724 L
s
.81714 .7349 m .82056 .72741 L .81196 .73254 L .599 .766 .959 r
F
.81714 .7349 m .82832 .73098 L .82056 .72741 L F
.60869 .84817 m .60474 .84626 L .60509 .84909 L .607 .4 .574 r
F
.60869 .84817 m .60834 .84534 L .60474 .84626 L F
0 g
.60159 .84752 m
.60474 .84626 L
s
.60194 .85035 m
.60509 .84909 L
s
.79318 .74568 m .79124 .73932 L .78413 .7402 L .597 .767 .96 r
F
.79686 .74568 m .79124 .73932 L .79318 .74568 L F
.80041 .74611 m .79863 .73932 L .79686 .74568 L F
.80041 .74611 m .80578 .74019 L .79863 .73932 L F
.31071 .73877 m .30029 .73366 L .29412 .73724 L .594 .768 .963 r
F
.31627 .73709 m .30029 .73366 L .31071 .73877 L F
.56132 .48788 m .5564 .47016 L .54806 .48514 L .655 .782 .942 r
F
.56132 .48788 m .57643 .47435 L .5564 .47016 L F
.35019 .74113 m .35077 .73363 L .34423 .73876 L .594 .768 .963 r
F
.35019 .74113 m .35972 .73721 L .35077 .73363 L F
.77779 .74188 m .76135 .74034 L .77265 .74424 L .597 .767 .96 r
F
.61624 .84763 m .61589 .8448 L .61214 .84485 L .73 .488 .56 r
F
.61967 .84805 m .61589 .8448 L .61624 .84763 L .79 .531 .545 r
F
0 g
.61589 .8448 m
.61931 .84522 L
s
.61967 .84805 m
.62255 .84888 L
s
.51055 .59178 m .49026 .5957 L .49425 .60042 L .659 .806 .953 r
F
.79686 .74568 m .79863 .73932 L .79124 .73932 L .597 .767 .96 r
F
.79037 .46578 m .8005 .44781 L .80135 .45441 L .255 .152 .539 r
F
.79119 .47237 m .79037 .46578 L .80135 .45441 L F
.76796 .45858 m .79037 .46578 L .80135 .45441 L .655 .781 .941 r
F
.75773 .46517 m .79037 .46578 L .76796 .45858 L F
0 g
.78033 .47217 m
.79037 .46578 L
s
.82106 .74713 m .82866 .74032 L .81739 .74424 L .597 .767 .96 r
F
.82106 .74713 m .83414 .74468 L .82866 .74032 L F
.76902 .73207 m .76134 .73097 L .76134 .73565 L .409 .24 .538 r
F
.76902 .73207 m .76901 .72738 L .76134 .73097 L F
0 g
.75603 .73534 m
.76134 .73097 L
s
.5915 .59768 m .59388 .58399 L .59453 .58947 L 0 0 .405 r
F
.59214 .60315 m .5915 .59768 L .59453 .58947 L F
.5716 .59624 m .5915 .59768 L .59453 .58947 L .658 .806 .954 r
F
0 g
.58569 .60415 m
.5915 .59768 L
s
.33246 .46935 m .32864 .45081 L .32864 .45741 L .941 .721 .248 r
F
.30438 .46995 m .33246 .46935 L .32864 .45741 L .657 .779 .939 r
F
.33247 .47595 m .33246 .46935 L .32864 .45741 L .941 .721 .248 r
F
0 g
.33137 .47597 m
.33186 .473 L
s
.36964 .32923 m .35144 .3485 L .37546 .33416 L .643 .738 .918 r
F
.36964 .32923 m .33976 .33878 L .35144 .3485 L F
.6125 .84768 m .60834 .84534 L .60869 .84817 L .672 .446 .57 r
F
.6125 .84768 m .61214 .84485 L .60834 .84534 L F
0 g
.60474 .84626 m
.60834 .84534 L
s
.29974 .73836 m .29412 .73724 L .29357 .74193 L .311 .135 .473 r
F
.29974 .73836 m .30029 .73366 L .29412 .73724 L F
0 g
.29054 .74159 m
.29412 .73724 L
s
.31687 .73247 m .30929 .72651 L .301 .72906 L .595 .768 .962 r
F
.32344 .7316 m .30929 .72651 L .31687 .73247 L F
.61624 .84763 m .61214 .84485 L .6125 .84768 L .73 .488 .56 r
F
0 g
.60834 .84534 m
.61214 .84485 L
s
.61214 .84485 m
.61589 .8448 L
s
.61624 .84763 m
.61967 .84805 L
s
.83405 .73998 m .83396 .7353 L .82849 .73092 L .949 .681 .496 r
F
0 g
.83396 .7353 m
.83672 .74015 L
s
.70323 .34119 m .68834 .32099 L .67281 .32735 L .644 .736 .916 r
F
.71199 .33943 m .68834 .32099 L .70323 .34119 L F
.34466 .73413 m .34089 .72648 L .33784 .73245 L .595 .768 .962 r
F
.34466 .73413 m .35116 .72901 L .34089 .72648 L F
.73461 .46386 m .74596 .47689 L .7585 .47177 L .655 .782 .942 r
F
.42529 .33677 m .45022 .35367 L .46138 .34515 L .643 .738 .918 r
F
.41806 .33992 m .45022 .35367 L .42529 .33677 L F
.73818 .34302 m .74269 .31929 L .7301 .34038 L .644 .736 .916 r
F
.73818 .34302 m .75899 .32468 L .74269 .31929 L F
.3678 .30716 m .34194 .32232 L .37155 .31276 L .644 .737 .916 r
F
.3678 .30716 m .3343 .31121 L .34194 .32232 L F
.36667 .74157 m .3602 .73252 L .35972 .73721 L .913 .673 .562 r
F
.36621 .74626 m .36667 .74157 L .35972 .73721 L F
0 g
.36667 .74157 m
.37116 .7464 L
s
.27569 .48113 m .30435 .47655 L .27619 .47716 L .656 .78 .94 r
F
.40129 .2918 m .40306 .29157 L .40244 .30618 L .631 .379 .518 r
F
.40244 .30618 m .40215 .32547 L .40285 .30614 L .644 .737 .916 r
F
.40161 .30625 m .40162 .3065 L .40244 .30618 L F
.40162 .3065 m .40215 .32547 L .40244 .30618 L F
.40129 .2918 m .40244 .30618 L .40107 .3063 L .631 .379 .518 r
F
.39952 .2915 m .40129 .2918 L .40067 .30634 L .753 .483 .524 r
F
.3976 .2903 m .39838 .29097 L .39775 .30545 L .929 .648 .486 r
F
.397 .28859 m .39712 .28951 L .39648 .30402 L .875 .7 .179 r
F
.39829 .31724 m .39312 .32425 L .39937 .3251 L .644 .737 .916 r
F
.40063 .31066 m .39804 .31536 L .40179 .3125 L F
.39804 .31536 m .39312 .32425 L .39829 .31724 L F
.39804 .31536 m .39829 .31724 L .40179 .3125 L F
.40114 .30831 m .40026 .31006 L .40168 .30877 L F
.40026 .31006 m .39312 .32425 L .40063 .31066 L F
.40026 .31006 m .40063 .31066 L .40168 .30877 L F
.40131 .30716 m .40087 .30808 L .40164 .30731 L F
.40087 .30808 m .39312 .32425 L .40114 .30831 L F
.40087 .30808 m .40114 .30831 L .40164 .30731 L F
.4015 .30649 m .40121 .30711 L .40162 .30652 L F
.40121 .30711 m .39312 .32425 L .40131 .30716 L F
.40121 .30711 m .40131 .30716 L .40162 .30652 L F
.40022 .30638 m .39312 .32425 L .4015 .30649 L F
.40067 .30634 m .4015 .30649 L .40161 .30625 L F
.40022 .30638 m .4015 .30649 L .40067 .30634 L F
.40179 .3125 m .39829 .31724 L .40215 .32547 L F
.39829 .31724 m .39937 .3251 L .40215 .32547 L F
.39952 .2915 m .39929 .30607 L .39889 .306 L .753 .483 .524 r
F
.39838 .29097 m .39952 .2915 L .39889 .306 L .849 .569 .514 r
F
.39838 .29097 m .39889 .306 L .398 .30557 L F
.39952 .2915 m .40067 .30634 L .39929 .30607 L .753 .483 .524 r
F
.40129 .2918 m .40107 .3063 L .40067 .30634 L .631 .379 .518 r
F
.40152 .30308 m .39077 .31488 L .39312 .32425 L .644 .737 .916 r
F
.39077 .31488 m .38465 .3216 L .3872 .32239 L F
.39077 .31488 m .3872 .32239 L .39312 .32425 L F
.39712 .28951 m .39659 .30419 L .39648 .30402 L .989 .724 .411 r
F
.397 .28859 m .39639 .30333 L .39636 .30314 L .875 .7 .179 r
F
.397 .28859 m .39648 .30402 L .39639 .30333 L F
.39712 .28951 m .3976 .2903 L .39696 .30478 L .989 .724 .411 r
F
.39712 .28951 m .39696 .30478 L .39659 .30419 L F
.39752 .28742 m .397 .28859 L .39636 .30314 L 0 0 .269 r
F
.39838 .29097 m .398 .30557 L .39775 .30545 L .849 .569 .514 r
F
.3976 .2903 m .39775 .30545 L .39713 .30493 L .929 .648 .486 r
F
.39077 .31488 m .3773 .31768 L .38465 .3216 L .644 .737 .916 r
F
.40152 .30308 m .39432 .30742 L .39077 .31488 L F
.39432 .30742 m .3773 .31768 L .39077 .31488 L F
.40321 .30697 m .40215 .32547 L .403 .32545 L F
.40432 .30953 m .403 .32545 L .41112 .32519 L F
.40321 .30697 m .403 .32545 L .40432 .30953 L F
.40285 .30756 m .40215 .32547 L .40321 .30697 L F
.40285 .3063 m .40215 .32547 L .4029 .30626 L F
.40068 .32237 m .40074 .31917 L .40362 .31894 L .66 .409 .529 r
F
.40356 .32047 m .40362 .31894 L .4062 .31873 L F
.40068 .32237 m .40362 .31894 L .40356 .32047 L F
.40417 .29108 m .40373 .30562 L .40356 .30575 L .286 .104 .449 r
F
.40306 .29157 m .40269 .30608 L .40244 .30618 L .484 .259 .497 r
F
.40492 .29043 m .40536 .28966 L .40475 .30444 L 0 0 .327 r
F
.40457 .30654 m .41112 .32519 L .41531 .3243 L .644 .737 .916 r
F
.40457 .30654 m .41531 .3243 L .40867 .31118 L F
.40451 .30737 m .41112 .32519 L .40457 .30654 L F
.40388 .30587 m .41112 .32519 L .40392 .3058 L F
.40356 .30575 m .41112 .32519 L .40379 .30566 L F
.40281 .30604 m .4029 .30626 L .40356 .30575 L F
.4029 .30626 m .41112 .32519 L .40356 .30575 L F
.40417 .29108 m .40492 .29043 L .40431 .30516 L .286 .104 .449 r
F
.40392 .3058 m .40451 .30737 L .40457 .30654 L .644 .737 .916 r
F
.40379 .30566 m .40388 .30587 L .40392 .3058 L F
.40417 .29108 m .40431 .30516 L .40373 .30562 L .286 .104 .449 r
F
.40306 .29157 m .40417 .29108 L .40356 .30575 L .484 .259 .497 r
F
.40306 .29157 m .40356 .30575 L .40269 .30608 L F
.40152 .30308 m .40281 .30604 L .40379 .30566 L .644 .737 .916 r
F
.40492 .29043 m .40441 .305 L .40431 .30516 L 0 0 .327 r
F
.40619 .30628 m .41947 .32342 L .42663 .32027 L .644 .737 .916 r
F
.40152 .30308 m .40867 .31118 L .40619 .30628 L F
.40867 .31118 m .41947 .32342 L .40619 .30628 L F
.40492 .29043 m .40475 .30444 L .40441 .305 L 0 0 .327 r
F
.40543 .28874 m .40486 .28756 L .40424 .30243 L .99 .735 .374 r
F
.40232 .30967 m .40425 .31418 L .40762 .31327 L .668 .746 .909 r
F
.40867 .31118 m .41531 .3243 L .41947 .32342 L .644 .737 .916 r
F
.40401 .30922 m .40762 .31327 L .4105 .31181 L .668 .746 .909 r
F
.40232 .30967 m .40762 .31327 L .40401 .30922 L F
.40401 .30922 m .4105 .31181 L .40545 .30848 L F
.40425 .31418 m .40617 .31866 L .41121 .3173 L F
.40762 .31327 m .41121 .3173 L .41553 .31512 L F
.40425 .31418 m .41121 .3173 L .40762 .31327 L F
.40397 .31244 m .4076 .31651 L .4105 .31505 L .668 .747 .909 r
F
.40168 .30877 m .40063 .31066 L .40179 .3125 L .644 .737 .916 r
F
.4005 .30982 m .40062 .31447 L .40425 .31418 L .668 .746 .909 r
F
.4005 .30982 m .40425 .31418 L .40232 .30967 L F
.40236 .31288 m .4076 .31651 L .40397 .31244 L .668 .747 .909 r
F
.40227 .3129 m .40232 .31294 L .40236 .31288 L F
.40062 .31447 m .40617 .31866 L .40425 .31418 L .668 .746 .909 r
F
.40232 .31294 m .4076 .31651 L .40236 .31288 L .668 .747 .909 r
F
.40536 .28966 m .40477 .30425 L .40475 .30444 L 0 0 .006 r
F
.40152 .30308 m .42663 .32027 L .4274 .31967 L .644 .737 .916 r
F
.40978 .30655 m .4274 .31967 L .43213 .31593 L F
.40152 .30308 m .4274 .31967 L .40978 .30655 L F
.40536 .28966 m .40482 .30357 L .40477 .30425 L 0 0 .006 r
F
.40667 .30424 m .43213 .31593 L .43558 .31071 L .644 .737 .916 r
F
.40152 .30308 m .40978 .30655 L .40667 .30424 L F
.40978 .30655 m .43213 .31593 L .40667 .30424 L F
.40486 .28756 m .40362 .28662 L .40299 .3015 L .912 .629 .494 r
F
.40373 .30562 m .40375 .3056 L .40374 .30586 L .286 .104 .449 r
F
.40375 .3056 m .40431 .30516 L .40374 .30586 L F
.40281 .30787 m .40232 .30967 L .40401 .30922 L .668 .746 .909 r
F
.40285 .30614 m .40285 .3063 L .4029 .30626 L .644 .737 .916 r
F
.40269 .30608 m .40356 .30575 L .40349 .30729 L .484 .259 .497 r
F
.4027 .30775 m .40189 .30866 L .40281 .30787 L .668 .746 .909 r
F
.40264 .30767 m .40257 .30776 L .4027 .30775 L F
.40257 .30776 m .40189 .30866 L .4027 .30775 L F
.40161 .30625 m .4015 .30649 L .40162 .30652 L .644 .737 .916 r
F
.40107 .3063 m .40244 .30618 L .40237 .30779 L .631 .379 .518 r
F
.40165 .30811 m .40189 .30866 L .40264 .30767 L .668 .746 .909 r
F
.40189 .30866 m .40232 .30967 L .40281 .30787 L F
.40062 .31447 m .40074 .3191 L .40617 .31866 L F
.39697 .31414 m .40074 .3191 L .40062 .31447 L F
.39867 .30965 m .40062 .31447 L .4005 .30982 L F
.39867 .30965 m .39697 .31414 L .40062 .31447 L F
.40044 .31305 m .40056 .31772 L .40421 .31743 L .668 .747 .909 r
F
.40044 .31305 m .40421 .31743 L .40227 .3129 L F
.40198 .31418 m .40084 .31554 L .40214 .31454 L .643 .737 .917 r
F
.40068 .32237 m .4062 .31873 L .40614 .32193 L .66 .409 .529 r
F
.40666 .32491 m .40264 .33372 L .4104 .33347 L .643 .737 .917 r
F
.40138 .32508 m .40068 .32237 L .40614 .32193 L .66 .409 .529 r
F
.39519 .32187 m .40074 .31917 L .40068 .32237 L .731 .468 .53 r
F
.39519 .32187 m .39526 .31867 L .40074 .31917 L F
.39697 .31414 m .39528 .3186 L .40074 .3191 L .668 .746 .909 r
F
.40056 .31772 m .40068 .32237 L .40614 .32193 L .668 .747 .909 r
F
.40639 .32486 m .40614 .32193 L .41121 .32057 L .575 .34 .522 r
F
.40609 .32493 m .40264 .33372 L .40666 .32491 L .643 .737 .917 r
F
.40337 .32501 m .40332 .32552 L .40609 .32493 L F
.40332 .32552 m .40264 .33372 L .40609 .32493 L F
.40986 .32413 m .41121 .32057 L .41116 .32378 L .575 .34 .522 r
F
.40662 .32481 m .40609 .32493 L .40666 .32491 L .643 .737 .917 r
F
.40639 .32486 m .41121 .32057 L .40986 .32413 L .575 .34 .522 r
F
.40609 .32493 m .40614 .32193 L .40639 .32486 L F
.40227 .3129 m .40421 .31743 L .4076 .31651 L .668 .747 .909 r
F
.40169 .3082 m .4005 .30982 L .40232 .30967 L .668 .746 .909 r
F
.40164 .30731 m .40114 .30831 L .40168 .30877 L .644 .737 .916 r
F
.40165 .30811 m .4016 .30819 L .40169 .3082 L .668 .746 .909 r
F
.4016 .30819 m .4005 .30982 L .40169 .3082 L F
.39929 .30607 m .40067 .30634 L .4006 .30804 L .753 .483 .524 r
F
.39929 .30607 m .4006 .30804 L .39926 .30784 L F
.40152 .30308 m .40022 .30638 L .40161 .30625 L .644 .737 .916 r
F
.40157 .30791 m .40047 .30864 L .40165 .30811 L .668 .746 .909 r
F
.40067 .30634 m .40066 .30803 L .4006 .30804 L .631 .379 .518 r
F
.40046 .30806 m .40047 .30864 L .40157 .30791 L .668 .746 .909 r
F
.40047 .30864 m .4005 .30982 L .40165 .30811 L F
.40244 .30618 m .40241 .30778 L .40237 .30779 L .484 .259 .497 r
F
.4029 .30626 m .40285 .30756 L .40321 .30697 L .644 .737 .916 r
F
.40269 .30608 m .40349 .30729 L .40265 .30767 L .484 .259 .497 r
F
.40382 .3074 m .40443 .309 L .40453 .30787 L .668 .746 .909 r
F
.40372 .30757 m .40443 .309 L .40382 .3074 L F
.40304 .30767 m .40344 .30805 L .40356 .30724 L F
.40344 .30805 m .40443 .309 L .40372 .30757 L F
.40344 .30805 m .40372 .30757 L .40356 .30724 L F
.40441 .305 m .40436 .30646 L .40431 .30516 L 0 0 .327 r
F
.40344 .30805 m .40401 .30922 L .40443 .309 L .668 .746 .909 r
F
.40453 .30787 m .40443 .309 L .40545 .30848 L F
.40462 .30678 m .40545 .30848 L .40655 .30752 L F
.40373 .30562 m .40378 .30705 L .40368 .30713 L .286 .104 .449 r
F
.40374 .30586 m .40425 .30665 L .40378 .30705 L F
.40441 .305 m .40475 .30444 L .40469 .30589 L 0 0 .327 r
F
.40426 .30664 m .40453 .30787 L .40462 .30678 L .668 .746 .909 r
F
.40441 .305 m .40469 .30589 L .40446 .30629 L 0 0 .327 r
F
.40469 .30593 m .40655 .30752 L .40723 .3064 L .668 .746 .909 r
F
.40436 .30646 m .40426 .30663 L .40431 .30516 L 0 0 .327 r
F
.40431 .30516 m .40426 .30663 L .40425 .30665 L F
.40441 .305 m .40446 .30629 L .40436 .30646 L F
.40374 .30586 m .40431 .30516 L .40425 .30665 L .286 .104 .449 r
F
.40356 .31374 m .40391 .31566 L .40536 .31492 L .667 .747 .91 r
F
.40342 .31398 m .40391 .31566 L .40356 .31374 L F
.40259 .31419 m .40391 .31566 L .40332 .31361 L F
.40323 .31365 m .40332 .31361 L .40331 .31358 L F
.40259 .31419 m .40332 .31361 L .40323 .31365 L F
.40291 .30755 m .40326 .30837 L .40344 .30805 L .668 .746 .909 r
F
.40269 .30608 m .40265 .30767 L .40244 .30618 L .484 .259 .497 r
F
.40265 .30767 m .40241 .30778 L .40244 .30618 L F
.40038 .30515 m .40264 .30767 L .40291 .30755 L .668 .746 .909 r
F
.40264 .30767 m .40326 .30837 L .40291 .30755 L F
.40265 .30767 m .40257 .31082 L .40241 .30778 L .484 .259 .497 r
F
.4027 .31102 m .40227 .3129 L .40397 .31244 L .668 .747 .909 r
F
.40253 .31084 m .40248 .31121 L .4027 .31102 L F
.40248 .31121 m .40227 .3129 L .4027 .31102 L F
.40349 .30729 m .40341 .31043 L .40336 .31047 L .286 .104 .449 r
F
.40257 .31082 m .40245 .31087 L .40241 .30778 L .484 .259 .497 r
F
.40369 .31057 m .40397 .31244 L .40429 .31228 L .668 .747 .909 r
F
.4044 .31104 m .40429 .31228 L .40542 .31171 L F
.40369 .31057 m .40429 .31228 L .4044 .31104 L F
.40245 .31087 m .40234 .31092 L .40241 .30778 L .484 .259 .497 r
F
.40449 .30996 m .40542 .31171 L .40611 .3111 L .668 .747 .909 r
F
.40449 .30996 m .40611 .3111 L .40578 .31046 L F
.40448 .30997 m .40542 .31171 L .40449 .30996 L F
.40382 .3074 m .40453 .30787 L .40426 .30664 L .668 .746 .909 r
F
.40436 .30646 m .40425 .3096 L .40426 .30663 L 0 0 .327 r
F
.40388 .31023 m .4044 .31104 L .40448 .30997 L .668 .747 .909 r
F
.40265 .30767 m .40349 .30729 L .40336 .31047 L .484 .259 .497 r
F
.40265 .30767 m .40336 .31047 L .40294 .31065 L F
.40336 .31047 m .40397 .31244 L .40346 .31042 L .668 .747 .909 r
F
.40253 .31084 m .4027 .31102 L .40336 .31047 L F
.4027 .31102 m .40397 .31244 L .40336 .31047 L F
.40326 .30837 m .40401 .30922 L .40344 .30805 L .668 .746 .909 r
F
.40352 .30727 m .40343 .31041 L .40349 .30729 L .286 .104 .449 r
F
.40331 .31358 m .40342 .31398 L .40356 .31374 L .667 .747 .91 r
F
.40391 .31566 m .40413 .3159 L .40413 .31584 L F
.40614 .32193 m .4062 .31873 L .41127 .31736 L .575 .34 .522 r
F
.40614 .32193 m .41127 .31736 L .41121 .32057 L F
.40421 .31743 m .41121 .32057 L .4076 .31651 L .668 .747 .909 r
F
.40391 .31566 m .40848 .31926 L .40736 .31703 L .667 .747 .91 r
F
.40421 .31743 m .40614 .32193 L .41121 .32057 L .668 .747 .909 r
F
.40365 .31573 m .40754 .31973 L .40391 .31566 L .667 .747 .91 r
F
.40567 .31846 m .40754 .31973 L .40365 .31573 L F
.40331 .31421 m .40394 .31613 L .40419 .3152 L .643 .737 .917 r
F
.40394 .31613 m .40408 .31652 L .40409 .31633 L F
.40391 .31566 m .40736 .31703 L .40536 .31492 L .667 .747 .91 r
F
.41121 .32057 m .41127 .31736 L .41561 .31517 L .463 .251 .505 r
F
.41121 .32057 m .41561 .31517 L .41556 .31837 L F
.4076 .31651 m .41121 .32057 L .41556 .31837 L .668 .747 .909 r
F
.4076 .31651 m .41556 .31837 L .4105 .31505 L F
.40736 .31703 m .41045 .31826 L .40676 .31584 L .667 .747 .91 r
F
.40736 .31703 m .40676 .31584 L .40536 .31492 L F
.40343 .31041 m .40341 .31043 L .40349 .30729 L .286 .104 .449 r
F
.40257 .31082 m .40323 .31365 L .40249 .31397 L .484 .259 .497 r
F
.40265 .30767 m .40294 .31065 L .40257 .31082 L F
.40294 .31065 m .40323 .31365 L .40257 .31082 L F
.4042 .30969 m .40416 .30976 L .40426 .30663 L 0 0 .327 r
F
.40518 .30924 m .40652 .31074 L .40721 .30961 L .668 .747 .909 r
F
.40425 .3096 m .4042 .30969 L .40426 .30663 L 0 0 .327 r
F
.40425 .30665 m .40415 .30978 L .40412 .30983 L F
.40462 .30678 m .40655 .30752 L .40469 .30593 L .668 .746 .909 r
F
.40486 .30517 m .40723 .3064 L .40744 .30519 L F
.40469 .30583 m .40469 .30586 L .40475 .30444 L 0 0 .006 r
F
.40471 .30567 m .40469 .30583 L .40475 .30444 L F
.40475 .30444 m .40469 .30586 L .40469 .30589 L F
.40543 .28874 m .40424 .30243 L .40469 .30331 L .99 .735 .374 r
F
.40536 .28966 m .40543 .28874 L .40482 .30357 L 0 0 .006 r
F
.40543 .28874 m .40469 .30331 L .40482 .30357 L .99 .735 .374 r
F
.40834 .30344 m .43558 .31071 L .43672 .30493 L .644 .737 .916 r
F
.40152 .30308 m .41674 .30649 L .40834 .30344 L F
.41674 .30649 m .43558 .31071 L .40834 .30344 L F
.40453 .30787 m .40545 .30848 L .40462 .30678 L .668 .746 .909 r
F
.40471 .30567 m .40463 .30816 L .40458 .3088 L 0 0 .006 r
F
.40477 .30425 m .40472 .30547 L .40471 .30567 L F
.40472 .30547 m .40463 .30816 L .40471 .30567 L F
.40481 .30438 m .40744 .30519 L .40718 .30397 L .668 .746 .909 r
F
.40477 .30425 m .40476 .30498 L .40472 .30547 L 0 0 .006 r
F
.40477 .30425 m .40482 .30357 L .40476 .30498 L F
.40477 .30425 m .40471 .30567 L .40475 .30444 L F
.40473 .30491 m .40475 .30495 L .40482 .30357 L .99 .735 .374 r
F
.40469 .30331 m .40462 .3047 L .40482 .30357 L F
.40152 .30308 m .40161 .30625 L .40285 .30614 L .644 .737 .916 r
F
.40038 .30515 m .40475 .30517 L .40476 .30498 L .668 .746 .909 r
F
.40038 .30515 m .40476 .30498 L .40449 .30444 L F
.40373 .30562 m .40368 .30713 L .40356 .30575 L .286 .104 .449 r
F
.40368 .30713 m .40357 .30723 L .40356 .30575 L F
.40358 .31028 m .40343 .31041 L .40356 .30575 L F
.40356 .30575 m .40352 .30727 L .40349 .30729 L F
.40038 .30515 m .40356 .30724 L .40426 .30664 L .668 .746 .909 r
F
.40356 .30724 m .40382 .3074 L .40425 .30665 L F
.40356 .30724 m .40425 .30665 L .40426 .30664 L F
.40368 .30713 m .40358 .31028 L .40357 .30723 L .286 .104 .449 r
F
.40413 .31584 m .40754 .31973 L .40848 .31926 L .667 .747 .91 r
F
.40413 .3159 m .40754 .31973 L .40413 .31584 L F
.41116 .32378 m .41121 .32057 L .41556 .31837 L .463 .251 .505 r
F
.40883 .32273 m .40986 .32413 L .41116 .32378 L .667 .747 .91 r
F
.40497 .31752 m .4104 .33347 L .41591 .33231 L .643 .737 .917 r
F
.40676 .31994 m .41116 .32378 L .40754 .31973 L .667 .747 .91 r
F
.40138 .32508 m .40614 .32193 L .40609 .32493 L .66 .409 .529 r
F
.40056 .31772 m .40614 .32193 L .40421 .31743 L .668 .747 .909 r
F
.40408 .31652 m .4072 .32489 L .40497 .31752 L .643 .737 .917 r
F
.4072 .32489 m .4104 .33347 L .40748 .32488 L F
.4072 .32489 m .40748 .32488 L .40497 .31752 L F
.40254 .31547 m .40136 .33376 L .40264 .33372 L F
.40254 .31547 m .40264 .33372 L .4039 .31859 L F
.40207 .31624 m .40136 .33376 L .40254 .31547 L F
.40062 .3251 m .40068 .32237 L .40138 .32508 L .66 .409 .529 r
F
.40084 .31554 m .40136 .33376 L .40214 .31454 L .643 .737 .917 r
F
.40111 .32517 m .39227 .33252 L .40136 .33376 L F
.39628 .32451 m .40068 .32237 L .40062 .3251 L .731 .468 .53 r
F
.39628 .32451 m .39519 .32187 L .40068 .32237 L F
.3955 .32441 m .39227 .33252 L .39756 .32469 L .643 .737 .917 r
F
.39513 .32436 m .39519 .32187 L .39628 .32451 L .731 .468 .53 r
F
.39689 .31739 m .40068 .32237 L .40056 .31772 L .668 .747 .909 r
F
.39689 .31739 m .39519 .32187 L .40068 .32237 L F
.3986 .31288 m .39689 .31739 L .40056 .31772 L F
.39878 .31618 m .39724 .32004 L .40096 .31966 L .643 .737 .917 r
F
.39724 .32004 m .3955 .32441 L .39759 .32259 L F
.39724 .32004 m .39759 .32259 L .40096 .31966 L F
.3976 .2903 m .39713 .30493 L .39696 .30478 L .929 .648 .486 r
F
.40152 .30308 m .38955 .30695 L .3773 .31768 L .644 .737 .916 r
F
.38955 .30695 m .37155 .31276 L .37564 .31626 L F
.38955 .30695 m .37564 .31626 L .3773 .31768 L F
.39872 .28653 m .39752 .28742 L .39688 .30205 L .339 .143 .462 r
F
.38955 .30695 m .3678 .30716 L .37155 .31276 L .644 .737 .916 r
F
.40152 .30308 m .39397 .304 L .38955 .30695 L F
.39397 .304 m .3678 .30716 L .38955 .30695 L F
.39004 .32045 m .39526 .31867 L .39519 .32187 L .797 .525 .526 r
F
.39548 .32447 m .38997 .32373 L .39227 .33252 L .643 .737 .917 r
F
.39117 .32312 m .38997 .32373 L .39548 .32447 L F
.39136 .32318 m .39004 .32045 L .39519 .32187 L .797 .525 .526 r
F
.38999 .32275 m .39004 .32045 L .39136 .32318 L F
.39004 .32045 m .39011 .31725 L .39526 .31867 L F
.39356 .31319 m .39528 .3186 L .39697 .31414 L .668 .746 .909 r
F
.39356 .31319 m .39016 .31719 L .39528 .3186 L F
.39345 .31644 m .39519 .32187 L .39689 .31739 L .668 .747 .909 r
F
.39345 .31644 m .39004 .32045 L .39519 .32187 L F
.39693 .31777 m .39081 .32301 L .39724 .32004 L .643 .737 .917 r
F
.39081 .32301 m .38997 .32373 L .39117 .32312 L F
.39081 .32301 m .39117 .32312 L .39724 .32004 L F
.39696 .30918 m .39697 .31414 L .39867 .30965 L .668 .746 .909 r
F
.39696 .30918 m .39356 .31319 L .39697 .31414 L F
.39688 .31241 m .39689 .31739 L .3986 .31288 L .668 .747 .909 r
F
.39688 .31241 m .39345 .31644 L .39689 .31739 L F
.39848 .31571 m .39686 .31723 L .39878 .31618 L .643 .737 .917 r
F
.39686 .31723 m .38997 .32373 L .39693 .31777 L F
.39686 .31723 m .39693 .31777 L .39878 .31618 L F
.39136 .32318 m .39519 .32187 L .39513 .32436 L .797 .525 .526 r
F
.39724 .32004 m .39117 .32312 L .39548 .32447 L .643 .737 .917 r
F
.39907 .3148 m .39835 .31551 L .39926 .31496 L F
.39835 .31551 m .38997 .32373 L .39848 .31571 L F
.39835 .31551 m .39848 .31571 L .39926 .31496 L F
.39548 .30843 m .39356 .31319 L .39696 .30918 L .668 .746 .909 r
F
.39539 .31165 m .39345 .31644 L .39688 .31241 L .668 .747 .909 r
F
.39784 .30815 m .39548 .30843 L .39696 .30918 L .668 .746 .909 r
F
.39727 .30723 m .39548 .30843 L .39784 .30815 L F
.398 .30557 m .39795 .30739 L .39775 .30545 L .849 .569 .514 r
F
.39913 .30846 m .39696 .30918 L .39867 .30965 L .668 .746 .909 r
F
.3993 .30799 m .39884 .30823 L .39913 .30846 L F
.39884 .30823 m .39696 .30918 L .39913 .30846 L F
.39713 .30493 m .39775 .30545 L .39767 .30726 L .929 .648 .486 r
F
.3992 .30794 m .39696 .30918 L .3993 .30799 L .668 .746 .909 r
F
.398 .30557 m .39889 .306 L .39881 .30777 L .849 .569 .514 r
F
.39823 .30768 m .39821 .30771 L .39885 .30779 L .668 .746 .909 r
F
.39823 .30768 m .39885 .30779 L .39881 .30777 L F
.39821 .30771 m .39696 .30918 L .39878 .30817 L F
.39821 .30771 m .39878 .30817 L .39936 .30785 L F
.39834 .30756 m .39727 .30723 L .39784 .30815 L F
.3974 .30714 m .39727 .30723 L .39834 .30756 L F
.39878 .31618 m .39693 .31777 L .39724 .32004 L .643 .737 .917 r
F
.3986 .31288 m .40056 .31772 L .40044 .31305 L .668 .747 .909 r
F
.39947 .31439 m .39906 .31479 L .39949 .31439 L .643 .737 .917 r
F
.39906 .31479 m .38997 .32373 L .39907 .3148 L F
.39906 .31479 m .39907 .3148 L .39949 .31439 L F
.398 .30557 m .39881 .30777 L .39795 .30739 L .849 .569 .514 r
F
.39713 .30493 m .39708 .30677 L .39696 .30478 L .929 .648 .486 r
F
.39708 .30677 m .39691 .30663 L .39696 .30478 L F
.39713 .30493 m .39767 .30726 L .39708 .30677 L F
.39795 .30739 m .39771 .30728 L .39775 .30545 L .849 .569 .514 r
F
.39889 .306 m .39888 .30778 L .39881 .30777 L .753 .483 .524 r
F
.39775 .30545 m .39771 .30728 L .39767 .30726 L .849 .569 .514 r
F
.39659 .30419 m .39696 .30478 L .39688 .30661 L .989 .724 .411 r
F
.39659 .30419 m .39688 .30661 L .39659 .30615 L F
.39727 .30723 m .39434 .30745 L .39548 .30843 L .668 .746 .909 r
F
.39682 .30651 m .3965 .30662 L .39727 .30723 L F
.3965 .30662 m .39434 .30745 L .39659 .30728 L F
.3965 .30662 m .39659 .30728 L .39727 .30723 L F
.39752 .28742 m .39636 .30314 L .39676 .30229 L 0 0 .269 r
F
.38251 .30538 m .36633 .30124 L .3678 .30716 L .644 .737 .916 r
F
.40152 .30308 m .39286 .30263 L .38251 .30538 L F
.39286 .30263 m .36633 .30124 L .38251 .30538 L F
.39994 .28615 m .39872 .28653 L .39808 .30124 L .545 .308 .506 r
F
.40038 .30515 m .39682 .30651 L .39688 .30661 L .668 .746 .909 r
F
.39881 .30777 m .39885 .30779 L .39936 .30785 L F
.39936 .30785 m .3992 .30794 L .3993 .30799 L F
.39926 .31496 m .39848 .31571 L .39878 .31618 L .643 .737 .917 r
F
.39949 .31439 m .39907 .3148 L .39926 .31496 L F
.40046 .30802 m .39867 .30965 L .4005 .30982 L .668 .746 .909 r
F
.40038 .30515 m .39936 .30785 L .40046 .30802 L F
.39936 .30785 m .39867 .30965 L .40046 .30802 L F
.39929 .30607 m .39926 .30784 L .39889 .306 L .753 .483 .524 r
F
.40046 .31121 m .40056 .31427 L .40033 .31429 L .631 .379 .518 r
F
.4006 .30804 m .40058 .3112 L .40046 .31121 L F
.40157 .31126 m .40044 .31305 L .40227 .3129 L .668 .747 .909 r
F
.40224 .31097 m .40228 .31406 L .40211 .31413 L .484 .259 .497 r
F
.40237 .30779 m .40233 .31093 L .40224 .31097 L F
.40157 .31126 m .40227 .3129 L .40252 .31093 L .668 .747 .909 r
F
.40224 .31097 m .40252 .31093 L .40253 .31084 L F
.40157 .31126 m .40252 .31093 L .40224 .31097 L F
.40104 .30798 m .40237 .30779 L .40224 .31097 L .631 .379 .518 r
F
.40157 .31106 m .40224 .31097 L .40211 .31413 L F
.40104 .30798 m .40224 .31097 L .40157 .31106 L F
.40233 .31093 m .40228 .31406 L .40224 .31097 L .484 .259 .497 r
F
.40148 .31107 m .40133 .31137 L .40157 .31126 L .668 .747 .909 r
F
.40133 .31137 m .40044 .31305 L .40157 .31126 L F
.40107 .3063 m .40104 .30798 L .40067 .30634 L .631 .379 .518 r
F
.40104 .30798 m .40099 .31114 L .40078 .30801 L F
.40104 .30798 m .40078 .30801 L .40067 .30634 L F
.40162 .30652 m .40131 .30716 L .40164 .30731 L .644 .737 .916 r
F
.40107 .3063 m .40237 .30779 L .40104 .30798 L .631 .379 .518 r
F
.40038 .30515 m .40157 .30791 L .40264 .30767 L .668 .746 .909 r
F
.40157 .30791 m .40165 .30811 L .40237 .30779 L F
.40157 .30791 m .40237 .30779 L .40264 .30767 L F
.40099 .31114 m .40084 .31116 L .40067 .30634 L .631 .379 .518 r
F
.40039 .31122 m .40044 .31305 L .40134 .31135 L .668 .747 .909 r
F
.40046 .31121 m .40134 .31135 L .40148 .31107 L F
.40039 .31122 m .40134 .31135 L .40046 .31121 L F
.39926 .30784 m .4006 .30804 L .40046 .31121 L .753 .483 .524 r
F
.40039 .31122 m .3986 .31288 L .40044 .31305 L .668 .747 .909 r
F
.40039 .3112 m .40037 .31123 L .40039 .31122 L F
.40037 .31123 m .3986 .31288 L .40039 .31122 L F
.3993 .31104 m .3986 .31288 L .40039 .3112 L F
.39959 .31414 m .39916 .31424 L .3995 .31436 L .643 .737 .917 r
F
.39916 .31424 m .39792 .3145 L .39943 .31437 L F
.39916 .31424 m .39943 .31437 L .3995 .31436 L F
.39708 .30677 m .39697 .30998 L .39691 .30663 L .929 .648 .486 r
F
.39795 .30739 m .39881 .30777 L .39868 .31095 L .849 .569 .514 r
F
.39795 .30739 m .39868 .31095 L .39826 .31076 L F
.39696 .30478 m .39691 .30663 L .39688 .30661 L .929 .648 .486 r
F
.39659 .30419 m .39659 .30615 L .39652 .30603 L .989 .724 .411 r
F
.3965 .30662 m .3936 .30632 L .39434 .30745 L .668 .746 .909 r
F
.39659 .30419 m .39652 .30603 L .39648 .30402 L .989 .724 .411 r
F
.39636 .30314 m .39629 .30497 L .39628 .30493 L .875 .7 .179 r
F
.3964 .30584 m .39583 .30594 L .3965 .30662 L .668 .746 .909 r
F
.39583 .30594 m .39556 .30653 L .3965 .30662 L F
.3964 .30583 m .3936 .30632 L .3964 .30584 L F
.39656 .31129 m .39539 .31165 L .3967 .31231 L .668 .747 .909 r
F
.39651 .3109 m .39539 .31165 L .39656 .31129 L F
.39651 .3109 m .39513 .31033 L .39539 .31165 L F
.39716 .31047 m .39645 .31042 L .39651 .3109 L F
.39645 .31042 m .39513 .31033 L .39651 .3109 L F
.3964 .30583 m .39332 .30511 L .3936 .30632 L .668 .746 .909 r
F
.39631 .30512 m .39332 .30511 L .3964 .30583 L F
.39631 .30516 m .39623 .30875 L .39618 .30838 L .875 .7 .179 r
F
.39639 .30333 m .39633 .3053 L .39631 .30516 L F
.39633 .3053 m .39623 .30875 L .39631 .30516 L F
.39631 .30512 m .39353 .30389 L .39332 .30511 L .668 .746 .909 r
F
.39639 .30333 m .39631 .30516 L .39636 .30314 L .875 .7 .179 r
F
.39631 .30516 m .39629 .30503 L .39636 .30314 L F
.39621 .30438 m .39353 .30389 L .39631 .30512 L .668 .746 .909 r
F
.39618 .30838 m .39617 .3083 L .39629 .305 L .875 .7 .179 r
F
.39629 .30503 m .39629 .305 L .39636 .30314 L F
.39618 .30838 m .39629 .305 L .39629 .30503 L F
.39621 .30438 m .3942 .30276 L .39353 .30389 L .668 .746 .909 r
F
.39872 .28653 m .39688 .30205 L .39781 .30142 L .339 .143 .462 r
F
.39752 .28742 m .39676 .30229 L .39688 .30205 L 0 0 .269 r
F
.40152 .30308 m .3959 .30182 L .39286 .30263 L .644 .737 .916 r
F
.39676 .30229 m .39636 .30314 L .39628 .30493 L 0 0 .269 r
F
.39639 .30333 m .39648 .30402 L .3964 .30584 L .875 .7 .179 r
F
.39651 .30444 m .39612 .3035 L .39621 .30438 L .668 .746 .909 r
F
.40038 .30515 m .39682 .30377 L .39651 .30444 L F
.39676 .30229 m .39628 .30493 L .39667 .30407 L 0 0 .269 r
F
.39644 .3059 m .39642 .30587 L .39648 .30402 L .989 .724 .411 r
F
.39652 .30603 m .39644 .3059 L .39648 .30402 L F
.39639 .30333 m .3964 .30584 L .39633 .3053 L .875 .7 .179 r
F
.39652 .30603 m .39657 .30951 L .3964 .30924 L .989 .724 .411 r
F
.39691 .30663 m .39682 .30985 L .39688 .30661 L .929 .648 .486 r
F
.39682 .30985 m .3968 .30984 L .39688 .30661 L F
.39688 .30661 m .3968 .30984 L .39674 .30978 L F
.39548 .30843 m .3906 .31169 L .39356 .31319 L .668 .746 .909 r
F
.39434 .30745 m .3906 .31169 L .39548 .30843 L F
.39637 .30986 m .39349 .30954 L .39423 .31067 L .668 .747 .909 r
F
.39671 .30973 m .39635 .30971 L .39637 .30986 L F
.39635 .30971 m .39349 .30954 L .39637 .30986 L F
.39629 .30497 m .39615 .3082 L .39628 .30493 L .875 .7 .179 r
F
.39628 .30905 m .39627 .30906 L .39671 .30973 L .668 .747 .909 r
F
.39627 .30906 m .39349 .30954 L .39635 .30971 L F
.39627 .30906 m .39635 .30971 L .39671 .30973 L F
.39637 .30986 m .39513 .31033 L .39645 .31042 L F
.39648 .30402 m .39631 .30909 L .39626 .30902 L .989 .724 .411 r
F
.39434 .30745 m .3883 .30975 L .3906 .31169 L .668 .746 .909 r
F
.39566 .30916 m .39322 .30832 L .39349 .30954 L .668 .747 .909 r
F
.39631 .30516 m .39618 .30838 L .39629 .30503 L .875 .7 .179 r
F
.39635 .30916 m .39631 .30909 L .39642 .30587 L .989 .724 .411 r
F
.39636 .30918 m .39642 .30587 L .39644 .3059 L F
.39629 .31223 m .39635 .30916 L .39636 .30918 L F
.39635 .30916 m .39642 .30587 L .39636 .30918 L F
.39652 .30603 m .3964 .30924 L .39644 .3059 L F
.3964 .30924 m .39629 .31223 L .39636 .30918 L F
.3964 .30924 m .39636 .30918 L .39644 .3059 L F
.3936 .30632 m .3883 .30975 L .39434 .30745 L .668 .746 .909 r
F
.39583 .30833 m .39342 .3071 L .39322 .30832 L .668 .747 .909 r
F
.39617 .3083 m .39615 .3082 L .39629 .30497 L .875 .7 .179 r
F
.39629 .305 m .39629 .30497 L .39636 .30314 L F
.39617 .3083 m .39629 .30497 L .39629 .305 L F
.3959 .30182 m .37487 .29712 L .39286 .30263 L .644 .737 .916 r
F
.39609 .30349 m .3953 .3018 L .3942 .30276 L .668 .746 .909 r
F
.39688 .30205 m .39679 .30381 L .3968 .30378 L 0 0 .269 r
F
.37487 .29712 m .37053 .29007 L .36725 .29541 L .644 .737 .916 r
F
.40116 .28605 m .39994 .28615 L .3993 .30092 L .652 .396 .519 r
F
.40152 .30308 m .39665 .30104 L .39308 .30119 L .644 .737 .916 r
F
.40038 .30515 m .39752 .30326 L .39682 .30377 L .668 .746 .909 r
F
.40038 .30515 m .39651 .30444 L .39631 .30512 L F
.40038 .30515 m .39631 .30512 L .3964 .30583 L F
.40038 .30515 m .3964 .30583 L .3964 .30584 L F
.40038 .30515 m .3964 .30584 L .39682 .30651 L F
.39994 .28615 m .39808 .30124 L .39902 .30099 L .545 .308 .506 r
F
.39872 .28653 m .39781 .30142 L .39808 .30124 L .339 .143 .462 r
F
.39665 .30104 m .37596 .28559 L .37053 .29007 L .644 .737 .916 r
F
.40152 .30308 m .39842 .30096 L .39665 .30104 L F
.39842 .30096 m .37596 .28559 L .39665 .30104 L F
.39615 .3082 m .39615 .30818 L .39628 .30493 L .875 .7 .179 r
F
.39628 .30493 m .39615 .30818 L .39614 .30811 L F
.39604 .30833 m .39587 .30754 L .39583 .30833 L .668 .747 .909 r
F
.3964 .30583 m .3964 .30583 L .3964 .30584 L .668 .746 .909 r
F
.39633 .3053 m .3964 .30584 L .39626 .30902 L .875 .7 .179 r
F
.39633 .3053 m .39626 .30902 L .39623 .30875 L F
.39795 .30739 m .39826 .31076 L .39787 .31058 L .849 .569 .514 r
F
.39697 .30998 m .39689 .30991 L .39691 .30663 L .929 .648 .486 r
F
.39926 .30784 m .40046 .31121 L .39921 .31102 L .753 .483 .524 r
F
.39926 .30784 m .39921 .31102 L .39895 .30779 L F
.39921 .31102 m .39906 .311 L .39895 .30779 L F
.39906 .31169 m .39688 .31241 L .3986 .31288 L .668 .747 .909 r
F
.39924 .3112 m .39876 .31144 L .39906 .31169 L F
.39876 .31144 m .39688 .31241 L .39906 .31169 L F
.39868 .31095 m .39813 .31093 L .39924 .3112 L F
.39813 .31093 m .39688 .31241 L .39876 .31144 L F
.39813 .31093 m .39876 .31144 L .39924 .3112 L F
.39845 .31393 m .39792 .3145 L .39959 .31414 L .643 .737 .917 r
F
.39792 .3145 m .39058 .32245 L .39906 .31479 L F
.39058 .32245 m .38997 .32373 L .39906 .31479 L F
.3964 .30924 m .39661 .31273 L .39629 .31223 L .989 .724 .411 r
F
.39637 .30986 m .39645 .31042 L .39716 .31047 L .668 .747 .909 r
F
.39868 .31095 m .39866 .31397 L .39855 .31395 L .753 .483 .524 r
F
.39864 .31444 m .39906 .31479 L .3995 .31436 L .643 .737 .917 r
F
.39792 .3145 m .39906 .31479 L .39864 .31444 L F
.3955 .32441 m .39756 .32469 L .40096 .31966 L F
.40096 .31966 m .39756 .32469 L .40111 .32517 L F
.39756 .32469 m .39227 .33252 L .40111 .32517 L F
.39512 .32508 m .39628 .32451 L .40061 .32558 L .731 .468 .53 r
F
.39628 .32451 m .40062 .3251 L .40061 .32558 L F
.39879 .31096 m .39877 .31399 L .39868 .31095 L .753 .483 .524 r
F
.39016 .32284 m .37632 .32594 L .38373 .32986 L .643 .737 .917 r
F
.38963 .32256 m .37632 .32594 L .39016 .32284 L F
.38691 .32112 m .39004 .32045 L .38999 .32275 L .864 .585 .513 r
F
.38558 .31821 m .39011 .31725 L .39004 .32045 L F
.38691 .32112 m .38558 .31821 L .39004 .32045 L F
.38552 .32038 m .38558 .31821 L .38691 .32112 L F
.3906 .31169 m .39016 .31719 L .39356 .31319 L .668 .746 .909 r
F
.39048 .31494 m .39004 .32045 L .39345 .31644 L .668 .747 .909 r
F
.38558 .31821 m .38566 .315 L .39011 .31725 L .864 .585 .513 r
F
.3906 .31169 m .38573 .31495 L .39016 .31719 L .668 .746 .909 r
F
.39048 .31494 m .38558 .31821 L .39004 .32045 L .668 .747 .909 r
F
.39337 .31662 m .38601 .32064 L .39065 .3223 L .643 .737 .917 r
F
.3859 .3207 m .37632 .32594 L .38843 .32286 L F
.39539 .31165 m .39048 .31494 L .39345 .31644 L .668 .747 .909 r
F
.39685 .31362 m .37632 .32594 L .39834 .31391 L .643 .737 .917 r
F
.38322 .3184 m .38558 .31821 L .38552 .32038 L .932 .65 .484 r
F
.39877 .31399 m .39866 .31397 L .39868 .31095 L .753 .483 .524 r
F
.39734 .31035 m .39716 .31047 L .39796 .31079 L .668 .747 .909 r
F
.39716 .31047 m .39651 .3109 L .39739 .31083 L F
.39716 .31047 m .39739 .31083 L .39796 .31079 L F
.39651 .3109 m .39656 .31129 L .3975 .311 L F
.39739 .31083 m .3975 .311 L .39827 .31076 L F
.39651 .3109 m .3975 .311 L .39739 .31083 L F
.39682 .30651 m .3964 .30584 L .3965 .30662 L .668 .746 .909 r
F
.39659 .30615 m .3966 .30956 L .39652 .30603 L .989 .724 .411 r
F
.39669 .30974 m .39637 .30986 L .39674 .30978 L .668 .747 .909 r
F
.3966 .30956 m .39661 .31273 L .39657 .30951 L .989 .724 .411 r
F
.3966 .30956 m .39657 .30951 L .39652 .30603 L F
.39659 .30615 m .39688 .30661 L .39674 .30978 L F
.39671 .30973 m .39669 .30974 L .39674 .30978 L .668 .747 .909 r
F
.3966 .30956 m .39674 .30978 L .39661 .31273 L .989 .724 .411 r
F
.39659 .30615 m .39674 .30978 L .3966 .30956 L F
.39774 .31139 m .39656 .31129 L .39688 .31241 L .668 .747 .909 r
F
.39813 .31093 m .39754 .31107 L .39774 .31139 L F
.39754 .31107 m .39656 .31129 L .39774 .31139 L F
.39827 .31076 m .39803 .31084 L .39813 .31093 L F
.39803 .31084 m .39656 .31129 L .39813 .31093 L F
.39688 .31296 m .39673 .31284 L .39682 .30985 L .929 .648 .486 r
F
.39689 .30991 m .39682 .30985 L .39691 .30663 L F
.39688 .31296 m .39682 .30985 L .39689 .30991 L F
.39697 .30998 m .39753 .31043 L .3974 .3134 L F
.39697 .30998 m .3974 .3134 L .39688 .31296 L F
.39916 .31406 m .39882 .314 L .39885 .31097 L .753 .483 .524 r
F
.39916 .31406 m .39885 .31097 L .39906 .311 L F
.39657 .30951 m .39661 .31273 L .3964 .30924 L .989 .724 .411 r
F
.39682 .30985 m .39673 .31284 L .3968 .30984 L .929 .648 .486 r
F
.39656 .31129 m .3967 .31231 L .39688 .31241 L .668 .747 .909 r
F
.39674 .30978 m .39673 .31284 L .39661 .31273 L .929 .648 .486 r
F
.39674 .30978 m .39637 .30986 L .39716 .31047 L .668 .747 .909 r
F
.3968 .30984 m .39673 .31284 L .39674 .30978 L .929 .648 .486 r
F
.39881 .30777 m .39879 .31096 L .39868 .31095 L .753 .483 .524 r
F
.39747 .3071 m .39688 .30661 L .39727 .30723 L .668 .746 .909 r
F
.39708 .30677 m .39767 .30726 L .39753 .31043 L .929 .648 .486 r
F
.39708 .30677 m .39753 .31043 L .39697 .30998 L F
.39906 .311 m .39885 .31097 L .39889 .306 L .753 .483 .524 r
F
.39753 .31043 m .39796 .31079 L .39827 .31076 L .668 .747 .909 r
F
.39734 .31035 m .39796 .31079 L .39753 .31043 L F
.39795 .30739 m .39787 .31058 L .39771 .30728 L .849 .569 .514 r
F
.39787 .31058 m .39775 .31053 L .39771 .30728 L F
.39779 .31358 m .39758 .31348 L .39771 .30728 L F
.40013 .32686 m .39145 .34074 L .40056 .34197 L .643 .738 .918 r
F
.39512 .32508 m .39513 .32436 L .39628 .32451 L .731 .468 .53 r
F
.39682 .3206 m .39512 .32508 L .40061 .32558 L .667 .747 .91 r
F
.39883 .3248 m .397 .32876 L .40013 .32686 L .643 .738 .918 r
F
.397 .32876 m .39145 .34074 L .39735 .3313 L F
.397 .32876 m .39735 .3313 L .40013 .32686 L F
.3973 .31335 m .39504 .31313 L .39398 .31535 L .643 .737 .917 r
F
.39611 .31278 m .39504 .31313 L .3973 .31335 L F
.39834 .31391 m .39337 .31662 L .39065 .3223 L F
.39834 .31391 m .38373 .32986 L .39845 .31393 L F
.3993 .31104 m .39868 .31095 L .39924 .3112 L .668 .747 .909 r
F
.39888 .30778 m .39882 .314 L .39881 .30777 L .753 .483 .524 r
F
.39682 .3206 m .40061 .32558 L .40049 .32094 L .667 .747 .91 r
F
.39999 .32228 m .39883 .3248 L .40013 .32686 L .643 .738 .918 r
F
.39999 .32228 m .40024 .35836 L .39844 .35859 L .631 .379 .518 r
F
.40081 .31438 m .39878 .31618 L .40096 .31966 L .643 .737 .917 r
F
.39921 .31102 m .40046 .31121 L .40033 .31429 L .753 .483 .524 r
F
.39921 .31102 m .40033 .31429 L .39916 .31406 L F
.40084 .31116 m .40063 .31119 L .40067 .30634 L .631 .379 .518 r
F
.40081 .31424 m .40033 .31429 L .40081 .31438 L .643 .737 .917 r
F
.40066 .30803 m .40061 .31426 L .4006 .30804 L .631 .379 .518 r
F
.40033 .31429 m .39878 .31618 L .40081 .31438 L .643 .737 .917 r
F
.40061 .32558 m .40138 .32508 L .40608 .32514 L .66 .409 .529 r
F
.40138 .32508 m .40609 .32493 L .40608 .32514 L F
.40408 .31652 m .40497 .31752 L .40409 .31633 L .643 .737 .917 r
F
.40452 .30912 m .40413 .30982 L .40455 .30913 L .668 .747 .909 r
F
.40426 .30663 m .40416 .30976 L .40425 .30665 L 0 0 .327 r
F
.40416 .30976 m .40415 .30977 L .40425 .30665 L F
.40413 .30982 m .40388 .31023 L .40449 .30996 L .668 .747 .909 r
F
.40412 .30982 m .40412 .30983 L .40413 .30982 L F
.40412 .30983 m .40388 .31023 L .40413 .30982 L F
.40378 .30705 m .40425 .30665 L .40412 .30983 L .286 .104 .449 r
F
.40369 .31057 m .4044 .31104 L .40388 .31023 L .668 .747 .909 r
F
.40399 .31301 m .40536 .31492 L .40601 .31435 L .667 .747 .91 r
F
.40399 .31301 m .40601 .31435 L .40566 .31365 L F
.40331 .31358 m .40536 .31492 L .40399 .31301 L F
.40311 .31499 m .4104 .33347 L .40391 .31608 L .643 .737 .917 r
F
.40196 .31414 m .40214 .31454 L .40254 .31423 L F
.40196 .31414 m .40254 .31423 L .40244 .3141 L F
.40259 .31419 m .40365 .31573 L .40391 .31566 L .667 .747 .91 r
F
.40212 .31366 m .40254 .31423 L .40259 .31419 L F
.40254 .31423 m .40365 .31573 L .40259 .31419 L F
.40343 .31041 m .40335 .31355 L .40341 .31043 L .286 .104 .449 r
F
.40214 .31454 m .4104 .33347 L .40274 .31407 L .643 .737 .917 r
F
.40335 .31355 m .40334 .31361 L .40333 .31356 L .286 .104 .449 r
F
.40061 .31426 m .40056 .31427 L .4006 .30804 L .631 .379 .518 r
F
.40094 .31423 m .40061 .31426 L .40063 .31119 L F
.40094 .31423 m .40063 .31119 L .40084 .31116 L F
.40058 .3112 m .40056 .31427 L .40046 .31121 L F
.40067 .3117 m .39959 .31414 L .40033 .31429 L .643 .737 .917 r
F
.40335 .31355 m .40333 .31356 L .40341 .31043 L .286 .104 .449 r
F
.4044 .31104 m .40542 .31171 L .40448 .30997 L .668 .747 .909 r
F
.40378 .30705 m .40412 .30983 L .40388 .31003 L .286 .104 .449 r
F
.40415 .30977 m .40415 .30978 L .40425 .30665 L 0 0 .327 r
F
.40471 .30567 m .40458 .3088 L .40469 .30583 L 0 0 .006 r
F
.40458 .3088 m .40457 .30888 L .40469 .30583 L F
.40457 .30888 m .40469 .30586 L .40469 .30583 L F
.40457 .3089 m .40469 .30586 L .40457 .30888 L F
.40457 .3089 m .40456 .30898 L .40469 .30586 L F
.40426 .30664 m .40462 .30678 L .40465 .30631 L .668 .746 .909 r
F
.40426 .30664 m .40465 .30631 L .40469 .30593 L F
.40446 .30629 m .40469 .30589 L .40456 .30906 L 0 0 .327 r
F
.40358 .31028 m .40398 .31311 L .40349 .3135 L .286 .104 .449 r
F
.40368 .30713 m .40383 .31007 L .40358 .31028 L F
.40373 .31015 m .40346 .31042 L .40388 .31023 L .668 .747 .909 r
F
.40356 .30724 m .40372 .30757 L .40382 .3074 L .668 .746 .909 r
F
.40378 .30705 m .40388 .31003 L .40368 .30713 L .286 .104 .449 r
F
.40388 .31003 m .40383 .31007 L .40368 .30713 L F
.40241 .30778 m .40228 .31406 L .40237 .30779 L .484 .259 .497 r
F
.40148 .31107 m .40157 .31126 L .40224 .31097 L .668 .747 .909 r
F
.40104 .30798 m .40211 .31413 L .40094 .31423 L .631 .379 .518 r
F
.40032 .30836 m .40373 .31015 L .40412 .30982 L .668 .747 .909 r
F
.40373 .31015 m .40388 .31023 L .40412 .30983 L F
.40373 .31015 m .40412 .30983 L .40412 .30982 L F
.40388 .31003 m .40398 .31311 L .40383 .31007 L .286 .104 .449 r
F
.40346 .31042 m .40369 .31057 L .40388 .31023 L .668 .747 .909 r
F
.40356 .3108 m .40397 .31244 L .40369 .31057 L F
.40383 .31007 m .40398 .31311 L .40358 .31028 L .286 .104 .449 r
F
.40032 .30836 m .40344 .3104 L .40373 .31015 L .668 .747 .909 r
F
.40344 .3104 m .40346 .31042 L .40373 .31015 L F
.40436 .30646 m .40456 .30906 L .40425 .3096 L 0 0 .327 r
F
.40446 .30629 m .40456 .30906 L .40436 .30646 L F
.40762 .31327 m .41553 .31512 L .4105 .31181 L .668 .746 .909 r
F
.40429 .31228 m .4105 .31505 L .40542 .31171 L .668 .747 .909 r
F
.40427 .31257 m .4105 .31505 L .40429 .31228 L F
.4105 .31181 m .41553 .31512 L .41883 .31225 L .668 .746 .909 r
F
.40542 .31171 m .4105 .31505 L .41271 .31312 L .668 .747 .909 r
F
.40542 .31171 m .41271 .31312 L .40652 .31074 L F
.40448 .3116 m .40715 .31283 L .40737 .31161 L .667 .747 .91 r
F
.40405 .31289 m .40404 .31291 L .40415 .30978 L 0 0 .327 r
F
.40405 .313 m .40415 .30978 L .40415 .30977 L F
.4006 .3116 m .39959 .31414 L .40067 .3117 L .643 .737 .917 r
F
.40388 .31003 m .40412 .30983 L .40399 .31301 L .286 .104 .449 r
F
.40388 .31003 m .40399 .31301 L .40398 .31301 L F
.40416 .30976 m .40405 .313 L .40415 .30977 L 0 0 .327 r
F
.40338 .31358 m .40334 .31361 L .40343 .31041 L .286 .104 .449 r
F
.40346 .31042 m .40356 .3108 L .40369 .31057 L .668 .747 .909 r
F
.40358 .31028 m .40349 .31343 L .40343 .31041 L .286 .104 .449 r
F
.40349 .31343 m .40338 .31352 L .40343 .31041 L F
.40074 .31179 m .40033 .31429 L .40081 .31424 L .643 .737 .917 r
F
.40099 .31114 m .40094 .31423 L .40084 .31116 L .631 .379 .518 r
F
.40413 .31287 m .40405 .313 L .40416 .30976 L 0 0 .327 r
F
.40413 .31287 m .40416 .30976 L .4042 .30969 L F
.40425 .3096 m .40413 .31287 L .4042 .30969 L F
.40294 .31065 m .40336 .31047 L .40323 .31365 L .484 .259 .497 r
F
.40412 .30983 m .40404 .31291 L .40399 .31301 L 0 0 .327 r
F
.40415 .30978 m .40404 .31291 L .40412 .30983 L F
.40249 .31397 m .40239 .31402 L .40234 .31092 L .484 .259 .497 r
F
.40243 .314 m .40259 .31419 L .40323 .31365 L .667 .747 .91 r
F
.40294 .31381 m .40211 .31413 L .40315 .31404 L .643 .737 .917 r
F
.40239 .31402 m .40228 .31407 L .40228 .31406 L .484 .259 .497 r
F
.40239 .31402 m .40228 .31406 L .40234 .31092 L F
.40249 .31397 m .40234 .31092 L .40245 .31087 L F
.40336 .31047 m .40333 .31356 L .40323 .31365 L .286 .104 .449 r
F
.40341 .31043 m .40333 .31356 L .40336 .31047 L F
.40257 .31082 m .40249 .31397 L .40245 .31087 L .484 .259 .497 r
F
.40469 .30586 m .40456 .30898 L .40469 .30589 L 0 0 .006 r
F
.40456 .30898 m .40443 .31226 L .40456 .30899 L F
.40456 .30898 m .40456 .30899 L .40469 .30589 L F
.40461 .30838 m .40484 .30857 L .40474 .30838 L .668 .747 .909 r
F
.40032 .30836 m .4046 .30856 L .40461 .30838 L F
.4046 .30856 m .40484 .30857 L .40461 .30838 L F
.40412 .30982 m .40413 .30982 L .40452 .30912 L F
.40413 .30982 m .40448 .30996 L .40452 .30948 L F
.40413 .30982 m .40452 .30948 L .40455 .30913 L F
.40425 .3096 m .40456 .30906 L .40443 .31224 L 0 0 .327 r
F
.40438 .31232 m .40442 .31233 L .40443 .31224 L .667 .747 .91 r
F
.40441 .31227 m .40443 .31224 L .40442 .3124 L 0 0 .327 r
F
.40425 .3096 m .40443 .31224 L .40441 .31227 L F
.40399 .31301 m .40647 .31396 L .40438 .31233 L .667 .747 .91 r
F
.40414 .31275 m .40442 .3124 L .40413 .31287 L 0 0 .327 r
F
.40397 .31244 m .40427 .31257 L .40429 .31228 L .668 .747 .909 r
F
.40425 .3096 m .40441 .31227 L .40414 .31275 L 0 0 .327 r
F
.40438 .31233 m .40442 .31233 L .40438 .31232 L .667 .747 .91 r
F
.40441 .31227 m .40442 .3124 L .40414 .31275 L 0 0 .327 r
F
.40063 .31164 m .40438 .31233 L .40058 .31158 L .667 .747 .91 r
F
.40438 .31233 m .40438 .31232 L .40058 .31158 L F
.40058 .31158 m .40438 .31232 L .40448 .3116 L F
.40438 .31232 m .40443 .31224 L .40448 .3116 L F
.4014 .31268 m .40196 .31414 L .40211 .31413 L .643 .737 .917 r
F
.40063 .31164 m .40399 .31301 L .40438 .31233 L .667 .747 .91 r
F
.39882 .314 m .39877 .31399 L .39881 .30777 L .753 .483 .524 r
F
.39787 .31058 m .39855 .31395 L .39779 .31358 L .849 .569 .514 r
F
.39826 .31076 m .39855 .31395 L .39787 .31058 L F
.39827 .31076 m .39818 .31087 L .39868 .31095 L .668 .747 .909 r
F
.39818 .31087 m .39813 .31093 L .39868 .31095 L F
.39826 .31076 m .39868 .31095 L .39855 .31395 L .849 .569 .514 r
F
.39921 .31102 m .39916 .31406 L .39906 .311 L .753 .483 .524 r
F
.40053 .31151 m .39834 .31391 L .4006 .3116 L .643 .737 .917 r
F
.40026 .31158 m .40071 .31175 L .40063 .31164 L .667 .747 .91 r
F
.40071 .31175 m .40399 .31301 L .40063 .31164 L F
.40456 .30906 m .40444 .31211 L .40443 .31224 L 0 0 .006 r
F
.40456 .30899 m .40443 .31226 L .40456 .30906 L F
.40032 .30836 m .40456 .30906 L .4046 .30856 L .668 .747 .909 r
F
.40452 .30912 m .40721 .30961 L .40495 .30838 L F
.40469 .30589 m .40456 .30899 L .40456 .30906 L 0 0 .006 r
F
.40456 .30591 m .40469 .30593 L .4046 .30517 L .668 .746 .909 r
F
.40038 .30515 m .40426 .30664 L .40469 .30593 L F
.40462 .3047 m .40446 .30782 L .40471 .30488 L .99 .735 .374 r
F
.40472 .30547 m .40476 .30498 L .40463 .30816 L 0 0 .006 r
F
.40451 .30792 m .40458 .30805 L .40475 .30495 L .99 .735 .374 r
F
.40451 .30792 m .40475 .30495 L .40473 .30491 L F
.4046 .30517 m .40469 .30593 L .40475 .30517 L .668 .746 .909 r
F
.40446 .30782 m .40451 .30792 L .40473 .30491 L .99 .735 .374 r
F
.40471 .30488 m .40473 .30491 L .40482 .30357 L F
.40446 .30782 m .40473 .30491 L .40471 .30488 L F
.40038 .30515 m .40449 .30444 L .40418 .30383 L .668 .746 .909 r
F
.40038 .30515 m .40418 .30383 L .40407 .30374 L F
.40486 .28756 m .40299 .3015 L .40396 .30222 L .912 .629 .494 r
F
.40486 .28756 m .40396 .30222 L .40424 .30243 L F
.40372 .30176 m .43189 .29328 L .42619 .28822 L .644 .737 .916 r
F
.40152 .30308 m .40461 .30209 L .40372 .30176 L F
.40461 .30209 m .43189 .29328 L .40372 .30176 L F
.40362 .28662 m .40238 .2862 L .40175 .30105 L .814 .537 .519 r
F
.40655 .30752 m .4127 .30989 L .41407 .30764 L .668 .746 .909 r
F
.40545 .30848 m .4127 .30989 L .40655 .30752 L F
.40515 .30779 m .40742 .3084 L .40724 .30755 L .668 .747 .909 r
F
.40482 .30357 m .40458 .30805 L .40463 .30816 L .99 .735 .374 r
F
.40032 .30836 m .40474 .30838 L .40449 .30787 L .668 .747 .909 r
F
.40038 .30515 m .40456 .30591 L .4046 .30517 L .668 .746 .909 r
F
.40462 .3047 m .40424 .30737 L .40446 .30782 L .99 .735 .374 r
F
.40469 .30331 m .40455 .30456 L .40462 .3047 L F
.40455 .30456 m .40424 .30737 L .40462 .3047 L F
.40152 .30308 m .43547 .29898 L .43189 .29328 L .644 .737 .916 r
F
.40152 .30308 m .43672 .30493 L .43547 .29898 L F
.40396 .30222 m .40387 .3036 L .40424 .30243 L .912 .629 .494 r
F
.40387 .3036 m .40415 .3038 L .40424 .30243 L F
.40469 .30331 m .40424 .30243 L .40418 .30383 L .99 .735 .374 r
F
.40449 .30445 m .40418 .30383 L .40405 .307 L F
.40469 .30331 m .40418 .30383 L .40449 .30445 L F
.40485 .30757 m .40724 .30755 L .40646 .3073 L .668 .747 .909 r
F
.40032 .30836 m .40515 .30779 L .40485 .30757 L F
.40515 .30779 m .40724 .30755 L .40485 .30757 L F
.40578 .31046 m .40652 .31074 L .40518 .30924 L F
.40578 .31046 m .40611 .3111 L .40652 .31074 L F
.4105 .31181 m .41883 .31225 L .4127 .30989 L .668 .746 .909 r
F
.40545 .30848 m .4105 .31181 L .4127 .30989 L F
.40652 .31074 m .41271 .31312 L .41409 .31087 L .668 .747 .909 r
F
.40652 .31074 m .41409 .31087 L .40721 .30961 L F
.40477 .3108 m .40737 .31161 L .4071 .3104 L .667 .747 .91 r
F
.40032 .30836 m .40452 .30912 L .40456 .30906 L .668 .747 .909 r
F
.40032 .30836 m .40412 .30982 L .40452 .30912 L F
.40446 .30782 m .40392 .31018 L .4043 .31094 L .99 .735 .374 r
F
.40458 .30805 m .40441 .31116 L .40463 .30816 L F
.40448 .30996 m .40578 .31046 L .40455 .30913 L .668 .747 .909 r
F
.40458 .3088 m .40445 .31193 L .40457 .30888 L 0 0 .006 r
F
.40445 .31193 m .40457 .3089 L .40457 .30888 L F
.40445 .31193 m .40456 .30898 L .40457 .3089 L F
.40441 .31116 m .40446 .31126 L .40463 .30816 L .99 .735 .374 r
F
.40445 .31193 m .40444 .31211 L .40456 .30898 L 0 0 .006 r
F
.40454 .31084 m .40588 .3116 L .40477 .3108 L .667 .747 .91 r
F
.40427 .31088 m .40453 .311 L .40454 .31084 L F
.40453 .311 m .40588 .3116 L .40454 .31084 L F
.40458 .3088 m .4045 .31138 L .40445 .31193 L 0 0 .006 r
F
.40058 .31158 m .4059 .31161 L .40054 .31153 L .667 .747 .91 r
F
.4059 .31161 m .40737 .31161 L .40588 .3116 L F
.4059 .31161 m .40588 .3116 L .40054 .31153 L F
.40418 .30383 m .40394 .30692 L .40405 .307 L .912 .629 .494 r
F
.40424 .30243 m .40415 .3038 L .40418 .30383 L F
.40415 .3038 m .40394 .30692 L .40418 .30383 L F
.40362 .28662 m .40175 .30105 L .40271 .30139 L .814 .537 .519 r
F
.40116 .28605 m .40025 .30088 L .40052 .30087 L .652 .396 .519 r
F
.40116 .28605 m .3993 .30092 L .40025 .30088 L F
.40238 .2862 m .40116 .28605 L .40052 .30087 L .735 .467 .523 r
F
.40238 .2862 m .40052 .30087 L .40148 .30101 L F
.40238 .2862 m .40148 .30101 L .40175 .30105 L F
.40362 .28662 m .40271 .30139 L .40299 .3015 L .814 .537 .519 r
F
.40152 .30308 m .41013 .28139 L .40089 .28012 L .644 .737 .916 r
F
.40152 .30308 m .41877 .28416 L .41013 .28139 L F
.40271 .30139 m .40175 .30105 L .40169 .30252 L .814 .537 .519 r
F
.40038 .30515 m .4033 .30319 L .40293 .30292 L .668 .746 .909 r
F
.40038 .30515 m .40293 .30292 L .40241 .30275 L F
.40396 .30222 m .40293 .30292 L .40387 .3036 L .912 .629 .494 r
F
.40038 .30515 m .40413 .30372 L .40389 .30324 L .668 .746 .909 r
F
.40345 .30309 m .40389 .30324 L .40373 .30291 L F
.40038 .30515 m .40389 .30324 L .40345 .30309 L F
.40293 .30292 m .40269 .30606 L .4028 .3061 L .814 .537 .519 r
F
.40152 .30308 m .42619 .28822 L .41877 .28416 L .644 .737 .916 r
F
.40299 .3015 m .4029 .30291 L .40293 .30292 L .814 .537 .519 r
F
.4029 .30291 m .40269 .30606 L .40293 .30292 L F
.40387 .3036 m .40368 .30673 L .40415 .3038 L .912 .629 .494 r
F
.40368 .30673 m .40394 .30692 L .40415 .3038 L F
.40387 .3036 m .40293 .30292 L .4028 .3061 L F
.40038 .30515 m .40304 .30767 L .40356 .30724 L .668 .746 .909 r
F
.40038 .30515 m .40046 .30806 L .40157 .30791 L F
.40032 .30836 m .40399 .30696 L .40323 .30641 L .668 .747 .909 r
F
.40054 .31153 m .40448 .31158 L .40427 .31088 L .667 .747 .91 r
F
.40071 .31175 m .40331 .31358 L .40399 .31301 L F
.40088 .31199 m .40331 .31358 L .40071 .31175 L F
.40088 .31199 m .40243 .314 L .40331 .31358 L F
.40469 .30331 m .40405 .307 L .40424 .30737 L .99 .735 .374 r
F
.40262 .30282 m .40282 .30288 L .40299 .3015 L .814 .537 .519 r
F
.40243 .30598 m .40269 .30606 L .4029 .30291 L F
.40282 .30288 m .4029 .30291 L .40299 .3015 L F
.40243 .30598 m .4029 .30291 L .40282 .30288 L F
.40271 .30139 m .40262 .30282 L .40299 .3015 L F
.40271 .30139 m .40169 .30252 L .40262 .30282 L F
.39994 .28615 m .39902 .30099 L .3993 .30092 L .545 .308 .506 r
F
.40152 .30308 m .38318 .2823 L .37596 .28559 L .644 .737 .916 r
F
.40152 .30308 m .39169 .28043 L .38318 .2823 L F
.40152 .30308 m .40089 .28012 L .39169 .28043 L F
.40038 .30515 m .40241 .30275 L .40169 .30252 L .668 .746 .909 r
F
.40032 .30836 m .40646 .3073 L .40488 .30678 L .668 .747 .909 r
F
.40032 .30836 m .40653 .30621 L .40609 .30616 L F
.40032 .30836 m .40148 .31107 L .40253 .31084 L F
.40032 .30836 m .40039 .31122 L .40148 .31107 L F
.40032 .30836 m .40253 .31084 L .40346 .31042 L F
.40047 .31143 m .40392 .31018 L .40316 .30964 L .667 .747 .91 r
F
.39787 .31058 m .39779 .31358 L .39775 .31053 L .849 .569 .514 r
F
.39767 .30726 m .39758 .31348 L .3974 .3134 L F
.39771 .30728 m .39758 .31348 L .39767 .30726 L F
.40053 .31151 m .39685 .31362 L .39834 .31391 L .643 .737 .917 r
F
.40051 .31148 m .40392 .31018 L .40047 .31143 L .667 .747 .91 r
F
.40072 .3113 m .40048 .31144 L .40053 .31151 L .643 .737 .917 r
F
.40048 .31144 m .39685 .31362 L .40053 .31151 L F
.40455 .30913 m .40578 .31046 L .40518 .30924 L .668 .747 .909 r
F
.40479 .30998 m .4071 .3104 L .40645 .30939 L .667 .747 .91 r
F
.40368 .30673 m .40349 .30987 L .40394 .30692 L .912 .629 .494 r
F
.40458 .3088 m .40463 .30816 L .4045 .31134 L 0 0 .006 r
F
.40448 .31158 m .40462 .31158 L .4045 .31134 L .667 .747 .91 r
F
.4045 .31138 m .4045 .31134 L .40449 .31153 L 0 0 .006 r
F
.40458 .3088 m .4045 .31134 L .4045 .31138 L F
.40462 .30992 m .40645 .30939 L .40609 .30936 L .667 .747 .91 r
F
.40463 .30816 m .40446 .31126 L .4045 .31134 L .99 .735 .374 r
F
.40169 .30252 m .40148 .30568 L .40156 .30569 L .735 .467 .523 r
F
.40032 .30836 m .4025 .30579 L .40134 .30567 L .668 .747 .909 r
F
.4043 .31094 m .40441 .31116 L .40458 .30805 L .99 .735 .374 r
F
.4043 .31094 m .40458 .30805 L .40451 .30792 L F
.40446 .30782 m .4043 .31094 L .40451 .30792 L F
.40051 .31148 m .40461 .31004 L .40462 .30992 L .667 .747 .91 r
F
.40148 .31107 m .40224 .31097 L .40253 .31084 L .668 .747 .909 r
F
.40051 .31148 m .40426 .31086 L .40396 .31027 L .667 .747 .91 r
F
.40054 .31153 m .40643 .31051 L .40051 .31148 L F
.40643 .31051 m .4071 .3104 L .40642 .31051 L F
.40643 .31051 m .40642 .31051 L .40051 .31148 L F
.40072 .3113 m .4014 .31268 L .40294 .31381 L .643 .737 .917 r
F
.4014 .31268 m .40211 .31413 L .40239 .31402 L F
.40212 .31366 m .40243 .314 L .40088 .31199 L .667 .747 .91 r
F
.4014 .31268 m .40239 .31402 L .40294 .31381 L .643 .737 .917 r
F
.40219 .31607 m .40221 .31612 L .40238 .31607 L .667 .747 .91 r
F
.40219 .31607 m .40238 .31607 L .40365 .31573 L F
.40122 .31244 m .40196 .31414 L .4014 .31268 L .643 .737 .917 r
F
.40067 .3117 m .40033 .31429 L .40074 .31179 L F
.39834 .31391 m .39845 .31393 L .4006 .3116 L F
.4006 .3116 m .39845 .31393 L .39959 .31414 L F
.40214 .31454 m .40207 .31624 L .40254 .31547 L F
.40191 .3142 m .40084 .31554 L .40198 .31418 L F
.40148 .31442 m .40219 .31607 L .40229 .31412 L .667 .747 .91 r
F
.40211 .31415 m .40229 .31412 L .40229 .31406 L F
.40148 .31442 m .40229 .31412 L .40211 .31415 L F
.40081 .31424 m .40084 .31554 L .40196 .31414 L .643 .737 .917 r
F
.40094 .31423 m .40211 .31413 L .40211 .31415 L .631 .379 .518 r
F
.4039 .31859 m .40337 .32501 L .40609 .32493 L .643 .737 .917 r
F
.4039 .31859 m .40609 .32493 L .40662 .32481 L F
.40221 .31612 m .40415 .32064 L .40676 .31994 L .667 .747 .91 r
F
.40221 .31612 m .40676 .31994 L .40567 .31846 L F
.40221 .31612 m .40567 .31846 L .40365 .31573 L F
.40325 .31431 m .40408 .31652 L .40331 .31421 L .643 .737 .917 r
F
.40736 .31703 m .40848 .31926 L .41045 .31826 L .667 .747 .91 r
F
.41116 .32378 m .41556 .31837 L .41551 .32158 L .463 .251 .505 r
F
.40754 .31973 m .41116 .32378 L .41551 .32158 L .667 .747 .91 r
F
.41551 .32158 m .41556 .31837 L .41888 .31549 L .293 .12 .467 r
F
.41551 .32158 m .41888 .31549 L .41884 .31871 L F
.41045 .31826 m .41551 .32158 L .41884 .31871 L .667 .747 .91 r
F
.40754 .31973 m .41551 .32158 L .41045 .31826 L F
.41556 .31837 m .41561 .31517 L .41893 .31229 L .293 .12 .467 r
F
.41556 .31837 m .41893 .31229 L .41888 .31549 L F
.4105 .31505 m .41556 .31837 L .41888 .31549 L .668 .747 .909 r
F
.41045 .31826 m .41884 .31871 L .41266 .31634 L .667 .747 .91 r
F
.40536 .31492 m .41045 .31826 L .41266 .31634 L F
.40631 .31511 m .41881 .3317 L .42603 .32854 L .643 .737 .917 r
F
.40334 .31361 m .40332 .31362 L .40333 .31356 L .286 .104 .449 r
F
.40349 .31343 m .40349 .3135 L .40338 .31352 L F
.403 .31387 m .40928 .32095 L .40381 .31347 L .643 .737 .917 r
F
.40323 .3137 m .40381 .31347 L .4037 .31333 L F
.403 .31387 m .40381 .31347 L .40323 .3137 L F
.40249 .31397 m .40323 .31365 L .40323 .3137 L .484 .259 .497 r
F
.40061 .32558 m .40062 .3251 L .40138 .32508 L .66 .409 .529 r
F
.40049 .32094 m .40061 .32558 L .40608 .32514 L .667 .747 .91 r
F
.40187 .32401 m .40056 .34197 L .40229 .34191 L .643 .738 .918 r
F
.40348 .32768 m .40229 .34191 L .40963 .34169 L F
.40187 .32401 m .40229 .34191 L .40348 .32768 L F
.40536 .31492 m .41266 .31634 L .40647 .31396 L .667 .747 .91 r
F
.4037 .31333 m .40928 .32095 L .40631 .31511 L .643 .737 .917 r
F
.40442 .31233 m .40715 .31283 L .40448 .3116 L .667 .747 .91 r
F
.40438 .31233 m .40539 .31312 L .40506 .31245 L F
.40409 .31633 m .40497 .31752 L .40419 .3152 L .643 .737 .917 r
F
.40567 .31846 m .40676 .31994 L .40754 .31973 L .667 .747 .91 r
F
.40883 .32273 m .41116 .32378 L .40676 .31994 L F
.40419 .3152 m .40497 .31752 L .41881 .3317 L .643 .737 .917 r
F
.40506 .31245 m .40647 .31396 L .40715 .31283 L .667 .747 .91 r
F
.40539 .31312 m .40647 .31396 L .40506 .31245 L F
.40566 .31365 m .40601 .31435 L .40647 .31396 L F
.41884 .31871 m .41888 .31549 L .42095 .31212 L .001 0 .372 r
F
.41884 .31871 m .42095 .31212 L .42091 .31533 L F
.41266 .31634 m .41884 .31871 L .42091 .31533 L .667 .747 .91 r
F
.41888 .31549 m .41893 .31229 L .421 .30891 L .001 0 .372 r
F
.41888 .31549 m .421 .30891 L .42095 .31212 L F
.41271 .31312 m .41888 .31549 L .42095 .31212 L .668 .747 .909 r
F
.4105 .31505 m .41888 .31549 L .41271 .31312 L F
.41266 .31634 m .42091 .31533 L .41404 .31408 L .667 .747 .91 r
F
.40647 .31396 m .41266 .31634 L .41404 .31408 L F
.40647 .31396 m .41404 .31408 L .40715 .31283 L F
.40438 .31283 m .42603 .32854 L .43156 .3242 L .643 .737 .917 r
F
.40405 .313 m .40404 .31302 L .40404 .31291 L 0 0 .327 r
F
.40405 .313 m .40404 .31291 L .40405 .31289 L F
.40398 .31301 m .40399 .31301 L .40398 .31311 L .286 .104 .449 r
F
.40381 .3134 m .40431 .31374 L .4042 .31275 L .643 .737 .917 r
F
.40311 .31499 m .40391 .31608 L .40325 .31431 L F
.40431 .31374 m .42603 .32854 L .40438 .31283 L F
.40377 .32425 m .40963 .34169 L .41491 .34058 L .643 .738 .918 r
F
.40269 .32267 m .40367 .32536 L .40377 .32425 L F
.40367 .32536 m .40963 .34169 L .40377 .32425 L F
.40445 .3121 m .40443 .31226 L .40444 .31211 L 0 0 .006 r
F
.42663 .32027 m .46236 .32863 L .43213 .31593 L .644 .737 .916 r
F
.4127 .30989 m .41883 .31225 L .42089 .30889 L .668 .746 .909 r
F
.41271 .31312 m .42095 .31212 L .41409 .31087 L .668 .747 .909 r
F
.40715 .31283 m .41404 .31408 L .41448 .31165 L .667 .747 .91 r
F
.40715 .31283 m .41448 .31165 L .40737 .31161 L F
.40444 .31213 m .43156 .3242 L .43503 .31895 L .643 .737 .917 r
F
.40443 .31226 m .40443 .31226 L .40444 .31211 L 0 0 .006 r
F
.40443 .31224 m .40443 .31226 L .40442 .3124 L F
.40444 .31211 m .40443 .31226 L .40443 .31224 L F
.40072 .3113 m .40438 .31283 L .40444 .31213 L .643 .737 .917 r
F
.40438 .31283 m .43156 .3242 L .40444 .31213 L F
.40412 .31999 m .40411 .32013 L .40443 .31226 L 0 0 .006 r
F
.40412 .31999 m .40443 .31226 L .40443 .31226 L F
.40445 .31193 m .40445 .3121 L .40444 .31211 L F
.40166 .30251 m .40144 .30568 L .40169 .30252 L .735 .467 .523 r
F
.40144 .30568 m .40146 .30568 L .40169 .30252 L F
.40387 .3036 m .4028 .3061 L .40368 .30673 L .912 .629 .494 r
F
.40032 .30836 m .40394 .30594 L .4025 .30579 L .668 .747 .909 r
F
.40123 .30886 m .40126 .30886 L .40148 .30568 L .735 .467 .523 r
F
.40122 .30898 m .40148 .30568 L .40146 .30568 L F
.40032 .30836 m .40134 .30567 L .40032 .30556 L .668 .747 .909 r
F
.39926 .30784 m .39895 .30779 L .39889 .306 L .753 .483 .524 r
F
.40038 .30515 m .39688 .30661 L .39747 .3071 L .668 .746 .909 r
F
.40038 .30515 m .39823 .30768 L .39936 .30785 L F
.40038 .30515 m .3974 .30714 L .39834 .30756 L F
.3954 .30186 m .39674 .30106 L .3953 .3018 L F
.39676 .30229 m .39667 .30407 L .39688 .30205 L 0 0 .269 r
F
.40032 .30836 m .39636 .30763 L .39604 .30833 L .668 .747 .909 r
F
.39682 .30377 m .3968 .30378 L .39651 .30444 L .668 .746 .909 r
F
.39667 .30407 m .39651 .3073 L .39676 .30387 L 0 0 .269 r
F
.40032 .30836 m .39604 .30833 L .39595 .30852 L .668 .747 .909 r
F
.40032 .30836 m .39595 .30852 L .39628 .30905 L F
.40032 .30836 m .39628 .30905 L .39671 .30973 L F
.39651 .3073 m .39655 .3072 L .39676 .30387 L 0 0 .269 r
F
.39651 .30444 m .39628 .30493 L .39631 .30512 L .668 .746 .909 r
F
.39667 .30407 m .39628 .30493 L .39614 .30811 L 0 0 .269 r
F
.39667 .30407 m .39614 .30811 L .39651 .3073 L F
.39583 .30594 m .3936 .30632 L .39556 .30653 L .668 .746 .909 r
F
.39636 .30763 m .3941 .30597 L .39342 .3071 L .668 .747 .909 r
F
.39781 .30142 m .39688 .30205 L .3968 .30378 L .339 .143 .462 r
F
.39742 .30333 m .3968 .30378 L .39666 .30696 L F
.39781 .30142 m .3968 .30378 L .39742 .30333 L F
.40038 .30515 m .39824 .30282 L .39752 .30326 L .668 .746 .909 r
F
.39902 .30099 m .39801 .30289 L .39893 .3026 L .545 .308 .506 r
F
.39824 .30282 m .39819 .30276 L .39801 .30289 L .668 .746 .909 r
F
.39824 .30282 m .39801 .30289 L .39752 .30326 L F
.39902 .30099 m .39808 .30124 L .39801 .30289 L .545 .308 .506 r
F
.40032 .30836 m .39667 .30695 L .39636 .30763 L .668 .747 .909 r
F
.39771 .30312 m .39666 .30696 L .39751 .30633 L .339 .143 .462 r
F
.39781 .30142 m .39742 .30333 L .39771 .30312 L F
.39742 .30333 m .39666 .30696 L .39771 .30312 L F
.39781 .30142 m .39771 .30312 L .39808 .30124 L F
.39771 .30312 m .39797 .30292 L .39808 .30124 L F
.39819 .30276 m .39767 .3021 L .39757 .30209 L .668 .746 .909 r
F
.40038 .30515 m .39823 .30273 L .39819 .30276 L F
.39823 .30273 m .39767 .3021 L .39819 .30276 L F
.39626 .30902 m .3962 .31209 L .39613 .31197 L .989 .724 .411 r
F
.39631 .30909 m .3962 .31209 L .39626 .30902 L F
.39629 .31223 m .3962 .31209 L .39631 .30909 L F
.39629 .31223 m .39631 .30909 L .39635 .30916 L F
.39618 .30838 m .39613 .31197 L .39605 .31139 L .875 .7 .179 r
F
.39623 .30875 m .39613 .31197 L .39618 .30838 L F
.39623 .30875 m .39626 .30902 L .39613 .31197 L F
.39697 .30998 m .39688 .31296 L .39689 .30991 L .929 .648 .486 r
F
.39423 .31067 m .39048 .31494 L .39539 .31165 L .668 .747 .909 r
F
.40044 .31139 m .39321 .31222 L .39475 .31322 L .643 .737 .917 r
F
.3883 .30975 m .38573 .31495 L .3906 .31169 L .668 .746 .909 r
F
.39423 .31067 m .38816 .31298 L .39048 .31494 L .668 .747 .909 r
F
.39321 .31222 m .39088 .31248 L .39238 .31277 L .643 .737 .917 r
F
.39321 .31222 m .39238 .31277 L .39475 .31322 L F
.39596 .30668 m .3952 .30499 L .3941 .30597 L .668 .747 .909 r
F
.39655 .3072 m .39661 .30707 L .39678 .30382 L 0 0 .269 r
F
.39676 .30387 m .39678 .30382 L .39688 .30205 L F
.39655 .3072 m .39678 .30382 L .39676 .30387 L F
.39682 .30377 m .39731 .30312 L .39707 .3032 L .668 .746 .909 r
F
.39667 .30407 m .39676 .30387 L .39688 .30205 L 0 0 .269 r
F
.39663 .30703 m .39645 .31017 L .39648 .31011 L F
.39688 .30205 m .39678 .30382 L .39679 .30381 L F
.39707 .3032 m .39592 .30221 L .39612 .3035 L .668 .746 .909 r
F
.39731 .30312 m .39715 .30302 L .39707 .3032 L F
.39715 .30302 m .39592 .30221 L .39707 .3032 L F
.39679 .30381 m .39661 .30707 L .39663 .30703 L 0 0 .269 r
F
.39678 .30382 m .39661 .30707 L .39679 .30381 L F
.39661 .30707 m .39645 .31017 L .39663 .30703 L F
.40032 .30836 m .39738 .30643 L .39722 .30655 L .668 .747 .909 r
F
.39667 .30695 m .39693 .30637 L .39667 .30695 L F
.40032 .30836 m .39722 .30655 L .39667 .30695 L F
.39722 .30655 m .39693 .30637 L .39667 .30695 L F
.39797 .30292 m .39776 .30615 L .39801 .30289 L .339 .143 .462 r
F
.4004 .31134 m .39088 .31248 L .40044 .31139 L .643 .737 .917 r
F
.39884 .32224 m .39865 .32273 L .3998 .3227 L .643 .738 .918 r
F
.3968 .32735 m .39145 .34074 L .397 .32876 L F
.39681 .31562 m .39338 .31965 L .39682 .3206 L .667 .747 .91 r
F
.39532 .31487 m .39338 .31965 L .39681 .31562 L F
.38211 .31529 m .38219 .31208 L .38566 .315 L .932 .65 .484 r
F
.3883 .30975 m .38228 .31205 L .38573 .31495 L .668 .746 .909 r
F
.37986 .31189 m .38219 .31208 L .38211 .31529 L .986 .716 .413 r
F
.37986 .31189 m .37995 .30868 L .38219 .31208 L F
.38682 .30749 m .38228 .31205 L .3883 .30975 L .668 .746 .909 r
F
.38682 .30749 m .38005 .30866 L .38228 .31205 L F
.38057 .31517 m .37986 .31189 L .38211 .31529 L .986 .716 .413 r
F
.3798 .31402 m .37986 .31189 L .38057 .31517 L F
.38211 .31529 m .38566 .315 L .38558 .31821 L .932 .65 .484 r
F
.38196 .31733 m .36674 .31538 L .37052 .321 L .643 .737 .917 r
F
.38322 .3184 m .38211 .31529 L .38558 .31821 L .932 .65 .484 r
F
.38205 .3174 m .38211 .31529 L .38322 .3184 L F
.38816 .31298 m .38558 .31821 L .39048 .31494 L .668 .747 .909 r
F
.38816 .31298 m .38211 .31529 L .38558 .31821 L F
.38199 .31732 m .37862 .31446 L .38196 .31733 L .643 .737 .917 r
F
.38003 .31435 m .37989 .31437 L .38199 .31732 L F
.37989 .31437 m .37862 .31446 L .38024 .31584 L F
.37989 .31437 m .38024 .31584 L .38199 .31732 L F
.37968 .31383 m .36526 .30944 L .36674 .31538 L F
.37922 .3116 m .37986 .31189 L .3798 .31402 L .927 .718 .232 r
F
.38667 .31071 m .38211 .31529 L .38816 .31298 L .668 .747 .909 r
F
.38667 .31071 m .37986 .31189 L .38211 .31529 L F
.379 .30824 m .37995 .30868 L .37986 .31189 L .927 .718 .232 r
F
.39349 .30954 m .38816 .31298 L .39423 .31067 L .668 .747 .909 r
F
.39349 .30954 m .38667 .31071 L .38816 .31298 L F
.37976 .31382 m .37757 .31066 L .37968 .31383 L .643 .737 .917 r
F
.37922 .3116 m .379 .30824 L .37986 .31189 L .927 .718 .232 r
F
.37894 .31045 m .379 .30824 L .37922 .3116 L F
.38611 .30828 m .37986 .31189 L .38667 .31071 L .668 .747 .909 r
F
.379 .30824 m .37909 .30502 L .37995 .30868 L .927 .718 .232 r
F
.38626 .30507 m .38005 .30866 L .38682 .30749 L .668 .746 .909 r
F
.38626 .30507 m .37919 .30503 L .38005 .30866 L F
.38611 .30828 m .379 .30824 L .37986 .31189 L .668 .747 .909 r
F
.39323 .3122 m .37903 .3108 L .37976 .31382 L .643 .737 .917 r
F
.37903 .3108 m .37757 .31066 L .37976 .31382 L F
.39513 .31033 m .39423 .31067 L .39477 .31113 L .668 .747 .909 r
F
.39513 .31033 m .39477 .31113 L .39539 .31165 L F
.39322 .30832 m .38667 .31071 L .39349 .30954 L F
.3936 .30632 m .38682 .30749 L .3883 .30975 L .668 .746 .909 r
F
.39322 .30832 m .38611 .30828 L .38667 .31071 L .668 .747 .909 r
F
.39503 .311 m .37899 .31016 L .39323 .3122 L .643 .737 .917 r
F
.39332 .30511 m .38626 .30507 L .38682 .30749 L .668 .746 .909 r
F
.38651 .30584 m .379 .30824 L .38611 .30828 L .668 .747 .909 r
F
.38666 .30264 m .37919 .30503 L .38626 .30507 L .668 .746 .909 r
F
.39286 .30263 m .37487 .29712 L .36633 .30124 L .644 .737 .916 r
F
.38666 .30264 m .37979 .30138 L .37919 .30503 L .668 .746 .909 r
F
.38651 .30584 m .3796 .30458 L .379 .30824 L .668 .747 .909 r
F
.37937 .30792 m .379 .30824 L .37894 .31045 L 0 0 .1 r
F
.37899 .31016 m .36526 .30944 L .37889 .31079 L .643 .737 .917 r
F
.37899 .31016 m .37889 .31079 L .39323 .3122 L F
.36633 .30124 m .3343 .31121 L .3678 .30716 L .644 .737 .916 r
F
.3796 .30458 m .37909 .30502 L .379 .30824 L 0 0 .1 r
F
.37937 .30792 m .3796 .30458 L .379 .30824 L F
.39503 .311 m .37952 .30702 L .37899 .31016 L .643 .737 .917 r
F
.37953 .30695 m .3796 .30458 L .37937 .30792 L 0 0 .1 r
F
.39605 .31139 m .39603 .31123 L .39615 .3082 L .875 .7 .179 r
F
.39605 .31139 m .39615 .3082 L .39617 .3083 L F
.39615 .3082 m .39603 .31123 L .39615 .30818 L F
.39614 .30811 m .39603 .31123 L .39601 .31109 L F
.39615 .30818 m .39603 .31123 L .39614 .30811 L F
.39618 .30838 m .39605 .31139 L .39617 .3083 L F
.39651 .3073 m .39614 .30811 L .39601 .31109 L 0 0 .269 r
F
.39651 .3073 m .39601 .31109 L .39635 .31038 L F
.39342 .3071 m .38611 .30828 L .39322 .30832 L .668 .747 .909 r
F
.39332 .30511 m .38682 .30749 L .3936 .30632 L .668 .746 .909 r
F
.39342 .3071 m .38651 .30584 L .38611 .30828 L .668 .747 .909 r
F
.39612 .31027 m .37974 .30662 L .39503 .311 L .643 .737 .917 r
F
.39353 .30389 m .38626 .30507 L .39332 .30511 L .668 .746 .909 r
F
.39353 .30389 m .38666 .30264 L .38626 .30507 L F
.38786 .30357 m .3796 .30458 L .38651 .30584 L .668 .747 .909 r
F
.38112 .30443 m .3796 .30458 L .37953 .30695 L 0 0 .351 r
F
.37974 .30662 m .36619 .3036 L .37949 .30701 L .643 .737 .917 r
F
.37974 .30662 m .37949 .30701 L .39503 .311 L F
.37487 .29712 m .36716 .29599 L .36633 .30124 L .644 .737 .916 r
F
.3796 .30458 m .37968 .30136 L .37909 .30502 L 0 0 .1 r
F
.388 .30038 m .37979 .30138 L .38666 .30264 L .668 .746 .909 r
F
.38161 .30116 m .37968 .30136 L .3796 .30458 L 0 0 .351 r
F
.38786 .30357 m .38161 .30116 L .3796 .30458 L .668 .747 .909 r
F
.38112 .30443 m .38161 .30116 L .3796 .30458 L 0 0 .351 r
F
.39612 .31027 m .38159 .30371 L .37974 .30662 L .643 .737 .917 r
F
.3942 .30276 m .38666 .30264 L .39353 .30389 L .668 .746 .909 r
F
.3942 .30276 m .388 .30038 L .38666 .30264 L F
.39007 .30162 m .38161 .30116 L .38786 .30357 L .668 .747 .909 r
F
.38442 .30142 m .38161 .30116 L .38154 .30375 L .277 .103 .456 r
F
.38159 .30371 m .38157 .3037 L .38154 .30375 L .643 .737 .917 r
F
.38159 .30371 m .38154 .30375 L .37974 .30662 L F
.38154 .30375 m .38161 .30116 L .38112 .30443 L 0 0 .351 r
F
.39635 .31038 m .39645 .31017 L .39661 .30707 L 0 0 .269 r
F
.39667 .30695 m .39666 .30696 L .39636 .30763 L .668 .747 .909 r
F
.39635 .31038 m .39661 .30707 L .39655 .3072 L 0 0 .269 r
F
.39651 .3073 m .39635 .31038 L .39655 .3072 L F
.40032 .30836 m .39671 .30973 L .397 .31019 L .668 .747 .909 r
F
.39776 .30615 m .39779 .30613 L .39801 .30289 L .339 .143 .462 r
F
.39801 .30289 m .39779 .30613 L .39787 .30607 L F
.39808 .30124 m .39797 .30292 L .39801 .30289 L F
.39812 .3026 m .39844 .3006 L .39674 .30106 L .668 .746 .909 r
F
.40038 .30515 m .39925 .3025 L .39812 .3026 L F
.39925 .3025 m .39844 .3006 L .39812 .3026 L F
.40025 .30088 m .3993 .30092 L .39923 .3025 L .652 .396 .519 r
F
.39651 .30444 m .39621 .30438 L .39628 .30493 L .668 .746 .909 r
F
.3966 .30591 m .39666 .30425 L .3952 .30499 L .668 .747 .909 r
F
.39893 .3026 m .39801 .30289 L .39787 .30607 L .545 .308 .506 r
F
.39771 .30312 m .39751 .30633 L .39797 .30292 L .339 .143 .462 r
F
.39751 .30633 m .39776 .30615 L .39797 .30292 L F
.39663 .30703 m .39664 .30702 L .3968 .30378 L 0 0 .269 r
F
.3968 .30378 m .39664 .30702 L .39666 .30696 L F
.39718 .30629 m .39802 .30578 L .3966 .30591 L .668 .747 .909 r
F
.40032 .30836 m .39819 .30597 L .39718 .30629 L F
.39819 .30597 m .39802 .30578 L .39718 .30629 L F
.39679 .30381 m .39663 .30703 L .3968 .30378 L 0 0 .269 r
F
.39802 .30578 m .39666 .30425 L .3966 .30591 L .668 .747 .909 r
F
.40025 .30088 m .39923 .3025 L .40015 .30242 L .652 .396 .519 r
F
.39902 .30099 m .39893 .3026 L .3993 .30092 L .545 .308 .506 r
F
.39893 .3026 m .39919 .30251 L .3993 .30092 L F
.3993 .30092 m .39919 .30251 L .39923 .3025 L F
.40038 .30515 m .40027 .30045 L .39844 .3006 L .668 .746 .909 r
F
.40015 .30242 m .39923 .3025 L .39909 .30568 L .652 .396 .519 r
F
.39734 .31035 m .397 .31019 L .39716 .31047 L .668 .747 .909 r
F
.40032 .30836 m .397 .31019 L .39734 .31035 L F
.40032 .30836 m .39827 .31076 L .39868 .31095 L F
.40032 .30836 m .39868 .31095 L .3993 .31104 L F
.40032 .30836 m .39734 .31035 L .39827 .31076 L F
.40032 .30836 m .3993 .31104 L .40039 .3112 L F
.40031 .31121 m .39695 .30972 L .39612 .31027 L .643 .737 .917 r
F
.4028 .3061 m .40258 .30925 L .40267 .30928 L .814 .537 .519 r
F
.40156 .30569 m .40126 .30886 L .40142 .30888 L .735 .467 .523 r
F
.40243 .30598 m .40156 .30569 L .40142 .30888 L .814 .537 .519 r
F
.40243 .30598 m .40142 .30888 L .40224 .30914 L F
.40243 .30598 m .40224 .30914 L .40269 .30606 L F
.40224 .30914 m .40248 .30922 L .40269 .30606 L F
.40032 .30836 m .40032 .30556 L .40025 .30557 L .668 .747 .909 r
F
.40015 .30242 m .39909 .30568 L .39996 .3056 L .652 .396 .519 r
F
.39893 .3026 m .39787 .30607 L .39873 .30579 L .545 .308 .506 r
F
.39802 .30578 m .39836 .30379 L .39666 .30425 L .668 .747 .909 r
F
.39893 .3026 m .39873 .30579 L .39919 .30251 L .545 .308 .506 r
F
.40032 .30836 m .39909 .30568 L .39819 .30597 L .668 .747 .909 r
F
.40036 .31128 m .39612 .31027 L .39503 .311 L .643 .737 .917 r
F
.40031 .31121 m .39612 .31027 L .40036 .31128 L F
.40022 .31109 m .39695 .30972 L .40031 .31121 L F
.40368 .30673 m .40267 .30928 L .40349 .30987 L .912 .629 .494 r
F
.40043 .31137 m .40238 .30908 L .40037 .31129 L .667 .747 .91 r
F
.40368 .30673 m .4028 .3061 L .40267 .30928 L .912 .629 .494 r
F
.40269 .30606 m .40248 .30922 L .4028 .3061 L .814 .537 .519 r
F
.40445 .31193 m .40449 .31153 L .40445 .3121 L 0 0 .006 r
F
.4045 .31138 m .40449 .31153 L .40445 .31193 L F
.43213 .31593 m .46236 .32863 L .46941 .31828 L .644 .737 .916 r
F
.43213 .31593 m .46941 .31828 L .43558 .31071 L F
.42091 .31533 m .42095 .31212 L .42163 .30848 L 0 0 .139 r
F
.42091 .31533 m .42163 .30848 L .42159 .31169 L F
.42095 .31212 m .421 .30891 L .42167 .30527 L F
.42095 .31212 m .42167 .30527 L .42163 .30848 L F
.4127 .30989 m .42089 .30889 L .41407 .30764 L .668 .746 .909 r
F
.41407 .30764 m .42089 .30889 L .42156 .30527 L F
.41409 .31087 m .42095 .31212 L .42163 .30848 L .668 .747 .909 r
F
.41404 .31408 m .42091 .31533 L .42159 .31169 L .667 .747 .91 r
F
.41404 .31408 m .42159 .31169 L .41448 .31165 L F
.40453 .3116 m .43503 .31895 L .43601 .31405 L .643 .737 .917 r
F
.40072 .3113 m .40484 .31222 L .40453 .3116 L F
.40484 .31222 m .43503 .31895 L .40453 .3116 L F
.4045 .31134 m .40449 .31152 L .40449 .31153 L .99 .735 .374 r
F
.40448 .31158 m .4045 .31134 L .40427 .31088 L .667 .747 .91 r
F
.40462 .31158 m .40588 .3116 L .40427 .31088 L F
.40588 .3116 m .40737 .31161 L .40477 .3108 L F
.40448 .3115 m .43601 .31405 L .42636 .31264 L .643 .737 .917 r
F
.40072 .3113 m .40453 .3116 L .40448 .3115 L F
.40453 .3116 m .43601 .31405 L .40448 .3115 L F
.40446 .31126 m .40445 .31145 L .4045 .31134 L .99 .735 .374 r
F
.4044 .31244 m .40442 .3124 L .40436 .31382 L 0 0 .327 r
F
.40379 .32391 m .41491 .34058 L .4099 .33076 L .643 .738 .918 r
F
.40269 .32267 m .40377 .32425 L .40379 .32391 L F
.40377 .32425 m .41491 .34058 L .40379 .32391 L F
.40187 .32401 m .40348 .32768 L .40269 .32267 L F
.40348 .32768 m .40963 .34169 L .40367 .32536 L F
.40348 .32768 m .40367 .32536 L .40269 .32267 L F
.40443 .31226 m .40411 .32013 L .40442 .3124 L 0 0 .006 r
F
.40608 .32514 m .40639 .32486 L .40986 .32413 L .575 .34 .522 r
F
.40608 .32514 m .40609 .32493 L .40639 .32486 L F
.40415 .32064 m .40608 .32514 L .40986 .32413 L .667 .747 .91 r
F
.40049 .32094 m .40608 .32514 L .40415 .32064 L F
.40322 .3218 m .4088 .32861 L .40644 .32398 L .643 .738 .918 r
F
.40269 .32267 m .4099 .33076 L .40322 .3218 L F
.4099 .33076 m .41806 .33992 L .4088 .32861 L F
.4099 .33076 m .4088 .32861 L .40322 .3218 L F
.40263 .35549 m .40264 .3555 L .4026 .35648 L 0 0 .327 r
F
.40394 .31613 m .40409 .31633 L .40419 .3152 L .643 .737 .917 r
F
.40365 .32111 m .40575 .32263 L .40533 .32181 L .643 .738 .918 r
F
.40497 .31752 m .41591 .33231 L .41881 .3317 L .643 .737 .917 r
F
.40322 .3218 m .40644 .32398 L .40365 .32111 L .643 .738 .918 r
F
.40644 .32398 m .42529 .33677 L .40575 .32263 L F
.40644 .32398 m .40575 .32263 L .40365 .32111 L F
.40413 .31287 m .40421 .31274 L .40398 .31726 L 0 0 .327 r
F
.4042 .31275 m .40431 .31374 L .40438 .31283 L .643 .737 .917 r
F
.40421 .31274 m .4044 .31244 L .40398 .31726 L 0 0 .327 r
F
.40038 .31627 m .40049 .32094 L .40415 .32064 L .667 .747 .91 r
F
.40038 .31627 m .40415 .32064 L .40221 .31612 L F
.40928 .32095 m .41881 .3317 L .40631 .31511 L .643 .737 .917 r
F
.40415 .32064 m .40883 .32273 L .40676 .31994 L .667 .747 .91 r
F
.42603 .32854 m .46202 .33693 L .43156 .3242 L .643 .737 .917 r
F
.40404 .32047 m .43084 .33244 L .43432 .3272 L .643 .738 .918 r
F
.40398 .31726 m .40407 .32043 L .40386 .32078 L 0 0 .327 r
F
.40413 .31287 m .40386 .32078 L .40385 .32078 L F
.39959 .31414 m .3995 .31436 L .40033 .31429 L .643 .737 .917 r
F
.3995 .31436 m .39878 .31618 L .40033 .31429 L F
.3995 .31436 m .39947 .31439 L .39949 .31439 L F
.39854 .3161 m .40049 .32094 L .40038 .31627 L .667 .747 .91 r
F
.39854 .3161 m .39682 .3206 L .40049 .32094 L F
.39916 .31406 m .40033 .31429 L .40033 .31439 L .753 .483 .524 r
F
.40033 .31439 m .39854 .3161 L .40038 .31627 L .667 .747 .91 r
F
.40033 .31439 m .40032 .32225 L .39999 .32228 L .631 .379 .518 r
F
.40033 .31429 m .40033 .31439 L .40033 .31439 L F
.40033 .31439 m .40032 .32225 L .40033 .31439 L F
.39925 .31423 m .39854 .3161 L .40033 .31439 L .667 .747 .91 r
F
.39916 .31406 m .40033 .31439 L .39917 .31422 L .753 .483 .524 r
F
.39925 .31423 m .39681 .31562 L .39854 .3161 L .667 .747 .91 r
F
.39916 .31406 m .39917 .31422 L .39915 .31422 L .753 .483 .524 r
F
.39814 .31407 m .39681 .31562 L .39904 .31435 L .667 .747 .91 r
F
.39854 .31413 m .39904 .31435 L .39925 .31423 L F
.39814 .31407 m .39904 .31435 L .39854 .31413 L F
.39779 .31358 m .39855 .31395 L .39854 .31413 L .849 .569 .514 r
F
.40048 .31144 m .39611 .31278 L .3973 .31335 L .643 .737 .917 r
F
.40044 .31139 m .39611 .31278 L .40048 .31144 L F
.40248 .30922 m .40258 .30925 L .4028 .3061 L .814 .537 .519 r
F
.4004 .31134 m .39503 .311 L .39323 .3122 L .643 .737 .917 r
F
.40349 .30987 m .40373 .31005 L .40394 .30692 L .912 .629 .494 r
F
.40394 .30692 m .40373 .31005 L .40405 .307 L F
.40373 .31005 m .40383 .31012 L .40405 .307 L F
.40405 .307 m .40383 .31012 L .40392 .31018 L F
.40424 .30737 m .40392 .31018 L .40446 .30782 L .99 .735 .374 r
F
.40474 .30838 m .40598 .30839 L .40449 .30787 L .668 .747 .909 r
F
.40474 .30838 m .40484 .30857 L .40495 .30838 L F
.40424 .30737 m .40405 .307 L .40392 .31018 L .99 .735 .374 r
F
.40495 .30838 m .40721 .30961 L .40742 .3084 L .668 .747 .909 r
F
.40246 .30898 m .40521 .30827 L .40372 .30751 L .667 .747 .91 r
F
.40043 .31137 m .40389 .30913 L .40246 .30898 L F
.40389 .30913 m .40521 .30827 L .40246 .30898 L F
.40038 .30515 m .40169 .30252 L .40139 .30248 L .668 .746 .909 r
F
.401 .30883 m .40123 .30886 L .40166 .30251 L .735 .467 .523 r
F
.40161 .30251 m .40166 .30251 L .40175 .30105 L F
.401 .30883 m .40166 .30251 L .40161 .30251 L F
.40025 .30088 m .40015 .30242 L .40052 .30087 L .652 .396 .519 r
F
.40015 .30242 m .40042 .30239 L .40052 .30087 L F
.40148 .30101 m .40052 .30087 L .40046 .30239 L .735 .467 .523 r
F
.40052 .30087 m .40042 .30239 L .40046 .30239 L .652 .396 .519 r
F
.40038 .30515 m .40139 .30248 L .40031 .30237 L .668 .746 .909 r
F
.40148 .30101 m .40032 .30556 L .40119 .30565 L .735 .467 .523 r
F
.40031 .30237 m .4021 .30062 L .40027 .30045 L .668 .746 .909 r
F
.40148 .30101 m .40139 .30248 L .40175 .30105 L .735 .467 .523 r
F
.40148 .30101 m .40046 .30239 L .40111 .30246 L F
.40139 .30248 m .4021 .30062 L .40031 .30237 L .668 .746 .909 r
F
.40169 .30252 m .40382 .3011 L .40142 .30243 L F
.40241 .30275 m .40254 .3026 L .40169 .30252 L F
.40254 .3026 m .40382 .3011 L .40169 .30252 L F
.40139 .30248 m .401 .30883 L .40161 .30251 L .735 .467 .523 r
F
.40139 .30248 m .40161 .30251 L .40175 .30105 L F
.40047 .31143 m .40521 .30827 L .40043 .31137 L .667 .747 .91 r
F
.39852 .34953 m .39844 .35859 L .39851 .34971 L .753 .483 .524 r
F
.39884 .32224 m .39849 .32259 L .39865 .32273 L .643 .738 .918 r
F
.39877 .32221 m .39641 .32457 L .39884 .32224 L F
.38997 .32373 m .38661 .33076 L .39227 .33252 L .643 .737 .917 r
F
.39641 .32457 m .38991 .33107 L .39642 .32463 L .643 .738 .918 r
F
.39641 .32457 m .39642 .32463 L .39884 .32224 L F
.39806 .31416 m .39532 .31487 L .39681 .31562 L .667 .747 .91 r
F
.39779 .31358 m .39854 .31413 L .39779 .31379 L .849 .569 .514 r
F
.39739 .31361 m .39532 .31487 L .39806 .31416 L .667 .747 .91 r
F
.39731 .31354 m .39728 .31356 L .39739 .31361 L F
.39728 .31356 m .39532 .31487 L .39739 .31361 L F
.39779 .31358 m .39779 .31379 L .39758 .31348 L .849 .569 .514 r
F
.39681 .31562 m .39682 .3206 L .39854 .3161 L .667 .747 .91 r
F
.39779 .31379 m .39758 .32164 L .39758 .3137 L .849 .569 .514 r
F
.39779 .31379 m .39758 .3137 L .39758 .31348 L F
.39688 .31296 m .3974 .3134 L .39739 .31361 L .929 .648 .486 r
F
.39504 .31313 m .38886 .31511 L .39398 .31535 L .643 .737 .917 r
F
.39731 .31354 m .39416 .31389 L .39532 .31487 L .667 .747 .91 r
F
.3966 .31296 m .3966 .31296 L .39731 .31354 L F
.3966 .31296 m .39416 .31389 L .39698 .31358 L F
.3966 .31296 m .39698 .31358 L .39731 .31354 L F
.39629 .31223 m .39661 .31273 L .3966 .31296 L .989 .724 .411 r
F
.39136 .32318 m .39513 .32436 L .39512 .32508 L .797 .525 .526 r
F
.39338 .31965 m .39512 .32508 L .39682 .3206 L .667 .747 .91 r
F
.39629 .31223 m .3966 .31296 L .39629 .31247 L .989 .724 .411 r
F
.38057 .31517 m .38211 .31529 L .38205 .3174 L .986 .716 .413 r
F
.39475 .31322 m .38003 .31435 L .38199 .31732 L .643 .737 .917 r
F
.39088 .31248 m .36674 .31538 L .39475 .31322 L F
.3966 .31296 m .39342 .31275 L .39416 .31389 L .667 .747 .91 r
F
.39605 .31139 m .39613 .31197 L .39612 .3122 L .875 .7 .179 r
F
.39613 .31229 m .39584 .31234 L .39618 .31262 L .667 .747 .91 r
F
.39584 .31234 m .39342 .31275 L .3966 .31296 L F
.39629 .31246 m .39626 .32073 L .396 .32032 L .989 .724 .411 r
F
.39629 .31223 m .39629 .31247 L .39629 .31246 L F
.39629 .31247 m .39626 .32073 L .39629 .31246 L F
.39605 .31139 m .39612 .3122 L .39604 .31162 L .875 .7 .179 r
F
.39613 .31229 m .39314 .31154 L .39342 .31275 L .667 .747 .91 r
F
.39612 .3122 m .39314 .31154 L .39613 .31229 L F
.39603 .31155 m .39572 .31155 L .39612 .3122 L F
.39572 .31155 m .39314 .31154 L .39612 .3122 L F
.40036 .31128 m .39503 .311 L .4004 .31134 L .643 .737 .917 r
F
.39635 .31038 m .39601 .31109 L .396 .31129 L 0 0 .269 r
F
.39605 .31139 m .39604 .3116 L .39603 .31123 L .875 .7 .179 r
F
.39604 .3116 m .39602 .31144 L .39603 .31123 L F
.39604 .3116 m .39578 .31997 L .39571 .31949 L F
.39605 .31139 m .39604 .31162 L .39604 .3116 L F
.39604 .31162 m .39578 .31997 L .39604 .3116 L F
.39603 .31123 m .39602 .31144 L .39601 .31109 L F
.39602 .31144 m .396 .3113 L .39601 .31109 L F
.40026 .31158 m .39593 .31079 L .39603 .31155 L .667 .747 .91 r
F
.39593 .31079 m .39335 .31032 L .39603 .31155 L F
.39604 .3116 m .39571 .31949 L .39602 .31144 L .875 .7 .179 r
F
.39571 .31949 m .39569 .31936 L .39603 .31123 L F
.39612 .3122 m .39586 .3201 L .39578 .31997 L .989 .724 .411 r
F
.39613 .31197 m .39612 .3122 L .39612 .3122 L F
.3968 .32735 m .38991 .33107 L .39145 .34074 L .643 .738 .918 r
F
.39652 .3253 m .38991 .33107 L .3968 .32735 L F
.39794 .3234 m .38991 .33107 L .39821 .32382 L F
.39612 .3122 m .39586 .32011 L .39612 .3122 L .989 .724 .411 r
F
.39784 .32323 m .38991 .33107 L .39794 .3234 L .643 .738 .918 r
F
.38997 .32366 m .39136 .32318 L .39512 .32508 L .797 .525 .526 r
F
.396 .32032 m .39593 .3202 L .3962 .31232 L .989 .724 .411 r
F
.3962 .31232 m .3962 .31232 L .3962 .31209 L F
.396 .32032 m .3962 .31232 L .3962 .31232 L F
.39629 .31246 m .3962 .31232 L .3962 .31209 L F
.39058 .32245 m .38373 .32986 L .38997 .32373 L .643 .737 .917 r
F
.38997 .32366 m .38999 .32275 L .39136 .32318 L .797 .525 .526 r
F
.39338 .31965 m .38997 .32366 L .39512 .32508 L .667 .747 .91 r
F
.39731 .32239 m .39053 .32976 L .39777 .32312 L .643 .738 .918 r
F
.39053 .32976 m .38991 .33107 L .3978 .32318 L F
.39778 .32314 m .3978 .32318 L .39843 .32255 L F
.39053 .32976 m .3978 .32318 L .39778 .32314 L F
.39617 .31228 m .39612 .3122 L .39613 .31229 L .667 .747 .91 r
F
.3962 .31209 m .39593 .3202 L .39613 .31197 L .989 .724 .411 r
F
.39053 .32976 m .39843 .32255 L .39841 .32253 L .643 .738 .918 r
F
.39688 .3132 m .39739 .31361 L .39705 .32139 L .929 .648 .486 r
F
.39772 .32195 m .39308 .32446 L .39053 .32976 L .643 .738 .918 r
F
.3978 .32186 m .39769 .32192 L .39772 .32195 L F
.39769 .32192 m .39308 .32446 L .39772 .32195 L F
.39673 .31284 m .3965 .32093 L .39661 .31273 L .929 .648 .486 r
F
.39871 .32204 m .39871 .32204 L .39877 .31399 L .753 .483 .524 r
F
.39841 .32253 m .39843 .32255 L .39891 .32207 L .643 .738 .918 r
F
.3978 .32186 m .39731 .32239 L .39861 .32213 L F
.3982 .32194 m .39861 .32213 L .39891 .32207 L F
.3978 .32186 m .39861 .32213 L .3982 .32194 L F
.3974 .32156 m .39726 .32149 L .3974 .3134 L .849 .569 .514 r
F
.39821 .31398 m .39739 .31361 L .39806 .31416 L .667 .747 .91 r
F
.39787 .32178 m .39648 .32161 L .3978 .32186 L .643 .738 .918 r
F
.3974 .3134 m .39726 .32149 L .39705 .32139 L .849 .569 .514 r
F
.39757 .31369 m .3974 .32156 L .3974 .31362 L F
.39882 .314 m .39875 .32204 L .39877 .31399 L .753 .483 .524 r
F
.39731 .32239 m .39777 .32312 L .39891 .32207 L .643 .738 .918 r
F
.39865 .32273 m .3968 .32735 L .39947 .32341 L F
.3968 .32735 m .397 .32876 L .39947 .32341 L F
.39865 .32273 m .39947 .32341 L .3998 .3227 L F
.39875 .32204 m .39852 .34953 L .39871 .32204 L .753 .483 .524 r
F
.39875 .32204 m .39871 .32204 L .39877 .31399 L F
.39779 .31379 m .39854 .31413 L .3982 .32194 L .849 .569 .514 r
F
.39779 .31379 m .3982 .32194 L .39758 .32164 L F
.39915 .31422 m .39999 .32228 L .39903 .3221 L .753 .483 .524 r
F
.39917 .31422 m .39999 .32228 L .39915 .31422 L F
.39917 .31422 m .40033 .31439 L .39999 .32228 L F
.39688 .31296 m .39705 .32139 L .39662 .32103 L .929 .648 .486 r
F
.39758 .32164 m .3974 .32156 L .39758 .31348 L .849 .569 .514 r
F
.39877 .31399 m .39871 .32204 L .39866 .31397 L .753 .483 .524 r
F
.39871 .32204 m .39862 .32202 L .39866 .31397 L F
.39849 .32259 m .39784 .32323 L .39865 .32273 L .643 .738 .918 r
F
.39784 .32323 m .39794 .3234 L .39865 .32273 L F
.39821 .32382 m .39652 .3253 L .3968 .32735 L F
.39865 .32273 m .39794 .3234 L .39821 .32382 L F
.3982 .32194 m .39844 .35859 L .39662 .3583 L .753 .483 .524 r
F
.39855 .31395 m .39853 .322 L .3982 .32194 L F
.39853 .322 m .39844 .35859 L .3982 .32194 L F
.3965 .32093 m .3964 .32085 L .39661 .31273 L .929 .648 .486 r
F
.39661 .31273 m .3964 .32085 L .39626 .32073 L F
.40026 .31158 m .39617 .31228 L .3966 .31296 L .667 .747 .91 r
F
.39617 .31228 m .39613 .31229 L .3966 .31296 L F
.39617 .31228 m .3966 .31296 L .3966 .31296 L F
.40026 .31158 m .39603 .31155 L .39612 .3122 L F
.39629 .31223 m .39629 .31246 L .3962 .31209 L .989 .724 .411 r
F
.40026 .31158 m .39612 .3122 L .39617 .31228 L .667 .747 .91 r
F
.39613 .31229 m .39618 .31262 L .3966 .31296 L F
.39662 .32103 m .3965 .32093 L .39672 .31307 L .929 .648 .486 r
F
.39673 .31307 m .39672 .31307 L .39673 .31284 L F
.39662 .32103 m .39672 .31307 L .39673 .31307 L F
.39629 .31247 m .3966 .31296 L .39626 .32073 L .989 .724 .411 r
F
.39688 .31296 m .39739 .31361 L .39688 .3132 L .929 .648 .486 r
F
.39688 .31296 m .39687 .31319 L .39673 .31284 L F
.39687 .31319 m .39673 .31307 L .39673 .31284 L F
.40026 .31158 m .3966 .31296 L .39731 .31354 L .667 .747 .91 r
F
.39687 .31319 m .39662 .32103 L .39673 .31307 L .929 .648 .486 r
F
.39751 .30633 m .39666 .30696 L .39653 .31 L .339 .143 .462 r
F
.39751 .30633 m .39653 .31 L .39732 .30948 L F
.39663 .30703 m .39648 .31011 L .39664 .30702 L 0 0 .269 r
F
.39604 .30833 m .39322 .30832 L .39566 .30916 L .668 .747 .909 r
F
.39666 .30696 m .39648 .31011 L .39653 .31 L 0 0 .269 r
F
.39664 .30702 m .39648 .31011 L .39666 .30696 L F
.3941 .30597 m .38651 .30584 L .39342 .3071 L .668 .747 .909 r
F
.3941 .30597 m .38786 .30357 L .38651 .30584 L F
.39695 .30972 m .36949 .29824 L .39612 .31027 L .643 .737 .917 r
F
.39433 .30946 m .39403 .30919 L .39396 .3093 L .667 .747 .91 r
F
.39433 .30946 m .39396 .3093 L .39335 .31032 L F
.3957 .31075 m .39433 .30946 L .39335 .31032 L F
.40026 .31158 m .39652 .31014 L .39621 .31084 L F
.39647 .31026 m .39604 .31829 L .39607 .31823 L 0 0 .269 r
F
.39648 .31011 m .39647 .31026 L .39647 .31026 L F
.39647 .31026 m .39604 .31829 L .39647 .31026 L F
.39635 .31038 m .396 .31129 L .39634 .31055 L F
.39648 .32161 m .39412 .32228 L .39363 .32331 L .643 .738 .918 r
F
.39866 .31397 m .39862 .32202 L .39855 .31395 L .753 .483 .524 r
F
.39862 .32202 m .39844 .35859 L .39853 .322 L F
.39862 .32202 m .39853 .322 L .39855 .31395 L F
.39398 .31535 m .38886 .31511 L .37632 .32594 L .643 .737 .917 r
F
.38886 .31511 m .37052 .321 L .37469 .32455 L F
.38886 .31511 m .37469 .32455 L .37632 .32594 L F
.38601 .32064 m .3859 .3207 L .38963 .32256 L F
.3859 .3207 m .38843 .32286 L .38963 .32256 L F
.38601 .32064 m .38963 .32256 L .39065 .3223 L F
.3855 .32142 m .38691 .32112 L .38997 .32366 L .864 .585 .513 r
F
.38691 .32112 m .38999 .32275 L .38997 .32366 L F
.39065 .3223 m .38963 .32256 L .39016 .32284 L .643 .737 .917 r
F
.3904 .31815 m .38997 .32366 L .39338 .31965 L .667 .747 .91 r
F
.3855 .32142 m .38552 .32038 L .38691 .32112 L .864 .585 .513 r
F
.3904 .31815 m .3855 .32142 L .38997 .32366 L .667 .747 .91 r
F
.39461 .32125 m .36585 .32362 L .36964 .32923 L .643 .738 .918 r
F
.39593 .3202 m .39586 .32011 L .39613 .31197 L .989 .724 .411 r
F
.39629 .31246 m .396 .32032 L .3962 .31232 L F
.39586 .32011 m .39586 .3201 L .39612 .3122 L F
.40238 .30908 m .40235 .30905 L .40037 .31129 L .667 .747 .91 r
F
.39308 .30119 m .39396 .29991 L .37487 .29712 L .644 .737 .916 r
F
.39396 .29991 m .37053 .29007 L .37487 .29712 L F
.39628 .30905 m .39595 .30852 L .39566 .30916 L .668 .747 .909 r
F
.37487 .29712 m .36725 .29541 L .36716 .29599 L .644 .737 .916 r
F
.388 .30038 m .38179 .29798 L .37979 .30138 L .668 .746 .909 r
F
.38161 .30116 m .38169 .29795 L .37968 .30136 L 0 0 .351 r
F
.3952 .30499 m .38786 .30357 L .3941 .30597 L .668 .747 .909 r
F
.3952 .30499 m .39007 .30162 L .38786 .30357 L F
.39019 .29844 m .38179 .29798 L .388 .30038 L .668 .746 .909 r
F
.38491 .29823 m .38169 .29795 L .38161 .30116 L .277 .103 .456 r
F
.3953 .3018 m .388 .30038 L .3942 .30276 L .668 .746 .909 r
F
.39665 .30104 m .39396 .29991 L .39308 .30119 L .644 .737 .916 r
F
.3953 .3018 m .39019 .29844 L .388 .30038 L .668 .746 .909 r
F
.39007 .30162 m .38491 .29823 L .38161 .30116 L .668 .747 .909 r
F
.38442 .30142 m .38491 .29823 L .38161 .30116 L .277 .103 .456 r
F
.39649 .30953 m .38491 .30104 L .38193 .30344 L .643 .737 .917 r
F
.39674 .30106 m .39019 .29844 L .3953 .3018 L .668 .746 .909 r
F
.39298 .30013 m .38491 .29823 L .39007 .30162 L .668 .747 .909 r
F
.39674 .30106 m .39309 .29695 L .39019 .29844 L .668 .746 .909 r
F
.39019 .29844 m .38507 .29506 L .38179 .29798 L F
.39309 .29695 m .38507 .29506 L .39019 .29844 L F
.39309 .29695 m .38941 .29283 L .38507 .29506 L F
.39298 .30013 m .38928 .29598 L .38491 .29823 L .668 .747 .909 r
F
.38905 .29918 m .38491 .29823 L .38484 .30107 L .455 .241 .498 r
F
.38491 .30104 m .38489 .30103 L .38484 .30107 L .643 .737 .917 r
F
.38491 .30104 m .38484 .30107 L .38193 .30344 L F
.38484 .30107 m .38491 .29823 L .38442 .30142 L .277 .103 .456 r
F
.39779 .30613 m .39758 .3093 L .39787 .30607 L .339 .143 .462 r
F
.39758 .3093 m .39765 .30926 L .39787 .30607 L F
.39787 .30607 m .39765 .30926 L .39773 .3092 L F
.39776 .30615 m .39755 .30933 L .39779 .30613 L F
.39755 .30933 m .39758 .3093 L .39779 .30613 L F
.39751 .30633 m .39732 .30948 L .39776 .30615 L F
.39732 .30948 m .39755 .30933 L .39776 .30615 L F
.39636 .30763 m .39587 .30754 L .39604 .30833 L .668 .747 .909 r
F
.39587 .30754 m .39528 .30744 L .39551 .30781 L F
.39587 .30754 m .39551 .30781 L .39583 .30833 L F
.39528 .30744 m .39342 .3071 L .39583 .30833 L F
.39767 .30922 m .37496 .29375 L .39649 .30953 L .643 .737 .917 r
F
.39873 .30579 m .39853 .30899 L .39898 .30571 L .545 .308 .506 r
F
.39853 .30899 m .39865 .30896 L .39898 .30571 L F
.39981 .31053 m .39909 .30885 L .39865 .30896 L .667 .747 .91 r
F
.39909 .30885 m .39895 .30886 L .39865 .30896 L F
.40032 .30836 m .39917 .30567 L .39909 .30568 L .668 .747 .909 r
F
.39873 .30579 m .39898 .30571 L .39919 .30251 L .545 .308 .506 r
F
.40015 .30242 m .39996 .3056 L .40042 .30239 L .652 .396 .519 r
F
.39996 .3056 m .40021 .30557 L .40042 .30239 L F
.39923 .3025 m .39901 .3057 L .39909 .30568 L .545 .308 .506 r
F
.39667 .30695 m .3941 .30597 L .39636 .30763 L .668 .747 .909 r
F
.39612 .3035 m .39609 .30351 L .39621 .30438 L .668 .746 .909 r
F
.39609 .30349 m .3942 .30276 L .39621 .30438 L F
.39666 .30425 m .39007 .30162 L .3952 .30499 L .668 .747 .909 r
F
.39666 .30425 m .39298 .30013 L .39007 .30162 L F
.38491 .29823 m .38499 .29501 L .38169 .29795 L .277 .103 .456 r
F
.38928 .29598 m .38499 .29501 L .38491 .29823 L .455 .241 .498 r
F
.38928 .29598 m .38936 .29277 L .38499 .29501 L F
.38905 .29918 m .38928 .29598 L .38491 .29823 L F
.39767 .30922 m .38933 .29908 L .38536 .30084 L .643 .737 .917 r
F
.39844 .3006 m .39309 .29695 L .39674 .30106 L .668 .746 .909 r
F
.39639 .2992 m .38928 .29598 L .39298 .30013 L .668 .747 .909 r
F
.39844 .3006 m .39648 .29603 L .39309 .29695 L .668 .746 .909 r
F
.39648 .29603 m .38941 .29283 L .39309 .29695 L F
.39648 .29603 m .39452 .29143 L .38941 .29283 L F
.39639 .2992 m .39442 .29458 L .38928 .29598 L .668 .747 .909 r
F
.39435 .29781 m .38928 .29598 L .38921 .29911 L .571 .333 .517 r
F
.38933 .29908 m .38931 .29906 L .38921 .29911 L .643 .737 .917 r
F
.38933 .29908 m .38921 .29911 L .38536 .30084 L F
.39435 .29781 m .38921 .29911 L .39106 .2987 L .571 .333 .517 r
F
.38921 .29911 m .38928 .29598 L .38905 .29918 L .455 .241 .498 r
F
.39667 .30695 m .39693 .30637 L .39596 .30668 L .668 .747 .909 r
F
.39718 .30629 m .3952 .30499 L .39596 .30668 L F
.40037 .31129 m .40242 .30898 L .40129 .30886 L .667 .747 .91 r
F
.40025 .31112 m .40129 .30886 L .40019 .30875 L F
.40037 .31129 m .40129 .30886 L .40025 .31112 L F
.39873 .30579 m .39787 .30607 L .39773 .3092 L .545 .308 .506 r
F
.39873 .30579 m .39773 .3092 L .39775 .3092 L F
.40003 .31082 m .39865 .30896 L .39767 .30922 L .643 .737 .917 r
F
.39853 .30899 m .39773 .30925 L .39853 .309 L .545 .308 .506 r
F
.39873 .30579 m .39775 .3092 L .39853 .30899 L F
.39775 .3092 m .39773 .30925 L .39853 .30899 L F
.39919 .30251 m .39898 .30571 L .39923 .3025 L F
.39898 .30571 m .39876 .30893 L .399 .30571 L F
.39898 .30571 m .399 .30571 L .39923 .3025 L F
.39876 .30893 m .3988 .30892 L .39923 .3025 L F
.39909 .30568 m .39836 .30379 L .39802 .30578 L .668 .747 .909 r
F
.39917 .30567 m .39916 .30566 L .39909 .30568 L F
.39916 .30566 m .39836 .30379 L .39909 .30568 L F
.40032 .30836 m .40024 .30531 L .39916 .30566 L F
.39981 .31053 m .39999 .30853 L .39907 .30882 L .667 .747 .91 r
F
.40025 .31112 m .40019 .30875 L .39981 .31053 L F
.40019 .30875 m .39997 .30877 L .39981 .31053 L F
.40072 .3113 m .39965 .30885 L .39865 .30896 L .643 .737 .917 r
F
.39996 .3056 m .39895 .30886 L .39976 .30879 L .652 .396 .519 r
F
.39965 .30885 m .39959 .30871 L .39895 .30888 L .643 .737 .917 r
F
.39965 .30885 m .39895 .30888 L .39865 .30896 L F
.40021 .30557 m .39999 .30883 L .40032 .30556 L .652 .396 .519 r
F
.39976 .30879 m .4 .30877 L .40021 .30557 L F
.39965 .30885 m .40064 .30843 L .39959 .30871 L .643 .737 .917 r
F
.401 .30883 m .40018 .30875 L .40018 .30883 L .735 .467 .523 r
F
.40072 .3113 m .40065 .30889 L .39965 .30885 L .643 .737 .917 r
F
.40065 .30889 m .40018 .30883 L .39965 .30885 L F
.40072 .3113 m .39865 .30896 L .39865 .30896 L F
.40072 .3113 m .39865 .30896 L .40003 .31082 L F
.40072 .3113 m .39767 .30922 L .39649 .30953 L F
.40026 .31158 m .40025 .31112 L .39981 .31053 L .667 .747 .91 r
F
.40026 .31158 m .39725 .3096 L .39652 .31014 L F
.39891 .32207 m .39877 .32221 L .39884 .32224 L .643 .738 .918 r
F
.39891 .32207 m .39884 .32224 L .39999 .32228 L F
.39891 .32207 m .39999 .32228 L .39999 .32228 L F
.39884 .32224 m .3998 .3227 L .39999 .32228 L F
.39916 .31406 m .39903 .3221 L .39882 .314 L .753 .483 .524 r
F
.39903 .3221 m .39844 .35859 L .39875 .32204 L F
.39903 .3221 m .39875 .32204 L .39882 .314 L F
.38202 .3185 m .38322 .3184 L .3855 .32142 L .932 .65 .484 r
F
.38322 .3184 m .38552 .32038 L .3855 .32142 L F
.36674 .31538 m .34071 .33058 L .37052 .321 L .643 .737 .917 r
F
.38809 .3162 m .3855 .32142 L .3904 .31815 L .667 .747 .91 r
F
.38202 .3185 m .38205 .3174 L .38322 .3184 L .932 .65 .484 r
F
.38809 .3162 m .38202 .3185 L .3855 .32142 L .667 .747 .91 r
F
.39118 .3206 m .36436 .3177 L .36585 .32362 L .643 .738 .918 r
F
.39602 .31144 m .39569 .31936 L .396 .3113 L .875 .7 .179 r
F
.39604 .31162 m .39612 .3122 L .39578 .31997 L F
.39569 .31936 m .39568 .31925 L .39601 .31109 L F
.3925 .32044 m .39033 .31906 L .39118 .3206 L .643 .738 .918 r
F
.39648 .31011 m .39607 .31823 L .39653 .31 L 0 0 .269 r
F
.39992 .31956 m .39554 .31933 L .39516 .32013 L .643 .738 .918 r
F
.39462 .32125 m .3925 .32044 L .39461 .32125 L F
.39992 .31956 m .39516 .32013 L .39462 .32125 L F
.39516 .32013 m .3925 .32044 L .39462 .32125 L F
.39594 .32083 m .39462 .32125 L .39591 .3215 L F
.39594 .32083 m .39591 .3215 L .39648 .32161 L F
.39992 .31956 m .39594 .32083 L .39648 .32161 L F
.39462 .32125 m .39462 .32126 L .39648 .32161 L F
.39461 .32125 m .36964 .32923 L .39648 .32161 L F
.38997 .32373 m .38373 .32986 L .38661 .33076 L .643 .737 .917 r
F
.39648 .32161 m .37546 .33416 L .3978 .32186 L .643 .738 .918 r
F
.39593 .3202 m .39466 .35711 L .39586 .32011 L .989 .724 .411 r
F
.396 .32032 m .39466 .35711 L .39593 .3202 L F
.39586 .32011 m .39466 .35711 L .39586 .3201 L F
.39578 .31997 m .39466 .35711 L .39417 .35633 L F
.39586 .3201 m .39466 .35711 L .39578 .31997 L F
.396 .32032 m .39626 .32073 L .39466 .35711 L F
.37862 .31446 m .36674 .31538 L .38196 .31733 L .643 .737 .917 r
F
.36674 .31538 m .33299 .31943 L .34071 .33058 L F
.36526 .30944 m .33299 .31943 L .36674 .31538 L F
.37122 .31806 m .36529 .31186 L .36436 .3177 L .643 .738 .918 r
F
.40026 .31158 m .39731 .31354 L .39739 .31361 L .667 .747 .91 r
F
.39758 .31348 m .39757 .31369 L .3974 .3134 L .849 .569 .514 r
F
.39757 .31369 m .3974 .31362 L .3974 .3134 L F
.40026 .31158 m .39739 .31361 L .39821 .31398 L .667 .747 .91 r
F
.40026 .31158 m .39981 .31053 L .39828 .30908 L F
.39667 .30695 m .39667 .30695 L .39666 .30696 L .668 .747 .909 r
F
.39865 .30896 m .38223 .29045 L .39767 .30922 L .643 .737 .917 r
F
.39865 .30896 m .3983 .30701 L .39739 .30726 L .667 .747 .91 r
F
.39865 .30896 m .39864 .30896 L .39865 .30896 L .643 .737 .917 r
F
.39864 .30896 m .38223 .29045 L .39865 .30896 L F
.39808 .30914 m .39828 .30908 L .39659 .30747 L .667 .747 .91 r
F
.40026 .31158 m .39828 .30908 L .39808 .30914 L F
.39722 .30655 m .39718 .30629 L .39693 .30637 L .668 .747 .909 r
F
.39738 .30643 m .39718 .30629 L .39722 .30655 L F
.39681 .30377 m .39707 .3032 L .39612 .3035 L .668 .746 .909 r
F
.39715 .30302 m .39757 .30209 L .3954 .30186 L F
.39767 .3021 m .39674 .30106 L .3954 .30186 L F
.39612 .3035 m .39592 .30221 L .39609 .30349 L F
.39592 .30221 m .3953 .3018 L .39609 .30349 L F
.39681 .30377 m .39612 .3035 L .39651 .30444 L F
.39612 .3035 m .39609 .30349 L .39609 .30351 L F
.39682 .30377 m .39707 .3032 L .39681 .30377 L F
.39752 .30326 m .39805 .30261 L .39715 .30302 L F
.39805 .30261 m .3973 .30268 L .39715 .30302 L F
.39752 .30326 m .39731 .30312 L .39682 .30377 L F
.39682 .30377 m .39681 .30377 L .3968 .30378 L F
.39836 .30379 m .39298 .30013 L .39666 .30425 L .668 .747 .909 r
F
.39819 .30276 m .39805 .30261 L .39752 .30326 L .668 .746 .909 r
F
.39805 .30261 m .39757 .30209 L .3973 .30268 L F
.39836 .30379 m .39639 .2992 L .39298 .30013 L .668 .747 .909 r
F
.3983 .30701 m .3961 .30552 L .39739 .30726 L .667 .747 .91 r
F
.39864 .30896 m .38458 .28993 L .38223 .29045 L .643 .737 .917 r
F
.3983 .30701 m .39633 .30242 L .39291 .30335 L .667 .747 .91 r
F
.39633 .30242 m .38921 .29921 L .39291 .30335 L F
.39442 .29458 m .38936 .29277 L .38928 .29598 L .571 .333 .517 r
F
.39442 .29458 m .39449 .29136 L .38936 .29277 L F
.39633 .30242 m .39435 .29781 L .38921 .29921 L .667 .747 .91 r
F
.4002 .30364 m .39639 .2992 L .39836 .30379 L .668 .747 .909 r
F
.40027 .30045 m .39648 .29603 L .39844 .3006 L .668 .746 .909 r
F
.40027 .30045 m .40015 .29572 L .39648 .29603 L F
.4002 .30364 m .40008 .29889 L .39639 .2992 L .668 .747 .909 r
F
.40002 .30212 m .39435 .29781 L .39633 .30242 L .667 .747 .91 r
F
.40008 .29889 m .39442 .29458 L .39639 .2992 L .668 .747 .909 r
F
.40015 .29572 m .39452 .29143 L .39648 .29603 L .668 .746 .909 r
F
.40015 .29572 m .40003 .29098 L .39452 .29143 L F
.40008 .29889 m .39996 .29413 L .39442 .29458 L .668 .747 .909 r
F
.40002 .30212 m .3999 .29736 L .39435 .29781 L .667 .747 .91 r
F
.39435 .29781 m .39442 .29458 L .38928 .29598 L .571 .333 .517 r
F
.3999 .29736 m .39442 .29458 L .39435 .29781 L .658 .404 .524 r
F
.39865 .30896 m .3908 .28857 L .38458 .28993 L .643 .737 .917 r
F
.39865 .30896 m .38458 .28993 L .39864 .30896 L F
.39739 .30726 m .39291 .30335 L .39659 .30747 L .667 .747 .91 r
F
.3961 .30552 m .39291 .30335 L .39739 .30726 L F
.39828 .30908 m .39739 .30726 L .39659 .30747 L F
.39981 .31053 m .39865 .30896 L .39828 .30908 L F
.39865 .30896 m .39739 .30726 L .39828 .30908 L F
.39901 .3057 m .3988 .30891 L .39909 .30568 L .545 .308 .506 r
F
.39601 .31109 m .396 .31129 L .396 .31129 L .875 .7 .179 r
F
.39571 .31835 m .39568 .31925 L .39565 .31909 L F
.39634 .31055 m .396 .31129 L .39565 .31909 L 0 0 .269 r
F
.39532 .31487 m .3904 .31815 L .39338 .31965 L .667 .747 .91 r
F
.39428 .31926 m .39369 .31817 L .39033 .31906 L .643 .738 .918 r
F
.39635 .31038 m .39565 .31909 L .39593 .31851 L 0 0 .269 r
F
.39992 .31956 m .39536 .31855 L .39428 .31926 L .643 .738 .918 r
F
.39536 .31855 m .39369 .31817 L .39428 .31926 L F
.39725 .3096 m .39659 .30747 L .39513 .30821 L .667 .747 .91 r
F
.40026 .31158 m .398 .30905 L .39725 .3096 L F
.39765 .30926 m .39765 .30931 L .39773 .3092 L .339 .143 .462 r
F
.39765 .30931 m .39773 .30925 L .39773 .3092 L F
.39775 .3092 m .39773 .3092 L .39773 .30925 L .545 .308 .506 r
F
.39758 .3093 m .39758 .30937 L .39765 .30926 L .339 .143 .462 r
F
.39758 .30937 m .39765 .30931 L .39765 .30926 L F
.39693 .32134 m .39648 .32161 L .39787 .32178 L .643 .738 .918 r
F
.3965 .32093 m .39546 .35777 L .3964 .32085 L .929 .648 .486 r
F
.39626 .32073 m .39546 .35777 L .39466 .35711 L F
.3964 .32085 m .39546 .35777 L .39626 .32073 L F
.39662 .32103 m .39546 .35777 L .3965 .32093 L F
.39662 .32103 m .39705 .32139 L .39546 .35777 L F
.39755 .30933 m .39701 .31745 L .39758 .3093 L .339 .143 .462 r
F
.39635 .31038 m .39593 .31851 L .39645 .31017 L 0 0 .269 r
F
.39593 .31851 m .39601 .31834 L .39645 .31017 L F
.39992 .31956 m .39618 .318 L .39536 .31855 L .643 .738 .918 r
F
.37974 .30662 m .36949 .29824 L .36619 .3036 L .643 .737 .917 r
F
.38157 .3037 m .36949 .29824 L .37974 .30662 L F
.38153 .30439 m .38112 .30443 L .37951 .3078 L 0 0 .351 r
F
.38112 .30443 m .37953 .30695 L .37951 .3078 L F
.37951 .3078 m .37953 .30695 L .37937 .30792 L 0 0 .1 r
F
.37899 .31016 m .36619 .3036 L .36526 .30944 L .643 .737 .917 r
F
.37952 .30702 m .36619 .3036 L .37899 .31016 L F
.37951 .3078 m .37937 .30792 L .37892 .31146 L 0 0 .1 r
F
.37937 .30792 m .37894 .31045 L .37892 .31146 L F
.37892 .31146 m .37894 .31045 L .37922 .3116 L .927 .718 .232 r
F
.3866 .31393 m .38202 .3185 L .38809 .3162 L .667 .747 .91 r
F
.37978 .31511 m .38057 .31517 L .38202 .3185 L .986 .716 .413 r
F
.38057 .31517 m .38205 .3174 L .38202 .3185 L F
.37978 .31511 m .3798 .31402 L .38057 .31517 L F
.3866 .31393 m .37978 .31511 L .38202 .3185 L .667 .747 .91 r
F
.39416 .31389 m .3904 .31815 L .39532 .31487 L F
.39416 .31389 m .38809 .3162 L .3904 .31815 L F
.39342 .31275 m .38809 .3162 L .39416 .31389 L F
.39342 .31275 m .3866 .31393 L .38809 .3162 L F
.38603 .3115 m .37978 .31511 L .3866 .31393 L F
.37757 .31066 m .36526 .30944 L .37968 .31383 L .643 .737 .917 r
F
.37892 .31146 m .37922 .3116 L .37978 .31511 L .927 .718 .232 r
F
.37922 .3116 m .3798 .31402 L .37978 .31511 L F
.38603 .3115 m .37892 .31146 L .37978 .31511 L .667 .747 .91 r
F
.39314 .31154 m .3866 .31393 L .39342 .31275 L F
.39314 .31154 m .38603 .3115 L .3866 .31393 L F
.39335 .31032 m .38603 .3115 L .39314 .31154 L F
.38644 .30906 m .37892 .31146 L .38603 .3115 L F
.39335 .31032 m .38644 .30906 L .38603 .3115 L F
.38644 .30906 m .37951 .3078 L .37892 .31146 L F
.38779 .30679 m .37951 .3078 L .38644 .30906 L F
.38779 .30679 m .38153 .30439 L .37951 .3078 L F
.39547 .31771 m .37408 .30204 L .3686 .30652 L .643 .738 .918 r
F
.39607 .31823 m .39611 .31813 L .39653 .31 L 0 0 .269 r
F
.39653 .31 m .39611 .31813 L .39618 .318 L F
.39644 .31032 m .39601 .31834 L .39647 .31026 L F
.39601 .31834 m .39604 .31829 L .39648 .31011 L F
.39725 .3096 m .39652 .31014 L .39652 .31014 L .667 .747 .91 r
F
.39731 .30956 m .39652 .31014 L .39618 .318 L .339 .143 .462 r
F
.39732 .30948 m .39618 .318 L .39682 .31757 L F
.39732 .30948 m .39682 .31757 L .39755 .30933 L F
.39992 .31956 m .39691 .31752 L .39618 .318 L .643 .738 .918 r
F
.39682 .31757 m .39701 .31745 L .39755 .30933 L .339 .143 .462 r
F
.39701 .31745 m .39704 .31743 L .39758 .3093 L F
.39765 .30931 m .3971 .31739 L .39773 .30925 L F
.3971 .31739 m .39716 .31735 L .39773 .3092 L F
.39853 .309 m .39773 .30925 L .39738 .3172 L .545 .308 .506 r
F
.40026 .31158 m .39814 .31407 L .39925 .31423 L .667 .747 .91 r
F
.39853 .309 m .39738 .3172 L .39804 .31703 L .545 .308 .506 r
F
.39773 .3092 m .39716 .31735 L .39738 .3172 L .339 .143 .462 r
F
.38193 .30344 m .37496 .29375 L .36949 .29824 L .643 .737 .917 r
F
.38489 .30103 m .37496 .29375 L .38193 .30344 L F
.38483 .30146 m .38442 .30142 L .38153 .30439 L .277 .103 .456 r
F
.38442 .30142 m .38154 .30375 L .38153 .30439 L F
.38153 .30439 m .38154 .30375 L .38112 .30443 L 0 0 .351 r
F
.39403 .30919 m .38644 .30906 L .39335 .31032 L .667 .747 .91 r
F
.39403 .30919 m .38779 .30679 L .38644 .30906 L F
.38999 .30484 m .38153 .30439 L .38779 .30679 L F
.38999 .30484 m .38483 .30146 L .38153 .30439 L F
.39481 .3161 m .38136 .29874 L .37408 .30204 L .643 .738 .918 r
F
.40026 .31158 m .39925 .31423 L .40033 .31439 L .667 .747 .91 r
F
.40018 .30883 m .39961 .31684 L .40018 .30883 L .652 .396 .519 r
F
.39758 .30937 m .39704 .31743 L .39765 .30931 L .339 .143 .462 r
F
.39704 .31743 m .3971 .31739 L .39765 .30926 L F
.3967 .31738 m .39757 .31693 L .39612 .31699 L .643 .738 .918 r
F
.39992 .31956 m .39773 .31711 L .3967 .31738 L F
.39773 .31711 m .39757 .31693 L .3967 .31738 L F
.39876 .30893 m .39823 .31698 L .3988 .30892 L .545 .308 .506 r
F
.39992 .31956 m .39693 .32134 L .39787 .32178 L .643 .738 .918 r
F
.39705 .32139 m .39662 .3583 L .39546 .35777 L .849 .569 .514 r
F
.39726 .32149 m .39662 .3583 L .39705 .32139 L F
.3974 .32156 m .39662 .3583 L .39726 .32149 L F
.39758 .32164 m .3982 .32194 L .39662 .3583 L F
.39992 .31956 m .3978 .32186 L .39891 .32207 L .643 .738 .918 r
F
.39758 .32164 m .39662 .3583 L .3974 .32156 L .849 .569 .514 r
F
.39823 .31698 m .39825 .31697 L .3988 .30892 L .545 .308 .506 r
F
.3988 .30891 m .39825 .31697 L .39887 .30889 L F
.39825 .31697 m .39831 .31696 L .39887 .30889 L F
.39895 .30886 m .39831 .31696 L .39861 .31688 L F
.39887 .30889 m .39831 .31696 L .39895 .30886 L F
.39106 .2987 m .38921 .29911 L .38921 .29921 L .571 .333 .517 r
F
.38921 .29921 m .38921 .29911 L .38905 .29918 L .455 .241 .498 r
F
.38536 .30084 m .38223 .29045 L .37496 .29375 L .643 .737 .917 r
F
.38931 .29906 m .38223 .29045 L .38536 .30084 L F
.38921 .29921 m .38905 .29918 L .38483 .30146 L .455 .241 .498 r
F
.38905 .29918 m .38484 .30107 L .38483 .30146 L F
.38483 .30146 m .38484 .30107 L .38442 .30142 L .277 .103 .456 r
F
.39652 .31014 m .39513 .30821 L .39403 .30919 L .667 .747 .91 r
F
.39652 .31014 m .39403 .30919 L .3957 .31075 L F
.39588 .31155 m .39335 .31032 L .39314 .31154 L F
.39591 .31149 m .39335 .31032 L .39588 .31155 L F
.39513 .30821 m .38779 .30679 L .39403 .30919 L F
.39513 .30821 m .38999 .30484 L .38779 .30679 L F
.39659 .30747 m .38999 .30484 L .39513 .30821 L F
.39659 .30747 m .39291 .30335 L .38999 .30484 L F
.39291 .30335 m .38483 .30146 L .38999 .30484 L F
.39291 .30335 m .38921 .29921 L .38483 .30146 L F
.39757 .31693 m .38996 .29688 L .38136 .29874 L .643 .738 .918 r
F
.39853 .30899 m .39804 .31703 L .39876 .30893 L .545 .308 .506 r
F
.39992 .31956 m .39861 .31688 L .39773 .31711 L .643 .738 .918 r
F
.39804 .31703 m .3958 .35339 L .39823 .31698 L .545 .308 .506 r
F
.39804 .31703 m .39823 .31698 L .39876 .30893 L F
.39992 .31956 m .39874 .31688 L .39861 .31688 L .643 .738 .918 r
F
.39773 .31711 m .39861 .31688 L .39757 .31693 L F
.39852 .34953 m .39851 .34971 L .39871 .32204 L .753 .483 .524 r
F
.39852 .34953 m .39871 .32204 L .39871 .32204 L F
.39992 .31956 m .39891 .32207 L .39999 .32228 L .643 .738 .918 r
F
.39871 .32204 m .39844 .35859 L .39862 .32202 L .753 .483 .524 r
F
.39976 .30879 m .39895 .30886 L .39861 .31688 L .652 .396 .519 r
F
.39992 .31956 m .39984 .31683 L .39874 .31688 L .643 .738 .918 r
F
.39927 .31685 m .39861 .31688 L .39704 .35301 L .652 .396 .519 r
F
.39976 .30879 m .39861 .31688 L .39927 .31685 L F
.398 .30905 m .39659 .30747 L .39725 .3096 L .667 .747 .91 r
F
.3988 .30891 m .39887 .30889 L .39909 .30568 L .545 .308 .506 r
F
.39909 .30568 m .39887 .30889 L .39895 .30886 L F
.39865 .30896 m .39876 .30892 L .39898 .30571 L F
.39895 .30853 m .39899 .30695 L .3983 .30701 L .667 .747 .91 r
F
.39996 .3056 m .39909 .30568 L .39895 .30886 L .652 .396 .519 r
F
.39907 .30882 m .39899 .30695 L .39895 .30853 L .667 .747 .91 r
F
.39996 .3056 m .39976 .30879 L .40021 .30557 L .652 .396 .519 r
F
.39907 .30882 m .40014 .30686 L .39899 .30695 L .667 .747 .91 r
F
.39999 .30853 m .40014 .30686 L .39907 .30882 L F
.39916 .30566 m .4002 .30364 L .39836 .30379 L .668 .747 .909 r
F
.40024 .30531 m .4002 .30364 L .39916 .30566 L F
.39819 .30597 m .39909 .30568 L .39802 .30578 L F
.40014 .30686 m .39633 .30242 L .3983 .30701 L .667 .747 .91 r
F
.40014 .30686 m .40002 .30212 L .39633 .30242 L F
.39996 .29413 m .39449 .29136 L .39442 .29458 L .658 .404 .524 r
F
.39996 .29413 m .40002 .29091 L .39449 .29136 L F
.3999 .29736 m .39996 .29413 L .39442 .29458 L F
.39959 .30871 m .40007 .28826 L .3908 .28857 L .643 .737 .917 r
F
.39907 .30882 m .3983 .30701 L .39863 .30889 L .667 .747 .91 r
F
.39895 .30886 m .39863 .30889 L .39865 .30896 L F
.39907 .30882 m .39863 .30889 L .39895 .30886 L F
.39909 .30885 m .39907 .30882 L .39895 .30886 L F
.39865 .30896 m .39876 .30893 L .39876 .30892 L .545 .308 .506 r
F
.39959 .30871 m .3908 .28857 L .39865 .30896 L .643 .737 .917 r
F
.39732 .30948 m .39653 .31 L .39652 .31014 L .339 .143 .462 r
F
.39732 .30948 m .39652 .31014 L .39731 .30956 L F
.39725 .3096 m .39688 .30936 L .39652 .31014 L .667 .747 .91 r
F
.39688 .30936 m .39513 .30821 L .39652 .31014 L F
.39645 .31017 m .39644 .31032 L .39648 .31011 L 0 0 .269 r
F
.39644 .31032 m .39647 .31026 L .39648 .31011 L F
.39621 .31084 m .39652 .31014 L .3957 .31075 L .667 .747 .91 r
F
.39652 .31014 m .39652 .31014 L .39621 .31084 L F
.39874 .31688 m .39925 .29657 L .38996 .29688 L .643 .738 .918 r
F
.39999 .30883 m .39946 .31684 L .4001 .30883 L .652 .396 .519 r
F
.39946 .31684 m .39954 .31684 L .4001 .30883 L F
.39961 .31684 m .39961 .31684 L .40018 .30883 L F
.40018 .30883 m .39961 .31684 L .39984 .31683 L F
.39999 .32228 m .39999 .32228 L .39999 .32228 L .643 .738 .918 r
F
.39903 .3221 m .39999 .32228 L .39844 .35859 L .753 .483 .524 r
F
.4001 .30876 m .39954 .31684 L .40018 .30875 L .652 .396 .519 r
F
.39954 .31684 m .39704 .35301 L .39961 .31684 L F
.39954 .31684 m .39961 .31684 L .40018 .30875 L F
.40072 .3113 m .40036 .31128 L .4004 .31134 L .643 .737 .917 r
F
.40026 .31158 m .40047 .31143 L .40043 .31137 L .667 .747 .91 r
F
.40072 .3113 m .40044 .31139 L .40048 .31144 L .643 .737 .917 r
F
.40026 .31158 m .40043 .31137 L .40037 .31129 L .667 .747 .91 r
F
.40072 .3113 m .40031 .31121 L .40036 .31128 L .643 .737 .917 r
F
.40072 .3113 m .40022 .31109 L .40031 .31121 L F
.40026 .31158 m .40037 .31129 L .40025 .31112 L .667 .747 .91 r
F
.40211 .31413 m .40211 .31415 L .40211 .31415 L .484 .259 .497 r
F
.40196 .31414 m .40191 .3142 L .40198 .31418 L .643 .737 .917 r
F
.40072 .3113 m .40081 .31424 L .40196 .31414 L F
.40026 .31158 m .40148 .31442 L .40229 .31406 L .667 .747 .91 r
F
.40026 .31158 m .40054 .31153 L .40051 .31148 L F
.40026 .31158 m .40051 .31148 L .40047 .31143 L F
.40072 .3113 m .4004 .31134 L .40044 .31139 L .643 .737 .917 r
F
.40026 .31158 m .40058 .31158 L .40054 .31153 L .667 .747 .91 r
F
.40026 .31158 m .40063 .31164 L .40058 .31158 L F
.40026 .31158 m .40088 .31199 L .40071 .31175 L F
.40026 .31158 m .40365 .31573 L .40212 .31366 L F
.40072 .3113 m .40053 .31151 L .4006 .3116 L .643 .737 .917 r
F
.40026 .31158 m .40212 .31366 L .40088 .31199 L .667 .747 .91 r
F
.40094 .31423 m .40211 .31415 L .40094 .31431 L .631 .379 .518 r
F
.4014 .31424 m .40038 .31627 L .40221 .31612 L .667 .747 .91 r
F
.40061 .31426 m .40061 .31435 L .40056 .31427 L .631 .379 .518 r
F
.40061 .31435 m .40056 .31436 L .40056 .31427 L F
.40033 .31439 m .40038 .31627 L .4014 .31424 L .667 .747 .91 r
F
.40056 .31427 m .4005 .32223 L .40033 .31429 L .631 .379 .518 r
F
.39999 .32228 m .40056 .34197 L .40107 .32218 L .643 .738 .918 r
F
.4005 .32223 m .40024 .35836 L .40032 .32225 L .631 .379 .518 r
F
.4005 .32223 m .40032 .32225 L .40033 .31429 L F
.40061 .31435 m .40054 .32223 L .40056 .31436 L F
.40229 .31406 m .40219 .31607 L .40365 .31573 L .667 .747 .91 r
F
.40244 .3141 m .40254 .31423 L .40274 .31407 L .643 .737 .917 r
F
.403 .31472 m .40311 .31499 L .40325 .31431 L F
.40274 .31407 m .403 .31472 L .40315 .31404 L F
.403 .31472 m .40325 .31431 L .40315 .31404 L F
.40249 .31398 m .40323 .3137 L .40289 .32169 L .484 .259 .497 r
F
.403 .32165 m .40283 .32174 L .40322 .3218 L .643 .738 .918 r
F
.40283 .32174 m .40217 .32209 L .40249 .322 L F
.40283 .32174 m .40249 .322 L .40322 .3218 L F
.40334 .31361 m .40313 .32151 L .40332 .31362 L .286 .104 .449 r
F
.40241 .32207 m .40269 .32267 L .4031 .322 L .643 .738 .918 r
F
.40217 .32209 m .40225 .32218 L .40241 .32207 L F
.40225 .32218 m .40269 .32267 L .40241 .32207 L F
.40249 .322 m .4031 .322 L .40322 .3218 L F
.40217 .32209 m .40241 .32207 L .40249 .322 L F
.40241 .32207 m .4031 .322 L .40249 .322 L F
.40315 .31404 m .40325 .31431 L .40331 .31421 L .643 .737 .917 r
F
.40333 .31356 m .40332 .31362 L .40323 .31365 L .286 .104 .449 r
F
.40332 .31362 m .40311 .32152 L .40323 .3137 L F
.40332 .31362 m .40323 .3137 L .40323 .31365 L F
.40311 .32152 m .40303 .32159 L .40323 .31365 L F
.40323 .31365 m .40303 .32159 L .40289 .32169 L F
.40313 .32151 m .40311 .32152 L .40332 .31362 L F
.40249 .31398 m .40289 .32169 L .40229 .32192 L .484 .259 .497 r
F
.40349 .3135 m .40324 .32142 L .40338 .31358 L .286 .104 .449 r
F
.40094 .31431 m .40211 .31415 L .40177 .32212 L .631 .379 .518 r
F
.40177 .32212 m .40187 .32401 L .40217 .32209 L .643 .738 .918 r
F
.40107 .32218 m .40115 .32236 L .40177 .32212 L F
.40115 .32236 m .40187 .32401 L .40177 .32212 L F
.40137 .32287 m .40128 .32496 L .40187 .32401 L F
.40128 .32496 m .40056 .34197 L .40187 .32401 L F
.40177 .32212 m .40138 .35787 L .40024 .35836 L .484 .259 .497 r
F
.40211 .31415 m .40197 .32204 L .40177 .32212 L F
.40217 .32209 m .40187 .32401 L .40269 .32267 L .643 .738 .918 r
F
.40094 .31431 m .40177 .32212 L .40081 .32221 L .631 .379 .518 r
F
.40054 .32223 m .4005 .32223 L .40056 .31427 L F
.40094 .31423 m .40081 .32221 L .40061 .31426 L F
.40081 .32221 m .40024 .35836 L .40054 .32223 L F
.40081 .32221 m .40054 .32223 L .40061 .31426 L F
.46236 .32863 m .50303 .32581 L .46941 .31828 L .644 .737 .916 r
F
.43156 .3242 m .46202 .33693 L .46913 .32656 L .643 .737 .917 r
F
.43156 .3242 m .46913 .32656 L .43503 .31895 L F
.41928 .32057 m .43432 .3272 L .43547 .32142 L .643 .738 .918 r
F
.40211 .31415 m .40198 .32204 L .40211 .31415 L .484 .259 .497 r
F
.40198 .32204 m .40197 .32204 L .40211 .31415 L F
.40398 .31726 m .4044 .31244 L .40407 .32043 L 0 0 .327 r
F
.4044 .31244 m .40436 .31382 L .40409 .3204 L F
.4044 .31244 m .40409 .3204 L .40407 .32043 L F
.40411 .32013 m .4041 .32024 L .40442 .3124 L 0 0 .006 r
F
.40442 .3124 m .4041 .32024 L .40409 .3204 L F
.40399 .31301 m .40398 .31311 L .40398 .31311 L 0 0 .327 r
F
.40072 .3113 m .40381 .3134 L .4042 .31275 L .643 .737 .917 r
F
.40349 .3135 m .40338 .31358 L .40338 .31352 L .286 .104 .449 r
F
.40243 .314 m .40323 .31365 L .40331 .31358 L .667 .747 .91 r
F
.40072 .3113 m .403 .31387 L .4037 .31333 L .643 .737 .917 r
F
.40228 .31406 m .40212 .32199 L .40211 .31413 L .484 .259 .497 r
F
.40209 .322 m .40177 .32212 L .40217 .32209 L .643 .738 .918 r
F
.40212 .32199 m .40138 .35787 L .40198 .32204 L .484 .259 .497 r
F
.40212 .32199 m .40198 .32204 L .40211 .31413 L F
.40635 .32037 m .40869 .32151 L .4126 .32116 L .643 .738 .918 r
F
.40398 .31311 m .40373 .32098 L .40365 .32111 L 0 0 .327 r
F
.40398 .31311 m .40373 .32098 L .40398 .31311 L F
.40415 .32064 m .40986 .32413 L .40883 .32273 L .667 .747 .91 r
F
.40349 .3135 m .40398 .31311 L .40365 .32111 L .286 .104 .449 r
F
.40365 .32111 m .40322 .3218 L .40365 .32111 L .643 .738 .918 r
F
.40349 .3135 m .40365 .32111 L .40324 .32142 L .286 .104 .449 r
F
.40324 .32142 m .40313 .32151 L .40334 .31361 L F
.40324 .32142 m .40334 .31361 L .40338 .31358 L F
.40249 .31397 m .40229 .32192 L .40228 .31407 L .484 .259 .497 r
F
.40209 .322 m .40217 .32209 L .403 .32165 L .643 .738 .918 r
F
.40229 .32192 m .40138 .35787 L .40212 .32199 L .484 .259 .497 r
F
.40229 .32192 m .40212 .32199 L .40228 .31407 L F
.40744 .31995 m .4126 .32116 L .40955 .32006 L .643 .738 .918 r
F
.40373 .32098 m .40373 .32098 L .40398 .31311 L 0 0 .327 r
F
.40445 .3121 m .40416 .31953 L .40412 .31999 L 0 0 .006 r
F
.40445 .3121 m .40412 .31999 L .40443 .31226 L F
.40405 .313 m .40379 .32089 L .40404 .31302 L 0 0 .327 r
F
.40379 .32089 m .40378 .3209 L .40404 .31302 L F
.4046 .30856 m .40456 .30906 L .40484 .30857 L .668 .747 .909 r
F
.40316 .30964 m .40636 .30925 L .40521 .30827 L .667 .747 .91 r
F
.40392 .31018 m .40636 .30925 L .40316 .30964 L F
.40072 .3113 m .40381 .31031 L .40317 .30983 L .643 .737 .917 r
F
.40446 .3198 m .40625 .32036 L .40557 .31985 L .643 .738 .918 r
F
.40404 .31291 m .40378 .3209 L .40399 .31301 L 0 0 .327 r
F
.40378 .3209 m .40373 .32098 L .40399 .31301 L F
.40365 .32111 m .40533 .32181 L .40423 .32067 L .643 .738 .918 r
F
.40365 .32111 m .40423 .32067 L .40404 .32047 L F
.40365 .32111 m .40423 .32067 L .40365 .32111 L F
.40413 .31287 m .40385 .32078 L .40405 .313 L 0 0 .327 r
F
.40385 .32078 m .4026 .35648 L .40379 .32089 L F
.40385 .32078 m .40379 .32089 L .40405 .313 L F
.40249 .31397 m .40323 .3137 L .40249 .31398 L .484 .259 .497 r
F
.40248 .30922 m .40246 .30939 L .40258 .30925 L .814 .537 .519 r
F
.40072 .3113 m .40317 .30983 L .40266 .30945 L .643 .737 .917 r
F
.40072 .3113 m .40266 .30945 L .40247 .30939 L F
.4013 .30884 m .40372 .30751 L .40199 .30703 L .667 .747 .91 r
F
.40132 .30884 m .40372 .30751 L .4013 .30884 L F
.40242 .30898 m .40372 .30751 L .40129 .30886 L F
.4025 .30579 m .40527 .30505 L .40378 .30429 L .668 .747 .909 r
F
.40394 .30594 m .40527 .30505 L .4025 .30579 L F
.40146 .30568 m .40148 .30568 L .40169 .30252 L .735 .467 .523 r
F
.40262 .30282 m .40243 .30598 L .40282 .30288 L .814 .537 .519 r
F
.40262 .30282 m .40169 .30252 L .40156 .30569 L F
.40262 .30282 m .40156 .30569 L .40243 .30598 L F
.40134 .30567 m .40378 .30429 L .40205 .30381 L .668 .747 .909 r
F
.4025 .30579 m .40378 .30429 L .40134 .30567 L F
.40072 .3113 m .40247 .30939 L .40161 .30907 L .643 .737 .917 r
F
.40026 .31158 m .40033 .31439 L .4014 .31424 L .667 .747 .91 r
F
.40072 .3113 m .40122 .31244 L .4014 .31268 L .643 .737 .917 r
F
.40119 .30565 m .40032 .30556 L .40018 .30875 L .735 .467 .523 r
F
.40119 .30565 m .40018 .30875 L .401 .30883 L F
.40111 .30246 m .40046 .30239 L .40032 .30556 L F
.4 .30877 m .4001 .30876 L .40032 .30556 L .652 .396 .519 r
F
.40032 .30556 m .4001 .30876 L .40018 .30875 L F
.40144 .30568 m .40122 .30898 L .40146 .30568 L .735 .467 .523 r
F
.40148 .30568 m .40126 .30886 L .40156 .30569 L F
.40019 .30875 m .40199 .30703 L .40014 .30686 L .667 .747 .91 r
F
.39999 .30883 m .4001 .30883 L .4001 .30876 L .652 .396 .519 r
F
.39999 .30883 m .4001 .30876 L .4 .30877 L F
.40129 .30886 m .40199 .30703 L .40019 .30875 L .667 .747 .91 r
F
.40046 .30239 m .40021 .30557 L .40032 .30556 L .652 .396 .519 r
F
.40042 .30239 m .40021 .30557 L .40046 .30239 L F
.40025 .30556 m .40205 .30381 L .4002 .30364 L .668 .747 .909 r
F
.40134 .30567 m .40205 .30381 L .40025 .30556 L F
.40175 .30105 m .40166 .30251 L .40169 .30252 L .735 .467 .523 r
F
.40139 .30248 m .40169 .30252 L .40142 .30243 L .668 .746 .909 r
F
.40142 .30243 m .40382 .3011 L .4021 .30062 L F
.40396 .30222 m .40299 .3015 L .40293 .30292 L .912 .629 .494 r
F
.40293 .30292 m .4053 .30185 L .40252 .30263 L .668 .746 .909 r
F
.4033 .30319 m .40345 .30309 L .40293 .30292 L F
.40345 .30309 m .4053 .30185 L .40293 .30292 L F
.40241 .30275 m .40293 .30292 L .40252 .30263 L F
.40252 .30263 m .4053 .30185 L .40382 .3011 L F
.4053 .30185 m .40727 .29703 L .40382 .3011 L F
.40382 .3011 m .40383 .29607 L .4021 .30062 L F
.40382 .3011 m .40727 .29703 L .40383 .29607 L F
.4021 .30062 m .40015 .29572 L .40027 .30045 L F
.4021 .30062 m .40383 .29607 L .40015 .29572 L F
.40373 .30291 m .40645 .30283 L .4053 .30185 L F
.40413 .30372 m .40645 .30283 L .40373 .30291 L F
.40378 .30429 m .40378 .29924 L .40205 .30381 L .668 .747 .909 r
F
.40462 .3047 m .40471 .30488 L .40482 .30357 L .99 .735 .374 r
F
.40418 .30383 m .40718 .30397 L .40413 .30372 L .668 .746 .909 r
F
.40407 .30374 m .40418 .30383 L .40413 .30372 L F
.40413 .30372 m .40718 .30397 L .40645 .30283 L F
.40645 .30283 m .41024 .29855 L .4053 .30185 L F
.4053 .30185 m .41024 .29855 L .40727 .29703 L F
.40378 .30429 m .40725 .30021 L .40378 .29924 L .668 .747 .909 r
F
.40205 .30381 m .40008 .29889 L .4002 .30364 L F
.40205 .30381 m .40378 .29924 L .40008 .29889 L F
.40727 .29703 m .40556 .2915 L .40383 .29607 L .668 .746 .909 r
F
.40727 .29703 m .41073 .29295 L .40556 .2915 L F
.40025 .30557 m .40032 .30556 L .40025 .30556 L .668 .747 .909 r
F
.40199 .30703 m .40002 .30212 L .40014 .30686 L .667 .747 .91 r
F
.40199 .30703 m .40372 .30246 L .40002 .30212 L F
.40383 .29607 m .40003 .29098 L .40015 .29572 L .668 .746 .909 r
F
.40383 .29607 m .40556 .2915 L .40003 .29098 L F
.40725 .30021 m .40553 .29465 L .40378 .29924 L .668 .747 .909 r
F
.41024 .29855 m .41073 .29295 L .40727 .29703 L .668 .746 .909 r
F
.41024 .29855 m .41519 .29524 L .41073 .29295 L F
.40725 .30021 m .41073 .29611 L .40553 .29465 L .668 .747 .909 r
F
.40378 .29924 m .39996 .29413 L .40008 .29889 L F
.40378 .29924 m .40553 .29465 L .39996 .29413 L F
.41073 .29611 m .41079 .29289 L .40559 .29143 L .799 .523 .521 r
F
.40718 .30397 m .41252 .30052 L .40645 .30283 L .668 .746 .909 r
F
.40645 .30283 m .41252 .30052 L .41024 .29855 L F
.40449 .30444 m .40492 .30436 L .40418 .30383 L F
.40492 .30436 m .40718 .30397 L .40418 .30383 L F
.40449 .30444 m .40476 .30498 L .40481 .30438 L F
.40475 .30517 m .40744 .30519 L .40481 .30438 L F
.40527 .30505 m .40725 .30021 L .40378 .30429 L .668 .747 .909 r
F
.40527 .30505 m .41023 .30173 L .40725 .30021 L F
.40719 .30343 m .40547 .29788 L .40372 .30246 L .667 .747 .91 r
F
.41252 .30052 m .41519 .29524 L .41024 .29855 L .668 .746 .909 r
F
.41023 .30173 m .41073 .29611 L .40725 .30021 L .668 .747 .909 r
F
.41252 .30052 m .41861 .29819 L .41519 .29524 L .668 .746 .909 r
F
.41023 .30173 m .41521 .2984 L .41073 .29611 L .668 .747 .909 r
F
.40719 .30343 m .41068 .29933 L .40547 .29788 L .667 .747 .91 r
F
.40372 .30246 m .3999 .29736 L .40002 .30212 L F
.40372 .30246 m .40547 .29788 L .3999 .29736 L F
.40553 .29465 m .40559 .29143 L .40002 .29091 L .731 .465 .526 r
F
.41073 .29611 m .40559 .29143 L .40553 .29465 L .799 .523 .521 r
F
.41068 .29933 m .41073 .29611 L .40553 .29465 L F
.40553 .29465 m .40002 .29091 L .39996 .29413 L .731 .465 .526 r
F
.40547 .29788 m .40553 .29465 L .39996 .29413 L F
.41068 .29933 m .40553 .29465 L .40547 .29788 L .799 .523 .521 r
F
.40547 .29788 m .39996 .29413 L .3999 .29736 L .731 .465 .526 r
F
.40065 .30873 m .40939 .28955 L .40007 .28826 L .643 .737 .917 r
F
.401 .30883 m .40018 .30883 L .40099 .30894 L .735 .467 .523 r
F
.401 .30883 m .40099 .30894 L .40123 .30886 L F
.40072 .3113 m .40161 .30907 L .40142 .30901 L .643 .737 .917 r
F
.40072 .3113 m .40142 .30901 L .40065 .30889 L F
.39992 .31956 m .40196 .31733 L .40108 .31701 L .643 .738 .918 r
F
.39992 .31956 m .40108 .31701 L .40094 .31699 L F
.40401 .31025 m .40642 .31051 L .40479 .30998 L .667 .747 .91 r
F
.40642 .31051 m .4071 .3104 L .40479 .30998 L F
.41407 .30764 m .42156 .30527 L .4145 .30523 L .668 .746 .909 r
F
.40723 .3064 m .41407 .30764 L .4145 .30523 L F
.40655 .30752 m .41407 .30764 L .40723 .3064 L F
.41409 .31087 m .42163 .30848 L .41453 .30844 L .668 .747 .909 r
F
.40721 .30961 m .41409 .31087 L .41453 .30844 L F
.4145 .30523 m .42156 .30527 L .42079 .30162 L .668 .746 .909 r
F
.42163 .30848 m .42167 .30527 L .42089 .3016 L .907 .7 .196 r
F
.40721 .30961 m .41453 .30844 L .40742 .3084 L .668 .747 .909 r
F
.42163 .30848 m .42089 .3016 L .42085 .30481 L .907 .7 .196 r
F
.41453 .30844 m .42163 .30848 L .42085 .30481 L .668 .747 .909 r
F
.42159 .31169 m .42163 .30848 L .42085 .30481 L .907 .7 .196 r
F
.41453 .30844 m .42085 .30481 L .414 .30599 L .668 .747 .909 r
F
.40742 .3084 m .41453 .30844 L .414 .30599 L F
.42159 .31169 m .42085 .30481 L .42081 .30803 L .907 .7 .196 r
F
.41448 .31165 m .42159 .31169 L .42081 .30803 L .667 .747 .91 r
F
.41448 .31165 m .42081 .30803 L .41395 .30921 L F
.4071 .3104 m .41248 .30693 L .40636 .30925 L F
.4071 .3104 m .41395 .30921 L .41248 .30693 L F
.4145 .30523 m .42079 .30162 L .41398 .30279 L .668 .746 .909 r
F
.41398 .30279 m .42079 .30162 L .41861 .29819 L F
.414 .30599 m .42085 .30481 L .41866 .30138 L .668 .747 .909 r
F
.42081 .30803 m .42085 .30481 L .41866 .30138 L .987 .714 .396 r
F
.41395 .30921 m .41862 .3046 L .41248 .30693 L .667 .747 .91 r
F
.41395 .30921 m .42081 .30803 L .41862 .3046 L F
.42081 .30803 m .41866 .30138 L .41862 .3046 L .987 .714 .396 r
F
.40445 .3101 m .43493 .30719 L .43131 .30147 L .643 .737 .917 r
F
.40072 .3113 m .40417 .31089 L .40381 .31031 L F
.4043 .31094 m .40392 .31018 L .40391 .31038 L .99 .735 .374 r
F
.4043 .31094 m .40391 .31038 L .40428 .31112 L F
.40426 .31086 m .40475 .31078 L .40396 .31027 L .667 .747 .91 r
F
.40417 .31089 m .40453 .31084 L .40391 .31038 L .643 .737 .917 r
F
.40417 .31089 m .40391 .31038 L .40381 .31031 L F
.43558 .31071 m .46941 .31828 L .47193 .30677 L .644 .737 .916 r
F
.43558 .31071 m .47193 .30677 L .43672 .30493 L F
.40737 .31161 m .41448 .31165 L .41395 .30921 L .667 .747 .91 r
F
.40737 .31161 m .41395 .30921 L .4071 .3104 L F
.40453 .31084 m .43619 .31316 L .43493 .30719 L .643 .737 .917 r
F
.40072 .3113 m .40448 .3115 L .40417 .31089 L F
.40429 .31113 m .40358 .31838 L .40389 .31899 L .99 .735 .374 r
F
.4043 .31094 m .40428 .31112 L .40429 .31113 L F
.40428 .31112 m .40358 .31838 L .40429 .31113 L F
.40417 .31089 m .40548 .31155 L .40453 .31084 L .643 .737 .917 r
F
.40445 .31145 m .40449 .31152 L .4045 .31134 L .99 .735 .374 r
F
.40441 .31116 m .4044 .31135 L .40446 .31126 L F
.4044 .31135 m .40445 .31145 L .40446 .31126 L F
.40448 .3115 m .40548 .31155 L .40417 .31089 L .643 .737 .917 r
F
.40548 .31155 m .43619 .31316 L .40453 .31084 L F
.40299 .31795 m .40319 .3181 L .40372 .31024 L .912 .629 .494 r
F
.40371 .31024 m .40372 .31024 L .40373 .31005 L F
.40299 .31795 m .40372 .31024 L .40371 .31024 L F
.40428 .31112 m .40391 .31038 L .40358 .31838 L .99 .735 .374 r
F
.40348 .31006 m .40232 .31746 L .40299 .31795 L .912 .629 .494 r
F
.40349 .30987 m .40346 .31005 L .40348 .31006 L F
.40346 .31005 m .40232 .31746 L .40348 .31006 L F
.40475 .31078 m .40642 .31051 L .40401 .31025 L .667 .747 .91 r
F
.39992 .31956 m .40427 .32011 L .40446 .3198 L .643 .738 .918 r
F
.39992 .31956 m .40297 .32163 L .40365 .32111 L F
.40297 .32163 m .40322 .3218 L .40365 .32111 L F
.39992 .31956 m .40404 .32047 L .40427 .32011 L F
.40198 .32204 m .40138 .35787 L .40197 .32204 L .484 .259 .497 r
F
.40197 .32204 m .40138 .35787 L .40177 .32212 L F
.40311 .32152 m .40215 .35724 L .40303 .32159 L .286 .104 .449 r
F
.40289 .32169 m .40215 .35724 L .40138 .35787 L F
.40303 .32159 m .40215 .35724 L .40289 .32169 L F
.40229 .32192 m .40289 .32169 L .40138 .35787 L .484 .259 .497 r
F
.39992 .31956 m .40209 .322 L .403 .32165 L .643 .738 .918 r
F
.39992 .31956 m .40365 .32111 L .40404 .32047 L F
.40373 .31005 m .40319 .3181 L .40383 .31012 L .912 .629 .494 r
F
.40319 .3181 m .40327 .31816 L .40383 .31012 L F
.406 .31067 m .43493 .30719 L .40445 .3101 L .643 .737 .917 r
F
.4043 .31094 m .40389 .31899 L .40441 .31116 L .99 .735 .374 r
F
.40389 .31899 m .40398 .31917 L .40441 .31116 L F
.40449 .31152 m .40405 .31931 L .40449 .31153 L F
.40405 .31931 m .40405 .31932 L .40449 .31153 L F
.40445 .3121 m .40449 .31153 L .40416 .31953 L 0 0 .006 r
F
.40449 .31153 m .40405 .31932 L .40416 .31953 L .99 .735 .374 r
F
.40445 .31145 m .40402 .31925 L .40449 .31152 L F
.40402 .31925 m .40405 .31931 L .40449 .31152 L F
.4044 .31135 m .40398 .31917 L .40445 .31145 L F
.40398 .31917 m .40402 .31925 L .40445 .31145 L F
.40324 .32142 m .40365 .32111 L .40215 .35724 L .286 .104 .449 r
F
.40313 .32151 m .40215 .35724 L .40311 .32152 L F
.40324 .32142 m .40215 .35724 L .40313 .32151 L F
.42636 .31264 m .43601 .31405 L .43619 .31316 L .643 .737 .917 r
F
.40576 .31769 m .43421 .31547 L .43058 .30976 L .643 .738 .918 r
F
.40358 .31839 m .4061 .31882 L .40428 .31816 L F
.39992 .31956 m .40444 .31902 L .40358 .31839 L F
.40444 .31902 m .4061 .31882 L .40358 .31839 L F
.40383 .31012 m .40327 .31816 L .40392 .31018 L .912 .629 .494 r
F
.39992 .31956 m .40358 .31839 L .40282 .31782 L .643 .738 .918 r
F
.4061 .31882 m .43547 .32142 L .43421 .31547 L F
.39992 .31956 m .40955 .32006 L .4061 .31882 L F
.40955 .32006 m .43547 .32142 L .4061 .31882 L F
.40265 .30945 m .40209 .31737 L .40266 .30945 L .814 .537 .519 r
F
.40193 .31732 m .40202 .31735 L .40257 .30942 L F
.39992 .31956 m .40282 .31782 L .40232 .31746 L .643 .738 .918 r
F
.40266 .30945 m .40209 .31737 L .40232 .31746 L .814 .537 .519 r
F
.40196 .31733 m .40232 .31746 L .40204 .31725 L .643 .738 .918 r
F
.39992 .31956 m .40232 .31746 L .40196 .31733 L F
.40258 .30925 m .40257 .30942 L .40267 .30928 L .814 .537 .519 r
F
.40257 .30942 m .40265 .30945 L .40267 .30928 L F
.40257 .30942 m .40257 .30942 L .40258 .30925 L F
.40246 .30939 m .40257 .30942 L .40258 .30925 L F
.40349 .30987 m .40267 .30928 L .40266 .30945 L .912 .629 .494 r
F
.40267 .30928 m .40265 .30945 L .40266 .30945 L .814 .537 .519 r
F
.40488 .30678 m .40716 .30718 L .40653 .30621 L .668 .747 .909 r
F
.40646 .3073 m .40716 .30718 L .40488 .30678 L F
.40449 .30787 m .40598 .30839 L .40515 .30779 L F
.40598 .30839 m .40742 .3084 L .40515 .30779 L F
.40723 .3064 m .4145 .30523 L .40744 .30519 L .668 .746 .909 r
F
.40744 .30519 m .4145 .30523 L .41398 .30279 L F
.40529 .30604 m .40723 .3064 L .40486 .30517 L F
.40716 .30718 m .41253 .30371 L .40642 .30603 L .668 .747 .909 r
F
.40716 .30718 m .414 .30599 L .41253 .30371 L F
.42085 .30481 m .42089 .3016 L .41871 .29816 L .987 .714 .396 r
F
.414 .30599 m .41866 .30138 L .41253 .30371 L .668 .747 .909 r
F
.42085 .30481 m .41871 .29816 L .41866 .30138 L .987 .714 .396 r
F
.40646 .3073 m .40724 .30755 L .40716 .30718 L .668 .747 .909 r
F
.40742 .3084 m .414 .30599 L .40716 .30718 L F
.40636 .30925 m .41018 .30496 L .40521 .30827 L .667 .747 .91 r
F
.40636 .30925 m .41248 .30693 L .41018 .30496 L F
.40744 .30519 m .41398 .30279 L .40718 .30397 L .668 .746 .909 r
F
.40718 .30397 m .41398 .30279 L .41252 .30052 L F
.41398 .30279 m .41861 .29819 L .41252 .30052 L F
.41253 .30371 m .41866 .30138 L .41521 .2984 L .668 .747 .909 r
F
.41866 .30138 m .41871 .29816 L .41526 .29519 L .936 .65 .474 r
F
.40323 .30641 m .40466 .30671 L .4034 .3063 L .668 .747 .909 r
F
.40399 .30696 m .40466 .30671 L .40323 .30641 L F
.40475 .30517 m .40529 .30604 L .40486 .30517 L .668 .746 .909 r
F
.40469 .30593 m .40529 .30604 L .40475 .30517 L F
.4034 .3063 m .40642 .30603 L .40527 .30505 L .668 .747 .909 r
F
.40466 .30671 m .40642 .30603 L .4034 .3063 L F
.40642 .30603 m .41023 .30173 L .40527 .30505 L F
.40521 .30827 m .40719 .30343 L .40372 .30751 L .667 .747 .91 r
F
.40609 .30616 m .40653 .30621 L .40642 .30603 L .668 .747 .909 r
F
.40642 .30603 m .41253 .30371 L .41023 .30173 L F
.40521 .30827 m .41018 .30496 L .40719 .30343 L .667 .747 .91 r
F
.41253 .30371 m .41521 .2984 L .41023 .30173 L .668 .747 .909 r
F
.41248 .30693 m .41517 .30163 L .41018 .30496 L .667 .747 .91 r
F
.41248 .30693 m .41862 .3046 L .41517 .30163 L F
.41866 .30138 m .41526 .29519 L .41521 .2984 L .936 .65 .474 r
F
.41862 .3046 m .41866 .30138 L .41521 .2984 L F
.41862 .3046 m .41521 .2984 L .41517 .30163 L F
.40266 .30945 m .42557 .2964 L .40251 .30935 L .643 .737 .917 r
F
.40349 .30987 m .40266 .30945 L .40346 .31005 L .912 .629 .494 r
F
.40317 .30983 m .40337 .30971 L .40266 .30945 L .643 .737 .917 r
F
.40337 .30971 m .42557 .2964 L .40266 .30945 L F
.40257 .30942 m .40202 .31735 L .40265 .30945 L .814 .537 .519 r
F
.39992 .31956 m .40107 .32218 L .40177 .32212 L .643 .738 .918 r
F
.39992 .31956 m .40177 .32212 L .40209 .322 L F
.40107 .32218 m .40104 .32311 L .40137 .32287 L F
.40104 .32311 m .40056 .34197 L .40137 .32287 L F
.40081 .32221 m .40177 .32212 L .40024 .35836 L .631 .379 .518 r
F
.40054 .32223 m .40024 .35836 L .4005 .32223 L F
.40032 .32225 m .40024 .35836 L .39999 .32228 L F
.40202 .31735 m .39955 .35305 L .40209 .31737 L .814 .537 .519 r
F
.40202 .31735 m .40209 .31737 L .40267 .30928 L F
.40209 .31737 m .39955 .35305 L .40209 .31737 L F
.40209 .31737 m .40209 .31737 L .40266 .30945 L F
.40327 .31816 m .40081 .35348 L .40334 .31821 L .912 .629 .494 r
F
.40327 .31816 m .40334 .31821 L .40392 .31018 L F
.40232 .31746 m .39955 .35305 L .40081 .35348 L .814 .537 .519 r
F
.40209 .31737 m .39955 .35305 L .40232 .31746 L F
.40428 .31816 m .41019 .31833 L .40576 .31769 L .643 .738 .918 r
F
.4061 .31882 m .41019 .31833 L .40428 .31816 L F
.41019 .31833 m .43421 .31547 L .40576 .31769 L F
.40122 .30898 m .40069 .31695 L .40126 .30898 L .735 .467 .523 r
F
.40069 .31695 m .40072 .31696 L .40126 .30898 L F
.40141 .30901 m .40085 .31697 L .40142 .30901 L F
.40085 .31697 m .40085 .31698 L .40142 .30901 L F
.40142 .30901 m .40085 .31698 L .40108 .31701 L F
.39992 .31956 m .40094 .31699 L .39984 .31683 L .643 .738 .918 r
F
.4005 .31692 m .40069 .31695 L .40122 .30898 L .735 .467 .523 r
F
.40094 .31699 m .39984 .31683 L .39984 .31683 L .643 .738 .918 r
F
.40126 .30886 m .40072 .31696 L .40142 .30888 L .735 .467 .523 r
F
.39992 .31956 m .39999 .32228 L .40107 .32218 L .643 .738 .918 r
F
.40072 .31696 m .39829 .35291 L .40085 .31697 L .735 .467 .523 r
F
.40072 .31696 m .40085 .31697 L .40142 .30888 L F
.40223 .3093 m .40108 .31701 L .40174 .31725 L .814 .537 .519 r
F
.40224 .30914 m .40221 .30929 L .40223 .3093 L F
.40221 .30929 m .40108 .31701 L .40223 .3093 L F
.40142 .30888 m .40141 .30901 L .40142 .30901 L .735 .467 .523 r
F
.40224 .30914 m .40142 .30888 L .40142 .30901 L .814 .537 .519 r
F
.40129 .30886 m .40132 .30884 L .4013 .30884 L .667 .747 .91 r
F
.40122 .30898 m .40126 .30898 L .40126 .30886 L .735 .467 .523 r
F
.40122 .30898 m .40126 .30886 L .40123 .30886 L F
.40372 .30751 m .40372 .30246 L .40199 .30703 L .667 .747 .91 r
F
.40372 .30751 m .40719 .30343 L .40372 .30246 L F
.40142 .30901 m .40939 .28955 L .40065 .30873 L .643 .737 .917 r
F
.40224 .30914 m .40142 .30901 L .40221 .30929 L .814 .537 .519 r
F
.40161 .30907 m .40162 .30904 L .40142 .30901 L .643 .737 .917 r
F
.40162 .30904 m .40939 .28955 L .40142 .30901 L F
.40099 .30894 m .4005 .31692 L .40122 .30898 L .735 .467 .523 r
F
.40099 .30894 m .40122 .30898 L .40123 .30886 L F
.40065 .30889 m .40142 .30901 L .40065 .30873 L .643 .737 .917 r
F
.40221 .30929 m .40142 .30901 L .40108 .31701 L .814 .537 .519 r
F
.41521 .2984 m .41526 .29519 L .41079 .29289 L .867 .584 .507 r
F
.41018 .30496 m .41068 .29933 L .40719 .30343 L .667 .747 .91 r
F
.41018 .30496 m .41517 .30163 L .41068 .29933 L F
.41521 .2984 m .41079 .29289 L .41073 .29611 L .867 .584 .507 r
F
.41517 .30163 m .41521 .2984 L .41073 .29611 L F
.41517 .30163 m .41073 .29611 L .41068 .29933 L F
.40161 .30907 m .41809 .29232 L .40939 .28955 L .643 .737 .917 r
F
.40238 .30908 m .40372 .30751 L .40235 .30905 L .667 .747 .91 r
F
.40224 .30914 m .40174 .31725 L .40248 .30922 L .814 .537 .519 r
F
.40174 .31725 m .39955 .35305 L .40193 .31732 L F
.40174 .31725 m .40193 .31732 L .40248 .30922 L F
.40394 .30778 m .41809 .29232 L .4049 .30573 L .643 .737 .917 r
F
.40394 .30778 m .4049 .30573 L .40161 .30907 L F
.40247 .30939 m .40394 .30778 L .40161 .30907 L F
.40193 .31732 m .40257 .30942 L .40257 .30942 L .814 .537 .519 r
F
.40246 .30939 m .40193 .31732 L .40257 .30942 L F
.40247 .30939 m .40266 .30945 L .40251 .30935 L .643 .737 .917 r
F
.40251 .30935 m .42557 .2964 L .41809 .29232 L F
.40346 .31005 m .40266 .30945 L .40232 .31746 L .912 .629 .494 r
F
.3999 .31641 m .39985 .31651 L .39984 .31683 L .735 .467 .523 r
F
.40099 .30894 m .39985 .31651 L .3999 .31641 L F
.40099 .30894 m .40018 .30883 L .39985 .31651 L F
.40072 .3113 m .40067 .3117 L .40074 .31179 L .643 .737 .917 r
F
.40072 .3113 m .4006 .3116 L .40067 .3117 L F
.40099 .30894 m .39984 .31683 L .4005 .31692 L .735 .467 .523 r
F
.40065 .30889 m .40065 .30881 L .40018 .30883 L .643 .737 .917 r
F
.40018 .30875 m .40018 .30883 L .40018 .30883 L .652 .396 .519 r
F
.39976 .30879 m .39704 .35301 L .4 .30877 L F
.40065 .30881 m .40064 .30843 L .39965 .30885 L .643 .737 .917 r
F
.40019 .30875 m .40014 .30686 L .39997 .30877 L .667 .747 .91 r
F
.40064 .30843 m .40007 .28826 L .39959 .30871 L .643 .737 .917 r
F
.39983 .31656 m .40859 .29785 L .39925 .29657 L .643 .738 .918 r
F
.39984 .31683 m .39994 .3166 L .39983 .31656 L F
.39994 .3166 m .40859 .29785 L .39983 .31656 L F
.40094 .31699 m .40103 .31678 L .39984 .31683 L F
.40069 .31695 m .39829 .35291 L .40072 .31696 L .735 .467 .523 r
F
.40358 .31838 m .40081 .35348 L .40208 .3544 L .912 .629 .494 r
F
.40392 .31018 m .40334 .31821 L .40358 .31838 L F
.40334 .31821 m .40081 .35348 L .40358 .31838 L F
.40348 .31006 m .40299 .31795 L .40371 .31024 L F
.40282 .31782 m .40576 .31769 L .40358 .31737 L .643 .738 .918 r
F
.40358 .31839 m .40576 .31769 L .40282 .31782 L F
.40358 .31737 m .43058 .30976 L .42482 .30469 L F
.40576 .31769 m .43058 .30976 L .40358 .31737 L F
.40085 .31697 m .39829 .35291 L .40085 .31698 L .735 .467 .523 r
F
.40319 .3181 m .40081 .35348 L .40327 .31816 L .912 .629 .494 r
F
.40317 .30983 m .43131 .30147 L .42557 .2964 L .643 .737 .917 r
F
.40349 .30987 m .40348 .31006 L .40373 .31005 L .912 .629 .494 r
F
.40348 .31006 m .40371 .31024 L .40373 .31005 L F
.40461 .31004 m .40645 .30939 L .40462 .30992 L .667 .747 .91 r
F
.40609 .30936 m .40645 .30939 L .40636 .30925 L F
.40381 .31031 m .43131 .30147 L .40317 .30983 L .643 .737 .917 r
F
.40204 .31725 m .42482 .30469 L .41732 .30063 L .643 .738 .918 r
F
.40282 .31782 m .42482 .30469 L .40204 .31725 L F
.40381 .31031 m .406 .31067 L .40445 .3101 L .643 .737 .917 r
F
.40396 .31027 m .40475 .31078 L .40401 .31025 L .667 .747 .91 r
F
.40453 .31084 m .406 .31067 L .40381 .31031 L .643 .737 .917 r
F
.40095 .31696 m .40118 .31702 L .40111 .31656 L .643 .738 .918 r
F
.40118 .31702 m .40204 .31725 L .40187 .31712 L F
.40118 .31702 m .40187 .31712 L .40111 .31656 L F
.40108 .31701 m .39829 .35291 L .39955 .35305 L .735 .467 .523 r
F
.40085 .31698 m .39829 .35291 L .40108 .31701 L F
.40094 .31699 m .40108 .31701 L .40095 .31696 L .643 .738 .918 r
F
.4005 .31692 m .39829 .35291 L .40069 .31695 L .735 .467 .523 r
F
.40174 .31725 m .40108 .31701 L .39955 .35305 L .814 .537 .519 r
F
.40196 .31733 m .40204 .31725 L .40095 .31696 L .643 .738 .918 r
F
.40299 .31795 m .40232 .31746 L .40081 .35348 L .912 .629 .494 r
F
.40111 .31656 m .41408 .30415 L .40859 .29785 L .643 .738 .918 r
F
.40204 .31725 m .41408 .30415 L .40111 .31656 L F
.41408 .30415 m .41732 .30063 L .41642 .30034 L F
.41408 .30415 m .41642 .30034 L .40859 .29785 L F
.40427 .32011 m .40625 .32036 L .40446 .3198 L F
.40378 .3209 m .4026 .35648 L .40373 .32098 L 0 0 .327 r
F
.40299 .31795 m .40081 .35348 L .40319 .3181 L .912 .629 .494 r
F
.40557 .31985 m .40635 .32037 L .40744 .31995 L .643 .738 .918 r
F
.40625 .32036 m .40635 .32037 L .40557 .31985 L F
.40635 .32037 m .4126 .32116 L .40744 .31995 L F
.40533 .32181 m .43084 .33244 L .40482 .32083 L F
.40533 .32181 m .40482 .32083 L .40404 .32047 L F
.40373 .32098 m .4026 .35648 L .40373 .32098 L 0 0 .327 r
F
.40365 .32111 m .4026 .35648 L .40215 .35724 L F
.40373 .32098 m .4026 .35648 L .40365 .32111 L F
.40379 .32089 m .4026 .35648 L .40378 .3209 L F
.40389 .31899 m .40358 .31838 L .40208 .3544 L .99 .735 .374 r
F
.40427 .32011 m .40533 .32076 L .40635 .32037 L .643 .738 .918 r
F
.40404 .32047 m .40533 .32076 L .40427 .32011 L F
.40533 .32076 m .40869 .32151 L .40635 .32037 L F
.40193 .31732 m .39955 .35305 L .40202 .31735 L .814 .537 .519 r
F
.40955 .32006 m .4126 .32116 L .41928 .32057 L .643 .738 .918 r
F
.40869 .32151 m .43432 .3272 L .41928 .32057 L F
.40103 .31678 m .40859 .29785 L .39984 .31683 L F
.39984 .31683 m .39925 .29657 L .39874 .31688 L F
.39603 .31155 m .39591 .31149 L .39588 .31155 L .667 .747 .91 r
F
.39874 .31688 m .38996 .29688 L .39757 .31693 L .643 .738 .918 r
F
.39946 .31684 m .39704 .35301 L .39954 .31684 L .652 .396 .519 r
F
.39823 .31698 m .3958 .35339 L .39825 .31697 L .545 .308 .506 r
F
.39961 .31684 m .39704 .35301 L .39961 .31684 L .652 .396 .519 r
F
.39612 .31699 m .39713 .31643 L .39481 .3161 L .643 .738 .918 r
F
.39757 .31693 m .39713 .31643 L .39612 .31699 L F
.39713 .31643 m .38136 .29874 L .39481 .3161 L F
.4005 .31692 m .39984 .31683 L .39829 .35291 L .735 .467 .523 r
F
.39682 .31757 m .39458 .35426 L .39701 .31745 L .339 .143 .462 r
F
.39618 .318 m .3967 .31738 L .39547 .31771 L .643 .738 .918 r
F
.39691 .31752 m .3967 .31738 L .39618 .318 L F
.3967 .31738 m .37408 .30204 L .39547 .31771 L F
.39825 .31697 m .3958 .35339 L .39831 .31696 L .545 .308 .506 r
F
.39701 .31745 m .39458 .35426 L .39704 .31743 L .339 .143 .462 r
F
.39536 .31855 m .3686 .30652 L .36529 .31186 L .643 .738 .918 r
F
.39618 .318 m .3686 .30652 L .39536 .31855 L F
.3971 .31739 m .39458 .35426 L .39716 .31735 L .339 .143 .462 r
F
.39804 .31703 m .39738 .3172 L .3958 .35339 L .545 .308 .506 r
F
.39033 .31906 m .38961 .31727 L .37122 .31806 L .643 .738 .918 r
F
.39369 .31817 m .38961 .31727 L .39033 .31906 L F
.38961 .31727 m .36529 .31186 L .37122 .31806 L F
.39984 .31683 m .39704 .35301 L .39829 .35291 L .652 .396 .519 r
F
.39961 .31684 m .39704 .35301 L .39984 .31683 L F
.39607 .31823 m .39423 .35502 L .39611 .31813 L 0 0 .269 r
F
.39516 .32013 m .39428 .31926 L .3925 .32044 L .643 .738 .918 r
F
.39554 .31933 m .39428 .31926 L .39516 .32013 L F
.39428 .31926 m .39033 .31906 L .3925 .32044 L F
.39738 .3172 m .39458 .35426 L .3958 .35339 L .339 .143 .462 r
F
.39716 .31735 m .39458 .35426 L .39738 .3172 L F
.39861 .31688 m .3958 .35339 L .39704 .35301 L .545 .308 .506 r
F
.39831 .31696 m .3958 .35339 L .39861 .31688 L F
.39033 .31906 m .38032 .31853 L .38728 .31986 L .643 .738 .918 r
F
.39033 .31906 m .38728 .31986 L .39118 .3206 L F
.38032 .31853 m .36436 .3177 L .39118 .3206 L F
.39704 .31743 m .39458 .35426 L .3971 .31739 L .339 .143 .462 r
F
.3925 .32044 m .39118 .3206 L .39202 .32076 L .643 .738 .918 r
F
.3925 .32044 m .39202 .32076 L .39461 .32125 L F
.39118 .3206 m .36585 .32362 L .39461 .32125 L F
.39618 .318 m .39423 .35502 L .39538 .336 L 0 0 .269 r
F
.39611 .31813 m .39423 .35502 L .39618 .318 L F
.39462 .32125 m .39461 .32125 L .39462 .32126 L .643 .738 .918 r
F
.39571 .31949 m .39417 .35633 L .39569 .31936 L .875 .7 .179 r
F
.39569 .31936 m .39417 .35633 L .39568 .31925 L F
.39565 .31909 m .39417 .35633 L .39405 .35542 L F
.39568 .31925 m .39417 .35633 L .39565 .31909 L F
.39571 .31949 m .39578 .31997 L .39417 .35633 L F
.39601 .31834 m .39405 .35542 L .39604 .31829 L 0 0 .269 r
F
.39363 .32331 m .38643 .32446 L .37546 .33416 L .643 .738 .918 r
F
.39412 .32228 m .38643 .32446 L .39363 .32331 L F
.39682 .31757 m .39618 .318 L .39458 .35426 L .339 .143 .462 r
F
.38643 .32446 m .36964 .32923 L .37385 .3328 L .643 .738 .918 r
F
.38643 .32446 m .37385 .3328 L .37546 .33416 L F
.39607 .31823 m .39405 .35542 L .39423 .35502 L 0 0 .269 r
F
.39604 .31829 m .39405 .35542 L .39607 .31823 L F
.39053 .32976 m .37546 .33416 L .38289 .33808 L .643 .738 .918 r
F
.39308 .32446 m .37546 .33416 L .39053 .32976 L F
.39053 .32976 m .38289 .33808 L .38991 .33107 L F
.39593 .31851 m .39405 .35542 L .39601 .31834 L 0 0 .269 r
F
.40386 .32078 m .40407 .32043 L .40264 .3555 L 0 0 .327 r
F
.40385 .32078 m .40264 .3555 L .40263 .35549 L F
.40386 .32078 m .40264 .3555 L .40385 .32078 L F
.40389 .31899 m .40208 .3544 L .40398 .31917 L .99 .735 .374 r
F
.40405 .31931 m .40208 .3544 L .40405 .31932 L F
.40533 .32181 m .42529 .33677 L .43084 .33244 L .643 .738 .918 r
F
.40575 .32263 m .42529 .33677 L .40533 .32181 L F
.40407 .32043 m .40409 .3204 L .4026 .35648 L 0 0 .327 r
F
.40411 .32013 m .40267 .35557 L .4041 .32024 L 0 0 .006 r
F
.40409 .3204 m .40267 .35557 L .4026 .35648 L F
.4041 .32024 m .40267 .35557 L .40409 .3204 L F
.40412 .31999 m .40416 .31953 L .40267 .35557 L F
.40412 .31999 m .40267 .35557 L .40411 .32013 L F
.40416 .31953 m .40208 .3544 L .40267 .35557 L .99 .735 .374 r
F
.40405 .31932 m .40208 .3544 L .40416 .31953 L F
.40402 .31925 m .40208 .3544 L .40405 .31931 L F
.40644 .32398 m .41806 .33992 L .42529 .33677 L .643 .738 .918 r
F
.4088 .32861 m .41806 .33992 L .40644 .32398 L F
.39593 .31851 m .39565 .31909 L .39405 .35542 L 0 0 .269 r
F
.38991 .33107 m .38289 .33808 L .38607 .33906 L .643 .738 .918 r
F
.38991 .33107 m .38607 .33906 L .39145 .34074 L F
.40398 .31917 m .40208 .3544 L .40402 .31925 L .99 .735 .374 r
F
.4099 .33076 m .41491 .34058 L .41806 .33992 L .643 .738 .918 r
F
.39538 .336 m .39423 .35502 L .39458 .35426 L 0 0 .269 r
F
.54767 .47853 m .53417 .46238 L .53326 .4778 L .655 .781 .941 r
F
.54767 .47853 m .55599 .4635 L .53417 .46238 L F
.56757 .60696 m .59214 .60315 L .57221 .60173 L .658 .807 .955 r
F
.54988 .60292 m .56757 .60696 L .57221 .60173 L F
.54638 .60527 m .56757 .60696 L .54988 .60292 L F
0 g
.60509 .84909 m
.60869 .84817 L
s
.22066 .46117 m .19229 .46576 L .2203 .46516 L .657 .779 .938 r
F
0 g
.6125 .84768 m
.61624 .84763 L
s
.30438 .46995 m .32864 .45741 L .3017 .46201 L .657 .779 .939 r
F
.27628 .47055 m .30438 .46995 L .3017 .46201 L F
.69546 .35251 m .67271 .33558 L .6604 .34419 L .643 .737 .917 r
F
.70321 .3494 m .67271 .33558 L .69546 .35251 L F
.19597 .33812 m .1771 .33932 L .17573 .34753 L .433 .211 .475 r
F
0 g
.1613 .36023 m
.17573 .34753 L
s
.19597 .33812 m .19728 .32988 L .1771 .33932 L .433 .211 .475 r
F
0 g
.16269 .35205 m
.1771 .33932 L
s
.74491 .3551 m .75911 .33294 L .73824 .35123 L .643 .737 .917 r
F
.74491 .3551 m .77248 .34081 L .75911 .33294 L F
.77776 .73719 m .76902 .73207 L .76134 .73565 L .598 .766 .96 r
F
.7841 .7355 m .76902 .73207 L .77776 .73719 L F
0 g
.60869 .84817 m
.6125 .84768 L
s
.81732 .73954 m .82076 .73203 L .81211 .73717 L .598 .766 .96 r
F
.81732 .73954 m .82858 .73562 L .82076 .73203 L F
.31018 .74346 m .29974 .73836 L .29357 .74193 L .593 .769 .963 r
F
0 g
.28998 .74626 m
.29357 .74193 L
s
.31574 .74178 m .29974 .73836 L .31018 .74346 L .593 .769 .963 r
F
.32436 .35531 m .32535 .34708 L .30275 .33541 L .857 .601 .55 r
F
0 g
.32535 .34708 m
.34286 .36149 L
s
.50542 .4891 m .49183 .47618 L .47414 .48388 L .655 .782 .942 r
F
.51906 .48578 m .49183 .47618 L .50542 .4891 L F
.23243 .35462 m .22059 .33276 L .19597 .33812 L .642 .739 .919 r
F
.25035 .35408 m .22059 .33276 L .23243 .35462 L F
.51872 .47915 m .51214 .46444 L .49154 .46953 L .655 .781 .941 r
F
.53326 .4778 m .51214 .46444 L .51872 .47915 L F
.26861 .35652 m .24779 .33191 L .25035 .35408 L .642 .739 .919 r
F
.26861 .35652 m .27553 .33564 L .24779 .33191 L F
.3497 .74582 m .35028 .73834 L .34373 .74345 L .593 .769 .963 r
F
.3497 .74582 m .35924 .74191 L .35028 .73834 L F
.19285 .45776 m .16425 .46636 L .19229 .46576 L .657 .779 .938 r
F
.22066 .46117 m .19285 .45776 L .19229 .46576 L F
.32344 .7316 m .31919 .72519 L .30929 .72651 L .595 .768 .962 r
F
.3306 .73159 m .31919 .72519 L .32344 .7316 L F
.63862 .45788 m .645 .46231 L .64556 .46891 L .978 .694 .31 r
F
.63862 .45788 m .63807 .45125 L .645 .46231 L F
0 g
.645 .46231 m
.65117 .46708 L
s
.76904 .73677 m .76134 .73565 L .76135 .74034 L .409 .24 .538 r
F
.76904 .73677 m .76902 .73207 L .76134 .73565 L F
0 g
.75602 .74001 m
.76134 .73565 L
s
.78412 .73088 m .77861 .72491 L .76914 .72746 L .599 .766 .959 r
F
.79118 .73 m .77861 .72491 L .78412 .73088 L F
.27628 .47055 m .3017 .46201 L .27487 .4666 L .657 .779 .939 r
F
.33784 .73245 m .32997 .72518 L .3306 .73159 L .595 .768 .962 r
F
.33784 .73245 m .34089 .72648 L .32997 .72518 L F
.51098 .59729 m .49055 .60123 L .49457 .60596 L .658 .806 .954 r
F
.66608 .44657 m .64538 .46219 L .67056 .45397 L .656 .78 .94 r
F
.66608 .44657 m .63848 .45119 L .64538 .46219 L F
.81196 .73254 m .81099 .72487 L .80561 .73086 L .599 .766 .959 r
F
.81196 .73254 m .82056 .72741 L .81099 .72487 L F
.57079 .59076 m .59357 .58401 L .57271 .58529 L .659 .806 .953 r
F
.83405 .73998 m .82849 .73092 L .82858 .73562 L .949 .681 .496 r
F
.83414 .74468 m .83405 .73998 L .82858 .73562 L F
0 g
.83405 .73998 m
.83681 .74482 L
s
.53326 .4778 m .53417 .46238 L .51214 .46444 L .655 .781 .941 r
F
.70111 .46212 m .69025 .4781 L .70651 .46447 L .655 .782 .942 r
F
.70111 .46212 m .67946 .47349 L .69025 .4781 L F
.31627 .73709 m .30864 .73112 L .30029 .73366 L .594 .768 .963 r
F
.32288 .73622 m .30864 .73112 L .31627 .73709 L F
.59271 .47466 m .57554 .46109 L .57598 .46771 L .866 .595 .526 r
F
.59319 .48128 m .59271 .47466 L .57598 .46771 L F
0 g
.59271 .47466 m
.60501 .48381 L
s
.59214 .60315 m .59453 .58947 L .59517 .59496 L 0 0 .405 r
F
.57221 .60173 m .59214 .60315 L .59517 .59496 L .658 .807 .955 r
F
0 g
.5851 .61096 m
.59214 .60315 L
s
.34423 .73876 m .34043 .73109 L .33737 .73708 L .594 .768 .963 r
F
.34423 .73876 m .35077 .73363 L .34043 .73109 L F
.71199 .33943 m .70602 .31737 L .68834 .32099 L .644 .736 .916 r
F
.72116 .33915 m .70602 .31737 L .71199 .33943 L F
.6604 .34419 m .63115 .33148 L .61903 .34697 L .643 .737 .917 r
F
0 g
.61387 .36369 m
.61903 .34697 L
s
.61927 .33878 m
.6268 .3291 L
s
.7301 .34038 m .72459 .31679 L .72116 .33915 L .644 .736 .916 r
F
.7301 .34038 m .74269 .31929 L .72459 .31679 L F
.36621 .74626 m .35972 .73721 L .35924 .74191 L .913 .673 .562 r
F
0 g
.36621 .74626 m
.3707 .75108 L
s
.3306 .73159 m .32997 .72518 L .31919 .72519 L .595 .768 .962 r
F
.79119 .47237 m .80135 .45441 L .80219 .46103 L .255 .152 .539 r
F
.76874 .4652 m .79119 .47237 L .80219 .46103 L .655 .782 .942 r
F
.7585 .47177 m .79119 .47237 L .76874 .4652 L F
0 g
.77581 .48212 m
.79119 .47237 L
s
.19285 .45776 m .16487 .45432 L .16425 .46636 L .657 .779 .938 r
F
.82184 .35759 m .81439 .33283 L .81465 .34108 L .971 .709 .288 r
F
0 g
.8218 .37458 m
.82184 .35759 L
s
.16416 .4609 m .16383 .46637 L .16354 .47297 L 0 0 0 r
F
0 g
.16387 .46648 m
.16666 .47291 L
s
.16416 .4609 m .16445 .45427 L .16383 .46637 L 0 0 0 r
F
.33247 .47595 m .32864 .45741 L .32865 .46405 L .941 .721 .248 r
F
.30435 .47655 m .33247 .47595 L .32865 .46405 L .656 .78 .94 r
F
0 g
.33052 .48778 m
.33247 .47595 L
s
.25035 .35408 m .24779 .33191 L .22059 .33276 L .642 .739 .919 r
F
.72116 .33915 m .72459 .31679 L .70602 .31737 L .644 .736 .916 r
F
.78179 .34233 m .80033 .31797 L .77234 .33256 L F
.78179 .34233 m .81439 .33283 L .80033 .31797 L F
.77779 .74188 m .76904 .73677 L .76135 .74034 L .597 .767 .96 r
F
0 g
.75602 .74469 m
.76135 .74034 L
s
.78413 .7402 m .76904 .73677 L .77779 .74188 L .597 .767 .96 r
F
.81739 .74424 m .82084 .73674 L .81218 .74187 L F
.81739 .74424 m .82866 .74032 L .82084 .73674 L F
.49154 .46953 m .47362 .47062 L .47388 .47724 L .501 .312 .557 r
F
.49154 .46953 m .49125 .4629 L .47362 .47062 L F
0 g
.46016 .48038 m
.47362 .47062 L
s
.27482 .46002 m .29512 .44808 L .27159 .45636 L .657 .779 .938 r
F
.27482 .46002 m .30147 .45546 L .29512 .44808 L F
.54806 .48514 m .53454 .46905 L .53363 .48442 L .655 .782 .942 r
F
.54806 .48514 m .5564 .47016 L .53454 .46905 L F
.30864 .73112 m .30084 .72898 L .30029 .73366 L .488 .284 .529 r
F
.30864 .73112 m .30918 .72642 L .30084 .72898 L F
0 g
.29467 .73256 m
.30084 .72898 L
s
.79118 .73 m .78924 .72358 L .77861 .72491 L .599 .766 .959 r
F
.79852 .72999 m .78924 .72358 L .79118 .73 L F
.80561 .73086 m .8003 .72357 L .79852 .72999 L F
.80561 .73086 m .81099 .72487 L .8003 .72357 L F
.35972 .73721 m .3602 .73252 L .35126 .72893 L .849 .609 .575 r
F
0 g
.3602 .73252 m
.36714 .73689 L
s
.46817 .59723 m .46971 .59967 L .47018 .60516 L .844 .618 .074 r
F
.46817 .59723 m .4677 .59172 L .46971 .59967 L F
0 g
.46971 .59967 m
.47386 .60445 L
s
.489 .59041 m .47002 .59961 L .49026 .5957 L .659 .806 .953 r
F
.489 .59041 m .46801 .5917 L .47002 .59961 L F
.22033 .46776 m .19177 .47237 L .21998 .47176 L .657 .779 .939 r
F
.30435 .47655 m .32865 .46405 L .30166 .46864 L .656 .78 .94 r
F
.27619 .47716 m .30435 .47655 L .30166 .46864 L F
.32288 .73622 m .31859 .72979 L .30864 .73112 L .594 .768 .963 r
F
.33008 .73621 m .31859 .72979 L .32288 .73622 L F
.7841 .7355 m .77855 .72952 L .76902 .73207 L .598 .766 .96 r
F
.7912 .73462 m .77855 .72952 L .7841 .7355 L F
.33737 .73708 m .32945 .72978 L .33008 .73621 L .594 .768 .963 r
F
.33737 .73708 m .34043 .73109 L .32945 .72978 L F
.81211 .73717 m .81113 .72949 L .80572 .73549 L .598 .766 .96 r
F
.81211 .73717 m .82076 .73203 L .81113 .72949 L F
.83414 .74468 m .82858 .73562 L .82866 .74032 L .949 .681 .496 r
F
0 g
.83414 .74468 m
.83691 .74951 L
s
.31574 .74178 m .3081 .73582 L .29974 .73836 L .593 .769 .963 r
F
.32236 .74091 m .3081 .73582 L .31574 .74178 L F
.79852 .72999 m .8003 .72357 L .78924 .72358 L .599 .766 .959 r
F
.51151 .6028 m .49508 .61145 L .51349 .60517 L .658 .807 .955 r
F
.51151 .6028 m .49106 .60674 L .49508 .61145 L F
.34373 .74345 m .33993 .73581 L .33686 .74178 L .593 .769 .963 r
F
.34373 .74345 m .35028 .73834 L .33993 .73581 L F
.5716 .59624 m .59453 .58947 L .57353 .59076 L .658 .806 .954 r
F
.70321 .3494 m .68827 .32923 L .67271 .33558 L .643 .737 .917 r
F
.71198 .34764 m .68827 .32923 L .70321 .3494 L F
.51906 .48578 m .51247 .47111 L .49183 .47618 L .655 .782 .942 r
F
.53363 .48442 m .51247 .47111 L .51906 .48578 L F
.73824 .35123 m .74276 .32755 L .73014 .3486 L .643 .737 .917 r
F
.73824 .35123 m .75911 .33294 L .74276 .32755 L F
.33008 .73621 m .32945 .72978 L .31859 .72979 L .594 .768 .963 r
F
.46202 .33693 m .503 .33411 L .46913 .32656 L .643 .737 .917 r
F
.63918 .46453 m .64556 .46891 L .64613 .47553 L .978 .694 .31 r
F
.63918 .46453 m .63862 .45788 L .64556 .46891 L F
.66641 .45325 m .64556 .46891 L .67092 .46066 L .655 .781 .941 r
F
.66641 .45325 m .63862 .45788 L .64556 .46891 L F
0 g
.64556 .46891 m
.65179 .47369 L
s
.19234 .46434 m .16354 .47297 L .19177 .47237 L .657 .779 .939 r
F
.22033 .46776 m .19234 .46434 L .19177 .47237 L F
.27619 .47716 m .30166 .46864 L .27478 .47322 L .656 .78 .94 r
F
.29434 .30573 m .30051 .31529 L .29946 .32346 L .984 .793 .39 r
F
.29434 .30573 m .29541 .29753 L .30051 .31529 L F
0 g
.30051 .31529 m
.30576 .3227 L
s
.33113 .2994 m .30101 .31523 L .3343 .31121 L .644 .737 .916 r
F
.33113 .2994 m .29594 .29756 L .30101 .31523 L F
.53363 .48442 m .53454 .46905 L .51247 .47111 L .655 .782 .942 r
F
.59319 .48128 m .57598 .46771 L .57643 .47435 L .866 .595 .526 r
F
0 g
.59319 .48128 m
.6055 .4904 L
s
.77855 .72952 m .76901 .72738 L .76902 .73207 L .524 .329 .559 r
F
.77855 .72952 m .77852 .72482 L .76901 .72738 L F
0 g
.76134 .73097 m
.76901 .72738 L
s
.22291 .45739 m .19285 .45776 L .22066 .46117 L .657 .779 .938 r
F
.503 .33411 m .50353 .32592 L .50767 .30864 L 0 0 .106 r
F
0 g
.49847 .3331 m
.50353 .32592 L
s
.74092 .46127 m .7585 .47177 L .76874 .4652 L .655 .782 .942 r
F
.73461 .46386 m .7585 .47177 L .74092 .46127 L F
.46941 .31828 m .50303 .32581 L .50714 .30861 L .644 .737 .916 r
F
.82858 .73562 m .82849 .73092 L .82069 .72733 L .868 .609 .545 r
F
0 g
.82849 .73092 m
.83396 .7353 L
s
.3081 .73582 m .30029 .73366 L .29974 .73836 L .488 .284 .529 r
F
0 g
.29357 .74193 m
.29974 .73836 L
s
.3081 .73582 m .30864 .73112 L .30029 .73366 L .488 .284 .529 r
F
0 g
.29412 .73724 m
.30029 .73366 L
s
.32436 .35531 m .30275 .33541 L .3017 .34365 L .857 .601 .55 r
F
0 g
.32436 .35531 m
.34192 .3697 L
s
.35972 .73721 m .35126 .72893 L .35077 .73363 L .849 .609 .575 r
F
.35924 .74191 m .35972 .73721 L .35077 .73363 L F
0 g
.35972 .73721 m
.36667 .74157 L
s
.7912 .73462 m .78925 .72818 L .77855 .72952 L .598 .766 .96 r
F
.79858 .73462 m .78925 .72818 L .7912 .73462 L F
.80572 .73549 m .80037 .72817 L .79858 .73462 L F
.80572 .73549 m .81113 .72949 L .80037 .72817 L F
.19234 .46434 m .16416 .4609 L .16354 .47297 L .657 .779 .939 r
F
.16387 .46756 m .16354 .47297 L .16325 .4796 L 0 0 0 r
F
0 g
.16359 .47308 m
.1664 .47953 L
s
.16387 .46756 m .16416 .4609 L .16354 .47297 L 0 0 0 r
F
.32236 .74091 m .31806 .7345 L .3081 .73582 L .593 .769 .963 r
F
.32957 .74091 m .31806 .7345 L .32236 .74091 L F
.78413 .7402 m .77857 .73422 L .76904 .73677 L .597 .767 .96 r
F
.79124 .73932 m .77857 .73422 L .78413 .7402 L F
.33686 .74178 m .32893 .7345 L .32957 .74091 L .593 .769 .963 r
F
.33686 .74178 m .33993 .73581 L .32893 .7345 L F
.81218 .74187 m .8112 .7342 L .80578 .74019 L .597 .767 .96 r
F
.81218 .74187 m .82084 .73674 L .8112 .7342 L F
.46864 .60275 m .47018 .60516 L .47066 .61066 L .844 .618 .074 r
F
.46864 .60275 m .46817 .59723 L .47018 .60516 L F
.48929 .59593 m .47018 .60516 L .49055 .60123 L .658 .806 .954 r
F
.48929 .59593 m .46817 .59723 L .47018 .60516 L F
0 g
.47018 .60516 m
.47436 .60995 L
s
.50997 .58913 m .49026 .5957 L .51055 .59178 L .659 .806 .953 r
F
.50997 .58913 m .489 .59041 L .49026 .5957 L F
.79858 .73462 m .80037 .72817 L .78925 .72818 L .598 .766 .96 r
F
.49183 .47618 m .47388 .47724 L .47414 .48388 L .501 .312 .557 r
F
0 g
.46063 .49359 m
.47414 .48388 L
s
.49183 .47618 m .49154 .46953 L .47388 .47724 L .501 .312 .557 r
F
0 g
.4604 .48698 m
.47388 .47724 L
s
.27487 .4666 m .2953 .45462 L .27161 .46293 L .657 .779 .939 r
F
.27487 .4666 m .3017 .46201 L .2953 .45462 L F
0 g
.72163 .36803 m
.72397 .40369 L
s
.32957 .74091 m .32893 .7345 L .31806 .7345 L .593 .769 .963 r
F
.71198 .34764 m .706 .32563 L .68827 .32923 L .643 .737 .917 r
F
.72118 .34737 m .706 .32563 L .71198 .34764 L F
.73014 .3486 m .72462 .32505 L .72118 .34737 L F
.73014 .3486 m .74276 .32755 L .72462 .32505 L F
0 g
.71441 .36766 m
.71668 .40357 L
s
.57221 .60173 m .59517 .59496 L .57415 .59626 L .658 .807 .955 r
F
.55217 .60029 m .57221 .60173 L .57415 .59626 L F
.54988 .60292 m .57221 .60173 L .55217 .60029 L F
.22015 .47439 m .19154 .47899 L .21979 .47838 L .656 .78 .94 r
F
.30147 .45546 m .31886 .43973 L .29512 .44808 L .657 .779 .938 r
F
.30147 .45546 m .32823 .45088 L .31886 .43973 L F
.22185 .32451 m .19859 .32169 L .19728 .32988 L .569 .331 .515 r
F
.22185 .32451 m .2231 .3163 L .19859 .32169 L F
0 g
.17845 .33115 m
.19859 .32169 L
s
.24502 .58977 m .24486 .5843 L .26114 .58223 L .671 .448 .574 r
F
.22839 .58971 m .24486 .5843 L .24502 .58977 L .733 .498 .571 r
F
.22839 .58971 m .22825 .58422 L .24486 .5843 L F
.67271 .33558 m .63115 .33148 L .6604 .34419 L .643 .737 .917 r
F
.24326 .57362 m .24484 .58414 L .26104 .58208 L .662 .802 .95 r
F
.23312 .57356 m .24484 .58414 L .24339 .57448 L F
.24314 .57361 m .24339 .57448 L .24326 .57362 L F
.23312 .57356 m .24339 .57448 L .24314 .57361 L F
.24164 .50092 m .24183 .50175 L .23714 .55336 L .952 .765 .308 r
F
.23997 .56291 m .24326 .57362 L .24166 .56293 L .662 .802 .95 r
F
.23607 .56289 m .24304 .57328 L .23997 .56291 L F
.24304 .57328 m .24326 .57362 L .23997 .56291 L F
.23607 .56289 m .23216 .57355 L .24326 .57362 L F
.23252 .56238 m .23216 .57355 L .23607 .56289 L F
.23073 .56212 m .23114 .56541 L .23252 .56238 L F
.23114 .56541 m .23216 .57355 L .23252 .56238 L F
.24164 .50092 m .23708 .55317 L .23693 .55266 L .952 .765 .308 r
F
.24164 .50092 m .23714 .55336 L .23708 .55317 L F
.2362 .56848 m .24344 .57923 L .24183 .56851 L .661 .803 .951 r
F
.2328 .57409 m .24484 .58414 L .23312 .57356 L .662 .802 .95 r
F
.23216 .57355 m .22831 .58406 L .24484 .58414 L F
.2362 .56848 m .23226 .57917 L .24344 .57923 L .661 .803 .951 r
F
.23216 .57355 m .2328 .57409 L .23312 .57356 L .662 .802 .95 r
F
.23226 .57917 m .24502 .58977 L .24344 .57923 L .661 .803 .951 r
F
.23226 .57917 m .22839 .58971 L .24502 .58977 L F
.22155 .57205 m .22831 .58406 L .23216 .57355 L .662 .802 .95 r
F
.21247 .58749 m .22825 .58422 L .22839 .58971 L .791 .544 .564 r
F
.21247 .58749 m .21235 .58199 L .22825 .58422 L F
.22155 .57205 m .21249 .58185 L .22831 .58406 L .662 .802 .95 r
F
.22159 .57767 m .22839 .58971 L .23226 .57917 L .661 .803 .951 r
F
.23073 .56212 m .22155 .57205 L .23216 .57355 L .662 .802 .95 r
F
.23193 .56787 m .23226 .57917 L .2362 .56848 L .661 .803 .951 r
F
.23083 .56771 m .23108 .56974 L .23193 .56787 L F
.23108 .56974 m .23226 .57917 L .23193 .56787 L F
.24183 .50175 m .24237 .50245 L .2377 .55394 L .98 .727 .476 r
F
.24078 .55708 m .23607 .56289 L .24166 .56293 L .662 .802 .95 r
F
.2389 .55516 m .23607 .56289 L .24078 .55708 L F
.23083 .56771 m .22159 .57767 L .23226 .57917 L .661 .803 .951 r
F
.23097 .57327 m .23241 .5847 L .23635 .57404 L .661 .804 .952 r
F
.2444 .50353 m .24111 .5548 L .23979 .55472 L .751 .492 .54 r
F
.24046 .55491 m .2389 .55516 L .24078 .55708 L .662 .802 .95 r
F
.24321 .50305 m .2444 .50353 L .23979 .55472 L .839 .573 .538 r
F
.24321 .50305 m .23979 .55472 L .23944 .55463 L F
.23912 .55455 m .2389 .55516 L .24046 .55491 L .662 .802 .95 r
F
.2389 .55516 m .23447 .55808 L .23607 .56289 L F
.23907 .55469 m .2387 .55496 L .2389 .55516 L F
.2387 .55496 m .23447 .55808 L .2389 .55516 L F
.23768 .55461 m .23447 .55808 L .23907 .55469 L F
.24101 .56306 m .2362 .56848 L .24183 .56851 L .661 .803 .951 r
F
.23896 .56098 m .2362 .56848 L .24101 .56306 L F
.23635 .57404 m .2436 .58475 L .24199 .57407 L .661 .804 .952 r
F
.23635 .57404 m .23241 .5847 L .2436 .58475 L F
.23908 .55467 m .23768 .55461 L .23907 .55469 L .662 .802 .95 r
F
.23912 .55455 m .23887 .55456 L .23908 .55467 L F
.23887 .55456 m .23768 .55461 L .23908 .55467 L F
.24237 .50245 m .24321 .50305 L .23857 .5544 L .913 .647 .523 r
F
.24237 .50245 m .23857 .5544 L .23832 .55427 L F
.24321 .50305 m .23944 .55463 L .23857 .5544 L .839 .573 .538 r
F
.24237 .50245 m .23832 .55427 L .2377 .55394 L .913 .647 .523 r
F
.24003 .55207 m .2381 .55415 L .23912 .55455 L .662 .802 .95 r
F
.2381 .55415 m .23802 .55425 L .23857 .5544 L F
.2381 .55415 m .23857 .5544 L .23912 .55455 L F
.24183 .50175 m .23754 .55378 L .23714 .55336 L .98 .727 .476 r
F
.24183 .50175 m .2377 .55394 L .23754 .55378 L F
.24003 .55207 m .22602 .56067 L .23073 .56212 L .662 .802 .95 r
F
.24003 .55207 m .23297 .55467 L .22602 .56067 L F
.23297 .55467 m .22224 .55863 L .22492 .56008 L F
.23297 .55467 m .22492 .56008 L .22602 .56067 L F
.2432 .49909 m .24207 .49988 L .23735 .55173 L .329 .133 .455 r
F
.23754 .55378 m .2371 .5591 L .23714 .55336 L .98 .727 .476 r
F
.23896 .56098 m .23083 .56771 L .2362 .56848 L .661 .803 .951 r
F
.23871 .56073 m .23757 .56173 L .23896 .56098 L F
.23757 .56173 m .23083 .56771 L .23767 .56205 L F
.23757 .56173 m .23767 .56205 L .23896 .56098 L F
.23708 .55317 m .23714 .55336 L .23666 .55865 L .952 .765 .308 r
F
.23447 .55808 m .23252 .56238 L .23607 .56289 L .662 .802 .95 r
F
.23822 .55975 m .23799 .56 L .23922 .56027 L .661 .803 .951 r
F
.23729 .56076 m .23083 .56771 L .23757 .56173 L F
.2377 .55394 m .23744 .55934 L .23722 .55922 L .913 .647 .523 r
F
.22602 .56067 m .22155 .57205 L .23073 .56212 L .662 .802 .95 r
F
.23314 .56523 m .22608 .56626 L .23083 .56771 L .661 .803 .951 r
F
.23297 .55467 m .21966 .55614 L .22224 .55863 L .662 .802 .95 r
F
.24003 .55207 m .2355 .55297 L .23297 .55467 L F
.2355 .55297 m .21966 .55614 L .23297 .55467 L F
.23729 .56076 m .23474 .56171 L .23314 .56523 L .661 .803 .951 r
F
.23799 .56 m .23719 .56042 L .23729 .56076 L F
.23719 .56042 m .23474 .56171 L .23729 .56076 L F
.23791 .55992 m .22608 .56626 L .23799 .56 L F
.23447 .55808 m .23073 .56212 L .23252 .56238 L .662 .802 .95 r
F
.23742 .55933 m .22608 .56626 L .23822 .55975 L .661 .803 .951 r
F
.23754 .55378 m .23714 .55914 L .2371 .5591 L .98 .727 .476 r
F
.23802 .55425 m .23768 .55461 L .23912 .55455 L .662 .802 .95 r
F
.23832 .55427 m .23791 .55958 L .2377 .55394 L .913 .647 .523 r
F
.23791 .55958 m .23744 .55934 L .2377 .55394 L F
.23754 .55378 m .2377 .55394 L .23722 .55922 L .98 .727 .476 r
F
.23754 .55378 m .23722 .55922 L .23714 .55914 L F
.2371 .5591 m .2368 .5588 L .23714 .55336 L F
.23832 .55427 m .23857 .5544 L .23809 .55968 L .913 .647 .523 r
F
.23822 .55975 m .23791 .55992 L .23799 .56 L .661 .803 .951 r
F
.23799 .56 m .23729 .56076 L .23871 .56073 L F
.23729 .56076 m .23757 .56173 L .23871 .56073 L F
.23799 .56 m .23871 .56073 L .23922 .56027 L F
.24087 .56669 m .23635 .57404 L .24199 .57407 L .661 .804 .952 r
F
.23935 .5659 m .23635 .57404 L .24087 .56669 L F
.2406 .56035 m .23896 .56098 L .24101 .56306 L .661 .803 .951 r
F
.23931 .56001 m .23896 .56098 L .2406 .56035 L F
.23931 .56001 m .23978 .56536 L .23883 .56531 L .751 .492 .54 r
F
.23979 .55472 m .23978 .56003 L .23931 .56001 L F
.23978 .56003 m .23978 .56536 L .23931 .56001 L F
.23857 .5544 m .23905 .55994 L .23809 .55968 L .839 .573 .538 r
F
.23944 .55463 m .23905 .55994 L .23857 .5544 L F
.23944 .55463 m .23979 .55472 L .23931 .56001 L F
.23931 .56001 m .23864 .55997 L .23922 .56027 L .661 .803 .951 r
F
.23742 .55933 m .2308 .56108 L .22608 .56626 L F
.23666 .55893 m .2308 .56108 L .23742 .55933 L F
.23944 .55463 m .23931 .56001 L .23905 .55994 L .839 .573 .538 r
F
.23832 .55427 m .23809 .55968 L .23791 .55958 L .913 .647 .523 r
F
.22602 .56067 m .21214 .56919 L .22155 .57205 L .662 .802 .95 r
F
.22224 .55863 m .21214 .56919 L .22602 .56067 L F
.2308 .56108 m .21968 .56172 L .22228 .56422 L .661 .803 .951 r
F
.24207 .49988 m .23705 .5524 L .23735 .55173 L 0 0 .188 r
F
.24207 .49988 m .24164 .50092 L .23693 .55266 L F
.24207 .49988 m .23693 .55266 L .23705 .5524 L F
.2264 .55479 m .21845 .55335 L .21966 .55614 L .662 .802 .95 r
F
.24003 .55207 m .23383 .55244 L .2264 .55479 L F
.23383 .55244 m .21845 .55335 L .2264 .55479 L F
.24439 .49874 m .2432 .49909 L .2385 .55096 L .55 .315 .512 r
F
.23708 .55317 m .23661 .55851 L .23693 .55266 L .952 .765 .308 r
F
.23673 .5589 m .23416 .55883 L .2308 .56108 L .661 .803 .951 r
F
.23661 .55851 m .2365 .55813 L .23693 .55266 L .952 .765 .308 r
F
.23708 .55317 m .23666 .55865 L .23661 .55851 L F
.23714 .55336 m .2368 .5588 L .23666 .55865 L .98 .727 .476 r
F
.24056 .56007 m .23931 .56001 L .2406 .56035 L .661 .803 .951 r
F
.24077 .56008 m .24011 .56005 L .23979 .55472 L .751 .492 .54 r
F
.23931 .56001 m .23931 .56001 L .24056 .56007 L .661 .803 .951 r
F
.24043 .56539 m .23978 .56536 L .23978 .56003 L .751 .492 .54 r
F
.24011 .56005 m .23978 .56003 L .23979 .55472 L F
.24043 .56539 m .23978 .56003 L .24011 .56005 L F
.22224 .55863 m .20456 .56515 L .21214 .56919 L .662 .802 .95 r
F
.21966 .55614 m .20456 .56515 L .22224 .55863 L F
.23058 .55954 m .21847 .55893 L .21968 .56172 L .661 .803 .951 r
F
.23383 .55244 m .21872 .55047 L .21845 .55335 L .662 .802 .95 r
F
.24003 .55207 m .23596 .55176 L .23383 .55244 L F
.23596 .55176 m .21872 .55047 L .23383 .55244 L F
.23693 .55266 m .2365 .55813 L .23645 .55795 L .952 .765 .308 r
F
.23705 .5524 m .23693 .55266 L .23645 .55795 L 0 0 .188 r
F
.23705 .5524 m .23645 .55795 L .23654 .55776 L F
.23416 .55883 m .23212 .55811 L .23058 .55954 L .661 .803 .951 r
F
.24019 .55763 m .23554 .55791 L .23416 .55883 L F
.23554 .55791 m .23212 .55811 L .23416 .55883 L F
.2432 .49909 m .23735 .55173 L .23767 .55152 L .329 .133 .455 r
F
.23265 .55151 m .22045 .54769 L .21872 .55047 L .662 .802 .95 r
F
.24003 .55207 m .23573 .5511 L .23265 .55151 L F
.23573 .5511 m .22045 .54769 L .23265 .55151 L F
.24068 .56541 m .23935 .5659 L .24087 .56669 L .661 .804 .952 r
F
.24068 .5654 m .24067 .56541 L .24068 .56541 L F
.24067 .56541 m .23935 .5659 L .24068 .56541 L F
.24166 .56293 m .24326 .57362 L .24588 .57328 L .662 .802 .95 r
F
.24578 .566 m .24588 .57328 L .25414 .57223 L F
.24166 .56293 m .24588 .57328 L .24578 .566 L F
.24574 .56241 m .25414 .57223 L .24714 .56223 L F
.24166 .56293 m .24578 .566 L .24574 .56241 L F
.24578 .566 m .25414 .57223 L .24574 .56241 L F
.24329 .55672 m .24166 .56293 L .24714 .56223 L F
.24213 .55506 m .24124 .56012 L .24329 .55672 L F
.24193 .55477 m .24188 .55517 L .24213 .55506 L F
.24188 .55517 m .24124 .56012 L .24213 .55506 L F
.24124 .56012 m .24166 .56293 L .24329 .55672 L F
.24326 .57362 m .26104 .58208 L .25414 .57223 L F
.24183 .56851 m .24344 .57923 L .25439 .57784 L .661 .803 .951 r
F
.24183 .56851 m .25439 .57784 L .24734 .56781 L F
.24426 .55512 m .24714 .56223 L .25215 .56084 L .662 .802 .95 r
F
.24329 .55672 m .24714 .56223 L .24426 .55512 L F
.24795 .50359 m .2442 .55419 L .24342 .55452 L .487 .263 .5 r
F
.2462 .5038 m .24291 .55461 L .24164 .55482 L .636 .39 .528 r
F
.2444 .50353 m .2462 .5038 L .24164 .55482 L .751 .492 .54 r
F
.24196 .56015 m .24066 .56076 L .242 .5602 L .661 .803 .951 r
F
.24048 .55502 m .24124 .56012 L .24193 .55477 L .662 .802 .95 r
F
.24111 .5548 m .24164 .55482 L .24116 .56011 L .751 .492 .54 r
F
.24111 .5548 m .24116 .56011 L .24077 .56008 L F
.24116 .56011 m .24066 .56076 L .24196 .56015 L .661 .803 .951 r
F
.24056 .56007 m .24058 .5602 L .24116 .56011 L F
.24058 .5602 m .24066 .56076 L .24116 .56011 L F
.2444 .50353 m .24164 .55482 L .24111 .5548 L .751 .492 .54 r
F
.24795 .50359 m .24903 .50315 L .24452 .55406 L .487 .263 .5 r
F
.24342 .55452 m .24329 .55672 L .24426 .55512 L .662 .802 .95 r
F
.24795 .50359 m .24452 .55406 L .2442 .55419 L .487 .263 .5 r
F
.2462 .5038 m .24795 .50359 L .24342 .55452 L .636 .39 .528 r
F
.2462 .5038 m .24342 .55452 L .24291 .55461 L F
.24462 .55398 m .24402 .55495 L .2474 .55513 L .662 .802 .95 r
F
.24903 .50315 m .24503 .55367 L .24452 .55406 L .269 .086 .437 r
F
.24003 .55207 m .24368 .55471 L .24462 .55398 L .662 .802 .95 r
F
.24368 .55471 m .24402 .55495 L .24462 .55398 L F
.24402 .55495 m .25215 .56084 L .2474 .55513 L F
.24278 .56207 m .24183 .56851 L .24528 .56808 L .661 .803 .951 r
F
.24973 .50257 m .2455 .55306 L .24523 .55351 L 0 0 .268 r
F
.24551 .55329 m .25634 .55886 L .25944 .55641 L .662 .802 .95 r
F
.24903 .50315 m .24973 .50257 L .24523 .55351 L .269 .086 .437 r
F
.24903 .50315 m .24523 .55351 L .24503 .55367 L F
.24003 .55207 m .24462 .55398 L .24551 .55329 L .662 .802 .95 r
F
.24462 .55398 m .24828 .5555 L .24551 .55329 L F
.24302 .56166 m .24528 .56808 L .24523 .56481 L .661 .803 .951 r
F
.24284 .56197 m .24528 .56808 L .24302 .56166 L F
.24222 .56075 m .24528 .56808 L .24232 .56067 L F
.2422 .56755 m .24199 .57407 L .24482 .57371 L .661 .804 .952 r
F
.24386 .56028 m .24521 .56319 L .24518 .56123 L .661 .803 .951 r
F
.24368 .56058 m .24522 .56361 L .24386 .56028 L F
.24522 .56361 m .24734 .56781 L .24521 .56319 L F
.24522 .56361 m .24521 .56319 L .24386 .56028 L F
.24828 .5555 m .2472 .55416 L .24551 .55329 L .662 .802 .95 r
F
.24973 .50257 m .24554 .55299 L .2455 .55306 L 0 0 .268 r
F
.24973 .50257 m .25011 .50188 L .24561 .55289 L F
.24973 .50257 m .24561 .55289 L .24554 .55299 L F
.25011 .50188 m .2456 .55238 L .24561 .55289 L .796 .683 .137 r
F
.24586 .5525 m .25944 .55641 L .26123 .55365 L .662 .802 .95 r
F
.24003 .55207 m .24672 .55356 L .24586 .5525 L F
.24672 .55356 m .25944 .55641 L .24586 .5525 L F
.25011 .50106 m .24944 .5 L .2449 .5513 L .991 .745 .452 r
F
.24714 .56223 m .25414 .57223 L .26409 .56949 L .662 .802 .95 r
F
.24386 .56028 m .25238 .56642 L .25238 .56642 L .661 .803 .951 r
F
.24386 .56028 m .25238 .56642 L .24386 .56028 L F
.24232 .56067 m .24302 .56166 L .24333 .55989 L F
.24302 .56166 m .24734 .56781 L .24368 .56058 L F
.24302 .56166 m .24368 .56058 L .24333 .55989 L F
.24554 .55299 m .24561 .55289 L .24514 .55817 L 0 0 .268 r
F
.24714 .56223 m .26409 .56949 L .25215 .56084 L .662 .802 .95 r
F
.24783 .5608 m .25238 .56642 L .2566 .56443 L .661 .803 .951 r
F
.24415 .55927 m .25238 .56642 L .24783 .5608 L F
.24333 .55989 m .25238 .56642 L .24417 .55929 L F
.24405 .55934 m .24417 .55929 L .24415 .55927 L F
.24333 .55989 m .24417 .55929 L .24405 .55934 L F
.2442 .55419 m .24452 .55406 L .24405 .55934 L .487 .263 .5 r
F
.24333 .55989 m .24386 .56028 L .24386 .56028 L .661 .803 .951 r
F
.24333 .55989 m .24368 .56058 L .24386 .56028 L F
.2442 .55419 m .24405 .55934 L .24382 .55944 L .487 .263 .5 r
F
.24503 .55367 m .24466 .55887 L .24461 .55891 L .269 .086 .437 r
F
.24503 .55367 m .24523 .55351 L .24476 .55879 L F
.24503 .55367 m .24476 .55879 L .24466 .55887 L F
.2474 .55513 m .25215 .56084 L .25634 .55886 L .662 .802 .95 r
F
.25215 .56084 m .26409 .56949 L .27246 .56556 L F
.25215 .56084 m .27246 .56556 L .25634 .55886 L F
.24639 .55901 m .2566 .56443 L .25972 .56197 L .661 .803 .951 r
F
.24503 .55367 m .24461 .55891 L .24452 .55406 L .269 .086 .437 r
F
.24461 .55891 m .24423 .5592 L .24452 .55406 L F
.24523 .55351 m .24486 .55863 L .24476 .55879 L 0 0 .268 r
F
.24452 .55406 m .24423 .5592 L .24405 .55934 L .269 .086 .437 r
F
.24193 .55477 m .24329 .55672 L .24342 .55452 L .662 .802 .95 r
F
.24291 .55461 m .24342 .55452 L .24295 .5598 L .636 .39 .528 r
F
.2421 .56319 m .24183 .56851 L .24278 .56207 L .661 .803 .951 r
F
.24198 .56093 m .24183 .56851 L .24222 .56075 L F
.24066 .56076 m .24183 .56851 L .242 .5602 L F
.24186 .56536 m .24248 .56709 L .24276 .56663 L .661 .804 .952 r
F
.24135 .56557 m .2416 .56616 L .24186 .56536 L F
.2422 .56755 m .24482 .57371 L .24248 .56709 L F
.24276 .56663 m .24482 .57371 L .24476 .56946 L F
.24248 .56709 m .24482 .57371 L .24276 .56663 L F
.24502 .58977 m .26114 .58223 L .26132 .5877 L .671 .448 .574 r
F
.24344 .57923 m .26132 .5877 L .25439 .57784 L .661 .803 .951 r
F
.24199 .57407 m .25456 .58336 L .24751 .57336 L .661 .804 .952 r
F
.24291 .55461 m .24295 .5598 L .24257 .55987 L .636 .39 .528 r
F
.24291 .55461 m .24257 .55987 L .24164 .55482 L F
.24257 .55987 m .24193 .55997 L .24164 .55482 L F
.24164 .55482 m .24193 .55997 L .24116 .56011 L F
.24342 .55452 m .24323 .55968 L .24295 .5598 L .487 .263 .5 r
F
.24538 .55878 m .24471 .5595 L .24639 .55901 L .661 .803 .951 r
F
.2442 .55419 m .24382 .55944 L .24342 .55452 L .487 .263 .5 r
F
.24382 .55944 m .24323 .55968 L .24342 .55452 L F
.24111 .5548 m .24077 .56008 L .23979 .55472 L .751 .492 .54 r
F
.24019 .55763 m .24418 .55928 L .24538 .55878 L .661 .803 .951 r
F
.24418 .55928 m .24471 .5595 L .24538 .55878 L F
.24347 .56545 m .24474 .56838 L .24471 .56634 L .661 .804 .952 r
F
.24288 .56503 m .24329 .56575 L .24347 .56545 L F
.24329 .56575 m .24474 .56838 L .24347 .56545 L F
.24471 .5595 m .24783 .5608 L .24653 .55919 L .661 .803 .951 r
F
.24471 .5595 m .24653 .55919 L .24639 .55901 L F
.24554 .55299 m .24514 .55817 L .24511 .55822 L 0 0 .268 r
F
.24554 .55299 m .24511 .55822 L .2455 .55306 L F
.24511 .55822 m .24509 .55826 L .2455 .55306 L F
.24561 .55289 m .24514 .55799 L .24514 .55817 L .796 .683 .137 r
F
.2455 .55306 m .24509 .55826 L .24506 .5583 L 0 0 .268 r
F
.24828 .5555 m .25634 .55886 L .2472 .55416 L .662 .802 .95 r
F
.2455 .55306 m .24506 .5583 L .24523 .55351 L 0 0 .268 r
F
.24506 .5583 m .24486 .55863 L .24523 .55351 L F
.25634 .55886 m .27246 .56556 L .27868 .56071 L .662 .802 .95 r
F
.25634 .55886 m .27868 .56071 L .25944 .55641 L F
.24795 .55821 m .25972 .56197 L .26152 .55921 L .661 .803 .951 r
F
.24019 .55763 m .2528 .56043 L .24795 .55821 L F
.2528 .56043 m .25972 .56197 L .24795 .55821 L F
.24019 .55763 m .24333 .55989 L .24415 .55927 L F
.24019 .55763 m .24232 .56067 L .24333 .55989 L F
.24382 .55944 m .24343 .5647 L .24323 .55968 L .487 .263 .5 r
F
.24248 .5651 m .24264 .56536 L .24288 .56503 L .661 .804 .952 r
F
.24506 .5583 m .24462 .56356 L .24486 .55863 L 0 0 .268 r
F
.24581 .55172 m .26123 .55365 L .26158 .55078 L .662 .802 .95 r
F
.25011 .50106 m .2451 .55155 L .2456 .55217 L .991 .745 .452 r
F
.25011 .50188 m .25011 .50106 L .2456 .55217 L .796 .683 .137 r
F
.25011 .50188 m .2456 .55217 L .2456 .55238 L F
.24003 .55207 m .24781 .55265 L .24581 .55172 L .662 .802 .95 r
F
.24781 .55265 m .26123 .55365 L .24581 .55172 L F
.24944 .5 m .24392 .55085 L .2449 .5513 L .896 .63 .527 r
F
.25011 .50106 m .2449 .5513 L .2451 .55155 L .991 .745 .452 r
F
.24458 .55116 m .26158 .55078 L .26047 .54798 L .662 .802 .95 r
F
.24003 .55207 m .24581 .55172 L .24458 .55116 L F
.24581 .55172 m .26158 .55078 L .24458 .55116 L F
.24944 .5 m .24812 .49917 L .24354 .55067 L .896 .63 .527 r
F
.25944 .55641 m .27868 .56071 L .28232 .55523 L .662 .802 .95 r
F
.24595 .55729 m .26152 .55921 L .26188 .55633 L .661 .803 .951 r
F
.2456 .55238 m .24513 .55761 L .24561 .55289 L .796 .683 .137 r
F
.24513 .55761 m .24514 .55799 L .24561 .55289 L F
.2456 .55238 m .24513 .55746 L .24513 .55761 L F
.24513 .55733 m .24795 .55821 L .24595 .55729 L .661 .803 .951 r
F
.24019 .55763 m .24514 .558 L .24513 .55733 L F
.24514 .558 m .24795 .55821 L .24513 .55733 L F
.24795 .55821 m .26152 .55921 L .24595 .55729 L F
.24003 .55207 m .24193 .55477 L .24342 .55452 L .662 .802 .95 r
F
.24944 .5 m .24354 .55067 L .24392 .55085 L .896 .63 .527 r
F
.24812 .49917 m .24259 .5505 L .24354 .55067 L .807 .543 .539 r
F
.24003 .55207 m .24372 .55071 L .24259 .5505 L .662 .802 .95 r
F
.24232 .56067 m .24284 .56197 L .24302 .56166 L .661 .803 .951 r
F
.24222 .56075 m .2421 .56319 L .24278 .56207 L F
.24257 .55987 m .24295 .5598 L .24248 .5651 L .636 .39 .528 r
F
.24257 .55987 m .24248 .5651 L .24223 .56514 L F
.242 .5602 m .24222 .56075 L .24232 .56067 L .661 .803 .951 r
F
.242 .5602 m .24198 .56093 L .24222 .56075 L F
.24257 .55987 m .24223 .56514 L .24193 .55997 L .636 .39 .528 r
F
.24116 .56011 m .24223 .56514 L .24069 .5654 L F
.24185 .55999 m .24116 .56011 L .24196 .56015 L .661 .803 .951 r
F
.24193 .55997 m .24223 .56514 L .24116 .56011 L .636 .39 .528 r
F
.24077 .56008 m .24116 .56011 L .24069 .5654 L .751 .492 .54 r
F
.24068 .56541 m .24074 .56583 L .24124 .56531 L .661 .804 .952 r
F
.24074 .56583 m .24199 .57407 L .24127 .56561 L F
.24074 .56583 m .24127 .56561 L .24124 .56531 L F
.24186 .56536 m .24214 .56575 L .24248 .5651 L F
.24214 .56575 m .24751 .57336 L .24264 .56536 L F
.24214 .56575 m .24264 .56536 L .24248 .5651 L F
.24423 .5592 m .24394 .56436 L .24405 .55934 L .269 .086 .437 r
F
.24264 .56536 m .24475 .56882 L .24294 .56513 L .661 .804 .952 r
F
.24475 .56882 m .24474 .56838 L .24294 .56513 L F
.24295 .5598 m .24285 .56494 L .24248 .5651 L .487 .263 .5 r
F
.24077 .56008 m .24069 .5654 L .24043 .56539 L .751 .492 .54 r
F
.24405 .55934 m .24382 .56445 L .24358 .56464 L .269 .086 .437 r
F
.24343 .5647 m .24304 .56487 L .24323 .55968 L .487 .263 .5 r
F
.24518 .56123 m .24734 .56781 L .25238 .56642 L .661 .803 .951 r
F
.25414 .57223 m .26104 .58208 L .27587 .57801 L .662 .802 .95 r
F
.25414 .57223 m .27587 .57801 L .26409 .56949 L F
.24734 .56781 m .25439 .57784 L .2644 .57508 L .661 .803 .951 r
F
.24734 .56781 m .2644 .57508 L .25238 .56642 L F
.24739 .56611 m .25256 .57197 L .25678 .56998 L .661 .804 .952 r
F
.24382 .55944 m .24405 .55934 L .24358 .56464 L .487 .263 .5 r
F
.24382 .55944 m .24358 .56464 L .24343 .5647 L F
.24521 .56319 m .24734 .56781 L .24518 .56123 L .661 .803 .951 r
F
.24523 .56481 m .24528 .56808 L .24734 .56781 L F
.24323 .55968 m .24304 .56487 L .24295 .5598 L .487 .263 .5 r
F
.2428 .56497 m .25158 .57127 L .2437 .56459 L .661 .804 .952 r
F
.24077 .56008 m .24043 .56539 L .24011 .56005 L .751 .492 .54 r
F
.24035 .56321 m .24177 .56522 L .24248 .5651 L .661 .804 .952 r
F
.2428 .56497 m .24248 .5651 L .24288 .56503 L F
.24035 .56321 m .24248 .5651 L .2428 .56497 L F
.24344 .57923 m .24502 .58977 L .26132 .5877 L .661 .803 .951 r
F
.24199 .57407 m .2436 .58475 L .25456 .58336 L .661 .804 .952 r
F
.24304 .56487 m .24266 .57507 L .24285 .56494 L .487 .263 .5 r
F
.24304 .56487 m .24285 .56494 L .24295 .5598 L F
.2437 .56459 m .25158 .57127 L .24739 .56611 L .661 .804 .952 r
F
.24035 .56321 m .2428 .56497 L .2437 .56459 L F
.25158 .57127 m .25256 .57197 L .24739 .56611 L F
.24461 .55891 m .24419 .56417 L .24423 .5592 L .269 .086 .437 r
F
.24419 .56417 m .24394 .56436 L .24423 .5592 L F
.24003 .55207 m .24048 .55502 L .24193 .55477 L .662 .802 .95 r
F
.24812 .49917 m .24685 .49878 L .24223 .55043 L .807 .543 .539 r
F
.24812 .49917 m .24223 .55043 L .24235 .55045 L F
.24436 .55047 m .26047 .54798 L .25795 .54546 L .662 .802 .95 r
F
.24003 .55207 m .24771 .55053 L .24436 .55047 L F
.24771 .55053 m .26047 .54798 L .24436 .55047 L F
.2451 .55155 m .24458 .55677 L .2456 .55217 L .991 .745 .452 r
F
.24458 .55677 m .24495 .55724 L .2456 .55217 L F
.2451 .55155 m .24443 .55659 L .24458 .55677 L F
.2456 .55217 m .24495 .55724 L .24513 .55746 L F
.2456 .55238 m .2456 .55217 L .24513 .55746 L .796 .683 .137 r
F
.24019 .55763 m .24921 .55709 L .24592 .55649 L .661 .803 .951 r
F
.23956 .56534 m .23935 .5659 L .24068 .5654 L .661 .804 .952 r
F
.24043 .56539 m .24069 .5654 L .23977 .57571 L .751 .492 .54 r
F
.24035 .56321 m .2413 .56544 L .24186 .56536 L .661 .804 .952 r
F
.24019 .55763 m .24056 .56007 L .24116 .56011 L .661 .803 .951 r
F
.24019 .55763 m .24116 .56011 L .24185 .55999 L F
.24035 .56321 m .24068 .56541 L .24124 .56531 L .661 .804 .952 r
F
.24069 .5654 m .24156 .57551 L .23977 .57571 L .636 .39 .528 r
F
.2413 .56544 m .24135 .56557 L .24163 .56545 L .661 .804 .952 r
F
.2413 .56544 m .24163 .56545 L .24186 .56536 L F
.24177 .56522 m .24186 .56536 L .24248 .5651 L F
.2416 .56616 m .2422 .56755 L .24203 .56583 L F
.2422 .56755 m .24248 .56709 L .24203 .56583 L F
.2416 .56616 m .24203 .56583 L .24186 .56536 L F
.24124 .56531 m .24153 .56865 L .2422 .56755 L F
.24153 .56865 m .24199 .57407 L .2422 .56755 L F
.24223 .56514 m .24156 .57551 L .24069 .5654 L .636 .39 .528 r
F
.24043 .56539 m .23977 .57571 L .23978 .56536 L .751 .492 .54 r
F
.23905 .55994 m .23931 .56001 L .23883 .56531 L .839 .573 .538 r
F
.23905 .55994 m .23883 .56531 L .23866 .56526 L F
.23935 .5659 m .23725 .56754 L .23792 .56978 L .661 .804 .952 r
F
.23951 .56549 m .23917 .5658 L .23935 .5659 L F
.23917 .5658 m .23725 .56754 L .23935 .5659 L F
.23791 .55958 m .23749 .56492 L .23744 .55934 L .913 .647 .523 r
F
.23792 .56978 m .23097 .57327 L .23635 .57404 L .661 .804 .952 r
F
.23725 .56754 m .23097 .57327 L .23792 .56978 L F
.23702 .56678 m .2318 .57238 L .23724 .56751 L F
.2318 .57238 m .23169 .57261 L .23725 .56754 L F
.23724 .56751 m .23725 .56754 L .23951 .56549 L F
.2318 .57238 m .23725 .56754 L .23724 .56751 L F
.23657 .55835 m .23416 .55883 L .23673 .5589 L .661 .803 .951 r
F
.23661 .55851 m .23666 .55865 L .23618 .56395 L .952 .765 .308 r
F
.23872 .55985 m .23822 .55975 L .23864 .55997 L .661 .803 .951 r
F
.23825 .55972 m .23822 .55975 L .23872 .55985 L F
.23922 .56027 m .23871 .56073 L .23896 .56098 L F
.23905 .55994 m .23866 .56526 L .23809 .55968 L .839 .573 .538 r
F
.22608 .56626 m .22159 .57767 L .23083 .56771 L .661 .803 .951 r
F
.23702 .56678 m .22622 .57182 L .23097 .57327 L .661 .804 .952 r
F
.23682 .56611 m .22622 .57182 L .23702 .56678 L F
.24019 .55763 m .23657 .55835 L .23673 .5589 L .661 .803 .951 r
F
.24019 .55763 m .23666 .55893 L .23742 .55933 L F
.2371 .5591 m .23666 .56445 L .2368 .5588 L .98 .727 .476 r
F
.23729 .56508 m .2343 .56689 L .23779 .56558 L .661 .804 .952 r
F
.2343 .56689 m .22622 .57182 L .23396 .56765 L F
.2343 .56689 m .23396 .56765 L .23779 .56558 L F
.2365 .55813 m .23608 .56362 L .23645 .55795 L .952 .765 .308 r
F
.23608 .56362 m .23604 .5635 L .23645 .55795 L F
.23661 .55851 m .23615 .56386 L .2365 .55813 L F
.23615 .56386 m .23608 .56362 L .2365 .55813 L F
.23735 .55173 m .23654 .55776 L .23687 .55702 L 0 0 .188 r
F
.23705 .5524 m .23654 .55776 L .23735 .55173 L F
.24019 .55763 m .23489 .55724 L .23212 .55811 L .661 .803 .951 r
F
.23749 .56495 m .23729 .56508 L .23848 .56521 L .661 .804 .952 r
F
.23729 .56508 m .23779 .56558 L .23848 .56521 L F
.23722 .55922 m .23704 .56468 L .23674 .56452 L .913 .647 .523 r
F
.23866 .56526 m .23803 .56509 L .23809 .55968 L .839 .573 .538 r
F
.23749 .56492 m .23719 .56476 L .23744 .55934 L .913 .647 .523 r
F
.23791 .55958 m .23809 .55968 L .23761 .56498 L F
.23791 .55958 m .23761 .56498 L .23749 .56492 L F
.23744 .55934 m .23719 .56476 L .23722 .55922 L F
.23729 .56508 m .22862 .56751 L .22622 .57182 L .661 .804 .952 r
F
.23752 .56493 m .23723 .56502 L .23729 .56508 L F
.23723 .56502 m .22862 .56751 L .23729 .56508 L F
.23675 .56453 m .23675 .56453 L .23752 .56493 L F
.23675 .56453 m .23511 .56513 L .23723 .56502 L F
.23511 .56513 m .23485 .56571 L .23723 .56502 L F
.2368 .5588 m .23647 .56425 L .23666 .55865 L .98 .727 .476 r
F
.23647 .56425 m .23637 .56415 L .23666 .55865 L F
.23666 .55865 m .23637 .56415 L .23618 .56395 L F
.23719 .56476 m .23704 .56468 L .23722 .55922 L .913 .647 .523 r
F
.23666 .56445 m .23647 .56425 L .2368 .5588 L .98 .727 .476 r
F
.21214 .56919 m .21249 .58185 L .22155 .57205 L .662 .802 .95 r
F
.21214 .56919 m .19841 .57762 L .21249 .58185 L F
.22608 .56626 m .21212 .5748 L .22159 .57767 L .661 .803 .951 r
F
.22228 .56422 m .21212 .5748 L .22608 .56626 L F
.22862 .56751 m .21981 .5673 L .22241 .56979 L .661 .804 .952 r
F
.2371 .5591 m .23674 .56452 L .23666 .56445 L .98 .727 .476 r
F
.23474 .56171 m .22608 .56626 L .23314 .56523 L .661 .803 .951 r
F
.23675 .56453 m .23282 .56471 L .22862 .56751 L .661 .804 .952 r
F
.23714 .55914 m .23674 .56452 L .2371 .5591 L .98 .727 .476 r
F
.23714 .55914 m .23722 .55922 L .23674 .56452 L F
.23834 .56536 m .23682 .56611 L .23702 .56678 L .661 .804 .952 r
F
.23827 .56533 m .23682 .56611 L .23834 .56536 L F
.23848 .56521 m .23702 .56678 L .23951 .56549 L F
.23702 .56678 m .23724 .56751 L .23951 .56549 L F
.23761 .56498 m .23792 .57545 L .2367 .57498 L .839 .573 .538 r
F
.23809 .55968 m .23803 .56509 L .23761 .56498 L F
.23803 .56509 m .23792 .57545 L .23761 .56498 L F
.2308 .56108 m .22228 .56422 L .22441 .56536 L .661 .803 .951 r
F
.2308 .56108 m .22441 .56536 L .22608 .56626 L F
.20456 .56515 m .19841 .57762 L .21214 .56919 L .662 .802 .95 r
F
.22228 .56422 m .20449 .57076 L .21212 .5748 L .661 .803 .951 r
F
.21968 .56172 m .20449 .57076 L .22228 .56422 L F
.23498 .56428 m .2186 .56451 L .21981 .5673 L .661 .804 .952 r
F
.23661 .55851 m .23618 .56395 L .23615 .56386 L .952 .765 .308 r
F
.23645 .55795 m .23604 .5635 L .23597 .56326 L F
.24035 .56321 m .23454 .56356 L .23498 .56428 L .661 .804 .952 r
F
.24035 .56321 m .23625 .56403 L .23675 .56453 L F
.23625 .56403 m .23282 .56471 L .23675 .56453 L F
.23618 .56395 m .23584 .57439 L .23529 .5737 L .98 .727 .476 r
F
.236 .56943 m .23552 .57187 L .23593 .57159 L .329 .133 .455 r
F
.23647 .56425 m .23584 .57439 L .23637 .56415 L .98 .727 .476 r
F
.23637 .56415 m .23584 .57439 L .23618 .56395 L F
.23674 .56452 m .2367 .57498 L .23584 .57439 L .913 .647 .523 r
F
.23624 .57001 m .23611 .57148 L .23668 .57109 L .329 .133 .455 r
F
.23666 .56445 m .23584 .57439 L .23647 .56425 L .98 .727 .476 r
F
.236 .56943 m .23611 .57148 L .23624 .57001 L .329 .133 .455 r
F
.236 .56943 m .23593 .57159 L .23611 .57148 L F
.23675 .56453 m .23723 .56502 L .23752 .56493 L .661 .804 .952 r
F
.23719 .56476 m .2367 .57498 L .23704 .56468 L .913 .647 .523 r
F
.24035 .56321 m .23675 .56453 L .23752 .56493 L .661 .804 .952 r
F
.23704 .56468 m .2367 .57498 L .23674 .56452 L .913 .647 .523 r
F
.23749 .56492 m .2367 .57498 L .23719 .56476 L F
.23666 .56445 m .23674 .56452 L .23584 .57439 L .98 .727 .476 r
F
.20456 .56515 m .18701 .57163 L .19841 .57762 L .662 .802 .95 r
F
.19934 .56019 m .18701 .57163 L .20456 .56515 L F
.21966 .55614 m .19934 .56019 L .20456 .56515 L F
.21968 .56172 m .19923 .56579 L .20449 .57076 L .661 .803 .951 r
F
.21847 .55893 m .19923 .56579 L .21968 .56172 L F
.2304 .56381 m .21887 .56163 L .2186 .56451 L .661 .804 .952 r
F
.2432 .49909 m .23767 .55152 L .2385 .55096 L .329 .133 .455 r
F
.23573 .5511 m .22352 .54519 L .22045 .54769 L .662 .802 .95 r
F
.24003 .55207 m .23724 .5509 L .23573 .5511 L F
.23724 .5509 m .22352 .54519 L .23573 .5511 L F
.21845 .55335 m .19934 .56019 L .21966 .55614 L F
.23105 .55695 m .22048 .55325 L .21874 .55604 L .661 .803 .951 r
F
.23767 .55152 m .23735 .55173 L .23687 .55702 L .329 .133 .455 r
F
.23638 .55735 m .23486 .55645 L .23105 .55695 L .661 .803 .951 r
F
.24019 .55763 m .23701 .55692 L .23638 .55735 L F
.23767 .55152 m .23687 .55702 L .23711 .55686 L .329 .133 .455 r
F
.23701 .55692 m .23486 .55645 L .23638 .55735 L .661 .803 .951 r
F
.23486 .55645 m .22048 .55325 L .23105 .55695 L F
.23654 .55776 m .23602 .56313 L .23687 .55702 L 0 0 .188 r
F
.23586 .56348 m .23382 .56273 L .2304 .56381 L .661 .804 .952 r
F
.24035 .56321 m .23613 .5629 L .23586 .56348 L F
.23602 .56313 m .23624 .56266 L .23687 .55702 L 0 0 .188 r
F
.23654 .55776 m .23645 .55795 L .23597 .56326 L F
.23654 .55776 m .23597 .56326 L .23602 .56313 L F
.23613 .5629 m .23382 .56273 L .23586 .56348 L .661 .804 .952 r
F
.23848 .56521 m .23827 .56533 L .23834 .56536 L F
.23866 .56526 m .23792 .57545 L .23803 .56509 L .839 .573 .538 r
F
.24035 .56321 m .23749 .56495 L .23848 .56521 L .661 .804 .952 r
F
.24035 .56321 m .23848 .56521 L .23883 .56531 L F
.23956 .56534 m .23883 .56531 L .23951 .56549 L F
.24035 .56321 m .23883 .56531 L .23956 .56534 L F
.23866 .56526 m .23883 .56531 L .23792 .57545 L .839 .573 .538 r
F
.23883 .56531 m .23977 .57571 L .23792 .57545 L .751 .492 .54 r
F
.23978 .56536 m .23977 .57571 L .23883 .56531 L F
.24035 .56321 m .23956 .56534 L .24068 .5654 L .661 .804 .952 r
F
.23212 .55811 m .2187 .55892 L .22801 .55941 L .661 .803 .951 r
F
.2187 .55892 m .21847 .55893 L .23058 .55954 L F
.23416 .55883 m .21968 .56172 L .2308 .56108 L F
.22945 .56241 m .22061 .55885 L .21887 .56163 L .661 .804 .952 r
F
.23687 .55702 m .23624 .56266 L .23639 .56232 L 0 0 .188 r
F
.24019 .55763 m .23825 .55972 L .23872 .55985 L .661 .803 .951 r
F
.24019 .55763 m .23742 .55933 L .23822 .55975 L F
.23486 .55645 m .22357 .55075 L .22048 .55325 L F
.24003 .55207 m .22774 .54317 L .22352 .54519 L .662 .802 .95 r
F
.24439 .49874 m .23884 .55085 L .23971 .55057 L .55 .315 .512 r
F
.24439 .49874 m .2385 .55096 L .23884 .55085 L F
.24003 .55207 m .23281 .54174 L .22774 .54317 L .662 .802 .95 r
F
.24561 .49865 m .24439 .49874 L .23971 .55057 L .656 .407 .53 r
F
.24561 .49865 m .23971 .55057 L .24006 .55053 L F
.24003 .55207 m .23838 .54103 L .23281 .54174 L .662 .802 .95 r
F
.23884 .55085 m .23827 .55617 L .23971 .55057 L .55 .315 .512 r
F
.23767 .55152 m .23711 .55686 L .2385 .55096 L .329 .133 .455 r
F
.23711 .55686 m .23772 .55645 L .2385 .55096 L F
.24019 .55763 m .23736 .55646 L .23635 .55678 L .661 .803 .951 r
F
.23559 .56286 m .23561 .56216 L .23382 .56273 L .661 .804 .952 r
F
.24035 .56321 m .23638 .56233 L .23559 .56286 L F
.23638 .56233 m .23561 .56216 L .23559 .56286 L F
.23884 .55085 m .2385 .55096 L .23802 .55625 L .55 .315 .512 r
F
.23884 .55085 m .23802 .55625 L .23827 .55617 L F
.2385 .55096 m .23772 .55645 L .23802 .55625 L .329 .133 .455 r
F
.24019 .55763 m .22782 .54871 L .22357 .55075 L .661 .803 .951 r
F
.23772 .55645 m .23693 .56196 L .23802 .55625 L .329 .133 .455 r
F
.23693 .56196 m .23713 .56183 L .23802 .55625 L F
.23212 .55811 m .23105 .55695 L .21847 .55893 L .661 .803 .951 r
F
.23105 .55695 m .21874 .55604 L .2185 .55862 L F
.23105 .55695 m .2185 .55862 L .21847 .55893 L F
.23212 .55811 m .22801 .55941 L .23058 .55954 L F
.23561 .56216 m .22371 .55635 L .22061 .55885 L .661 .804 .952 r
F
.23711 .55686 m .23654 .56223 L .23772 .55645 L .329 .133 .455 r
F
.23654 .56223 m .23693 .56196 L .23772 .55645 L F
.23711 .55686 m .23687 .55702 L .23639 .56232 L F
.23711 .55686 m .23639 .56232 L .23654 .56223 L F
.24035 .56321 m .23686 .56177 L .23561 .56216 L .661 .804 .952 r
F
.23686 .56177 m .22371 .55635 L .23561 .56216 L F
.23827 .55617 m .23892 .55597 L .23971 .55057 L .55 .315 .512 r
F
.24003 .55207 m .23912 .55455 L .24046 .55491 L .662 .802 .95 r
F
.23971 .55057 m .23892 .55597 L .23924 .55587 L .55 .315 .512 r
F
.24019 .55763 m .23292 .54729 L .22782 .54871 L .661 .803 .951 r
F
.23827 .55617 m .2377 .56151 L .23892 .55597 L .55 .315 .512 r
F
.23749 .56492 m .23761 .56498 L .2367 .57498 L .913 .647 .523 r
F
.2377 .56151 m .23812 .56138 L .23892 .55597 L .55 .315 .512 r
F
.23489 .55724 m .23105 .55695 L .23212 .55811 L .661 .803 .951 r
F
.23622 .56151 m .22796 .55432 L .22371 .55635 L .661 .804 .952 r
F
.23802 .55625 m .23713 .56183 L .23754 .56156 L .329 .133 .455 r
F
.23827 .55617 m .23802 .55625 L .23754 .56156 L .55 .315 .512 r
F
.24035 .56321 m .23789 .56145 L .23686 .56177 L .661 .804 .952 r
F
.2377 .56151 m .23754 .56156 L .23668 .57109 L .55 .315 .512 r
F
.23827 .55617 m .23754 .56156 L .2377 .56151 L F
.23686 .56177 m .2377 .56131 L .23622 .56151 L .661 .804 .952 r
F
.23789 .56145 m .2377 .56131 L .23686 .56177 L F
.2377 .56131 m .22796 .55432 L .23622 .56151 L F
.24019 .55763 m .23864 .55997 L .23931 .56001 L .661 .803 .951 r
F
.24561 .49865 m .24006 .55053 L .24096 .55041 L .656 .407 .53 r
F
.24685 .49878 m .24131 .55042 L .24223 .55043 L .734 .476 .538 r
F
.24685 .49878 m .24561 .49865 L .24096 .55041 L F
.24685 .49878 m .24096 .55041 L .24131 .55042 L F
.24064 .5504 m .24164 .55032 L .24073 .55016 L .662 .802 .95 r
F
.24003 .55207 m .24155 .55042 L .24064 .5504 L F
.24155 .55042 m .24164 .55032 L .24064 .5504 L F
.24019 .55763 m .23931 .56001 L .24056 .56007 L .661 .803 .951 r
F
.24812 .49917 m .24235 .55045 L .24259 .5505 L .807 .543 .539 r
F
.24003 .55207 m .25419 .54337 L .24946 .54188 L .662 .802 .95 r
F
.24131 .55042 m .24096 .55041 L .24048 .5557 L .734 .476 .538 r
F
.24131 .55042 m .24048 .5557 L .24074 .5557 L F
.23967 .55416 m .23949 .55583 L .23977 .55481 L .656 .407 .53 r
F
.23967 .55416 m .23977 .55481 L .24096 .55041 L F
.24003 .55207 m .24073 .55016 L .23972 .54997 L .662 .802 .95 r
F
.24006 .55053 m .23967 .55416 L .24096 .55041 L .656 .407 .53 r
F
.23949 .55583 m .24015 .55574 L .24096 .55041 L F
.24096 .55041 m .24015 .55574 L .24048 .5557 L F
.24006 .55053 m .23971 .55057 L .23924 .55587 L F
.24006 .55053 m .23924 .55587 L .23949 .55583 L F
.24394 .56436 m .24382 .56445 L .24405 .55934 L .269 .086 .437 r
F
.2449 .5513 m .24335 .55609 L .24443 .55659 L .896 .63 .527 r
F
.2451 .55155 m .2449 .5513 L .24443 .55659 L .991 .745 .452 r
F
.24417 .55617 m .2491 .55585 L .24521 .55578 L .661 .803 .951 r
F
.24019 .55763 m .24592 .55649 L .24417 .55617 L F
.24592 .55649 m .2491 .55585 L .24417 .55617 L F
.24035 .56321 m .24739 .56611 L .2465 .56502 L .661 .804 .952 r
F
.24476 .55879 m .24442 .56388 L .2443 .56409 L 0 0 .268 r
F
.24461 .55891 m .2443 .56409 L .24419 .56417 L .269 .086 .437 r
F
.24466 .55887 m .2443 .56409 L .24461 .55891 L F
.25238 .56642 m .25238 .56642 L .24783 .5608 L .661 .803 .951 r
F
.25238 .56642 m .25238 .56642 L .25238 .56642 L F
.26409 .56949 m .27587 .57801 L .28838 .57219 L .662 .802 .95 r
F
.26409 .56949 m .28838 .57219 L .27246 .56556 L F
.25238 .56642 m .2644 .57508 L .27282 .57115 L .661 .803 .951 r
F
.25238 .56642 m .27282 .57115 L .2566 .56443 L F
.24605 .56447 m .25858 .56858 L .25291 .56599 L .661 .804 .952 r
F
.24466 .55887 m .24476 .55879 L .2443 .56409 L .269 .086 .437 r
F
.24035 .56321 m .2465 .56502 L .24605 .56447 L .661 .804 .952 r
F
.2465 .56502 m .25858 .56858 L .24605 .56447 L F
.24394 .56436 m .24337 .57451 L .24382 .56445 L .269 .086 .437 r
F
.24358 .56464 m .24337 .57451 L .24266 .57507 L F
.24382 .56445 m .24337 .57451 L .24358 .56464 L F
.24783 .5608 m .2566 .56443 L .24639 .55901 L .661 .803 .951 r
F
.27246 .56556 m .28838 .57219 L .29774 .56497 L .662 .802 .95 r
F
.2566 .56443 m .27282 .57115 L .27908 .56628 L .661 .803 .951 r
F
.27246 .56556 m .29774 .56497 L .27868 .56071 L .662 .802 .95 r
F
.2566 .56443 m .27908 .56628 L .25972 .56197 L .661 .803 .951 r
F
.24808 .56378 m .25991 .56753 L .26171 .56478 L .661 .804 .952 r
F
.24486 .55863 m .24449 .56378 L .24476 .55879 L 0 0 .268 r
F
.24449 .56378 m .24442 .56388 L .24476 .55879 L F
.24462 .56356 m .24449 .56378 L .24486 .55863 L F
.24506 .5583 m .24467 .56347 L .24462 .56356 L F
.24495 .55724 m .2443 .56232 L .24513 .55746 L .991 .745 .452 r
F
.24035 .56321 m .24605 .56447 L .24533 .56358 L .661 .804 .952 r
F
.24419 .56417 m .24337 .57451 L .24394 .56436 L .269 .086 .437 r
F
.24354 .55067 m .24272 .5559 L .24306 .55596 L .807 .543 .539 r
F
.24392 .55085 m .24306 .55596 L .24335 .55609 L .896 .63 .527 r
F
.24392 .55085 m .24335 .55609 L .2449 .5513 L F
.24326 .55575 m .25822 .551 L .25444 .54891 L .661 .803 .951 r
F
.24259 .5505 m .24203 .55577 L .24354 .55067 L .807 .543 .539 r
F
.24019 .55763 m .24417 .55617 L .24295 .55594 L .661 .803 .951 r
F
.24035 .56321 m .24808 .56378 L .24806 .56377 L .661 .804 .952 r
F
.24467 .56286 m .24467 .56311 L .24514 .55799 L .796 .683 .137 r
F
.24511 .55822 m .24514 .55817 L .24467 .56347 L 0 0 .268 r
F
.24511 .55822 m .24467 .56347 L .24509 .55826 L F
.24514 .55817 m .24467 .56311 L .24467 .56347 L .796 .683 .137 r
F
.24514 .55799 m .24467 .56311 L .24514 .55817 L F
.24509 .55826 m .24467 .56347 L .24506 .5583 L 0 0 .268 r
F
.24035 .56321 m .26171 .56476 L .25004 .56263 L .661 .804 .952 r
F
.24203 .55577 m .24272 .5559 L .24354 .55067 L .807 .543 .539 r
F
.24259 .5505 m .24176 .55572 L .24203 .55577 L F
.24259 .5505 m .25795 .54546 L .25419 .54337 L .662 .802 .95 r
F
.24372 .55071 m .25795 .54546 L .24259 .5505 L F
.24392 .55085 m .24354 .55067 L .24306 .55596 L .896 .63 .527 r
F
.24019 .55763 m .25444 .54891 L .24968 .54741 L .661 .803 .951 r
F
.27868 .56071 m .29774 .56497 L .30329 .5568 L .662 .802 .95 r
F
.25972 .56197 m .27908 .56628 L .28274 .56079 L .661 .803 .951 r
F
.27868 .56071 m .30329 .5568 L .28232 .55523 L .662 .802 .95 r
F
.25972 .56197 m .28274 .56079 L .26152 .55921 L .661 .803 .951 r
F
.24651 .56198 m .26207 .56191 L .26094 .55911 L .661 .804 .952 r
F
.2443 .56232 m .24442 .56246 L .24513 .55746 L .991 .745 .452 r
F
.24513 .55746 m .24442 .56246 L .24466 .56276 L F
.24513 .55761 m .24513 .55746 L .24466 .56276 L .796 .683 .137 r
F
.24513 .55761 m .24466 .56276 L .24467 .56286 L F
.24513 .55761 m .24467 .56286 L .24514 .55799 L F
.24035 .56321 m .25004 .56263 L .24651 .56198 L .661 .804 .952 r
F
.25004 .56263 m .26207 .56191 L .24651 .56198 L F
.24203 .55577 m .24146 .56106 L .24272 .5559 L .807 .543 .539 r
F
.24146 .56106 m .24191 .56114 L .24272 .5559 L F
.24295 .55594 m .24521 .55578 L .24326 .55575 L .661 .803 .951 r
F
.24417 .55617 m .24521 .55578 L .24295 .55594 L F
.24521 .55578 m .25822 .551 L .24326 .55575 L F
.24335 .55609 m .24278 .56135 L .24443 .55659 L .896 .63 .527 r
F
.24278 .56135 m .24348 .56168 L .24443 .55659 L F
.24306 .55596 m .24213 .56119 L .24259 .56127 L .807 .543 .539 r
F
.24443 .55659 m .24348 .56168 L .24396 .5619 L .896 .63 .527 r
F
.24272 .5559 m .24191 .56114 L .24306 .55596 L .807 .543 .539 r
F
.24191 .56114 m .24213 .56119 L .24306 .55596 L F
.24035 .56321 m .24222 .5612 L .24128 .56103 L .661 .804 .952 r
F
.24521 .55578 m .26076 .55353 L .25822 .551 L .661 .803 .951 r
F
.2491 .55585 m .26076 .55353 L .24521 .55578 L F
.24458 .55677 m .24443 .55659 L .24396 .5619 L .991 .745 .452 r
F
.24458 .55677 m .24396 .5619 L .24406 .56201 L F
.24335 .55609 m .24306 .55596 L .24259 .56127 L .896 .63 .527 r
F
.24335 .55609 m .24259 .56127 L .24278 .56135 L F
.25944 .55641 m .28232 .55523 L .26123 .55365 L .662 .802 .95 r
F
.24592 .55649 m .26188 .55633 L .26076 .55353 L .661 .803 .951 r
F
.24921 .55709 m .26188 .55633 L .24592 .55649 L F
.24458 .55677 m .24406 .56201 L .24495 .55724 L .991 .745 .452 r
F
.24406 .56201 m .2443 .56232 L .24495 .55724 L F
.24236 .56105 m .25462 .5545 L .24985 .55301 L .661 .804 .952 r
F
.24074 .5557 m .24142 .55572 L .24223 .55043 L .734 .476 .538 r
F
.24223 .55043 m .24142 .55572 L .24176 .55572 L F
.24235 .55045 m .24176 .55572 L .24259 .5505 L .807 .543 .539 r
F
.24073 .55016 m .24946 .54188 L .24406 .54108 L .662 .802 .95 r
F
.24164 .55032 m .24946 .54188 L .24073 .55016 L F
.24235 .55045 m .24223 .55043 L .24176 .55572 L .807 .543 .539 r
F
.24019 .55763 m .24968 .54741 L .24424 .54661 L .661 .803 .951 r
F
.24203 .55577 m .24176 .55572 L .24128 .56103 L .807 .543 .539 r
F
.24035 .56321 m .24331 .5614 L .24222 .5612 L .661 .804 .952 r
F
.24035 .56321 m .25841 .55659 L .25462 .5545 L F
.24035 .56321 m .26094 .55911 L .25841 .55659 L F
.24146 .56106 m .24128 .56103 L .24041 .57079 L .807 .543 .539 r
F
.24203 .55577 m .24128 .56103 L .24146 .56106 L F
.24222 .5612 m .24385 .56108 L .24236 .56105 L .661 .804 .952 r
F
.24331 .5614 m .24385 .56108 L .24222 .5612 L F
.24385 .56108 m .25462 .5545 L .24236 .56105 L F
.24142 .55572 m .24061 .56102 L .24176 .55572 L .734 .476 .538 r
F
.24035 .56321 m .24128 .56103 L .24115 .56103 L .661 .804 .952 r
F
.23635 .55678 m .23673 .5562 L .23486 .55645 L .661 .803 .951 r
F
.23673 .5562 m .22357 .55075 L .23486 .55645 L F
.23721 .56096 m .23307 .5529 L .22796 .55432 L .661 .804 .952 r
F
.239 .55594 m .23853 .54657 L .23292 .54729 L .661 .803 .951 r
F
.24019 .55763 m .23989 .55566 L .239 .55594 L F
.23989 .55566 m .23853 .54657 L .239 .55594 L F
.23892 .55597 m .23812 .56138 L .23924 .55587 L .55 .315 .512 r
F
.23812 .56138 m .23832 .56131 L .23924 .55587 L F
.23924 .55587 m .23832 .56131 L .23876 .56117 L F
.23949 .55583 m .23924 .55587 L .23876 .56117 L .656 .407 .53 r
F
.24035 .56321 m .2389 .56116 L .2377 .56131 L .661 .804 .952 r
F
.23949 .55583 m .23876 .56117 L .23892 .56115 L .656 .407 .53 r
F
.23736 .55646 m .23673 .5562 L .23635 .55678 L .661 .803 .951 r
F
.23878 .56099 m .23868 .55218 L .23307 .5529 L .661 .804 .952 r
F
.24035 .56321 m .24001 .56101 L .23878 .56099 L F
.24019 .55763 m .2409 .55571 L .2399 .55569 L .661 .803 .951 r
F
.23949 .55583 m .23892 .56115 L .24015 .55574 L .656 .407 .53 r
F
.23892 .56115 m .23935 .5611 L .24015 .55574 L F
.24015 .55574 m .23935 .5611 L .24048 .5557 L F
.23935 .5611 m .23956 .56107 L .24048 .5557 L F
.24048 .5557 m .23956 .56107 L .24 .56101 L F
.24001 .56101 m .23868 .55218 L .23878 .56099 L .661 .804 .952 r
F
.24074 .5557 m .24048 .5557 L .24 .56101 L .734 .476 .538 r
F
.24074 .5557 m .24 .56101 L .24017 .56101 L F
.24074 .5557 m .24017 .56101 L .24142 .55572 L F
.24017 .56101 m .24061 .56102 L .24142 .55572 L F
.24061 .56102 m .24083 .56102 L .24176 .55572 L F
.24176 .55572 m .24083 .56102 L .24128 .56103 L F
.24131 .55042 m .24074 .5557 L .24223 .55043 L F
.23972 .54997 m .24406 .54108 L .23838 .54103 L .662 .802 .95 r
F
.24073 .55016 m .24406 .54108 L .23972 .54997 L F
.2399 .55569 m .24424 .54661 L .23853 .54657 L .661 .803 .951 r
F
.2409 .55571 m .24424 .54661 L .2399 .55569 L F
.24035 .56321 m .24441 .55222 L .23868 .55218 L .661 .804 .952 r
F
.24017 .56101 m .24 .56101 L .23914 .57067 L .734 .476 .538 r
F
.23892 .56115 m .23876 .56117 L .23789 .57075 L .656 .407 .53 r
F
.2377 .56131 m .23878 .56099 L .23721 .56096 L .661 .804 .952 r
F
.2389 .56116 m .23878 .56099 L .2377 .56131 L F
.23878 .56099 m .23307 .5529 L .23721 .56096 L F
.24017 .56101 m .23914 .57067 L .24061 .56102 L .734 .476 .538 r
F
.24061 .56102 m .23914 .57067 L .24083 .56102 L F
.24128 .56103 m .23914 .57067 L .24041 .57079 L F
.24083 .56102 m .23914 .57067 L .24128 .56103 L F
.24115 .56103 m .24128 .56103 L .24116 .56101 L .661 .804 .952 r
F
.24116 .56101 m .24985 .55301 L .24441 .55222 L F
.24222 .5612 m .24985 .55301 L .24116 .56101 L F
.24191 .56114 m .24041 .57079 L .24213 .56119 L .807 .543 .539 r
F
.24146 .56106 m .24041 .57079 L .24191 .56114 L F
.24248 .5651 m .24266 .57507 L .24156 .57551 L .487 .263 .5 r
F
.24264 .56536 m .24294 .56513 L .24288 .56503 L .661 .804 .952 r
F
.24285 .56494 m .24266 .57507 L .24248 .5651 L .487 .263 .5 r
F
.24223 .56514 m .24248 .5651 L .24156 .57551 L .636 .39 .528 r
F
.24278 .56135 m .24171 .57117 L .24348 .56168 L .896 .63 .527 r
F
.24806 .56377 m .26171 .56478 L .26171 .56476 L .661 .804 .952 r
F
.24808 .56378 m .26171 .56478 L .24806 .56377 L F
.25004 .56263 m .26171 .56476 L .26207 .56191 L F
.24259 .56127 m .24041 .57079 L .24171 .57117 L .807 .543 .539 r
F
.24213 .56119 m .24041 .57079 L .24259 .56127 L F
.2443 .56232 m .24307 .57199 L .24442 .56246 L .991 .745 .452 r
F
.24533 .56358 m .25291 .56599 L .24808 .56378 L .661 .804 .952 r
F
.24605 .56447 m .25291 .56599 L .24533 .56358 L F
.25291 .56599 m .25991 .56753 L .24808 .56378 L F
.24343 .5647 m .24266 .57507 L .24304 .56487 L .487 .263 .5 r
F
.24343 .5647 m .24358 .56464 L .24266 .57507 L F
.24396 .5619 m .24171 .57117 L .24307 .57199 L .896 .63 .527 r
F
.24348 .56168 m .24171 .57117 L .24396 .5619 L F
.24449 .56378 m .24376 .57383 L .24442 .56388 L 0 0 .268 r
F
.2443 .56409 m .24376 .57383 L .24337 .57451 L F
.24442 .56388 m .24376 .57383 L .2443 .56409 L F
.24419 .56417 m .2443 .56409 L .24337 .57451 L .269 .086 .437 r
F
.24466 .56276 m .24307 .57199 L .24376 .57303 L .991 .745 .452 r
F
.24442 .56246 m .24307 .57199 L .24466 .56276 L F
.24406 .56201 m .24396 .5619 L .24307 .57199 L F
.2465 .56502 m .25678 .56998 L .25858 .56858 L .661 .804 .952 r
F
.24739 .56611 m .25678 .56998 L .2465 .56502 L F
.25291 .56599 m .25858 .56858 L .25991 .56753 L F
.24278 .56135 m .24259 .56127 L .24171 .57117 L .896 .63 .527 r
F
.23892 .56115 m .23789 .57075 L .23935 .5611 L .656 .407 .53 r
F
.2377 .56151 m .23668 .57109 L .23812 .56138 L .55 .315 .512 r
F
.23693 .56196 m .23552 .57187 L .23713 .56183 L .329 .133 .455 r
F
.23812 .56138 m .23668 .57109 L .23832 .56131 L .55 .315 .512 r
F
.23382 .56273 m .23399 .56181 L .22945 .56241 L .661 .804 .952 r
F
.23561 .56216 m .23399 .56181 L .23382 .56273 L F
.23399 .56181 m .22061 .55885 L .22945 .56241 L F
.23935 .5611 m .23789 .57075 L .23956 .56107 L .656 .407 .53 r
F
.24 .56101 m .23789 .57075 L .23914 .57067 L F
.23956 .56107 m .23789 .57075 L .24 .56101 L F
.23382 .56273 m .21887 .56163 L .2304 .56381 L .661 .804 .952 r
F
.23876 .56117 m .23668 .57109 L .23789 .57075 L .55 .315 .512 r
F
.23832 .56131 m .23668 .57109 L .23876 .56117 L F
.23754 .56156 m .236 .56943 L .23668 .57109 L .329 .133 .455 r
F
.23713 .56183 m .23552 .57187 L .23754 .56156 L F
.23454 .56356 m .23271 .56367 L .2339 .56399 L .661 .804 .952 r
F
.23454 .56356 m .2339 .56399 L .23498 .56428 L F
.23271 .56367 m .2186 .56451 L .23498 .56428 L F
.23282 .56471 m .21981 .5673 L .22862 .56751 L F
.23654 .56223 m .23552 .57187 L .23693 .56196 L .329 .133 .455 r
F
.23608 .56362 m .23529 .5737 L .23604 .5635 L .952 .765 .308 r
F
.23615 .56386 m .23618 .56395 L .23529 .5737 L F
.23597 .56326 m .23529 .5737 L .23509 .57289 L F
.23604 .5635 m .23529 .5737 L .23597 .56326 L F
.23615 .56386 m .23529 .5737 L .23608 .56362 L F
.23639 .56232 m .23509 .57289 L .23552 .57187 L 0 0 .188 r
F
.23624 .56266 m .23509 .57289 L .23639 .56232 L F
.23511 .56513 m .22862 .56751 L .23485 .56571 L .661 .804 .952 r
F
.22862 .56751 m .22241 .56979 L .22396 .57062 L F
.22862 .56751 m .22396 .57062 L .22622 .57182 L F
.23654 .56223 m .23639 .56232 L .23552 .57187 L .329 .133 .455 r
F
.23602 .56313 m .23509 .57289 L .23624 .56266 L 0 0 .188 r
F
.2318 .57238 m .23097 .57327 L .23169 .57261 L .661 .804 .952 r
F
.23602 .56313 m .23597 .56326 L .23509 .57289 L 0 0 .188 r
F
.24406 .56201 m .24307 .57199 L .2443 .56232 L .991 .745 .452 r
F
.24462 .56356 m .24376 .57383 L .24449 .56378 L 0 0 .268 r
F
.24467 .56286 m .24466 .56276 L .24376 .57303 L .796 .683 .137 r
F
.24475 .56882 m .24751 .57336 L .24474 .56838 L .661 .804 .952 r
F
.24467 .56286 m .24376 .57303 L .24467 .56311 L .796 .683 .137 r
F
.24471 .56634 m .24751 .57336 L .25256 .57197 L .661 .804 .952 r
F
.24474 .56838 m .24751 .57336 L .24471 .56634 L F
.24462 .56356 m .24467 .56347 L .24376 .57383 L 0 0 .268 r
F
.24476 .56946 m .24482 .57371 L .24751 .57336 L .661 .804 .952 r
F
.24467 .56347 m .24376 .57303 L .24376 .57383 L .796 .683 .137 r
F
.24467 .56311 m .24376 .57303 L .24467 .56347 L F
0 g
.30061 .32621 m
.30379 .3272 L
s
.77857 .73422 m .76902 .73207 L .76904 .73677 L .524 .329 .559 r
F
0 g
.76135 .74034 m
.76904 .73677 L
s
.77857 .73422 m .77855 .72952 L .76902 .73207 L .524 .329 .559 r
F
0 g
.76134 .73565 m
.76902 .73207 L
s
.72118 .34737 m .72462 .32505 L .706 .32563 L .643 .737 .917 r
F
.78196 .35055 m .80055 .32626 L .77248 .34081 L F
.78196 .35055 m .81465 .34108 L .80055 .32626 L F
.82858 .73562 m .82069 .72733 L .82076 .73203 L .868 .609 .545 r
F
.82866 .74032 m .82858 .73562 L .82076 .73203 L F
0 g
.82858 .73562 m
.83405 .73998 L
s
.26132 .5877 m .26114 .58223 L .27605 .57814 L .597 .39 .572 r
F
0 g
.25778 .58266 m
.26114 .58223 L
s
.72397 .40369 m
.72513 .42134 L
s
.77191 .3245 m .77978 .29796 L .75867 .31665 L .645 .736 .915 r
F
.77191 .3245 m .79969 .30996 L .77978 .29796 L F
0 g
.71668 .40357 m
.71784 .42193 L
s
.31859 .72979 m .30918 .72642 L .30864 .73112 L .595 .377 .555 r
F
.31859 .72979 m .31912 .72509 L .30918 .72642 L F
0 g
.30084 .72898 m
.30918 .72642 L
s
.59453 .58947 m .59388 .58399 L .59263 .57592 L .738 .53 0 r
F
0 g
.59181 .58964 m
.59379 .58423 L
s
.57271 .58529 m .59357 .58401 L .59232 .57598 L .659 .806 .953 r
F
.27159 .45636 m .28546 .44178 L .26674 .45325 L .657 .779 .938 r
F
.27159 .45636 m .29512 .44808 L .28546 .44178 L F
.35924 .74191 m .35077 .73363 L .35028 .73834 L .849 .609 .575 r
F
0 g
.35924 .74191 m
.36621 .74626 L
s
.79124 .73932 m .78929 .7329 L .77857 .73422 L .597 .767 .96 r
F
.79863 .73932 m .78929 .7329 L .79124 .73932 L F
.80578 .74019 m .80043 .73289 L .79863 .73932 L F
.80578 .74019 m .8112 .7342 L .80043 .73289 L F
.66702 .4599 m .64613 .47553 L .67153 .46729 L .655 .782 .942 r
F
.66702 .4599 m .63918 .46453 L .64613 .47553 L F
0 g
.64613 .47553 m
.65811 .4847 L
s
.1921 .47099 m .16325 .4796 L .19154 .47899 L .656 .78 .94 r
F
.22015 .47439 m .1921 .47099 L .19154 .47899 L F
.35077 .73363 m .35126 .72893 L .34093 .72639 L .79 .553 .578 r
F
0 g
.35126 .72893 m
.3602 .73252 L
s
.69718 .45898 m .67946 .47349 L .70111 .46212 L .655 .782 .942 r
F
.69718 .45898 m .67153 .46729 L .67946 .47349 L F
.57598 .46771 m .57554 .46109 L .55558 .45687 L .798 .541 .549 r
F
0 g
.57554 .46109 m
.59224 .46807 L
s
.2226 .46397 m .19234 .46434 L .22033 .46776 L .657 .779 .939 r
F
.59505 .31731 m .62243 .31286 L .62219 .32103 L .733 .477 .542 r
F
.59505 .31731 m .59535 .30913 L .62243 .31286 L F
0 g
.62243 .31286 m
.62298 .31284 L
s
.79863 .73932 m .80043 .73289 L .78929 .7329 L .597 .767 .96 r
F
.4898 .60145 m .47066 .61066 L .49106 .60674 L .658 .807 .955 r
F
.4898 .60145 m .46864 .60275 L .47066 .61066 L F
0 g
.47066 .61066 m
.47679 .61768 L
s
.51039 .59463 m .49055 .60123 L .51098 .59729 L .658 .806 .954 r
F
.51039 .59463 m .48929 .59593 L .49055 .60123 L F
.60645 .28733 m .62246 .31252 L .62463 .28985 L .645 .736 .915 r
F
.60645 .28733 m .59551 .30881 L .62246 .31252 L F
.57271 .58529 m .59232 .57598 L .57179 .57994 L .659 .806 .953 r
F
.55182 .58656 m .57271 .58529 L .57179 .57994 L F
.36585 .32362 m .33976 .33878 L .36964 .32923 L .643 .738 .918 r
F
.36585 .32362 m .33202 .32766 L .33976 .33878 L F
.1921 .47099 m .16387 .46756 L .16325 .4796 L .656 .78 .94 r
F
0 g
.16325 .4796 m
.16838 .49132 L
s
.46138 .34515 m .50246 .34235 L .4685 .3348 L .643 .738 .918 r
F
.43084 .33244 m .46138 .34515 L .4685 .3348 L F
.42529 .33677 m .46138 .34515 L .43084 .33244 L F
.80135 .45441 m .8005 .44781 L .80625 .43551 L 0 0 .456 r
F
0 g
.79319 .45542 m
.8005 .44781 L
s
.29326 .31397 m .29434 .30573 L .29946 .32346 L .984 .793 .39 r
F
.3298 .30759 m .29946 .32346 L .33299 .31943 L .643 .737 .917 r
F
.3298 .30759 m .29434 .30573 L .29946 .32346 L F
0 g
.29946 .32346 m
.30073 .32524 L
s
.76796 .45858 m .80135 .45441 L .77519 .45094 L .655 .781 .941 r
F
.24519 .59527 m .24502 .58977 L .26132 .5877 L .671 .448 .574 r
F
.22852 .59521 m .24502 .58977 L .24519 .59527 L .733 .498 .571 r
F
.22852 .59521 m .22839 .58971 L .24502 .58977 L F
.27478 .47322 m .29524 .46127 L .27152 .46956 L .656 .78 .94 r
F
.27478 .47322 m .30166 .46864 L .29524 .46127 L F
.22291 .45739 m .19724 .45014 L .19285 .45776 L .657 .779 .938 r
F
.22691 .45409 m .19724 .45014 L .22291 .45739 L F
.78925 .72818 m .77852 .72482 L .77855 .72952 L .605 .394 .568 r
F
.78925 .72818 m .78921 .72348 L .77852 .72482 L F
0 g
.76901 .72738 m
.77852 .72482 L
s
.82866 .74032 m .82076 .73203 L .82084 .73674 L .868 .609 .545 r
F
0 g
.82866 .74032 m
.83414 .74468 L
s
.82076 .73203 m .82069 .72733 L .81107 .72478 L .797 .549 .563 r
F
0 g
.82069 .72733 m
.82849 .73092 L
s
.503 .33411 m .50767 .30864 L .50714 .31687 L 0 0 .106 r
F
.50246 .34235 m .503 .33411 L .50714 .31687 L F
.46913 .32656 m .503 .33411 L .50714 .31687 L .643 .737 .917 r
F
0 g
.49789 .34133 m
.503 .33411 L
s
.81439 .33283 m .81414 .32462 L .80012 .30974 L .958 .67 .446 r
F
0 g
.81414 .32462 m
.8213 .34119 L
s
.31806 .7345 m .30864 .73112 L .3081 .73582 L .595 .377 .555 r
F
0 g
.29974 .73836 m
.3081 .73582 L
s
.31806 .7345 m .31859 .72979 L .30864 .73112 L .595 .377 .555 r
F
0 g
.30029 .73366 m
.30864 .73112 L
s
.6938 .44194 m .66608 .44657 L .67056 .45397 L .656 .78 .94 r
F
.55182 .58656 m .57179 .57994 L .55132 .5839 L .659 .806 .953 r
F
.35077 .73363 m .34093 .72639 L .34043 .73109 L .79 .553 .578 r
F
.35028 .73834 m .35077 .73363 L .34043 .73109 L F
0 g
.35077 .73363 m
.35972 .73721 L
s
.26132 .5877 m .27605 .57814 L .27625 .58362 L .597 .39 .572 r
F
.26151 .5932 m .26132 .5877 L .27625 .58362 L F
.24519 .59527 m .26132 .5877 L .26151 .5932 L .671 .448 .574 r
F
.25439 .57784 m .26132 .5877 L .27625 .58362 L .661 .803 .951 r
F
0 g
.24502 .58977 m
.26132 .5877 L
s
.3017 .46201 m .31921 .44624 L .2953 .45462 L .657 .779 .939 r
F
.3017 .46201 m .32864 .45741 L .31921 .44624 L F
.59453 .58947 m .59263 .57592 L .59327 .58142 L .738 .53 0 r
F
.57353 .59076 m .59453 .58947 L .59327 .58142 L .658 .806 .954 r
F
.59517 .59496 m .59453 .58947 L .59327 .58142 L .738 .53 0 r
F
0 g
.59244 .59513 m
.59444 .58971 L
s
.32945 .72978 m .31912 .72509 L .31859 .72979 L .67 .444 .568 r
F
.32945 .72978 m .32996 .72508 L .31912 .72509 L F
0 g
.30918 .72642 m
.31912 .72509 L
s
.34043 .73109 m .34093 .72639 L .32996 .72508 L .733 .5 .576 r
F
0 g
.34093 .72639 m
.35126 .72893 L
s
.57 .30919 m .59535 .30913 L .59505 .31731 L .801 .536 .538 r
F
.57 .30919 m .57037 .30101 L .59535 .30913 L F
0 g
.59535 .30913 m
.62243 .31286 L
s
.36633 .30124 m .33113 .2994 L .3343 .31121 L .644 .737 .916 r
F
.32864 .45741 m .32864 .45081 L .31922 .4396 L .983 .719 .444 r
F
0 g
.32864 .45081 m
.33244 .46277 L
s
.27625 .58362 m .27605 .57814 L .28862 .57229 L .497 .313 .562 r
F
0 g
.26597 .5809 m
.27605 .57814 L
s
.27161 .46293 m .28558 .4483 L .26673 .45981 L .657 .779 .939 r
F
.27161 .46293 m .2953 .45462 L .28558 .4483 L F
.58972 .28183 m .59551 .30881 L .60645 .28733 L .645 .736 .915 r
F
.58972 .28183 m .57065 .30072 L .59551 .30881 L F
.19724 .45014 m .16487 .45432 L .19285 .45776 L .657 .779 .938 r
F
.46941 .31828 m .50714 .30861 L .47193 .30677 L .644 .737 .916 r
F
.51093 .60015 m .49106 .60674 L .51151 .6028 L .658 .807 .955 r
F
.51093 .60015 m .4898 .60145 L .49106 .60674 L F
.57353 .59076 m .59327 .58142 L .57261 .58541 L .658 .806 .954 r
F
.55251 .59205 m .57353 .59076 L .57261 .58541 L F
.51214 .46444 m .49125 .4629 L .49154 .46953 L .596 .384 .565 r
F
.51214 .46444 m .51181 .4578 L .49125 .4629 L F
0 g
.47362 .47062 m
.49125 .4629 L
s
.55217 .60029 m .57415 .59626 L .5531 .59755 L .658 .807 .955 r
F
.57598 .46771 m .55558 .45687 L .55599 .4635 L .798 .541 .549 r
F
.57643 .47435 m .57598 .46771 L .55599 .4635 L F
0 g
.57598 .46771 m
.59271 .47466 L
s
.34043 .73109 m .32996 .72508 L .32945 .72978 L .733 .5 .576 r
F
0 g
.32996 .72508 m
.34093 .72639 L
s
.31912 .72509 m
.32996 .72508 L
s
.22059 .33276 m .19728 .32988 L .19597 .33812 L .569 .331 .515 r
F
0 g
.17573 .34753 m
.19597 .33812 L
s
.22059 .33276 m .22185 .32451 L .19728 .32988 L .569 .331 .515 r
F
0 g
.1771 .33932 m
.19728 .32988 L
s
.22241 .47061 m .1921 .47099 L .22015 .47439 L .656 .78 .94 r
F
.26674 .45325 m .27315 .437 L .26061 .4509 L .657 .779 .938 r
F
.26674 .45325 m .28546 .44178 L .27315 .437 L F
.78929 .7329 m .77855 .72952 L .77857 .73422 L .605 .394 .568 r
F
0 g
.76904 .73677 m
.77857 .73422 L
s
.78929 .7329 m .78925 .72818 L .77855 .72952 L .605 .394 .568 r
F
0 g
.76902 .73207 m
.77855 .72952 L
s
.3017 .34365 m .30275 .33541 L .27665 .32738 L .796 .54 .552 r
F
0 g
.30275 .33541 m
.32535 .34708 L
s
.29955 .33442 m
.30275 .33541 L
s
.29872 .33417 m
.29955 .33442 L
s
.21258 .593 m .22839 .58971 L .22852 .59521 L .791 .544 .564 r
F
.21258 .593 m .21247 .58749 L .22839 .58971 L F
.22159 .57767 m .21247 .58749 L .22839 .58971 L .661 .803 .951 r
F
0 g
.22839 .58971 m
.24502 .58977 L
s
.82076 .73203 m .81107 .72478 L .81113 .72949 L .797 .549 .563 r
F
.82084 .73674 m .82076 .73203 L .81113 .72949 L F
0 g
.82076 .73203 m
.82858 .73562 L
s
.2436 .58475 m .24519 .59527 L .26151 .5932 L .661 .804 .952 r
F
.23241 .5847 m .24519 .59527 L .2436 .58475 L F
.23241 .5847 m .22852 .59521 L .24519 .59527 L F
.35028 .73834 m .34043 .73109 L .33993 .73581 L .79 .553 .578 r
F
0 g
.35028 .73834 m
.35924 .74191 L
s
.51081 .58638 m .489 .59041 L .50997 .58913 L .659 .806 .953 r
F
.77234 .33256 m .78027 .30594 L .75899 .32468 L .644 .736 .916 r
F
.77234 .33256 m .80033 .31797 L .78027 .30594 L F
.80135 .45441 m .80625 .43551 L .80711 .44214 L 0 0 .456 r
F
.80219 .46103 m .80135 .45441 L .80711 .44214 L F
.77519 .45094 m .80135 .45441 L .80711 .44214 L .655 .781 .941 r
F
0 g
.79397 .46205 m
.80135 .45441 L
s
.80037 .72817 m .78921 .72348 L .78925 .72818 L .671 .447 .572 r
F
.80037 .72817 m .80032 .72347 L .78921 .72348 L F
0 g
.77852 .72482 m
.78921 .72348 L
s
.55251 .59205 m .57261 .58541 L .55201 .58938 L .658 .806 .954 r
F
.81113 .72949 m .81107 .72478 L .80032 .72347 L .733 .497 .57 r
F
0 g
.81107 .72478 m
.82069 .72733 L
s
.26151 .5932 m .27625 .58362 L .27645 .58912 L .597 .39 .572 r
F
.25456 .58336 m .26151 .5932 L .27645 .58912 L .661 .804 .952 r
F
.2436 .58475 m .26151 .5932 L .25456 .58336 L F
0 g
.24519 .59527 m
.26151 .5932 L
s
.76874 .4652 m .80219 .46103 L .77599 .45757 L .655 .782 .942 r
F
.74603 .45794 m .76874 .4652 L .77599 .45757 L F
.74092 .46127 m .76874 .4652 L .74603 .45794 L F
.32893 .7345 m .31859 .72979 L .31806 .7345 L .67 .444 .568 r
F
0 g
.3081 .73582 m
.31806 .7345 L
s
.32893 .7345 m .32945 .72978 L .31859 .72979 L .67 .444 .568 r
F
0 g
.30864 .73112 m
.31859 .72979 L
s
.59517 .59496 m .59327 .58142 L .59392 .58694 L .738 .53 0 r
F
.57415 .59626 m .59517 .59496 L .59392 .58694 L .658 .807 .955 r
F
0 g
.59214 .60315 m
.59517 .59496 L
s
.33993 .73581 m .34043 .73109 L .32945 .72978 L .733 .5 .576 r
F
0 g
.34043 .73109 m
.35077 .73363 L
s
.2226 .46397 m .19675 .45671 L .19234 .46434 L .657 .779 .939 r
F
.22662 .46066 m .19675 .45671 L .2226 .46397 L F
.59474 .32552 m .62219 .32103 L .62196 .32925 L .733 .477 .542 r
F
.59474 .32552 m .59505 .31731 L .62219 .32103 L F
.60606 .29577 m .62219 .32103 L .62438 .29831 L .644 .736 .916 r
F
.60606 .29577 m .59505 .31731 L .62219 .32103 L F
0 g
.62219 .32103 m
.62275 .32102 L
s
.69432 .4486 m .66641 .45325 L .67092 .46066 L .655 .781 .941 r
F
0 g
.40514 .28071 m
.40752 .22366 L
s
.22691 .45409 m .2052 .44345 L .19724 .45014 L .657 .779 .938 r
F
.2324 .4515 m .2052 .44345 L .22691 .45409 L F
0 g
.39784 .28022 m
.40034 .22352 L
s
.30166 .46864 m .3192 .4529 L .29524 .46127 L .656 .78 .94 r
F
.30166 .46864 m .32865 .46405 L .3192 .4529 L F
.49061 .5849 m .46801 .5917 L .489 .59041 L .659 .806 .953 r
F
.51081 .58638 m .49061 .5849 L .489 .59041 L F
.81113 .72949 m .80032 .72347 L .80037 .72817 L .733 .497 .57 r
F
0 g
.80032 .72347 m
.81107 .72478 L
s
.78921 .72348 m
.80032 .72347 L
s
.25439 .57784 m .27625 .58362 L .2644 .57508 L .661 .803 .951 r
F
.27625 .58362 m .28862 .57229 L .28884 .57778 L .497 .313 .562 r
F
.27645 .58912 m .27625 .58362 L .28884 .57778 L F
.2644 .57508 m .27625 .58362 L .28884 .57778 L .661 .803 .951 r
F
0 g
.26611 .5864 m
.27625 .58362 L
s
.55132 .5839 m .56806 .5751 L .54942 .5815 L .659 .806 .953 r
F
.55132 .5839 m .57179 .57994 L .56806 .5751 L F
.33993 .73581 m .32945 .72978 L .32893 .7345 L .733 .5 .576 r
F
0 g
.32945 .72978 m
.34043 .73109 L
s
.33993 .73581 m
.35028 .73834 L
s
.31859 .72979 m
.32945 .72978 L
s
.32881 .31584 m .29841 .33166 L .33202 .32766 L .643 .738 .918 r
F
.32881 .31584 m .29326 .31397 L .29841 .33166 L F
0 g
.29841 .33166 m
.29968 .33344 L
s
.24898 .32364 m .2231 .3163 L .22185 .32451 L .661 .414 .535 r
F
.24898 .32364 m .25017 .31543 L .2231 .3163 L F
0 g
.19859 .32169 m
.2231 .3163 L
s
.57415 .59626 m .59392 .58694 L .57323 .59092 L .658 .807 .955 r
F
.5531 .59755 m .57415 .59626 L .57323 .59092 L F
.27665 .32738 m .27776 .31916 L .25017 .31543 L .732 .48 .547 r
F
0 g
.27776 .31916 m
.29645 .32493 L
s
.32864 .45741 m .31922 .4396 L .31921 .44624 L .983 .719 .444 r
F
.32865 .46405 m .32864 .45741 L .31921 .44624 L F
0 g
.32864 .45741 m
.33246 .46935 L
s
.82084 .73674 m .81113 .72949 L .8112 .7342 L .797 .549 .563 r
F
0 g
.82084 .73674 m
.82866 .74032 L
s
.27152 .46956 m .28551 .45497 L .26663 .46645 L .656 .78 .94 r
F
.27152 .46956 m .29524 .46127 L .28551 .45497 L F
.19675 .45671 m .16416 .4609 L .19234 .46434 L .657 .779 .939 r
F
.22172 .5832 m .22852 .59521 L .23241 .5847 L .661 .804 .952 r
F
.22172 .5832 m .21258 .593 L .22852 .59521 L F
0 g
.22852 .59521 m
.24519 .59527 L
s
.50246 .34235 m .50714 .31687 L .5066 .32514 L 0 0 .106 r
F
.4685 .3348 m .50246 .34235 L .5066 .32514 L .643 .738 .918 r
F
0 g
.49154 .35771 m
.50246 .34235 L
s
.81439 .33283 m .80012 .30974 L .80033 .31797 L .958 .67 .446 r
F
.81465 .34108 m .81439 .33283 L .80033 .31797 L F
0 g
.81439 .33283 m
.82157 .34937 L
s
.1983 .58326 m .21235 .58199 L .21247 .58749 L .849 .593 .551 r
F
.1983 .58326 m .1982 .57774 L .21235 .58199 L F
0 g
.21235 .58199 m
.21697 .58264 L
s
.49061 .5849 m .4703 .58342 L .46801 .5917 L .659 .806 .953 r
F
.47047 .58893 m .4677 .59172 L .46817 .59723 L 0 0 .325 r
F
0 g
.46865 .59549 m
.46908 .59717 L
s
.47047 .58893 m .47 .5834 L .4677 .59172 L 0 0 .325 r
F
.51247 .47111 m .49154 .46953 L .49183 .47618 L .596 .384 .565 r
F
0 g
.47414 .48388 m
.49183 .47618 L
s
.51247 .47111 m .51214 .46444 L .49154 .46953 L .596 .384 .565 r
F
0 g
.47388 .47724 m
.49154 .46953 L
s
.55599 .4635 m .55558 .45687 L .53379 .45574 L .734 .491 .561 r
F
0 g
.55558 .45687 m
.57554 .46109 L
s
.80043 .73289 m .78925 .72818 L .78929 .7329 L .671 .447 .572 r
F
0 g
.77857 .73422 m
.78929 .7329 L
s
.80043 .73289 m .80037 .72817 L .78925 .72818 L .671 .447 .572 r
F
0 g
.77855 .72952 m
.78925 .72818 L
s
.57643 .47435 m .55599 .4635 L .5564 .47016 L .798 .541 .549 r
F
0 g
.57643 .47435 m
.59319 .48128 L
s
.8112 .7342 m .81113 .72949 L .80037 .72817 L .733 .497 .57 r
F
0 g
.81113 .72949 m
.82076 .73203 L
s
.75867 .31665 m .75529 .28973 L .74249 .31128 L .645 .736 .915 r
F
.75867 .31665 m .77978 .29796 L .75529 .28973 L F
.51124 .59188 m .48929 .59593 L .51039 .59463 L .658 .806 .954 r
F
0 g
.31806 .7345 m
.32893 .7345 L
s
.32893 .7345 m
.33993 .73581 L
s
.26061 .4509 m .25904 .43411 L .25361 .44949 L .657 .779 .938 r
F
.26061 .4509 m .27315 .437 L .25904 .43411 L F
.5531 .59755 m .57323 .59092 L .5526 .59489 L .658 .807 .955 r
F
.26673 .45981 m .27318 .44352 L .26056 .45746 L .657 .779 .939 r
F
.26673 .45981 m .28558 .4483 L .27318 .44352 L F
.36526 .30944 m .3298 .30759 L .33299 .31943 L .643 .737 .917 r
F
.56963 .31742 m .59505 .31731 L .59474 .32552 L .801 .536 .538 r
F
.56963 .31742 m .57 .30919 L .59505 .31731 L F
.5892 .29025 m .59505 .31731 L .60606 .29577 L .644 .736 .916 r
F
.5892 .29025 m .57 .30919 L .59505 .31731 L F
0 g
.59505 .31731 m
.62219 .32103 L
s
.63728 .44572 m .63807 .45125 L .63862 .45788 L .731 .545 0 r
F
.63728 .44572 m .63673 .43907 L .63807 .45125 L F
0 g
.63807 .45125 m
.64188 .45734 L
s
.33093 .8303 m .3343 .82653 L .33445 .82937 L .6 .388 .565 r
F
.33445 .82937 m .3343 .82653 L .33728 .82523 L .506 .317 .558 r
F
0 g
.33388 .82664 m
.3343 .82653 L
s
.66535 .43847 m .63848 .45119 L .66608 .44657 L .656 .78 .94 r
F
.66535 .43847 m .63715 .43906 L .63848 .45119 L F
.46913 .32656 m .50714 .31687 L .47166 .31501 L .643 .737 .917 r
F
.43503 .31895 m .46913 .32656 L .47166 .31501 L F
.80219 .46103 m .80711 .44214 L .80797 .44879 L 0 0 .456 r
F
.77599 .45757 m .80219 .46103 L .80797 .44879 L .655 .782 .942 r
F
0 g
.79119 .47237 m
.80219 .46103 L
s
.8112 .7342 m .80037 .72817 L .80043 .73289 L .733 .497 .57 r
F
0 g
.80037 .72817 m
.81113 .72949 L
s
.8112 .7342 m
.82084 .73674 L
s
.78925 .72818 m
.80037 .72817 L
s
.51304 .58372 m .49061 .5849 L .51081 .58638 L .659 .806 .953 r
F
.32725 .83364 m .32711 .8308 L .33093 .8303 L .67 .442 .566 r
F
.32338 .83368 m .32711 .8308 L .32725 .83364 L .73 .489 .562 r
F
.32338 .83368 m .32324 .83084 L .32711 .8308 L F
.32689 .82853 m .32711 .8308 L .33093 .8303 L .658 .812 .957 r
F
.32431 .82856 m .32711 .8308 L .32689 .82853 L F
.32431 .82856 m .32324 .83084 L .32711 .8308 L F
.49091 .59041 m .46817 .59723 L .48929 .59593 L .658 .806 .954 r
F
.51124 .59188 m .49091 .59041 L .48929 .59593 L F
.25456 .58336 m .27645 .58912 L .26459 .58061 L .661 .804 .952 r
F
.27645 .58912 m .28884 .57778 L .28906 .58329 L .497 .313 .562 r
F
.26459 .58061 m .27645 .58912 L .28906 .58329 L .661 .804 .952 r
F
0 g
.26151 .5932 m
.27645 .58912 L
s
.33107 .83314 m .33093 .8303 L .33445 .82937 L .6 .388 .565 r
F
.32725 .83364 m .33093 .8303 L .33107 .83314 L .67 .442 .566 r
F
.32944 .8282 m .33093 .8303 L .33445 .82937 L .658 .812 .957 r
F
.32689 .82853 m .33093 .8303 L .32944 .8282 L F
0 g
.32711 .8308 m
.33093 .8303 L
s
.2324 .4515 m .21621 .43818 L .2052 .44345 L .657 .779 .938 r
F
.23899 .4498 m .21621 .43818 L .2324 .4515 L F
.22241 .47061 m .19652 .46337 L .1921 .47099 L .656 .78 .94 r
F
.22645 .46731 m .19652 .46337 L .22241 .47061 L F
.29512 .44808 m .30444 .43015 L .28546 .44178 L .657 .779 .938 r
F
.29512 .44808 m .31886 .43973 L .30444 .43015 L F
.55201 .58938 m .56886 .58055 L .5501 .58697 L .658 .806 .954 r
F
.55201 .58938 m .57261 .58541 L .56886 .58055 L F
.31639 .82954 m .31945 .82756 L .31959 .83041 L .847 .582 .537 r
F
.31639 .82954 m .31626 .8267 L .31945 .82756 L F
0 g
.31945 .82756 m
.32207 .82787 L
s
.57179 .57994 m .58682 .56867 L .56806 .5751 L .659 .806 .953 r
F
.57179 .57994 m .59232 .57598 L .58682 .56867 L F
.53417 .46238 m .51181 .4578 L .51214 .46444 L .669 .441 .566 r
F
.53417 .46238 m .53379 .45574 L .51181 .4578 L F
0 g
.49125 .4629 m
.51181 .4578 L
s
.31964 .82483 m .31949 .82753 L .32175 .8254 L .659 .811 .957 r
F
.31964 .82483 m .31631 .82667 L .31949 .82753 L F
.27665 .32738 m .25017 .31543 L .24898 .32364 L .732 .48 .547 r
F
0 g
.25017 .31543 m
.27776 .31916 L
s
.2231 .3163 m
.25017 .31543 L
s
.69498 .45526 m .67153 .46729 L .69718 .45898 L .655 .782 .942 r
F
.69498 .45526 m .66702 .4599 L .67153 .46729 L F
.3017 .34365 m .27665 .32738 L .27553 .33564 L .796 .54 .552 r
F
0 g
.3017 .34365 m
.32436 .35531 L
s
.31972 .83326 m .32324 .83084 L .32338 .83368 L .787 .534 .553 r
F
.31972 .83326 m .31959 .83041 L .32324 .83084 L F
.32187 .82827 m .32324 .83084 L .32431 .82856 L .658 .812 .957 r
F
.32187 .82827 m .31959 .83041 L .32324 .83084 L F
0 g
.32324 .83084 m
.32711 .8308 L
s
.22662 .46066 m .20477 .45 L .19675 .45671 L .657 .779 .939 r
F
.23215 .45806 m .20477 .45 L .22662 .46066 L F
.67271 .33558 m .64954 .31835 L .63115 .33148 L .643 .737 .917 r
F
0 g
.61903 .34697 m
.63115 .33148 L
s
.68827 .32923 m .64954 .31835 L .67271 .33558 L .643 .737 .917 r
F
.33743 .82807 m .33728 .82523 L .33952 .82365 L .36 .208 .535 r
F
.33445 .82937 m .33728 .82523 L .33743 .82807 L .506 .317 .558 r
F
0 g
.3343 .82653 m
.33728 .82523 L
s
.33459 .83221 m .33445 .82937 L .33743 .82807 L .506 .317 .558 r
F
.33107 .83314 m .33445 .82937 L .33459 .83221 L .6 .388 .565 r
F
.33179 .82758 m .33445 .82937 L .33743 .82807 L .658 .812 .957 r
F
.32944 .8282 m .33445 .82937 L .33179 .82758 L F
0 g
.33093 .8303 m
.33445 .82937 L
s
.78929 .7329 m
.80043 .73289 L
s
.19724 .45014 m .17129 .4428 L .16487 .45432 L .657 .779 .938 r
F
0 g
.80043 .73289 m
.8112 .7342 L
s
.1984 .58879 m .21247 .58749 L .21258 .593 L .849 .593 .551 r
F
.1984 .58879 m .1983 .58326 L .21247 .58749 L F
.21212 .5748 m .21247 .58749 L .22159 .57767 L .661 .803 .951 r
F
.21212 .5748 m .1983 .58326 L .21247 .58749 L F
0 g
.21247 .58749 m
.21712 .58814 L
s
.77248 .34081 m .78044 .31424 L .75911 .33294 L .643 .737 .917 r
F
.77248 .34081 m .80055 .32626 L .78044 .31424 L F
.17061 .44936 m .16445 .45427 L .16416 .4609 L 0 0 .333 r
F
.17061 .44936 m .17089 .44269 L .16445 .45427 L F
0 g
.16383 .46637 m
.16445 .45427 L
s
.28884 .57778 m .28862 .57229 L .29802 .56503 L .339 .195 .533 r
F
0 g
.27912 .57671 m
.28862 .57229 L
s
.79152 .8289 m .79438 .82649 L .79488 .82933 L .793 .527 .535 r
F
.79152 .8289 m .79103 .82606 L .79438 .82649 L F
0 g
.79438 .82649 m
.79691 .82646 L
s
.79402 .82389 m .79441 .82645 L .79625 .82418 L .654 .816 .961 r
F
.79402 .82389 m .79107 .82603 L .79441 .82645 L F
.25361 .44949 m .24413 .43333 L .24623 .44911 L .657 .779 .938 r
F
.25361 .44949 m .25904 .43411 L .24413 .43333 L F
.49091 .59041 m .47047 .58893 L .46817 .59723 L .658 .806 .954 r
F
.47095 .59448 m .46817 .59723 L .46864 .60275 L 0 0 .325 r
F
0 g
.46913 .60101 m
.46956 .6027 L
s
.47095 .59448 m .47047 .58893 L .46817 .59723 L 0 0 .325 r
F
.54942 .5815 m .56174 .5711 L .54625 .57952 L .659 .806 .953 r
F
.54942 .5815 m .56806 .5751 L .56174 .5711 L F
.32865 .46405 m .31921 .44624 L .3192 .4529 L .983 .719 .444 r
F
0 g
.32865 .46405 m
.33247 .47595 L
s
.32703 .83138 m .32725 .83364 L .33107 .83314 L .658 .812 .957 r
F
.32444 .83141 m .32725 .83364 L .32703 .83138 L F
.32444 .83141 m .32338 .83368 L .32725 .83364 L F
.51178 .5974 m .4898 .60145 L .51093 .60015 L .658 .807 .955 r
F
.55599 .4635 m .53379 .45574 L .53417 .46238 L .734 .491 .561 r
F
0 g
.51181 .4578 m
.53379 .45574 L
s
.53379 .45574 m
.55558 .45687 L
s
.32958 .83105 m .33107 .83314 L .33459 .83221 L .658 .812 .957 r
F
.32703 .83138 m .33107 .83314 L .32958 .83105 L F
0 g
.32725 .83364 m
.33107 .83314 L
s
.54861 .29715 m .57037 .30101 L .57 .30919 L .87 .6 .527 r
F
.54861 .29715 m .54904 .28894 L .57037 .30101 L F
0 g
.57037 .30101 m
.57633 .30294 L
s
.19652 .46337 m .16387 .46756 L .1921 .47099 L .656 .78 .94 r
F
.31653 .83239 m .31959 .83041 L .31972 .83326 L .847 .582 .537 r
F
.31653 .83239 m .31639 .82954 L .31959 .83041 L F
.31974 .82769 m .31959 .83041 L .32187 .82827 L .658 .812 .957 r
F
.31974 .82769 m .31639 .82954 L .31959 .83041 L F
0 g
.31959 .83041 m
.32324 .83084 L
s
.63185 .32895 m
.6324 .32893 L
s
.60578 .30404 m .62196 .32925 L .62414 .30657 L .644 .737 .917 r
F
.60578 .30404 m .59474 .32552 L .62196 .32925 L F
0 g
.62196 .32925 m
.63185 .32895 L
s
.23899 .4498 m .2295 .43472 L .21621 .43818 L .657 .779 .938 r
F
.24623 .44911 m .2295 .43472 L .23899 .4498 L F
.57552 .27367 m .57065 .30072 L .58972 .28183 L .645 .736 .915 r
F
.57552 .27367 m .54943 .28872 L .57065 .30072 L F
.5564 .47016 m .55599 .4635 L .53417 .46238 L .734 .491 .561 r
F
0 g
.55599 .4635 m
.57598 .46771 L
s
.79911 .83214 m .79861 .82929 L .80246 .82879 L .671 .445 .569 r
F
.79537 .83218 m .79861 .82929 L .79911 .83214 L .731 .485 .556 r
F
.79537 .83218 m .79488 .82933 L .79861 .82929 L F
.79922 .82702 m .79861 .82929 L .80246 .82879 L .653 .817 .962 r
F
.79673 .82705 m .79861 .82929 L .79922 .82702 L F
.79673 .82705 m .79488 .82933 L .79861 .82929 L F
.322 .83112 m .32338 .83368 L .32444 .83141 L .658 .812 .957 r
F
.322 .83112 m .31972 .83326 L .32338 .83368 L F
0 g
.32338 .83368 m
.32725 .83364 L
s
.39783 .44394 m .39771 .43733 L .41964 .43526 L .669 .439 .564 r
F
.37573 .44279 m .39771 .43733 L .39783 .44394 L .734 .492 .562 r
F
.37573 .44279 m .37564 .43617 L .39771 .43733 L F
.31388 .8283 m .31626 .8267 L .31639 .82954 L .913 .637 .505 r
F
.31388 .8283 m .31375 .82545 L .31626 .8267 L F
0 g
.31626 .8267 m
.31945 .82756 L
s
.80296 .83164 m .80246 .82879 L .80618 .82786 L .609 .403 .577 r
F
.79911 .83214 m .80246 .82879 L .80296 .83164 L .671 .445 .569 r
F
.80179 .82669 m .80246 .82879 L .80618 .82786 L .653 .817 .962 r
F
.79922 .82702 m .80246 .82879 L .80179 .82669 L F
0 g
.79861 .82929 m
.80246 .82879 L
s
.31797 .824 m .31631 .82667 L .31964 .82483 L .659 .811 .957 r
F
.31797 .824 m .31381 .82543 L .31631 .82667 L F
.24623 .44911 m .24413 .43333 L .2295 .43472 L .657 .779 .938 r
F
.33743 .82807 m .33952 .82365 L .33967 .8265 L .36 .208 .535 r
F
.33758 .83092 m .33743 .82807 L .33967 .8265 L F
.33459 .83221 m .33743 .82807 L .33758 .83092 L .506 .317 .558 r
F
.33378 .82671 m .33743 .82807 L .33967 .8265 L .658 .812 .957 r
F
.33179 .82758 m .33743 .82807 L .33378 .82671 L F
0 g
.33445 .82937 m
.33743 .82807 L
s
.33193 .83043 m .33459 .83221 L .33758 .83092 L .658 .812 .957 r
F
.32958 .83105 m .33459 .83221 L .33193 .83043 L F
0 g
.33107 .83314 m
.33459 .83221 L
s
.39719 .42119 m .3977 .4371 L .41953 .43503 L .658 .778 .938 r
F
.3824 .4204 m .3977 .4371 L .39719 .42119 L F
.3824 .4204 m .37574 .43594 L .3977 .4371 L F
.78877 .82804 m .79103 .82606 L .79152 .8289 L .865 .576 .497 r
F
.78877 .82804 m .78828 .82519 L .79103 .82606 L F
0 g
.79103 .82606 m
.79438 .82649 L
s
.7922 .82331 m .79107 .82603 L .79402 .82389 L .654 .816 .961 r
F
.7922 .82331 m .78834 .82516 L .79107 .82603 L F
.26056 .45746 m .25898 .44062 L .25351 .45604 L .657 .779 .939 r
F
.26056 .45746 m .27318 .44352 L .25898 .44062 L F
.26663 .46645 m .27309 .4502 L .26044 .46411 L .656 .78 .94 r
F
.26663 .46645 m .28551 .45497 L .27309 .4502 L F
.77519 .45094 m .80711 .44214 L .77889 .44274 L .655 .781 .941 r
F
.79202 .83175 m .79488 .82933 L .79537 .83218 L .793 .527 .535 r
F
.79202 .83175 m .79152 .8289 L .79488 .82933 L F
.79449 .82676 m .79488 .82933 L .79673 .82705 L .653 .817 .962 r
F
.79449 .82676 m .79152 .8289 L .79488 .82933 L F
0 g
.79488 .82933 m
.79861 .82929 L
s
.51348 .58921 m .49091 .59041 L .51124 .59188 L .658 .806 .954 r
F
.24779 .33191 m .22185 .32451 L .22059 .33276 L .661 .414 .535 r
F
0 g
.19597 .33812 m
.22059 .33276 L
s
.24779 .33191 m .24898 .32364 L .22185 .32451 L .661 .414 .535 r
F
0 g
.19728 .32988 m
.22185 .32451 L
s
.49142 .59594 m .46864 .60275 L .4898 .60145 L .658 .807 .955 r
F
.51178 .5974 m .49142 .59594 L .4898 .60145 L F
0 g
.63115 .33148 m
.63235 .33062 L
s
.63784 .45241 m .63862 .45788 L .63918 .46453 L .731 .545 0 r
F
.63784 .45241 m .63728 .44572 L .63862 .45788 L F
.66567 .44512 m .63862 .45788 L .66641 .45325 L .655 .781 .941 r
F
.66567 .44512 m .63728 .44572 L .63862 .45788 L F
0 g
.63862 .45788 m
.64246 .46398 L
s
.33967 .8265 m .33952 .82365 L .34086 .8219 L .09 .01 .462 r
F
0 g
.33728 .82523 m
.33952 .82365 L
s
.33508 .8228 m .33945 .82364 L .34079 .82189 L .659 .811 .957 r
F
.3336 .82385 m .33945 .82364 L .33508 .8228 L F
.27553 .33564 m .27665 .32738 L .24898 .32364 L .732 .48 .547 r
F
0 g
.27665 .32738 m
.29872 .33417 L
s
.80951 .82656 m .80901 .82372 L .81173 .82214 L .44 .29 .58 r
F
.80618 .82786 m .80901 .82372 L .80951 .82656 L .537 .355 .582 r
F
0 g
.80862 .82387 m
.80901 .82372 L
s
.80668 .83071 m .80618 .82786 L .80951 .82656 L .537 .355 .582 r
F
.80296 .83164 m .80618 .82786 L .80668 .83071 L .609 .403 .577 r
F
.80428 .82607 m .80618 .82786 L .80951 .82656 L .653 .817 .962 r
F
.80179 .82669 m .80618 .82786 L .80428 .82607 L F
0 g
.80246 .82879 m
.80618 .82786 L
s
.5526 .59489 m .56948 .58609 L .55069 .59249 L .658 .807 .955 r
F
.5526 .59489 m .57323 .59092 L .56948 .58609 L F
.57261 .58541 m .58775 .5741 L .56886 .58055 L .658 .806 .954 r
F
.57261 .58541 m .59327 .58142 L .58775 .5741 L F
.59327 .58142 m .59263 .57592 L .58711 .56857 L .977 .681 .308 r
F
0 g
.59263 .57592 m
.59388 .58399 L
s
.41981 .44187 m .41964 .43526 L .4401 .43007 L .592 .379 .561 r
F
.39783 .44394 m .41964 .43526 L .41981 .44187 L .669 .439 .564 r
F
0 g
.39771 .43733 m
.41964 .43526 L
s
.31987 .83054 m .31972 .83326 L .322 .83112 L .658 .812 .957 r
F
.31987 .83054 m .31653 .83239 L .31972 .83326 L F
0 g
.31972 .83326 m
.32338 .83368 L
s
.81465 .34108 m .80033 .31797 L .80055 .32626 L .958 .67 .446 r
F
0 g
.81465 .34108 m
.82184 .35759 L
s
.53234 .68543 m .53192 .6922 L .53932 .69218 L .598 .766 .96 r
F
.52865 .68498 m .53192 .6922 L .53234 .68543 L F
.53234 .68543 m .53932 .69218 L .53606 .68542 L F
.53402 .6812 m .53234 .68543 L .53606 .68542 L F
.53192 .61114 m .53378 .68096 L .53206 .68104 L .641 .401 .54 r
F
.53598 .6816 m .53606 .68542 L .53955 .68494 L .598 .766 .96 r
F
.53524 .68091 m .53564 .68315 L .53598 .6816 L F
.53564 .68315 m .53606 .68542 L .53598 .6816 L F
.53192 .61114 m .53371 .61095 L .53388 .68095 L .641 .401 .54 r
F
.53192 .61114 m .53388 .68095 L .53378 .68096 L F
.53486 .61053 m .53583 .68025 L .53506 .68065 L .358 .18 .498 r
F
.53615 .60935 m .53629 .60857 L .53652 .67903 L 0 0 .15 r
F
.53621 .6805 m .53955 .68494 L .53988 .68485 L .598 .766 .96 r
F
.53792 .68145 m .53988 .68485 L .54259 .68404 L F
.53621 .6805 m .53988 .68485 L .53792 .68145 L F
.53619 .68061 m .53955 .68494 L .53621 .6805 L F
.53566 .60999 m .53615 .60935 L .53638 .67969 L .08 0 .418 r
F
.53561 .68051 m .53955 .68494 L .53602 .6804 L .598 .766 .96 r
F
.53528 .68086 m .53955 .68494 L .53561 .68051 L F
.535 .68068 m .53955 .68494 L .53506 .68065 L F
.53486 .61053 m .53566 .60999 L .53588 .68022 L .358 .18 .498 r
F
.53486 .61053 m .53588 .68022 L .53583 .68025 L F
.53371 .61095 m .53499 .68067 L .53388 .68095 L .517 .303 .528 r
F
.53566 .60999 m .53635 .67971 L .53588 .68022 L .08 0 .418 r
F
.53718 .6801 m .54259 .68404 L .54497 .68276 L .598 .766 .96 r
F
.53371 .61095 m .53486 .61053 L .53506 .68065 L .517 .303 .528 r
F
.53371 .61095 m .53506 .68065 L .53499 .68067 L F
.53566 .60999 m .53638 .67969 L .53635 .67971 L .08 0 .418 r
F
.53615 .60935 m .53652 .67903 L .53651 .67906 L 0 0 .15 r
F
.53615 .60935 m .53651 .67906 L .53638 .67969 L F
.53629 .60857 m .53579 .60758 L .53601 .67814 L .983 .725 .332 r
F
.53276 .67859 m .53602 .6804 L .53715 .68011 L .598 .766 .96 r
F
.53276 .67859 m .53715 .68011 L .53713 .68009 L F
.53858 .67969 m .54497 .68276 L .54652 .6812 L F
.53276 .67859 m .54196 .68173 L .53858 .67969 L F
.54196 .68173 m .54497 .68276 L .53858 .67969 L F
.53498 .68067 m .535 .68068 L .53506 .68065 L F
.53276 .67859 m .5339 .68095 L .53522 .68089 L F
.5339 .68095 m .53606 .68542 L .53522 .68089 L F
.53499 .68067 m .53506 .68065 L .53507 .68503 L .517 .303 .528 r
F
.53506 .68065 m .53528 .68086 L .53561 .68051 L .598 .766 .96 r
F
.53276 .67859 m .53498 .68067 L .53602 .6804 L F
.53583 .68025 m .53588 .68022 L .53589 .68451 L .358 .18 .498 r
F
.53377 .68133 m .53234 .68543 L .53402 .6812 L .598 .766 .96 r
F
.53499 .68067 m .53507 .68503 L .53388 .68095 L .517 .303 .528 r
F
.53588 .68022 m .53639 .68387 L .53589 .68451 L .08 0 .418 r
F
.53522 .68089 m .53523 .68092 L .53524 .68091 L .598 .766 .96 r
F
.53523 .68092 m .53606 .68542 L .53524 .68091 L F
.53506 .68065 m .53589 .68451 L .53507 .68503 L .358 .18 .498 r
F
.53583 .68025 m .53589 .68451 L .53506 .68065 L F
.53629 .60857 m .53604 .67819 L .53652 .67903 L .983 .725 .332 r
F
.5372 .67886 m .54652 .6812 L .54714 .67945 L .598 .766 .96 r
F
.53276 .67859 m .53858 .67969 L .5372 .67886 L F
.53858 .67969 m .54652 .6812 L .5372 .67886 L F
.53579 .60758 m .53461 .60679 L .5348 .67741 L .911 .629 .497 r
F
.53579 .60758 m .5348 .67741 L .53486 .67745 L F
.53579 .60758 m .53486 .67745 L .53601 .67814 L F
.53629 .60857 m .53601 .67814 L .53604 .67819 L .983 .725 .332 r
F
.53461 .60679 m .53363 .67707 L .5348 .67741 L .81 .54 .53 r
F
.5345 .67732 m .54327 .67432 L .54036 .67304 L .598 .766 .96 r
F
.53276 .67859 m .5353 .67756 L .5345 .67732 L F
.5353 .67756 m .54327 .67432 L .5345 .67732 L F
.53276 .67859 m .53261 .68101 L .5339 .68095 L F
.5353 .67756 m .54546 .67589 L .54327 .67432 L F
.53276 .67859 m .53627 .67785 L .5353 .67756 L F
.53627 .67785 m .54546 .67589 L .5353 .67756 L F
.53461 .60679 m .5334 .60643 L .53356 .67705 L .81 .54 .53 r
F
.53461 .60679 m .53356 .67705 L .53363 .67707 L F
.5334 .60643 m .53238 .67689 L .53356 .67705 L .734 .477 .539 r
F
.53286 .67696 m .53692 .67214 L .53319 .67168 L .598 .766 .96 r
F
.53276 .67859 m .53374 .67707 L .53286 .67696 L F
.53374 .67707 m .53692 .67214 L .53286 .67696 L F
.52905 .61044 m .53016 .61089 L .53026 .68075 L .845 .571 .524 r
F
.53251 .68263 m .52865 .68498 L .53234 .68543 L .598 .766 .96 r
F
.53257 .68164 m .5319 .68221 L .53251 .68263 L F
.5319 .68221 m .52865 .68498 L .53251 .68263 L F
.52831 .60988 m .52905 .61044 L .52912 .68031 L .929 .648 .487 r
F
.53222 .68151 m .53166 .68205 L .53257 .68164 L .598 .766 .96 r
F
.53166 .68205 m .52865 .68498 L .5319 .68221 L F
.53166 .68205 m .5319 .68221 L .53257 .68164 L F
.53127 .68091 m .53115 .68109 L .53261 .68113 L F
.53115 .68109 m .52865 .68498 L .53222 .68151 L F
.53115 .68109 m .53222 .68151 L .53261 .68113 L F
.52905 .61044 m .53019 .68072 L .52912 .68031 L .845 .571 .524 r
F
.52905 .61044 m .53026 .68075 L .53019 .68072 L F
.53016 .61089 m .53192 .61114 L .53206 .68104 L .751 .491 .539 r
F
.53016 .61089 m .53206 .68104 L .53195 .68102 L F
.52789 .60922 m .52831 .60988 L .52837 .67979 L .988 .719 .384 r
F
.5303 .68242 m .52827 .68309 L .52865 .68498 L .598 .766 .96 r
F
.52827 .68309 m .52524 .68409 L .52843 .68492 L F
.52827 .68309 m .52843 .68492 L .52865 .68498 L F
.52783 .60844 m .52789 .60922 L .52793 .6792 L .781 .623 .061 r
F
.52977 .6817 m .52822 .68252 L .5303 .68242 L .598 .766 .96 r
F
.52822 .68252 m .52524 .68409 L .52827 .68309 L F
.52822 .68252 m .52827 .68309 L .5303 .68242 L F
.5299 .68069 m .52933 .6811 L .53127 .68091 L F
.52933 .6811 m .52524 .68409 L .52977 .6817 L F
.52933 .6811 m .52977 .6817 L .53127 .68091 L F
.53016 .61089 m .53195 .68102 L .53026 .68075 L .751 .491 .539 r
F
.52831 .60988 m .52908 .68028 L .52837 .67979 L .929 .648 .487 r
F
.52831 .60988 m .52912 .68031 L .52908 .68028 L F
.53276 .67859 m .52565 .68148 L .52524 .68409 L .598 .766 .96 r
F
.52565 .68148 m .52233 .68283 L .52407 .68359 L F
.52565 .68148 m .52407 .68359 L .52524 .68409 L F
.52789 .60922 m .52834 .67975 L .52793 .6792 L .988 .719 .384 r
F
.52783 .60844 m .52793 .67916 L .52788 .67853 L .781 .623 .061 r
F
.52783 .60844 m .52793 .6792 L .52793 .67916 L F
.52789 .60922 m .52837 .67979 L .52834 .67975 L .988 .719 .384 r
F
.52843 .60746 m .52783 .60844 L .52788 .67853 L 0 0 .377 r
F
.53276 .67859 m .52689 .67985 L .52565 .68148 L .598 .766 .96 r
F
.52104 .68109 m .51878 .67955 L .52013 .68128 L F
.53276 .67859 m .52544 .67909 L .52104 .68109 L F
.52544 .67909 m .51878 .67955 L .52104 .68109 L F
.52912 .68031 m .53025 .68533 L .52913 .68489 L .845 .571 .524 r
F
.52865 .68498 m .52458 .6913 L .53192 .6922 L .598 .766 .96 r
F
.52524 .68409 m .52458 .6913 L .52865 .68498 L F
.52524 .68409 m .51779 .68954 L .52458 .6913 L F
.52988 .68527 m .52199 .68762 L .52492 .68888 L .597 .767 .96 r
F
.53127 .68091 m .52977 .6817 L .5303 .68242 L .598 .766 .96 r
F
.53026 .68075 m .53207 .68563 L .53026 .68533 L .751 .491 .539 r
F
.53195 .68102 m .53207 .68563 L .53026 .68075 L F
.53019 .68072 m .53026 .68533 L .52912 .68031 L .845 .571 .524 r
F
.52995 .68521 m .52492 .68888 L .53103 .68563 L .597 .767 .96 r
F
.53026 .68533 m .53026 .68538 L .53025 .68533 L .845 .571 .524 r
F
.53026 .68533 m .53025 .68533 L .52912 .68031 L F
.52233 .68283 m .51779 .68954 L .52524 .68409 L .598 .766 .96 r
F
.52233 .68283 m .51198 .68704 L .51779 .68954 L F
.52892 .68481 m .51977 .68606 L .52199 .68762 L .597 .767 .96 r
F
.52793 .6792 m .52837 .68437 L .52794 .68375 L .988 .719 .384 r
F
.52829 .68426 m .52777 .68437 L .5286 .68469 L .597 .767 .96 r
F
.52837 .68437 m .52822 .68417 L .52794 .68375 L .988 .719 .384 r
F
.52843 .60746 m .52791 .67848 L .52849 .67771 L 0 0 .377 r
F
.52843 .60746 m .52788 .67853 L .52791 .67848 L F
.53276 .67859 m .52424 .67809 L .51878 .67955 L .598 .766 .96 r
F
.52424 .67809 m .51838 .67774 L .51867 .67905 L F
.52424 .67809 m .51867 .67905 L .51878 .67955 L F
.53094 .60639 m .52969 .60672 L .52978 .67712 L .567 .342 .533 r
F
.52424 .67809 m .51896 .67599 L .51838 .67774 L .598 .766 .96 r
F
.53276 .67859 m .52728 .67756 L .52424 .67809 L F
.52728 .67756 m .51896 .67599 L .52424 .67809 L F
.53276 .67859 m .5299 .68069 L .53127 .68091 L F
.53019 .68072 m .53026 .68075 L .53026 .68538 L .845 .571 .524 r
F
.52969 .60672 m .52856 .67768 L .52978 .67712 L .4 .211 .506 r
F
.52969 .60672 m .52843 .60746 L .52849 .67771 L F
.52969 .60672 m .52849 .67771 L .52856 .67768 L F
.53217 .60631 m .53094 .60639 L .53105 .6769 L .66 .416 .54 r
F
.53276 .67859 m .52792 .67694 L .52428 .67699 L .598 .766 .96 r
F
.53094 .60639 m .52985 .67711 L .53105 .6769 L .567 .342 .533 r
F
.53094 .60639 m .52978 .67712 L .52985 .67711 L F
.52792 .67694 m .52286 .67311 L .52049 .67441 L .598 .766 .96 r
F
.53276 .67859 m .52974 .67692 L .52792 .67694 L F
.52974 .67692 m .52286 .67311 L .52792 .67694 L F
.53276 .67859 m .53127 .68091 L .53261 .68113 L F
.53276 .67859 m .52591 .67219 L .52286 .67311 L F
.53217 .60631 m .53112 .6769 L .53232 .67689 L .66 .416 .54 r
F
.53217 .60631 m .53105 .6769 L .53112 .6769 L F
.53276 .67859 m .52943 .6717 L .52591 .67219 L .598 .766 .96 r
F
.5334 .60643 m .53217 .60631 L .53232 .67689 L .734 .477 .539 r
F
.5334 .60643 m .53232 .67689 L .53238 .67689 L F
.53276 .67859 m .53319 .67168 L .52943 .6717 L .598 .766 .96 r
F
.53232 .67689 m .53106 .68099 L .53232 .68091 L .66 .416 .54 r
F
.53112 .6769 m .53106 .68099 L .53232 .67689 L F
.53112 .6769 m .53105 .6769 L .53106 .68099 L F
.52428 .67699 m .52499 .67594 L .51896 .67599 L .598 .766 .96 r
F
.52792 .67694 m .52499 .67594 L .52428 .67699 L F
.52499 .67594 m .52049 .67441 L .51967 .67526 L F
.52499 .67594 m .51967 .67526 L .51896 .67599 L F
.53238 .67689 m .53232 .67689 L .53232 .68091 L .734 .477 .539 r
F
.53105 .6769 m .52979 .68131 L .53106 .68099 L .567 .342 .533 r
F
.52985 .67711 m .52979 .68131 L .53105 .6769 L F
.52985 .67711 m .52978 .67712 L .52979 .68131 L F
.52788 .67853 m .52794 .68375 L .52788 .68299 L .781 .623 .061 r
F
.52013 .68128 m .51198 .68704 L .52233 .68283 L .598 .766 .96 r
F
.52798 .68432 m .51842 .68432 L .51977 .68606 L .597 .767 .96 r
F
.52834 .67975 m .52837 .68437 L .52793 .6792 L .988 .719 .384 r
F
.52837 .68437 m .52837 .68439 L .52837 .68437 L F
.52837 .68437 m .52837 .68437 L .52793 .6792 L F
.52013 .68128 m .50757 .68396 L .51198 .68704 L .598 .766 .96 r
F
.52786 .68368 m .51801 .68251 L .51842 .68432 L .597 .767 .96 r
F
.52793 .67916 m .52794 .68375 L .52788 .67853 L .781 .623 .061 r
F
.52793 .67916 m .52793 .6792 L .52794 .68375 L F
.52834 .67975 m .52837 .67979 L .52837 .68439 L .988 .719 .384 r
F
.52829 .68426 m .5286 .68469 L .52892 .68481 L .597 .767 .96 r
F
.52837 .67979 m .52912 .68489 L .52837 .68437 L .929 .648 .487 r
F
.52908 .68028 m .52913 .68489 L .52837 .67979 L F
.52913 .68489 m .52912 .68489 L .52837 .67979 L F
.52908 .68028 m .52912 .68031 L .52913 .68494 L F
.53195 .68102 m .53206 .68104 L .53207 .68563 L .751 .491 .539 r
F
.53234 .68567 m .52835 .68977 L .53206 .69022 L .597 .767 .96 r
F
.53261 .68101 m .53234 .68543 L .5339 .68095 L .598 .766 .96 r
F
.53206 .68104 m .53389 .68544 L .53208 .68563 L .641 .401 .54 r
F
.53235 .68561 m .53207 .68563 L .53234 .68567 L .597 .767 .96 r
F
.53207 .68563 m .53208 .68563 L .53207 .68563 L .641 .401 .54 r
F
.53206 .68104 m .53208 .68563 L .53207 .68563 L F
.53248 .68337 m .53113 .68547 L .53207 .68563 L .597 .767 .96 r
F
.53248 .68337 m .53207 .68563 L .53235 .68561 L F
.53207 .68563 m .52835 .68977 L .53234 .68567 L F
.53123 .70372 m .5315 .69899 L .5426 .69896 L .67 .443 .567 r
F
.53192 .6922 m .53151 .69889 L .54255 .69886 L .598 .766 .96 r
F
.53123 .70372 m .5426 .69896 L .54234 .70369 L .67 .443 .567 r
F
.53192 .6922 m .54255 .69886 L .53932 .69218 L .598 .766 .96 r
F
.53095 .70846 m .53123 .70372 L .54234 .70369 L .67 .443 .567 r
F
.53164 .69701 m .53123 .70372 L .54234 .70369 L .597 .767 .96 r
F
.53095 .70846 m .54234 .70369 L .54207 .70843 L .67 .443 .567 r
F
.53164 .69701 m .54234 .70369 L .53908 .69699 L .597 .767 .96 r
F
.53136 .70176 m .53095 .70846 L .54207 .70843 L .597 .767 .961 r
F
.53136 .70176 m .54207 .70843 L .53882 .70174 L F
.53206 .69022 m .53164 .69701 L .53908 .69699 L .597 .767 .96 r
F
.53206 .69022 m .53908 .69699 L .5358 .69021 L F
.53178 .695 m .53136 .70176 L .53882 .70174 L .597 .767 .961 r
F
.53178 .695 m .53882 .70174 L .53553 .69499 L F
.53208 .68563 m .53389 .68544 L .5339 .68554 L .641 .401 .54 r
F
.53358 .68562 m .53206 .69022 L .5358 .69021 L .597 .767 .96 r
F
.53248 .68337 m .53233 .68595 L .53358 .68562 L F
.53233 .68595 m .53206 .69022 L .53358 .68562 L F
.53389 .68544 m .5339 .68554 L .5339 .68554 L .517 .303 .528 r
F
.5339 .68095 m .53377 .68133 L .53402 .6812 L .598 .766 .96 r
F
.53388 .68095 m .53507 .68503 L .53389 .68544 L .517 .303 .528 r
F
.53378 .68096 m .53388 .68095 L .53389 .68544 L .641 .401 .54 r
F
.53261 .68113 m .53222 .68151 L .53257 .68164 L .598 .766 .96 r
F
.53378 .68096 m .53389 .68544 L .53206 .68104 L .641 .401 .54 r
F
.53606 .68542 m .53932 .69218 L .54628 .69124 L .598 .766 .96 r
F
.53461 .68536 m .5358 .69021 L .53932 .68974 L .597 .767 .96 r
F
.53389 .68544 m .53508 .68524 L .5339 .68554 L .517 .303 .528 r
F
.53248 .68337 m .53358 .68562 L .53461 .68536 L .597 .767 .96 r
F
.53358 .68562 m .5358 .69021 L .53461 .68536 L F
.53389 .68544 m .53507 .68503 L .53508 .68524 L .517 .303 .528 r
F
.53606 .68542 m .54628 .69124 L .53955 .68494 L .598 .766 .96 r
F
.53548 .68502 m .53932 .68974 L .54238 .68883 L .597 .767 .96 r
F
.53507 .68503 m .53508 .68524 L .53508 .68524 L .358 .18 .498 r
F
.5347 .68543 m .53932 .68974 L .53548 .68502 L .597 .767 .96 r
F
.53932 .69218 m .54255 .69886 L .55295 .69748 L .598 .766 .96 r
F
.5358 .69021 m .53908 .69699 L .54609 .69605 L .597 .767 .96 r
F
.53932 .69218 m .55295 .69748 L .54628 .69124 L .598 .766 .96 r
F
.5358 .69021 m .54609 .69605 L .53932 .68974 L .597 .767 .96 r
F
.54234 .70369 m .5426 .69896 L .55305 .69757 L .597 .381 .558 r
F
.54234 .70369 m .55305 .69757 L .5528 .7023 L F
.53908 .69699 m .54234 .70369 L .5528 .7023 L .597 .767 .96 r
F
.53553 .69499 m .53882 .70174 L .54583 .70081 L .597 .767 .961 r
F
.53908 .69699 m .5528 .7023 L .54609 .69605 L .597 .767 .96 r
F
.53553 .69499 m .54583 .70081 L .53905 .69451 L .597 .767 .961 r
F
.53955 .68494 m .54628 .69124 L .55235 .68944 L .598 .766 .96 r
F
.53622 .68464 m .54238 .68883 L .54477 .68755 L .597 .767 .96 r
F
.53507 .68503 m .53589 .68451 L .53589 .68481 L .358 .18 .498 r
F
.53589 .68481 m .54238 .68883 L .53622 .68464 L .597 .767 .96 r
F
.53548 .68502 m .53562 .6851 L .53589 .68481 L F
.53562 .6851 m .54238 .68883 L .53589 .68481 L F
.53589 .68451 m .53639 .68387 L .5364 .68427 L .08 0 .418 r
F
.53609 .6846 m .53589 .68481 L .53622 .68464 L .597 .767 .96 r
F
.53584 .69154 m .53553 .69499 L .53905 .69451 L .597 .767 .961 r
F
.54259 .68404 m .55235 .68944 L .55712 .68691 L .598 .766 .96 r
F
.53955 .68494 m .55235 .68944 L .54259 .68404 L F
.53643 .68411 m .54477 .68755 L .54633 .68598 L .597 .767 .96 r
F
.53631 .68467 m .54477 .68755 L .53643 .68411 L F
.5364 .68427 m .53655 .68822 L .53642 .68883 L 0 0 .15 r
F
.53639 .68387 m .53641 .68422 L .5364 .68427 L F
.53641 .68422 m .53655 .68822 L .5364 .68427 L F
.53602 .6804 m .54259 .68404 L .53718 .6801 L .598 .766 .96 r
F
.54259 .68404 m .55712 .68691 L .54497 .68276 L F
.53654 .68361 m .54633 .68598 L .54695 .68423 L .597 .767 .96 r
F
.53639 .68387 m .53654 .68362 L .53641 .68422 L 0 0 .15 r
F
.53639 .68387 m .53642 .68883 L .53641 .68888 L F
.53635 .67971 m .53638 .67969 L .53639 .68387 L .08 0 .418 r
F
.53638 .67969 m .53653 .68312 L .53639 .68387 L 0 0 .15 r
F
.53602 .6804 m .53619 .68061 L .53621 .6805 L .598 .766 .96 r
F
.53635 .67971 m .53639 .68387 L .53588 .68022 L .08 0 .418 r
F
.53654 .68362 m .54633 .68598 L .53654 .68361 L .597 .767 .96 r
F
.53643 .68411 m .53687 .6842 L .53654 .68362 L F
.53687 .6842 m .54633 .68598 L .53654 .68362 L F
.53653 .68312 m .53603 .68215 L .53603 .68274 L .983 .725 .332 r
F
.53248 .68337 m .53643 .68411 L .53654 .68362 L .597 .767 .96 r
F
.53248 .68337 m .53654 .68362 L .53653 .68361 L F
.53589 .68451 m .5364 .68427 L .53589 .68481 L .08 0 .418 r
F
.53248 .68337 m .53631 .68467 L .53643 .68411 L .597 .767 .96 r
F
.53639 .68387 m .53653 .68312 L .53654 .68362 L 0 0 .15 r
F
.53641 .68422 m .53654 .68362 L .53655 .68822 L F
.53611 .69031 m .53905 .69451 L .54211 .69361 L .597 .767 .961 r
F
.53602 .69069 m .53905 .69451 L .53611 .69031 L F
.53481 .69057 m .53905 .69451 L .53542 .68993 L F
.54628 .69124 m .55295 .69748 L .56204 .69481 L .598 .766 .96 r
F
.53932 .68974 m .54609 .69605 L .5522 .69425 L .597 .767 .96 r
F
.53757 .68998 m .54211 .69361 L .54451 .69233 L .597 .767 .961 r
F
.53589 .68481 m .53594 .68938 L .53589 .68481 L .08 0 .418 r
F
.5359 .68941 m .53854 .69164 L .53757 .68998 L .597 .767 .961 r
F
.53542 .68993 m .53854 .69164 L .5359 .68941 L F
.53542 .68993 m .53602 .69069 L .53611 .69031 L F
.53594 .68938 m .53594 .68938 L .53589 .68481 L .08 0 .418 r
F
.55235 .68944 m .56204 .69481 L .5692 .69103 L .598 .766 .96 r
F
.54628 .69124 m .56204 .69481 L .55235 .68944 L F
.54238 .68883 m .5522 .69425 L .55699 .69171 L .597 .767 .96 r
F
.53932 .68974 m .5522 .69425 L .54238 .68883 L F
.53705 .68907 m .54451 .69233 L .54607 .69077 L .597 .767 .961 r
F
.53589 .68481 m .53594 .68938 L .53591 .68941 L .08 0 .418 r
F
.53589 .68481 m .53641 .68888 L .53594 .68938 L F
.53511 .68522 m .53589 .68481 L .53591 .68941 L .358 .18 .498 r
F
.53507 .68503 m .53591 .68941 L .53514 .68981 L F
.53508 .68524 m .53514 .68981 L .53509 .68984 L F
.5339 .68554 m .53508 .68524 L .53509 .68984 L .517 .303 .528 r
F
.5352 .68981 m .53481 .69057 L .53542 .68993 L .597 .767 .961 r
F
.53516 .68982 m .53481 .69057 L .5352 .68981 L F
.5344 .6902 m .53481 .69057 L .53517 .68979 L F
.53481 .69057 m .53534 .69387 L .53584 .69154 L F
.5339 .68554 m .53509 .68984 L .53398 .69012 L .517 .303 .528 r
F
.53208 .68563 m .5339 .68554 L .53391 .69014 L .641 .401 .54 r
F
.53432 .69012 m .53386 .69157 L .53481 .69057 L .597 .767 .961 r
F
.53423 .69013 m .53386 .69157 L .53432 .69012 L F
.53325 .69031 m .53386 .69157 L .53424 .69005 L F
.53386 .69157 m .53553 .69499 L .53481 .69057 L F
.53344 .6907 m .53178 .695 L .53553 .69499 L F
.53208 .68563 m .53391 .69014 L .5322 .69022 L .641 .401 .54 r
F
.53113 .68547 m .53099 .68568 L .53207 .68563 L .597 .767 .96 r
F
.53099 .68568 m .52835 .68977 L .53207 .68563 L F
.53113 .68547 m .53026 .68533 L .53103 .68563 L F
.53103 .68563 m .52492 .68888 L .52835 .68977 L F
.53026 .68538 m .53207 .68563 L .53208 .69022 L .751 .491 .539 r
F
.53331 .69042 m .532 .69144 L .53344 .6907 L .597 .767 .961 r
F
.533 .69037 m .532 .69144 L .53331 .69042 L F
.53208 .69022 m .532 .69144 L .53318 .69017 L F
.532 .69144 m .53178 .695 L .53344 .6907 L F
.52021 .70238 m .5315 .69899 L .53123 .70372 L .733 .497 .571 r
F
.52021 .70238 m .52049 .69765 L .5315 .69899 L F
.52458 .6913 m .53151 .69889 L .53192 .6922 L .598 .766 .96 r
F
.52458 .6913 m .52055 .69755 L .53151 .69889 L F
.51991 .70711 m .53123 .70372 L .53095 .70846 L .733 .497 .571 r
F
.51991 .70711 m .52021 .70238 L .53123 .70372 L F
.52426 .69611 m .53123 .70372 L .53164 .69701 L .597 .767 .96 r
F
.52426 .69611 m .52021 .70238 L .53123 .70372 L F
.52397 .70086 m .53095 .70846 L .53136 .70176 L .597 .767 .961 r
F
.52397 .70086 m .51991 .70711 L .53095 .70846 L F
.52835 .68977 m .53164 .69701 L .53206 .69022 L .597 .767 .96 r
F
.52835 .68977 m .52426 .69611 L .53164 .69701 L F
.52807 .69454 m .53136 .70176 L .53178 .695 L .597 .767 .961 r
F
.52807 .69454 m .52397 .70086 L .53136 .70176 L F
.53026 .68538 m .53208 .69022 L .53038 .68995 L .751 .491 .539 r
F
.53207 .68563 m .53208 .68563 L .5322 .69022 L .641 .401 .54 r
F
.53207 .68563 m .5322 .69022 L .53219 .69022 L F
.52898 .68479 m .52839 .68503 L .52961 .68523 L .597 .767 .96 r
F
.52777 .68437 m .51977 .68606 L .52892 .68481 L F
.52839 .68503 m .52199 .68762 L .52988 .68527 L F
.52837 .68439 m .52913 .68494 L .52913 .68949 L .929 .648 .487 r
F
.532 .69145 m .52807 .69454 L .53178 .695 L .597 .767 .961 r
F
.53153 .69113 m .52807 .69454 L .532 .69145 L F
.5318 .69052 m .53135 .691 L .53205 .69062 L F
.53135 .691 m .52807 .69454 L .53153 .69113 L F
.53135 .691 m .53153 .69113 L .53205 .69062 L F
.52794 .68375 m .52837 .68439 L .52837 .68898 L .988 .719 .384 r
F
.53013 .69135 m .52807 .69454 L .53053 .69189 L .597 .767 .961 r
F
.52492 .68888 m .52426 .69611 L .52835 .68977 L .597 .767 .96 r
F
.52463 .69366 m .52397 .70086 L .52807 .69454 L .597 .767 .961 r
F
.52898 .68479 m .52961 .68523 L .52988 .68527 L .597 .767 .96 r
F
.52913 .68494 m .53026 .68538 L .53027 .68993 L .845 .571 .524 r
F
.52913 .68494 m .53027 .68993 L .5292 .68952 L F
.53026 .68538 m .53038 .68995 L .53027 .68993 L .751 .491 .539 r
F
.53207 .68563 m .53219 .69022 L .53208 .69022 L .641 .401 .54 r
F
.53013 .69135 m .52463 .69366 L .52807 .69454 L .597 .767 .961 r
F
.5322 .68816 m .52932 .69025 L .53013 .69135 L F
.52849 .68204 m .52788 .68299 L .52788 .68312 L 0 0 .377 r
F
.52793 .68368 m .52768 .68338 L .52786 .68368 L .597 .767 .96 r
F
.52788 .68299 m .52794 .68375 L .52794 .68379 L .781 .623 .061 r
F
.52788 .68299 m .52794 .68379 L .52788 .68313 L F
.52788 .6831 m .52741 .68307 L .52793 .68368 L .597 .767 .96 r
F
.52817 .69108 m .52463 .69366 L .52826 .69214 L .597 .767 .961 r
F
.52794 .68379 m .51842 .68432 L .52798 .68432 L .597 .767 .96 r
F
.52793 .68368 m .52786 .68368 L .52794 .68379 L F
.52786 .68368 m .51842 .68432 L .52794 .68379 L F
.52794 .68379 m .52797 .68842 L .52794 .68839 L .988 .719 .384 r
F
.52794 .68375 m .52794 .68379 L .52794 .68379 L F
.52794 .68379 m .52797 .68842 L .52794 .68379 L F
.51779 .68954 m .52055 .69755 L .52458 .6913 L .598 .766 .96 r
F
.51779 .68954 m .5104 .69494 L .52055 .69755 L F
.52492 .68888 m .51742 .69434 L .52426 .69611 L .597 .767 .96 r
F
.52817 .69108 m .5217 .69239 L .52463 .69366 L .597 .767 .961 r
F
.52806 .68983 m .5217 .69239 L .52817 .69108 L F
.52199 .68762 m .51742 .69434 L .52492 .68888 L .597 .767 .96 r
F
.51198 .68704 m .5104 .69494 L .51779 .68954 L .598 .766 .96 r
F
.52199 .68762 m .51158 .69183 L .51742 .69434 L .597 .767 .96 r
F
.52551 .69086 m .51948 .69084 L .5217 .69239 L .597 .767 .961 r
F
.52913 .68494 m .5292 .68952 L .52913 .68949 L .845 .571 .524 r
F
.52837 .68439 m .52842 .68901 L .52837 .68898 L .929 .648 .487 r
F
.52837 .68439 m .52913 .68949 L .52842 .68901 L F
.5322 .68816 m .52666 .68933 L .52551 .69086 L .597 .767 .961 r
F
.52666 .68933 m .51948 .69084 L .52551 .69086 L F
.52788 .68312 m .52789 .68776 L .52788 .68772 L .781 .623 .061 r
F
.52788 .68299 m .52788 .68312 L .52788 .68312 L F
.52788 .68312 m .52789 .68776 L .52788 .68312 L F
.52565 .68148 m .52104 .68109 L .52233 .68283 L .598 .766 .96 r
F
.52104 .68109 m .52013 .68128 L .52032 .68141 L F
.52104 .68109 m .52032 .68141 L .52233 .68283 L F
.51878 .67955 m .50757 .68396 L .52013 .68128 L F
.52788 .6831 m .5186 .68075 L .51801 .68251 L .597 .767 .96 r
F
.52849 .68204 m .52788 .68312 L .52849 .6823 L 0 0 .377 r
F
.52849 .67771 m .52788 .68299 L .52849 .68204 L F
.52791 .67848 m .52788 .68299 L .52849 .67771 L F
.52791 .67848 m .52788 .67853 L .52788 .68299 L F
.53248 .68337 m .52782 .68249 L .52788 .6831 L .597 .767 .96 r
F
.52782 .68249 m .5186 .68075 L .52788 .6831 L F
.53248 .68337 m .52789 .6831 L .52793 .68368 L F
.52789 .6831 m .52788 .6831 L .52788 .68312 L F
.52789 .6831 m .52788 .68312 L .52793 .68368 L F
.52788 .68313 m .52794 .68379 L .52794 .68839 L .781 .623 .061 r
F
.52788 .68299 m .52794 .68839 L .52789 .68776 L F
.52794 .68375 m .52837 .68898 L .52797 .68842 L .988 .719 .384 r
F
.53248 .68337 m .52793 .68368 L .52798 .68432 L .597 .767 .96 r
F
.52978 .67712 m .52849 .68204 L .52979 .68131 L .4 .211 .506 r
F
.52856 .67768 m .52849 .68204 L .52978 .67712 L F
.52689 .67985 m .52104 .68109 L .52565 .68148 L .598 .766 .96 r
F
.52856 .67768 m .52849 .67771 L .52849 .68204 L .4 .211 .506 r
F
.528 .68253 m .52013 .67917 L .5186 .68075 L .597 .767 .96 r
F
.53248 .68337 m .52849 .6823 L .52828 .68258 L F
.51977 .68606 m .51158 .69183 L .52199 .68762 L F
.52666 .68933 m .51812 .6891 L .51948 .69084 L .597 .767 .961 r
F
.5322 .68816 m .5273 .68849 L .52666 .68933 L F
.5273 .68849 m .51812 .6891 L .52666 .68933 L F
.51198 .68704 m .50171 .69122 L .5104 .69494 L .598 .766 .96 r
F
.50757 .68396 m .50171 .69122 L .51198 .68704 L F
.51977 .68606 m .50713 .68874 L .51158 .69183 L .597 .767 .96 r
F
.5273 .68849 m .51772 .6873 L .51812 .6891 L .597 .767 .961 r
F
.5322 .68816 m .52775 .68789 L .5273 .68849 L F
.52775 .68789 m .51772 .6873 L .5273 .68849 L F
.52837 .68437 m .52913 .68494 L .52837 .68439 L .929 .648 .487 r
F
.52898 .68479 m .52859 .68453 L .52892 .68481 L .597 .767 .96 r
F
.52912 .68489 m .52913 .68494 L .52837 .68437 L .929 .648 .487 r
F
.53248 .68337 m .52829 .68426 L .52859 .68453 L .597 .767 .96 r
F
.52849 .6823 m .52846 .68696 L .52849 .6823 L 0 0 .377 r
F
.51842 .68432 m .50713 .68874 L .51977 .68606 L .597 .767 .96 r
F
.52647 .68782 m .5183 .68554 L .51772 .6873 L .597 .767 .961 r
F
.52849 .6823 m .52788 .68312 L .52788 .68772 L 0 0 .377 r
F
.52837 .68437 m .52837 .68439 L .52822 .68417 L .988 .719 .384 r
F
.52849 .6823 m .52788 .68772 L .52846 .68696 L 0 0 .377 r
F
.5322 .68816 m .52763 .6873 L .52647 .68782 L .597 .767 .961 r
F
.52763 .6873 m .5183 .68554 L .52647 .68782 L F
.53248 .68337 m .52886 .68214 L .52849 .6823 L .597 .767 .96 r
F
.53248 .68337 m .52898 .68479 L .52988 .68527 L F
.53248 .68337 m .52859 .68453 L .52898 .68479 L F
.52979 .68131 m .52849 .68204 L .52849 .6823 L .4 .211 .506 r
F
.52979 .68131 m .52849 .6823 L .52978 .68172 L F
.52886 .68214 m .52252 .67787 L .52013 .67917 L .597 .767 .96 r
F
.53248 .68337 m .52962 .68179 L .52886 .68214 L F
.52962 .68179 m .52252 .67787 L .52886 .68214 L F
.5322 .68816 m .52806 .68983 L .52817 .69108 L .597 .767 .961 r
F
.52932 .69025 m .52817 .69108 L .53013 .69135 L F
.52817 .69108 m .52826 .69214 L .53013 .69135 L F
.5288 .76238 m .53129 .76485 L .53144 .76237 L .657 .813 .958 r
F
.5288 .76238 m .52734 .76486 L .53129 .76485 L F
.53026 .75989 m .53144 .76237 L .53158 .75989 L F
.53026 .75989 m .5288 .76238 L .53144 .76237 L F
.52904 .75973 m .5288 .76238 L .53026 .75989 L F
.5316 .7678 m .53129 .76488 L .53529 .76436 L .668 .435 .558 r
F
.52762 .76782 m .53129 .76488 L .5316 .7678 L .731 .481 .55 r
F
.52762 .76782 m .52732 .7649 L .53129 .76488 L F
.53144 .76237 m .53129 .76485 L .53527 .76432 L .657 .813 .958 r
F
.53056 .76283 m .52909 .76533 L .53174 .76532 L .657 .813 .959 r
F
.52933 .76267 m .52909 .76533 L .53056 .76283 L F
.52394 .76733 m .52732 .7649 L .52762 .76782 L .793 .527 .535 r
F
.52394 .76733 m .52364 .76441 L .52732 .7649 L F
.52636 .76206 m .52734 .76486 L .5288 .76238 L .657 .813 .958 r
F
.52636 .76206 m .52368 .76438 L .52734 .76486 L F
.52933 .76267 m .52663 .765 L .52909 .76533 L .657 .813 .959 r
F
.52829 .76234 m .52663 .765 L .52927 .76273 L F
.52918 .76262 m .52927 .76273 L .52933 .76267 L F
.52829 .76234 m .52927 .76273 L .52918 .76262 L F
.52788 .68772 m .52798 .75467 L .52795 .75788 L .781 .623 .061 r
F
.52818 .76047 m .52636 .76206 L .52834 .76232 L .657 .813 .958 r
F
.528 .75941 m .52636 .76206 L .52818 .76047 L F
.52809 .75943 m .52818 .76047 L .52904 .75973 L F
.528 .75941 m .52818 .76047 L .52809 .75943 L F
.52789 .68776 m .52798 .75822 L .52788 .68772 L .781 .623 .061 r
F
.528 .75941 m .5259 .76054 L .52636 .76206 L .657 .813 .958 r
F
.5259 .76054 m .52428 .76141 L .52512 .76167 L F
.5259 .76054 m .52512 .76167 L .52636 .76206 L F
.52798 .75822 m .52798 .75822 L .52788 .68772 L .781 .623 .061 r
F
.52904 .75973 m .52818 .76047 L .5288 .76238 L .657 .813 .958 r
F
.52818 .76047 m .52834 .76232 L .5288 .76238 L F
.52721 .75895 m .52668 .75939 L .528 .75941 L F
.52668 .75939 m .52428 .76141 L .5259 .76054 L F
.52668 .75939 m .5259 .76054 L .528 .75941 L F
.52912 .75966 m .528 .75941 L .52904 .75973 L F
.52913 .68949 m .53031 .75954 L .52921 .75924 L .845 .571 .524 r
F
.52864 .75906 m .528 .75941 L .52912 .75966 L .657 .813 .958 r
F
.52837 .68898 m .52917 .75922 L .52843 .75881 L .929 .648 .487 r
F
.5292 .68952 m .53031 .75954 L .52913 .68949 L .845 .571 .524 r
F
.53031 .75954 m .53031 .75954 L .52913 .68949 L F
.52794 .68839 m .5284 .75774 L .52828 .75862 L .988 .719 .384 r
F
.52794 .68839 m .52828 .75862 L .52799 .75825 L F
.52789 .68776 m .52794 .68839 L .52799 .75825 L .781 .623 .061 r
F
.52826 .75859 m .52721 .75895 L .52864 .75906 L .657 .813 .958 r
F
.52789 .68776 m .52799 .75825 L .52798 .75822 L .781 .623 .061 r
F
.5284 .75774 m .52841 .75878 L .52828 .75862 L .988 .719 .384 r
F
.52797 .68842 m .52841 .75878 L .52794 .68839 L F
.52875 .76209 m .52829 .76234 L .52918 .76262 L .657 .813 .959 r
F
.52843 .75881 m .52904 .76203 L .52843 .76169 L .929 .648 .487 r
F
.52841 .75878 m .52843 .76169 L .52841 .75878 L .988 .719 .384 r
F
.52843 .76169 m .52843 .76169 L .52841 .75878 L F
.52864 .75906 m .52805 .75902 L .52808 .75936 L .657 .813 .958 r
F
.52828 .75862 m .52843 .76169 L .52799 .76065 L .988 .719 .384 r
F
.52841 .75878 m .52843 .76169 L .52828 .75862 L F
.53144 .76237 m .53527 .76432 L .5341 .76202 L .657 .813 .958 r
F
.53189 .76015 m .53144 .76237 L .5341 .76202 L F
.53158 .75989 m .53156 .76027 L .53189 .76015 L F
.53156 .76027 m .53144 .76237 L .53189 .76015 L F
.5341 .76202 m .53527 .76432 L .53902 .76333 L F
.53584 .76156 m .53902 .76333 L .5366 .76136 L F
.5341 .76202 m .53566 .76244 L .53584 .76156 L F
.53566 .76244 m .53902 .76333 L .53584 .76156 L F
.5366 .76136 m .53902 .76333 L .54227 .76193 L F
.5366 .76136 m .54227 .76193 L .53877 .76042 L F
.5359 .68941 m .53757 .68998 L .53669 .689 L .597 .767 .961 r
F
.53594 .68938 m .53661 .75772 L .53594 .68938 L .08 0 .418 r
F
.5339 .68554 m .53398 .69012 L .53391 .69014 L .517 .303 .528 r
F
.53508 .68524 m .53514 .68981 L .53508 .68524 L .358 .18 .498 r
F
.53514 .68981 m .53514 .68981 L .53508 .68524 L F
.53505 .75958 m .53602 .76069 L .53619 .75984 L .657 .813 .958 r
F
.53484 .75983 m .5366 .76136 L .53505 .75958 L F
.5343 .75949 m .53479 .75989 L .53438 .75943 L F
.53479 .75989 m .5366 .76136 L .53484 .75983 L F
.53479 .75989 m .53484 .75983 L .53438 .75943 L F
.53619 .75984 m .5366 .76136 L .53877 .76042 L F
.53602 .76069 m .5366 .76136 L .53619 .75984 L F
.5339 .68554 m .53398 .69012 L .5339 .68554 L .517 .303 .528 r
F
.53398 .69012 m .53398 .69012 L .5339 .68554 L F
.53522 .75887 m .53522 .75887 L .53398 .69012 L F
.53398 .69012 m .53398 .69012 L .5339 .68554 L F
.53522 .75887 m .53398 .69012 L .53398 .69012 L F
.5322 .68816 m .5352 .68981 L .5359 .68941 L .597 .767 .961 r
F
.5352 .68981 m .53542 .68993 L .53564 .6897 L F
.5352 .68981 m .53564 .6897 L .5359 .68941 L F
.5322 .68816 m .53424 .69005 L .53517 .68979 L F
.53424 .69005 m .5344 .6902 L .53509 .68984 L F
.53424 .69005 m .53509 .68984 L .53517 .68979 L F
.53398 .69012 m .53522 .75887 L .53398 .69012 L .517 .303 .528 r
F
.53353 .75999 m .5341 .76202 L .5366 .76136 L .657 .813 .958 r
F
.53296 .75973 m .5332 .7602 L .53353 .75999 L F
.5332 .7602 m .5341 .76202 L .53353 .75999 L F
.53514 .68981 m .53608 .75833 L .53509 .68984 L .358 .18 .498 r
F
.53372 .75986 m .5366 .76136 L .5343 .75949 L .657 .813 .958 r
F
.53296 .75973 m .53353 .75999 L .53325 .75962 L F
.53353 .75999 m .5366 .76136 L .53372 .75986 L F
.53353 .75999 m .53372 .75986 L .53325 .75962 L F
.53517 .68979 m .53516 .68982 L .5352 .68981 L .597 .767 .961 r
F
.53534 .69387 m .53553 .69499 L .53584 .69154 L F
.53514 .68981 m .53591 .68941 L .53612 .7583 L .358 .18 .498 r
F
.53594 .68938 m .53661 .75772 L .53591 .68941 L .08 0 .418 r
F
.5363 .75933 m .53877 .76042 L .53886 .76036 L .657 .813 .958 r
F
.53552 .75902 m .53629 .75935 L .5363 .75933 L F
.53629 .75935 m .53877 .76042 L .5363 .75933 L F
.5322 .68816 m .5359 .68941 L .53635 .68918 L .597 .767 .961 r
F
.5364 .68895 m .53635 .68918 L .53669 .689 L F
.5322 .68816 m .53635 .68918 L .5364 .68895 L F
.54238 .68883 m .55699 .69171 L .54477 .68755 L .597 .767 .96 r
F
.53667 .68843 m .54607 .69077 L .54669 .68902 L .597 .767 .961 r
F
.53589 .68481 m .5364 .68427 L .53641 .68888 L .08 0 .418 r
F
.5322 .68816 m .53705 .68907 L .53667 .68843 L .597 .767 .961 r
F
.53705 .68907 m .54607 .69077 L .53667 .68843 L F
.53653 .68361 m .53652 .68816 L .53654 .68362 L .983 .725 .332 r
F
.53642 .68883 m .53677 .75702 L .53641 .68888 L 0 0 .15 r
F
.53677 .75702 m .53677 .75703 L .53641 .68888 L F
.53661 .75772 m .5366 .75772 L .53591 .68941 L .08 0 .418 r
F
.53551 .75902 m .53877 .76042 L .53552 .75902 L .657 .813 .958 r
F
.53559 .75894 m .53886 .76036 L .53809 .75911 L F
.53525 .75891 m .53552 .75902 L .53559 .75894 L F
.53552 .75902 m .53886 .76036 L .53559 .75894 L F
.53594 .68938 m .53641 .68888 L .53663 .75768 L .08 0 .418 r
F
.53417 .75938 m .53877 .76042 L .53525 .75891 L .657 .813 .958 r
F
.53756 .75825 m .54046 .75928 L .54157 .75801 L F
.5361 .75834 m .53785 .75872 L .53756 .75825 L F
.53785 .75872 m .54046 .75928 L .53756 .75825 L F
.53594 .68938 m .53663 .75768 L .53661 .75772 L .08 0 .418 r
F
.53591 .68941 m .5366 .75772 L .53612 .7583 L F
.53652 .68816 m .53652 .68817 L .53654 .68362 L .983 .725 .332 r
F
.53654 .68362 m .53652 .68817 L .53655 .68822 L F
.53653 .68361 m .53604 .68734 L .53652 .68816 L F
.55235 .68944 m .5692 .69103 L .55712 .68691 L .598 .766 .96 r
F
.54477 .68755 m .55699 .69171 L .56014 .68859 L .597 .767 .96 r
F
.54477 .68755 m .56014 .68859 L .54633 .68598 L F
.53688 .68785 m .54669 .68902 L .54633 .68721 L .597 .767 .961 r
F
.5322 .68816 m .53798 .6885 L .53688 .68785 L F
.53798 .6885 m .54669 .68902 L .53688 .68785 L F
.53525 .75891 m .53551 .75902 L .53552 .75902 L .657 .813 .958 r
F
.53642 .68883 m .53652 .68837 L .53648 .70008 L 0 0 .15 r
F
.53649 .70288 m .53655 .68822 L .53678 .75699 L F
.53642 .68883 m .53678 .75699 L .53677 .75702 L F
.53661 .75772 m .53661 .75772 L .53594 .68938 L .08 0 .418 r
F
.53641 .68888 m .53677 .75703 L .53663 .75768 L 0 0 .15 r
F
.53652 .68817 m .53628 .75619 L .53655 .68822 L .983 .725 .332 r
F
.53525 .75891 m .53809 .75911 L .53641 .75841 L .657 .813 .958 r
F
.53545 .75878 m .53641 .75841 L .5361 .75834 L F
.53525 .75891 m .53641 .75841 L .53545 .75878 L F
.53589 .68451 m .53589 .68481 L .53589 .68481 L .08 0 .418 r
F
.53248 .68337 m .53589 .68481 L .53609 .6846 L .597 .767 .96 r
F
.53603 .68215 m .53602 .68273 L .53603 .68274 L .911 .629 .497 r
F
.53653 .68312 m .53603 .68274 L .53653 .68361 L .983 .725 .332 r
F
.53651 .67906 m .53652 .67903 L .53653 .68312 L 0 0 .15 r
F
.54497 .68276 m .56025 .68379 L .54652 .6812 L .598 .766 .96 r
F
.53678 .68246 m .54659 .68242 L .54526 .68066 L .597 .767 .96 r
F
.53651 .67906 m .53653 .68312 L .53638 .67969 L 0 0 .15 r
F
.53652 .67903 m .53603 .68215 L .53653 .68312 L .983 .725 .332 r
F
.53603 .68215 m .53481 .68138 L .53481 .68201 L .911 .629 .497 r
F
.53248 .68337 m .53662 .68309 L .53588 .68265 L .597 .767 .96 r
F
.53248 .68337 m .53588 .68265 L .53523 .68226 L F
.53248 .68337 m .53548 .68502 L .53589 .68481 L F
.53507 .68503 m .53589 .68481 L .53511 .68522 L .358 .18 .498 r
F
.53248 .68337 m .5347 .68543 L .53548 .68502 L .597 .767 .96 r
F
.53653 .68312 m .53653 .68361 L .53654 .68362 L .983 .725 .332 r
F
.54497 .68276 m .55712 .68691 L .56025 .68379 L .598 .766 .96 r
F
.53814 .68299 m .54695 .68423 L .54659 .68242 L .597 .767 .96 r
F
.53248 .68337 m .54119 .68389 L .53814 .68299 L F
.54119 .68389 m .54695 .68423 L .53814 .68299 L F
.5322 .68816 m .53605 .68735 L .53531 .68691 L .597 .767 .961 r
F
.53424 .69005 m .53423 .69013 L .53432 .69012 L F
.53398 .69012 m .53509 .68984 L .53528 .75884 L .517 .303 .528 r
F
.53398 .69012 m .53528 .75884 L .53522 .75887 L F
.53398 .69012 m .53522 .75887 L .53391 .69014 L F
.53522 .75887 m .53522 .75887 L .53391 .69014 L F
.53391 .69014 m .53522 .75887 L .53408 .75931 L F
.53438 .75943 m .53484 .75983 L .53505 .75958 L .657 .813 .958 r
F
.53417 .75938 m .5343 .75949 L .53438 .75943 L F
.5356 .76727 m .53529 .76436 L .53905 .76336 L .597 .383 .562 r
F
.53449 .76231 m .53693 .7643 L .53912 .76336 L .657 .813 .959 r
F
.53432 .76236 m .53693 .7643 L .53449 .76231 L F
.53323 .76265 m .53361 .76282 L .53432 .76236 L F
.53361 .76282 m .53693 .7643 L .53432 .76236 L F
.53557 .76185 m .53912 .76336 L .53558 .76184 L F
.53449 .76231 m .53507 .76245 L .53557 .76185 L F
.53507 .76245 m .53912 .76336 L .53557 .76185 L F
.53558 .76184 m .53912 .76336 L .54082 .76221 L F
.53558 .76184 m .53637 .7619 L .53644 .76127 L F
.53637 .7619 m .54082 .76221 L .5365 .76128 L F
.53637 .7619 m .5365 .76128 L .53644 .76127 L F
.53877 .76042 m .54227 .76193 L .54481 .76022 L .657 .813 .958 r
F
.53644 .76127 m .54082 .76221 L .54193 .76094 L .657 .813 .959 r
F
.53644 .76127 m .54193 .76094 L .53699 .76063 L F
.53664 .76057 m .53679 .76119 L .53665 .76192 L 0 0 .15 r
F
.5361 .75834 m .53756 .75825 L .53665 .7577 L .657 .813 .958 r
F
.53809 .75911 m .53785 .75872 L .53641 .75841 L F
.53663 .75768 m .53674 .76009 L .53664 .76057 L 0 0 .15 r
F
.53612 .7583 m .53648 .76076 L .53613 .76118 L .08 0 .418 r
F
.53528 .75884 m .53586 .76136 L .53529 .76173 L .358 .18 .498 r
F
.53522 .75887 m .53527 .76174 L .53408 .75931 L .517 .303 .528 r
F
.53527 .76174 m .5353 .76305 L .53491 .76187 L F
.53527 .76174 m .53491 .76187 L .53408 .75931 L F
.53083 .69028 m .53013 .69135 L .5318 .69052 L .597 .767 .961 r
F
.53013 .69135 m .53053 .69189 L .5318 .69052 L F
.53027 .68993 m .53211 .75962 L .53037 .75955 L .751 .491 .539 r
F
.53158 .75989 m .5341 .76202 L .53292 .75971 L .657 .813 .958 r
F
.53189 .76282 m .53174 .76532 L .53442 .76497 L .657 .813 .959 r
F
.53189 .76282 m .53442 .76497 L .53323 .76265 L F
.53038 .68995 m .53212 .75962 L .53027 .68993 L .751 .491 .539 r
F
.53318 .76255 m .53189 .76282 L .53323 .76265 L .657 .813 .959 r
F
.53212 .75962 m .53219 .76251 L .53211 .75962 L .751 .491 .539 r
F
.53219 .76251 m .53219 .76251 L .53211 .75962 L F
.53222 .76251 m .53189 .76282 L .53318 .76255 L .657 .813 .959 r
F
.53191 .7625 m .53191 .76256 L .53222 .76251 L F
.53191 .76256 m .53189 .76282 L .53222 .76251 L F
.5316 .7678 m .53529 .76436 L .5356 .76727 L .668 .435 .558 r
F
.53323 .76265 m .53442 .76497 L .53693 .7643 L .657 .813 .959 r
F
.53222 .76251 m .53409 .76344 L .53222 .76363 L .641 .401 .54 r
F
.53289 .75965 m .53158 .75989 L .53292 .75971 L .657 .813 .958 r
F
.53212 .75962 m .53211 .75962 L .53027 .68993 L .751 .491 .539 r
F
.5316 .7596 m .53158 .75989 L .53289 .75965 L .657 .813 .958 r
F
.53114 .69027 m .5318 .69052 L .53208 .69022 L .597 .767 .961 r
F
.53083 .69028 m .5318 .69052 L .53114 .69027 L F
.53205 .69062 m .53153 .69113 L .532 .69145 L F
.53208 .69022 m .5318 .69052 L .53205 .69062 L F
.5322 .68816 m .53083 .69028 L .53208 .69022 L F
.53038 .68995 m .53208 .69022 L .53221 .75963 L .751 .491 .539 r
F
.53212 .75962 m .53221 .75963 L .53222 .76251 L F
.53212 .75962 m .53222 .76251 L .53219 .76251 L F
.53221 .75963 m .53405 .7622 L .53222 .76251 L .641 .401 .54 r
F
.53289 .75965 m .53292 .75971 L .53311 .75966 L .657 .813 .958 r
F
.53289 .75965 m .53311 .75966 L .53417 .75938 L F
.53282 .75952 m .53221 .75963 L .53289 .75965 L F
.53325 .75962 m .53372 .75986 L .53417 .75938 L F
.53292 .75971 m .53296 .75973 L .53325 .75962 L F
.53292 .75971 m .53293 .75975 L .53296 .75973 L F
.53293 .75975 m .5341 .76202 L .53296 .75973 L F
.53398 .75932 m .53405 .7622 L .53221 .75963 L .641 .401 .54 r
F
.53037 .75955 m .53033 .75955 L .53045 .75957 L .657 .813 .958 r
F
.53158 .75987 m .53026 .75989 L .53158 .75989 L F
.53173 .7574 m .53045 .75957 L .53158 .75987 L F
.53045 .75957 m .53026 .75989 L .53158 .75987 L F
.5292 .68952 m .53027 .68993 L .53037 .75955 L .845 .571 .524 r
F
.53031 .75954 m .53037 .75955 L .53037 .76244 L F
.53031 .75954 m .53037 .76244 L .53036 .76243 L F
.53211 .75962 m .53219 .76251 L .53037 .75955 L .751 .491 .539 r
F
.53219 .76251 m .5317 .76249 L .53037 .75955 L F
.53056 .76283 m .53174 .76532 L .53189 .76282 L .657 .813 .959 r
F
.53037 .75955 m .5317 .76249 L .53037 .76244 L .751 .491 .539 r
F
.53074 .76253 m .52933 .76267 L .53056 .76283 L .657 .813 .959 r
F
.53031 .75954 m .53036 .76243 L .53031 .75954 L .845 .571 .524 r
F
.53036 .76243 m .53036 .76243 L .53031 .75954 L F
.52978 .76228 m .52933 .76267 L .53074 .76253 L .657 .813 .959 r
F
.52978 .76228 m .52921 .76213 L .52966 .76238 L F
.52966 .76238 m .52875 .76209 L .52933 .76267 L F
.52921 .76213 m .53037 .76339 L .52921 .76296 L .845 .571 .524 r
F
.53029 .75985 m .52904 .75973 L .53026 .75989 L .657 .813 .958 r
F
.5299 .75963 m .52904 .75973 L .53029 .75985 L F
.52921 .75924 m .53008 .76236 L .52921 .76213 L .845 .571 .524 r
F
.53008 .76236 m .53037 .76339 L .52921 .76213 L F
.52921 .76213 m .52875 .76209 L .52966 .76238 L .657 .813 .959 r
F
.52895 .76199 m .52886 .76204 L .52921 .76213 L F
.52886 .76204 m .52875 .76209 L .52921 .76213 L F
.52951 .75932 m .52944 .75938 L .53033 .75955 L .657 .813 .958 r
F
.52951 .75932 m .53033 .75955 L .53037 .75955 L F
.52944 .75938 m .52904 .75973 L .5299 .75963 L F
.52944 .75938 m .5299 .75963 L .53045 .75957 L F
.53045 .75957 m .5299 .75963 L .53029 .75985 L F
.53031 .75954 m .53037 .76339 L .52921 .75924 L .845 .571 .524 r
F
.53204 .76032 m .52978 .76228 L .53074 .76253 L .657 .813 .959 r
F
.53036 .76243 m .53037 .76339 L .53036 .76243 L .845 .571 .524 r
F
.53037 .76244 m .53222 .76363 L .53037 .76339 L .751 .491 .539 r
F
.53191 .7625 m .53056 .76283 L .53189 .76282 L .657 .813 .959 r
F
.53079 .76245 m .53056 .76283 L .53191 .7625 L F
.5317 .76249 m .53222 .76363 L .53037 .76244 L .751 .491 .539 r
F
.53204 .76032 m .53079 .76245 L .53191 .7625 L .657 .813 .959 r
F
.52917 .75922 m .52921 .76296 L .52917 .75922 L .929 .648 .487 r
F
.52944 .75938 m .52867 .7591 L .52912 .75966 L .657 .813 .958 r
F
.52951 .75932 m .52921 .75924 L .52944 .75938 L F
.52921 .75924 m .52867 .7591 L .52944 .75938 L F
.52842 .68901 m .52913 .68949 L .52921 .75924 L .929 .648 .487 r
F
.52917 .75922 m .52921 .75924 L .52921 .76296 L F
.52842 .68901 m .52921 .75924 L .52917 .75922 L F
.52917 .75922 m .5292 .76213 L .52843 .75881 L F
.5292 .76213 m .52904 .76203 L .52843 .75881 L F
.53204 .76032 m .52895 .76199 L .52921 .76213 L .657 .813 .959 r
F
.53204 .76032 m .52921 .76213 L .52978 .76228 L F
.53036 .76243 m .53037 .76244 L .53037 .76339 L .845 .571 .524 r
F
.5292 .68952 m .53037 .75955 L .53031 .75954 L F
.53219 .76251 m .53222 .76363 L .5317 .76249 L .751 .491 .539 r
F
.53409 .76219 m .5353 .76305 L .53409 .76344 L .517 .303 .528 r
F
.53408 .75931 m .53491 .76187 L .53409 .76219 L F
.53491 .76187 m .5353 .76305 L .53409 .76219 L F
.53408 .75931 m .53289 .75965 L .53417 .75938 L .657 .813 .958 r
F
.53219 .69022 m .53398 .75932 L .53208 .69022 L .641 .401 .54 r
F
.53398 .75932 m .53398 .75932 L .53208 .69022 L F
.53282 .75952 m .53289 .75965 L .53408 .75931 L .657 .813 .958 r
F
.53398 .75932 m .53398 .75932 L .53208 .69022 L .641 .401 .54 r
F
.53038 .68995 m .53221 .75963 L .53212 .75962 L .751 .491 .539 r
F
.53208 .69022 m .53398 .75932 L .53221 .75963 L .641 .401 .54 r
F
.5343 .76215 m .53318 .76255 L .53449 .76231 L .657 .813 .959 r
F
.53409 .76219 m .53318 .76255 L .5343 .76215 L F
.53372 .75986 m .5343 .75949 L .53417 .75938 L .657 .813 .958 r
F
.53219 .69022 m .5322 .69022 L .53406 .7622 L .641 .401 .54 r
F
.53406 .7622 m .53406 .7622 L .53409 .76344 L F
.53219 .69022 m .53406 .7622 L .53406 .7622 L F
.53406 .7622 m .53405 .7622 L .53398 .75932 L F
.53406 .7622 m .53398 .75932 L .53398 .75932 L F
.53398 .75932 m .53406 .7622 L .53398 .75932 L F
.53309 .76236 m .53318 .76254 L .53409 .76219 L .657 .813 .959 r
F
.53408 .75931 m .53417 .75938 L .53451 .75923 L .657 .813 .958 r
F
.53318 .69017 m .533 .69037 L .53331 .69042 L .597 .767 .961 r
F
.5322 .69022 m .53391 .69014 L .53409 .76219 L .641 .401 .54 r
F
.53406 .7622 m .53409 .76219 L .53409 .76344 L F
.5322 .69022 m .53409 .76219 L .53406 .7622 L F
.53318 .76254 m .53318 .76255 L .53409 .76219 L .657 .813 .959 r
F
.53409 .76219 m .53409 .76219 L .53426 .76212 L F
.53318 .76254 m .53409 .76219 L .53409 .76219 L F
.53204 .76032 m .53309 .76236 L .53426 .76212 L F
.53309 .76236 m .53409 .76219 L .53426 .76212 L F
.53173 .7574 m .53408 .75931 L .53525 .75891 L .657 .813 .958 r
F
.53408 .75931 m .53451 .75923 L .53525 .75891 L F
.53173 .7574 m .53282 .75952 L .53408 .75931 L F
.53406 .7622 m .53409 .76344 L .53405 .7622 L .641 .401 .54 r
F
.53426 .76212 m .53409 .76219 L .5343 .76215 L .657 .813 .959 r
F
.53318 .76255 m .53323 .76265 L .53355 .76256 L F
.53318 .76255 m .53355 .76256 L .53449 .76231 L F
.53219 .76251 m .53222 .76251 L .53222 .76363 L .751 .491 .539 r
F
.53173 .7574 m .5316 .7596 L .53221 .75963 L .657 .813 .958 r
F
.53173 .7574 m .53221 .75963 L .53282 .75952 L F
.53204 .76032 m .53191 .7625 L .53318 .76255 L .657 .813 .959 r
F
.53405 .7622 m .53409 .76344 L .53222 .76251 L .641 .401 .54 r
F
.53219 .76251 m .53222 .76363 L .53219 .76251 L .751 .491 .539 r
F
.53509 .68984 m .53607 .75833 L .53528 .75884 L .358 .18 .498 r
F
.53173 .7574 m .53525 .75891 L .5361 .75834 L .657 .813 .958 r
F
.53522 .75887 m .53528 .75884 L .53529 .76173 L .517 .303 .528 r
F
.53527 .76173 m .53529 .76173 L .5353 .76305 L F
.53522 .75887 m .53529 .76173 L .53527 .76173 L F
.5353 .76172 m .53449 .76231 L .53558 .76184 L .657 .813 .959 r
F
.53522 .75887 m .53527 .76173 L .53522 .75887 L .517 .303 .528 r
F
.53527 .76173 m .5353 .76305 L .53527 .76174 L F
.53527 .76173 m .53527 .76174 L .53522 .75887 L F
.53608 .75833 m .53612 .7583 L .53613 .76118 L .358 .18 .498 r
F
.53611 .76119 m .53613 .76118 L .53613 .76254 L F
.53608 .75833 m .53613 .76118 L .53611 .76119 L F
.5361 .7612 m .5353 .76172 L .53644 .76127 L .657 .813 .959 r
F
.5353 .76172 m .5353 .76172 L .5361 .7612 L F
.5353 .76172 m .53558 .76184 L .53638 .76131 L F
.5353 .76172 m .53638 .76131 L .53644 .76127 L F
.53607 .75833 m .53611 .76119 L .53528 .75884 L .358 .18 .498 r
F
.53611 .76119 m .53613 .76254 L .53586 .76136 L F
.53611 .76119 m .53586 .76136 L .53528 .75884 L F
.53698 .76063 m .53644 .76127 L .53699 .76063 L .657 .813 .959 r
F
.53661 .75772 m .53663 .75768 L .53664 .76057 L .08 0 .418 r
F
.53613 .76118 m .53644 .76127 L .53698 .76063 L .657 .813 .959 r
F
.5361 .7612 m .53611 .7612 L .53613 .76118 L F
.53611 .7612 m .53644 .76127 L .53613 .76118 L F
.53661 .75772 m .53663 .76058 L .5366 .75772 L .08 0 .418 r
F
.53663 .76058 m .53665 .76192 L .53663 .76058 L F
.53663 .76058 m .53663 .76058 L .5366 .75772 L F
.53663 .76058 m .53664 .76057 L .53665 .76192 L F
.53661 .75772 m .53664 .76057 L .53663 .76058 L F
.53522 .75887 m .5353 .76305 L .53522 .75887 L .517 .303 .528 r
F
.53204 .76032 m .5361 .7612 L .53613 .76118 L .657 .813 .959 r
F
.53661 .76061 m .53613 .76118 L .53698 .76063 L F
.53608 .75833 m .53611 .76119 L .53607 .75833 L .358 .18 .498 r
F
.53611 .76119 m .53613 .76254 L .53611 .76119 L F
.53611 .76119 m .53611 .76119 L .53607 .75833 L F
.53514 .68981 m .53612 .7583 L .53608 .75833 L F
.53608 .75833 m .53607 .75833 L .53509 .68984 L F
.53514 .68981 m .53608 .75833 L .53514 .68981 L F
.53608 .75833 m .53608 .75833 L .53514 .68981 L F
.53173 .7574 m .5361 .75834 L .53665 .7577 L .657 .813 .958 r
F
.53173 .7574 m .53665 .7577 L .53687 .75705 L F
.53173 .7574 m .53687 .75705 L .53673 .75641 L F
.53173 .7574 m .53673 .75641 L .53668 .75635 L F
.53679 .68719 m .54633 .68721 L .545 .68546 L .597 .767 .961 r
F
.5322 .68816 m .53862 .68773 L .53679 .68719 L F
.53862 .68773 m .54633 .68721 L .53679 .68719 L F
.53173 .7574 m .53668 .75635 L .53589 .75597 L .657 .813 .958 r
F
.53481 .68138 m .5348 .682 L .53481 .68201 L .81 .54 .53 r
F
.53603 .68215 m .53481 .68201 L .53602 .68273 L .911 .629 .497 r
F
.53276 .67859 m .54678 .67764 L .54546 .67589 L .598 .766 .96 r
F
.53276 .67859 m .54714 .67945 L .54678 .67764 L F
.53601 .67814 m .53481 .68138 L .53603 .68215 L .911 .629 .497 r
F
.53604 .67819 m .53601 .67814 L .53603 .68215 L .983 .725 .332 r
F
.53713 .68009 m .53715 .68011 L .53718 .6801 L .598 .766 .96 r
F
.53604 .67819 m .53603 .68215 L .53652 .67903 L .983 .725 .332 r
F
.53449 .68191 m .54306 .67909 L .54012 .67781 L .597 .767 .96 r
F
.53248 .68337 m .53541 .68218 L .53449 .68191 L F
.53541 .68218 m .54306 .67909 L .53449 .68191 L F
.53481 .68138 m .53357 .68103 L .53358 .68164 L .81 .54 .53 r
F
.5348 .682 m .53359 .68625 L .53474 .68659 L F
.53481 .68201 m .53475 .68631 L .53483 .68626 L F
.53475 .68631 m .53475 .68659 L .53483 .68626 L F
.53483 .68626 m .53475 .68659 L .53483 .68661 L F
.5322 .68816 m .53553 .68682 L .53448 .68651 L .597 .767 .961 r
F
.5348 .682 m .53474 .68659 L .53481 .68201 L .81 .54 .53 r
F
.53474 .68659 m .53381 .75534 L .53475 .68659 L F
.53381 .75534 m .53381 .75534 L .53475 .68659 L F
.53173 .7574 m .53406 .75538 L .53375 .75533 L .657 .813 .958 r
F
.5322 .68816 m .53325 .69031 L .53424 .69005 L .597 .767 .961 r
F
.53248 .68337 m .5336 .68164 L .5326 .68152 L .597 .767 .96 r
F
.53481 .68138 m .53358 .68164 L .5348 .682 L .81 .54 .53 r
F
.5348 .67741 m .53357 .68103 L .53481 .68138 L F
.53486 .67745 m .5348 .67741 L .53481 .68138 L .911 .629 .497 r
F
.53486 .67745 m .53481 .68138 L .53601 .67814 L F
.5336 .68164 m .54012 .67781 L .53666 .6769 L .597 .767 .96 r
F
.53248 .68337 m .53467 .68178 L .5336 .68164 L F
.53467 .68178 m .54012 .67781 L .5336 .68164 L F
.53357 .68103 m .53232 .68091 L .53232 .68148 L .734 .477 .539 r
F
.53173 .7574 m .53375 .75533 L .53295 .75532 L .657 .813 .958 r
F
.53357 .68164 m .53233 .68609 L .5335 .68624 L .734 .477 .539 r
F
.5322 .68816 m .53345 .68623 L .53233 .68609 L .597 .767 .961 r
F
.53248 .68337 m .52995 .68521 L .53026 .68533 L .597 .767 .96 r
F
.53248 .68337 m .53026 .68533 L .53113 .68547 L F
.53026 .68533 m .53207 .68563 L .53026 .68538 L .751 .491 .539 r
F
.53207 .68563 m .53207 .68563 L .53026 .68533 L F
.52913 .68152 m .52559 .67694 L .52252 .67787 L .597 .767 .96 r
F
.52979 .68131 m .52978 .68172 L .52979 .68172 L .4 .211 .506 r
F
.53106 .68099 m .52979 .68131 L .52979 .68172 L .567 .342 .533 r
F
.53248 .68337 m .53056 .68158 L .52956 .68176 L .597 .767 .96 r
F
.52842 .68901 m .52917 .75922 L .52837 .68898 L .929 .648 .487 r
F
.52917 .75922 m .52917 .75922 L .52837 .68898 L F
.52841 .75878 m .52841 .75878 L .52794 .68839 L .988 .719 .384 r
F
.5279 .75815 m .52659 .75775 L .52673 .75838 L .657 .813 .958 r
F
.52797 .68842 m .52837 .68898 L .52843 .75881 L .988 .719 .384 r
F
.52797 .68842 m .52843 .75881 L .52841 .75879 L F
.52841 .75878 m .52843 .76169 L .52843 .76169 L F
.52797 .68842 m .52841 .75879 L .52841 .75878 L F
.52841 .75879 m .52843 .76169 L .52841 .75878 L F
.52753 .75768 m .52681 .75709 L .52659 .75775 L .657 .813 .958 r
F
.52596 .68698 m .51984 .68396 L .5183 .68554 L .597 .767 .961 r
F
.5322 .68816 m .5285 .6869 L .52763 .6873 L F
.52846 .68696 m .52796 .75753 L .5285 .68691 L 0 0 .377 r
F
.52787 .75766 m .52771 .75714 L .52753 .75768 L .657 .813 .958 r
F
.52788 .68772 m .52795 .75788 L .52793 .75757 L .781 .623 .061 r
F
.53173 .7574 m .5282 .75717 L .52787 .75766 L .657 .813 .958 r
F
.52796 .75753 m .52796 .75753 L .5285 .68691 L 0 0 .377 r
F
.5285 .68691 m .52796 .75753 L .52856 .75665 L F
.52846 .68696 m .52796 .75753 L .52846 .68696 L F
.52796 .75753 m .52796 .75753 L .52846 .68696 L F
.52846 .68696 m .52788 .68772 L .52793 .75757 L F
.53173 .7574 m .52787 .75766 L .5279 .75815 L .657 .813 .958 r
F
.52793 .75814 m .5279 .75815 L .52793 .75818 L F
.52793 .75814 m .52793 .75818 L .52826 .75859 L F
.53173 .7574 m .52793 .75814 L .52826 .75859 L F
.52826 .75859 m .52748 .75823 L .52721 .75895 L F
.5279 .75815 m .52748 .75823 L .52826 .75859 L F
.52793 .75757 m .52795 .75788 L .52793 .76051 L .781 .623 .061 r
F
.52794 .7606 m .52687 .76068 L .52799 .76112 L .657 .813 .959 r
F
.52793 .75757 m .52793 .76051 L .52793 .76046 L .781 .623 .061 r
F
.52783 .76061 m .52709 .76002 L .52687 .76068 L .657 .813 .959 r
F
.52841 .75879 m .52843 .75881 L .52843 .76169 L .988 .719 .384 r
F
.52805 .75902 m .52721 .75895 L .52808 .75936 L .657 .813 .958 r
F
.52798 .75822 m .52799 .75825 L .52799 .76114 L .781 .623 .061 r
F
.52798 .75822 m .52799 .76114 L .52799 .76114 L F
.52799 .75825 m .52828 .75862 L .52799 .76065 L .988 .719 .384 r
F
.52798 .75822 m .52799 .76114 L .52798 .75822 L .781 .623 .061 r
F
.52799 .76112 m .52701 .76131 L .52804 .7617 L .657 .813 .959 r
F
.52799 .76114 m .52799 .7618 L .52799 .76114 L .781 .623 .061 r
F
.52799 .76114 m .52799 .76114 L .52798 .75822 L F
.52804 .7617 m .52701 .76131 L .5275 .76188 L .657 .813 .959 r
F
.52799 .76065 m .52843 .76169 L .52799 .76114 L .988 .719 .384 r
F
.53204 .76032 m .52799 .76112 L .52804 .7617 L .657 .813 .959 r
F
.53204 .76032 m .52819 .76008 L .52783 .76061 L F
.52796 .75753 m .52794 .76045 L .52796 .75753 L 0 0 .377 r
F
.52793 .76046 m .52793 .76051 L .52793 .76106 L .781 .623 .061 r
F
.52794 .76045 m .52793 .76106 L .52794 .76045 L 0 0 .377 r
F
.52794 .76045 m .52794 .76045 L .52796 .75753 L F
.53204 .76032 m .52854 .75957 L .52819 .76008 L .657 .813 .959 r
F
.53204 .76032 m .52794 .7606 L .52799 .76112 L F
.53173 .7574 m .52826 .75859 L .52864 .75906 L .657 .813 .958 r
F
.52846 .68696 m .52793 .75757 L .52796 .75753 L 0 0 .377 r
F
.52771 .75714 m .52735 .75645 L .52681 .75709 L .657 .813 .958 r
F
.53173 .7574 m .52849 .75669 L .52771 .75714 L F
.52849 .75669 m .52735 .75645 L .52771 .75714 L F
.52846 .68696 m .52846 .68696 L .52849 .6823 L 0 0 .377 r
F
.52849 .6823 m .52846 .68696 L .5285 .68691 L F
.52741 .68307 m .51801 .68251 L .52786 .68368 L .597 .767 .96 r
F
.5285 .6869 m .52222 .68267 L .51984 .68396 L .597 .767 .961 r
F
.5322 .68816 m .52928 .68655 L .5285 .6869 L F
.52978 .68172 m .52849 .6823 L .5285 .68691 L .4 .211 .506 r
F
.52913 .68489 m .52913 .68494 L .52912 .68489 L .929 .648 .487 r
F
.52913 .68489 m .53026 .68538 L .52913 .68494 L .845 .571 .524 r
F
.53025 .68533 m .53026 .68538 L .52913 .68489 L F
.52978 .68172 m .5285 .68691 L .52971 .68636 L .4 .211 .506 r
F
.52928 .68655 m .52222 .68267 L .5285 .6869 L .597 .767 .961 r
F
.52978 .68172 m .52971 .68636 L .52979 .68172 L .4 .211 .506 r
F
.52971 .68636 m .52972 .68636 L .52979 .68172 L F
.52979 .68172 m .52972 .68636 L .52979 .68632 L F
.53106 .68099 m .52979 .68172 L .53105 .6815 L .567 .342 .533 r
F
.53232 .68091 m .53106 .68099 L .53106 .6815 L .66 .416 .54 r
F
.53232 .68091 m .53106 .6815 L .53218 .68148 L F
.53048 .6815 m .52913 .67646 L .52559 .67694 L .597 .767 .96 r
F
.53248 .68337 m .53106 .6815 L .53056 .68158 L F
.52909 .68644 m .5253 .68175 L .52222 .68267 L .597 .767 .961 r
F
.5322 .68816 m .53016 .68626 L .52909 .68644 L F
.53105 .6815 m .52979 .68172 L .52979 .68632 L .567 .342 .533 r
F
.53105 .6815 m .52979 .68632 L .53098 .68612 L F
.53016 .68626 m .5253 .68175 L .52909 .68644 L .597 .767 .961 r
F
.53173 .7574 m .52951 .75932 L .53045 .75957 L .657 .813 .958 r
F
.53173 .7574 m .52864 .75906 L .52867 .7591 L F
.53173 .7574 m .52867 .7591 L .52951 .75932 L F
.53106 .6815 m .53099 .68612 L .53107 .6861 L .567 .342 .533 r
F
.52849 .68204 m .52849 .6823 L .52849 .6823 L 0 0 .377 r
F
.52828 .68258 m .52849 .6823 L .528 .68253 L .597 .767 .96 r
F
.52886 .68214 m .52013 .67917 L .528 .68253 L F
.52768 .68338 m .52741 .68307 L .52766 .68341 L F
.52768 .68338 m .52766 .68341 L .52786 .68368 L F
.53016 .68626 m .52885 .68126 L .5253 .68175 L .597 .767 .961 r
F
.5322 .68816 m .53119 .68608 L .53016 .68626 L F
.53105 .6815 m .53098 .68612 L .53106 .6815 L .567 .342 .533 r
F
.53098 .68612 m .53099 .68612 L .53106 .6815 L F
.53248 .68337 m .53157 .68149 L .53106 .6815 L .597 .767 .96 r
F
.53232 .68091 m .53218 .68148 L .53231 .68148 L .66 .416 .54 r
F
.53276 .67859 m .54036 .67304 L .53692 .67214 L .598 .766 .96 r
F
.53238 .67689 m .53232 .68091 L .53356 .67705 L .734 .477 .539 r
F
.53157 .68149 m .53291 .67644 L .52913 .67646 L .597 .767 .96 r
F
.53248 .68337 m .5326 .68148 L .53157 .68149 L F
.53232 .68091 m .53231 .68148 L .53232 .68148 L .66 .416 .54 r
F
.53356 .67705 m .53232 .68091 L .53357 .68103 L .734 .477 .539 r
F
.5326 .68148 m .53291 .67644 L .53157 .68149 L .597 .767 .96 r
F
.53232 .68148 m .53225 .68609 L .53233 .68609 L .66 .416 .54 r
F
.53231 .68148 m .53225 .68609 L .53232 .68148 L F
.53231 .68148 m .53107 .6861 L .53225 .68609 L F
.53218 .68148 m .53107 .6861 L .53231 .68148 L F
.53218 .68148 m .53106 .6815 L .53107 .6861 L F
.53119 .68608 m .52885 .68126 L .53016 .68626 L .597 .767 .961 r
F
.52773 .75653 m .5282 .75588 L .52735 .75645 L .657 .813 .958 r
F
.52971 .68636 m .52861 .75662 L .52972 .68636 L .4 .211 .506 r
F
.53173 .7574 m .52918 .7563 L .52849 .75669 L .657 .813 .958 r
F
.52856 .75954 m .52793 .76106 L .52856 .76014 L 0 0 .377 r
F
.52856 .75665 m .52804 .7603 L .52856 .75954 L F
.52804 .7603 m .52793 .76106 L .52856 .75954 L F
.52796 .75753 m .52793 .75757 L .52793 .76046 L F
.52796 .75753 m .52793 .76046 L .52793 .76045 L F
.52796 .75753 m .52793 .76106 L .52856 .75665 L F
.52796 .75753 m .52793 .76106 L .52796 .75753 L F
.52852 .75957 m .52849 .7588 L .52764 .75937 L .657 .813 .959 r
F
.53204 .76032 m .52927 .75913 L .52852 .75957 L F
.52861 .75662 m .52861 .75662 L .52972 .68636 L .4 .211 .506 r
F
.52972 .68636 m .52861 .75662 L .52979 .68632 L F
.52861 .75662 m .52862 .75662 L .52979 .68632 L F
.52979 .68632 m .52862 .75662 L .52988 .75589 L F
.52971 .68636 m .5285 .68691 L .52856 .75954 L F
.52857 .75954 m .52856 .75954 L .52856 .76014 L F
.52971 .68636 m .52856 .75954 L .52857 .75954 L F
.53204 .76032 m .53007 .75872 L .52927 .75913 L .657 .813 .959 r
F
.53173 .7574 m .52988 .75589 L .5289 .75618 L .657 .813 .958 r
F
.53107 .6861 m .52994 .75587 L .53118 .7555 L .567 .342 .533 r
F
.53098 .68612 m .52994 .75587 L .53099 .68612 L F
.52994 .75587 m .52994 .75587 L .53099 .68612 L F
.53099 .68612 m .52994 .75587 L .53107 .6861 L F
.52994 .75587 m .52994 .75587 L .53107 .6861 L F
.53173 .7574 m .53082 .75561 L .52988 .75589 L .657 .813 .958 r
F
.53007 .75872 m .52988 .75878 L .52927 .75913 L .657 .813 .959 r
F
.53098 .68612 m .52979 .68632 L .52988 .75878 L .567 .342 .533 r
F
.52989 .75877 m .52988 .75878 L .52988 .75943 L F
.53098 .68612 m .52988 .75878 L .52989 .75877 L F
.52988 .75589 m .52878 .75941 L .52988 .75878 L .4 .211 .506 r
F
.53003 .75869 m .52958 .75833 L .52934 .75894 L .657 .813 .959 r
F
.52988 .75878 m .52934 .75894 L .52927 .75913 L F
.53003 .75869 m .52934 .75894 L .52988 .75878 L F
.52988 .75589 m .53054 .75507 L .52929 .75541 L .657 .813 .958 r
F
.53082 .75561 m .53054 .75507 L .52988 .75589 L F
.52994 .75587 m .52989 .75877 L .52994 .75587 L .567 .342 .533 r
F
.52989 .75877 m .5299 .75877 L .52994 .75587 L F
.5322 .68816 m .53208 .69022 L .53318 .69017 L .597 .767 .961 r
F
.53106 .68099 m .53105 .6815 L .53106 .6815 L .567 .342 .533 r
F
.53056 .68158 m .53106 .6815 L .53048 .6815 L .597 .767 .96 r
F
.53157 .68149 m .52913 .67646 L .53048 .6815 L F
.52956 .68176 m .53048 .6815 L .52913 .68152 L F
.53056 .68158 m .53048 .6815 L .52956 .68176 L F
.53048 .6815 m .52559 .67694 L .52913 .68152 L F
.53357 .68164 m .53232 .68148 L .53233 .68609 L .734 .477 .539 r
F
.53357 .68103 m .53232 .68148 L .53357 .68164 L F
.53363 .67707 m .53356 .67705 L .53357 .68103 L .81 .54 .53 r
F
.53363 .67707 m .53357 .68103 L .5348 .67741 L F
.5326 .68152 m .53666 .6769 L .53291 .67644 L .597 .767 .96 r
F
.53357 .68103 m .53357 .68164 L .53358 .68164 L .734 .477 .539 r
F
.5336 .68164 m .53666 .6769 L .5326 .68152 L .597 .767 .96 r
F
.5322 .68816 m .53263 .68125 L .52885 .68126 L .597 .767 .961 r
F
.53358 .68164 m .53351 .68624 L .53359 .68625 L .734 .477 .539 r
F
.5322 .68816 m .53465 .68639 L .53345 .68623 L .597 .767 .961 r
F
.53357 .68164 m .53253 .75532 L .53358 .68164 L .734 .477 .539 r
F
.53474 .68659 m .53475 .68659 L .53481 .68201 L .81 .54 .53 r
F
.5348 .682 m .53358 .68164 L .53359 .68625 L F
.53602 .68273 m .53483 .68661 L .53596 .68729 L .911 .629 .497 r
F
.53602 .68273 m .53481 .68201 L .53483 .68661 L F
.53588 .68265 m .53665 .68309 L .53678 .68246 L .597 .767 .96 r
F
.53662 .68309 m .53665 .68309 L .53588 .68265 L F
.53665 .68309 m .54659 .68242 L .53678 .68246 L F
.53603 .68274 m .53596 .68729 L .53604 .68734 L .911 .629 .497 r
F
.53602 .68273 m .53596 .68729 L .53603 .68274 L F
.53523 .68226 m .54526 .68066 L .54306 .67909 L .597 .767 .96 r
F
.53588 .68265 m .54526 .68066 L .53523 .68226 L F
.53653 .68361 m .53603 .68274 L .53604 .68734 L .983 .725 .332 r
F
.53653 .68361 m .53654 .68362 L .53654 .68361 L .597 .767 .96 r
F
.53366 .68591 m .53985 .68261 L .53639 .68171 L .597 .767 .961 r
F
.53345 .68623 m .53383 .68602 L .53366 .68591 L F
.53383 .68602 m .53985 .68261 L .53366 .68591 L F
.53465 .68639 m .53985 .68261 L .53345 .68623 L F
.53359 .68625 m .53253 .75532 L .53375 .75533 L .734 .477 .539 r
F
.53351 .68624 m .53253 .75532 L .53359 .68625 L F
.53225 .68609 m .53107 .6861 L .53118 .7555 L .66 .416 .54 r
F
.53225 .68609 m .53118 .7555 L .53124 .75549 L F
.53173 .7574 m .53185 .75541 L .53079 .75555 L .657 .813 .958 r
F
.53204 .76032 m .53107 .75842 L .53007 .75872 L .657 .813 .959 r
F
.53173 .7574 m .53295 .75532 L .53185 .75541 L .657 .813 .958 r
F
.53295 .75532 m .53299 .75525 L .53247 .75532 L F
.53295 .75532 m .53247 .75532 L .53185 .75541 L F
.5335 .68624 m .53233 .68609 L .53247 .75532 L .734 .477 .539 r
F
.53474 .68659 m .53359 .68625 L .53375 .75533 L .81 .54 .53 r
F
.53596 .68729 m .53502 .75555 L .53508 .75558 L .911 .629 .497 r
F
.53604 .68734 m .53508 .75558 L .53626 .75615 L F
.53173 .7574 m .53509 .75558 L .53406 .75538 L .657 .813 .958 r
F
.53508 .75558 m .53508 .75558 L .53604 .68734 L .911 .629 .497 r
F
.53509 .75558 m .53513 .75557 L .53502 .75555 L .657 .813 .958 r
F
.53509 .75558 m .53502 .75555 L .53406 .75538 L F
.53596 .68729 m .53508 .75558 L .53604 .68734 L .911 .629 .497 r
F
.53652 .68816 m .53604 .68734 L .53626 .75615 L .983 .725 .332 r
F
.53601 .75575 m .53626 .75584 L .53606 .75573 L .657 .813 .958 r
F
.53173 .7574 m .5361 .7559 L .53601 .75575 L F
.5361 .7559 m .53626 .75584 L .53601 .75575 L F
.53513 .75557 m .53606 .75573 L .53547 .75538 L F
.53173 .7574 m .53606 .75573 L .53513 .75557 L F
.53502 .75555 m .53407 .75827 L .53502 .75844 L .81 .54 .53 r
F
.53204 .76032 m .53436 .75832 L .53376 .75822 L .657 .813 .959 r
F
.53375 .75533 m .53276 .75821 L .53376 .75822 L .734 .477 .539 r
F
.53329 .75822 m .53376 .75822 L .53333 .75814 L .657 .813 .959 r
F
.53204 .76032 m .53376 .75822 L .53329 .75822 L F
.53253 .75532 m .53247 .75532 L .53248 .75821 L .734 .477 .539 r
F
.53253 .75532 m .53248 .75821 L .53249 .75821 L F
.53204 .76032 m .53248 .75821 L .53217 .75825 L .657 .813 .959 r
F
.53247 .75532 m .53145 .75835 L .53248 .75821 L .66 .416 .54 r
F
.53125 .75549 m .5312 .75839 L .53247 .75532 L F
.5312 .75839 m .53145 .75835 L .53247 .75532 L F
.53204 .76032 m .53217 .75825 L .53106 .75841 L .657 .813 .959 r
F
.53124 .75549 m .53118 .7555 L .53119 .75912 L .66 .416 .54 r
F
.53118 .7555 m .53012 .75871 L .53119 .75839 L .567 .342 .533 r
F
.53225 .68609 m .53119 .75912 L .53233 .68609 L .66 .416 .54 r
F
.53106 .75841 m .53219 .75781 L .53085 .75799 L .657 .813 .959 r
F
.53217 .75825 m .53219 .75781 L .53106 .75841 L F
.5312 .75839 m .53119 .75912 L .53145 .75835 L .66 .416 .54 r
F
.53248 .75821 m .53119 .75912 L .53248 .75904 L F
.53145 .75835 m .53119 .75912 L .53248 .75821 L F
.53204 .76032 m .53329 .75822 L .53248 .75821 L .657 .813 .959 r
F
.53217 .75825 m .53248 .75821 L .53217 .75821 L F
.53253 .75532 m .53248 .75904 L .53375 .75533 L .734 .477 .539 r
F
.53217 .75821 m .53353 .75781 L .53219 .75781 L .657 .813 .959 r
F
.53329 .75822 m .53353 .75781 L .53217 .75821 L F
.53249 .75821 m .53248 .75821 L .53248 .75904 L .734 .477 .539 r
F
.53382 .75534 m .53377 .75822 L .53502 .75555 L .81 .54 .53 r
F
.53377 .75822 m .53376 .75916 L .53407 .75827 L F
.53377 .75822 m .53407 .75827 L .53502 .75555 L F
.53508 .75558 m .53504 .75844 L .53508 .75558 L .911 .629 .497 r
F
.53204 .76032 m .53608 .75894 L .5353 .75857 L .657 .813 .959 r
F
.53676 .76 m .53708 .76034 L .53686 .75999 L F
.5366 .75772 m .53663 .76058 L .53612 .7583 L .08 0 .418 r
F
.53663 .76058 m .53665 .76192 L .53648 .76076 L F
.53663 .76058 m .53648 .76076 L .53612 .7583 L F
.53683 .76034 m .53698 .76063 L .53708 .76034 L .657 .813 .959 r
F
.54029 .75809 m .53991 .75791 L .53665 .7577 L .657 .813 .958 r
F
.53665 .7577 m .54157 .75801 L .542 .7567 L F
.53665 .7577 m .542 .7567 L .53687 .75705 L F
.53677 .75702 m .53678 .75699 L .53679 .75987 L 0 0 .15 r
F
.53669 .76034 m .53708 .76034 L .53676 .76 L .657 .813 .959 r
F
.53677 .75702 m .53679 .75987 L .53678 .75988 L 0 0 .15 r
F
.53677 .75702 m .53678 .75988 L .53677 .75703 L F
.53678 .75988 m .53678 .75989 L .53677 .75703 L F
.53661 .75772 m .53665 .76192 L .53661 .75772 L .08 0 .418 r
F
.53608 .75833 m .53613 .76254 L .53608 .75833 L .358 .18 .498 r
F
.53204 .76032 m .53676 .76 L .53652 .75944 L .657 .813 .959 r
F
.53676 .76 m .53686 .75999 L .53679 .75987 L F
.53676 .76 m .53679 .75987 L .53652 .75944 L F
.53677 .75703 m .53678 .75989 L .53663 .75768 L 0 0 .15 r
F
.53669 .76034 m .53664 .76057 L .53683 .76034 L .657 .813 .959 r
F
.53678 .75989 m .53679 .76119 L .53674 .76009 L 0 0 .15 r
F
.53678 .75989 m .53674 .76009 L .53663 .75768 L F
.53678 .75988 m .53679 .75987 L .53679 .76119 L F
.53204 .76032 m .53669 .76034 L .53676 .76 L .657 .813 .959 r
F
.53678 .75988 m .53679 .76119 L .53678 .75989 L 0 0 .15 r
F
.53674 .76009 m .53679 .76119 L .53664 .76057 L F
.53756 .75825 m .53726 .75777 L .53665 .7577 L .657 .813 .958 r
F
.53204 .76032 m .53664 .76057 L .53669 .76034 L .657 .813 .959 r
F
.53679 .75987 m .53627 .76024 L .53679 .76119 L .983 .725 .332 r
F
.53678 .75699 m .53642 .75928 L .53679 .75987 L F
.53642 .75928 m .53627 .76024 L .53679 .75987 L F
.53204 .76032 m .53652 .75944 L .53627 .75903 L .657 .813 .959 r
F
.53626 .75615 m .53536 .7586 L .53627 .75903 L .911 .629 .497 r
F
.53608 .75894 m .53627 .75903 L .53619 .7589 L .657 .813 .959 r
F
.53204 .76032 m .53627 .75903 L .53608 .75894 L F
.53508 .75558 m .53504 .75845 L .53626 .75615 L .911 .629 .497 r
F
.53504 .75845 m .53503 .7595 L .53536 .7586 L F
.53504 .75845 m .53536 .7586 L .53626 .75615 L F
.53629 .75619 m .53627 .75905 L .53678 .75699 L .983 .725 .332 r
F
.53627 .75905 m .53627 .76024 L .53642 .75928 L F
.53627 .75905 m .53642 .75928 L .53678 .75699 L F
.5353 .75857 m .53605 .75868 L .53581 .7583 L .657 .813 .959 r
F
.53628 .75619 m .53627 .75905 L .53628 .75619 L .983 .725 .332 r
F
.53627 .75905 m .53627 .76024 L .53627 .75905 L F
.53627 .75905 m .53627 .75905 L .53628 .75619 L F
.53608 .75894 m .53619 .7589 L .5353 .75857 L .657 .813 .959 r
F
.53619 .7589 m .53659 .75876 L .53605 .75868 L F
.53619 .7589 m .53605 .75868 L .5353 .75857 L F
.53605 .75868 m .53659 .75876 L .53582 .75831 L F
.53605 .75868 m .53582 .75831 L .53581 .7583 L F
.53619 .7589 m .53707 .75933 L .53659 .75876 L F
.53652 .75944 m .53707 .75933 L .53619 .7589 L F
.53652 .75944 m .53721 .75997 L .53707 .75933 L F
.53686 .75999 m .53721 .75997 L .53652 .75944 L F
.53628 .75619 m .53627 .75905 L .53629 .75619 L .983 .725 .332 r
F
.53627 .75905 m .53627 .76024 L .53627 .75905 L F
.53627 .75905 m .53627 .75905 L .53629 .75619 L F
.53204 .76032 m .53661 .76061 L .53664 .76057 L .657 .813 .959 r
F
.53661 .76061 m .53698 .76063 L .53683 .76034 L F
.53627 .75903 m .53503 .7595 L .53627 .76024 L .911 .629 .497 r
F
.53536 .7586 m .53503 .7595 L .53627 .75903 L F
.53542 .75851 m .53581 .7583 L .53477 .75832 L .657 .813 .959 r
F
.53502 .75844 m .53477 .75832 L .53436 .75832 L F
.53542 .75851 m .53477 .75832 L .53502 .75844 L F
.53508 .75558 m .53502 .75555 L .53502 .75844 L .911 .629 .497 r
F
.53504 .75844 m .53502 .75844 L .53503 .7595 L F
.53508 .75558 m .53502 .75844 L .53504 .75844 L F
.53504 .75844 m .53503 .7595 L .53504 .75845 L F
.53504 .75844 m .53504 .75845 L .53508 .75558 L F
.53451 .75819 m .53581 .7583 L .53476 .75797 L .657 .813 .959 r
F
.53436 .75832 m .53477 .75832 L .53451 .75819 L F
.53477 .75832 m .53581 .7583 L .53451 .75819 L F
.53204 .76032 m .53542 .75851 L .53436 .75832 L F
.53376 .75822 m .53248 .75904 L .53376 .75916 L .734 .477 .539 r
F
.53276 .75821 m .53248 .75904 L .53376 .75822 L F
.53381 .75534 m .53375 .75533 L .53376 .75916 L .81 .54 .53 r
F
.53381 .75534 m .53376 .75916 L .53381 .75534 L F
.53475 .68659 m .53376 .75916 L .53483 .68661 L F
.53333 .75814 m .53476 .75797 L .53353 .75781 L .657 .813 .959 r
F
.53436 .75832 m .53476 .75797 L .53333 .75814 L F
.53502 .75844 m .53376 .75916 L .53503 .7595 L .81 .54 .53 r
F
.53407 .75827 m .53376 .75916 L .53502 .75844 L F
.53483 .68661 m .53382 .75534 L .53502 .75555 L F
.53474 .68659 m .53375 .75533 L .53381 .75534 L F
.53596 .68729 m .53483 .68661 L .53502 .75555 L .911 .629 .497 r
F
.53406 .75538 m .53547 .75538 L .53443 .75505 L .657 .813 .958 r
F
.53513 .75557 m .53547 .75538 L .53406 .75538 L F
.5335 .68624 m .53247 .75532 L .53253 .75532 L .734 .477 .539 r
F
.53233 .68609 m .53125 .75549 L .53247 .75532 L .66 .416 .54 r
F
.53185 .75541 m .53321 .75489 L .53188 .75489 L .657 .813 .958 r
F
.53299 .75525 m .53321 .75489 L .53185 .75541 L F
.53079 .75555 m .53188 .75489 L .53054 .75507 L F
.53185 .75541 m .53188 .75489 L .53079 .75555 L F
.52994 .75587 m .5299 .75877 L .53118 .7555 L .567 .342 .533 r
F
.5299 .75877 m .52988 .75943 L .53012 .75871 L F
.5299 .75877 m .53012 .75871 L .53118 .7555 L F
.52994 .75587 m .52988 .75943 L .52994 .75587 L F
.53007 .75872 m .53085 .75799 L .52958 .75833 L .657 .813 .959 r
F
.53107 .75842 m .53085 .75799 L .53007 .75872 L F
.52989 .75877 m .52988 .75943 L .5299 .75877 L .567 .342 .533 r
F
.53007 .75872 m .53003 .75869 L .52988 .75878 L .657 .813 .959 r
F
.53119 .75839 m .52988 .75943 L .53119 .75912 L .567 .342 .533 r
F
.53012 .75871 m .52988 .75943 L .53119 .75839 L F
.52988 .75878 m .52856 .76014 L .52988 .75943 L .4 .211 .506 r
F
.52878 .75941 m .52856 .76014 L .52988 .75878 L F
.52862 .75662 m .52856 .76014 L .52988 .75589 L F
.52927 .75913 m .52958 .75833 L .52849 .7588 L .657 .813 .959 r
F
.5289 .75618 m .52929 .75541 L .5282 .75588 L .657 .813 .958 r
F
.52988 .75589 m .52929 .75541 L .5289 .75618 L F
.52927 .75913 m .52849 .7588 L .52852 .75957 L .657 .813 .959 r
F
.52861 .75662 m .52857 .75954 L .52861 .75662 L .4 .211 .506 r
F
.52857 .75954 m .52856 .76014 L .52857 .75954 L F
.52857 .75954 m .52857 .75954 L .52861 .75662 L F
.52849 .75669 m .5289 .75618 L .52773 .75653 L .657 .813 .958 r
F
.52918 .7563 m .5289 .75618 L .52849 .75669 L F
.5289 .75618 m .5282 .75588 L .52773 .75653 L F
.52861 .75662 m .52856 .76014 L .52862 .75662 L .4 .211 .506 r
F
.52819 .76008 m .52764 .75937 L .52709 .76002 L .657 .813 .959 r
F
.52854 .75957 m .52764 .75937 L .52819 .76008 L F
.52819 .76008 m .52709 .76002 L .52783 .76061 L F
.52793 .76045 m .52793 .76046 L .52793 .76106 L 0 0 .377 r
F
.52799 .76112 m .52687 .76068 L .52701 .76131 L .657 .813 .959 r
F
.52787 .75766 m .52753 .75768 L .5277 .7579 L .657 .813 .958 r
F
.52787 .75766 m .5277 .7579 L .5279 .75815 L F
.5282 .75717 m .52771 .75714 L .52787 .75766 L F
.52771 .75714 m .52706 .7571 L .52729 .75739 L F
.52771 .75714 m .52729 .75739 L .52753 .75768 L F
.52763 .6873 m .5278 .68667 L .52596 .68698 L .597 .767 .961 r
F
.5285 .6869 m .5278 .68667 L .52763 .6873 L F
.5278 .68667 m .51984 .68396 L .52596 .68698 L F
.52706 .7571 m .52681 .75709 L .52753 .75768 L .657 .813 .958 r
F
.52753 .75768 m .52659 .75775 L .5279 .75815 L F
.52875 .76209 m .52804 .7617 L .52829 .76234 L .657 .813 .959 r
F
.52843 .76169 m .52843 .76169 L .52843 .76243 L .988 .719 .384 r
F
.52895 .76199 m .52857 .76186 L .52875 .76209 L .657 .813 .959 r
F
.52857 .76186 m .52804 .7617 L .52875 .76209 L F
.53233 .68609 m .53233 .68609 L .53235 .68588 L .597 .767 .961 r
F
.53233 .68609 m .53347 .68621 L .53301 .68608 L F
.53233 .68609 m .53301 .68608 L .53235 .68588 L F
.53345 .68623 m .53347 .68621 L .53233 .68609 L F
.53295 .75532 m .53375 .75533 L .53302 .7552 L .657 .813 .958 r
F
.53302 .7552 m .53443 .75505 L .53321 .75489 L F
.53406 .75538 m .53443 .75505 L .53302 .7552 L F
.53235 .68588 m .53639 .68171 L .53263 .68125 L .597 .767 .961 r
F
.53347 .68621 m .53639 .68171 L .53235 .68588 L F
.53448 .68651 m .54279 .68389 L .53985 .68261 L F
.53553 .68682 m .54279 .68389 L .53448 .68651 L F
.53652 .68816 m .53626 .75615 L .53628 .75619 L .983 .725 .332 r
F
.53628 .75619 m .53629 .75619 L .53655 .68822 L F
.53652 .68816 m .53628 .75619 L .53652 .68817 L F
.53628 .75619 m .53628 .75619 L .53652 .68817 L F
.53655 .68822 m .53629 .75619 L .53678 .75699 L F
.53589 .75597 m .53668 .75635 L .53626 .75584 L .657 .813 .958 r
F
.53628 .75619 m .53626 .75615 L .53627 .75903 L .983 .725 .332 r
F
.53627 .75905 m .53627 .75903 L .53627 .76024 L F
.53628 .75619 m .53627 .75903 L .53627 .75905 L F
.53686 .75999 m .53708 .76034 L .53721 .75997 L .657 .813 .959 r
F
.53698 .76063 m .53699 .76063 L .53699 .76062 L F
.53698 .76063 m .53699 .76062 L .53721 .75997 L F
.53204 .76032 m .53613 .76118 L .53661 .76061 L F
.53204 .76032 m .5353 .76172 L .5361 .7612 L F
.53204 .76032 m .53426 .76212 L .5353 .76172 L F
.53426 .76212 m .53449 .76231 L .5353 .76172 L F
.53613 .76118 m .53665 .76192 L .53613 .76254 L .08 0 .418 r
F
.53648 .76076 m .53665 .76192 L .53613 .76118 L F
.53529 .76173 m .53613 .76254 L .5353 .76305 L .358 .18 .498 r
F
.53586 .76136 m .53613 .76254 L .53529 .76173 L F
.53531 .68691 m .545 .68546 L .54279 .68389 L .597 .767 .961 r
F
.53605 .68735 m .545 .68546 L .53531 .68691 L F
.53756 .75825 m .54029 .75809 L .53726 .75777 L .657 .813 .958 r
F
.54029 .75809 m .54157 .75801 L .53991 .75791 L F
.53809 .75911 m .54046 .75928 L .53785 .75872 L F
.53809 .75911 m .53886 .76036 L .54046 .75928 L F
.5292 .76213 m .52921 .76296 L .52904 .76203 L .929 .648 .487 r
F
.53204 .76032 m .52829 .76161 L .52895 .76199 L .657 .813 .959 r
F
.52829 .76161 m .52804 .7617 L .52895 .76199 L F
.52804 .7617 m .5275 .76188 L .52808 .76222 L F
.52804 .7617 m .52808 .76222 L .52829 .76234 L F
.52799 .76114 m .52799 .76114 L .52799 .7618 L .781 .623 .061 r
F
.52843 .76169 m .52921 .76296 L .52843 .76243 L .929 .648 .487 r
F
.52875 .76209 m .52918 .76262 L .52933 .76267 L .657 .813 .959 r
F
.52904 .76203 m .52921 .76296 L .52843 .76169 L .929 .648 .487 r
F
.52843 .76169 m .52843 .76243 L .52843 .76169 L .988 .719 .384 r
F
.52748 .75823 m .52673 .75838 L .52709 .7588 L .657 .813 .958 r
F
.52748 .75823 m .52709 .7588 L .52721 .75895 L F
.52808 .75936 m .52721 .75895 L .528 .75941 L F
.52799 .76114 m .52843 .76243 L .52799 .7618 L .988 .719 .384 r
F
.52843 .76169 m .52843 .76243 L .52799 .76114 L F
.52799 .76098 m .52799 .7618 L .52793 .76106 L .781 .623 .061 r
F
.53669 .689 m .53757 .68998 L .53705 .68907 L .597 .767 .961 r
F
.53757 .68998 m .54451 .69233 L .53705 .68907 L F
.53854 .69164 m .54211 .69361 L .53757 .68998 L F
.51304 .58372 m .495 .57955 L .49061 .5849 L .659 .806 .953 r
F
.51649 .58133 m .495 .57955 L .51304 .58372 L F
.79972 .82987 m .79911 .83214 L .80296 .83164 L .653 .817 .962 r
F
.79723 .8299 m .79911 .83214 L .79972 .82987 L F
.79723 .8299 m .79537 .83218 L .79911 .83214 L F
.69351 .43788 m .66608 .44657 L .6938 .44194 L .656 .78 .94 r
F
.69351 .43788 m .66535 .43847 L .66608 .44657 L F
.41189 .41979 m .41953 .43503 L .43988 .42987 L .658 .778 .938 r
F
.39719 .42119 m .41953 .43503 L .41189 .41979 L F
.31401 .83115 m .31639 .82954 L .31653 .83239 L .913 .637 .505 r
F
.31401 .83115 m .31388 .8283 L .31639 .82954 L F
.31806 .82686 m .31639 .82954 L .31974 .82769 L .658 .812 .957 r
F
.31806 .82686 m .31388 .8283 L .31639 .82954 L F
0 g
.31639 .82954 m
.31959 .83041 L
s
.8023 .82954 m .80296 .83164 L .80668 .83071 L .653 .817 .962 r
F
.79972 .82987 m .80296 .83164 L .8023 .82954 L F
0 g
.79911 .83214 m
.80296 .83164 L
s
.23215 .45806 m .21585 .44472 L .20477 .45 L .657 .779 .939 r
F
.23879 .45635 m .21585 .44472 L .23215 .45806 L F
.21224 .58035 m .21258 .593 L .22172 .5832 L .661 .804 .952 r
F
.21224 .58035 m .1984 .58879 L .21258 .593 L F
0 g
.21258 .593 m
.22852 .59521 L
s
.53454 .46905 m .51214 .46444 L .51247 .47111 L .669 .441 .566 r
F
0 g
.49183 .47618 m
.51247 .47111 L
s
.53454 .46905 m .53417 .46238 L .51214 .46444 L .669 .441 .566 r
F
0 g
.49154 .46953 m
.51214 .46444 L
s
.2953 .45462 m .30469 .43664 L .28558 .4483 L .657 .779 .939 r
F
.2953 .45462 m .31921 .44624 L .30469 .43664 L F
.33758 .83092 m .33967 .8265 L .33982 .82934 L .36 .208 .535 r
F
.33392 .82956 m .33758 .83092 L .33982 .82934 L .658 .812 .957 r
F
.33193 .83043 m .33758 .83092 L .33392 .82956 L F
0 g
.33459 .83221 m
.33758 .83092 L
s
.28884 .57778 m .29802 .56503 L .29826 .57054 L .339 .195 .533 r
F
.28906 .58329 m .28884 .57778 L .29826 .57054 L F
.27282 .57115 m .28884 .57778 L .29826 .57054 L .661 .803 .951 r
F
.2644 .57508 m .28884 .57778 L .27282 .57115 L F
0 g
.27928 .58222 m
.28884 .57778 L
s
.78926 .83089 m .79152 .8289 L .79202 .83175 L .865 .576 .497 r
F
.78926 .83089 m .78877 .82804 L .79152 .8289 L F
.79266 .82618 m .79152 .8289 L .79449 .82676 L .653 .817 .962 r
F
.79266 .82618 m .78877 .82804 L .79152 .8289 L F
0 g
.79152 .8289 m
.79488 .82933 L
s
.75899 .32468 m .75559 .29767 L .74269 .31929 L .644 .736 .916 r
F
.75899 .32468 m .78027 .30594 L .75559 .29767 L F
0 g
.24944 .5 m
.25152 .47654 L
s
.49142 .59594 m .47095 .59448 L .46864 .60275 L .658 .807 .955 r
F
0 g
.46864 .60275 m
.47066 .61066 L
s
.24207 .49988 m
.24418 .47669 L
s
.79499 .82961 m .79537 .83218 L .79723 .8299 L .653 .817 .962 r
F
.79499 .82961 m .79202 .83175 L .79537 .83218 L F
0 g
.79537 .83218 m
.79911 .83214 L
s
.5501 .58697 m .56251 .57655 L .54691 .58499 L .658 .806 .954 r
F
.5501 .58697 m .56886 .58055 L .56251 .57655 L F
.22645 .46731 m .20455 .45668 L .19652 .46337 L .656 .78 .94 r
F
.23198 .46471 m .20455 .45668 L .22645 .46731 L F
.2052 .44345 m .17129 .4428 L .19724 .45014 L .657 .779 .938 r
F
.78681 .82679 m .78828 .82519 L .78877 .82804 L .942 .629 .414 r
F
.78681 .82679 m .78631 .82394 L .78828 .82519 L F
0 g
.78828 .82519 m
.79103 .82606 L
s
.36436 .3177 m .33202 .32766 L .36585 .32362 L .643 .738 .918 r
F
.36436 .3177 m .32881 .31584 L .33202 .32766 L F
.7909 .82248 m .78834 .82516 L .7922 .82331 L .654 .816 .961 r
F
.7909 .82248 m .78638 .82392 L .78834 .82516 L F
.58888 .29852 m .59474 .32552 L .60578 .30404 L .644 .737 .917 r
F
.58888 .29852 m .56963 .31742 L .59474 .32552 L F
0 g
.59474 .32552 m
.62196 .32925 L
s
.33967 .8265 m .34086 .8219 L .34101 .82474 L .09 .01 .462 r
F
.33982 .82934 m .33967 .8265 L .34101 .82474 L F
.33527 .82566 m .33967 .8265 L .34101 .82474 L .658 .812 .957 r
F
.33378 .82671 m .33967 .8265 L .33527 .82566 L F
0 g
.33743 .82807 m
.33967 .8265 L
s
.32213 .82256 m .31797 .824 L .31964 .82483 L .659 .811 .957 r
F
.80951 .82656 m .81173 .82214 L .81224 .82498 L .44 .29 .58 r
F
.81002 .82941 m .80951 .82656 L .81224 .82498 L F
.80668 .83071 m .80951 .82656 L .81002 .82941 L .537 .355 .582 r
F
.8065 .8252 m .80951 .82656 L .81224 .82498 L .653 .817 .962 r
F
.80428 .82607 m .80951 .82656 L .8065 .8252 L F
0 g
.80618 .82786 m
.80951 .82656 L
s
.31221 .82676 m .31375 .82545 L .31388 .8283 L .976 .696 .429 r
F
.31221 .82676 m .31208 .82391 L .31375 .82545 L F
0 g
.31375 .82545 m
.31626 .8267 L
s
.80478 .82892 m .80668 .83071 L .81002 .82941 L .653 .817 .962 r
F
.8023 .82954 m .80668 .83071 L .80478 .82892 L F
0 g
.80296 .83164 m
.80668 .83071 L
s
.31687 .82297 m .31381 .82543 L .31797 .824 L .659 .811 .957 r
F
.31687 .82297 m .31215 .82389 L .31381 .82543 L F
.19675 .45671 m .17061 .44936 L .16416 .4609 L .657 .779 .939 r
F
.17034 .45605 m .16416 .4609 L .16387 .46756 L 0 0 .333 r
F
.17034 .45605 m .17061 .44936 L .16416 .4609 L F
0 g
.16354 .47297 m
.16416 .4609 L
s
.4685 .3348 m .5066 .32514 L .47104 .32328 L .643 .738 .918 r
F
.43432 .3272 m .4685 .3348 L .47104 .32328 L F
.43084 .33244 m .4685 .3348 L .43432 .3272 L F
.32309 .82584 m .31974 .82769 L .32187 .82827 L .658 .812 .957 r
F
.54625 .57952 m .55326 .56824 L .54201 .5781 L .659 .806 .953 r
F
.54625 .57952 m .56174 .5711 L .55326 .56824 L F
.25351 .45604 m .24396 .43984 L .24608 .45566 L .657 .779 .939 r
F
.25351 .45604 m .25898 .44062 L .24396 .43984 L F
.33508 .8228 m .34079 .82189 L .33597 .82164 L .659 .811 .957 r
F
.32681 .82911 m .32703 .83138 L .32958 .83105 L .658 .812 .957 r
F
.32551 .82912 m .32703 .83138 L .32681 .82911 L F
.32551 .82912 m .32444 .83141 L .32703 .83138 L F
.81224 .82498 m .81173 .82214 L .81366 .82038 L .29 .189 .564 r
F
0 g
.80901 .82372 m
.81173 .82214 L
s
.80777 .82129 m .81167 .82213 L .81359 .82038 L .654 .816 .961 r
F
.80597 .82234 m .81167 .82213 L .80777 .82129 L F
.32809 .82894 m .32958 .83105 L .33193 .83043 L .658 .812 .957 r
F
.32681 .82911 m .32958 .83105 L .32809 .82894 L F
.5564 .47016 m .53417 .46238 L .53454 .46905 L .734 .491 .561 r
F
0 g
.51214 .46444 m
.53417 .46238 L
s
.53417 .46238 m
.55599 .4635 L
s
.5564 .47016 m
.57643 .47435 L
s
.35488 .43847 m .37564 .43617 L .37573 .44279 L .796 .543 .555 r
F
.35488 .43847 m .35483 .43183 L .37564 .43617 L F
0 g
.37564 .43617 m
.39771 .43733 L
s
.495 .57955 m .4703 .58342 L .49061 .5849 L .659 .806 .953 r
F
0 g
.24578 .54133 m
.24944 .5 L
s
.31819 .82971 m .31653 .83239 L .31987 .83054 L .658 .812 .957 r
F
.31819 .82971 m .31401 .83115 L .31653 .83239 L F
0 g
.31653 .83239 m
.31972 .83326 L
s
.23833 .54104 m
.24207 .49988 L
s
.79607 .82146 m .7922 .82331 L .79402 .82389 L .654 .816 .961 r
F
.34101 .82474 m .34086 .8219 L .34122 .82009 L 0 0 .224 r
F
0 g
.33952 .82365 m
.34086 .8219 L
s
.33597 .82164 m .34079 .82189 L .34114 .82009 L .659 .811 .957 r
F
.32429 .82898 m .32444 .83141 L .32551 .82912 L .658 .812 .957 r
F
.32429 .82898 m .322 .83112 L .32444 .83141 L F
.36849 .41745 m .37574 .43594 L .3824 .4204 L .658 .778 .938 r
F
.36849 .41745 m .35503 .43162 L .37574 .43594 L F
.27553 .33564 m .24898 .32364 L .24779 .33191 L .732 .48 .547 r
F
0 g
.24898 .32364 m
.27665 .32738 L
s
.27553 .33564 m
.3017 .34365 L
s
.22185 .32451 m
.24898 .32364 L
s
.79315 .82903 m .79202 .83175 L .79499 .82961 L .653 .817 .962 r
F
.79315 .82903 m .78926 .83089 L .79202 .83175 L F
0 g
.79202 .83175 m
.79537 .83218 L
s
.23879 .45635 m .22923 .44124 L .21585 .44472 L .657 .779 .939 r
F
.24608 .45566 m .22923 .44124 L .23879 .45635 L F
.51402 .59474 m .49142 .59594 L .51178 .5974 L .658 .807 .955 r
F
0 g
.53454 .46905 m
.5564 .47016 L
s
.32926 .82863 m .33193 .83043 L .33392 .82956 L .658 .812 .957 r
F
.32809 .82894 m .33193 .83043 L .32926 .82863 L F
.39796 .45058 m .39783 .44394 L .41981 .44187 L .669 .439 .564 r
F
.37582 .44943 m .39783 .44394 L .39796 .45058 L .734 .492 .562 r
F
.37582 .44943 m .37573 .44279 L .39783 .44394 L F
.39732 .428 m .39783 .44394 L .41981 .44187 L .657 .779 .939 r
F
.38244 .42721 m .39783 .44394 L .39732 .428 L F
.38244 .42721 m .37573 .44279 L .39783 .44394 L F
.7873 .82964 m .78877 .82804 L .78926 .83089 L .942 .629 .414 r
F
.7873 .82964 m .78681 .82679 L .78877 .82804 L F
.79135 .82535 m .78877 .82804 L .79266 .82618 L .653 .817 .962 r
F
.79135 .82535 m .78681 .82679 L .78877 .82804 L F
0 g
.78877 .82804 m
.79152 .8289 L
s
.57323 .59092 m .5884 .57964 L .56948 .58609 L .658 .807 .955 r
F
.57323 .59092 m .59392 .58694 L .5884 .57964 L F
.24608 .45566 m .24396 .43984 L .22923 .44124 L .657 .779 .939 r
F
.33982 .82934 m .34101 .82474 L .34116 .82759 L .09 .01 .462 r
F
.33542 .82851 m .33982 .82934 L .34116 .82759 L .658 .812 .957 r
F
.33392 .82956 m .33982 .82934 L .33542 .82851 L F
0 g
.33758 .83092 m
.33982 .82934 L
s
.59327 .58142 m .58711 .56857 L .58775 .5741 L .977 .681 .308 r
F
.59392 .58694 m .59327 .58142 L .58775 .5741 L F
0 g
.59327 .58142 m
.59453 .58947 L
s
.32225 .82542 m .31974 .82769 L .32309 .82584 L .658 .812 .957 r
F
.32225 .82542 m .31806 .82686 L .31974 .82769 L F
.79747 .82461 m .79449 .82676 L .79673 .82705 L .653 .817 .962 r
F
.81002 .82941 m .81224 .82498 L .81275 .82783 L .44 .29 .58 r
F
.80701 .82805 m .81002 .82941 L .81275 .82783 L .653 .817 .962 r
F
.80478 .82892 m .81002 .82941 L .80701 .82805 L F
0 g
.80668 .83071 m
.81002 .82941 L
s
.32159 .82205 m .31797 .824 L .32213 .82256 L .659 .811 .957 r
F
.32159 .82205 m .31687 .82297 L .31797 .824 L F
.31234 .82961 m .31388 .8283 L .31401 .83115 L .976 .696 .429 r
F
.31234 .82961 m .31221 .82676 L .31388 .8283 L F
.31695 .82583 m .31388 .8283 L .31806 .82686 L .658 .812 .957 r
F
.31695 .82583 m .31221 .82676 L .31388 .8283 L F
0 g
.31388 .8283 m
.31639 .82954 L
s
.43503 .31895 m .47166 .31501 L .43619 .31316 L .643 .737 .917 r
F
.26044 .46411 m .25886 .44731 L .25338 .46269 L .656 .78 .94 r
F
.26044 .46411 m .27309 .4502 L .25886 .44731 L F
.77599 .45757 m .80797 .44879 L .7797 .44939 L .655 .782 .942 r
F
.74961 .4541 m .77599 .45757 L .7797 .44939 L F
.74603 .45794 m .77599 .45757 L .74961 .4541 L F
.32323 .82869 m .322 .83112 L .32429 .82898 L .658 .812 .957 r
F
.32323 .82869 m .31987 .83054 L .322 .83112 L F
.51348 .58921 m .49533 .58505 L .49091 .59041 L .658 .806 .954 r
F
.51696 .58682 m .49533 .58505 L .51348 .58921 L F
.69403 .44453 m .66641 .45325 L .69432 .4486 L .655 .781 .941 r
F
.69403 .44453 m .66567 .44512 L .66641 .45325 L F
.66628 .4518 m .63918 .46453 L .66702 .4599 L .655 .782 .942 r
F
.66628 .4518 m .63784 .45241 L .63918 .46453 L F
0 g
.63918 .46453 m
.64613 .47553 L
s
.33527 .82566 m .34101 .82474 L .33616 .82449 L .658 .812 .957 r
F
.18682 .57726 m .1982 .57774 L .1983 .58326 L .912 .647 .524 r
F
.18682 .57726 m .18674 .57172 L .1982 .57774 L F
0 g
.1982 .57774 m
.20431 .57958 L
s
.81224 .82498 m .81366 .82038 L .81417 .82323 L .29 .189 .564 r
F
.81275 .82783 m .81224 .82498 L .81417 .82323 L F
.80832 .82414 m .81224 .82498 L .81417 .82323 L .653 .817 .962 r
F
.8065 .8252 m .81224 .82498 L .80832 .82414 L F
0 g
.80951 .82656 m
.81224 .82498 L
s
.53576 .59759 m
.53579 .60758 L
s
.33597 .82164 m .34114 .82009 L .3362 .82044 L .659 .811 .957 r
F
.33114 .82138 m .33597 .82164 L .3362 .82044 L F
.51649 .58133 m .5019 .57474 L .495 .57955 L .659 .806 .953 r
F
.52095 .57939 m .5019 .57474 L .51649 .58133 L F
.79542 .82105 m .7922 .82331 L .79607 .82146 L .654 .816 .961 r
F
.79542 .82105 m .7909 .82248 L .7922 .82331 L F
.33026 .8282 m .33392 .82956 L .33542 .82851 L .658 .812 .957 r
F
.32926 .82863 m .33392 .82956 L .33026 .8282 L F
.78577 .82524 m .78631 .82394 L .78681 .82679 L .947 .635 .197 r
F
.78577 .82524 m .78528 .82239 L .78631 .82394 L F
0 g
.78631 .82394 m
.78828 .82519 L
s
.79021 .82145 m .78638 .82392 L .7909 .82248 L .654 .816 .961 r
F
.79021 .82145 m .78535 .82238 L .78638 .82392 L F
.28906 .58329 m .29826 .57054 L .2985 .57606 L .339 .195 .533 r
F
.27302 .57668 m .28906 .58329 L .2985 .57606 L .661 .804 .952 r
F
.26459 .58061 m .28906 .58329 L .27302 .57668 L F
0 g
.27645 .58912 m
.28906 .58329 L
s
.52842 .59802 m
.52843 .60746 L
s
.54818 .30539 m .57 .30919 L .56963 .31742 L .87 .6 .527 r
F
.54818 .30539 m .54861 .29715 L .57 .30919 L F
.57489 .28207 m .57 .30919 L .5892 .29025 L .644 .736 .916 r
F
.57489 .28207 m .54861 .29715 L .57 .30919 L F
0 g
.57 .30919 m
.57602 .31114 L
s
.79655 .82432 m .79449 .82676 L .79747 .82461 L .653 .817 .962 r
F
.79655 .82432 m .79266 .82618 L .79449 .82676 L F
.41981 .44187 m .4401 .43007 L .4403 .43669 L .592 .379 .561 r
F
.41998 .4485 m .41981 .44187 L .4403 .43669 L F
.39796 .45058 m .41981 .44187 L .41998 .4485 L .669 .439 .564 r
F
.41212 .4266 m .41981 .44187 L .4403 .43669 L .657 .779 .939 r
F
.39732 .428 m .41981 .44187 L .41212 .4266 L F
0 g
.39783 .44394 m
.41981 .44187 L
s
.34101 .82474 m .34122 .82009 L .34137 .82294 L 0 0 .224 r
F
.34116 .82759 m .34101 .82474 L .34137 .82294 L F
.33616 .82449 m .34101 .82474 L .34137 .82294 L .658 .812 .957 r
F
0 g
.33967 .8265 m
.34101 .82474 L
s
.55069 .59249 m .56312 .58209 L .54749 .59052 L .658 .807 .955 r
F
.55069 .59249 m .56948 .58609 L .56312 .58209 L F
.80777 .82129 m .81359 .82038 L .80905 .82012 L .654 .816 .961 r
F
.80034 .8276 m .79972 .82987 L .8023 .82954 L .653 .817 .962 r
F
.79909 .82761 m .79972 .82987 L .80034 .8276 L F
.79909 .82761 m .79723 .8299 L .79972 .82987 L F
.29643 .28804 m .29541 .29753 L .29434 .30573 L .716 .657 .103 r
F
.29643 .28804 m .29751 .2798 L .29541 .29753 L F
0 g
.29541 .29753 m
.29782 .30591 L
s
.33276 .28769 m .29594 .29756 L .33113 .2994 L .644 .737 .916 r
F
.33276 .28769 m .29804 .27992 L .29594 .29756 L F
.31151 .82502 m .31208 .82391 L .31221 .82676 L .935 .694 .216 r
F
.31151 .82502 m .31138 .82217 L .31208 .82391 L F
0 g
.31208 .82391 m
.31375 .82545 L
s
.31641 .82182 m .31215 .82389 L .31687 .82297 L .659 .811 .957 r
F
.31641 .82182 m .31146 .82216 L .31215 .82389 L F
.80163 .82743 m .8023 .82954 L .80478 .82892 L .653 .817 .962 r
F
.80034 .8276 m .8023 .82954 L .80163 .82743 L F
.36725 .29541 m .33113 .2994 L .36633 .30124 L .644 .737 .916 r
F
.36725 .29541 m .33276 .28769 L .33113 .2994 L F
.23198 .46471 m .21565 .45141 L .20455 .45668 L .656 .78 .94 r
F
.23863 .46301 m .21565 .45141 L .23198 .46471 L F
.79184 .8282 m .78926 .83089 L .79315 .82903 L .653 .817 .962 r
F
.79184 .8282 m .7873 .82964 L .78926 .83089 L F
0 g
.78926 .83089 m
.79202 .83175 L
s
.51247 .47111 m
.53454 .46905 L
s
.29524 .46127 m .30465 .44333 L .28551 .45497 L .656 .78 .94 r
F
.29524 .46127 m .3192 .4529 L .30465 .44333 L F
.81417 .82323 m .81366 .82038 L .81466 .81857 L .01 .003 .499 r
F
0 g
.81173 .82214 m
.81366 .82038 L
s
.32239 .82827 m .31987 .83054 L .32323 .82869 L .658 .812 .957 r
F
.32239 .82827 m .31819 .82971 L .31987 .83054 L F
.80905 .82012 m .81359 .82038 L .81458 .81857 L .654 .816 .961 r
F
.79797 .82747 m .79723 .8299 L .79909 .82761 L .653 .817 .962 r
F
.79797 .82747 m .79499 .82961 L .79723 .8299 L F
.43672 .30493 m .46965 .29485 L .43547 .29898 L .644 .737 .916 r
F
.43672 .30493 m .47193 .30677 L .46965 .29485 L F
.3217 .8249 m .31806 .82686 L .32225 .82542 L .658 .812 .957 r
F
.3217 .8249 m .31695 .82583 L .31806 .82686 L F
.54201 .5781 m .54319 .56671 L .537 .57736 L .659 .806 .953 r
F
.54201 .5781 m .55326 .56824 L .54319 .56671 L F
.31709 .82869 m .31401 .83115 L .31819 .82971 L .658 .812 .957 r
F
.31709 .82869 m .31234 .82961 L .31401 .83115 L F
0 g
.31401 .83115 m
.31653 .83239 L
s
.47193 .30677 m .50405 .29069 L .46965 .29485 L .644 .737 .916 r
F
.47193 .30677 m .50714 .30861 L .50405 .29069 L F
.54691 .58499 m .55397 .57368 L .54265 .58357 L .658 .806 .954 r
F
.54691 .58499 m .56251 .57655 L .55397 .57368 L F
.50714 .31687 m .50767 .30864 L .50457 .29063 L .915 .736 .243 r
F
0 g
.50572 .31679 m
.50672 .3126 L
s
.80287 .82712 m .80478 .82892 L .80701 .82805 L .653 .817 .962 r
F
.80163 .82743 m .80478 .82892 L .80287 .82712 L F
0 g
.53579 .60758 m
.53599 .67203 L
s
.32136 .82147 m .31687 .82297 L .32159 .82205 L .659 .811 .957 r
F
.32136 .82147 m .31641 .82182 L .31687 .82297 L F
.33114 .82138 m .3362 .82044 L .33125 .82078 L F
0 g
.22059 .33276 m
.24779 .33191 L
s
.52843 .60746 m
.52848 .67183 L
s
.20477 .45 m .17061 .44936 L .19675 .45671 L .657 .779 .939 r
F
.33542 .82851 m .34116 .82759 L .33631 .82734 L .658 .812 .957 r
F
.33101 .82767 m .33542 .82851 L .33631 .82734 L F
.33026 .8282 m .33542 .82851 L .33101 .82767 L F
0 g
.32687 .82706 m
.32864 .82689 L
s
.32687 .82706 m
.32687 .82706 L
s
.32507 .82684 m
.32687 .82706 L
s
.24779 .33191 m
.27553 .33564 L
s
.49533 .58505 m .47047 .58893 L .49091 .59041 L .658 .806 .954 r
F
.3362 .82044 m .34114 .82009 L .34049 .81836 L .659 .811 .957 r
F
.34137 .82294 m .34122 .82009 L .34056 .81834 L .923 .683 .192 r
F
0 g
.34086 .8219 m
.34103 .82103 L
s
.81275 .82783 m .81417 .82323 L .81468 .82608 L .29 .189 .564 r
F
.80883 .827 m .81275 .82783 L .81468 .82608 L .653 .817 .962 r
F
.80701 .82805 m .81275 .82783 L .80883 .827 L F
0 g
.81002 .82941 m
.81275 .82783 L
s
.56806 .5751 m .5774 .56261 L .56174 .5711 L .659 .806 .953 r
F
.56806 .5751 m .58682 .56867 L .5774 .56261 L F
.33616 .82449 m .34137 .82294 L .3364 .82328 L .658 .812 .957 r
F
.33131 .82423 m .33616 .82449 L .3364 .82328 L F
.7959 .8239 m .79266 .82618 L .79655 .82432 L .653 .817 .962 r
F
.7959 .8239 m .79135 .82535 L .79266 .82618 L F
.79508 .82053 m .7909 .82248 L .79542 .82105 L .654 .816 .961 r
F
.79508 .82053 m .79021 .82145 L .7909 .82248 L F
.78626 .8281 m .78681 .82679 L .7873 .82964 L .947 .635 .197 r
F
.78626 .8281 m .78577 .82524 L .78681 .82679 L F
.79066 .82432 m .78681 .82679 L .79135 .82535 L .653 .817 .962 r
F
.79066 .82432 m .78577 .82524 L .78681 .82679 L F
0 g
.78681 .82679 m
.78877 .82804 L
s
.19652 .46337 m .17034 .45605 L .16387 .46756 L .656 .78 .94 r
F
0 g
.16325 .4796 m
.16387 .46756 L
s
.79705 .82718 m .79499 .82961 L .79797 .82747 L .653 .817 .962 r
F
.79705 .82718 m .79315 .82903 L .79499 .82961 L F
.3362 .82044 m .34049 .81836 L .33576 .81928 L .659 .811 .957 r
F
.33125 .82078 m .3362 .82044 L .33576 .81928 L F
.34116 .82759 m .34137 .82294 L .34152 .82579 L 0 0 .224 r
F
.33631 .82734 m .34116 .82759 L .34152 .82579 L .658 .812 .957 r
F
0 g
.33982 .82934 m
.34116 .82759 L
s
.25338 .46269 m .24382 .44654 L .24593 .46232 L .656 .78 .94 r
F
.25338 .46269 m .25886 .44731 L .24382 .44654 L F
.32659 .82683 m .32681 .82911 L .32809 .82894 L .658 .812 .957 r
F
.32659 .82683 m .32551 .82912 L .32681 .82911 L F
.80711 .44214 m .80625 .43551 L .80629 .42314 L 0 0 .202 r
F
0 g
.80311 .44222 m
.80625 .43551 L
s
.7778 .43611 m .80583 .43552 L .80587 .42321 L .656 .78 .94 r
F
.32659 .82683 m .32809 .82894 L .32926 .82863 L .658 .812 .957 r
F
0 g
.32864 .82689 m
.32974 .82653 L
s
.80832 .82414 m .81417 .82323 L .8096 .82297 L .653 .817 .962 r
F
.31164 .82788 m .31221 .82676 L .31234 .82961 L .935 .694 .216 r
F
.31164 .82788 m .31151 .82502 L .31221 .82676 L F
.31649 .82467 m .31221 .82676 L .31695 .82583 L .658 .812 .957 r
F
.31649 .82467 m .31151 .82502 L .31221 .82676 L F
0 g
.31221 .82676 m
.31388 .8283 L
s
.35493 .44512 m .37573 .44279 L .37582 .44943 L .796 .543 .555 r
F
.35493 .44512 m .35488 .43847 L .37573 .44279 L F
.36843 .42426 m .37573 .44279 L .38244 .42721 L .657 .779 .939 r
F
.36843 .42426 m .35488 .43847 L .37573 .44279 L F
0 g
.37573 .44279 m
.39783 .44394 L
s
.33125 .82078 m .33576 .81928 L .33103 .8202 L .659 .811 .957 r
F
.4403 .43669 m .4401 .43007 L .45778 .42207 L .493 .303 .551 r
F
0 g
.4294 .43278 m
.4401 .43007 L
s
.80905 .82012 m .81458 .81857 L .80971 .81892 L .654 .816 .961 r
F
.32659 .82683 m .32429 .82898 L .32551 .82912 L .658 .812 .957 r
F
0 g
.32391 .82645 m
.32507 .82684 L
s
.59392 .58694 m .58775 .5741 L .5884 .57964 L .977 .681 .308 r
F
0 g
.59392 .58694 m
.59517 .59496 L
s
.80399 .82669 m .80701 .82805 L .80883 .827 L .653 .817 .962 r
F
.80287 .82712 m .80701 .82805 L .80399 .82669 L F
0 g
.32974 .82653 m
.33047 .82606 L
s
.52095 .57939 m .51084 .57081 L .5019 .57474 L .659 .806 .953 r
F
.52609 .57802 m .51084 .57081 L .52095 .57939 L F
.80033 .31797 m .80012 .30974 L .7801 .29768 L .881 .598 .504 r
F
0 g
.80012 .30974 m
.81414 .32462 L
s
.32659 .82683 m .32926 .82863 L .33026 .8282 L .658 .812 .957 r
F
.68827 .32923 m .673 .30862 L .64954 .31835 L .643 .737 .917 r
F
0 g
.63235 .33062 m
.64954 .31835 L
s
.706 .32563 m .673 .30862 L .68827 .32923 L .643 .737 .917 r
F
.62501 .16712 m .62916 .2313 L .62731 .23154 L .629 .374 .513 r
F
.62501 .16712 m .62682 .16687 L .62916 .2313 L F
.62326 .1668 m .62501 .16712 L .62731 .23154 L .755 .473 .507 r
F
0 g
.62501 .16712 m
.62501 .16712 L
s
.32309 .82596 m
.32391 .82645 L
s
.74269 .31929 m .75559 .29767 L .72811 .29384 L .644 .736 .916 r
F
.42557 .41629 m .43988 .42987 L .45747 .4219 L .658 .778 .938 r
F
.41189 .41979 m .43988 .42987 L .42557 .41629 L F
.81417 .82323 m .81466 .81857 L .81517 .82142 L .01 .003 .499 r
F
.81468 .82608 m .81417 .82323 L .81517 .82142 L F
.8096 .82297 m .81417 .82323 L .81517 .82142 L .653 .817 .962 r
F
0 g
.81224 .82498 m
.81417 .82323 L
s
.75911 .33294 m .75569 .30598 L .74276 .32755 L .643 .737 .917 r
F
.75911 .33294 m .78044 .31424 L .75569 .30598 L F
.32183 .82776 m .31819 .82971 L .32239 .82827 L .658 .812 .957 r
F
.32183 .82776 m .31709 .82869 L .31819 .82971 L F
.23863 .46301 m .22906 .44794 L .21565 .45141 L .656 .78 .94 r
F
.24593 .46232 m .22906 .44794 L .23863 .46301 L F
.62682 .16687 m .63036 .23077 L .62916 .2313 L .492 .27 .504 r
F
.62682 .16687 m .628 .16634 L .63036 .23077 L F
0 g
.62501 .16712 m
.62682 .16687 L
s
.32659 .82683 m .32323 .82869 L .32429 .82898 L .658 .812 .957 r
F
.62326 .1668 m .62731 .23154 L .62552 .23123 L .755 .473 .507 r
F
.62217 .16623 m .62326 .1668 L .62552 .23123 L .862 .563 .481 r
F
0 g
.62326 .1668 m
.62501 .16712 L
s
.28546 .44178 m .28592 .42285 L .27315 .437 L .657 .779 .938 r
F
.28546 .44178 m .30444 .43015 L .28592 .42285 L F
.51402 .59474 m .49585 .5906 L .49142 .59594 L .658 .807 .955 r
F
.5175 .59235 m .49585 .5906 L .51402 .59474 L F
.39745 .43468 m .39796 .45058 L .41998 .4485 L .656 .78 .939 r
F
.38254 .43389 m .39796 .45058 L .39745 .43468 L F
.38254 .43389 m .37582 .44943 L .39796 .45058 L F
.78573 .8235 m .78528 .82239 L .78577 .82524 L 0 0 .229 r
F
.79019 .8203 m .78535 .82238 L .79021 .82145 L .654 .816 .961 r
F
.79019 .8203 m .78531 .82064 L .78535 .82238 L F
.78573 .8235 m .78523 .82065 L .78528 .82239 L 0 0 .229 r
F
0 g
.78562 .82291 m
.78631 .82394 L
s
.32147 .82433 m .31695 .82583 L .3217 .8249 L .658 .812 .957 r
F
.32147 .82433 m .31649 .82467 L .31695 .82583 L F
.33131 .82423 m .3364 .82328 L .33142 .82363 L F
.32147 .82087 m .31641 .82182 L .32136 .82147 L .659 .811 .957 r
F
.18691 .58281 m .1983 .58326 L .1984 .58879 L .912 .647 .524 r
F
.18691 .58281 m .18682 .57726 L .1983 .58326 L F
.20449 .57076 m .1983 .58326 L .21212 .5748 L .661 .803 .951 r
F
.20449 .57076 m .18682 .57726 L .1983 .58326 L F
0 g
.1983 .58326 m
.20445 .5851 L
s
.32659 .82683 m .33026 .8282 L .33101 .82767 L .658 .812 .957 r
F
.537 .57736 m .53224 .56664 L .53157 .57733 L .659 .806 .953 r
F
.537 .57736 m .54319 .56671 L .53224 .56664 L F
0 g
.33047 .82606 m
.33089 .8255 L
s
.51696 .58682 m .50228 .58022 L .49533 .58505 L .658 .806 .954 r
F
.52144 .58487 m .50228 .58022 L .51696 .58682 L F
.24593 .46232 m .24382 .44654 L .22906 .44794 L .656 .78 .94 r
F
0 g
.32258 .82539 m
.32309 .82596 L
s
.34137 .82294 m .34056 .81834 L .34071 .82119 L .923 .683 .192 r
F
.3364 .82328 m .34137 .82294 L .34071 .82119 L .658 .812 .957 r
F
.34152 .82579 m .34137 .82294 L .34071 .82119 L .923 .683 .192 r
F
0 g
.34101 .82474 m
.34118 .82388 L
s
.628 .16634 m .63121 .23009 L .63036 .23077 L .328 .148 .478 r
F
.628 .16634 m .62883 .16565 L .63121 .23009 L F
0 g
.62682 .16687 m
.628 .16634 L
s
.33103 .8202 m .33467 .81825 L .33048 .81969 L .659 .811 .957 r
F
0 g
.33039 .8224 m
.33053 .81996 L
s
.33103 .8202 m .33576 .81928 L .33467 .81825 L .659 .811 .957 r
F
0 g
.33054 .81967 m
.33434 .75281 L
s
.33631 .82734 m .34152 .82579 L .33654 .82614 L .658 .812 .957 r
F
.33145 .82709 m .33631 .82734 L .33654 .82614 L F
.33101 .82767 m .33631 .82734 L .33145 .82709 L F
.7964 .82676 m .79315 .82903 L .79705 .82718 L .653 .817 .962 r
F
.7964 .82676 m .79184 .8282 L .79315 .82903 L F
.31662 .82061 m .31146 .82216 L .31641 .82182 L .659 .811 .957 r
F
.32147 .82087 m .31662 .82061 L .31641 .82182 L F
.79556 .82339 m .79135 .82535 L .7959 .8239 L .653 .817 .962 r
F
.79556 .82339 m .79066 .82432 L .79135 .82535 L F
.79116 .82717 m .7873 .82964 L .79184 .8282 L F
.79116 .82717 m .78626 .8281 L .7873 .82964 L F
0 g
.7873 .82964 m
.78926 .83089 L
s
.31921 .44624 m .31922 .4396 L .30473 .42997 L .923 .656 .514 r
F
0 g
.31922 .4396 m
.32864 .45081 L
s
.62217 .16623 m .62552 .23123 L .62441 .23066 L .862 .563 .481 r
F
.62146 .16551 m .62217 .16623 L .62441 .23066 L .948 .643 .425 r
F
0 g
.62217 .16623 m
.62326 .1668 L
s
.7778 .43611 m .80587 .42321 L .77767 .42792 L .656 .78 .94 r
F
.74974 .4367 m .7778 .43611 L .77767 .42792 L F
.32659 .82683 m .32239 .82827 L .32323 .82869 L .658 .812 .957 r
F
.3364 .82328 m .34071 .82119 L .33595 .82212 L F
.33142 .82363 m .3364 .82328 L .33595 .82212 L F
.79507 .81995 m .79021 .82145 L .79508 .82053 L .654 .816 .961 r
F
.79507 .81995 m .79019 .8203 L .79021 .82145 L F
.31662 .82061 m .31177 .82036 L .31146 .82216 L .659 .811 .957 r
F
.31183 .82321 m .31138 .82217 L .31151 .82502 L 0 0 .198 r
F
0 g
.31182 .82325 m
.31208 .82391 L
s
.31183 .82321 m .3117 .82035 L .31138 .82217 L 0 0 .198 r
F
.32659 .82683 m .33101 .82767 L .33145 .82709 L .658 .812 .957 r
F
.52609 .57802 m .5212 .56804 L .51084 .57081 L .659 .806 .953 r
F
.53157 .57733 m .5212 .56804 L .52609 .57802 L F
.80883 .827 m .81468 .82608 L .81011 .82583 L .653 .817 .962 r
F
.8049 .82616 m .80883 .827 L .81011 .82583 L F
.80399 .82669 m .80883 .827 L .8049 .82616 L F
0 g
.80029 .82555 m
.80211 .82538 L
s
.80029 .82555 m
.80029 .82555 L
s
.79856 .82533 m
.80029 .82555 L
s
.81517 .82142 m .81466 .81857 L .81466 .81682 L 0 0 .255 r
F
0 g
.81366 .82038 m
.81466 .81857 L
s
.80971 .81892 m .81458 .81857 L .81458 .81683 L .654 .816 .961 r
F
.31662 .82753 m .31234 .82961 L .31709 .82869 L .658 .812 .957 r
F
.31662 .82753 m .31164 .82788 L .31234 .82961 L F
0 g
.31234 .82961 m
.31401 .83115 L
s
.32191 .82029 m .31662 .82061 L .32147 .82087 L .659 .811 .957 r
F
.33142 .82363 m .33595 .82212 L .3312 .82305 L .658 .812 .957 r
F
0 g
.33089 .8255 m
.33093 .82483 L
s
.8096 .82297 m .81517 .82142 L .81027 .82176 L .653 .817 .962 r
F
.80503 .82272 m .8096 .82297 L .81027 .82176 L F
.33576 .81928 m .33886 .81681 L .33467 .81825 L .659 .811 .957 r
F
.33576 .81928 m .34049 .81836 L .33886 .81681 L F
.29826 .57054 m .29802 .56503 L .30361 .55682 L .049 0 .448 r
F
0 g
.29065 .57072 m
.29802 .56503 L
s
.62883 .16565 m .63176 .22927 L .63121 .23009 L .067 0 .41 r
F
.62883 .16565 m .62936 .16483 L .63176 .22927 L F
0 g
.628 .16634 m
.62883 .16565 L
s
.53157 .57733 m .53224 .56664 L .5212 .56804 L .659 .806 .953 r
F
0 g
.32243 .82471 m
.32258 .82539 L
s
.54265 .58357 m .54384 .57215 L .53761 .58282 L .658 .806 .954 r
F
.54265 .58357 m .55397 .57368 L .54384 .57215 L F
.62146 .16551 m .62441 .23066 L .62368 .22995 L .948 .643 .425 r
F
.62107 .16467 m .62146 .16551 L .62368 .22995 L .972 .694 .284 r
F
0 g
.62146 .16551 m
.62217 .16623 L
s
.41998 .4485 m .4403 .43669 L .44051 .44333 L .592 .379 .561 r
F
.41228 .43327 m .41998 .4485 L .44051 .44333 L .656 .78 .939 r
F
.39745 .43468 m .41998 .4485 L .41228 .43327 L F
0 g
.39796 .45058 m
.41998 .4485 L
s
.54749 .59052 m .55457 .57923 L .54323 .58911 L .658 .807 .955 r
F
.54749 .59052 m .56312 .58209 L .55457 .57923 L F
.495 .57955 m .47681 .57535 L .4703 .58342 L .659 .806 .953 r
F
.33048 .81969 m .33301 .81741 L .32965 .81927 L .659 .811 .957 r
F
.33048 .81969 m .33467 .81825 L .33301 .81741 L F
.80971 .81892 m .81458 .81683 L .8097 .81776 L .654 .816 .961 r
F
.80483 .81926 m .80971 .81892 L .8097 .81776 L F
.81468 .82608 m .81517 .82142 L .81569 .82427 L .01 .003 .499 r
F
.81011 .82583 m .81468 .82608 L .81569 .82427 L .653 .817 .962 r
F
0 g
.81275 .82783 m
.81468 .82608 L
s
.47702 .58084 m .47 .5834 L .47047 .58893 L .148 .067 .501 r
F
.47702 .58084 m .47653 .57529 L .47 .5834 L F
0 g
.4677 .59172 m
.47 .5834 L
s
.32659 .82683 m .32183 .82776 L .32239 .82827 L .658 .812 .957 r
F
.80096 .82532 m .80034 .8276 L .80163 .82743 L .653 .817 .962 r
F
.80096 .82532 m .79909 .82761 L .80034 .8276 L F
.69469 .4512 m .66702 .4599 L .69498 .45526 L .655 .782 .942 r
F
.69469 .4512 m .66628 .4518 L .66702 .4599 L F
.80096 .82532 m .80163 .82743 L .80287 .82712 L .653 .817 .962 r
F
0 g
.80211 .82538 m
.80334 .82502 L
s
.78622 .82636 m .78577 .82524 L .78626 .8281 L 0 0 .229 r
F
.79064 .82315 m .78577 .82524 L .79066 .82432 L .653 .817 .962 r
F
.79064 .82315 m .78573 .8235 L .78577 .82524 L F
.78622 .82636 m .78573 .8235 L .78577 .82524 L 0 0 .229 r
F
0 g
.78611 .82576 m
.78681 .82679 L
s
.80483 .81926 m .8097 .81776 L .80483 .81868 L .654 .816 .961 r
F
.49585 .5906 m .47095 .59448 L .49142 .59594 L .658 .807 .955 r
F
.3216 .82718 m .31709 .82869 L .32183 .82776 L .658 .812 .957 r
F
.3216 .82718 m .31662 .82753 L .31709 .82869 L F
.33145 .82709 m .33654 .82614 L .33157 .82648 L F
.32659 .82683 m .33145 .82709 L .33157 .82648 L F
.32158 .82372 m .31649 .82467 L .32147 .82433 L F
.34071 .82119 m .34056 .81834 L .33892 .81678 L .978 .695 .419 r
F
0 g
.34056 .81834 m
.34122 .82009 L
s
.80096 .82532 m .79797 .82747 L .79909 .82761 L .653 .817 .962 r
F
0 g
.79752 .82494 m
.79856 .82533 L
s
.74974 .4367 m .77767 .42792 L .7496 .43261 L .656 .78 .94 r
F
0 g
.80334 .82502 m
.80423 .82455 L
s
.56886 .58055 m .57827 .56802 L .56251 .57655 L .658 .806 .954 r
F
.56886 .58055 m .58775 .5741 L .57827 .56802 L F
.80096 .82532 m .80287 .82712 L .80399 .82669 L .653 .817 .962 r
F
0 g
.79687 .82445 m
.79752 .82494 L
s
.32191 .82029 m .3175 .81944 L .31662 .82061 L .659 .811 .957 r
F
.32265 .81976 m .3175 .81944 L .32191 .82029 L F
.62936 .16483 m .63194 .22829 L .63176 .22927 L 0 0 .209 r
F
.62936 .16483 m .62954 .16384 L .63194 .22829 L F
0 g
.62883 .16565 m
.62936 .16483 L
s
.34152 .82579 m .34071 .82119 L .34086 .82405 L .923 .683 .192 r
F
.33654 .82614 m .34152 .82579 L .34086 .82405 L .658 .812 .957 r
F
0 g
.34116 .82759 m
.34152 .82579 L
s
.3312 .82305 m .33486 .82109 L .33065 .82253 L .658 .812 .957 r
F
.3312 .82305 m .33595 .82212 L .33486 .82109 L F
.31671 .82347 m .31151 .82502 L .31649 .82467 L F
.32158 .82372 m .31671 .82347 L .31649 .82467 L F
.43432 .3272 m .47104 .32328 L .43547 .32142 L .643 .738 .918 r
F
0 g
.3303 .82396 m
.33093 .82483 L
s
.79606 .82624 m .79184 .8282 L .7964 .82676 L .653 .817 .962 r
F
.79606 .82624 m .79116 .82717 L .79184 .8282 L F
.62107 .16467 m .62368 .22995 L .62328 .22911 L .972 .694 .284 r
F
.62106 .16368 m .62107 .16467 L .62328 .22911 L 0 0 .044 r
F
0 g
.6211 .16471 m
.62146 .16551 L
s
.32965 .81927 m .33088 .81683 L .32859 .81898 L .659 .811 .957 r
F
.32965 .81927 m .33301 .81741 L .33088 .81683 L F
.80096 .82532 m .79705 .82718 L .79797 .82747 L .653 .817 .962 r
F
0 g
.32243 .82471 m
.32291 .82386 L
s
.3175 .81944 m .31177 .82036 L .31662 .82061 L .659 .811 .957 r
F
.33654 .82614 m .34086 .82405 L .3361 .82498 L .658 .812 .957 r
F
.33157 .82648 m .33654 .82614 L .3361 .82498 L F
.79555 .82281 m .79066 .82432 L .79556 .82339 L .653 .817 .962 r
F
.79555 .82281 m .79064 .82315 L .79066 .82432 L F
.32659 .82683 m .3216 .82718 L .32183 .82776 L .658 .812 .957 r
F
.80503 .82272 m .81027 .82176 L .80536 .82211 L .653 .817 .962 r
F
.7954 .81935 m .79019 .8203 L .79507 .81995 L .654 .816 .961 r
F
.80096 .82532 m .80399 .82669 L .8049 .82616 L .653 .817 .962 r
F
.31195 .82607 m .31151 .82502 L .31164 .82788 L 0 0 .198 r
F
0 g
.31195 .82611 m
.31221 .82676 L
s
.31671 .82347 m .31183 .82321 L .31151 .82502 L .658 .812 .957 r
F
.31195 .82607 m .31183 .82321 L .31151 .82502 L 0 0 .198 r
F
.20455 .45668 m .17034 .45605 L .19652 .46337 L .656 .78 .94 r
F
0 g
.80423 .82455 m
.80483 .82398 L
s
.52144 .58487 m .51127 .57627 L .50228 .58022 L .658 .806 .954 r
F
.52662 .5835 m .51127 .57627 L .52144 .58487 L F
0 g
.79655 .82387 m
.79687 .82445 L
s
.32265 .81976 m .31898 .81839 L .3175 .81944 L .659 .811 .957 r
F
.32364 .81932 m .31898 .81839 L .32265 .81976 L F
.81517 .82142 m .81466 .81682 L .81517 .81967 L 0 0 .255 r
F
.81569 .82427 m .81517 .82142 L .81517 .81967 L F
.81027 .82176 m .81517 .82142 L .81517 .81967 L .653 .817 .962 r
F
0 g
.81417 .82323 m
.81517 .82142 L
s
.24751 .57336 m .25456 .58336 L .26459 .58061 L .661 .804 .952 r
F
.33157 .82648 m .3361 .82498 L .33134 .82591 L .658 .812 .957 r
F
.32659 .82683 m .33157 .82648 L .33134 .82591 L F
.80483 .81868 m .80903 .81672 L .80449 .81817 L .654 .816 .961 r
F
0 g
.80443 .81844 m
.80462 .82075 L
s
.80483 .81868 m .8097 .81776 L .80903 .81672 L .654 .816 .961 r
F
.32202 .82313 m .31671 .82347 L .32158 .82372 L .658 .812 .957 r
F
.81011 .82583 m .81569 .82427 L .81078 .82462 L .653 .817 .962 r
F
.80554 .82557 m .81011 .82583 L .81078 .82462 L F
.8049 .82616 m .81011 .82583 L .80554 .82557 L F
.79083 .81909 m .78531 .82064 L .79019 .8203 L .654 .816 .961 r
F
.7954 .81935 m .79083 .81909 L .79019 .8203 L F
.33595 .82212 m .33907 .81964 L .33486 .82109 L .658 .812 .957 r
F
.33595 .82212 m .34071 .82119 L .33907 .81964 L F
.57453 .29035 m .56963 .31742 L .58888 .29852 L .644 .737 .917 r
F
.57453 .29035 m .54818 .30539 L .56963 .31742 L F
0 g
.56963 .31742 m
.59474 .32552 L
s
.32859 .81898 m .32845 .81653 L .32738 .81883 L .659 .811 .957 r
F
.32859 .81898 m .33088 .81683 L .32845 .81653 L F
.80096 .82532 m .7964 .82676 L .79705 .82718 L .653 .817 .962 r
F
.33467 .81825 m .33637 .81555 L .33301 .81741 L .659 .811 .957 r
F
.33467 .81825 m .33886 .81681 L .33637 .81555 L F
.62954 .16384 m .63149 .22704 L .63194 .22829 L .944 .685 .22 r
F
.62954 .16384 m .6291 .16257 L .63149 .22704 L F
.33065 .82253 m .33319 .82025 L .32981 .82211 L .658 .812 .957 r
F
.33065 .82253 m .33486 .82109 L .33319 .82025 L F
.81027 .82176 m .81517 .81967 L .81026 .8206 L .653 .817 .962 r
F
.80536 .82211 m .81027 .82176 L .81026 .8206 L F
.32659 .82683 m .32171 .82658 L .3216 .82718 L .658 .812 .957 r
F
.32659 .82683 m .32216 .82599 L .32171 .82658 L F
.32659 .82683 m .3229 .82546 L .32216 .82599 L F
.32659 .82683 m .3239 .82503 L .3229 .82546 L F
.32659 .82683 m .32508 .82471 L .3239 .82503 L F
.32659 .82683 m .32636 .82455 L .32508 .82471 L F
.32659 .82683 m .32766 .82453 L .32636 .82455 L F
.32659 .82683 m .32889 .82468 L .32766 .82453 L F
.32659 .82683 m .32995 .82497 L .32889 .82468 L F
.32659 .82683 m .33079 .82539 L .32995 .82497 L F
.32659 .82683 m .33134 .82591 L .33079 .82539 L F
.79083 .81909 m .78627 .81883 L .78531 .82064 L .654 .816 .961 r
F
.78669 .82169 m .78523 .82065 L .78573 .8235 L 0 0 .488 r
F
.78669 .82169 m .7862 .81883 L .78523 .82065 L F
0 g
.78523 .82065 m
.78528 .82239 L
s
.80711 .44214 m .80629 .42314 L .80716 .4298 L 0 0 .202 r
F
.80797 .44879 m .80711 .44214 L .80716 .4298 L F
.77889 .44274 m .80711 .44214 L .80716 .4298 L .655 .781 .941 r
F
0 g
.80394 .44888 m
.80711 .44214 L
s
.2046 .57632 m .1984 .58879 L .21224 .58035 L .661 .804 .952 r
F
.2046 .57632 m .18691 .58281 L .1984 .58879 L F
0 g
.1984 .58879 m
.21258 .593 L
s
.80096 .82532 m .8049 .82616 L .80554 .82557 L .653 .817 .962 r
F
.62106 .16368 m .62328 .22911 L .62327 .22813 L 0 0 .044 r
F
.62172 .16243 m .62106 .16368 L .62327 .22813 L 0 0 .377 r
F
0 g
.62106 .16368 m
.62107 .16467 L
s
.32364 .81932 m .32096 .81752 L .31898 .81839 L .659 .811 .957 r
F
.32481 .81901 m .32096 .81752 L .32364 .81932 L F
.29535 .29632 m .29434 .30573 L .29326 .31397 L .716 .657 .103 r
F
.29535 .29632 m .29643 .28804 L .29434 .30573 L F
.33142 .29584 m .29434 .30573 L .3298 .30759 L .643 .737 .917 r
F
.33142 .29584 m .29643 .28804 L .29434 .30573 L F
0 g
.29434 .30573 m
.29678 .31416 L
s
.3366 .43121 m .35483 .43183 L .35488 .43847 L .859 .596 .54 r
F
.3366 .43121 m .33658 .42455 L .35483 .43183 L F
0 g
.35483 .43183 m
.36015 .43294 L
s
.5175 .59235 m .5028 .58578 L .49585 .5906 L .658 .807 .955 r
F
.52199 .59041 m .5028 .58578 L .5175 .59235 L F
.36851 .43095 m .37582 .44943 L .38254 .43389 L .656 .78 .939 r
F
.36851 .43095 m .35493 .44512 L .37582 .44943 L F
0 g
.37582 .44943 m
.39796 .45058 L
s
.41212 .4266 m .4403 .43669 L .4259 .42308 L .657 .779 .939 r
F
.4403 .43669 m .45778 .42207 L .45801 .4287 L .493 .303 .551 r
F
.44051 .44333 m .4403 .43669 L .45801 .4287 L F
.4259 .42308 m .4403 .43669 L .45801 .4287 L .657 .779 .939 r
F
0 g
.42952 .43941 m
.4403 .43669 L
s
.53761 .58282 m .53282 .57209 L .53214 .5828 L .658 .806 .954 r
F
.53761 .58282 m .54384 .57215 L .53282 .57209 L F
.36619 .3036 m .3298 .30759 L .36526 .30944 L .643 .737 .917 r
F
.36619 .3036 m .33142 .29584 L .3298 .30759 L F
.32738 .81883 m .32586 .81656 L .32608 .81885 L .659 .811 .957 r
F
.32738 .81883 m .32845 .81653 L .32586 .81656 L F
.79113 .82601 m .78626 .8281 L .79116 .82717 L .653 .817 .962 r
F
.79113 .82601 m .78622 .82636 L .78626 .8281 L F
0 g
.78626 .8281 m
.7873 .82964 L
s
.79603 .81876 m .79083 .81909 L .7954 .81935 L .654 .816 .961 r
F
.80536 .82211 m .81026 .8206 L .80536 .82153 L .653 .817 .962 r
F
0 g
.80483 .82398 m
.80509 .82331 L
s
.8097 .81776 m .81358 .81528 L .80903 .81672 L .654 .816 .961 r
F
.8097 .81776 m .81458 .81683 L .81358 .81528 L F
.32171 .82658 m .31662 .82753 L .3216 .82718 L .658 .812 .957 r
F
.34071 .82119 m .33892 .81678 L .33907 .81964 L .978 .695 .419 r
F
.34086 .82405 m .34071 .82119 L .33907 .81964 L F
0 g
.34071 .82119 m
.34137 .82294 L
s
.32901 .82328 m
.3303 .82396 L
s
.3303 .82396 m
.3303 .82396 L
s
.5019 .57474 m .47681 .57535 L .495 .57955 L .659 .806 .953 r
F
.32481 .81901 m .32331 .81689 L .32096 .81752 L .659 .811 .957 r
F
.32608 .81885 m .32331 .81689 L .32481 .81901 L F
.35635 .41254 m .35503 .43162 L .36849 .41745 L .658 .778 .938 r
F
.35635 .41254 m .33687 .42438 L .35503 .43162 L F
.2052 .44345 m .18316 .43265 L .17129 .4428 L .657 .779 .938 r
F
.21621 .43818 m .18316 .43265 L .2052 .44345 L F
0 g
.79655 .82387 m
.79662 .82319 L
s
.32291 .82386 m
.32291 .82386 L
s
.32291 .82386 m
.32408 .82321 L
s
.32608 .81885 m .32586 .81656 L .32331 .81689 L .659 .811 .957 r
F
.32202 .82313 m .31759 .82229 L .31671 .82347 L .658 .812 .957 r
F
.32276 .82261 m .31759 .82229 L .32202 .82313 L F
.43619 .31316 m .46936 .30306 L .43493 .30719 L .643 .737 .917 r
F
.43619 .31316 m .47166 .31501 L .46936 .30306 L F
.80449 .81817 m .80774 .81588 L .80384 .81775 L .654 .816 .961 r
F
.80449 .81817 m .80903 .81672 L .80774 .81588 L F
.3175 .81944 m .31308 .8186 L .31177 .82036 L .659 .811 .957 r
F
.74961 .4541 m .7797 .44939 L .7514 .44999 L .655 .782 .942 r
F
.31314 .82144 m .3117 .82035 L .31183 .82321 L .071 0 .451 r
F
.31314 .82144 m .31301 .81859 L .3117 .82035 L F
0 g
.31138 .82217 m
.3117 .82035 L
s
.33134 .82591 m .335 .82394 L .33079 .82539 L .658 .812 .957 r
F
.33134 .82591 m .3361 .82498 L .335 .82394 L F
.31684 .82632 m .31164 .82788 L .31662 .82753 L F
.32171 .82658 m .31684 .82632 L .31662 .82753 L F
.80096 .82532 m .79606 .82624 L .7964 .82676 L .653 .817 .962 r
F
.47166 .31501 m .50403 .2989 L .46936 .30306 L .643 .737 .917 r
F
.47166 .31501 m .50714 .31687 L .50403 .2989 L F
.32981 .82211 m .33105 .81966 L .32875 .82182 L .658 .812 .957 r
F
.32981 .82211 m .33319 .82025 L .33105 .81966 L F
.50714 .31687 m .50457 .29063 L .50403 .2989 L .915 .736 .243 r
F
.5066 .32514 m .50714 .31687 L .50403 .2989 L F
0 g
.50517 .32507 m
.50618 .32085 L
s
.28558 .4483 m .28604 .42933 L .27318 .44352 L .657 .779 .939 r
F
.28558 .4483 m .30469 .43664 L .28604 .42933 L F
.52662 .5835 m .5217 .5735 L .51127 .57627 L .658 .806 .954 r
F
.53214 .5828 m .5217 .5735 L .52662 .5835 L F
.79605 .82566 m .79116 .82717 L .79606 .82624 L .653 .817 .962 r
F
.79605 .82566 m .79113 .82601 L .79116 .82717 L F
.31759 .82229 m .31183 .82321 L .31671 .82347 L .658 .812 .957 r
F
.80554 .82557 m .81078 .82462 L .80587 .82497 L .653 .817 .962 r
F
.80096 .82532 m .80554 .82557 L .80587 .82497 L F
.79587 .8222 m .79064 .82315 L .79555 .82281 L F
.81517 .81967 m .81466 .81682 L .81365 .81526 L .938 .625 .174 r
F
0 g
.81466 .81818 m
.81466 .81857 L
s
.31684 .82632 m .31195 .82607 L .31164 .82788 L .658 .812 .957 r
F
0 g
.31164 .82788 m
.31234 .82961 L
s
.23097 .57327 m .22172 .5832 L .23241 .5847 L .661 .804 .952 r
F
.31898 .81839 m .31308 .8186 L .3175 .81944 L .659 .811 .957 r
F
.29826 .57054 m .30361 .55682 L .30385 .56235 L .049 0 .448 r
F
.2985 .57606 m .29826 .57054 L .30385 .56235 L F
.27908 .56628 m .29826 .57054 L .30385 .56235 L .661 .803 .951 r
F
.27282 .57115 m .29826 .57054 L .27908 .56628 L F
0 g
.29084 .57625 m
.29826 .57054 L
s
.53214 .5828 m .53282 .57209 L .5217 .5735 L .658 .806 .954 r
F
.79603 .81876 m .7921 .81792 L .79083 .81909 L .654 .816 .961 r
F
.79693 .81823 m .7921 .81792 L .79603 .81876 L F
.54323 .58911 m .54442 .57771 L .53818 .58836 L .658 .807 .955 r
F
.54323 .58911 m .55457 .57923 L .54442 .57771 L F
.6291 .16257 m .63032 .22604 L .63149 .22704 L .931 .625 .44 r
F
.6291 .16257 m .62795 .16157 L .63032 .22604 L F
0 g
.6291 .16257 m
.62954 .16384 L
s
.6291 .16257 m
.6291 .16257 L
s
.69514 .43375 m .66535 .43847 L .69351 .43788 L .656 .78 .94 r
F
.81569 .82427 m .81517 .81967 L .81569 .82253 L 0 0 .255 r
F
.81078 .82462 m .81569 .82427 L .81569 .82253 L .653 .817 .962 r
F
0 g
.81468 .82608 m
.81569 .82427 L
s
.32276 .82261 m .31907 .82123 L .31759 .82229 L .658 .812 .957 r
F
.32376 .82217 m .31907 .82123 L .32276 .82261 L F
.77889 .44274 m .80716 .4298 L .77877 .43453 L .655 .781 .941 r
F
.75064 .44333 m .77889 .44274 L .77877 .43453 L F
.32216 .82599 m .31684 .82632 L .32171 .82658 L .658 .812 .957 r
F
.80536 .82153 m .80959 .81956 L .80502 .82101 L .653 .817 .962 r
F
.80536 .82153 m .81026 .8206 L .80959 .81956 L F
.31921 .44624 m .30473 .42997 L .30469 .43664 L .923 .656 .514 r
F
.3192 .4529 m .31921 .44624 L .30469 .43664 L F
0 g
.31921 .44624 m
.32864 .45741 L
s
.3361 .82498 m .33922 .8225 L .335 .82394 L .658 .812 .957 r
F
.3361 .82498 m .34086 .82405 L .33922 .8225 L F
.79128 .82194 m .78573 .8235 L .79064 .82315 L .653 .817 .962 r
F
.79587 .8222 m .79128 .82194 L .79064 .82315 L F
.49533 .58505 m .47702 .58084 L .47047 .58893 L .658 .806 .954 r
F
.47751 .58641 m .47047 .58893 L .47095 .59448 L .148 .067 .501 r
F
.47751 .58641 m .47702 .58084 L .47047 .58893 L F
0 g
.46817 .59723 m
.47047 .58893 L
s
.32776 .82296 m
.32901 .82328 L
s
.62303 .16147 m .62172 .16243 L .62395 .22689 L .369 .177 .485 r
F
.62172 .16243 m .62327 .22813 L .62395 .22689 L 0 0 .377 r
F
0 g
.62106 .16368 m
.62172 .16243 L
s
.62172 .16243 m
.62172 .16243 L
s
.80384 .81775 m .80592 .8153 L .80293 .81745 L .654 .816 .961 r
F
.80384 .81775 m .80774 .81588 L .80592 .8153 L F
0 g
.32408 .82321 m
.32529 .82293 L
s
.32875 .82182 m .3286 .81937 L .32752 .82168 L .658 .812 .957 r
F
.32875 .82182 m .33105 .81966 L .3286 .81937 L F
0 g
.79662 .82319 m
.79739 .82234 L
s
.33907 .81964 m .33892 .81678 L .33642 .81552 L .915 .637 .5 r
F
0 g
.33892 .81678 m
.34056 .81834 L
s
.33486 .82109 m .33657 .81837 L .33319 .82025 L .658 .812 .957 r
F
.33486 .82109 m .33907 .81964 L .33657 .81837 L F
.33301 .81741 m .33318 .81466 L .33088 .81683 L .659 .811 .957 r
F
.33301 .81741 m .33637 .81555 L .33318 .81466 L F
.33079 .82539 m .33333 .8231 L .32995 .82497 L .658 .812 .957 r
F
.33079 .82539 m .335 .82394 L .33333 .8231 L F
.7921 .81792 m .78627 .81883 L .79083 .81909 L .654 .816 .961 r
F
.81078 .82462 m .81569 .82253 L .81077 .82346 L .653 .817 .962 r
F
.80587 .82497 m .81078 .82462 L .81077 .82346 L F
.80096 .82532 m .79605 .82566 L .79606 .82624 L F
.78718 .82455 m .78573 .8235 L .78622 .82636 L 0 0 .488 r
F
.79128 .82194 m .78669 .82169 L .78573 .8235 L .653 .817 .962 r
F
.78718 .82455 m .78669 .82169 L .78573 .8235 L 0 0 .488 r
F
0 g
.78573 .8235 m
.78577 .82524 L
s
.53229 .28185 m .54904 .28894 L .54861 .29715 L .941 .671 .497 r
F
.53229 .28185 m .53276 .27362 L .54904 .28894 L F
0 g
.54904 .28894 m
.55603 .29289 L
s
.56948 .58609 m .5789 .57358 L .56312 .58209 L .658 .807 .955 r
F
.56948 .58609 m .5884 .57964 L .5789 .57358 L F
.32376 .82217 m .32107 .82035 L .31907 .82123 L .658 .812 .957 r
F
.32494 .82186 m .32107 .82035 L .32376 .82217 L F
0 g
.32651 .82286 m
.32776 .82296 L
s
.32529 .82293 m
.32651 .82286 L
s
.79693 .81823 m .79391 .81686 L .7921 .81792 L .654 .816 .961 r
F
.79804 .8178 m .79391 .81686 L .79693 .81823 L F
.37053 .29007 m .33276 .28769 L .36725 .29541 L .644 .737 .916 r
F
.32752 .82168 m .326 .81939 L .32622 .82169 L .658 .812 .957 r
F
.32752 .82168 m .3286 .81937 L .326 .81939 L F
.80587 .82497 m .81077 .82346 L .80587 .82439 L .653 .817 .962 r
F
.80096 .82532 m .80587 .82497 L .80587 .82439 L F
.79651 .82161 m .79128 .82194 L .79587 .8222 L F
.81026 .8206 m .81417 .81811 L .80959 .81956 L F
.81026 .8206 m .81517 .81967 L .81417 .81811 L F
.34086 .82405 m .33907 .81964 L .33922 .8225 L .978 .695 .419 r
F
0 g
.34086 .82405 m
.34152 .82579 L
s
.80033 .31797 m .7801 .29768 L .78027 .30594 L .881 .598 .504 r
F
.80055 .32626 m .80033 .31797 L .78027 .30594 L F
0 g
.80033 .31797 m
.81439 .33283 L
s
.56479 .26336 m .54943 .28872 L .57552 .27367 L .645 .736 .915 r
F
.56479 .26336 m .53323 .27347 L .54943 .28872 L F
.706 .32563 m .69987 .30306 L .673 .30862 L .643 .737 .917 r
F
.72462 .32505 m .69987 .30306 L .706 .32563 L F
.80293 .81745 m .80368 .815 L .80181 .81731 L .654 .816 .961 r
F
.80293 .81745 m .80592 .8153 L .80368 .815 L F
.32494 .82186 m .32343 .81973 L .32107 .82035 L .658 .812 .957 r
F
.32622 .82169 m .32343 .81973 L .32494 .82186 L F
.43547 .29898 m .46264 .28335 L .43189 .29328 L .644 .737 .916 r
F
.43547 .29898 m .46965 .29485 L .46264 .28335 L F
.32622 .82169 m .326 .81939 L .32343 .81973 L .658 .812 .957 r
F
.74276 .32755 m .72814 .30216 L .72462 .32505 L .643 .737 .917 r
F
.74276 .32755 m .75569 .30598 L .72814 .30216 L F
0 g
.71493 .28601 m
.71744 .28424 L
s
.32216 .82599 m .31772 .82515 L .31684 .82632 L .658 .812 .957 r
F
.3229 .82546 m .31772 .82515 L .32216 .82599 L F
.80903 .81672 m .81165 .81401 L .80774 .81588 L .654 .816 .961 r
F
.80903 .81672 m .81358 .81528 L .81165 .81401 L F
.80502 .82101 m .80829 .81872 L .80437 .82059 L .653 .817 .962 r
F
.80502 .82101 m .80959 .81956 L .80829 .81872 L F
.62795 .16157 m .6291 .22559 L .63032 .22604 L .822 .528 .492 r
F
.62795 .16157 m .62676 .16111 L .6291 .22559 L F
0 g
.62795 .16157 m
.6291 .16257 L
s
.31327 .82431 m .31183 .82321 L .31195 .82607 L .071 0 .451 r
F
.31759 .82229 m .31314 .82144 L .31183 .82321 L .658 .812 .957 r
F
.31327 .82431 m .31314 .82144 L .31183 .82321 L .071 0 .451 r
F
0 g
.31151 .82502 m
.31183 .82321 L
s
.80096 .82532 m .79637 .82506 L .79605 .82566 L .653 .817 .962 r
F
.80096 .82532 m .79701 .82447 L .79637 .82506 L F
.80096 .82532 m .79792 .82394 L .79701 .82447 L F
.80096 .82532 m .79904 .82351 L .79792 .82394 L F
.80096 .82532 m .80029 .82319 L .79904 .82351 L F
.80096 .82532 m .80158 .82303 L .80029 .82319 L F
.80096 .82532 m .80283 .82301 L .80158 .82303 L F
.80096 .82532 m .80396 .82316 L .80283 .82301 L F
.80096 .82532 m .80488 .82345 L .80396 .82316 L F
0 g
.80476 .82244 m
.80509 .82331 L
s
.80096 .82532 m .80553 .82387 L .80488 .82345 L .653 .817 .962 r
F
.80096 .82532 m .80587 .82439 L .80553 .82387 L F
.25256 .57197 m .26459 .58061 L .27302 .57668 L .661 .804 .952 r
F
.24751 .57336 m .26459 .58061 L .25256 .57197 L F
.62303 .16147 m .62395 .22689 L .62529 .22595 L .369 .177 .485 r
F
.6243 .16106 m .62303 .16147 L .62529 .22595 L .547 .31 .508 r
F
0 g
.62172 .16243 m
.62303 .16147 L
s
.32995 .82497 m .3312 .82252 L .32889 .82468 L .658 .812 .957 r
F
.32995 .82497 m .33333 .8231 L .3312 .82252 L F
.79804 .8178 m .79613 .81599 L .79391 .81686 L .654 .816 .961 r
F
.79928 .81749 m .79613 .81599 L .79804 .8178 L F
.66847 .43019 m .63715 .43906 L .66535 .43847 L .656 .78 .94 r
F
.69514 .43375 m .66847 .43019 L .66535 .43847 L F
.31898 .81839 m .3153 .81701 L .31308 .8186 L .659 .811 .957 r
F
.32096 .81752 m .3153 .81701 L .31898 .81839 L F
.75064 .44333 m .77877 .43453 L .7505 .43924 L .655 .781 .941 r
F
.80181 .81731 m .80119 .81503 L .80057 .81732 L .654 .816 .961 r
F
.80181 .81731 m .80368 .815 L .80119 .81503 L F
.52199 .59041 m .51181 .58184 L .5028 .58578 L .658 .807 .955 r
F
.52718 .58904 m .51181 .58184 L .52199 .59041 L F
.31772 .82515 m .31195 .82607 L .31684 .82632 L .658 .812 .957 r
F
.79637 .82506 m .79113 .82601 L .79605 .82566 L .653 .817 .962 r
F
.81517 .81967 m .81365 .81526 L .81417 .81811 L .938 .625 .174 r
F
.81569 .82253 m .81517 .81967 L .81417 .81811 L F
0 g
.81517 .82142 m
.81517 .82103 L
s
.8037 .82176 m
.80476 .82244 L
s
.80476 .82244 m
.80476 .82244 L
s
.31907 .82123 m .31314 .82144 L .31759 .82229 L .658 .812 .957 r
F
.79928 .81749 m .79861 .81536 L .79613 .81599 L .654 .816 .961 r
F
.80057 .81732 m .79861 .81536 L .79928 .81749 L F
.62676 .16111 m .62786 .22543 L .6291 .22559 L .735 .457 .508 r
F
.62676 .16111 m .62554 .16096 L .62786 .22543 L F
0 g
.62676 .16111 m
.62795 .16157 L
s
.79739 .82234 m
.79739 .82234 L
s
.79739 .82234 m
.79878 .82169 L
s
.80057 .81732 m .80119 .81503 L .79861 .81536 L .654 .816 .961 r
F
.6243 .16106 m .62529 .22595 L .62659 .22554 L .547 .31 .508 r
F
.62554 .16096 m .6243 .16106 L .62659 .22554 L .65 .39 .512 r
F
0 g
.62303 .16147 m
.6243 .16106 L
s
.79651 .82161 m .79256 .82077 L .79128 .82194 L .653 .817 .962 r
F
.79742 .82108 m .79256 .82077 L .79651 .82161 L F
.7921 .81792 m .78816 .81707 L .78627 .81883 L .654 .816 .961 r
F
.62554 .16096 m .62659 .22554 L .62786 .22543 L .65 .39 .512 r
F
0 g
.6243 .16106 m
.62554 .16096 L
s
.62554 .16096 m
.62676 .16111 L
s
.3229 .82546 m .31921 .82409 L .31772 .82515 L .658 .812 .957 r
F
.3239 .82503 m .31921 .82409 L .3229 .82546 L F
.7886 .81992 m .7862 .81883 L .78669 .82169 L .279 .18 .559 r
F
.7886 .81992 m .7881 .81706 L .7862 .81883 L F
0 g
.78523 .82065 m
.7862 .81883 L
s
.33088 .81683 m .32952 .81423 L .32845 .81653 L .659 .811 .957 r
F
.33088 .81683 m .33318 .81466 L .32952 .81423 L F
.80587 .82439 m .8101 .82242 L .80553 .82387 L .653 .817 .962 r
F
.80587 .82439 m .81077 .82346 L .8101 .82242 L F
.79178 .8248 m .78622 .82636 L .79113 .82601 L F
.79637 .82506 m .79178 .8248 L .79113 .82601 L F
.58775 .5741 m .58711 .56857 L .57764 .56248 L .939 .646 .459 r
F
0 g
.58711 .56857 m
.59263 .57592 L
s
.80437 .82059 m .80645 .81813 L .80345 .8203 L .653 .817 .962 r
F
.80437 .82059 m .80829 .81872 L .80645 .81813 L F
.56174 .5711 m .56466 .55824 L .55326 .56824 L .659 .806 .953 r
F
.56174 .5711 m .5774 .56261 L .56466 .55824 L F
.32889 .82468 m .32874 .82223 L .32766 .82453 L .658 .812 .957 r
F
.32889 .82468 m .3312 .82252 L .32874 .82223 L F
.33907 .81964 m .33642 .81552 L .33657 .81837 L .915 .637 .5 r
F
.33922 .8225 m .33907 .81964 L .33657 .81837 L F
0 g
.33907 .81964 m
.34071 .82119 L
s
.335 .82394 m .33671 .82123 L .33333 .8231 L .658 .812 .957 r
F
.335 .82394 m .33922 .8225 L .33671 .82123 L F
.53818 .58836 m .53339 .57766 L .5327 .58834 L .658 .807 .955 r
F
.53818 .58836 m .54442 .57771 L .53339 .57766 L F
.33319 .82025 m .33336 .81749 L .33105 .81966 L .658 .812 .957 r
F
.33319 .82025 m .33657 .81837 L .33336 .81749 L F
.79256 .82077 m .78669 .82169 L .79128 .82194 L .653 .817 .962 r
F
.31537 .81985 m .31301 .81859 L .31314 .82144 L .352 .199 .53 r
F
.31537 .81985 m .31524 .81699 L .31301 .81859 L F
0 g
.3117 .82035 m
.31301 .81859 L
s
.79178 .8248 m .78718 .82455 L .78622 .82636 L .653 .817 .962 r
F
0 g
.78622 .82636 m
.78626 .8281 L
s
.79391 .81686 m .78816 .81707 L .7921 .81792 L .654 .816 .961 r
F
.3239 .82503 m .3212 .82322 L .31921 .82409 L .658 .812 .957 r
F
.32508 .82471 m .3212 .82322 L .3239 .82503 L F
.50228 .58022 m .47702 .58084 L .49533 .58505 L .658 .806 .954 r
F
.79742 .82108 m .79438 .8197 L .79256 .82077 L .653 .817 .962 r
F
.79854 .82065 m .79438 .8197 L .79742 .82108 L F
.32766 .82453 m .32614 .82225 L .32636 .82455 L .658 .812 .957 r
F
.32766 .82453 m .32874 .82223 L .32614 .82225 L F
.79701 .82447 m .79178 .8248 L .79637 .82506 L .653 .817 .962 r
F
.32096 .81752 m .31827 .8157 L .3153 .81701 L .659 .811 .957 r
F
.32331 .81689 m .31827 .8157 L .32096 .81752 L F
.81077 .82346 m .81468 .82097 L .8101 .82242 L .653 .817 .962 r
F
.81077 .82346 m .81569 .82253 L .81468 .82097 L F
0 g
.80254 .82144 m
.8037 .82176 L
s
.32508 .82471 m .32357 .82259 L .3212 .82322 L .658 .812 .957 r
F
.32636 .82455 m .32357 .82259 L .32508 .82471 L F
0 g
.79878 .82169 m
.80008 .82141 L
s
.80345 .8203 m .80421 .81784 L .80233 .82015 L .653 .817 .962 r
F
.80345 .8203 m .80645 .81813 L .80421 .81784 L F
.66847 .43019 m .64162 .42661 L .63715 .43906 L .656 .78 .94 r
F
.64178 .43324 m .63673 .43907 L .63728 .44572 L 0 0 .371 r
F
0 g
.63742 .44536 m
.63746 .44572 L
s
.64178 .43324 m .64121 .42655 L .63673 .43907 L 0 0 .371 r
F
.32636 .82455 m .32614 .82225 L .32357 .82259 L .658 .812 .957 r
F
.81417 .81811 m .81365 .81526 L .81171 .81399 L .944 .627 .405 r
F
0 g
.81365 .81526 m
.81466 .81682 L
s
.32845 .81653 m .32564 .81426 L .32586 .81656 L .659 .811 .957 r
F
.32845 .81653 m .32952 .81423 L .32564 .81426 L F
.80797 .44879 m .80716 .4298 L .80803 .43648 L 0 0 .202 r
F
.7797 .44939 m .80797 .44879 L .80803 .43648 L .655 .782 .942 r
F
0 g
.80219 .46103 m
.80797 .44879 L
s
.80959 .81956 m .81222 .81684 L .80829 .81872 L .653 .817 .962 r
F
.80959 .81956 m .81417 .81811 L .81222 .81684 L F
.80774 .81588 m .80891 .81313 L .80592 .8153 L .654 .816 .961 r
F
.80774 .81588 m .81165 .81401 L .80891 .81313 L F
.80553 .82387 m .8088 .82158 L .80488 .82345 L .653 .817 .962 r
F
.80553 .82387 m .8101 .82242 L .8088 .82158 L F
.31772 .82515 m .31327 .82431 L .31195 .82607 L .658 .812 .957 r
F
0 g
.31164 .82788 m
.31195 .82607 L
s
.52718 .58904 m .52226 .57907 L .51181 .58184 L .658 .807 .955 r
F
.5327 .58834 m .52226 .57907 L .52718 .58904 L F
.72462 .32505 m .72814 .30216 L .69987 .30306 L .643 .737 .917 r
F
.33662 .43789 m .35488 .43847 L .35493 .44512 L .859 .596 .54 r
F
.33662 .43789 m .3366 .43121 L .35488 .43847 L F
.35621 .41934 m .35488 .43847 L .36843 .42426 L .657 .779 .939 r
F
.35621 .41934 m .3366 .43121 L .35488 .43847 L F
0 g
.35488 .43847 m
.36025 .43958 L
s
.44051 .44333 m .45801 .4287 L .45825 .43536 L .493 .303 .551 r
F
.42608 .42976 m .44051 .44333 L .45825 .43536 L .656 .78 .939 r
F
.41228 .43327 m .44051 .44333 L .42608 .42976 L F
0 g
.41998 .4485 m
.44051 .44333 L
s
.18256 .43917 m .17089 .44269 L .17061 .44936 L .272 .116 .479 r
F
.18256 .43917 m .18282 .43248 L .17089 .44269 L F
0 g
.16445 .45427 m
.17089 .44269 L
s
.33657 .81837 m .33642 .81552 L .33322 .81463 L .848 .581 .534 r
F
0 g
.33642 .81552 m
.33892 .81678 L
s
.2985 .57606 m .30385 .56235 L .3041 .56789 L .049 0 .448 r
F
.27929 .57182 m .2985 .57606 L .3041 .56789 L .661 .804 .952 r
F
.27302 .57668 m .2985 .57606 L .27929 .57182 L F
0 g
.28906 .58329 m
.2985 .57606 L
s
.79854 .82065 m .79661 .81883 L .79438 .8197 L .653 .817 .962 r
F
.79978 .82033 m .79661 .81883 L .79854 .82065 L F
0 g
.80133 .82134 m
.80254 .82144 L
s
.5327 .58834 m .53339 .57766 L .52226 .57907 L .658 .807 .955 r
F
0 g
.80008 .82141 m
.80133 .82134 L
s
.32331 .81689 m .3218 .81476 L .31827 .8157 L .659 .811 .957 r
F
.32586 .81656 m .3218 .81476 L .32331 .81689 L F
.31907 .82123 m .31537 .81985 L .31314 .82144 L .658 .812 .957 r
F
.32107 .82035 m .31537 .81985 L .31907 .82123 L F
.80233 .82015 m .8017 .81786 L .80108 .82016 L .653 .817 .962 r
F
.80233 .82015 m .80421 .81784 L .8017 .81786 L F
.81569 .82253 m .81417 .81811 L .81468 .82097 L .938 .625 .174 r
F
0 g
.81569 .82427 m
.81569 .82253 L
s
.32586 .81656 m .32564 .81426 L .3218 .81476 L .659 .811 .957 r
F
.49585 .5906 m .47751 .58641 L .47095 .59448 L .658 .807 .955 r
F
0 g
.46864 .60275 m
.47095 .59448 L
s
.31921 .82409 m .31327 .82431 L .31772 .82515 L .658 .812 .957 r
F
.79978 .82033 m .79911 .8182 L .79661 .81883 L .653 .817 .962 r
F
.80108 .82016 m .79911 .8182 L .79978 .82033 L F
.80108 .82016 m .8017 .81786 L .79911 .8182 L F
.20477 .45 m .18256 .43917 L .17061 .44936 L .657 .779 .939 r
F
.21585 .44472 m .18256 .43917 L .20477 .45 L F
.79701 .82447 m .79306 .82363 L .79178 .8248 L .653 .817 .962 r
F
.79792 .82394 m .79306 .82363 L .79701 .82447 L F
.27315 .437 m .26458 .41843 L .25904 .43411 L .657 .779 .938 r
F
.27315 .437 m .28592 .42285 L .26458 .41843 L F
.7496 .43261 m .77369 .42029 L .74754 .42883 L .656 .78 .94 r
F
.7496 .43261 m .77767 .42792 L .77369 .42029 L F
.78909 .82278 m .78669 .82169 L .78718 .82455 L .279 .18 .559 r
F
.79256 .82077 m .7886 .81992 L .78669 .82169 L .653 .817 .962 r
F
.78909 .82278 m .7886 .81992 L .78669 .82169 L .279 .18 .559 r
F
0 g
.78573 .8235 m
.78669 .82169 L
s
.33105 .81966 m .32968 .81705 L .3286 .81937 L .658 .812 .957 r
F
.33105 .81966 m .33336 .81749 L .32968 .81705 L F
.28551 .45497 m .28597 .43604 L .27309 .4502 L .656 .78 .94 r
F
.28551 .45497 m .30465 .44333 L .28597 .43604 L F
.80488 .82345 m .80696 .82099 L .80396 .82316 L .653 .817 .962 r
F
.80488 .82345 m .8088 .82158 L .80696 .82099 L F
.33922 .8225 m .33657 .81837 L .33671 .82123 L .915 .637 .5 r
F
0 g
.33922 .8225 m
.34086 .82405 L
s
.79391 .81686 m .79087 .81548 L .78816 .81707 L .654 .816 .961 r
F
.79613 .81599 m .79087 .81548 L .79391 .81686 L F
.33333 .8231 m .33351 .82035 L .3312 .82252 L .658 .812 .957 r
F
.33333 .8231 m .33671 .82123 L .33351 .82035 L F
.79306 .82363 m .78718 .82455 L .79178 .8248 L .653 .817 .962 r
F
.3155 .82271 m .31314 .82144 L .31327 .82431 L .352 .199 .53 r
F
.3155 .82271 m .31537 .81985 L .31314 .82144 L F
0 g
.31183 .82321 m
.31314 .82144 L
s
.79438 .8197 m .7886 .81992 L .79256 .82077 L .653 .817 .962 r
F
.69567 .44039 m .66567 .44512 L .69403 .44453 L .655 .781 .941 r
F
.22622 .57182 m .22172 .5832 L .23097 .57327 L .661 .804 .952 r
F
.22622 .57182 m .21224 .58035 L .22172 .5832 L F
.7797 .44939 m .80803 .43648 L .77958 .44121 L .655 .782 .942 r
F
.7514 .44999 m .7797 .44939 L .77958 .44121 L F
.3192 .4529 m .30469 .43664 L .30465 .44333 L .923 .656 .514 r
F
0 g
.3192 .4529 m
.32865 .46405 L
s
.17884 .56986 m .18674 .57172 L .18682 .57726 L .974 .706 .463 r
F
.17884 .56986 m .17877 .5643 L .18674 .57172 L F
0 g
.18674 .57172 m
.19297 .575 L
s
.79792 .82394 m .79488 .82257 L .79306 .82363 L .653 .817 .962 r
F
.79904 .82351 m .79488 .82257 L .79792 .82394 L F
.80592 .8153 m .80555 .81269 L .80368 .815 L .654 .816 .961 r
F
.80592 .8153 m .80891 .81313 L .80555 .81269 L F
.32107 .82035 m .31836 .81853 L .31537 .81985 L .658 .812 .957 r
F
.32343 .81973 m .31836 .81853 L .32107 .82035 L F
.19934 .56019 m .17908 .56424 L .18701 .57163 L .662 .802 .95 r
F
.80396 .82316 m .80471 .8207 L .80283 .82301 L .653 .817 .962 r
F
.80396 .82316 m .80696 .82099 L .80471 .8207 L F
.81417 .81811 m .81171 .81399 L .81222 .81684 L .944 .627 .405 r
F
.81468 .82097 m .81417 .81811 L .81222 .81684 L F
0 g
.81417 .81811 m
.81517 .81967 L
s
.31836 .81853 m .31524 .81699 L .31537 .81985 L .502 .312 .555 r
F
.31836 .81853 m .31823 .81567 L .31524 .81699 L F
0 g
.31301 .81859 m
.31524 .81699 L
s
.8101 .82242 m .81274 .81971 L .8088 .82158 L .653 .817 .962 r
F
.8101 .82242 m .81468 .82097 L .81274 .81971 L F
.3286 .81937 m .32578 .81708 L .326 .81939 L .658 .812 .957 r
F
.3286 .81937 m .32968 .81705 L .32578 .81708 L F
.62686 .26661 m .62463 .28985 L .64311 .28925 L .645 .736 .915 r
F
.61766 .26532 m .62463 .28985 L .62686 .26661 L F
.61766 .26532 m .60645 .28733 L .62463 .28985 L F
.80829 .81872 m .80947 .81596 L .80645 .81813 L .653 .817 .962 r
F
.80829 .81872 m .81222 .81684 L .80947 .81596 L F
.79132 .81832 m .7881 .81706 L .7886 .81992 L .435 .285 .577 r
F
.79132 .81832 m .79082 .81546 L .7881 .81706 L F
0 g
.7862 .81883 m
.7881 .81706 L
s
.33043 .30411 m .29326 .31397 L .32881 .31584 L .643 .738 .918 r
F
.33043 .30411 m .29535 .29632 L .29326 .31397 L F
0 g
.29326 .31397 m
.29841 .33166 L
s
.33657 .81837 m .33322 .81463 L .33336 .81749 L .848 .581 .534 r
F
.33671 .82123 m .33657 .81837 L .33336 .81749 L F
0 g
.33657 .81837 m
.33907 .81964 L
s
.79904 .82351 m .79711 .82169 L .79488 .82257 L .653 .817 .962 r
F
.80029 .82319 m .79711 .82169 L .79904 .82351 L F
.36529 .31186 m .32881 .31584 L .36436 .3177 L .643 .738 .918 r
F
.36529 .31186 m .33043 .30411 L .32881 .31584 L F
.31921 .82409 m .3155 .82271 L .31327 .82431 L .658 .812 .957 r
F
0 g
.31195 .82607 m
.31327 .82431 L
s
.3212 .82322 m .3155 .82271 L .31921 .82409 L .658 .812 .957 r
F
.80283 .82301 m .80221 .82073 L .80158 .82303 L .653 .817 .962 r
F
.80283 .82301 m .80471 .8207 L .80221 .82073 L F
.32343 .81973 m .32191 .81759 L .31836 .81853 L .658 .812 .957 r
F
.326 .81939 m .32191 .81759 L .32343 .81973 L F
.79613 .81599 m .7942 .81417 L .79087 .81548 L .654 .816 .961 r
F
.79861 .81536 m .7942 .81417 L .79613 .81599 L F
.326 .81939 m .32578 .81708 L .32191 .81759 L .658 .812 .957 r
F
.80029 .82319 m .79961 .82106 L .79711 .82169 L .653 .817 .962 r
F
.80158 .82303 m .79961 .82106 L .80029 .82319 L F
.58775 .5741 m .57764 .56248 L .57827 .56802 L .939 .646 .459 r
F
.5884 .57964 m .58775 .5741 L .57827 .56802 L F
0 g
.58775 .5741 m
.59327 .58142 L
s
.43547 .32142 m .46873 .31135 L .43421 .31547 L .643 .738 .918 r
F
.43547 .32142 m .47104 .32328 L .46873 .31135 L F
.80158 .82303 m .80221 .82073 L .79961 .82106 L .653 .817 .962 r
F
.33336 .81749 m .33322 .81463 L .32954 .81419 L .788 .533 .551 r
F
0 g
.33322 .81463 m
.33642 .81552 L
s
.80368 .815 m .80181 .81272 L .80119 .81503 L .654 .816 .961 r
F
.80368 .815 m .80555 .81269 L .80181 .81272 L F
.47104 .32328 m .50348 .30721 L .46873 .31135 L .643 .738 .918 r
F
.47104 .32328 m .5066 .32514 L .50348 .30721 L F
.79306 .82363 m .78909 .82278 L .78718 .82455 L .653 .817 .962 r
F
0 g
.78622 .82636 m
.78718 .82455 L
s
.56251 .57655 m .56545 .56365 L .55397 .57368 L .658 .806 .954 r
F
.56251 .57655 m .57827 .56802 L .56545 .56365 L F
.3312 .82252 m .32983 .81991 L .32874 .82223 L .658 .812 .957 r
F
.3312 .82252 m .33351 .82035 L .32983 .81991 L F
.45801 .4287 m .45778 .42207 L .47152 .41172 L .347 .192 .524 r
F
0 g
.44727 .42682 m
.45778 .42207 L
s
.5066 .32514 m .50403 .2989 L .50348 .30721 L .915 .736 .243 r
F
0 g
.50246 .34235 m
.5066 .32514 L
s
.66881 .43683 m .63728 .44572 L .66567 .44512 L .655 .781 .941 r
F
.69567 .44039 m .66881 .43683 L .66567 .44512 L F
.81222 .81684 m .81171 .81399 L .80896 .8131 L .867 .575 .492 r
F
0 g
.81171 .81399 m
.81365 .81526 L
s
.7514 .44999 m .77958 .44121 L .75126 .44591 L .655 .782 .942 r
F
.79861 .81536 m .79794 .81323 L .7942 .81417 L .654 .816 .961 r
F
.80119 .81503 m .79794 .81323 L .79861 .81536 L F
.79438 .8197 m .79132 .81832 L .7886 .81992 L .653 .817 .962 r
F
.79661 .81883 m .79132 .81832 L .79438 .8197 L F
.43735 .4109 m .45747 .4219 L .47115 .4116 L .658 .778 .938 r
F
.42557 .41629 m .45747 .4219 L .43735 .4109 L F
.5028 .58578 m .47751 .58641 L .49585 .5906 L .658 .807 .955 r
F
.80119 .81503 m .80181 .81272 L .79794 .81323 L .654 .816 .961 r
F
.79488 .82257 m .78909 .82278 L .79306 .82363 L .653 .817 .962 r
F
.80645 .81813 m .80609 .81552 L .80421 .81784 L F
.80645 .81813 m .80947 .81596 L .80609 .81552 L F
.3212 .82322 m .3185 .8214 L .3155 .82271 L .658 .812 .957 r
F
.32357 .82259 m .3185 .8214 L .3212 .82322 L F
.5019 .57474 m .48713 .56807 L .47681 .57535 L .659 .806 .953 r
F
.51084 .57081 m .48713 .56807 L .5019 .57474 L F
.69859 .42985 m .66847 .43019 L .69514 .43375 L .656 .78 .94 r
F
.21621 .43818 m .19972 .42462 L .18316 .43265 L .657 .779 .938 r
F
.2295 .43472 m .19972 .42462 L .21621 .43818 L F
0 g
.64954 .31835 m
.673 .30862 L
s
.32191 .81759 m .31823 .81567 L .31836 .81853 L .598 .385 .563 r
F
.32191 .81759 m .32178 .81473 L .31823 .81567 L F
0 g
.31524 .81699 m
.31823 .81567 L
s
.81468 .82097 m .81222 .81684 L .81274 .81971 L .944 .627 .405 r
F
0 g
.81468 .82097 m
.81569 .82253 L
s
.3185 .8214 m .31537 .81985 L .3155 .82271 L .502 .312 .555 r
F
0 g
.31327 .82431 m
.3155 .82271 L
s
.3185 .8214 m .31836 .81853 L .31537 .81985 L .502 .312 .555 r
F
0 g
.31314 .82144 m
.31537 .81985 L
s
.25678 .56998 m .27302 .57668 L .27929 .57182 L .661 .804 .952 r
F
.25256 .57197 m .27302 .57668 L .25678 .56998 L F
.32874 .82223 m .32592 .81995 L .32614 .82225 L .658 .812 .957 r
F
.32874 .82223 m .32983 .81991 L .32592 .81995 L F
.8088 .82158 m .80998 .81882 L .80696 .82099 L .653 .817 .962 r
F
.8088 .82158 m .81274 .81971 L .80998 .81882 L F
.53182 .29013 m .54861 .29715 L .54818 .30539 L .941 .671 .497 r
F
.53182 .29013 m .53229 .28185 L .54861 .29715 L F
.56408 .27172 m .54861 .29715 L .57489 .28207 L .644 .736 .916 r
F
.56408 .27172 m .53229 .28185 L .54861 .29715 L F
0 g
.54861 .29715 m
.55567 .30112 L
s
.79182 .82119 m .7886 .81992 L .78909 .82278 L .435 .285 .577 r
F
.79182 .82119 m .79132 .81832 L .7886 .81992 L F
0 g
.78669 .82169 m
.7886 .81992 L
s
.60921 .26251 m .60645 .28733 L .61766 .26532 L .645 .736 .915 r
F
.60921 .26251 m .58972 .28183 L .60645 .28733 L F
.33671 .82123 m .33336 .81749 L .33351 .82035 L .848 .581 .534 r
F
0 g
.33671 .82123 m
.33922 .8225 L
s
.63621 .26629 m .64311 .28925 L .66073 .28554 L .645 .736 .915 r
F
.62686 .26661 m .64311 .28925 L .63621 .26629 L F
.36949 .29824 m .33142 .29584 L .36619 .3036 L .643 .737 .917 r
F
.32968 .81705 m .32954 .81419 L .32564 .81422 L .73 .487 .56 r
F
.33336 .81749 m .32954 .81419 L .32968 .81705 L .788 .533 .551 r
F
0 g
.32954 .81419 m
.33322 .81463 L
s
.80055 .32626 m .78027 .30594 L .78044 .31424 L .881 .598 .504 r
F
0 g
.80055 .32626 m
.81465 .34108 L
s
.32357 .82259 m .32205 .82046 L .3185 .8214 L .658 .812 .957 r
F
.32614 .82225 m .32205 .82046 L .32357 .82259 L F
.79661 .81883 m .79468 .817 L .79132 .81832 L .653 .817 .962 r
F
.79911 .8182 m .79468 .817 L .79661 .81883 L F
.32614 .82225 m .32592 .81995 L .32205 .82046 L .658 .812 .957 r
F
.66881 .43683 m .64178 .43324 L .63728 .44572 L .655 .781 .941 r
F
.64235 .43996 m .63728 .44572 L .63784 .45241 L 0 0 .371 r
F
0 g
.63798 .45204 m
.63802 .4524 L
s
.64235 .43996 m .64178 .43324 L .63728 .44572 L 0 0 .371 r
F
.43493 .30719 m .4623 .29152 L .43131 .30147 L .643 .737 .917 r
F
.43493 .30719 m .46936 .30306 L .4623 .29152 L F
.33351 .82035 m .33336 .81749 L .32968 .81705 L .788 .533 .551 r
F
0 g
.33336 .81749 m
.33657 .81837 L
s
.79468 .817 m .79082 .81546 L .79132 .81832 L .534 .351 .579 r
F
.79468 .817 m .79418 .81414 L .79082 .81546 L F
0 g
.7881 .81706 m
.79082 .81546 L
s
.80421 .81784 m .80233 .81555 L .8017 .81786 L .653 .817 .962 r
F
.80421 .81784 m .80609 .81552 L .80233 .81555 L F
.35626 .42605 m .35493 .44512 L .36851 .43095 L .656 .78 .939 r
F
.35626 .42605 m .33662 .43789 L .35493 .44512 L F
0 g
.35493 .44512 m
.37582 .44943 L
s
.18231 .44588 m .17061 .44936 L .17034 .45605 L .272 .116 .479 r
F
.18231 .44588 m .18256 .43917 L .17061 .44936 L F
0 g
.16416 .4609 m
.17061 .44936 L
s
.50999 .69975 m .52049 .69765 L .52021 .70238 L .794 .551 .57 r
F
.50999 .69975 m .51029 .69502 L .52049 .69765 L F
0 g
.52049 .69765 m
.52306 .69796 L
s
.32578 .81708 m .32178 .81473 L .32191 .81759 L .67 .44 .564 r
F
.32578 .81708 m .32564 .81422 L .32178 .81473 L F
0 g
.31823 .81567 m
.32178 .81473 L
s
.81222 .81684 m .80896 .8131 L .80947 .81596 L .867 .575 .492 r
F
.81274 .81971 m .81222 .81684 L .80947 .81596 L F
0 g
.81222 .81684 m
.81417 .81811 L
s
.32968 .81705 m .32564 .81422 L .32578 .81708 L .73 .487 .56 r
F
0 g
.32178 .81473 m
.32564 .81422 L
s
.32564 .81422 m
.32954 .81419 L
s
.79488 .82257 m .79182 .82119 L .78909 .82278 L .653 .817 .962 r
F
0 g
.78718 .82455 m
.78909 .82278 L
s
.79711 .82169 m .79182 .82119 L .79488 .82257 L .653 .817 .962 r
F
.79911 .8182 m .79843 .81606 L .79468 .817 L F
.8017 .81786 m .79843 .81606 L .79911 .8182 L F
.17891 .57543 m .18682 .57726 L .18691 .58281 L .974 .706 .463 r
F
.17891 .57543 m .17884 .56986 L .18682 .57726 L F
.19923 .56579 m .18682 .57726 L .20449 .57076 L .661 .803 .951 r
F
.19923 .56579 m .17884 .56986 L .18682 .57726 L F
0 g
.18682 .57726 m
.1931 .58054 L
s
.8017 .81786 m .80233 .81555 L .79843 .81606 L .653 .817 .962 r
F
.20455 .45668 m .18231 .44588 L .17034 .45605 L .656 .78 .94 r
F
0 g
.16387 .46756 m
.17034 .45605 L
s
.21565 .45141 m .18231 .44588 L .20455 .45668 L .656 .78 .94 r
F
.80947 .81596 m .80896 .8131 L .80558 .81266 L .794 .526 .532 r
F
0 g
.80896 .8131 m
.81171 .81399 L
s
.7505 .43924 m .77476 .42688 L .74843 .43544 L .655 .781 .941 r
F
.7505 .43924 m .77877 .43453 L .77476 .42688 L F
.37053 .29007 m .33915 .27689 L .33276 .28769 L .644 .737 .916 r
F
.37596 .28559 m .33915 .27689 L .37053 .29007 L F
.27318 .44352 m .26455 .42489 L .25898 .44062 L .657 .779 .939 r
F
.27318 .44352 m .28604 .42933 L .26455 .42489 L F
.80696 .82099 m .8066 .81838 L .80471 .8207 L .653 .817 .962 r
F
.80696 .82099 m .80998 .81882 L .8066 .81838 L F
.43189 .29328 m .45131 .27308 L .42619 .28822 L .644 .737 .916 r
F
.43189 .29328 m .46264 .28335 L .45131 .27308 L F
.32205 .82046 m .31836 .81853 L .3185 .8214 L .598 .385 .563 r
F
.32205 .82046 m .32191 .81759 L .31836 .81853 L F
0 g
.31537 .81985 m
.31836 .81853 L
s
.3155 .82271 m
.3185 .8214 L
s
.33915 .27689 m .29804 .27992 L .33276 .28769 L .644 .737 .916 r
F
.69634 .44707 m .66628 .4518 L .69469 .4512 L .655 .782 .942 r
F
.55326 .56824 m .54947 .5559 L .54319 .56671 L .659 .806 .953 r
F
.55326 .56824 m .56466 .55824 L .54947 .5559 L F
.5884 .57964 m .57827 .56802 L .5789 .57358 L .939 .646 .459 r
F
0 g
.5884 .57964 m
.59392 .58694 L
s
.77767 .42792 m .80008 .41167 L .77369 .42029 L .656 .78 .94 r
F
.77767 .42792 m .80587 .42321 L .80008 .41167 L F
.32983 .81991 m .32968 .81705 L .32578 .81708 L .73 .487 .56 r
F
.33351 .82035 m .32968 .81705 L .32983 .81991 L .788 .533 .551 r
F
0 g
.32968 .81705 m
.33336 .81749 L
s
.33351 .82035 m
.33671 .82123 L
s
.68951 .28868 m
.69994 .2865 L
s
.72103 .56427 m .7202 .55874 L .73688 .55663 L .671 .449 .574 r
F
.70476 .56417 m .7202 .55874 L .72103 .56427 L .734 .492 .562 r
F
.70476 .56417 m .70395 .55863 L .7202 .55874 L F
.79711 .82169 m .79518 .81987 L .79182 .82119 L .653 .817 .962 r
F
.79961 .82106 m .79518 .81987 L .79711 .82169 L F
.56312 .58209 m .56607 .56923 L .55457 .57923 L .658 .807 .955 r
F
.56312 .58209 m .5789 .57358 L .56607 .56923 L F
.46965 .29485 m .49379 .27329 L .46264 .28335 L .644 .737 .916 r
F
.46965 .29485 m .50405 .29069 L .49379 .27329 L F
.79843 .81606 m .79418 .81414 L .79468 .817 L .608 .401 .575 r
F
.79843 .81606 m .79793 .8132 L .79418 .81414 L F
0 g
.79082 .81546 m
.79418 .81414 L
s
.72241 .54769 m .72023 .55858 L .73683 .55648 L .658 .806 .954 r
F
.71155 .54761 m .72023 .55858 L .72241 .54769 L F
.71155 .54761 m .70406 .55847 L .72023 .55858 L F
.79518 .81987 m .79132 .81832 L .79182 .82119 L .534 .351 .579 r
F
0 g
.78909 .82278 m
.79182 .82119 L
s
.79518 .81987 m .79468 .817 L .79132 .81832 L .534 .351 .579 r
F
0 g
.7886 .81992 m
.79132 .81832 L
s
.78027 .30594 m .7801 .29768 L .75548 .2894 L .805 .532 .526 r
F
0 g
.7801 .29768 m
.80012 .30974 L
s
.80471 .8207 m .80283 .81842 L .80221 .82073 L .653 .817 .962 r
F
.80471 .8207 m .8066 .81838 L .80283 .81842 L F
.25904 .43411 m .24199 .41722 L .24413 .43333 L .657 .779 .938 r
F
.25904 .43411 m .26458 .41843 L .24199 .41722 L F
.32592 .81995 m .32191 .81759 L .32205 .82046 L .67 .44 .564 r
F
.32592 .81995 m .32578 .81708 L .32191 .81759 L F
0 g
.31836 .81853 m
.32191 .81759 L
s
.81274 .81971 m .80947 .81596 L .80998 .81882 L .867 .575 .492 r
F
0 g
.81274 .81971 m
.81468 .82097 L
s
.80947 .81596 m .80558 .81266 L .80609 .81552 L .794 .526 .532 r
F
.80609 .81552 m .80558 .81266 L .80182 .81269 L .731 .483 .554 r
F
0 g
.80558 .81266 m
.80896 .8131 L
s
.32983 .81991 m .32578 .81708 L .32592 .81995 L .73 .487 .56 r
F
0 g
.32191 .81759 m
.32578 .81708 L
s
.32578 .81708 m
.32968 .81705 L
s
.32983 .81991 m
.33351 .82035 L
s
.73773 .56216 m .73688 .55663 L .75292 .55244 L .605 .403 .581 r
F
.72103 .56427 m .73688 .55663 L .73773 .56216 L .671 .449 .574 r
F
0 g
.7202 .55874 m
.73688 .55663 L
s
.79961 .82106 m .79894 .81893 L .79518 .81987 L .653 .817 .962 r
F
.80221 .82073 m .79894 .81893 L .79961 .82106 L F
.30385 .56235 m .30361 .55682 L .30493 .5482 L 0 0 .191 r
F
0 g
.29937 .56306 m
.30361 .55682 L
s
.80221 .82073 m .80283 .81842 L .79894 .81893 L .653 .817 .962 r
F
.28232 .55523 m .30329 .5568 L .3046 .54822 L .662 .802 .95 r
F
.80998 .81882 m .80947 .81596 L .80609 .81552 L .794 .526 .532 r
F
0 g
.80947 .81596 m
.81222 .81684 L
s
.73356 .54628 m .73683 .55648 L .74445 .55449 L .658 .806 .954 r
F
.73356 .54628 m .74445 .55449 L .74213 .54896 L F
.73356 .54628 m .75279 .5523 L .74428 .54346 L F
.72509 .54735 m .73683 .55648 L .73356 .54628 L F
.72241 .54769 m .72455 .54899 L .72509 .54735 L F
.72455 .54899 m .73683 .55648 L .72509 .54735 L F
.72462 .53663 m .72241 .54769 L .73356 .54628 L F
.73024 .53591 m .73356 .54628 L .74026 .54451 L F
.73852 .54037 m .74026 .54451 L .74428 .54346 L F
.73024 .53591 m .74026 .54451 L .73852 .54037 L F
.72867 .47488 m .73221 .52571 L .73204 .52624 L 0 0 .297 r
F
.72462 .53663 m .73356 .54628 L .73024 .53591 L .658 .806 .954 r
F
.73024 .53591 m .74428 .54346 L .73563 .53449 L F
.74213 .54896 m .74445 .55449 L .75279 .5523 L F
.73112 .54155 m .73445 .55194 L .74524 .54911 L .658 .807 .955 r
F
.73112 .54155 m .74524 .54911 L .73655 .54012 L F
.73773 .56216 m .75292 .55244 L .7538 .55797 L .605 .403 .581 r
F
.73445 .55194 m .7538 .55797 L .74524 .54911 L .658 .807 .955 r
F
.72546 .54227 m .73445 .55194 L .73112 .54155 L F
.73198 .54715 m .74611 .55468 L .73742 .54572 L .657 .808 .956 r
F
.72809 .47559 m .72867 .47488 L .73204 .52624 L .157 .044 .463 r
F
.73093 .5296 m .73024 .53591 L .73563 .53449 L .658 .806 .954 r
F
.72992 .52856 m .73008 .5322 L .73093 .5296 L F
.73008 .5322 m .73024 .53591 L .73093 .5296 L F
.72867 .47488 m .7289 .47404 L .73228 .5255 L 0 0 .297 r
F
.7309 .52748 m .73563 .53449 L .74044 .53244 L .658 .806 .954 r
F
.72992 .52856 m .73563 .53449 L .7309 .52748 L F
.73445 .55194 m .73773 .56216 L .7538 .55797 L .658 .807 .955 r
F
.72323 .55336 m .73773 .56216 L .73445 .55194 L F
.72546 .54227 m .72323 .55336 L .73445 .55194 L F
.73198 .54715 m .73531 .55751 L .74611 .55468 L .657 .808 .956 r
F
.73134 .53473 m .73112 .54155 L .73655 .54012 L .658 .807 .955 r
F
.72809 .47559 m .73187 .52643 L .73145 .52689 L .157 .044 .463 r
F
.73379 .52718 m .74044 .53244 L .74435 .52991 L .658 .806 .954 r
F
.72416 .47686 m .72879 .52802 L .72746 .52824 L .638 .394 .533 r
F
.72416 .47686 m .726 .47664 L .72932 .52793 L F
.72416 .47686 m .72932 .52793 L .72915 .52796 L F
.72932 .52793 m .72841 .53021 L .72992 .52856 L .658 .806 .954 r
F
.72841 .53021 m .73024 .53591 L .72992 .52856 L F
.72987 .53321 m .73039 .53374 L .73106 .53301 L .658 .807 .955 r
F
.72987 .53321 m .73106 .53301 L .73124 .53281 L F
.73039 .53374 m .73134 .53473 L .73124 .53281 L F
.73134 .53473 m .73655 .54012 L .73175 .53351 L F
.73134 .53473 m .73175 .53351 L .73124 .53281 L F
.7318 .52666 m .73117 .52762 L .73379 .52718 L .658 .806 .954 r
F
.72722 .47619 m .73119 .52705 L .73056 .52745 L .379 .203 .512 r
F
.726 .47664 m .7302 .52759 L .72932 .52793 L .519 .305 .529 r
F
.72416 .47686 m .72915 .52796 L .72879 .52802 L .638 .394 .533 r
F
.72632 .54787 m .73531 .55751 L .73198 .54715 L .657 .808 .956 r
F
.72241 .47658 m .72416 .47686 L .72746 .52824 L .753 .483 .523 r
F
.72065 .47547 m .72134 .47609 L .7246 .52779 L .947 .644 .431 r
F
.7285 .5305 m .72462 .53663 L .73024 .53591 L .658 .806 .954 r
F
.72756 .52984 m .72462 .53663 L .7285 .5305 L F
.7276 .52875 m .72726 .52964 L .72798 .52887 L F
.72726 .52964 m .72462 .53663 L .72756 .52984 L F
.72726 .52964 m .72756 .52984 L .72798 .52887 L F
.72631 .52817 m .72628 .52832 L .72779 .52826 L F
.72628 .52832 m .72462 .53663 L .7276 .52875 L F
.72628 .52832 m .7276 .52875 L .72779 .52826 L F
.72323 .55336 m .72103 .56427 L .73773 .56216 L .658 .807 .955 r
F
.72632 .54787 m .72407 .55893 L .73531 .55751 L .657 .808 .956 r
F
.7123 .55328 m .72103 .56427 L .72323 .55336 L .658 .807 .955 r
F
.72296 .53661 m .72241 .54769 L .72462 .53663 L .658 .806 .954 r
F
.71915 .53658 m .72231 .54734 L .72296 .53661 L F
.72231 .54734 m .72241 .54769 L .72296 .53661 L F
.72327 .54225 m .72323 .55336 L .72546 .54227 L .658 .807 .955 r
F
.71915 .53658 m .71155 .54761 L .72241 .54769 L .658 .806 .954 r
F
.71996 .54222 m .7227 .55156 L .72327 .54225 L .658 .807 .955 r
F
.7227 .55156 m .72323 .55336 L .72327 .54225 L F
.71996 .54222 m .7123 .55328 L .72323 .55336 L F
.7208 .54782 m .72407 .55893 L .72632 .54787 L .657 .808 .956 r
F
.7266 .53662 m .71996 .54222 L .72546 .54227 L .658 .807 .955 r
F
.72583 .53057 m .71915 .53658 L .72462 .53663 L .658 .806 .954 r
F
.72134 .47609 m .72538 .52804 L .7246 .52779 L .857 .566 .495 r
F
.72134 .47609 m .72241 .47658 L .72568 .52813 L F
.72134 .47609 m .72568 .52813 L .72538 .52804 L F
.72241 .47658 m .72746 .52824 L .72695 .52821 L .753 .483 .523 r
F
.72631 .52817 m .72466 .52858 L .72583 .53057 L .658 .806 .954 r
F
.725 .52809 m .72466 .52858 L .72631 .52817 L F
.72533 .53446 m .71996 .54222 L .7266 .53662 L .658 .807 .955 r
F
.72716 .53382 m .72533 .53446 L .7266 .53662 L F
.72602 .53346 m .72533 .53446 L .72716 .53382 L F
.72466 .52858 m .72334 .5305 L .72583 .53057 L .658 .806 .954 r
F
.72334 .5305 m .71915 .53658 L .72319 .53295 L F
.72334 .5305 m .72319 .53295 L .72583 .53057 L F
.7203 .47474 m .72382 .52715 L .72357 .52672 L .965 .686 .26 r
F
.7203 .47474 m .72065 .47547 L .72392 .52731 L F
.72334 .5305 m .7142 .53577 L .71915 .53658 L .658 .806 .954 r
F
.72466 .52858 m .7234 .52944 L .72334 .5305 L F
.7234 .52944 m .7142 .53577 L .72334 .5305 L F
.72411 .52764 m .71929 .53159 L .72466 .52858 L F
.71929 .53159 m .7142 .53577 L .71818 .53304 L F
.71929 .53159 m .71818 .53304 L .72466 .52858 L F
.7203 .47474 m .72392 .52731 L .72382 .52715 L .965 .686 .26 r
F
.72065 .47547 m .72441 .52766 L .72392 .52731 L .947 .644 .431 r
F
.72065 .47547 m .7246 .52779 L .72441 .52766 L F
.72106 .47282 m .72033 .47389 L .72361 .52599 L .076 0 .438 r
F
.72241 .47658 m .72695 .52821 L .72568 .52813 L .753 .483 .523 r
F
.71929 .53159 m .71009 .53426 L .7142 .53577 L .658 .806 .954 r
F
.72686 .52538 m .72217 .52787 L .71929 .53159 L F
.72217 .52787 m .71009 .53426 L .71929 .53159 L F
.72737 .54268 m .7208 .54782 L .72632 .54787 L .657 .808 .956 r
F
.7278 .53356 m .72701 .53455 L .72857 .5336 L .658 .807 .955 r
F
.72701 .53455 m .72546 .54227 L .72799 .53522 L F
.72701 .53455 m .72799 .53522 L .72857 .5336 L F
.7294 .53619 m .72546 .54227 L .73112 .54155 L F
.7288 .53434 m .72833 .53546 L .7294 .53619 L F
.72833 .53546 m .72546 .54227 L .7294 .53619 L F
.72441 .52766 m .7246 .52779 L .72494 .53311 L .947 .644 .431 r
F
.72835 .53419 m .72546 .54227 L .7288 .53434 L .658 .807 .955 r
F
.726 .54036 m .72387 .54342 L .72737 .54268 L .657 .808 .956 r
F
.72387 .54342 m .7208 .54782 L .72373 .54553 L F
.72387 .54342 m .72373 .54553 L .72737 .54268 L F
.7142 .53577 m .71155 .54761 L .71915 .53658 L .658 .806 .954 r
F
.72533 .53446 m .71497 .54142 L .71996 .54222 L .658 .807 .955 r
F
.72798 .52887 m .72756 .52984 L .7285 .5305 L .658 .806 .954 r
F
.72746 .52824 m .72827 .53348 L .7278 .53356 L .638 .394 .533 r
F
.72686 .52538 m .72411 .52764 L .72466 .52858 L .658 .806 .954 r
F
.72538 .52804 m .72579 .53338 L .7246 .52779 L .857 .566 .495 r
F
.72579 .53338 m .72522 .5332 L .7246 .52779 L F
.72695 .52821 m .72742 .53354 L .72568 .52813 L .753 .483 .523 r
F
.72742 .53354 m .72647 .53348 L .72568 .52813 L F
.72568 .52813 m .72647 .53348 L .72602 .53345 L F
.7246 .52779 m .72522 .5332 L .72494 .53311 L .857 .566 .495 r
F
.72538 .52804 m .72568 .52813 L .72602 .53345 L F
.72602 .53346 m .72473 .53344 L .72533 .53446 L .658 .807 .955 r
F
.72508 .53316 m .72473 .53344 L .72602 .53346 L F
.72666 .5394 m .72579 .54001 L .726 .54036 L .657 .808 .956 r
F
.72696 .53898 m .72586 .53885 L .72666 .5394 L F
.72579 .53338 m .72602 .53345 L .72636 .53879 L .857 .566 .495 r
F
.72579 .53338 m .72636 .53879 L .72621 .53875 L F
.7278 .53356 m .7284 .53678 L .72803 .53709 L .638 .394 .533 r
F
.7284 .53678 m .72877 .53879 L .72803 .53709 L F
.72803 .53709 m .72877 .53879 L .72814 .5389 L F
.72857 .5336 m .72835 .53419 L .7288 .53434 L .658 .807 .955 r
F
.72695 .52821 m .72746 .52824 L .7278 .53356 L .753 .483 .523 r
F
.72695 .52821 m .7278 .53356 L .72755 .53354 L F
.72722 .53353 m .72719 .53366 L .7278 .53356 L .658 .807 .955 r
F
.72719 .53366 m .72701 .53455 L .7278 .53356 L F
.72742 .53354 m .72814 .5389 L .72789 .53888 L .753 .483 .523 r
F
.72695 .52821 m .72755 .53354 L .72742 .53354 L F
.72755 .53354 m .72814 .5389 L .72742 .53354 L F
.72722 .53353 m .72602 .53346 L .72716 .53382 L .658 .807 .955 r
F
.72773 .531 m .72603 .53345 L .72722 .53353 L F
.72603 .53345 m .72602 .53346 L .72722 .53353 L F
.72538 .52804 m .72602 .53345 L .72579 .53338 L .857 .566 .495 r
F
.72773 .531 m .72508 .53316 L .72602 .53345 L .658 .807 .955 r
F
.72603 .53345 m .72602 .53345 L .72602 .53346 L F
.72773 .531 m .72602 .53345 L .72603 .53345 L F
.72755 .53354 m .7278 .53356 L .72814 .5389 L .753 .483 .523 r
F
.72813 .5389 m .72719 .53906 L .72805 .53932 L .657 .808 .956 r
F
.72805 .53932 m .726 .54036 L .72737 .54268 L F
.72696 .53898 m .726 .54036 L .72805 .53932 L F
.72827 .53348 m .72909 .53874 L .7278 .53356 L .638 .394 .533 r
F
.72962 .53982 m .72632 .54787 L .73198 .54715 L .657 .808 .956 r
F
.72911 .53966 m .72632 .54787 L .72962 .53982 L F
.72918 .53896 m .72897 .53962 L .72935 .53897 L F
.72897 .53962 m .72632 .54787 L .72911 .53966 L F
.72897 .53962 m .72911 .53966 L .72935 .53897 L F
.72473 .53344 m .72377 .53423 L .72533 .53446 L .658 .807 .955 r
F
.72377 .53423 m .71497 .54142 L .72369 .53556 L F
.72377 .53423 m .72369 .53556 L .72533 .53446 L F
.72033 .47389 m .72357 .52665 L .72358 .52652 L 0 0 .132 r
F
.72033 .47389 m .7203 .47474 L .72357 .52672 L F
.72033 .47389 m .72357 .52672 L .72357 .52665 L F
.72033 .47389 m .72358 .52652 L .72361 .52599 L F
.72686 .52538 m .71902 .52806 L .71009 .53426 L .658 .806 .954 r
F
.71902 .52806 m .70711 .53214 L .70922 .53364 L F
.71902 .52806 m .70922 .53364 L .71009 .53426 L F
.72243 .472 m .72106 .47282 L .72436 .52503 L .414 .228 .517 r
F
.72441 .52766 m .72494 .53311 L .7248 .53301 L .947 .644 .431 r
F
.72441 .52766 m .7248 .53301 L .72392 .52731 L F
.7248 .53301 m .72443 .53276 L .72392 .52731 L F
.72505 .53319 m .72434 .53278 L .72473 .53344 L .658 .807 .955 r
F
.72392 .52731 m .72443 .53276 L .72425 .53264 L .947 .644 .431 r
F
.72773 .531 m .72441 .53274 L .72505 .53319 L .658 .807 .955 r
F
.72441 .53274 m .72434 .53278 L .72505 .53319 L F
.72377 .53423 m .72094 .53521 L .71812 .53885 L F
.72473 .53344 m .72379 .53388 L .72377 .53423 L F
.72379 .53388 m .72094 .53521 L .72377 .53423 L F
.72357 .52672 m .72418 .53251 L .7239 .53204 L .965 .686 .26 r
F
.71902 .52806 m .70546 .52955 L .70711 .53214 L .658 .806 .954 r
F
.72686 .52538 m .72211 .52631 L .71902 .52806 L F
.72211 .52631 m .70546 .52955 L .71902 .52806 L F
.72522 .5332 m .72583 .53863 L .72494 .53311 L .857 .566 .495 r
F
.72813 .5389 m .72632 .54787 L .72918 .53896 L .657 .808 .956 r
F
.72814 .5389 m .72918 .53896 L .72926 .53871 L F
.72813 .5389 m .72918 .53896 L .72814 .5389 L F
.72605 .53869 m .72586 .53885 L .72696 .53898 L F
.72586 .53885 m .72406 .54031 L .72666 .5394 L F
.71497 .54142 m .7123 .55328 L .71996 .54222 L .658 .807 .955 r
F
.72406 .54031 m .71581 .54702 L .724 .54127 L .657 .808 .956 r
F
.72406 .54031 m .724 .54127 L .72666 .5394 L F
.72434 .53278 m .72176 .53414 L .72473 .53344 L .658 .807 .955 r
F
.7142 .53577 m .70169 .54603 L .71155 .54761 L .658 .806 .954 r
F
.72176 .53414 m .71084 .5399 L .72094 .53521 L .658 .807 .955 r
F
.72176 .53414 m .72094 .53521 L .72473 .53344 L F
.72382 .52715 m .72392 .52731 L .72425 .53264 L .965 .686 .26 r
F
.72382 .52715 m .72425 .53264 L .7242 .53255 L F
.72106 .47282 m .72382 .52573 L .72436 .52503 L .076 0 .438 r
F
.72106 .47282 m .72361 .52599 L .72382 .52573 L F
.71254 .52817 m .70526 .52667 L .70546 .52955 L .658 .806 .954 r
F
.72686 .52538 m .72066 .52575 L .71254 .52817 L F
.72066 .52575 m .70526 .52667 L .71254 .52817 L F
.72373 .47164 m .72243 .472 L .72576 .52423 L .566 .34 .531 r
F
.72636 .53879 m .72881 .54928 L .72701 .54901 L .753 .483 .523 r
F
.72602 .53345 m .72697 .53883 L .72636 .53879 L F
.72706 .53883 m .72636 .53879 L .72696 .53898 L .657 .808 .956 r
F
.72742 .53354 m .72789 .53888 L .72647 .53348 L .753 .483 .523 r
F
.72789 .53888 m .72727 .53885 L .72647 .53348 L F
.72909 .53874 m .72877 .53879 L .7278 .53356 L .638 .394 .533 r
F
.72731 .53885 m .72696 .53898 L .72719 .53906 L .657 .808 .956 r
F
.72647 .53348 m .72727 .53885 L .72602 .53345 L .753 .483 .523 r
F
.72727 .53885 m .72697 .53883 L .72602 .53345 L F
.72859 .53662 m .72706 .53883 L .72731 .53885 L .657 .808 .956 r
F
.72706 .53883 m .72696 .53898 L .72731 .53885 L F
.72859 .53662 m .72719 .53906 L .72813 .5389 L F
.72727 .53885 m .72881 .54928 L .72697 .53883 L .753 .483 .523 r
F
.72697 .53883 m .72881 .54928 L .72636 .53879 L F
.72579 .53338 m .72621 .53875 L .72522 .5332 L .857 .566 .495 r
F
.72621 .53875 m .72583 .53863 L .72522 .5332 L F
.72859 .53662 m .72605 .53869 L .72636 .53879 L .657 .808 .956 r
F
.72859 .53662 m .72636 .53879 L .72706 .53883 L F
.72686 .52538 m .725 .52809 L .72631 .52817 L .658 .806 .954 r
F
.72382 .52715 m .72418 .53251 L .72357 .52672 L .965 .686 .26 r
F
.72434 .53278 m .7173 .53455 L .71084 .5399 L .658 .807 .955 r
F
.72382 .52715 m .7242 .53255 L .72418 .53252 L .965 .686 .26 r
F
.72403 .53226 m .7173 .53455 L .72434 .53278 L .658 .807 .955 r
F
.72418 .53251 m .72455 .53791 L .72454 .5379 L .965 .686 .26 r
F
.72382 .52715 m .72418 .53252 L .72418 .53251 L F
.72418 .53252 m .72455 .53791 L .72418 .53251 L F
.71009 .53426 m .70169 .54603 L .7142 .53577 L .658 .806 .954 r
F
.71009 .53426 m .69348 .54305 L .70169 .54603 L F
.70711 .53214 m .69348 .54305 L .71009 .53426 L F
.72403 .53226 m .70618 .53519 L .70784 .53778 L .658 .807 .955 r
F
.72358 .52652 m .72391 .5319 L .72361 .52599 L 0 0 .132 r
F
.72391 .5319 m .72394 .53151 L .72361 .52599 L F
.72358 .52652 m .7239 .53204 L .72391 .5319 L F
.72357 .52665 m .7239 .53204 L .72358 .52652 L F
.72357 .52665 m .72357 .52672 L .7239 .53204 L F
.72773 .531 m .72374 .53177 L .72403 .53226 L .658 .807 .955 r
F
.72374 .53177 m .70618 .53519 L .72403 .53226 L F
.72773 .531 m .72403 .53226 L .72434 .53278 L F
.7173 .53455 m .70784 .53778 L .70952 .53897 L F
.7173 .53455 m .70952 .53897 L .71084 .5399 L F
.72653 .54481 m .72701 .54901 L .72647 .54484 L .857 .566 .495 r
F
.726 .54036 m .71581 .54702 L .7208 .54782 L .657 .808 .956 r
F
.72579 .54001 m .71672 .54638 L .726 .54036 L F
.71672 .54638 m .71581 .54702 L .71666 .54647 L F
.71672 .54638 m .71666 .54647 L .726 .54036 L F
.70169 .54603 m .70406 .55847 L .71155 .54761 L .658 .806 .954 r
F
.70169 .54603 m .68935 .55615 L .70406 .55847 L F
.71497 .54142 m .70238 .5517 L .7123 .55328 L .658 .807 .955 r
F
.72406 .54031 m .71167 .54551 L .71581 .54702 L .657 .808 .956 r
F
.72586 .53885 m .7241 .53968 L .72406 .54031 L F
.7241 .53968 m .71167 .54551 L .72406 .54031 L F
.72394 .53241 m .72454 .5379 L .72424 .53739 L .965 .686 .26 r
F
.72391 .5319 m .7239 .53204 L .72424 .53739 L 0 0 .132 r
F
.72521 .5384 m .72136 .54043 L .72586 .53885 L .657 .808 .956 r
F
.72136 .54043 m .71167 .54551 L .7207 .54128 L F
.72136 .54043 m .7207 .54128 L .72586 .53885 L F
.72425 .53264 m .72483 .53814 L .72459 .53798 L .947 .644 .431 r
F
.72443 .53276 m .72494 .53822 L .72425 .53264 L F
.72418 .53251 m .72454 .5379 L .7239 .53204 L .965 .686 .26 r
F
.70711 .53214 m .68748 .53885 L .69348 .54305 L .658 .806 .954 r
F
.70546 .52955 m .68748 .53885 L .70711 .53214 L F
.7214 .53223 m .70599 .5323 L .70618 .53519 L .658 .807 .955 r
F
.72773 .531 m .72403 .53122 L .72357 .5318 L F
.72521 .5384 m .72223 .5393 L .72136 .54043 L .657 .808 .956 r
F
.71812 .53885 m .71084 .5399 L .71497 .54142 L .658 .807 .955 r
F
.71084 .5399 m .70238 .5517 L .71497 .54142 L F
.7246 .53798 m .70867 .5434 L .72521 .5384 L .657 .808 .956 r
F
.7248 .53301 m .72518 .53839 L .72443 .53276 L .947 .644 .431 r
F
.72518 .53839 m .72592 .54853 L .72494 .53822 L F
.72518 .53839 m .72494 .53822 L .72443 .53276 L F
.69348 .54305 m .68935 .55615 L .70169 .54603 L .658 .806 .954 r
F
.71084 .5399 m .69412 .54872 L .70238 .5517 L .658 .807 .955 r
F
.70784 .53778 m .69412 .54872 L .71084 .5399 L F
.7246 .53798 m .70702 .54081 L .70867 .5434 L .657 .808 .956 r
F
.72494 .53822 m .72483 .53814 L .72425 .53264 L .947 .644 .431 r
F
.72418 .53252 m .72459 .53798 L .72455 .53791 L .965 .686 .26 r
F
.7242 .53255 m .72459 .53798 L .72418 .53252 L F
.72583 .53863 m .72565 .53857 L .72494 .53311 L .857 .566 .495 r
F
.72494 .53311 m .72565 .53857 L .72528 .53845 L F
.7242 .53255 m .72425 .53264 L .72459 .53798 L .965 .686 .26 r
F
.7248 .53301 m .72494 .53311 L .72528 .53845 L .947 .644 .431 r
F
.7248 .53301 m .72528 .53845 L .72518 .53839 L F
.72859 .53662 m .72394 .53753 L .7246 .53798 L .657 .808 .956 r
F
.72094 .53521 m .71084 .5399 L .71812 .53885 L .658 .807 .955 r
F
.72394 .53753 m .70702 .54081 L .7246 .53798 L .657 .808 .956 r
F
.72308 .53127 m .70728 .52931 L .70599 .5323 L .658 .807 .955 r
F
.72066 .52575 m .70654 .52369 L .70526 .52667 L .658 .806 .954 r
F
.72686 .52538 m .72299 .52506 L .72066 .52575 L F
.72299 .52506 m .70654 .52369 L .72066 .52575 L F
.72243 .472 m .72436 .52503 L .72474 .52481 L .414 .228 .517 r
F
.72686 .52538 m .70922 .52081 L .70654 .52369 L .658 .806 .954 r
F
.72382 .52573 m .7241 .53112 L .72436 .52503 L .076 0 .438 r
F
.72382 .52573 m .72361 .52599 L .72395 .53132 L F
.72382 .52573 m .72395 .53132 L .7241 .53112 L F
.72361 .52599 m .72394 .53151 L .72395 .53132 L 0 0 .132 r
F
.72403 .53122 m .7241 .5307 L .72308 .53127 L .658 .807 .955 r
F
.72773 .531 m .72441 .53072 L .72403 .53122 L F
.7241 .53112 m .7245 .53061 L .72436 .52503 L .076 0 .438 r
F
.72441 .53072 m .7241 .5307 L .72403 .53122 L .658 .807 .955 r
F
.72859 .53662 m .7246 .53798 L .72521 .5384 L .657 .808 .956 r
F
.72859 .53662 m .72521 .5384 L .72586 .53885 L F
.72789 .53888 m .72881 .54928 L .72727 .53885 L .753 .483 .523 r
F
.72789 .53888 m .72814 .5389 L .72881 .54928 L F
.72779 .52826 m .7276 .52875 L .72798 .52887 L .658 .806 .954 r
F
.72776 .52819 m .72841 .53021 L .72932 .52793 L F
.72879 .52802 m .72926 .53331 L .72746 .52824 L .638 .394 .533 r
F
.72851 .53344 m .7278 .53356 L .72857 .5336 L .658 .807 .955 r
F
.72935 .53897 m .72911 .53966 L .72962 .53982 L .657 .808 .956 r
F
.72926 .53871 m .72918 .53896 L .72935 .53897 L F
.72926 .53331 m .72827 .53348 L .72746 .52824 L .638 .394 .533 r
F
.72932 .52793 m .72998 .53313 L .72966 .53325 L .519 .305 .529 r
F
.72984 .53318 m .72907 .53518 L .73039 .53374 L .658 .807 .955 r
F
.72879 .52802 m .72966 .53325 L .72926 .53331 L .638 .394 .533 r
F
.72915 .52796 m .72966 .53325 L .72879 .52802 L F
.72915 .52796 m .72932 .52793 L .72966 .53325 L F
.72773 .531 m .72858 .53366 L .72984 .53318 L .658 .807 .955 r
F
.72858 .53366 m .72907 .53518 L .72984 .53318 L F
.72932 .52793 m .72992 .52856 L .73071 .52769 L .658 .806 .954 r
F
.726 .47664 m .72722 .47619 L .73056 .52745 L .519 .305 .529 r
F
.73105 .53272 m .73088 .53279 L .73124 .53281 L .658 .807 .955 r
F
.73088 .53279 m .72987 .53321 L .7305 .53303 L F
.73088 .53279 m .7305 .53303 L .73124 .53281 L F
.72984 .53318 m .72987 .53321 L .73105 .53272 L F
.726 .47664 m .73056 .52745 L .7302 .52759 L .519 .305 .529 r
F
.72686 .52538 m .72932 .52793 L .7309 .52748 L .658 .806 .954 r
F
.72932 .52793 m .73071 .52769 L .7309 .52748 L F
.73039 .53374 m .73067 .53676 L .73134 .53473 L .658 .807 .955 r
F
.73067 .53676 m .73112 .54155 L .73134 .53473 L F
.73563 .53449 m .74428 .54346 L .75386 .53941 L .658 .806 .954 r
F
.73409 .53429 m .73655 .54012 L .74139 .53807 L .658 .807 .955 r
F
.73187 .53314 m .73654 .54011 L .73409 .53429 L F
.73654 .54011 m .73655 .54012 L .73409 .53429 L F
.73175 .53351 m .73654 .54011 L .73187 .53314 L F
.73117 .52762 m .74044 .53244 L .73379 .52718 L .658 .806 .954 r
F
.72809 .47559 m .73204 .52624 L .73187 .52643 L .157 .044 .463 r
F
.73301 .52589 m .74435 .52991 L .74708 .52707 L .658 .806 .954 r
F
.72722 .47619 m .72809 .47559 L .73145 .52689 L .379 .203 .512 r
F
.72722 .47619 m .73145 .52689 L .73119 .52705 L F
.72686 .52538 m .7318 .52666 L .73301 .52589 L .658 .806 .954 r
F
.7318 .52666 m .73826 .52833 L .73301 .52589 L F
.73175 .53988 m .73198 .54715 L .73706 .54581 L .657 .808 .956 r
F
.73671 .54499 m .73706 .54581 L .73742 .54572 L F
.73175 .53988 m .73706 .54581 L .73671 .54499 L F
.73204 .52624 m .73245 .53138 L .73239 .53156 L 0 0 .297 r
F
.73563 .53449 m .75386 .53941 L .74044 .53244 L .658 .806 .954 r
F
.73331 .53243 m .74139 .53807 L .74532 .53553 L .658 .807 .955 r
F
.73069 .52737 m .73117 .52762 L .7318 .52666 L .658 .806 .954 r
F
.73119 .52705 m .73145 .52689 L .7318 .53221 L .379 .203 .512 r
F
.7318 .53221 m .73409 .53429 L .73198 .53209 L .658 .807 .955 r
F
.73102 .5327 m .73124 .53281 L .7318 .53221 L F
.73124 .53281 m .73409 .53429 L .7318 .53221 L F
.73187 .52643 m .73204 .52624 L .73239 .53156 L .157 .044 .463 r
F
.73198 .53209 m .73409 .53429 L .73331 .53243 L .658 .807 .955 r
F
.73187 .52643 m .73239 .53156 L .73226 .5317 L .157 .044 .463 r
F
.73119 .52705 m .7318 .53221 L .7316 .53233 L .379 .203 .512 r
F
.74044 .53244 m .75386 .53941 L .76167 .5344 L .658 .806 .954 r
F
.74044 .53244 m .76167 .5344 L .74435 .52991 L F
.73288 .53142 m .74532 .53553 L .74807 .53267 L .658 .807 .955 r
F
.7302 .52759 m .73056 .52745 L .7309 .53277 L .519 .305 .529 r
F
.73073 .53284 m .7309 .53277 L .73125 .53811 L F
.7302 .52759 m .7309 .53277 L .73073 .53284 L F
.73064 .53288 m .73125 .53811 L .73107 .53818 L F
.7302 .52759 m .73073 .53284 L .73064 .53288 L F
.73073 .53284 m .73125 .53811 L .73064 .53288 L F
.74435 .52991 m .76167 .5344 L .76718 .52874 L .658 .806 .954 r
F
.73701 .53044 m .74807 .53267 L .74944 .5297 L .658 .807 .955 r
F
.7302 .52759 m .73064 .53288 L .72932 .52793 L .519 .305 .529 r
F
.73064 .53288 m .72998 .53313 L .72932 .52793 L F
.73056 .52745 m .7316 .53233 L .7309 .53277 L .379 .203 .512 r
F
.73119 .52705 m .7316 .53233 L .73056 .52745 L F
.73258 .53098 m .73245 .53138 L .73204 .52624 L 0 0 .297 r
F
.73187 .52643 m .73226 .5317 L .73145 .52689 L .157 .044 .463 r
F
.73226 .5317 m .73195 .53204 L .73145 .52689 L F
.73145 .52689 m .73195 .53204 L .7318 .53221 L F
.72773 .531 m .73417 .53153 L .73466 .53134 L .658 .807 .955 r
F
.72867 .47488 m .73228 .5255 L .73221 .52571 L 0 0 .297 r
F
.7289 .47404 m .73201 .52486 L .73228 .5255 L .925 .667 .181 r
F
.73264 .52504 m .74708 .52707 L .74844 .52409 L .658 .806 .954 r
F
.72686 .52538 m .73428 .526 L .73264 .52504 L F
.73428 .526 m .74708 .52707 L .73264 .52504 L F
.72851 .47294 m .7274 .47208 L .73079 .52395 L .928 .626 .449 r
F
.73221 .52571 m .73258 .53098 L .73204 .52624 L 0 0 .297 r
F
.73221 .52571 m .73228 .5255 L .73263 .53083 L F
.73221 .52571 m .73263 .53083 L .73258 .53098 L F
.73228 .5255 m .73253 .5306 L .73263 .53083 L .925 .667 .181 r
F
.72773 .531 m .7325 .53123 L .73267 .5307 L .658 .807 .955 r
F
.72773 .531 m .7324 .5322 L .73288 .53142 L F
.73221 .53849 m .73654 .54458 L .73445 .53964 L .657 .808 .956 r
F
.73158 .53816 m .7321 .53883 L .73221 .53849 L F
.7321 .53883 m .73654 .54458 L .73221 .53849 L F
.7325 .53123 m .73466 .53134 L .73267 .5307 L .658 .807 .955 r
F
.7324 .5322 m .73331 .53243 L .7331 .53193 L F
.7324 .5322 m .7331 .53193 L .73288 .53142 L F
.73258 .53098 m .73263 .53083 L .73298 .53617 L 0 0 .297 r
F
.73175 .53988 m .73671 .54499 L .73209 .53885 L .657 .808 .956 r
F
.73671 .54499 m .73654 .54458 L .7321 .53883 L F
.73209 .53885 m .7321 .53883 L .73158 .53816 L F
.73671 .54499 m .7321 .53883 L .73209 .53885 L F
.73245 .53138 m .73286 .53653 L .73239 .53156 L 0 0 .297 r
F
.7316 .53233 m .7318 .53221 L .73215 .53755 L .379 .203 .512 r
F
.74428 .54346 m .75279 .5523 L .76711 .5463 L .658 .806 .954 r
F
.74428 .54346 m .76711 .5463 L .75386 .53941 L F
.73655 .54012 m .74524 .54911 L .75488 .54505 L .658 .807 .955 r
F
.73655 .54012 m .75488 .54505 L .74139 .53807 L F
.73397 .53851 m .74227 .54367 L .74453 .54222 L .657 .808 .956 r
F
.72773 .531 m .73102 .5327 L .73198 .53209 L .658 .807 .955 r
F
.73226 .5317 m .73265 .53699 L .73195 .53204 L .157 .044 .463 r
F
.73192 .53779 m .73423 .53912 L .73397 .53851 L .657 .808 .956 r
F
.73191 .53781 m .73423 .53912 L .73192 .53779 L F
.73135 .53805 m .73158 .53816 L .73182 .53776 L F
.73158 .53816 m .74227 .54367 L .73191 .53781 L F
.73158 .53816 m .73191 .53781 L .73182 .53776 L F
.7318 .53221 m .73235 .53733 L .73215 .53755 L .157 .044 .463 r
F
.7316 .53233 m .73215 .53755 L .73202 .53763 L .379 .203 .512 r
F
.73251 .53763 m .74453 .54222 L .73991 .53952 L .657 .808 .956 r
F
.72907 .53518 m .73112 .54155 L .73039 .53374 L .658 .807 .955 r
F
.73064 .53288 m .73107 .53818 L .72998 .53313 L .519 .305 .529 r
F
.73107 .53818 m .73064 .53835 L .72998 .53313 L F
.72926 .53331 m .72974 .53863 L .72827 .53348 L .638 .394 .533 r
F
.72926 .53331 m .72966 .53325 L .73001 .53858 L F
.72931 .53885 m .72944 .53925 L .73026 .53854 L .657 .808 .956 r
F
.72931 .53885 m .73026 .53854 L .73001 .53858 L F
.72944 .53925 m .73198 .54715 L .7304 .53865 L F
.72944 .53925 m .7304 .53865 L .73036 .53845 L F
.72974 .53863 m .73001 .53858 L .73069 .54907 L .638 .394 .533 r
F
.72926 .53331 m .73001 .53858 L .72974 .53863 L F
.73001 .53858 m .73026 .53854 L .73036 .53845 L .657 .808 .956 r
F
.7309 .53277 m .73155 .53792 L .73125 .53811 L .379 .203 .512 r
F
.72974 .53863 m .72909 .53874 L .72827 .53348 L .638 .394 .533 r
F
.73138 .53806 m .73043 .53851 L .73158 .53816 L .657 .808 .956 r
F
.72966 .53325 m .73043 .53842 L .73001 .53858 L .519 .305 .529 r
F
.73036 .53845 m .73043 .53851 L .73138 .53806 L .657 .808 .956 r
F
.73043 .53851 m .73085 .53895 L .7314 .53835 L F
.73043 .53851 m .7314 .53835 L .73158 .53816 L F
.73036 .53845 m .73103 .54204 L .73175 .53988 L F
.73103 .54204 m .73198 .54715 L .73175 .53988 L F
.72998 .53313 m .73064 .53835 L .72966 .53325 L .519 .305 .529 r
F
.73064 .53835 m .73194 .54862 L .73043 .53842 L F
.73064 .53835 m .73043 .53842 L .72966 .53325 L F
.73409 .53429 m .74139 .53807 L .73331 .53243 L .658 .807 .955 r
F
.75386 .53941 m .76711 .5463 L .77884 .53885 L .658 .806 .954 r
F
.75386 .53941 m .77884 .53885 L .76167 .5344 L F
.74139 .53807 m .75488 .54505 L .76275 .54002 L .658 .807 .955 r
F
.74139 .53807 m .76275 .54002 L .74532 .53553 L F
.73399 .53707 m .74621 .54114 L .74896 .53829 L .657 .808 .956 r
F
.73265 .53699 m .73245 .53722 L .73195 .53204 L .157 .044 .463 r
F
.73226 .5317 m .73274 .5369 L .73265 .53699 L F
.73124 .53281 m .73175 .53351 L .73187 .53314 L .658 .807 .955 r
F
.7316 .53233 m .73202 .53763 L .7309 .53277 L .379 .203 .512 r
F
.73201 .53782 m .74453 .54222 L .73251 .53763 L .657 .808 .956 r
F
.73182 .53776 m .73191 .53781 L .73192 .53779 L F
.73175 .53988 m .73209 .53885 L .73158 .53816 L F
.73202 .53763 m .73283 .54804 L .73155 .53792 L .379 .203 .512 r
F
.73202 .53763 m .73155 .53792 L .7309 .53277 L F
.73303 .53699 m .73251 .53763 L .73399 .53707 L .657 .808 .956 r
F
.73195 .53204 m .73245 .53722 L .7318 .53221 L .157 .044 .463 r
F
.72859 .53662 m .73201 .53782 L .73251 .53763 L .657 .808 .956 r
F
.73245 .53722 m .73342 .54734 L .73235 .53733 L .157 .044 .463 r
F
.73245 .53722 m .73235 .53733 L .7318 .53221 L F
.73269 .53696 m .73216 .53754 L .73303 .53699 L .657 .808 .956 r
F
.72859 .53662 m .73215 .53754 L .73269 .53696 L F
.73215 .53754 m .73216 .53754 L .73269 .53696 L F
.73216 .53754 m .73251 .53763 L .73303 .53699 L F
.73251 .53763 m .73991 .53952 L .73399 .53707 L F
.73085 .53895 m .73175 .53988 L .73158 .53816 L F
.73125 .53811 m .73283 .54804 L .73194 .54862 L .379 .203 .512 r
F
.73155 .53792 m .73283 .54804 L .73125 .53811 L F
.73215 .53755 m .73342 .54734 L .73283 .54804 L .157 .044 .463 r
F
.73235 .53733 m .73342 .54734 L .73215 .53755 L F
.73265 .53699 m .73342 .54734 L .73245 .53722 L F
.73202 .53763 m .73215 .53755 L .73283 .54804 L .379 .203 .512 r
F
.73286 .53653 m .73282 .53665 L .73239 .53156 L 0 0 .297 r
F
.73239 .53156 m .73282 .53665 L .73274 .5369 L F
.76167 .5344 m .77884 .53885 L .78717 .53041 L .658 .806 .954 r
F
.74532 .53553 m .76275 .54002 L .76829 .53435 L .658 .807 .955 r
F
.73434 .53628 m .74896 .53829 L .75034 .53532 L .657 .808 .956 r
F
.73295 .53627 m .73286 .53653 L .73245 .53138 L 0 0 .297 r
F
.73292 .53637 m .73596 .53723 L .73434 .53628 L .657 .808 .956 r
F
.73226 .5317 m .73239 .53156 L .73274 .5369 L .157 .044 .463 r
F
.72859 .53662 m .73272 .53696 L .73292 .53637 L .657 .808 .956 r
F
.73272 .53696 m .73596 .53723 L .73292 .53637 L F
.73596 .53723 m .74896 .53829 L .73434 .53628 L F
.73826 .52833 m .74435 .52991 L .73577 .52687 L .658 .806 .954 r
F
.73233 .53012 m .73253 .5306 L .73228 .5255 L .925 .667 .181 r
F
.74708 .52707 m .76718 .52874 L .76998 .52281 L .658 .806 .954 r
F
.74435 .52991 m .76718 .52874 L .74708 .52707 L F
.73249 .53007 m .74944 .5297 L .74934 .52679 L .658 .807 .955 r
F
.72851 .47294 m .7311 .52413 L .7319 .5246 L .928 .626 .449 r
F
.7289 .47404 m .72851 .47294 L .7319 .5246 L .925 .667 .181 r
F
.7289 .47404 m .7319 .5246 L .73201 .52486 L F
.73244 .5243 m .74844 .52409 L .74833 .5212 L .658 .806 .954 r
F
.72686 .52538 m .73522 .52488 L .73244 .5243 L F
.73522 .52488 m .74844 .52409 L .73244 .5243 L F
.73201 .52486 m .73231 .53005 L .73233 .53012 L .925 .667 .181 r
F
.73233 .5301 m .73349 .53065 L .73249 .53007 L .658 .807 .955 r
F
.72773 .531 m .73258 .5307 L .73233 .5301 L F
.73258 .5307 m .73349 .53065 L .73233 .5301 L F
.72859 .53662 m .73036 .53845 L .73138 .53806 L .657 .808 .956 r
F
.73001 .53858 m .73194 .54862 L .73069 .54907 L .519 .305 .529 r
F
.73043 .53842 m .73194 .54862 L .73001 .53858 L F
.73107 .53818 m .73194 .54862 L .73064 .53835 L F
.72859 .53662 m .73135 .53805 L .73182 .53776 L .657 .808 .956 r
F
.73107 .53818 m .73125 .53811 L .73194 .54862 L .519 .305 .529 r
F
.72686 .52538 m .73069 .52737 L .7318 .52666 L .658 .806 .954 r
F
.72773 .531 m .72984 .53318 L .73105 .53272 L .658 .807 .955 r
F
.7274 .47208 m .72993 .52377 L .73079 .52395 L .818 .533 .507 r
F
.72851 .47294 m .73079 .52395 L .7311 .52413 L .928 .626 .449 r
F
.7274 .47208 m .7296 .5237 L .72993 .52377 L .818 .533 .507 r
F
.72992 .52376 m .74676 .51857 L .74382 .51641 L .658 .806 .954 r
F
.72686 .52538 m .73096 .52398 L .72992 .52376 L F
.73096 .52398 m .74676 .51857 L .72992 .52376 L F
.7274 .47208 m .72622 .47169 L .7296 .5237 L .818 .533 .507 r
F
.72622 .47169 m .7287 .52368 L .7296 .5237 L .735 .468 .525 r
F
.72894 .52368 m .74382 .51641 L .7397 .51485 L .658 .806 .954 r
F
.72686 .52538 m .73003 .5237 L .72894 .52368 L F
.73003 .5237 m .74382 .51641 L .72894 .52368 L F
.72974 .53863 m .73069 .54907 L .72909 .53874 L .638 .394 .533 r
F
.72859 .53662 m .72931 .53885 L .73036 .53845 L .657 .808 .956 r
F
.72909 .53874 m .73069 .54907 L .72877 .53879 L .638 .394 .533 r
F
.72877 .53879 m .73069 .54907 L .72814 .5389 L F
.73167 .52374 m .74833 .5212 L .74676 .51857 L .658 .806 .954 r
F
.72686 .52538 m .73493 .52381 L .73167 .52374 L F
.73493 .52381 m .74833 .5212 L .73167 .52374 L F
.72622 .47169 m .725 .47155 L .72836 .52367 L .735 .468 .525 r
F
.72686 .52538 m .72776 .52819 L .72932 .52793 L .658 .806 .954 r
F
.72622 .47169 m .72836 .52367 L .7287 .52368 L .735 .468 .525 r
F
.72686 .52538 m .72907 .52357 L .72801 .52371 L .658 .806 .954 r
F
.72773 .531 m .7278 .53356 L .72851 .53344 L .658 .807 .955 r
F
.72859 .53662 m .72813 .5389 L .72926 .53871 L .657 .808 .956 r
F
.72814 .5389 m .73069 .54907 L .72881 .54928 L .638 .394 .533 r
F
.72686 .52538 m .72631 .52817 L .72779 .52826 L .658 .806 .954 r
F
.72391 .5319 m .72424 .53739 L .72425 .53729 L 0 0 .132 r
F
.72391 .5319 m .72425 .53729 L .72394 .53151 L F
.72425 .53729 m .72426 .53704 L .72394 .53151 L F
.72395 .53132 m .72426 .53704 L .72429 .53666 L F
.72394 .53151 m .72426 .53704 L .72395 .53132 L F
.72859 .53662 m .72278 .53697 L .72069 .53816 L .657 .808 .956 r
F
.72653 .54481 m .72647 .54484 L .72565 .53857 L .857 .566 .495 r
F
.72583 .53863 m .72653 .54481 L .72565 .53857 L F
.72528 .53845 m .72701 .54901 L .72592 .54853 L F
.72565 .53857 m .72701 .54901 L .72528 .53845 L F
.72621 .53875 m .72636 .53879 L .72701 .54901 L F
.72518 .53839 m .72528 .53845 L .72592 .54853 L .947 .644 .431 r
F
.72621 .53875 m .72701 .54901 L .72583 .53863 L .857 .566 .495 r
F
.71901 .53028 m .70997 .52642 L .70728 .52931 L .658 .807 .955 r
F
.72686 .52538 m .72718 .52382 L .7264 .52393 L .658 .806 .954 r
F
.72243 .472 m .72474 .52481 L .72576 .52423 L .414 .228 .517 r
F
.72686 .52538 m .71312 .51823 L .70922 .52081 L .658 .806 .954 r
F
.72686 .52538 m .71797 .51614 L .71312 .51823 L F
.72373 .47164 m .72612 .52412 L .72708 .52384 L .566 .34 .531 r
F
.72373 .47164 m .72576 .52423 L .72612 .52412 L F
.72686 .52538 m .72344 .51468 L .71797 .51614 L .658 .806 .954 r
F
.725 .47155 m .72743 .52379 L .72836 .52367 L .657 .408 .532 r
F
.725 .47155 m .72708 .52384 L .72743 .52379 L F
.72686 .52538 m .7347 .51401 L .72915 .51396 L .658 .806 .954 r
F
.72612 .52412 m .72637 .52948 L .72708 .52384 L .566 .34 .531 r
F
.72436 .52503 m .7245 .53061 L .7247 .53035 L .076 0 .438 r
F
.72474 .52481 m .72436 .52503 L .7247 .53035 L .414 .228 .517 r
F
.72474 .52481 m .7247 .53035 L .72489 .53025 L F
.7241 .5307 m .72427 .5301 L .72268 .53058 L .658 .807 .955 r
F
.72773 .531 m .72487 .53026 L .7241 .5307 L F
.72487 .53026 m .72427 .5301 L .7241 .5307 L F
.72474 .52481 m .72498 .53019 L .72576 .52423 L .414 .228 .517 r
F
.72278 .53697 m .72237 .53612 L .71864 .53722 L .657 .808 .956 r
F
.7241 .53112 m .72395 .53132 L .72429 .53666 L .076 0 .438 r
F
.7241 .53112 m .72429 .53666 L .72438 .53654 L F
.7241 .53112 m .72438 .53654 L .7245 .53061 L F
.72438 .53654 m .72464 .53621 L .7245 .53061 L F
.72859 .53662 m .72406 .53625 L .72278 .53697 L .657 .808 .956 r
F
.72406 .53625 m .72237 .53612 L .72278 .53697 L F
.72498 .53019 m .72573 .52977 L .72576 .52423 L .414 .228 .517 r
F
.72474 .52481 m .72489 .53025 L .72498 .53019 L F
.72427 .5301 m .7139 .52384 L .70997 .52642 L .658 .807 .955 r
F
.72773 .531 m .72537 .52978 L .72427 .5301 L F
.72537 .52978 m .7139 .52384 L .72427 .5301 L F
.72612 .52412 m .72576 .52423 L .7261 .52956 L .566 .34 .531 r
F
.72612 .52412 m .7261 .52956 L .72637 .52948 L F
.72576 .52423 m .72573 .52977 L .7261 .52956 L .414 .228 .517 r
F
.72773 .531 m .71878 .52174 L .7139 .52384 L .658 .807 .955 r
F
.72637 .52948 m .72707 .52927 L .72708 .52384 L .566 .34 .531 r
F
.72708 .52384 m .72707 .52927 L .72742 .52917 L F
.72773 .531 m .72429 .52027 L .71878 .52174 L .658 .807 .955 r
F
.72308 .53127 m .70599 .5323 L .7214 .53223 L F
.72237 .53612 m .71082 .53207 L .70812 .53495 L .657 .808 .956 r
F
.7247 .53035 m .72464 .53621 L .72503 .5357 L .076 0 .438 r
F
.7245 .53061 m .72464 .53621 L .7247 .53035 L F
.72573 .52977 m .7257 .53533 L .7261 .52956 L .414 .228 .517 r
F
.72859 .53662 m .72502 .53571 L .72406 .53625 L .657 .808 .956 r
F
.7257 .53533 m .72594 .53519 L .7261 .52956 L .414 .228 .517 r
F
.72498 .53019 m .72522 .5356 L .72573 .52977 L F
.72522 .5356 m .7257 .53533 L .72573 .52977 L F
.7241 .5307 m .70728 .52931 L .72308 .53127 L .658 .807 .955 r
F
.72433 .53553 m .71475 .52949 L .71082 .53207 L .657 .808 .956 r
F
.72498 .53019 m .72503 .5357 L .72522 .5356 L .414 .228 .517 r
F
.72489 .53025 m .72503 .5357 L .72498 .53019 L F
.72489 .53025 m .7247 .53035 L .72503 .5357 L F
.72859 .53662 m .72569 .53513 L .72433 .53553 L .657 .808 .956 r
F
.72569 .53513 m .71475 .52949 L .72433 .53553 L F
.72637 .52948 m .72661 .53486 L .72707 .52927 L .566 .34 .531 r
F
.72661 .53486 m .72706 .53472 L .72707 .52927 L F
.72637 .52948 m .7261 .52956 L .72644 .53491 L F
.72637 .52948 m .72644 .53491 L .72661 .53486 L F
.72268 .53058 m .72293 .52976 L .71901 .53028 L .658 .807 .955 r
F
.72427 .5301 m .72293 .52976 L .72268 .53058 L F
.72293 .52976 m .70997 .52642 L .71901 .53028 L F
.72357 .5318 m .72308 .53127 L .7214 .53223 L F
.72516 .53486 m .71964 .5274 L .71475 .52949 L .657 .808 .956 r
F
.7261 .52956 m .72594 .53519 L .72644 .53491 L .414 .228 .517 r
F
.72859 .53662 m .72668 .53466 L .72516 .53486 L .657 .808 .956 r
F
.72403 .53122 m .72308 .53127 L .72357 .5318 L .658 .807 .955 r
F
.72668 .53466 m .71964 .5274 L .72516 .53486 L .657 .808 .956 r
F
.72773 .531 m .72722 .53353 L .7278 .53356 L .658 .807 .955 r
F
.72743 .52379 m .72708 .52384 L .72742 .52917 L .657 .408 .532 r
F
.72743 .52379 m .72742 .52917 L .72768 .52913 L F
.72836 .52367 m .72836 .52904 L .7287 .529 L F
.72773 .531 m .72811 .52908 L .72715 .5292 L .658 .807 .955 r
F
.72743 .52379 m .72768 .52913 L .72836 .52367 L .657 .408 .532 r
F
.72773 .531 m .7291 .52901 L .72811 .52908 L .658 .807 .955 r
F
.7291 .52901 m .7287 .529 L .72811 .52908 L F
.7287 .52368 m .72895 .529 L .7296 .5237 L .735 .468 .525 r
F
.72895 .529 m .72962 .52902 L .7296 .5237 L F
.7296 .5237 m .72962 .52902 L .72994 .52902 L F
.72993 .52377 m .7296 .5237 L .72994 .52902 L .818 .533 .507 r
F
.72773 .531 m .73014 .52903 L .7291 .52901 L .658 .807 .955 r
F
.72993 .52377 m .72994 .52902 L .73019 .52908 L .818 .533 .507 r
F
.73079 .52395 m .73083 .52921 L .73114 .52927 L F
.72773 .531 m .73103 .52925 L .7301 .52906 L .658 .807 .955 r
F
.72993 .52377 m .73019 .52908 L .73079 .52395 L .818 .533 .507 r
F
.7311 .52413 m .73079 .52395 L .73114 .52927 L .928 .626 .449 r
F
.7311 .52413 m .73114 .52927 L .73129 .52937 L F
.7311 .52413 m .73129 .52937 L .73137 .52941 L F
.7319 .5246 m .73196 .52976 L .73225 .52993 L F
.73201 .52486 m .7319 .5246 L .73225 .52993 L .925 .667 .181 r
F
.73201 .52486 m .73225 .52993 L .73231 .53005 L F
.72773 .531 m .73174 .52963 L .73107 .52923 L .658 .807 .955 r
F
.7311 .52413 m .73137 .52941 L .7319 .5246 L .928 .626 .449 r
F
.73137 .52941 m .73196 .52976 L .7319 .5246 L F
.73826 .52833 m .73577 .52687 L .73301 .52589 L .658 .806 .954 r
F
.73201 .52486 m .73233 .53012 L .73228 .5255 L .925 .667 .181 r
F
.74708 .52707 m .76998 .52281 L .74844 .52409 L .658 .806 .954 r
F
.72773 .531 m .74934 .52679 L .74776 .52416 L .658 .807 .955 r
F
.73331 .53243 m .74532 .53553 L .73288 .53142 L F
.76167 .5344 m .78717 .53041 L .76718 .52874 L .658 .806 .954 r
F
.76718 .52874 m .78717 .53041 L .7915 .52152 L F
.74807 .53267 m .76829 .53435 L .77112 .5284 L .658 .807 .955 r
F
.74532 .53553 m .76829 .53435 L .74807 .53267 L F
.73334 .5357 m .75034 .53532 L .75024 .53242 L .657 .808 .956 r
F
.73274 .53324 m .73295 .53627 L .73281 .53491 L 0 0 .297 r
F
.73274 .53324 m .73281 .53491 L .73245 .53138 L F
.73258 .53098 m .73274 .53324 L .73245 .53138 L F
.73279 .53571 m .73285 .53586 L .73263 .53083 L .925 .667 .181 r
F
.73258 .53098 m .73298 .53617 L .73295 .53627 L 0 0 .297 r
F
.73263 .53083 m .73285 .53586 L .73298 .53617 L .925 .667 .181 r
F
.72859 .53662 m .73434 .53628 L .73334 .5357 L .657 .808 .956 r
F
.73434 .53628 m .75034 .53532 L .73334 .5357 L F
.73137 .52941 m .73164 .53471 L .73196 .52976 L .928 .626 .449 r
F
.73164 .53471 m .73202 .53493 L .73196 .52976 L F
.73174 .52963 m .74776 .52416 L .73107 .52923 L .658 .807 .955 r
F
.73137 .52941 m .73149 .53462 L .73164 .53471 L .928 .626 .449 r
F
.73129 .52937 m .73149 .53462 L .73137 .52941 L F
.73196 .52976 m .73202 .53493 L .73225 .52993 L F
.73202 .53493 m .73221 .53504 L .73225 .52993 L F
.72859 .53662 m .73215 .53476 L .73114 .53455 L .657 .808 .956 r
F
.73349 .53065 m .74944 .5297 L .73249 .53007 L .658 .807 .955 r
F
.73225 .52993 m .73221 .53504 L .7326 .53527 L .928 .626 .449 r
F
.73253 .5306 m .73279 .53571 L .73263 .53083 L .925 .667 .181 r
F
.73417 .53153 m .74807 .53267 L .73701 .53044 L .658 .807 .955 r
F
.73233 .53012 m .7326 .53527 L .73266 .53539 L .925 .667 .181 r
F
.73231 .53005 m .7326 .53527 L .73233 .53012 L F
.73233 .53012 m .73266 .53539 L .73253 .5306 L F
.73266 .53539 m .73279 .53571 L .73253 .5306 L F
.73231 .53005 m .73225 .52993 L .7326 .53527 L F
.73215 .53476 m .74865 .5298 L .74569 .52764 L .657 .808 .956 r
F
.72859 .53662 m .73335 .53501 L .73215 .53476 L F
.73335 .53501 m .74865 .5298 L .73215 .53476 L F
.73083 .52921 m .73086 .53449 L .73114 .52927 L .818 .533 .507 r
F
.73086 .53449 m .73106 .53453 L .73114 .52927 L F
.73114 .52927 m .73106 .53453 L .73149 .53462 L F
.73019 .52908 m .73045 .5344 L .73083 .52921 L F
.73045 .5344 m .73086 .53449 L .73083 .52921 L F
.73107 .52923 m .74776 .52416 L .7448 .52199 L .658 .807 .955 r
F
.73019 .52908 m .73083 .52921 L .73079 .52395 L .818 .533 .507 r
F
.7301 .52906 m .7448 .52199 L .74066 .52043 L .658 .807 .955 r
F
.73103 .52925 m .7448 .52199 L .7301 .52906 L F
.73019 .52908 m .72994 .52902 L .73029 .53437 L .818 .533 .507 r
F
.73019 .52908 m .73029 .53437 L .73045 .5344 L F
.72859 .53662 m .73114 .53455 L .73029 .53437 L .657 .808 .956 r
F
.76718 .52874 m .7915 .52152 L .76998 .52281 L .658 .806 .954 r
F
.74807 .53267 m .77112 .5284 L .74944 .5297 L .658 .807 .955 r
F
.73494 .53447 m .75024 .53242 L .74865 .5298 L .657 .808 .956 r
F
.72859 .53662 m .73926 .53455 L .73494 .53447 L F
.73926 .53455 m .75024 .53242 L .73494 .53447 L F
.72962 .52902 m .72964 .53436 L .72994 .52902 L .735 .468 .525 r
F
.72859 .53662 m .73029 .53437 L .73016 .53437 L .657 .808 .956 r
F
.72921 .53435 m .72964 .53436 L .72962 .52902 L .735 .468 .525 r
F
.72859 .53662 m .73016 .53437 L .72906 .53435 L .657 .808 .956 r
F
.72895 .529 m .7287 .529 L .72905 .53434 L .735 .468 .525 r
F
.72921 .53435 m .72905 .53434 L .72967 .54407 L F
.72895 .529 m .72905 .53434 L .72921 .53435 L F
.72895 .529 m .72921 .53435 L .72962 .52902 L F
.73014 .52903 m .73038 .52883 L .72927 .52888 L .658 .807 .955 r
F
.73038 .52883 m .74066 .52043 L .7298 .52849 L F
.73038 .52883 m .7298 .52849 L .72927 .52888 L F
.72994 .52902 m .72927 .52888 L .7291 .52901 L F
.73014 .52903 m .72927 .52888 L .72994 .52902 L F
.7292 .52887 m .74066 .52043 L .73562 .5196 L F
.7291 .52901 m .72927 .52888 L .7292 .52887 L F
.72927 .52888 m .74066 .52043 L .7292 .52887 L F
.7287 .52368 m .72836 .52367 L .7287 .529 L .735 .468 .525 r
F
.7287 .52368 m .7287 .529 L .72895 .529 L F
.72768 .52913 m .72836 .52904 L .72836 .52367 L .657 .408 .532 r
F
.72801 .52371 m .7397 .51485 L .7347 .51401 L .658 .806 .954 r
F
.72907 .52357 m .7397 .51485 L .72801 .52371 L F
.72813 .52899 m .73562 .5196 L .73003 .51954 L .658 .807 .955 r
F
.72811 .52908 m .72818 .52899 L .72813 .52899 L F
.72818 .52899 m .73562 .5196 L .72813 .52899 L F
.7291 .52901 m .72915 .52894 L .7287 .529 L F
.72768 .52913 m .72793 .53449 L .72836 .52904 L .657 .408 .532 r
F
.72859 .53662 m .72905 .53434 L .72791 .53449 L .657 .808 .956 r
F
.72768 .52913 m .72742 .52917 L .72776 .53451 L .657 .408 .532 r
F
.72768 .52913 m .72776 .53451 L .72793 .53449 L F
.72707 .52927 m .72706 .53472 L .72742 .52917 L .566 .34 .531 r
F
.72706 .53472 m .72729 .53465 L .72742 .52917 L F
.72742 .52917 m .72729 .53465 L .72776 .53451 L F
.72859 .53662 m .72515 .52593 L .71964 .5274 L .657 .808 .956 r
F
.72793 .53449 m .72838 .54416 L .72837 .53443 L .657 .408 .532 r
F
.72793 .53449 m .72837 .53443 L .72836 .52904 L F
.72859 .53662 m .72906 .53435 L .72905 .53434 L .657 .808 .956 r
F
.72791 .53449 m .72905 .53434 L .72785 .53432 L F
.72915 .52894 m .73562 .5196 L .72811 .52908 L .658 .807 .955 r
F
.725 .47155 m .72373 .47164 L .72708 .52384 L .657 .408 .532 r
F
.7264 .52393 m .72915 .51396 L .72344 .51468 L .658 .806 .954 r
F
.72718 .52382 m .72915 .51396 L .7264 .52393 L F
.72715 .5292 m .73003 .51954 L .72429 .52027 L .658 .807 .955 r
F
.72811 .52908 m .73003 .51954 L .72715 .5292 L F
.7287 .529 m .72837 .53443 L .72905 .53434 L .657 .408 .532 r
F
.72836 .52904 m .72837 .53443 L .7287 .529 L F
.72785 .53432 m .73091 .5252 L .72515 .52593 L .657 .808 .956 r
F
.72964 .53436 m .72985 .53436 L .72994 .52902 L .735 .468 .525 r
F
.72994 .52902 m .72985 .53436 L .73029 .53437 L F
.72906 .53435 m .73091 .5252 L .72785 .53432 L .657 .808 .956 r
F
.72906 .53435 m .73018 .53435 L .7291 .53412 L F
.73016 .53437 m .73018 .53435 L .72906 .53435 L F
.72921 .53435 m .72967 .54407 L .72964 .53436 L .735 .468 .525 r
F
.72964 .53436 m .72967 .54407 L .72985 .53436 L F
.73029 .53437 m .72967 .54407 L .73093 .5442 L F
.72985 .53436 m .72967 .54407 L .73029 .53437 L F
.73016 .53437 m .73029 .53437 L .73018 .53435 L .657 .808 .956 r
F
.73129 .52937 m .73114 .52927 L .73149 .53462 L .928 .626 .449 r
F
.73267 .5307 m .73466 .53134 L .73349 .53065 L .658 .807 .955 r
F
.73349 .53065 m .73466 .53134 L .73701 .53044 L F
.73018 .53435 m .74155 .52609 L .7365 .52525 L .657 .808 .956 r
F
.73114 .53455 m .74155 .52609 L .73018 .53435 L F
.73045 .5344 m .73029 .53437 L .73093 .5442 L .818 .533 .507 r
F
.73086 .53449 m .73093 .5442 L .73106 .53453 L F
.73149 .53462 m .73093 .5442 L .73214 .54459 L F
.73106 .53453 m .73093 .5442 L .73149 .53462 L F
.7291 .53412 m .7365 .52525 L .73091 .5252 L .657 .808 .956 r
F
.73018 .53435 m .7365 .52525 L .7291 .53412 L F
.73114 .53455 m .74569 .52764 L .74155 .52609 L F
.73215 .53476 m .74569 .52764 L .73114 .53455 L F
.73045 .5344 m .73093 .5442 L .73086 .53449 L .818 .533 .507 r
F
.73164 .53471 m .73214 .54459 L .73202 .53493 L .928 .626 .449 r
F
.72793 .53449 m .72776 .53451 L .72838 .54416 L .657 .408 .532 r
F
.72661 .53486 m .72705 .54451 L .72706 .53472 L .566 .34 .531 r
F
.7257 .53533 m .72564 .54532 L .72594 .53519 L .414 .228 .517 r
F
.72406 .53625 m .72433 .53553 L .72237 .53612 L .657 .808 .956 r
F
.72502 .53571 m .72433 .53553 L .72406 .53625 L F
.72433 .53553 m .71082 .53207 L .72237 .53612 L F
.72661 .53486 m .72644 .53491 L .72705 .54451 L .566 .34 .531 r
F
.72522 .5356 m .72564 .54532 L .7257 .53533 L .414 .228 .517 r
F
.72706 .53472 m .72705 .54451 L .72729 .53465 L .566 .34 .531 r
F
.69348 .54305 m .67705 .55174 L .68935 .55615 L .658 .806 .954 r
F
.68748 .53885 m .67705 .55174 L .69348 .54305 L F
.70784 .53778 m .68809 .54452 L .69412 .54872 L .658 .807 .955 r
F
.70618 .53519 m .68809 .54452 L .70784 .53778 L F
.71864 .53722 m .7182 .53577 L .70682 .53793 L .657 .808 .956 r
F
.72237 .53612 m .7182 .53577 L .71864 .53722 L F
.7182 .53577 m .70812 .53495 L .70712 .53723 L F
.7182 .53577 m .70712 .53723 L .70682 .53793 L F
.72905 .53434 m .72838 .54416 L .72967 .54407 L .657 .408 .532 r
F
.72837 .53443 m .72838 .54416 L .72905 .53434 L F
.72644 .53491 m .72564 .54532 L .72705 .54451 L .414 .228 .517 r
F
.72594 .53519 m .72564 .54532 L .72644 .53491 L F
.72069 .53816 m .71864 .53722 L .70702 .54081 L .657 .808 .956 r
F
.72278 .53697 m .71864 .53722 L .72069 .53816 L F
.71864 .53722 m .70682 .53793 L .70701 .54067 L F
.71864 .53722 m .70701 .54067 L .70702 .54081 L F
.72776 .53451 m .72705 .54451 L .72838 .54416 L .566 .34 .531 r
F
.72729 .53465 m .72705 .54451 L .72776 .53451 L F
.73202 .53493 m .73214 .54459 L .73221 .53504 L .928 .626 .449 r
F
.73265 .53699 m .73274 .5369 L .73342 .54734 L .157 .044 .463 r
F
.7326 .53527 m .73214 .54459 L .73327 .54544 L .928 .626 .449 r
F
.73221 .53504 m .73214 .54459 L .7326 .53527 L F
.73991 .53952 m .74621 .54114 L .73796 .53839 L .657 .808 .956 r
F
.73991 .53952 m .73796 .53839 L .73399 .53707 L F
.73423 .53912 m .74227 .54367 L .73397 .53851 L F
.73286 .53653 m .73366 .54651 L .73282 .53665 L 0 0 .297 r
F
.73274 .5369 m .73366 .54651 L .73342 .54734 L F
.73282 .53665 m .73366 .54651 L .73274 .5369 L F
.73279 .53571 m .73327 .54544 L .73285 .53586 L .925 .667 .181 r
F
.73991 .53952 m .74453 .54222 L .74621 .54114 L .657 .808 .956 r
F
.73164 .53471 m .73149 .53462 L .73214 .54459 L .928 .626 .449 r
F
.73671 .54499 m .73742 .54572 L .73654 .54458 L .657 .808 .956 r
F
.73295 .53627 m .73298 .53617 L .73366 .54651 L 0 0 .297 r
F
.73295 .53627 m .73366 .54651 L .73286 .53653 L F
.73298 .53617 m .73327 .54544 L .73366 .54651 L .925 .667 .181 r
F
.73285 .53586 m .73327 .54544 L .73298 .53617 L F
.73266 .53539 m .73327 .54544 L .73279 .53571 L F
.73445 .53964 m .73742 .54572 L .74227 .54367 L .657 .808 .956 r
F
.73654 .54458 m .73742 .54572 L .73445 .53964 L F
.73266 .53539 m .7326 .53527 L .73327 .54544 L .925 .667 .181 r
F
.72424 .53739 m .72522 .54792 L .72486 .54721 L .965 .686 .26 r
F
.72467 .54202 m .72452 .54044 L .7249 .54637 L .076 0 .438 r
F
.72454 .5379 m .72522 .54792 L .72424 .53739 L .965 .686 .26 r
F
.72438 .53654 m .72452 .54044 L .72467 .54202 L .076 0 .438 r
F
.72438 .53654 m .72429 .53666 L .72452 .54044 L F
.72136 .54043 m .71457 .54162 L .71167 .54551 L .657 .808 .956 r
F
.72223 .5393 m .71457 .54162 L .72136 .54043 L F
.71457 .54162 m .70867 .5434 L .7099 .54426 L F
.71457 .54162 m .7099 .54426 L .71167 .54551 L F
.72522 .5356 m .72503 .5357 L .72564 .54532 L .414 .228 .517 r
F
.72494 .53822 m .72592 .54853 L .72483 .53814 L .947 .644 .431 r
F
.72459 .53798 m .72592 .54853 L .72522 .54792 L F
.72483 .53814 m .72592 .54853 L .72459 .53798 L F
.72455 .53791 m .72459 .53798 L .7251 .54608 L .965 .686 .26 r
F
.72454 .5379 m .7251 .54608 L .72509 .54609 L F
.72455 .53791 m .7251 .54608 L .72454 .5379 L F
.72438 .53654 m .7249 .54637 L .72464 .53621 L .076 0 .438 r
F
.72425 .53729 m .72424 .53739 L .72486 .54721 L 0 0 .132 r
F
.72503 .5357 m .7249 .54637 L .72564 .54532 L .076 0 .438 r
F
.72464 .53621 m .7249 .54637 L .72503 .5357 L F
.72425 .53729 m .72486 .54721 L .72426 .53704 L 0 0 .132 r
F
.72429 .53666 m .72486 .54721 L .7249 .54637 L F
.72426 .53704 m .72486 .54721 L .72429 .53666 L F
.72509 .54609 m .7251 .54608 L .72522 .54792 L .965 .686 .26 r
F
.74754 .42883 m .76607 .41376 L .7437 .4256 L .656 .78 .94 r
F
.74754 .42883 m .77369 .42029 L .76607 .41376 L F
.50228 .58022 m .48741 .57354 L .47702 .58084 L .658 .806 .954 r
F
.51127 .57627 m .48741 .57354 L .50228 .58022 L F
.45801 .4287 m .47152 .41172 L .47178 .41838 L .347 .192 .524 r
F
.45825 .43536 m .45801 .4287 L .47178 .41838 L F
.43776 .41767 m .45801 .4287 L .47178 .41838 L .657 .779 .939 r
F
.4259 .42308 m .45801 .4287 L .43776 .41767 L F
0 g
.44742 .43348 m
.45801 .4287 L
s
.48741 .57354 m .47653 .57529 L .47702 .58084 L .377 .232 .554 r
F
.48741 .57354 m .48691 .56797 L .47653 .57529 L F
0 g
.47 .5834 m
.47653 .57529 L
s
.66943 .44353 m .63784 .45241 L .66628 .4518 L .655 .782 .942 r
F
.69634 .44707 m .66943 .44353 L .66628 .4518 L F
.80233 .81555 m .79793 .8132 L .79843 .81606 L .671 .443 .567 r
F
.80233 .81555 m .80182 .81269 L .79793 .8132 L F
0 g
.79418 .81414 m
.79793 .8132 L
s
.3185 .8214 m
.32205 .82046 L
s
.80609 .81552 m .80182 .81269 L .80233 .81555 L .731 .483 .554 r
F
0 g
.79793 .8132 m
.80182 .81269 L
s
.80182 .81269 m
.80558 .81266 L
s
.50968 .7045 m .52021 .70238 L .51991 .70711 L .794 .551 .57 r
F
.50968 .7045 m .50999 .69975 L .52021 .70238 L F
.51742 .69434 m .52021 .70238 L .52426 .69611 L .597 .767 .96 r
F
.51742 .69434 m .50999 .69975 L .52021 .70238 L F
0 g
.52021 .70238 m
.52278 .70269 L
s
.54207 .70843 m .54234 .70369 L .5528 .7023 L .597 .381 .558 r
F
0 g
.53977 .7037 m
.54234 .70369 L
s
.27908 .56628 m .30385 .56235 L .28274 .56079 L .661 .803 .951 r
F
.62662 .27499 m .62438 .29831 L .643 .2977 L .644 .736 .916 r
F
.61735 .2737 m .62438 .29831 L .62662 .27499 L F
.61735 .2737 m .60606 .29577 L .62438 .29831 L F
0 g
.32592 .81995 m
.32983 .81991 L
s
.69915 .43648 m .66881 .43683 L .69567 .44039 L .655 .781 .941 r
F
.2295 .43472 m .21982 .41934 L .19972 .42462 L .657 .779 .938 r
F
.24413 .43333 m .21982 .41934 L .2295 .43472 L F
.79894 .81893 m .79468 .817 L .79518 .81987 L .608 .401 .575 r
F
.79894 .81893 m .79843 .81606 L .79468 .817 L F
0 g
.79132 .81832 m
.79468 .817 L
s
.22241 .56979 m .21224 .58035 L .22622 .57182 L .661 .804 .952 r
F
.22241 .56979 m .2046 .57632 L .21224 .58035 L F
.21585 .44472 m .19924 .43112 L .18256 .43917 L .657 .779 .939 r
F
.22923 .44124 m .19924 .43112 L .21585 .44472 L F
0 g
.79182 .82119 m
.79518 .81987 L
s
.50124 .69602 m .51029 .69502 L .50999 .69975 L .857 .609 .563 r
F
.50124 .69602 m .50155 .69128 L .51029 .69502 L F
0 g
.51029 .69502 m
.51487 .6962 L
s
.19933 .57137 m .18691 .58281 L .2046 .57632 L .661 .804 .952 r
F
.19933 .57137 m .17891 .57543 L .18691 .58281 L F
0 g
.18691 .58281 m
.1984 .58879 L
s
.32205 .82046 m
.32592 .81995 L
s
.5528 .7023 m .55305 .69757 L .56219 .69489 L .503 .303 .542 r
F
0 g
.54839 .69819 m
.55305 .69757 L
s
.8066 .81838 m .80609 .81552 L .80233 .81555 L .731 .483 .554 r
F
.80998 .81882 m .80609 .81552 L .8066 .81838 L .794 .526 .532 r
F
0 g
.80609 .81552 m
.80947 .81596 L
s
.80998 .81882 m
.81274 .81971 L
s
.66943 .44353 m .64235 .43996 L .63784 .45241 L .655 .782 .942 r
F
0 g
.63784 .45241 m
.63918 .46453 L
s
.32211 .42144 m .33658 .42455 L .3366 .43121 L .926 .656 .509 r
F
.32211 .42144 m .32211 .41475 L .33658 .42455 L F
0 g
.33658 .42455 m
.34322 .4272 L
s
.24413 .43333 m .24199 .41722 L .21982 .41934 L .657 .779 .938 r
F
.51084 .57081 m .50059 .56211 L .48713 .56807 L .659 .806 .953 r
F
.5212 .56804 m .50059 .56211 L .51084 .57081 L F
.34679 .40595 m .33687 .42438 L .35635 .41254 L .658 .778 .938 r
F
.34679 .40595 m .32248 .41462 L .33687 .42438 L F
.39963 .40784 m .39847 .42107 L .41189 .41979 L F
.39991 .40464 m .41189 .41979 L .40409 .40424 L F
.39667 .40495 m .39963 .40784 L .39991 .40464 L F
.39963 .40784 m .41189 .41979 L .39991 .40464 L F
.4026 .35648 m .40267 .35557 L .4013 .38884 L 0 0 .006 r
F
.39667 .40495 m .39719 .42119 L .39847 .42107 L .658 .778 .938 r
F
.39667 .40495 m .39847 .42107 L .39963 .40784 L F
.3892 .40454 m .39719 .42119 L .39707 .41738 L F
.39508 .40486 m .39707 .41738 L .39667 .40495 L F
.3892 .40454 m .39707 .41738 L .39508 .40486 L F
.39405 .35542 m .39417 .35633 L .39269 .38981 L .875 .7 .179 r
F
.3892 .40454 m .3824 .4204 L .39719 .42119 L .658 .778 .938 r
F
.38928 .41131 m .39732 .428 L .39728 .42666 L .657 .779 .939 r
F
.39488 .41162 m .39728 .42666 L .3968 .41172 L F
.38928 .41131 m .39728 .42666 L .39488 .41162 L F
.38928 .41131 m .38244 .42721 L .39732 .428 L F
.3894 .41803 m .39745 .43468 L .39693 .41844 L .656 .78 .939 r
F
.3894 .41803 m .38254 .43389 L .39745 .43468 L F
.39546 .35777 m .39662 .3583 L .39519 .39148 L .849 .569 .514 r
F
.39417 .35633 m .39466 .35711 L .39319 .39049 L .989 .724 .411 r
F
.39634 .39479 m .3892 .40454 L .39667 .40495 L .658 .778 .938 r
F
.39559 .39377 m .3892 .40454 L .39634 .39479 L F
.39595 .3924 m .39536 .39346 L .39627 .39262 L F
.39536 .39346 m .3892 .40454 L .39559 .39377 L F
.39536 .39346 m .39559 .39377 L .39627 .39262 L F
.39621 .39186 m .39592 .39238 L .39625 .39187 L F
.39592 .39238 m .3892 .40454 L .39595 .3924 L F
.39592 .39238 m .39595 .3924 L .39625 .39187 L F
.39455 .39204 m .3892 .40454 L .39621 .39186 L F
.3961 .39182 m .39621 .39186 L .39624 .3918 L F
.39455 .39204 m .39621 .39186 L .3961 .39182 L F
.39546 .35777 m .39457 .39126 L .394 .39105 L .849 .569 .514 r
F
.39466 .35711 m .39546 .35777 L .394 .39105 L .929 .648 .486 r
F
.39466 .35711 m .394 .39105 L .39358 .39076 L F
.39546 .35777 m .39519 .39148 L .39457 .39126 L .849 .569 .514 r
F
.39405 .35542 m .39262 .38939 L .39256 .389 L .875 .7 .179 r
F
.39417 .35633 m .39293 .39014 L .39269 .38981 L .989 .724 .411 r
F
.39417 .35633 m .39319 .39049 L .39293 .39014 L F
.39405 .35542 m .39269 .38981 L .39262 .38939 L .875 .7 .179 r
F
.39458 .35426 m .39405 .35542 L .39256 .389 L 0 0 .269 r
F
.39345 .39461 m .38744 .39911 L .3892 .40454 L .658 .778 .938 r
F
.39298 .39167 m .38918 .39568 L .39345 .39461 L F
.38918 .39568 m .38219 .40303 L .38744 .39911 L F
.38918 .39568 m .38744 .39911 L .39345 .39461 L F
.39466 .35711 m .39358 .39076 L .39319 .39049 L .929 .648 .486 r
F
.39335 .39129 m .3761 .40053 L .38219 .40303 L .658 .778 .938 r
F
.39662 .3583 m .39703 .39168 L .39607 .39158 L .753 .483 .524 r
F
.39662 .3583 m .39607 .39158 L .39519 .39148 L F
.39613 .38836 m .39455 .39204 L .39624 .3918 L .658 .778 .938 r
F
.39647 .40166 m .38928 .41131 L .3968 .41172 L .657 .779 .939 r
F
.39527 .40002 m .38928 .41131 L .39647 .40166 L F
.39508 .39783 m .39507 .39787 L .39636 .39797 L F
.39492 .39821 m .39455 .39906 L .39588 .39887 L F
.39613 .38836 m .39162 .3911 L .39335 .39129 L .658 .778 .938 r
F
.39162 .3911 m .3761 .40053 L .39335 .39129 L F
.39613 .38836 m .38833 .39114 L .3761 .40053 L F
.38833 .39114 m .37135 .3972 L .37521 .39991 L F
.38833 .39114 m .37521 .39991 L .3761 .40053 L F
.3958 .35339 m .39458 .35426 L .39309 .38795 L .339 .143 .462 r
F
.39333 .40191 m .38928 .41131 L .39355 .40327 L .657 .779 .939 r
F
.39519 .39148 m .39523 .39785 L .39491 .39781 L .753 .483 .524 r
F
.39293 .39014 m .3927 .39653 L .39269 .38981 L .989 .724 .411 r
F
.3927 .39653 m .3925 .39626 L .39269 .38981 L F
.39458 .35426 m .39256 .389 L .39283 .38846 L 0 0 .269 r
F
.38833 .39114 m .36825 .39324 L .37135 .3972 L .658 .778 .938 r
F
.39613 .38836 m .3912 .38922 L .38833 .39114 L F
.3912 .38922 m .36825 .39324 L .38833 .39114 L F
.38744 .39911 m .38513 .40366 L .3892 .40454 L F
.39481 .39144 m .39298 .39167 L .39345 .39461 L F
.39613 .38836 m .39335 .39129 L .39481 .39144 L F
.39335 .39129 m .39298 .39167 L .39481 .39144 L F
.39358 .39076 m .39338 .39714 L .39319 .39049 L .929 .648 .486 r
F
.38219 .40303 m .3824 .4204 L .3892 .40454 L .658 .778 .938 r
F
.39455 .39906 m .38735 .40503 L .38928 .41131 L .657 .779 .939 r
F
.39492 .39821 m .39432 .39875 L .39455 .39906 L F
.39432 .39875 m .38735 .40503 L .39455 .39906 L F
.39293 .39014 m .39319 .39049 L .39291 .39682 L .989 .724 .411 r
F
.3948 .39812 m .38735 .40503 L .39492 .39821 L .657 .779 .939 r
F
.39505 .39786 m .39478 .39811 L .39507 .39787 L F
.39478 .39811 m .38735 .40503 L .3948 .39812 L F
.39478 .39811 m .3948 .39812 L .39507 .39787 L F
.39358 .39076 m .394 .39105 L .39372 .39738 L .929 .648 .486 r
F
.39457 .39126 m .39519 .39148 L .39491 .39781 L .849 .569 .514 r
F
.39378 .39769 m .388 .40375 L .39505 .39786 L .657 .779 .939 r
F
.39378 .39769 m .39505 .39786 L .39491 .39781 L F
.388 .40375 m .38735 .40503 L .39508 .39783 L F
.39457 .39126 m .39491 .39781 L .3944 .39763 L .849 .569 .514 r
F
.39457 .39126 m .3944 .39763 L .394 .39105 L F
.3944 .39763 m .39393 .39746 L .394 .39105 L F
.39627 .39262 m .39559 .39377 L .39634 .39479 L .658 .778 .938 r
F
.39607 .39158 m .39596 .39793 L .39519 .39148 L .753 .483 .524 r
F
.39596 .39793 m .39523 .39785 L .39519 .39148 L F
.39507 .39787 m .39492 .39821 L .39619 .39828 L .657 .779 .939 r
F
.39492 .39821 m .39588 .39887 L .39619 .39828 L F
.39507 .39787 m .39619 .39828 L .39636 .39797 L F
.39636 .39797 m .39527 .40002 L .39647 .40166 L F
.39625 .39187 m .39595 .3924 L .39627 .39262 L .658 .778 .938 r
F
.39624 .3918 m .39621 .39186 L .39625 .39187 L F
.39662 .3583 m .39844 .35859 L .39703 .39168 L .753 .483 .524 r
F
.39844 .35859 m .3979 .39155 L .39703 .39168 L .631 .379 .518 r
F
.39873 .39353 m .39667 .40495 L .40409 .40424 L .658 .778 .938 r
F
.3968 .41172 m .39732 .428 L .41212 .4266 L .657 .779 .939 r
F
.3968 .41172 m .41212 .4266 L .40428 .41101 L F
.39693 .41844 m .39745 .43468 L .41228 .43327 L .656 .78 .939 r
F
.39693 .41844 m .41228 .43327 L .40442 .41772 L F
.40024 .35836 m .3994 .39119 L .39885 .39142 L .484 .259 .497 r
F
.39844 .35859 m .40024 .35836 L .39885 .39142 L .631 .379 .518 r
F
.39844 .35859 m .39885 .39142 L .3979 .39155 L F
.40138 .35787 m .40215 .35724 L .40078 .39035 L .286 .104 .449 r
F
.39981 .39184 m .40409 .40424 L .40953 .40283 L .658 .778 .938 r
F
.39981 .39184 m .40953 .40283 L .40718 .39883 L F
.39963 .39213 m .40409 .40424 L .39981 .39184 L F
.39929 .39149 m .40409 .40424 L .39937 .39142 L F
.39787 .39182 m .40409 .40424 L .3992 .39127 L F
.40024 .35836 m .40138 .35787 L .4 .39094 L .484 .259 .497 r
F
.40024 .35836 m .4 .39094 L .3994 .39119 L F
.40138 .35787 m .40037 .39066 L .4 .39094 L .286 .104 .449 r
F
.40333 .39229 m .41099 .40245 L .4169 .39972 L .658 .778 .938 r
F
.39613 .38836 m .40718 .39883 L .40333 .39229 L F
.40718 .39883 m .41099 .40245 L .40333 .39229 L F
.40215 .35724 m .4026 .35648 L .40122 .38965 L 0 0 .327 r
F
.40215 .35724 m .40122 .38965 L .40099 .39001 L F
.40138 .35787 m .40078 .39035 L .40037 .39066 L .286 .104 .449 r
F
.40215 .35724 m .40099 .39001 L .40078 .39035 L 0 0 .327 r
F
.4026 .35648 m .4013 .38884 L .40126 .38926 L 0 0 .006 r
F
.4026 .35648 m .40126 .38926 L .40122 .38965 L F
.40267 .35557 m .40208 .3544 L .40069 .38781 L .99 .735 .374 r
F
.39613 .38836 m .4169 .39972 L .41845 .39852 L .658 .778 .938 r
F
.40737 .39184 m .41845 .39852 L .42143 .3962 L F
.39613 .38836 m .41845 .39852 L .40737 .39184 L F
.40037 .39066 m .40078 .39035 L .40051 .39668 L .286 .104 .449 r
F
.40316 .3893 m .42143 .3962 L .42426 .39213 L .658 .778 .938 r
F
.39613 .38836 m .40737 .39184 L .40316 .3893 L F
.40737 .39184 m .42143 .3962 L .40316 .3893 L F
.40208 .3544 m .40081 .35348 L .3994 .38703 L .912 .629 .494 r
F
.39857 .39968 m .3968 .41172 L .40428 .41101 L .657 .779 .939 r
F
.39937 .39142 m .39963 .39213 L .39981 .39184 L .658 .778 .938 r
F
.3992 .39127 m .39929 .39149 L .39937 .39142 L F
.3994 .39119 m .4 .39094 L .39974 .39727 L .484 .259 .497 r
F
.40099 .39001 m .40077 .39628 L .40078 .39035 L 0 0 .327 r
F
.40409 .40424 m .41189 .41979 L .42557 .41629 L .658 .778 .938 r
F
.40409 .40424 m .42557 .41629 L .41099 .40245 L F
.40065 .39955 m .40428 .41101 L .40958 .40964 L .657 .779 .939 r
F
.3995 .39825 m .40052 .40099 L .40065 .39955 L F
.40052 .40099 m .40428 .41101 L .40065 .39955 L F
.40267 .35557 m .40069 .38781 L .401 .38834 L .99 .735 .374 r
F
.40267 .35557 m .401 .38834 L .4013 .38884 L F
.40388 .3882 m .42426 .39213 L .42519 .38778 L .658 .778 .938 r
F
.39613 .38836 m .41324 .39065 L .40388 .3882 L F
.41324 .39065 m .42426 .39213 L .40388 .3882 L F
.39893 .3976 m .3993 .39855 L .3995 .39825 L .657 .779 .939 r
F
.40067 .39926 m .40958 .40964 L .40695 .40519 L F
.40065 .39953 m .40958 .40964 L .40067 .39926 L F
.39908 .39777 m .40065 .39955 L .39909 .39776 L F
.40065 .39955 m .40958 .40964 L .40065 .39953 L F
.40065 .39955 m .40065 .39953 L .39909 .39776 L F
.40126 .38926 m .401 .39552 L .40122 .38965 L 0 0 .006 r
F
.3993 .39855 m .40428 .41101 L .3995 .39825 L .657 .779 .939 r
F
.39785 .39489 m .39667 .40495 L .39873 .39353 L .658 .778 .938 r
F
.39613 .38836 m .39787 .39182 L .3992 .39127 L F
.39814 .39236 m .39785 .39489 L .39873 .39353 L F
.3978 .39263 m .39667 .40495 L .39814 .39236 L F
.3979 .39155 m .39885 .39142 L .39858 .39775 L .631 .379 .518 r
F
.39777 .39808 m .39802 .39858 L .39883 .39771 L .657 .779 .939 r
F
.39777 .39808 m .39883 .39771 L .39858 .39775 L F
.39802 .39858 m .40428 .41101 L .39901 .39782 L F
.39802 .39858 m .39901 .39782 L .39893 .3976 L F
.39787 .39182 m .3978 .39263 L .39814 .39236 L .658 .778 .938 r
F
.3979 .39155 m .39858 .39775 L .3978 .39786 L .631 .379 .518 r
F
.39858 .39775 m .39883 .39771 L .39893 .3976 L .657 .779 .939 r
F
.39802 .39858 m .39781 .40086 L .39857 .39968 L F
.39781 .40086 m .3968 .41172 L .39857 .39968 L F
.40718 .39883 m .40953 .40283 L .41099 .40245 L .658 .778 .938 r
F
.41099 .40245 m .42557 .41629 L .43735 .4109 L F
.40322 .39888 m .41122 .40922 L .41717 .40647 L .657 .779 .939 r
F
.40004 .39715 m .40601 .40359 L .40322 .39888 L F
.40601 .40359 m .41122 .40922 L .40322 .39888 L F
.3979 .40482 m .39693 .41844 L .3993 .41821 L .656 .78 .939 r
F
.4001 .40917 m .3993 .41821 L .40442 .41772 L F
.39842 .40585 m .3993 .41821 L .4001 .40917 L F
.39858 .39775 m .39856 .404 L .39832 .4041 L .484 .259 .497 r
F
.39878 .39766 m .39872 .40394 L .39858 .39775 L F
.40428 .41101 m .41212 .4266 L .4259 .42308 L .657 .779 .939 r
F
.40428 .41101 m .4259 .42308 L .41122 .40922 L F
.40036 .40622 m .40442 .41772 L .40959 .4164 L .656 .78 .939 r
F
.39909 .40482 m .40019 .40812 L .40036 .40622 L F
.39861 .40429 m .39893 .40507 L .39909 .40482 L F
.39893 .40507 m .40019 .40812 L .39909 .40482 L F
.39893 .3976 m .40695 .40519 L .40004 .39715 L .657 .779 .939 r
F
.40695 .40519 m .41122 .40922 L .40601 .40359 L F
.40695 .40519 m .40601 .40359 L .40004 .39715 L F
.40077 .39628 m .40059 .39656 L .40078 .39035 L 0 0 .327 r
F
.40099 .39001 m .40122 .38965 L .40096 .39598 L F
.40099 .39001 m .40096 .39598 L .40077 .39628 L F
.401 .38834 m .40069 .39459 L .4013 .38884 L .99 .735 .374 r
F
.39909 .39776 m .40065 .39953 L .40067 .39926 L .657 .779 .939 r
F
.39885 .39142 m .39878 .39766 L .39858 .39775 L .484 .259 .497 r
F
.40037 .39066 m .40018 .39693 L .4 .39094 L .286 .104 .449 r
F
.40018 .39693 m .39987 .39717 L .4 .39094 L F
.4 .39094 m .39987 .39717 L .39974 .39727 L F
.3994 .39119 m .39974 .39727 L .39924 .39748 L .484 .259 .497 r
F
.40037 .39066 m .40051 .39668 L .40018 .39693 L .286 .104 .449 r
F
.3994 .39119 m .39924 .39748 L .39885 .39142 L .484 .259 .497 r
F
.39853 .40434 m .40019 .40812 L .39861 .40429 L .656 .78 .939 r
F
.41099 .40245 m .43735 .4109 L .4169 .39972 L .658 .778 .938 r
F
.40046 .39697 m .41717 .40647 L .41883 .40519 L .657 .779 .939 r
F
.40004 .39715 m .41717 .40647 L .40046 .39697 L F
.39924 .39748 m .39878 .39766 L .39885 .39142 L .484 .259 .497 r
F
.40078 .39035 m .40059 .39656 L .40051 .39668 L 0 0 .327 r
F
.39772 .39188 m .39667 .40495 L .39787 .39182 L .658 .778 .938 r
F
.39624 .3918 m .39667 .40495 L .39775 .39158 L F
.39607 .39158 m .39703 .39168 L .39676 .39801 L .753 .483 .524 r
F
.39607 .39158 m .39676 .39801 L .39596 .39793 L F
.40286 .39712 m .40467 .39886 L .40805 .39872 L .657 .779 .939 r
F
.39703 .39168 m .39707 .39797 L .39676 .39801 L .631 .379 .518 r
F
.39775 .39158 m .39772 .39188 L .39787 .39182 L .658 .778 .938 r
F
.3979 .39155 m .3978 .39786 L .39703 .39168 L .631 .379 .518 r
F
.3978 .39786 m .39736 .39792 L .39703 .39168 L F
.39767 .39788 m .39641 .39981 L .39802 .39858 L .657 .779 .939 r
F
.39636 .39807 m .39641 .39981 L .39767 .39788 L F
.39641 .39981 m .3968 .41172 L .39802 .39858 L F
.39769 .40419 m .39712 .40428 L .39707 .39797 L .631 .379 .518 r
F
.39736 .39792 m .39707 .39797 L .39703 .39168 L F
.39769 .40419 m .39707 .39797 L .39736 .39792 L F
.39626 .39509 m .39636 .39807 L .39767 .39788 L .657 .779 .939 r
F
.39626 .39509 m .39767 .39788 L .39893 .3976 L F
.39767 .39788 m .39777 .39808 L .39858 .39775 L F
.39767 .39788 m .39858 .39775 L .39893 .3976 L F
.3978 .39786 m .39769 .40419 L .39736 .39792 L .631 .379 .518 r
F
.39767 .40437 m .3979 .40482 L .39841 .40409 L .656 .78 .939 r
F
.3979 .40482 m .4001 .40917 L .39851 .40436 L F
.3979 .40482 m .39851 .40436 L .39841 .40409 L F
.39987 .39717 m .39974 .40342 L .39974 .39727 L .286 .104 .449 r
F
.3994 .40468 m .40039 .40582 L .40041 .40562 L .656 .78 .939 r
F
.3992 .40466 m .40959 .4164 L .3994 .40468 L F
.39891 .40463 m .39909 .40482 L .3992 .40466 L F
.39909 .40482 m .40959 .4164 L .3992 .40466 L F
.39626 .39509 m .40131 .39735 L .40286 .39712 L .657 .779 .939 r
F
.401 .39552 m .40097 .39584 L .40122 .38965 L 0 0 .006 r
F
.40122 .38965 m .40097 .39584 L .40096 .39598 L F
.39626 .39509 m .40805 .39872 L .40428 .39646 L .657 .779 .939 r
F
.4169 .39972 m .44643 .40394 L .42143 .3962 L .658 .778 .938 r
F
.40363 .39607 m .42392 .39982 L .4157 .39768 L .657 .779 .939 r
F
.39626 .39509 m .40428 .39646 L .40363 .39607 L F
.40428 .39646 m .42392 .39982 L .40363 .39607 L F
.40208 .3544 m .40007 .38743 L .40069 .38781 L .912 .629 .494 r
F
.40112 .38748 m .42519 .38778 L .42414 .38345 L .658 .778 .938 r
F
.39613 .38836 m .40388 .3882 L .40112 .38748 L F
.40388 .3882 m .42519 .38778 L .40112 .38748 L F
.40081 .35348 m .39955 .35305 L .39812 .3867 L .814 .537 .519 r
F
.39767 .40437 m .39841 .40409 L .39832 .4041 L .656 .78 .939 r
F
.39676 .39801 m .39687 .40431 L .39648 .40437 L .631 .379 .518 r
F
.39763 .40503 m .39693 .41844 L .3979 .40482 L .656 .78 .939 r
F
.39707 .39797 m .39712 .40428 L .39676 .39801 L .631 .379 .518 r
F
.39759 .40421 m .39649 .40485 L .39767 .40437 L .656 .78 .939 r
F
.39647 .40437 m .39649 .40485 L .39759 .40421 L F
.39649 .40485 m .39693 .41844 L .39767 .40437 L F
.39712 .40428 m .3973 .42829 L .39687 .40431 L .631 .379 .518 r
F
.39712 .40428 m .39687 .40431 L .39676 .39801 L F
.39596 .39793 m .39676 .39801 L .39648 .40437 L .753 .483 .524 r
F
.39639 .40185 m .39647 .40437 L .39759 .40421 L .656 .78 .939 r
F
.3978 .39786 m .39858 .39775 L .39832 .4041 L .631 .379 .518 r
F
.3978 .39786 m .39832 .4041 L .39769 .40419 L F
.39639 .40185 m .39759 .40421 L .39841 .40406 L .656 .78 .939 r
F
.39759 .40421 m .39767 .40437 L .39832 .4041 L F
.39759 .40421 m .39832 .4041 L .39841 .40406 L F
.39596 .39793 m .39648 .40437 L .39586 .4043 L .753 .483 .524 r
F
.39455 .39906 m .39333 .40191 L .39527 .40002 L .657 .779 .939 r
F
.39333 .40191 m .39355 .40327 L .39527 .40002 L F
.39358 .39076 m .39372 .39738 L .39338 .39714 L .929 .648 .486 r
F
.39338 .39714 m .39305 .39692 L .39319 .39049 L F
.394 .39105 m .39393 .39746 L .39372 .39738 L .849 .569 .514 r
F
.38219 .40303 m .36849 .41745 L .3824 .4204 L .658 .778 .938 r
F
.3761 .40053 m .36849 .41745 L .38219 .40303 L F
.388 .40375 m .37609 .4073 L .38222 .40981 L .657 .779 .939 r
F
.39626 .39509 m .39069 .39846 L .388 .40375 L F
.38744 .39911 m .38219 .40303 L .38513 .40366 L .658 .778 .938 r
F
.39069 .39846 m .37609 .4073 L .388 .40375 L .657 .779 .939 r
F
.39661 .40856 m .3894 .41803 L .39693 .41844 L .656 .78 .939 r
F
.39652 .40585 m .39567 .4073 L .39661 .40856 L F
.39567 .4073 m .3894 .41803 L .39661 .40856 L F
.39293 .39014 m .39291 .39682 L .3927 .39653 L .989 .724 .411 r
F
.39319 .39049 m .39305 .39692 L .39291 .39682 L .929 .648 .486 r
F
.39626 .39509 m .3863 .39863 L .37609 .4073 L .657 .779 .939 r
F
.3761 .40053 m .35635 .41254 L .36849 .41745 L .658 .778 .938 r
F
.3863 .39863 m .37131 .40396 L .37472 .40634 L .657 .779 .939 r
F
.3863 .39863 m .37472 .40634 L .37609 .4073 L F
.37135 .3972 m .35635 .41254 L .3761 .40053 L .658 .778 .938 r
F
.37135 .3972 m .34679 .40595 L .35635 .41254 L F
.3863 .39863 m .36819 .39999 L .37131 .40396 L .657 .779 .939 r
F
.39262 .38939 m .39269 .38981 L .39241 .39615 L .875 .7 .179 r
F
.39262 .38939 m .39241 .39615 L .39235 .3958 L F
.39269 .38981 m .3925 .39626 L .39241 .39615 L .989 .724 .411 r
F
.39256 .389 m .39235 .3958 L .39228 .39534 L .875 .7 .179 r
F
.39262 .38939 m .39235 .3958 L .39256 .389 L F
.39626 .39509 m .38996 .39619 L .3863 .39863 L .657 .779 .939 r
F
.38996 .39619 m .36819 .39999 L .3863 .39863 L F
.39458 .35426 m .39283 .38846 L .39309 .38795 L 0 0 .269 r
F
.38235 .39077 m .36704 .38893 L .36825 .39324 L .658 .778 .938 r
F
.39613 .38836 m .38988 .38848 L .38235 .39077 L F
.38988 .38848 m .36704 .38893 L .38235 .39077 L F
.39704 .35301 m .3958 .35339 L .39433 .38713 L .545 .308 .506 r
F
.39538 .4069 m .3894 .41803 L .39567 .4073 L .656 .78 .939 r
F
.39529 .40441 m .39509 .40487 L .39649 .40484 L F
.39235 .3958 m .39241 .39615 L .39213 .40251 L .875 .7 .179 r
F
.39321 .40922 m .3894 .41803 L .39342 .41055 L .656 .78 .939 r
F
.39626 .39509 m .39398 .39748 L .39508 .39783 L .657 .779 .939 r
F
.39398 .39748 m .39378 .39769 L .39491 .39781 L F
.39398 .39748 m .39491 .39781 L .39508 .39783 L F
.39455 .39906 m .39527 .40002 L .39588 .39887 L F
.3944 .39763 m .39491 .39781 L .39464 .40417 L .849 .569 .514 r
F
.3944 .39763 m .39464 .40417 L .39423 .40403 L F
.3944 .39763 m .39423 .40403 L .39393 .39746 L F
.38735 .40503 m .38466 .41033 L .38928 .41131 L .657 .779 .939 r
F
.38222 .40981 m .38244 .42721 L .38928 .41131 L F
.39464 .4059 m .38683 .41183 L .3894 .41803 L .656 .78 .939 r
F
.39434 .4055 m .38683 .41183 L .39464 .4059 L F
.39491 .40474 m .39422 .40534 L .39509 .40487 L F
.39422 .40534 m .38683 .41183 L .39434 .4055 L F
.39422 .40534 m .39434 .4055 L .39509 .40487 L F
.3925 .39626 m .3923 .40274 L .39241 .39615 L .989 .724 .411 r
F
.39305 .39692 m .39291 .40338 L .39291 .39682 L .929 .648 .486 r
F
.3944 .4044 m .3927 .40607 L .39491 .40474 L .656 .78 .939 r
F
.3927 .40607 m .38683 .41183 L .39279 .4066 L F
.3927 .40607 m .39279 .4066 L .39491 .40474 L F
.39421 .40413 m .39265 .40576 L .39464 .40417 L F
.39265 .40576 m .38683 .41183 L .3927 .40607 L F
.39265 .40576 m .3927 .40607 L .39464 .40417 L F
.36825 .39324 m .34679 .40595 L .37135 .3972 L .658 .778 .938 r
F
.37842 .39821 m .36697 .39567 L .36819 .39999 L .657 .779 .939 r
F
.39283 .38846 m .39256 .389 L .39228 .39534 L 0 0 .269 r
F
.39283 .38846 m .39228 .39534 L .3925 .39489 L F
.3958 .35339 m .39309 .38795 L .39372 .38753 L .339 .143 .462 r
F
.38988 .38848 m .36782 .38456 L .36704 .38893 L .658 .778 .938 r
F
.39613 .38836 m .39208 .38781 L .38988 .38848 L F
.39208 .38781 m .36782 .38456 L .38988 .38848 L F
.39626 .39509 m .39147 .39518 L .38996 .39619 L .657 .779 .939 r
F
.39464 .40417 m .3944 .4044 L .39529 .40441 L .656 .78 .939 r
F
.3944 .4044 m .39491 .40474 L .39529 .40441 L F
.39429 .40405 m .39421 .40413 L .39464 .40417 L F
.39509 .40487 m .39434 .4055 L .39464 .4059 L F
.39509 .40487 m .39321 .40922 L .3961 .40556 L F
.39321 .40922 m .39342 .41055 L .3961 .40556 L F
.39596 .39793 m .39586 .4043 L .39523 .39785 L .753 .483 .524 r
F
.39586 .4043 m .39528 .40424 L .39523 .39785 L F
.39423 .40403 m .39386 .40389 L .39393 .39746 L .849 .569 .514 r
F
.38222 .40981 m .36843 .42426 L .38244 .42721 L .657 .779 .939 r
F
.37609 .4073 m .36843 .42426 L .38222 .40981 L F
.38683 .41183 m .37618 .41403 L .38233 .41653 L .656 .78 .939 r
F
.39338 .39714 m .39372 .39738 L .39345 .40374 L .929 .648 .486 r
F
.39338 .39714 m .39345 .40374 L .39317 .40355 L F
.39429 .40405 m .38994 .40574 L .38683 .41183 L .656 .78 .939 r
F
.39332 .4037 m .38994 .40574 L .39429 .40405 L F
.39345 .40374 m .39359 .42823 L .3924 .42771 L .849 .569 .514 r
F
.39372 .39738 m .3937 .40383 L .39345 .40374 L F
.3937 .40383 m .39359 .42823 L .39345 .40374 L F
.39393 .39746 m .39386 .40389 L .39372 .39738 L F
.39386 .40389 m .39359 .42823 L .3937 .40383 L F
.39386 .40389 m .3937 .40383 L .39372 .39738 L F
.39291 .40338 m .3928 .4033 L .39291 .39682 L .929 .648 .486 r
F
.39291 .39682 m .3928 .4033 L .39263 .40318 L F
.3927 .39653 m .39291 .39682 L .39263 .40318 L .989 .724 .411 r
F
.3927 .39653 m .39263 .40318 L .39246 .40295 L F
.36825 .39324 m .34049 .39811 L .34679 .40595 L .658 .778 .938 r
F
.36704 .38893 m .34049 .39811 L .36825 .39324 L F
.38817 .39525 m .36775 .39129 L .36697 .39567 L .657 .779 .939 r
F
.39283 .38846 m .3925 .39489 L .39309 .38795 L 0 0 .269 r
F
.3925 .39489 m .39272 .39448 L .39309 .38795 L F
.39626 .39509 m .39101 .39439 L .38817 .39525 L .657 .779 .939 r
F
.39101 .39439 m .36775 .39129 L .38817 .39525 L F
.39338 .39714 m .39317 .40355 L .39305 .39692 L .929 .648 .486 r
F
.39317 .40355 m .39291 .40338 L .39305 .39692 L F
.39529 .40441 m .39491 .40474 L .39509 .40487 L .656 .78 .939 r
F
.39464 .40417 m .39545 .42852 L .39359 .42823 L .753 .483 .524 r
F
.39491 .39781 m .39502 .40421 L .39464 .40417 L F
.39502 .40421 m .39545 .42852 L .39464 .40417 L F
.39536 .40425 m .39464 .40417 L .39529 .40441 L .656 .78 .939 r
F
.39509 .40487 m .3961 .40556 L .39649 .40484 L F
.39491 .39781 m .39505 .39786 L .39508 .39783 L .657 .779 .939 r
F
.39507 .39787 m .3948 .39812 L .39492 .39821 L F
.39508 .39783 m .39505 .39786 L .39507 .39787 L F
.39523 .39785 m .39528 .40424 L .39491 .39781 L .753 .483 .524 r
F
.39528 .40424 m .39545 .42852 L .39502 .40421 L F
.39528 .40424 m .39502 .40421 L .39491 .39781 L F
.388 .40375 m .38222 .40981 L .38735 .40503 L .657 .779 .939 r
F
.38735 .40503 m .38222 .40981 L .38466 .41033 L F
.37609 .4073 m .35621 .41934 L .36843 .42426 L F
.37131 .40396 m .35621 .41934 L .37609 .4073 L F
.37131 .40396 m .34659 .41274 L .35621 .41934 L F
.39093 .40378 m .36827 .40675 L .37139 .4107 L .656 .78 .939 r
F
.3923 .40274 m .39223 .40265 L .39241 .39615 L .989 .724 .411 r
F
.39241 .39615 m .39223 .40265 L .39213 .40251 L F
.39101 .39439 m .37049 .38714 L .36775 .39129 L .657 .779 .939 r
F
.38913 .38742 m .37054 .38042 L .36782 .38456 L .658 .778 .938 r
F
.39613 .38836 m .39211 .38711 L .38913 .38742 L F
.39211 .38711 m .37054 .38042 L .38913 .38742 L F
.39829 .35291 m .39704 .35301 L .39558 .38675 L .652 .396 .519 r
F
.3958 .35339 m .39372 .38753 L .39433 .38713 L .339 .143 .462 r
F
.39211 .38711 m .37503 .37681 L .37054 .38042 L .658 .778 .938 r
F
.39613 .38836 m .39357 .38695 L .39211 .38711 L F
.39357 .38695 m .37503 .37681 L .39211 .38711 L F
.39626 .39509 m .39309 .39411 L .39239 .39457 L .657 .779 .939 r
F
.3927 .39653 m .39246 .40295 L .3925 .39626 L .989 .724 .411 r
F
.39246 .40295 m .3923 .40274 L .3925 .39626 L F
.39094 .40378 m .38872 .40318 L .39093 .40378 L .656 .78 .939 r
F
.39639 .40185 m .39149 .4027 L .39094 .40378 L F
.39149 .4027 m .38872 .40318 L .39094 .40378 L F
.39235 .3958 m .39208 .40224 L .39228 .39534 L .875 .7 .179 r
F
.39208 .40224 m .39203 .40187 L .39228 .39534 L F
.39228 .39534 m .39203 .40187 L .392 .4017 L F
.3925 .39489 m .39228 .39534 L .392 .4017 L 0 0 .269 r
F
.38994 .40574 m .38297 .407 L .37618 .41403 L .656 .78 .939 r
F
.39332 .4037 m .39052 .40459 L .38994 .40574 L F
.39052 .40459 m .38297 .407 L .38994 .40574 L F
.3925 .39489 m .39218 .40135 L .39272 .39448 L 0 0 .269 r
F
.39226 .40331 m .38427 .40614 L .39332 .4037 L .656 .78 .939 r
F
.38427 .40614 m .37139 .4107 L .38297 .407 L F
.38427 .40614 m .38297 .407 L .39332 .4037 L F
.39116 .39352 m .37501 .38352 L .37049 .38714 L .657 .779 .939 r
F
.39372 .38753 m .39309 .38795 L .39281 .39429 L .339 .143 .462 r
F
.39372 .38753 m .39281 .39429 L .39333 .39394 L F
.39704 .35301 m .39433 .38713 L .39497 .38693 L .545 .308 .506 r
F
.39613 .38836 m .38099 .37399 L .37503 .37681 L .658 .778 .938 r
F
.39372 .38753 m .39333 .39394 L .39433 .38713 L .339 .143 .462 r
F
.39333 .39394 m .39383 .39361 L .39433 .38713 L F
.39309 .38795 m .39272 .39448 L .39281 .39429 L 0 0 .269 r
F
.39626 .39509 m .39302 .39332 L .39116 .39352 L .657 .779 .939 r
F
.39302 .39332 m .37501 .38352 L .39116 .39352 L F
.39639 .40185 m .39429 .40405 L .39464 .40417 L .656 .78 .939 r
F
.39639 .40185 m .39464 .40417 L .39536 .40425 L F
.39639 .40185 m .39226 .40331 L .39332 .4037 L F
.39639 .40185 m .39332 .4037 L .39429 .40405 L F
.3961 .40556 m .39538 .4069 L .39652 .40585 L F
.39538 .4069 m .39567 .4073 L .39652 .40585 L F
.39639 .40185 m .39529 .40441 L .39649 .40484 L F
.39586 .4043 m .39545 .42852 L .39528 .40424 L .753 .483 .524 r
F
.39649 .40484 m .3961 .40556 L .39652 .40585 L .656 .78 .939 r
F
.39586 .4043 m .39648 .40437 L .39545 .42852 L .753 .483 .524 r
F
.36819 .39999 m .34659 .41274 L .37131 .40396 L .657 .779 .939 r
F
.37448 .40566 m .36705 .40244 L .36827 .40675 L .656 .78 .939 r
F
.39235 .3958 m .39213 .40251 L .39208 .40224 L .875 .7 .179 r
F
.39639 .40185 m .39056 .40196 L .38872 .40318 L .656 .78 .939 r
F
.39291 .40338 m .3924 .42771 L .3928 .4033 L .929 .648 .486 r
F
.3923 .40274 m .39158 .42705 L .39223 .40265 L .989 .724 .411 r
F
.39213 .40251 m .39158 .42705 L .39108 .42629 L F
.39223 .40265 m .39158 .42705 L .39213 .40251 L F
.39263 .40318 m .3924 .42771 L .39158 .42705 L .929 .648 .486 r
F
.3928 .4033 m .3924 .42771 L .39263 .40318 L F
.39317 .40355 m .3924 .42771 L .39291 .40338 L F
.39246 .40295 m .39158 .42705 L .3923 .40274 L .989 .724 .411 r
F
.39168 .42412 m .39171 .42411 L .39158 .42705 L F
.39246 .40295 m .39171 .42411 L .39168 .42412 L F
.39246 .40295 m .39263 .40318 L .39171 .42411 L F
.39317 .40355 m .39345 .40374 L .3924 .42771 L .929 .648 .486 r
F
.39218 .40135 m .39234 .40102 L .39272 .39448 L 0 0 .269 r
F
.3925 .39489 m .392 .4017 L .39218 .40135 L F
.39639 .40185 m .38994 .40099 L .38644 .40205 L .656 .78 .939 r
F
.39373 .4231 m .39359 .42823 L .39365 .42312 L .849 .569 .514 r
F
.39373 .4231 m .39365 .42312 L .39386 .40389 L F
.39423 .40403 m .39373 .4231 L .39386 .40389 L F
.39423 .40403 m .39464 .40417 L .39359 .42823 L F
.38996 .39619 m .38817 .39525 L .37842 .39821 L .657 .779 .939 r
F
.38817 .39525 m .36697 .39567 L .37842 .39821 L F
.38566 .40043 m .37057 .39393 L .36783 .39806 L .656 .78 .939 r
F
.39302 .39332 m .38101 .38068 L .37501 .38352 L .657 .779 .939 r
F
.39704 .35301 m .39497 .38693 L .39558 .38675 L .545 .308 .506 r
F
.39613 .38836 m .388 .37214 L .38099 .37399 L .658 .778 .938 r
F
.39497 .38693 m .39433 .38713 L .39405 .39347 L .545 .308 .506 r
F
.39497 .38693 m .39405 .39347 L .39458 .39331 L F
.39433 .38713 m .39383 .39361 L .39405 .39347 L .339 .143 .462 r
F
.39626 .39509 m .39426 .39319 L .39302 .39332 L .657 .779 .939 r
F
.39426 .39319 m .38101 .38068 L .39302 .39332 L F
.39613 .38836 m .39624 .3918 L .39775 .39158 L .658 .778 .938 r
F
.39829 .35291 m .39558 .38675 L .39623 .38668 L .652 .396 .519 r
F
.39613 .38836 m .39559 .37141 L .388 .37214 L .658 .778 .938 r
F
.39829 .35291 m .39623 .38668 L .39685 .38661 L .652 .396 .519 r
F
.40081 .35348 m .39812 .3867 L .39878 .38687 L .814 .537 .519 r
F
.40081 .35348 m .39878 .38687 L .3994 .38703 L F
.40208 .3544 m .3994 .38703 L .40007 .38743 L .912 .629 .494 r
F
.39955 .35305 m .3975 .38666 L .39812 .3867 L .735 .467 .523 r
F
.39613 .38836 m .39688 .38662 L .39608 .38656 L .658 .778 .938 r
F
.39272 .39448 m .39234 .40102 L .39281 .39429 L 0 0 .269 r
F
.39234 .40102 m .39242 .40088 L .39281 .39429 L F
.39281 .39429 m .39242 .40088 L .39253 .40066 L F
.39639 .40185 m .39178 .40043 L .38994 .40099 L .656 .78 .939 r
F
.39865 .40397 m .39842 .40409 L .39873 .40404 L F
.39872 .40394 m .39856 .404 L .39858 .39775 L .484 .259 .497 r
F
.39639 .40185 m .39841 .40406 L .39865 .40397 L .656 .78 .939 r
F
.39841 .40406 m .39842 .40409 L .39865 .40397 L F
.39893 .3976 m .39908 .39777 L .39909 .39776 L .657 .779 .939 r
F
.39924 .39748 m .39908 .40379 L .39878 .39766 L .484 .259 .497 r
F
.39873 .40404 m .39891 .40463 L .3994 .40468 L .656 .78 .939 r
F
.39842 .40409 m .39891 .40463 L .39873 .40404 L F
.40018 .39693 m .40051 .39668 L .40025 .40304 L .286 .104 .449 r
F
.4001 .40917 m .40019 .40812 L .39853 .40434 L .656 .78 .939 r
F
.4001 .40917 m .39853 .40434 L .39851 .40436 L F
.39908 .40379 m .39872 .40394 L .39878 .39766 L .484 .259 .497 r
F
.40695 .40519 m .40958 .40964 L .41122 .40922 L .657 .779 .939 r
F
.41122 .40922 m .4259 .42308 L .43776 .41767 L F
.40312 .40549 m .41138 .41594 L .41734 .4132 L .656 .78 .939 r
F
.39974 .39727 m .39963 .4035 L .39947 .40363 L .286 .104 .449 r
F
.39924 .39748 m .39974 .39727 L .39947 .40363 L .484 .259 .497 r
F
.39865 .40397 m .39927 .40455 L .39959 .40358 L .656 .78 .939 r
F
.39927 .40455 m .40672 .41156 L .39977 .40378 L F
.39927 .40455 m .39977 .40378 L .39959 .40358 L F
.40059 .39656 m .40041 .4028 L .40051 .39668 L 0 0 .327 r
F
.39959 .40358 m .40672 .41156 L .40312 .40549 L .656 .78 .939 r
F
.4001 .40917 m .40442 .41772 L .40019 .40812 L F
.40019 .40812 m .40442 .41772 L .40036 .40622 L F
.39924 .39748 m .39947 .40363 L .39908 .40379 L .484 .259 .497 r
F
.40018 .39693 m .40025 .40304 L .39998 .40324 L .286 .104 .449 r
F
.39974 .40342 m .39963 .4035 L .39974 .39727 L F
.40077 .39628 m .40096 .39598 L .4007 .40234 L 0 0 .327 r
F
.40077 .39628 m .4007 .40234 L .40055 .40258 L F
.39955 .35305 m .39685 .38661 L .39705 .38663 L .735 .467 .523 r
F
.39613 .38836 m .39773 .38667 L .39688 .38662 L .658 .778 .938 r
F
.39613 .38836 m .39879 .38674 L .39773 .38667 L F
.39613 .38836 m .42116 .37943 L .41645 .376 L F
.39613 .38836 m .42414 .38345 L .42116 .37943 L F
.3975 .38666 m .39658 .39295 L .39711 .39299 L .735 .467 .523 r
F
.39955 .35305 m .39705 .38663 L .3975 .38666 L F
.39705 .38663 m .39658 .39295 L .3975 .38666 L F
.39773 .38667 m .41645 .376 L .41033 .37341 L .658 .778 .938 r
F
.39879 .38674 m .41645 .376 L .39773 .38667 L F
.39688 .38662 m .41033 .37341 L .40321 .37184 L F
.39773 .38667 m .41033 .37341 L .39688 .38662 L F
.39955 .35305 m .39829 .35291 L .39685 .38661 L .735 .467 .523 r
F
.39705 .38663 m .39685 .38661 L .39658 .39295 L F
.42143 .3962 m .44643 .40394 L .4522 .39587 L .658 .778 .938 r
F
.42143 .3962 m .4522 .39587 L .42426 .39213 L F
.40546 .39502 m .42458 .39886 L .42544 .39486 L .657 .779 .939 r
F
.40126 .38926 m .4013 .38884 L .40103 .39517 L 0 0 .006 r
F
.40126 .38926 m .40103 .39517 L .401 .39552 L F
.4013 .38884 m .40093 .39499 L .40103 .39517 L .99 .735 .374 r
F
.39626 .39509 m .4157 .39768 L .40546 .39502 L .657 .779 .939 r
F
.4157 .39768 m .42458 .39886 L .40546 .39502 L F
.39878 .38687 m .39812 .3867 L .39785 .39304 L .814 .537 .519 r
F
.40507 .39491 m .42544 .39486 L .42136 .39459 L .657 .779 .939 r
F
.39626 .39509 m .40546 .39502 L .40507 .39491 L F
.40546 .39502 m .42544 .39486 L .40507 .39491 L F
.39878 .38687 m .39839 .39318 L .3994 .38703 L .814 .537 .519 r
F
.39998 .40324 m .39974 .40342 L .39987 .39717 L .286 .104 .449 r
F
.39639 .40185 m .40312 .40549 L .40257 .40456 L .656 .78 .939 r
F
.40051 .39668 m .40034 .40289 L .40025 .40304 L 0 0 .327 r
F
.40018 .39693 m .39998 .40324 L .39987 .39717 L .286 .104 .449 r
F
.41122 .40922 m .43776 .41767 L .41717 .40647 L .657 .779 .939 r
F
.40197 .40356 m .41911 .41183 L .40874 .40563 L .656 .78 .939 r
F
.39639 .40185 m .40257 .40456 L .40197 .40356 L F
.40257 .40456 m .41911 .41183 L .40197 .40356 L F
.39626 .39509 m .40004 .39715 L .40046 .39697 L .657 .779 .939 r
F
.42426 .39213 m .4522 .39587 L .45421 .38721 L .658 .778 .938 r
F
.42426 .39213 m .45421 .38721 L .42519 .38778 L F
.40522 .39352 m .42552 .39451 L .42446 .39016 L .657 .779 .939 r
F
.40069 .39459 m .40093 .39499 L .4013 .38884 L .99 .735 .374 r
F
.401 .38834 m .40043 .39415 L .40069 .39459 L F
.39626 .39509 m .42136 .39459 L .40522 .39352 L .657 .779 .939 r
F
.42136 .39459 m .42552 .39451 L .40522 .39352 L F
.39639 .40185 m .39865 .40397 L .39959 .40358 L .656 .78 .939 r
F
.39648 .40437 m .3973 .42829 L .39545 .42852 L .631 .379 .518 r
F
.39687 .40431 m .3973 .42829 L .39648 .40437 L F
.39737 .40424 m .39716 .40937 L .39712 .40428 L F
.39769 .40419 m .39716 .40937 L .39737 .40424 L F
.39769 .40419 m .3973 .42829 L .39716 .40937 L F
.39626 .39509 m .39893 .3976 L .40004 .39715 L .657 .779 .939 r
F
.40041 .4028 m .40034 .40289 L .40051 .39668 L 0 0 .327 r
F
.40077 .39628 m .40055 .40258 L .40059 .39656 L F
.40059 .40252 m .40874 .40563 L .4046 .40316 L .656 .78 .939 r
F
.40055 .40258 m .40041 .4028 L .40059 .39656 L 0 0 .327 r
F
.39639 .40185 m .40025 .40303 L .40059 .40252 L .656 .78 .939 r
F
.40025 .40303 m .40874 .40563 L .40059 .40252 L F
.40467 .39886 m .41883 .40519 L .40905 .39932 L .657 .779 .939 r
F
.40805 .39872 m .41883 .40519 L .42173 .40294 L F
.43735 .4109 m .47115 .4116 L .44643 .40394 L .658 .778 .938 r
F
.4169 .39972 m .43735 .4109 L .44643 .40394 L F
.41717 .40647 m .4469 .4107 L .42173 .40294 L .657 .779 .939 r
F
.40411 .40287 m .42427 .40631 L .41817 .40473 L .656 .78 .939 r
F
.39639 .40185 m .4046 .40316 L .40411 .40287 L F
.4046 .40316 m .42427 .40631 L .40411 .40287 L F
.40138 .39327 m .42446 .39016 L .42146 .38614 L .657 .779 .939 r
F
.39968 .3937 m .4002 .39401 L .40069 .38781 L .912 .629 .494 r
F
.40069 .38781 m .4002 .39401 L .40043 .39415 L F
.401 .38834 m .40069 .38781 L .40043 .39415 L .99 .735 .374 r
F
.39626 .39509 m .40522 .39352 L .40138 .39327 L .657 .779 .939 r
F
.40522 .39352 m .42446 .39016 L .40138 .39327 L F
.3975 .38666 m .39711 .39299 L .39812 .3867 L .735 .467 .523 r
F
.40428 .39646 m .42173 .40294 L .42392 .39982 L .657 .779 .939 r
F
.40805 .39872 m .42173 .40294 L .40428 .39646 L F
.44643 .40394 m .47115 .4116 L .47995 .39959 L .658 .778 .938 r
F
.44643 .40394 m .47995 .39959 L .4522 .39587 L F
.42173 .40294 m .4469 .4107 L .45271 .40261 L .657 .779 .939 r
F
.42173 .40294 m .45271 .40261 L .42458 .39886 L F
.40626 .40165 m .42476 .40561 L .4257 .40126 L .656 .78 .939 r
F
.401 .39552 m .40077 .40153 L .40075 .40181 L 0 0 .006 r
F
.40097 .39584 m .40072 .40206 L .40096 .39598 L F
.40072 .40206 m .40071 .40217 L .40096 .39598 L F
.40007 .38743 m .39968 .3937 L .40069 .38781 L .912 .629 .494 r
F
.3994 .38703 m .39891 .39331 L .39913 .39337 L .814 .537 .519 r
F
.40007 .38743 m .3994 .38703 L .39913 .39337 L .912 .629 .494 r
F
.40007 .38743 m .39913 .39337 L .39968 .3937 L F
.39626 .39509 m .42146 .38614 L .41673 .3827 L .657 .779 .939 r
F
.39968 .3937 m .39913 .39337 L .39886 .39974 L .912 .629 .494 r
F
.40096 .39598 m .40071 .40217 L .4007 .40234 L 0 0 .006 r
F
.401 .39552 m .40075 .40181 L .40097 .39584 L F
.40075 .40181 m .40072 .40206 L .40097 .39584 L F
.39639 .40185 m .40411 .40287 L .4022 .40173 L .656 .78 .939 r
F
.39806 .4064 m .3993 .41821 L .39842 .40585 L F
.39908 .40379 m .39846 .42781 L .39872 .40394 L .484 .259 .497 r
F
.39872 .40394 m .39846 .42781 L .39856 .404 L F
.3979 .40482 m .39806 .4064 L .39842 .40585 L .656 .78 .939 r
F
.39832 .4041 m .39846 .42781 L .3973 .42829 L .484 .259 .497 r
F
.39851 .40436 m .39853 .40434 L .39841 .40409 L .656 .78 .939 r
F
.39832 .4041 m .39841 .40409 L .39841 .40406 L F
.39841 .40406 m .39853 .40434 L .39861 .40429 L F
.39856 .404 m .39846 .42781 L .39832 .4041 L .484 .259 .497 r
F
.39639 .40185 m .40626 .40165 L .40624 .40165 L .656 .78 .939 r
F
.40093 .39499 m .40056 .40118 L .40103 .39517 L .99 .735 .374 r
F
.40056 .40118 m .40064 .40132 L .40103 .39517 L F
.40037 .40086 m .40056 .40118 L .40093 .39499 L F
.40275 .40074 m .4257 .40125 L .40692 .40001 L .656 .78 .939 r
F
.401 .39552 m .40103 .39517 L .40077 .40153 L 0 0 .006 r
F
.40103 .39517 m .40064 .40132 L .40077 .40153 L .99 .735 .374 r
F
.39639 .40185 m .40624 .40165 L .40275 .40074 L .656 .78 .939 r
F
.40624 .40165 m .4257 .40125 L .40275 .40074 L F
.39839 .39318 m .39891 .39331 L .3994 .38703 L .814 .537 .519 r
F
.39878 .38687 m .39785 .39304 L .39839 .39318 L F
.39626 .39509 m .41673 .3827 L .41056 .3801 L .657 .779 .939 r
F
.39891 .39331 m .39841 .39962 L .39913 .39337 L .814 .537 .519 r
F
.39767 .40437 m .39763 .40503 L .3979 .40482 L .656 .78 .939 r
F
.39769 .40419 m .39832 .4041 L .3973 .42829 L .631 .379 .518 r
F
.39841 .39962 m .39859 .39966 L .39913 .39337 L .814 .537 .519 r
F
.39913 .39337 m .39859 .39966 L .39886 .39974 L F
.39968 .3937 m .39886 .39974 L .3993 .4 L .912 .629 .494 r
F
.39711 .39299 m .39762 .39302 L .39812 .3867 L .735 .467 .523 r
F
.39812 .3867 m .39762 .39302 L .39785 .39304 L F
.39626 .39509 m .41056 .3801 L .40339 .37853 L .657 .779 .939 r
F
.39839 .39318 m .39785 .39304 L .39758 .3994 L .814 .537 .519 r
F
.39839 .39318 m .39758 .3994 L .39801 .39951 L F
.4002 .39401 m .39971 .40024 L .40043 .39415 L .912 .629 .494 r
F
.39971 .40024 m .39989 .40035 L .40043 .39415 L F
.40043 .39415 m .39989 .40035 L .40016 .40051 L F
.39839 .39318 m .39801 .39951 L .39891 .39331 L .814 .537 .519 r
F
.39801 .39951 m .39841 .39962 L .39891 .39331 L F
.39785 .39304 m .39731 .39938 L .39758 .3994 L .735 .467 .523 r
F
.40069 .39459 m .40043 .39415 L .40016 .40051 L .99 .735 .374 r
F
.40069 .39459 m .40016 .40051 L .40037 .40086 L F
.39968 .3937 m .3993 .4 L .4002 .39401 L .912 .629 .494 r
F
.3993 .4 m .39971 .40024 L .4002 .39401 L F
.40069 .39459 m .40037 .40086 L .40093 .39499 L .99 .735 .374 r
F
.39745 .39939 m .41072 .3869 L .40353 .38533 L .656 .78 .939 r
F
.39639 .40185 m .39867 .39947 L .39745 .39939 L F
.39867 .39947 m .41072 .3869 L .39745 .39939 L F
.40131 .39735 m .40467 .39886 L .40286 .39712 L .657 .779 .939 r
F
.39867 .39947 m .41689 .38948 L .41072 .3869 L .656 .78 .939 r
F
.39639 .40185 m .40017 .39957 L .39867 .39947 L F
.40017 .39957 m .41689 .38948 L .39867 .39947 L F
.39762 .39302 m .39713 .39937 L .39785 .39304 L .735 .467 .523 r
F
.39713 .39937 m .39731 .39938 L .39785 .39304 L F
.39608 .38656 m .40321 .37184 L .39559 .37141 L .658 .778 .938 r
F
.39688 .38662 m .40321 .37184 L .39608 .38656 L F
.39623 .38668 m .39584 .39303 L .39685 .38661 L .652 .396 .519 r
F
.39584 .39303 m .39615 .393 L .39685 .38661 L F
.39615 .393 m .39635 .39298 L .39685 .38661 L F
.39685 .38661 m .39635 .39298 L .39658 .39295 L F
.39626 .39509 m .39508 .39783 L .39636 .39797 L .657 .779 .939 r
F
.39623 .38668 m .39558 .38675 L .39531 .39308 L .652 .396 .519 r
F
.39626 .39509 m .39526 .39309 L .39426 .39319 L .657 .779 .939 r
F
.39623 .38668 m .39531 .39308 L .39563 .39305 L .652 .396 .519 r
F
.39497 .38693 m .39458 .39331 L .39558 .38675 L .545 .308 .506 r
F
.39458 .39331 m .39509 .39315 L .39558 .38675 L F
.39558 .38675 m .39509 .39315 L .39531 .39308 L F
.39526 .39309 m .39572 .3781 L .38808 .37883 L .657 .779 .939 r
F
.39626 .39509 m .3962 .39299 L .39526 .39309 L F
.39623 .38668 m .39563 .39305 L .39584 .39303 L .652 .396 .519 r
F
.3962 .39299 m .39572 .3781 L .39526 .39309 L .657 .779 .939 r
F
.39584 .39303 m .39503 .39945 L .39545 .39941 L .652 .396 .519 r
F
.39563 .39305 m .39503 .39945 L .39584 .39303 L F
.39563 .39305 m .39531 .39308 L .39503 .39945 L F
.39426 .39319 m .38808 .37883 L .38101 .38068 L .657 .779 .939 r
F
.39526 .39309 m .38808 .37883 L .39426 .39319 L F
.3962 .39299 m .40339 .37853 L .39572 .3781 L F
.39626 .39509 m .39721 .39289 L .3962 .39299 L F
.39721 .39289 m .40339 .37853 L .3962 .39299 L F
.39545 .39941 m .39585 .39937 L .39635 .39298 L .652 .396 .519 r
F
.39545 .39941 m .39635 .39298 L .39615 .393 L F
.39678 .3984 m .39673 .39935 L .39689 .3982 L .735 .467 .523 r
F
.39678 .3984 m .39689 .3982 L .39762 .39302 L F
.39711 .39299 m .39678 .3984 L .39762 .39302 L F
.39673 .39935 m .39713 .39937 L .39762 .39302 L F
.39711 .39299 m .39658 .39295 L .3963 .39932 L F
.39639 .40185 m .39745 .39939 L .39631 .39932 L .656 .78 .939 r
F
.39333 .39394 m .39294 .40038 L .39383 .39361 L .339 .143 .462 r
F
.39294 .40038 m .39333 .40012 L .39383 .39361 L F
.39333 .39394 m .39281 .39429 L .39253 .40066 L F
.39333 .39394 m .39253 .40066 L .39294 .40038 L F
.39178 .40043 m .3751 .39031 L .37057 .39393 L .656 .78 .939 r
F
.39639 .40185 m .39307 .40005 L .39178 .40043 L F
.39307 .40005 m .3751 .39031 L .39178 .40043 L F
.39458 .39331 m .39405 .39347 L .39377 .39983 L .545 .308 .506 r
F
.39458 .39331 m .39377 .39983 L .39419 .39971 L F
.39405 .39347 m .39351 .40001 L .39377 .39983 L .339 .143 .462 r
F
.39383 .39361 m .39333 .40012 L .39405 .39347 L F
.39333 .40012 m .39351 .40001 L .39405 .39347 L F
.39251 .39393 m .37049 .38714 L .39101 .39439 L .657 .779 .939 r
F
.39147 .39518 m .38817 .39525 L .38996 .39619 L F
.39639 .40185 m .38112 .38748 L .3751 .39031 L .656 .78 .939 r
F
.39509 .39315 m .39459 .39959 L .39531 .39308 L .545 .308 .506 r
F
.39459 .39959 m .39476 .39953 L .39531 .39308 L F
.39531 .39308 m .39476 .39953 L .39503 .39945 L F
.39458 .39331 m .39419 .39971 L .39509 .39315 L F
.39419 .39971 m .39459 .39959 L .39509 .39315 L F
.39239 .39457 m .39251 .39393 L .39101 .39439 L .657 .779 .939 r
F
.39309 .39411 m .39251 .39393 L .39239 .39457 L F
.39639 .40185 m .38819 .38563 L .38112 .38748 L .656 .78 .939 r
F
.39419 .39971 m .39377 .39983 L .39274 .42339 L .545 .308 .506 r
F
.39711 .39299 m .3963 .39932 L .39673 .39935 L .735 .467 .523 r
F
.39584 .39303 m .39545 .39941 L .39615 .393 L .652 .396 .519 r
F
.39635 .39298 m .39585 .39937 L .39658 .39295 L F
.39585 .39937 m .39603 .39935 L .39658 .39295 L F
.39658 .39295 m .39603 .39935 L .3963 .39932 L F
.39639 .40185 m .39585 .3849 L .38819 .38563 L .656 .78 .939 r
F
.40467 .39886 m .40905 .39932 L .40805 .39872 L .657 .779 .939 r
F
.39639 .40185 m .42164 .39291 L .41689 .38948 L .656 .78 .939 r
F
.42136 .39459 m .42544 .39486 L .42552 .39451 L .657 .779 .939 r
F
.4157 .39768 m .42392 .39982 L .42458 .39886 L F
.39639 .40185 m .42464 .39693 L .42164 .39291 L .656 .78 .939 r
F
.39673 .39935 m .3963 .39932 L .39529 .42292 L .735 .467 .523 r
F
.39631 .39932 m .39754 .39919 L .39631 .39932 L .656 .78 .939 r
F
.39745 .39939 m .39754 .39919 L .39631 .39932 L F
.39631 .39932 m .40353 .38533 L .39585 .3849 L F
.39754 .39919 m .40353 .38533 L .39631 .39932 L F
.39545 .39941 m .39503 .39945 L .39401 .42301 L .652 .396 .519 r
F
.39713 .39937 m .39529 .42292 L .39731 .39938 L .735 .467 .523 r
F
.39758 .3994 m .39529 .42292 L .39658 .42306 L F
.39731 .39938 m .39529 .42292 L .39758 .3994 L F
.39841 .39962 m .39658 .42306 L .39859 .39966 L .814 .537 .519 r
F
.39886 .39974 m .39658 .42306 L .39787 .42348 L F
.39859 .39966 m .39658 .42306 L .39886 .39974 L F
.40624 .40165 m .4257 .40126 L .4257 .40125 L .656 .78 .939 r
F
.40626 .40165 m .4257 .40126 L .40624 .40165 L F
.4522 .39587 m .47995 .39959 L .48319 .38663 L .658 .778 .938 r
F
.4522 .39587 m .48319 .38663 L .45421 .38721 L F
.42458 .39886 m .45271 .40261 L .45473 .39392 L .657 .779 .939 r
F
.42458 .39886 m .45473 .39392 L .42552 .39451 L F
.40692 .40001 m .4257 .40125 L .42464 .39693 L .656 .78 .939 r
F
.39673 .39935 m .39529 .42292 L .39713 .39937 L .735 .467 .523 r
F
.3993 .4 m .39886 .39974 L .39787 .42348 L .912 .629 .494 r
F
.4022 .40173 m .41817 .40473 L .40626 .40165 L .656 .78 .939 r
F
.40411 .40287 m .41817 .40473 L .4022 .40173 L F
.41817 .40473 m .42476 .40561 L .40626 .40165 L F
.39801 .39951 m .39758 .3994 L .39658 .42306 L .814 .537 .519 r
F
.39908 .40379 m .39947 .40363 L .39846 .42781 L .484 .259 .497 r
F
.39947 .40363 m .39925 .42719 L .39846 .42781 L .286 .104 .449 r
F
.39963 .4035 m .39925 .42719 L .39947 .40363 L F
.39971 .40024 m .39787 .42348 L .39989 .40035 L .912 .629 .494 r
F
.39998 .40324 m .40025 .40304 L .39925 .42719 L .286 .104 .449 r
F
.39974 .40342 m .39925 .42719 L .39963 .4035 L F
.39998 .40324 m .39979 .40946 L .39988 .40331 L F
.39979 .40946 m .39925 .42719 L .39988 .40331 L F
.39988 .40331 m .39925 .42719 L .39974 .40342 L F
.40016 .40051 m .39787 .42348 L .39917 .42439 L .912 .629 .494 r
F
.39989 .40035 m .39787 .42348 L .40016 .40051 L F
.41717 .40647 m .43776 .41767 L .4469 .4107 L .657 .779 .939 r
F
.4046 .40316 m .42191 .40968 L .42427 .40631 L .656 .78 .939 r
F
.40874 .40563 m .42191 .40968 L .4046 .40316 L F
.41817 .40473 m .42427 .40631 L .42476 .40561 L F
.39801 .39951 m .39658 .42306 L .39841 .39962 L .814 .537 .519 r
F
.40025 .40304 m .3997 .42644 L .39925 .42719 L 0 0 .327 r
F
.40034 .40289 m .3997 .42644 L .40025 .40304 L F
.40037 .40086 m .40016 .40051 L .39917 .42439 L .99 .735 .374 r
F
.40041 .4028 m .3997 .42644 L .40034 .40289 L 0 0 .327 r
F
.40041 .40562 m .40959 .4164 L .40672 .41156 L .656 .78 .939 r
F
.40039 .40582 m .40959 .4164 L .40041 .40562 L F
.40055 .40258 m .4007 .40234 L .3997 .42644 L 0 0 .327 r
F
.40055 .40258 m .3997 .42644 L .40041 .4028 L F
.40056 .40118 m .39917 .42439 L .40064 .40132 L .99 .735 .374 r
F
.40257 .40456 m .41734 .4132 L .41911 .41183 L .656 .78 .939 r
F
.40312 .40549 m .41734 .4132 L .40257 .40456 L F
.40874 .40563 m .41911 .41183 L .42191 .40968 L F
.3993 .4 m .39787 .42348 L .39971 .40024 L .912 .629 .494 r
F
.40672 .41156 m .41138 .41594 L .40312 .40549 L .656 .78 .939 r
F
.40037 .40086 m .39917 .42439 L .40056 .40118 L .99 .735 .374 r
F
.39459 .39959 m .39274 .42339 L .39476 .39953 L .545 .308 .506 r
F
.38994 .40099 m .39021 .39995 L .38566 .40043 L .656 .78 .939 r
F
.39178 .40043 m .39021 .39995 L .38994 .40099 L F
.39021 .39995 m .37057 .39393 L .38566 .40043 L F
.39545 .39941 m .39401 .42301 L .39585 .39937 L .652 .396 .519 r
F
.39503 .39945 m .39274 .42339 L .39401 .42301 L .545 .308 .506 r
F
.39476 .39953 m .39274 .42339 L .39503 .39945 L F
.38644 .40205 m .38566 .40043 L .36705 .40244 L .656 .78 .939 r
F
.38994 .40099 m .38566 .40043 L .38644 .40205 L F
.34049 .39811 m .32248 .41462 L .34679 .40595 L .658 .778 .938 r
F
.36819 .39999 m .34024 .40488 L .34659 .41274 L .657 .779 .939 r
F
.36697 .39567 m .34024 .40488 L .36819 .39999 L F
.38566 .40043 m .36783 .39806 L .36706 .40236 L .656 .78 .939 r
F
.38566 .40043 m .36706 .40236 L .36705 .40244 L F
.39585 .39937 m .39401 .42301 L .39603 .39935 L .652 .396 .519 r
F
.39377 .39983 m .39149 .42425 L .39274 .42339 L .339 .143 .462 r
F
.39351 .40001 m .39149 .42425 L .39377 .39983 L F
.38872 .40318 m .38644 .40205 L .37448 .40566 L .656 .78 .939 r
F
.39056 .40196 m .38644 .40205 L .38872 .40318 L F
.38644 .40205 m .36705 .40244 L .37448 .40566 L F
.39419 .39971 m .39274 .42339 L .39459 .39959 L .545 .308 .506 r
F
.3963 .39932 m .39401 .42301 L .39529 .42292 L .652 .396 .519 r
F
.39603 .39935 m .39401 .42301 L .3963 .39932 L F
.39333 .40012 m .39149 .42425 L .39351 .40001 L .339 .143 .462 r
F
.39208 .40224 m .39108 .42629 L .39203 .40187 L .875 .7 .179 r
F
.392 .4017 m .39108 .42629 L .39095 .42539 L F
.39203 .40187 m .39108 .42629 L .392 .4017 L F
.39208 .40224 m .39213 .40251 L .39108 .42629 L F
.39218 .40135 m .39095 .42539 L .39234 .40102 L 0 0 .269 r
F
.39218 .40135 m .392 .4017 L .39095 .42539 L F
.39294 .40038 m .39149 .42425 L .39333 .40012 L .339 .143 .462 r
F
.38872 .40318 m .38743 .40341 L .38825 .4035 L .656 .78 .939 r
F
.38872 .40318 m .38825 .4035 L .39093 .40378 L F
.38743 .40341 m .36827 .40675 L .39093 .40378 L F
.39294 .40038 m .39253 .40066 L .39149 .42425 L .339 .143 .462 r
F
.38297 .407 m .37139 .4107 L .37433 .41274 L .656 .78 .939 r
F
.38297 .407 m .37433 .41274 L .37618 .41403 L F
.38994 .40574 m .37618 .41403 L .38683 .41183 L F
.39234 .40102 m .39095 .42539 L .39242 .40088 L 0 0 .269 r
F
.38683 .41183 m .38233 .41653 L .38422 .41693 L .656 .78 .939 r
F
.38683 .41183 m .38422 .41693 L .3894 .41803 L F
.39253 .40066 m .39095 .42539 L .39149 .42425 L 0 0 .269 r
F
.39242 .40088 m .39095 .42539 L .39253 .40066 L F
.40075 .40181 m .40077 .40153 L .39978 .42554 L 0 0 .006 r
F
.40072 .40206 m .39978 .42554 L .40071 .40217 L F
.4007 .40234 m .39978 .42554 L .3997 .42644 L F
.40071 .40217 m .39978 .42554 L .4007 .40234 L F
.40672 .41156 m .40959 .4164 L .41138 .41594 L .656 .78 .939 r
F
.40075 .40181 m .39978 .42554 L .40072 .40206 L 0 0 .006 r
F
.40077 .40153 m .39917 .42439 L .39978 .42554 L .99 .735 .374 r
F
.40064 .40132 m .39917 .42439 L .40077 .40153 L F
.80283 .81842 m .79843 .81606 L .79894 .81893 L .671 .443 .567 r
F
.80283 .81842 m .80233 .81555 L .79843 .81606 L F
0 g
.79468 .817 m
.79843 .81606 L
s
.68996 .56184 m .70395 .55863 L .70476 .56417 L .799 .538 .543 r
F
.68996 .56184 m .68917 .5563 L .70395 .55863 L F
0 g
.70395 .55863 m
.71662 .55872 L
s
.30469 .43664 m .30473 .42997 L .28611 .42264 L .858 .597 .543 r
F
0 g
.30473 .42997 m
.31922 .4396 L
s
.8066 .81838 m .80233 .81555 L .80283 .81842 L .731 .483 .554 r
F
0 g
.79843 .81606 m
.80233 .81555 L
s
.80233 .81555 m
.80609 .81552 L
s
.8066 .81838 m
.80998 .81882 L
s
.72187 .56981 m .72103 .56427 L .73773 .56216 L .671 .449 .574 r
F
.70558 .56972 m .72103 .56427 L .72187 .56981 L .734 .492 .562 r
F
.70558 .56972 m .70476 .56417 L .72103 .56427 L F
.7123 .55328 m .70476 .56417 L .72103 .56427 L .658 .807 .955 r
F
.55397 .57368 m .55016 .56131 L .54384 .57215 L .658 .806 .954 r
F
.55397 .57368 m .56545 .56365 L .55016 .56131 L F
.75126 .44591 m .77558 .43358 L .74919 .44213 L .655 .782 .942 r
F
.75126 .44591 m .77958 .44121 L .77558 .43358 L F
.69859 .42985 m .67528 .42232 L .66847 .43019 L .656 .78 .94 r
F
.70365 .42643 m .67528 .42232 L .69859 .42985 L F
.27309 .4502 m .26444 .43162 L .25886 .44731 L F
.27309 .4502 m .28597 .43604 L .26444 .43162 L F
.60884 .27088 m .60606 .29577 L .61735 .2737 L .644 .736 .916 r
F
.60884 .27088 m .5892 .29025 L .60606 .29577 L F
.63604 .27468 m .643 .2977 L .66074 .29399 L F
.62662 .27499 m .643 .2977 L .63604 .27468 L F
0 g
.79518 .81987 m
.79894 .81893 L
s
.60209 .25835 m .58972 .28183 L .60921 .26251 L .645 .736 .915 r
F
.60209 .25835 m .57552 .27367 L .58972 .28183 L F
.56369 .28003 m .54818 .30539 L .57453 .29035 L .644 .737 .917 r
F
.56369 .28003 m .53182 .29013 L .54818 .30539 L F
0 g
.54818 .30539 m
.56963 .31742 L
s
.73859 .5677 m .73773 .56216 L .7538 .55797 L .605 .403 .581 r
F
.72187 .56981 m .73773 .56216 L .73859 .5677 L .671 .449 .574 r
F
0 g
.72103 .56427 m
.73773 .56216 L
s
.30385 .56235 m .30493 .5482 L .30518 .55374 L 0 0 .191 r
F
.3041 .56789 m .30385 .56235 L .30518 .55374 L F
.28274 .56079 m .30385 .56235 L .30518 .55374 L .661 .803 .951 r
F
0 g
.29958 .56861 m
.30385 .56235 L
s
.64511 .26438 m .66073 .28554 L .67635 .27894 L .645 .736 .915 r
F
.63621 .26629 m .66073 .28554 L .64511 .26438 L F
.3686 .30652 m .33043 .30411 L .36529 .31186 L .643 .738 .918 r
F
.77877 .43453 m .80135 .41823 L .77476 .42688 L .655 .781 .941 r
F
.77877 .43453 m .80716 .4298 L .80135 .41823 L F
.54319 .56671 m .53293 .55579 L .53224 .56664 L .659 .806 .953 r
F
.54319 .56671 m .54947 .5559 L .53293 .55579 L F
0 g
.80283 .81842 m
.8066 .81838 L
s
.51712 .6991 m .51991 .70711 L .52397 .70086 L .597 .767 .961 r
F
.51712 .6991 m .50968 .7045 L .51991 .70711 L F
0 g
.51991 .70711 m
.5279 .70808 L
s
.5028 .58578 m .48792 .57912 L .47751 .58641 L .658 .807 .955 r
F
.51181 .58184 m .48792 .57912 L .5028 .58578 L F
.43421 .31547 m .46164 .29983 L .43058 .30976 L .643 .738 .918 r
F
.43421 .31547 m .46873 .31135 L .46164 .29983 L F
.48792 .57912 m .47702 .58084 L .47751 .58641 L .377 .232 .554 r
F
0 g
.47095 .59448 m
.47751 .58641 L
s
.48792 .57912 m .48741 .57354 L .47702 .58084 L .377 .232 .554 r
F
0 g
.47047 .58893 m
.47702 .58084 L
s
.54207 .70843 m .5528 .7023 L .55255 .70705 L .597 .381 .558 r
F
.53882 .70174 m .54207 .70843 L .55255 .70705 L .597 .767 .961 r
F
0 g
.53662 .70844 m
.54207 .70843 L
s
.79894 .81893 m
.80283 .81842 L
s
.25898 .44062 m .24181 .42369 L .24396 .43984 L .657 .779 .939 r
F
.25898 .44062 m .26455 .42489 L .24181 .42369 L F
.27929 .57182 m .3041 .56789 L .28296 .56634 L .661 .804 .952 r
F
.25991 .56753 m .27929 .57182 L .28296 .56634 L F
.25678 .56998 m .27929 .57182 L .25991 .56753 L F
.80716 .4298 m .80629 .42314 L .80048 .41154 L .941 .651 .191 r
F
0 g
.80628 .42804 m
.80628 .42739 L
s
.50093 .70077 m .50999 .69975 L .50968 .7045 L .857 .609 .563 r
F
.50093 .70077 m .50124 .69602 L .50999 .69975 L F
.51158 .69183 m .50999 .69975 L .51742 .69434 L .597 .767 .96 r
F
.51158 .69183 m .50124 .69602 L .50999 .69975 L F
0 g
.50999 .69975 m
.51459 .70094 L
s
.7538 .55797 m .75292 .55244 L .76731 .54641 L .527 .349 .584 r
F
0 g
.74936 .55337 m
.75292 .55244 L
s
.45825 .43536 m .47178 .41838 L .47205 .42506 L .347 .192 .524 r
F
.43796 .42437 m .45825 .43536 L .47205 .42506 L .656 .78 .939 r
F
.42608 .42976 m .45825 .43536 L .43796 .42437 L F
0 g
.44051 .44333 m
.45825 .43536 L
s
.74843 .43544 m .76709 .42033 L .74456 .43221 L .655 .781 .941 r
F
.74843 .43544 m .77476 .42688 L .76709 .42033 L F
.67528 .42232 m .64162 .42661 L .66847 .43019 L .656 .78 .94 r
F
.5528 .7023 m .56219 .69489 L .56195 .69963 L .503 .303 .542 r
F
.55255 .70705 m .5528 .7023 L .56195 .69963 L F
.54609 .69605 m .5528 .7023 L .56195 .69963 L .597 .767 .96 r
F
0 g
.54347 .70354 m
.5528 .7023 L
s
.36949 .29824 m .33785 .28501 L .33142 .29584 L .643 .737 .917 r
F
.37496 .29375 m .33785 .28501 L .36949 .29824 L F
.37596 .28559 m .34994 .26779 L .33915 .27689 L .644 .737 .916 r
F
.38318 .2823 m .34994 .26779 L .37596 .28559 L F
.57827 .56802 m .57764 .56248 L .56483 .55809 L .865 .59 .519 r
F
0 g
.57764 .56248 m
.58711 .56857 L
s
.43131 .30147 m .45087 .28122 L .42557 .2964 L .643 .737 .917 r
F
.43131 .30147 m .4623 .29152 L .45087 .28122 L F
.42619 .28822 m .4364 .26481 L .41877 .28416 L .644 .737 .916 r
F
.42619 .28822 m .45131 .27308 L .4364 .26481 L F
.33785 .28501 m .29643 .28804 L .33142 .29584 L .643 .737 .917 r
F
.5212 .56804 m .51623 .55791 L .50059 .56211 L .659 .806 .953 r
F
.53224 .56664 m .51623 .55791 L .5212 .56804 L F
0 g
.6893 .29697 m
.6999 .29476 L
s
.69982 .44317 m .66943 .44353 L .69634 .44707 L .655 .782 .942 r
F
.46936 .30306 m .49369 .28144 L .4623 .29152 L .643 .737 .917 r
F
.46936 .30306 m .50403 .2989 L .49369 .28144 L F
.7437 .4256 m .7553 .40881 L .73832 .42317 L .656 .78 .94 r
F
.7437 .4256 m .76607 .41376 L .7553 .40881 L F
.21565 .45141 m .19901 .43785 L .18231 .44588 L F
.22906 .44794 m .19901 .43785 L .21565 .45141 L F
.53224 .56664 m .53293 .55579 L .51623 .55791 L .659 .806 .953 r
F
.51127 .57627 m .50096 .56755 L .48741 .57354 L .658 .806 .954 r
F
.5217 .5735 m .50096 .56755 L .51127 .57627 L F
.22923 .44124 m .21948 .42582 L .19924 .43112 L .657 .779 .939 r
F
.24396 .43984 m .21948 .42582 L .22923 .44124 L F
.78027 .30594 m .75548 .2894 L .75559 .29767 L .805 .532 .526 r
F
.78044 .31424 m .78027 .30594 L .75559 .29767 L F
0 g
.78027 .30594 m
.80033 .31797 L
s
.69075 .56741 m .70476 .56417 L .70558 .56972 L .799 .538 .543 r
F
.69075 .56741 m .68996 .56184 L .70476 .56417 L F
.70238 .5517 m .70476 .56417 L .7123 .55328 L .658 .807 .955 r
F
.70238 .5517 m .68996 .56184 L .70476 .56417 L F
0 g
.70476 .56417 m
.72103 .56427 L
s
.72407 .55893 m .72187 .56981 L .73859 .5677 L .657 .808 .956 r
F
.71313 .55885 m .72187 .56981 L .72407 .55893 L F
.71313 .55885 m .70558 .56972 L .72187 .56981 L F
.55457 .57923 m .55076 .56691 L .54442 .57771 L .658 .807 .955 r
F
.55457 .57923 m .56607 .56923 L .55076 .56691 L F
.3221 .42815 m .3366 .43121 L .33662 .43789 L .926 .656 .509 r
F
.3221 .42815 m .32211 .42144 L .3366 .43121 L F
.34659 .41274 m .3366 .43121 L .35621 .41934 L .657 .779 .939 r
F
.34659 .41274 m .32211 .42144 L .3366 .43121 L F
0 g
.3366 .43121 m
.34329 .43387 L
s
.28232 .55523 m .3046 .54822 L .28311 .5495 L .662 .802 .95 r
F
.26123 .55365 m .28232 .55523 L .28311 .5495 L F
.33915 .27689 m .30736 .26354 L .29804 .27992 L .644 .737 .916 r
F
.24396 .43984 m .24181 .42369 L .21948 .42582 L .657 .779 .939 r
F
.73859 .5677 m .7538 .55797 L .75469 .56351 L .605 .403 .581 r
F
.73531 .55751 m .73859 .5677 L .75469 .56351 L .657 .808 .956 r
F
.72407 .55893 m .73859 .5677 L .73531 .55751 L F
0 g
.72187 .56981 m
.73859 .5677 L
s
.30469 .43664 m .28611 .42264 L .28604 .42933 L .858 .597 .543 r
F
.30465 .44333 m .30469 .43664 L .28604 .42933 L F
0 g
.30469 .43664 m
.31921 .44624 L
s
.30581 .27161 m .29751 .2798 L .29643 .28804 L 0 0 .232 r
F
0 g
.29654 .28803 m
.29657 .28781 L
s
.30581 .27161 m .30688 .26334 L .29751 .2798 L 0 0 .232 r
F
.3041 .56789 m .30518 .55374 L .30543 .55931 L 0 0 .191 r
F
.28296 .56634 m .3041 .56789 L .30543 .55931 L .661 .804 .952 r
F
0 g
.2985 .57606 m
.3041 .56789 L
s
.69915 .43648 m .67568 .42894 L .66881 .43683 L .655 .781 .941 r
F
.70424 .43306 m .67568 .42894 L .69915 .43648 L F
.54384 .57215 m .53351 .56121 L .53282 .57209 L .658 .806 .954 r
F
.54384 .57215 m .55016 .56131 L .53351 .56121 L F
.62639 .2833 m .62414 .30657 L .64281 .30597 L .644 .737 .917 r
F
.61709 .28201 m .62414 .30657 L .62639 .2833 L F
.61709 .28201 m .60578 .30404 L .62414 .30657 L F
.51127 .6966 m .50968 .7045 L .51712 .6991 L .597 .767 .961 r
F
.51127 .6966 m .50093 .70077 L .50968 .7045 L F
0 g
.50968 .7045 m
.51991 .70711 L
s
.50403 .2989 m .50457 .29063 L .49426 .27314 L .992 .742 .433 r
F
0 g
.50457 .29063 m
.50767 .30864 L
s
.49456 .6914 m .50155 .69128 L .50124 .69602 L .927 .677 .54 r
F
.49456 .6914 m .49488 .68666 L .50155 .69128 L F
0 g
.50155 .69128 m
.50709 .69365 L
s
.55255 .70705 m .56195 .69963 L .56171 .70439 L .503 .303 .542 r
F
.54583 .70081 m .55255 .70705 L .56171 .70439 L .597 .767 .961 r
F
.53882 .70174 m .55255 .70705 L .54583 .70081 L F
0 g
.54207 .70843 m
.55255 .70705 L
s
.50757 .68396 m .49507 .68662 L .50171 .69122 L .598 .766 .96 r
F
.70365 .42643 m .68537 .41541 L .67528 .42232 L .656 .78 .94 r
F
.70996 .42376 m .68537 .41541 L .70365 .42643 L F
.56195 .69963 m .56219 .69489 L .56938 .69109 L .362 .189 .507 r
F
0 g
.55305 .69757 m
.56219 .69489 L
s
.77958 .44121 m .80221 .42495 L .77558 .43358 L .655 .782 .942 r
F
.77958 .44121 m .80803 .43648 L .80221 .42495 L F
.7538 .55797 m .76731 .54641 L .76821 .55195 L .527 .349 .584 r
F
.75469 .56351 m .7538 .55797 L .76821 .55195 L F
.74524 .54911 m .7538 .55797 L .76821 .55195 L .658 .807 .955 r
F
0 g
.74457 .56038 m
.7538 .55797 L
s
.57827 .56802 m .56483 .55809 L .56545 .56365 L .865 .59 .519 r
F
.5789 .57358 m .57827 .56802 L .56545 .56365 L F
0 g
.57827 .56802 m
.58775 .5741 L
s
.19924 .43112 m .18282 .43248 L .18256 .43917 L .467 .271 .53 r
F
.19924 .43112 m .19947 .42441 L .18282 .43248 L F
0 g
.17089 .44269 m
.18282 .43248 L
s
.69994 .2865 m
.71744 .28592 L
s
.25886 .44731 m .24165 .43043 L .24382 .44654 L .656 .78 .94 r
F
.25886 .44731 m .26444 .43162 L .24165 .43043 L F
.75559 .29767 m .75548 .2894 L .72807 .28557 L .733 .473 .535 r
F
0 g
.75548 .2894 m
.7801 .29768 L
s
.80716 .4298 m .80048 .41154 L .80135 .41823 L .941 .651 .191 r
F
.80803 .43648 m .80716 .4298 L .80135 .41823 L F
0 g
.80714 .43472 m
.80714 .43406 L
s
.5217 .5735 m .5167 .56334 L .50096 .56755 L .658 .806 .954 r
F
.53282 .57209 m .5167 .56334 L .5217 .5735 L F
.74919 .44213 m .7679 .42705 L .74532 .43891 L .655 .782 .942 r
F
.74919 .44213 m .77558 .43358 L .7679 .42705 L F
.17495 .56153 m .17877 .5643 L .17884 .56986 L .97 .73 .301 r
F
.17495 .56153 m .17488 .55595 L .17877 .5643 L F
0 g
.17877 .5643 m
.1837 .56889 L
s
.67568 .42894 m .64178 .43324 L .66881 .43683 L .655 .781 .941 r
F
.19685 .55464 m .17908 .56424 L .19934 .56019 L .662 .802 .95 r
F
.19685 .55464 m .17521 .55593 L .17908 .56424 L F
.51181 .58184 m .50149 .57315 L .48792 .57912 L .658 .807 .955 r
F
.52226 .57907 m .50149 .57315 L .51181 .58184 L F
.60166 .26671 m .5892 .29025 L .60884 .27088 L .644 .736 .916 r
F
.60166 .26671 m .57489 .28207 L .5892 .29025 L F
.7032 .55728 m .70558 .56972 L .71313 .55885 L .657 .808 .956 r
F
.7032 .55728 m .69075 .56741 L .70558 .56972 L F
0 g
.70558 .56972 m
.72187 .56981 L
s
.67758 .55744 m .68917 .5563 L .68996 .56184 L .87 .588 .508 r
F
.67758 .55744 m .67681 .55187 L .68917 .5563 L F
0 g
.68917 .5563 m
.69552 .5573 L
s
.60856 .27919 m .60578 .30404 L .61709 .28201 L .644 .737 .917 r
F
.60856 .27919 m .58888 .29852 L .60578 .30404 L F
.53282 .57209 m .53351 .56121 L .5167 .56334 L .658 .806 .954 r
F
.63584 .28299 m .64281 .30597 L .6606 .30227 L .644 .737 .917 r
F
.62639 .2833 m .64281 .30597 L .63584 .28299 L F
.64501 .27277 m .66074 .29399 L .67648 .28738 L .644 .736 .916 r
F
.63604 .27468 m .66074 .29399 L .64501 .27277 L F
.38318 .2823 m .36443 .26105 L .34994 .26779 L .644 .737 .916 r
F
.39169 .28043 m .36443 .26105 L .38318 .2823 L F
.21981 .5673 m .2046 .57632 L .22241 .56979 L .661 .804 .952 r
F
.21981 .5673 m .19933 .57137 L .2046 .57632 L F
.41877 .28416 m .41896 .25916 L .41013 .28139 L .644 .737 .916 r
F
.41877 .28416 m .4364 .26481 L .41896 .25916 L F
.28274 .56079 m .30518 .55374 L .28354 .55504 L .661 .803 .951 r
F
.26152 .55921 m .28274 .56079 L .28354 .55504 L F
.5222 .26421 m .53276 .27362 L .53229 .28185 L .992 .74 .421 r
F
.5222 .26421 m .5227 .25595 L .53276 .27362 L F
0 g
.53276 .27362 m
.53918 .27966 L
s
.73832 .42317 m .74213 .4058 L .73178 .4217 L .656 .78 .94 r
F
.73832 .42317 m .7553 .40881 L .74213 .4058 L F
.22906 .44794 m .21929 .43256 L .19901 .43785 L F
.24382 .44654 m .21929 .43256 L .22906 .44794 L F
.74456 .43221 m .75626 .41537 L .73915 .42978 L .655 .781 .941 r
F
.74456 .43221 m .76709 .42033 L .75626 .41537 L F
.55829 .25154 m .53323 .27347 L .56479 .26336 L .645 .736 .915 r
F
.55829 .25154 m .52323 .25589 L .53323 .27347 L F
.49423 .69616 m .50124 .69602 L .50093 .70077 L .927 .677 .54 r
F
.49423 .69616 m .49456 .6914 L .50124 .69602 L F
.50713 .68874 m .50124 .69602 L .51158 .69183 L .597 .767 .96 r
F
.50713 .68874 m .49456 .6914 L .50124 .69602 L F
0 g
.50124 .69602 m
.50681 .6984 L
s
.71871 .2916 m .7187 .28334 L .73204 .26689 L .124 .002 .428 r
F
0 g
.72185 .28578 m
.7235 .28573 L
s
.71744 .28424 m
.7187 .28334 L
s
.54442 .57771 m .53409 .5668 L .53339 .57766 L .658 .807 .955 r
F
.54442 .57771 m .55076 .56691 L .53409 .5668 L F
.34663 .41946 m .33662 .43789 L .35626 .42605 L .656 .78 .939 r
F
.34663 .41946 m .3221 .42815 L .33662 .43789 L F
0 g
.33662 .43789 m
.35493 .44512 L
s
.56195 .69963 m .56938 .69109 L .56915 .69585 L .362 .189 .507 r
F
.56171 .70439 m .56195 .69963 L .56915 .69585 L F
.5522 .69425 m .56195 .69963 L .56915 .69585 L .597 .767 .96 r
F
.54609 .69605 m .56195 .69963 L .5522 .69425 L F
0 g
.5528 .7023 m
.56195 .69963 L
s
.68894 .26985 m .71826 .28314 L .73153 .26677 L .645 .736 .915 r
F
.67635 .27894 m .71826 .28314 L .68894 .26985 L F
.3686 .30652 m .33687 .29331 L .33043 .30411 L .643 .738 .918 r
F
.37408 .30204 m .33687 .29331 L .3686 .30652 L F
.47178 .41838 m .47152 .41172 L .48037 .39965 L .096 .007 .455 r
F
0 g
.46292 .41819 m
.47152 .41172 L
s
.24382 .44654 m .24165 .43043 L .21929 .43256 L .656 .78 .94 r
F
.30465 .44333 m .28604 .42933 L .28597 .43604 L .858 .597 .543 r
F
0 g
.30465 .44333 m
.3192 .4529 L
s
.37496 .29375 m .34872 .27588 L .33785 .28501 L .643 .737 .917 r
F
.38223 .29045 m .34872 .27588 L .37496 .29375 L F
.43058 .30976 m .45018 .28955 L .42482 .30469 L .643 .738 .918 r
F
.43058 .30976 m .46164 .29983 L .45018 .28955 L F
.42557 .2964 m .43585 .27292 L .41809 .29232 L .643 .737 .917 r
F
.42557 .2964 m .45087 .28122 L .43585 .27292 L F
.33687 .29331 m .29535 .29632 L .33043 .30411 L .643 .738 .918 r
F
.75469 .56351 m .76821 .55195 L .76912 .5575 L .527 .349 .584 r
F
.74611 .55468 m .75469 .56351 L .76912 .5575 L .657 .808 .956 r
F
.73531 .55751 m .75469 .56351 L .74611 .55468 L F
0 g
.73859 .5677 m
.75469 .56351 L
s
.70996 .42376 m .69805 .40997 L .68537 .41541 L .656 .78 .94 r
F
.71708 .42201 m .69805 .40997 L .70996 .42376 L F
.69982 .44317 m .67631 .43565 L .66943 .44353 L .655 .782 .942 r
F
.70492 .43976 m .67631 .43565 L .69982 .44317 L F
.50096 .56755 m .48691 .56797 L .48741 .57354 L .509 .328 .571 r
F
.50096 .56755 m .50043 .56198 L .48691 .56797 L F
0 g
.47653 .57529 m
.48691 .56797 L
s
.673 .30862 m
.69987 .30306 L
s
.77369 .42029 m .78875 .40174 L .76607 .41376 L .656 .78 .94 r
F
.77369 .42029 m .80008 .41167 L .78875 .40174 L F
.5789 .57358 m .56545 .56365 L .56607 .56923 L .865 .59 .519 r
F
0 g
.5789 .57358 m
.5884 .57964 L
s
.40442 .41772 m .41228 .43327 L .42608 .42976 L .656 .78 .939 r
F
.75559 .29767 m .72807 .28557 L .72811 .29384 L .733 .473 .535 r
F
0 g
.72644 .28563 m
.72807 .28557 L
s
.72807 .28557 m
.75548 .2894 L
s
.46873 .31135 m .49311 .28978 L .46164 .29983 L .643 .738 .918 r
F
.46873 .31135 m .50348 .30721 L .49311 .28978 L F
.78044 .31424 m .75559 .29767 L .75569 .30598 L .805 .532 .526 r
F
0 g
.78044 .31424 m
.80055 .32626 L
s
.70424 .43306 m .68584 .42201 L .67568 .42894 L .655 .781 .941 r
F
.71059 .43037 m .68584 .42201 L .70424 .43306 L F
.52226 .57907 m .51726 .56894 L .50149 .57315 L .658 .807 .955 r
F
.53339 .57766 m .51726 .56894 L .52226 .57907 L F
.17501 .56713 m .17884 .56986 L .17891 .57543 L .97 .73 .301 r
F
.17501 .56713 m .17495 .56153 L .17884 .56986 L F
.19672 .56023 m .17884 .56986 L .19923 .56579 L .661 .803 .951 r
F
.19672 .56023 m .17495 .56153 L .17884 .56986 L F
0 g
.17884 .56986 m
.1838 .57446 L
s
.21845 .55335 m .19685 .55464 L .19934 .56019 L .662 .802 .95 r
F
.67528 .42232 m .6517 .41471 L .64162 .42661 L .656 .78 .94 r
F
.67837 .56302 m .68996 .56184 L .69075 .56741 L .87 .588 .508 r
F
.67837 .56302 m .67758 .55744 L .68996 .56184 L F
.69412 .54872 m .68996 .56184 L .70238 .5517 L .658 .807 .955 r
F
.69412 .54872 m .67758 .55744 L .68996 .56184 L F
0 g
.68996 .56184 m
.69636 .56285 L
s
.65193 .42131 m .64121 .42655 L .64178 .43324 L .182 .085 .502 r
F
.65193 .42131 m .65134 .41459 L .64121 .42655 L F
0 g
.63673 .43907 m
.64121 .42655 L
s
.53339 .57766 m .53409 .5668 L .51726 .56894 L .658 .807 .955 r
F
.76821 .55195 m .76731 .54641 L .77909 .53892 L .423 .279 .579 r
F
0 g
.75731 .5506 m
.76731 .54641 L
s
.39169 .28043 m .3816 .25721 L .36443 .26105 L .644 .737 .916 r
F
.40089 .28012 m .3816 .25721 L .39169 .28043 L F
.19901 .43785 m .18256 .43917 L .18231 .44588 L .467 .271 .53 r
F
0 g
.17034 .45605 m
.18231 .44588 L
s
.19901 .43785 m .19924 .43112 L .18256 .43917 L .467 .271 .53 r
F
0 g
.17061 .44936 m
.18256 .43917 L
s
.73178 .4217 m .72749 .40498 L .72454 .4213 L .656 .78 .94 r
F
.73178 .4217 m .74213 .4058 L .72749 .40498 L F
.41013 .28139 m .40023 .25656 L .40089 .28012 L .644 .737 .916 r
F
.41013 .28139 m .41896 .25916 L .40023 .25656 L F
.59676 .25312 m .57552 .27367 L .60209 .25835 L .645 .736 .915 r
F
.59676 .25312 m .56479 .26336 L .57552 .27367 L F
.26123 .55365 m .28311 .5495 L .26158 .55078 L .662 .802 .95 r
F
.33785 .28501 m .30581 .27161 L .29643 .28804 L .643 .737 .917 r
F
.30474 .27993 m .29643 .28804 L .29535 .29632 L 0 0 .232 r
F
0 g
.29545 .29631 m
.29548 .29609 L
s
.30474 .27993 m .30581 .27161 L .29643 .28804 L 0 0 .232 r
F
.80803 .43648 m .80135 .41823 L .80221 .42495 L .941 .651 .191 r
F
0 g
.80797 .44879 m
.80803 .43648 L
s
.38233 .41653 m .38254 .43389 L .3894 .41803 L .656 .78 .939 r
F
.38233 .41653 m .36851 .43095 L .38254 .43389 L F
.65296 .26101 m .67635 .27894 L .68894 .26985 L .645 .736 .915 r
F
.64511 .26438 m .67635 .27894 L .65296 .26101 L F
.28296 .56634 m .30543 .55931 L .28376 .56061 L .661 .804 .952 r
F
.26171 .56478 m .28296 .56634 L .28376 .56061 L F
.25991 .56753 m .28296 .56634 L .26171 .56478 L F
.50682 .69351 m .50093 .70077 L .51127 .6966 L .597 .767 .961 r
F
.50682 .69351 m .49423 .69616 L .50093 .70077 L F
0 g
.50093 .70077 m
.50968 .7045 L
s
.67631 .43565 m .64235 .43996 L .66943 .44353 L .655 .782 .942 r
F
.71708 .42201 m .71243 .40641 L .69805 .40997 L .656 .78 .94 r
F
.72454 .4213 m .71243 .40641 L .71708 .42201 L F
.34994 .26779 m .30736 .26354 L .33915 .27689 L .644 .737 .916 r
F
.56171 .70439 m .56915 .69585 L .56892 .70061 L .362 .189 .507 r
F
.55195 .69902 m .56171 .70439 L .56892 .70061 L .597 .767 .961 r
F
.54583 .70081 m .56171 .70439 L .55195 .69902 L F
0 g
.55255 .70705 m
.56171 .70439 L
s
.50403 .2989 m .49426 .27314 L .49369 .28144 L .992 .742 .433 r
F
.50348 .30721 m .50403 .2989 L .49369 .28144 L F
0 g
.50403 .2989 m
.50714 .31687 L
s
.40089 .28012 m .40023 .25656 L .3816 .25721 L .644 .737 .916 r
F
.46264 .28335 m .47688 .25767 L .45131 .27308 L F
.46264 .28335 m .49379 .27329 L .47688 .25767 L F
.72454 .4213 m .72749 .40498 L .71243 .40641 L .656 .78 .94 r
F
.73915 .42978 m .743 .41236 L .73257 .4283 L .655 .781 .941 r
F
.73915 .42978 m .75626 .41537 L .743 .41236 L F
.74532 .43891 m .75704 .4221 L .7399 .43648 L .655 .782 .942 r
F
.74532 .43891 m .7679 .42705 L .75704 .4221 L F
0 g
.6999 .29476 m
.71744 .29419 L
s
.28311 .5495 m .3046 .54822 L .30152 .53979 L .662 .802 .95 r
F
.30518 .55374 m .30493 .5482 L .30183 .53973 L .929 .692 .208 r
F
0 g
.30407 .55381 m
.30451 .55094 L
s
.75569 .30598 m .75559 .29767 L .72811 .29384 L .733 .473 .535 r
F
0 g
.75559 .29767 m
.78027 .30594 L
s
.50149 .57315 m .48741 .57354 L .48792 .57912 L .509 .328 .571 r
F
0 g
.47751 .58641 m
.48792 .57912 L
s
.50149 .57315 m .50096 .56755 L .48741 .57354 L .509 .328 .571 r
F
0 g
.47702 .58084 m
.48741 .57354 L
s
.56545 .56365 m .56483 .55809 L .54957 .55574 L .797 .539 .548 r
F
0 g
.56483 .55809 m
.57764 .56248 L
s
.4904 .68621 m .49488 .68666 L .49456 .6914 L .99 .751 .475 r
F
.4904 .68621 m .49073 .68145 L .49488 .68666 L F
0 g
.49488 .68666 m
.50005 .69024 L
s
.60136 .27503 m .58888 .29852 L .60856 .27919 L .644 .737 .917 r
F
.60136 .27503 m .57453 .29035 L .58888 .29852 L F
.47178 .41838 m .48037 .39965 L .48065 .40634 L .096 .007 .455 r
F
.47205 .42506 m .47178 .41838 L .48065 .40634 L F
.4469 .4107 m .47178 .41838 L .48065 .40634 L .657 .779 .939 r
F
.43776 .41767 m .47178 .41838 L .4469 .4107 L F
0 g
.46311 .42488 m
.47178 .41838 L
s
.50484 .68049 m .49507 .68662 L .50757 .68396 L .598 .766 .96 r
F
.50484 .68049 m .49094 .68144 L .49507 .68662 L F
.28604 .42933 m .28611 .42264 L .26467 .41819 L .796 .543 .555 r
F
0 g
.28611 .42264 m
.30473 .42997 L
s
.64483 .28109 m .6606 .30227 L .67638 .29568 L .644 .737 .917 r
F
.63584 .28299 m .6606 .30227 L .64483 .28109 L F
.56915 .69585 m .56938 .69109 L .57414 .68642 L .114 0 .425 r
F
0 g
.56219 .69489 m
.56938 .69109 L
s
.55712 .68691 m .5692 .69103 L .57394 .68638 L .598 .766 .96 r
F
.19682 .56582 m .17891 .57543 L .19933 .57137 L .661 .804 .952 r
F
.19682 .56582 m .17501 .56713 L .17891 .57543 L F
0 g
.17891 .57543 m
.18691 .58281 L
s
.71059 .43037 m .69861 .41655 L .68584 .42201 L .655 .781 .941 r
F
.71777 .42861 m .69861 .41655 L .71059 .43037 L F
.52463 .69366 m .51712 .6991 L .52397 .70086 L .597 .767 .961 r
F
.21847 .55893 m .19672 .56023 L .19923 .56579 L .661 .803 .951 r
F
.69493 .55431 m .69075 .56741 L .7032 .55728 L .657 .808 .956 r
F
.69493 .55431 m .67837 .56302 L .69075 .56741 L F
0 g
.69075 .56741 m
.70558 .56972 L
s
.38223 .29045 m .36332 .26913 L .34872 .27588 L .643 .737 .917 r
F
.3908 .28857 m .36332 .26913 L .38223 .29045 L F
.77476 .42688 m .78995 .40828 L .76709 .42033 L .655 .781 .941 r
F
.77476 .42688 m .80135 .41823 L .78995 .40828 L F
.41138 .41594 m .42608 .42976 L .43796 .42437 L .656 .78 .939 r
F
.40442 .41772 m .42608 .42976 L .41138 .41594 L F
.76821 .55195 m .77909 .53892 L .78002 .54447 L .423 .279 .579 r
F
.76912 .5575 m .76821 .55195 L .78002 .54447 L F
.75488 .54505 m .76821 .55195 L .78002 .54447 L .658 .807 .955 r
F
.74524 .54911 m .76821 .55195 L .75488 .54505 L F
0 g
.75814 .55616 m
.76821 .55195 L
s
.5217 .27252 m .53229 .28185 L .53182 .29013 L .992 .74 .421 r
F
.5217 .27252 m .5222 .26421 L .53229 .28185 L F
.55753 .25986 m .53229 .28185 L .56408 .27172 L .644 .736 .916 r
F
.55753 .25986 m .5222 .26421 L .53229 .28185 L F
0 g
.53229 .28185 m
.53877 .28792 L
s
.41809 .29232 m .41827 .26724 L .40939 .28955 L .643 .737 .917 r
F
.41809 .29232 m .43585 .27292 L .41827 .26724 L F
0 g
.72696 .44933 m
.72851 .47294 L
s
.28311 .5495 m .30152 .53979 L .28096 .54389 L .662 .802 .95 r
F
.26158 .55078 m .28311 .5495 L .28096 .54389 L F
.26152 .55921 m .28354 .55504 L .26188 .55633 L .661 .803 .951 r
F
0 g
.71959 .44948 m
.72106 .47282 L
s
.70492 .43976 m .6865 .42874 L .67631 .43565 L .655 .782 .942 r
F
.71129 .43708 m .6865 .42874 L .70492 .43976 L F
.68537 .41541 m .6517 .41471 L .67528 .42232 L .656 .78 .94 r
F
.71871 .2916 m .73204 .26689 L .73208 .27518 L .124 .002 .428 r
F
.68917 .27826 m .71871 .2916 L .73208 .27518 L .644 .736 .916 r
F
.67648 .28738 m .71871 .2916 L .68917 .27826 L F
0 g
.71744 .29249 m
.71871 .2916 L
s
.71871 .2916 m
.71927 .29092 L
s
.67568 .42894 m .65193 .42131 L .64178 .43324 L .655 .781 .941 r
F
.65253 .42805 m .64178 .43324 L .64235 .43996 L .182 .085 .502 r
F
.65253 .42805 m .65193 .42131 L .64178 .43324 L F
0 g
.63728 .44572 m
.64178 .43324 L
s
.73257 .4283 m .72826 .41154 L .72527 .42791 L .655 .781 .941 r
F
.73257 .4283 m .743 .41236 L .72826 .41154 L F
.37408 .30204 m .34777 .2842 L .33687 .29331 L .643 .738 .918 r
F
.38136 .29874 m .34777 .2842 L .37408 .30204 L F
.42482 .30469 m .43512 .28126 L .41732 .30063 L F
.42482 .30469 m .45018 .28955 L .43512 .28126 L F
0 g
.72851 .47294 m
.73121 .51398 L
s
.72106 .47282 m
.7237 .51465 L
s
.26158 .55078 m .28096 .54389 L .26047 .54798 L .662 .802 .95 r
F
.75569 .30598 m .72811 .29384 L .72814 .30216 L .733 .473 .535 r
F
0 g
.72811 .29384 m
.75559 .29767 L
s
.75569 .30598 m
.78044 .31424 L
s
.72189 .29405 m
.72811 .29384 L
s
.71777 .42861 m .71309 .41297 L .69861 .41655 L .655 .781 .941 r
F
.72527 .42791 m .71309 .41297 L .71777 .42861 L F
.30518 .55374 m .30183 .53973 L .30207 .5453 L .929 .692 .208 r
F
.28354 .55504 m .30518 .55374 L .30207 .5453 L .661 .803 .951 r
F
.30543 .55931 m .30518 .55374 L .30207 .5453 L .929 .692 .208 r
F
0 g
.30431 .55937 m
.30475 .55649 L
s
.49007 .69099 m .49456 .6914 L .49423 .69616 L .99 .751 .475 r
F
.49007 .69099 m .4904 .68621 L .49456 .6914 L F
.50439 .68527 m .49456 .6914 L .50713 .68874 L .597 .767 .96 r
F
.50439 .68527 m .4904 .68621 L .49456 .6914 L F
0 g
.49456 .6914 m
.49976 .695 L
s
.5217 .69239 m .51712 .6991 L .52463 .69366 L .597 .767 .961 r
F
.5217 .69239 m .51127 .6966 L .51712 .6991 L F
.56545 .56365 m .54957 .55574 L .55016 .56131 L .797 .539 .548 r
F
.56607 .56923 m .56545 .56365 L .55016 .56131 L F
0 g
.56545 .56365 m
.57827 .56802 L
s
.31242 .40974 m .32211 .41475 L .32211 .42144 L .984 .718 .437 r
F
.31242 .40974 m .31244 .40302 L .32211 .41475 L F
0 g
.32211 .41475 m
.32858 .41914 L
s
.53905 .69451 m .54583 .70081 L .55195 .69902 L .597 .767 .961 r
F
.72527 .42791 m .72826 .41154 L .71309 .41297 L .655 .781 .941 r
F
.56915 .69585 m .57414 .68642 L .57392 .69118 L .114 0 .425 r
F
.56892 .70061 m .56915 .69585 L .57392 .69118 L F
.55699 .69171 m .56915 .69585 L .57392 .69118 L .597 .767 .96 r
F
.5522 .69425 m .56915 .69585 L .55699 .69171 L F
0 g
.56195 .69963 m
.56915 .69585 L
s
.34049 .39811 m .31285 .40295 L .32248 .41462 L .658 .778 .938 r
F
.7399 .43648 m .74376 .41911 L .73331 .43501 L .655 .782 .942 r
F
.7399 .43648 m .75704 .4221 L .74376 .41911 L F
.59629 .26146 m .57489 .28207 L .60166 .26671 L .644 .736 .916 r
F
.59629 .26146 m .56408 .27172 L .57489 .28207 L F
.37618 .41403 m .36851 .43095 L .38233 .41653 L .656 .78 .939 r
F
.37618 .41403 m .35626 .42605 L .36851 .43095 L F
.3908 .28857 m .38063 .26528 L .36332 .26913 L .643 .737 .917 r
F
.40007 .28826 m .38063 .26528 L .3908 .28857 L F
.33687 .29331 m .30474 .27993 L .29535 .29632 L .643 .738 .918 r
F
0 g
.29326 .31397 m
.29535 .29632 L
s
.40939 .28955 m .3994 .26463 L .40007 .28826 L .643 .737 .917 r
F
.40939 .28955 m .41827 .26724 L .3994 .26463 L F
.65292 .26939 m .67648 .28738 L .68917 .27826 L .644 .736 .916 r
F
.64501 .27277 m .67648 .28738 L .65292 .26939 L F
.2186 .56451 m .19933 .57137 L .21981 .5673 L .661 .804 .952 r
F
.2186 .56451 m .19682 .56582 L .19933 .57137 L F
.66847 .55121 m .67681 .55187 L .67758 .55744 L .945 .643 .434 r
F
.66847 .55121 m .6677 .54562 L .67681 .55187 L F
0 g
.67681 .55187 m
.68355 .55429 L
s
.68748 .53885 m .668 .54552 L .67705 .55174 L .658 .806 .954 r
F
.76912 .5575 m .78002 .54447 L .78095 .55004 L .423 .279 .579 r
F
.75578 .55063 m .76912 .5575 L .78095 .55004 L .657 .808 .956 r
F
.74611 .55468 m .76912 .5575 L .75578 .55063 L F
0 g
.75469 .56351 m
.76912 .5575 L
s
.5167 .56334 m .50043 .56198 L .50096 .56755 L .599 .394 .574 r
F
.5167 .56334 m .51615 .55775 L .50043 .56198 L F
0 g
.48691 .56797 m
.50043 .56198 L
s
.28354 .55504 m .30207 .5453 L .28138 .54942 L .661 .803 .951 r
F
.26188 .55633 m .28354 .55504 L .28138 .54942 L F
.47205 .42506 m .48065 .40634 L .48093 .41305 L .096 .007 .455 r
F
.44712 .41741 m .47205 .42506 L .48093 .41305 L .656 .78 .939 r
F
.43796 .42437 m .47205 .42506 L .44712 .41741 L F
0 g
.45825 .43536 m
.47205 .42506 L
s
.21948 .42582 m .19947 .42441 L .19924 .43112 L .584 .366 .55 r
F
.21948 .42582 m .21968 .4191 L .19947 .42441 L F
0 g
.18282 .43248 m
.19947 .42441 L
s
.26171 .56478 m .28376 .56061 L .26207 .56191 L .661 .804 .952 r
F
.28604 .42933 m .26467 .41819 L .26455 .42489 L .796 .543 .555 r
F
.28597 .43604 m .28604 .42933 L .26455 .42489 L F
0 g
.28604 .42933 m
.30469 .43664 L
s
.50348 .30721 m .49369 .28144 L .49311 .28978 L .992 .742 .433 r
F
0 g
.50348 .30721 m
.5066 .32514 L
s
.34872 .27588 m .30581 .27161 L .33785 .28501 L .643 .737 .917 r
F
.71129 .43708 m .69929 .4233 L .6865 .42874 L .655 .782 .942 r
F
.71848 .43532 m .69929 .4233 L .71129 .43708 L F
.40007 .28826 m .3994 .26463 L .38063 .26528 L .643 .737 .917 r
F
.77558 .43358 m .7908 .41503 L .7679 .42705 L .655 .782 .942 r
F
.77558 .43358 m .80221 .42495 L .7908 .41503 L F
.4623 .29152 m .47665 .26576 L .45087 .28122 L .643 .737 .917 r
F
.4623 .29152 m .49369 .28144 L .47665 .26576 L F
0 g
.69987 .30306 m
.71745 .3025 L
s
.71745 .3025 m
.72814 .30216 L
s
.21872 .55047 m .19685 .55464 L .21845 .55335 L .662 .802 .95 r
F
.68584 .42201 m .65193 .42131 L .67568 .42894 L .655 .781 .941 r
F
0 g
.72814 .30216 m
.75569 .30598 L
s
.50408 .69005 m .49423 .69616 L .50682 .69351 L .597 .767 .961 r
F
.50408 .69005 m .49007 .69099 L .49423 .69616 L F
0 g
.49423 .69616 m
.50093 .70077 L
s
.26188 .55633 m .28138 .54942 L .26076 .55353 L .661 .803 .951 r
F
.67631 .43565 m .65253 .42805 L .64235 .43996 L .655 .782 .942 r
F
0 g
.63784 .45241 m
.64235 .43996 L
s
.30543 .55931 m .30207 .5453 L .30232 .55088 L .929 .692 .208 r
F
.28376 .56061 m .30543 .55931 L .30232 .55088 L .661 .804 .952 r
F
0 g
.3041 .56789 m
.30543 .55931 L
s
.56892 .70061 m .57392 .69118 L .57369 .69596 L .114 0 .425 r
F
.55674 .69648 m .56892 .70061 L .57369 .69596 L .597 .767 .961 r
F
.55195 .69902 m .56892 .70061 L .55674 .69648 L F
0 g
.56171 .70439 m
.56892 .70061 L
s
.73331 .43501 m .72899 .41829 L .726 .43462 L .655 .782 .942 r
F
.73331 .43501 m .74376 .41911 L .72899 .41829 L F
.51878 .67955 m .50484 .68049 L .50757 .68396 L .598 .766 .96 r
F
.56607 .56923 m .55016 .56131 L .55076 .56691 L .797 .539 .548 r
F
0 g
.56607 .56923 m
.5789 .57358 L
s
.55016 .56131 m .54957 .55574 L .53294 .55562 L .734 .492 .563 r
F
0 g
.54957 .55574 m
.56483 .55809 L
s
.55712 .68691 m .57394 .68638 L .56025 .68379 L .598 .766 .96 r
F
.38136 .29874 m .3624 .27746 L .34777 .2842 L .643 .738 .918 r
F
.38996 .29688 m .3624 .27746 L .38136 .29874 L F
.55712 .26818 m .53182 .29013 L .56369 .28003 L .644 .737 .917 r
F
.55712 .26818 m .5217 .27252 L .53182 .29013 L F
0 g
.53182 .29013 m
.54818 .30539 L
s
.51948 .69084 m .51127 .6966 L .5217 .69239 L .597 .767 .961 r
F
.51948 .69084 m .50682 .69351 L .51127 .6966 L F
.41732 .30063 m .41749 .27559 L .40859 .29785 L .643 .738 .918 r
F
.41732 .30063 m .43512 .28126 L .41749 .27559 L F
.71848 .43532 m .7138 .41972 L .69929 .4233 L .655 .782 .942 r
F
.726 .43462 m .7138 .41972 L .71848 .43532 L F
.19729 .54887 m .17521 .55593 L .19685 .55464 L .662 .802 .95 r
F
.21872 .55047 m .19729 .54887 L .19685 .55464 L F
.76607 .41376 m .77259 .39418 L .7553 .40881 L .656 .78 .94 r
F
.76607 .41376 m .78875 .40174 L .77259 .39418 L F
.54211 .69361 m .55195 .69902 L .55674 .69648 L .597 .767 .961 r
F
.53905 .69451 m .55195 .69902 L .54211 .69361 L F
.66925 .55681 m .67758 .55744 L .67837 .56302 L .945 .643 .434 r
F
.66925 .55681 m .66847 .55121 L .67758 .55744 L F
.68809 .54452 m .67758 .55744 L .69412 .54872 L .658 .807 .955 r
F
.68809 .54452 m .66847 .55121 L .67758 .55744 L F
0 g
.67758 .55744 m
.68438 .55986 L
s
.31239 .41648 m .32211 .42144 L .3221 .42815 L .984 .718 .437 r
F
.31239 .41648 m .31242 .40974 L .32211 .42144 L F
.34024 .40488 m .32211 .42144 L .34659 .41274 L .657 .779 .939 r
F
.34024 .40488 m .31242 .40974 L .32211 .42144 L F
0 g
.32211 .42144 m
.32863 .42584 L
s
.26047 .54798 m .27599 .5388 L .25795 .54546 L .662 .802 .95 r
F
.26047 .54798 m .28096 .54389 L .27599 .5388 L F
.726 .43462 m .72899 .41829 L .7138 .41972 L .655 .782 .942 r
F
.71872 .2999 m .73208 .27518 L .73213 .28352 L .124 .002 .428 r
F
.6891 .28658 m .71872 .2999 L .73213 .28352 L .644 .737 .917 r
F
.67638 .29568 m .71872 .2999 L .6891 .28658 L F
0 g
.71745 .30079 m
.71872 .2999 L
s
.71872 .2999 m
.71928 .29922 L
s
.51726 .56894 m .50096 .56755 L .50149 .57315 L .599 .394 .574 r
F
0 g
.48792 .57912 m
.50149 .57315 L
s
.51726 .56894 m .5167 .56334 L .50096 .56755 L .599 .394 .574 r
F
0 g
.48741 .57354 m
.50096 .56755 L
s
.28376 .56061 m .30232 .55088 L .2816 .555 L .661 .804 .952 r
F
.26207 .56191 m .28376 .56061 L .2816 .555 L F
.80135 .41823 m .80048 .41154 L .7891 .40156 L .957 .65 .409 r
F
0 g
.80048 .41154 m
.80629 .42314 L
s
.41734 .4132 m .43796 .42437 L .44712 .41741 L .656 .78 .939 r
F
.41138 .41594 m .43796 .42437 L .41734 .4132 L F
.78002 .54447 m .77909 .53892 L .78747 .53043 L .263 .171 .558 r
F
0 g
.76999 .5447 m
.77909 .53892 L
s
.19729 .54887 m .17575 .54725 L .17521 .55593 L .662 .802 .95 r
F
.17549 .55283 m .17488 .55595 L .17495 .56153 L 0 0 .069 r
F
0 g
.17525 .55673 m
.17741 .56138 L
s
.17549 .55283 m .17542 .54723 L .17488 .55595 L 0 0 .069 r
F
.21929 .43256 m .19924 .43112 L .19901 .43785 L .584 .366 .55 r
F
0 g
.18231 .44588 m
.19901 .43785 L
s
.21929 .43256 m .21948 .42582 L .19924 .43112 L .584 .366 .55 r
F
0 g
.18256 .43917 m
.19924 .43112 L
s
.26455 .42489 m .26467 .41819 L .24196 .41697 L .734 .49 .56 r
F
0 g
.26467 .41819 m
.28611 .42264 L
s
.28597 .43604 m .26455 .42489 L .26444 .43162 L .796 .543 .555 r
F
0 g
.28597 .43604 m
.30465 .44333 L
s
.53351 .56121 m .51615 .55775 L .5167 .56334 L .671 .446 .571 r
F
.53351 .56121 m .53294 .55562 L .51615 .55775 L F
0 g
.50043 .56198 m
.51615 .55775 L
s
.21874 .55604 m .19672 .56023 L .21847 .55893 L .661 .803 .951 r
F
.48908 .68079 m .49073 .68145 L .4904 .68621 L .929 .753 .272 r
F
.48908 .68079 m .48941 .67601 L .49073 .68145 L F
0 g
.49073 .68145 m
.49432 .68595 L
s
.504 .67688 m .49094 .68144 L .50484 .68049 L .598 .766 .96 r
F
.504 .67688 m .48963 .67603 L .49094 .68144 L F
.51842 .68432 m .50439 .68527 L .50713 .68874 L .597 .767 .96 r
F
.26207 .56191 m .2816 .555 L .26094 .55911 L .661 .804 .952 r
F
.57392 .69118 m .57414 .68642 L .57612 .68117 L 0 0 .201 r
F
0 g
.56938 .69109 m
.57414 .68642 L
s
.55699 .69171 m .57392 .69118 L .56014 .68859 L .597 .767 .96 r
F
.56025 .68379 m .57394 .68638 L .57591 .68116 L .598 .766 .96 r
F
.55016 .56131 m .53294 .55562 L .53351 .56121 L .734 .492 .563 r
F
0 g
.51615 .55775 m
.53294 .55562 L
s
.53294 .55562 m
.54957 .55574 L
s
.59597 .26979 m .57453 .29035 L .60136 .27503 L .644 .737 .917 r
F
.59597 .26979 m .56369 .28003 L .57453 .29035 L F
.7208 .54782 m .71313 .55885 L .72407 .55893 L .657 .808 .956 r
F
.55076 .56691 m .55016 .56131 L .53351 .56121 L .734 .492 .563 r
F
0 g
.55016 .56131 m
.56545 .56365 L
s
.40208 .3544 m
.40358 .31838 L
s
.6865 .42874 m .65253 .42805 L .67631 .43565 L .655 .782 .942 r
F
.38996 .29688 m .37975 .27362 L .3624 .27746 L .643 .738 .918 r
F
.39925 .29657 m .37975 .27362 L .38996 .29688 L F
.40859 .29785 m .39857 .27298 L .39925 .29657 L F
.40859 .29785 m .41749 .27559 L .39857 .27298 L F
.65275 .27772 m .67638 .29568 L .6891 .28658 L .644 .737 .917 r
F
.64483 .28109 m .67638 .29568 L .65275 .27772 L F
0 g
.39458 .35426 m
.39618 .318 L
s
.5936 .24716 m .56479 .26336 L .59676 .25312 L .645 .736 .915 r
F
.5936 .24716 m .55829 .25154 L .56479 .26336 L F
.63039 .24689 m .62686 .26661 L .62775 .26658 L F
.63121 .24962 m .62775 .26658 L .63621 .26629 L F
.63039 .24689 m .62775 .26658 L .63121 .24962 L F
.63176 .22927 m .63194 .22829 L .6325 .24327 L 0 0 .209 r
F
.63186 .24643 m .63621 .26629 L .64067 .26533 L .645 .736 .915 r
F
.6355 .25137 m .64067 .26533 L .64511 .26438 L F
.63186 .24643 m .64067 .26533 L .6355 .25137 L F
.63173 .24706 m .63621 .26629 L .63186 .24643 L F
.63121 .23009 m .63176 .22927 L .63231 .2442 L .067 0 .41 r
F
.63108 .24592 m .63621 .26629 L .63146 .24588 L .645 .736 .915 r
F
.63055 .24666 m .63621 .26629 L .63108 .24592 L F
.63016 .24613 m .63621 .26629 L .63036 .24599 L F
.63036 .23077 m .6311 .24545 L .63091 .24559 L .328 .148 .478 r
F
.62731 .23154 m .62916 .2313 L .62969 .24605 L .629 .374 .513 r
F
.62731 .23154 m .62969 .24605 L .62825 .24618 L F
.63121 .23009 m .63189 .24479 L .63177 .24496 L .067 0 .41 r
F
.63121 .23009 m .63231 .2442 L .63189 .24479 L F
.63176 .22927 m .6325 .24327 L .63236 .24399 L 0 0 .209 r
F
.63176 .22927 m .63236 .24399 L .63231 .2442 L F
.63194 .22829 m .63149 .22704 L .63205 .24205 L .944 .685 .22 r
F
.6322 .2451 m .63439 .24837 L .63357 .24615 L .645 .736 .915 r
F
.62916 .2313 m .62996 .24595 L .62969 .24605 L .492 .27 .504 r
F
.63036 .24599 m .63055 .24666 L .63108 .24592 L .645 .736 .915 r
F
.63012 .24601 m .63016 .24613 L .63036 .24599 L F
.62916 .2313 m .63036 .23077 L .63091 .24559 L .492 .27 .504 r
F
.63116 .24549 m .63077 .24568 L .63146 .24588 L .645 .736 .915 r
F
.63077 .24568 m .63012 .24601 L .63036 .24599 L F
.63077 .24568 m .63036 .24599 L .63146 .24588 L F
.63036 .23077 m .63121 .23009 L .63177 .24496 L .328 .148 .478 r
F
.63036 .23077 m .63177 .24496 L .6311 .24545 L F
.62916 .2313 m .63091 .24559 L .62996 .24595 L .492 .27 .504 r
F
.62914 .24275 m .63009 .2459 L .63116 .24549 L .645 .736 .915 r
F
.63009 .2459 m .63012 .24601 L .63116 .24549 L F
.6319 .24487 m .63116 .24549 L .6322 .2451 L F
.62914 .24275 m .63112 .24543 L .6319 .24487 L F
.63112 .24543 m .63116 .24549 L .6319 .24487 L F
.63116 .24549 m .64511 .26438 L .6322 .2451 L F
.63146 .24588 m .63173 .24706 L .63186 .24643 L F
.62914 .24275 m .65296 .26101 L .65383 .26037 L F
.63726 .24643 m .65383 .26037 L .65923 .25639 L F
.62914 .24275 m .65383 .26037 L .63726 .24643 L F
.63028 .24704 m .62686 .26661 L .63039 .24689 L F
.63002 .24666 m .62686 .26661 L .63034 .24672 L F
.62882 .24613 m .62879 .24641 L .63012 .24601 L F
.62879 .24641 m .62686 .26661 L .63002 .24666 L F
.62879 .24641 m .63002 .24666 L .63012 .24601 L F
.63434 .24397 m .65923 .25639 L .6635 .25081 L F
.62914 .24275 m .63726 .24643 L .63434 .24397 L F
.63726 .24643 m .65923 .25639 L .63434 .24397 L F
.63149 .22704 m .63032 .22604 L .63088 .24106 L .931 .625 .44 r
F
.62552 .23123 m .62731 .23154 L .62783 .24622 L .755 .473 .507 r
F
.62552 .23123 m .62783 .24622 L .62643 .24594 L F
.62731 .23154 m .62825 .24618 L .62783 .24622 L .629 .374 .513 r
F
.62368 .22995 m .62441 .23066 L .62491 .24528 L .948 .643 .425 r
F
.62328 .22911 m .62368 .22995 L .62418 .24457 L .972 .694 .284 r
F
.62328 .22911 m .62418 .24457 L .62387 .24394 L F
.62818 .25279 m .62394 .25784 L .62686 .26661 L .645 .736 .915 r
F
.62394 .25784 m .62403 .26621 L .62686 .26661 L F
.62723 .25083 m .62392 .25584 L .62818 .25279 L F
.62392 .25584 m .61766 .26532 L .62394 .25784 L F
.62392 .25584 m .62394 .25784 L .62818 .25279 L F
.62806 .24832 m .62692 .25019 L .62856 .24881 L F
.62692 .25019 m .61766 .26532 L .62723 .25083 L F
.62692 .25019 m .62723 .25083 L .62856 .24881 L F
.62724 .24649 m .62689 .24719 L .62871 .24726 L F
.62689 .24719 m .61766 .26532 L .62806 .24832 L F
.62689 .24719 m .62806 .24832 L .62871 .24726 L F
.62441 .23066 m .62552 .23123 L .62603 .24586 L .862 .563 .481 r
F
.62441 .23066 m .62603 .24586 L .62516 .24541 L F
.62552 .23123 m .62643 .24594 L .62603 .24586 L .755 .473 .507 r
F
.62368 .22995 m .62434 .24473 L .62418 .24457 L .948 .643 .425 r
F
.62328 .22911 m .62387 .24394 L .62379 .24376 L .972 .694 .284 r
F
.62368 .22995 m .62491 .24528 L .62434 .24473 L .948 .643 .425 r
F
.62395 .22689 m .62327 .22813 L .62378 .24282 L 0 0 .377 r
F
.62724 .24649 m .61553 .25689 L .61766 .26532 L .645 .736 .915 r
F
.62601 .24585 m .61644 .25534 L .62724 .24649 L F
.61644 .25534 m .60921 .26251 L .61553 .25689 L F
.61644 .25534 m .61553 .25689 L .62724 .24649 L F
.62441 .23066 m .62516 .24541 L .62491 .24528 L .862 .563 .481 r
F
.62914 .24275 m .60209 .25835 L .60921 .26251 L .645 .736 .915 r
F
.62394 .25784 m .61766 .26532 L .62403 .26621 L F
.62684 .26302 m .62666 .25978 L .63233 .25931 L .657 .402 .522 r
F
.6275 .26585 m .61735 .2737 L .62662 .27499 L .644 .736 .916 r
F
.62741 .26583 m .61735 .2737 L .6275 .26585 L F
.62256 .26516 m .62684 .26302 L .62699 .26578 L .731 .459 .516 r
F
.62126 .26248 m .62666 .25978 L .62684 .26302 L F
.62684 .26302 m .63233 .25931 L .63251 .26255 L .657 .402 .522 r
F
.62751 .26576 m .62741 .26583 L .6275 .26585 L .644 .736 .916 r
F
.62344 .2659 m .61735 .2737 L .62751 .26576 L F
.63329 .26556 m .62795 .27495 L .63604 .27468 L F
.62778 .26575 m .62684 .26302 L .63251 .26255 L .657 .402 .522 r
F
.62712 .25478 m .62667 .25971 L .63231 .25924 L .668 .746 .909 r
F
.6273 .25807 m .62684 .26302 L .63251 .26255 L .668 .747 .91 r
F
.63302 .26551 m .63251 .26255 L .6379 .2611 L .575 .34 .522 r
F
.63269 .26558 m .62795 .27495 L .63329 .26556 L .644 .736 .916 r
F
.62985 .26568 m .62974 .26621 L .63269 .26558 L F
.62974 .26621 m .62795 .27495 L .63269 .26558 L F
.63671 .26472 m .6379 .2611 L .6381 .26435 L .575 .34 .522 r
F
.63326 .26546 m .63269 .26558 L .63329 .26556 L .644 .736 .916 r
F
.63302 .26551 m .6379 .2611 L .63671 .26472 L .575 .34 .522 r
F
.63269 .26558 m .63251 .26255 L .63302 .26551 L F
.63052 .25322 m .63089 .25447 L .63135 .25435 L .668 .746 .909 r
F
.63052 .25322 m .63135 .25435 L .63447 .25351 L F
.62946 .24968 m .63052 .25322 L .63447 .25351 L F
.63034 .24672 m .63028 .24704 L .63039 .24689 L .645 .736 .915 r
F
.63012 .24601 m .63002 .24666 L .63034 .24672 L F
.62946 .24968 m .63447 .25351 L .63126 .24919 L .668 .746 .909 r
F
.63089 .25447 m .63231 .25924 L .63766 .2578 L F
.63089 .25447 m .63766 .2578 L .63447 .25351 L F
.62856 .24881 m .62723 .25083 L .62818 .25279 L .645 .736 .915 r
F
.62757 .24984 m .62712 .25478 L .63089 .25447 L .668 .746 .909 r
F
.62757 .24984 m .63089 .25447 L .62946 .24968 L F
.62975 .25292 m .63469 .25679 L .63146 .25246 L .668 .747 .91 r
F
.62966 .25295 m .62971 .25298 L .62975 .25292 L F
.62971 .25298 m .63469 .25679 L .62975 .25292 L F
.63194 .22829 m .63205 .24205 L .6324 .24299 L .944 .685 .22 r
F
.63194 .22829 m .6324 .24299 L .6325 .24327 L F
.63618 .24312 m .6635 .25081 L .66545 .24465 L .645 .736 .915 r
F
.62914 .24275 m .6445 .24635 L .63618 .24312 L F
.6445 .24635 m .6635 .25081 L .63618 .24312 L F
.63183 .24645 m .63218 .2466 L .63234 .2457 L .668 .746 .909 r
F
.63218 .2466 m .63408 .24739 L .63236 .24571 L F
.63218 .2466 m .63236 .24571 L .63234 .2457 L F
.63357 .24615 m .64511 .26438 L .65296 .26101 L .645 .736 .915 r
F
.63439 .24837 m .64511 .26438 L .63357 .24615 L F
.63236 .2457 m .63408 .24739 L .63492 .2462 L .668 .746 .909 r
F
.63236 .24571 m .63408 .24739 L .63236 .2457 L F
.63126 .24919 m .63447 .25351 L .63761 .25195 L F
.63126 .24919 m .63761 .25195 L .63283 .24841 L F
.63128 .24727 m .63126 .24919 L .63283 .24841 L F
.63447 .25351 m .63766 .2578 L .64237 .25548 L F
.63447 .25351 m .64237 .25548 L .63761 .25195 L F
.63182 .25228 m .63785 .25523 L .63304 .25168 L .668 .747 .91 r
F
.63146 .25246 m .63176 .25259 L .63182 .25228 L F
.63176 .25259 m .63785 .25523 L .63182 .25228 L F
.63251 .26255 m .63233 .25931 L .63771 .25786 L .575 .34 .522 r
F
.63251 .26255 m .63771 .25786 L .6379 .2611 L F
.62712 .25478 m .63231 .25924 L .63089 .25447 L .668 .746 .909 r
F
.63109 .25776 m .63251 .26255 L .6379 .2611 L .668 .747 .91 r
F
.63109 .25776 m .6379 .2611 L .63469 .25679 L F
.63581 .26321 m .63604 .27468 L .64109 .2736 L .644 .736 .916 r
F
.62966 .25295 m .63109 .25776 L .63469 .25679 L .668 .747 .91 r
F
.63231 .25735 m .63604 .27468 L .63581 .26321 L .644 .736 .916 r
F
.63175 .25643 m .63604 .27468 L .63231 .25735 L F
.63218 .2466 m .63283 .24841 L .63408 .24739 L .668 .746 .909 r
F
.63189 .24479 m .63214 .24444 L .63223 .24586 L .067 0 .41 r
F
.63196 .24777 m .63283 .24841 L .63218 .2466 L .668 .746 .909 r
F
.63189 .24479 m .63223 .24586 L .63202 .24617 L .067 0 .41 r
F
.63236 .24399 m .63241 .24542 L .63231 .2442 L 0 0 .209 r
F
.63241 .24542 m .63238 .24559 L .63231 .2442 L F
.63236 .2457 m .63297 .24582 L .63252 .24489 L .668 .746 .909 r
F
.63297 .24582 m .63492 .2462 L .63266 .24497 L F
.63297 .24582 m .63266 .24497 L .63252 .24489 L F
.63149 .22704 m .63179 .24182 L .63205 .24205 L .931 .625 .44 r
F
.63248 .24168 m .66493 .23831 L .66196 .23224 L .645 .736 .915 r
F
.62914 .24275 m .63376 .24218 L .63248 .24168 L F
.63376 .24218 m .66493 .23831 L .63248 .24168 L F
.63032 .22604 m .6291 .22559 L .62965 .24058 L .822 .528 .492 r
F
.63238 .24559 m .63237 .24563 L .63231 .2442 L 0 0 .209 r
F
.63237 .24566 m .6325 .24877 L .63249 .24886 L F
.63231 .2442 m .63237 .24563 L .63237 .24566 L F
.63237 .24563 m .6325 .24877 L .63237 .24566 L F
.63268 .24405 m .63529 .24491 L .63517 .24362 L .668 .746 .909 r
F
.6324 .24299 m .6321 .24346 L .63239 .24425 L .944 .685 .22 r
F
.63236 .24399 m .6325 .24327 L .63256 .24469 L 0 0 .209 r
F
.6325 .24327 m .63254 .24466 L .63256 .24469 L .944 .685 .22 r
F
.63214 .24444 m .63234 .2457 L .63223 .24586 L .067 0 .41 r
F
.63236 .24399 m .63244 .2453 L .63241 .24542 L 0 0 .209 r
F
.63236 .24399 m .63256 .24469 L .63244 .2453 L F
.63214 .24444 m .63231 .2442 L .63237 .24566 L .067 0 .41 r
F
.63214 .24444 m .63237 .24566 L .63234 .2457 L F
.62914 .24275 m .62601 .24585 L .62724 .24649 L .645 .736 .915 r
F
.62914 .24275 m .62724 .24649 L .62871 .24726 L F
.63189 .24479 m .63202 .24617 L .63196 .24627 L .067 0 .41 r
F
.63177 .24496 m .63199 .2496 L .63194 .24967 L F
.63208 .25096 m .63182 .25228 L .63304 .25168 L .668 .747 .91 r
F
.63141 .25046 m .63182 .25228 L .63208 .25096 L F
.6311 .24545 m .63177 .24496 L .63182 .24647 L .328 .148 .478 r
F
.63104 .24709 m .63128 .24727 L .63182 .24647 L .668 .746 .909 r
F
.63128 .24727 m .63196 .24777 L .63183 .24646 L F
.63182 .24647 m .63183 .24646 L .63183 .24645 L F
.63128 .24727 m .63183 .24646 L .63182 .24647 L F
.63141 .25046 m .63146 .25246 L .63182 .25228 L .668 .747 .91 r
F
.63106 .24711 m .63059 .2483 L .63128 .24727 L .668 .746 .909 r
F
.62996 .24595 m .63096 .24715 L .63034 .24742 L .492 .27 .504 r
F
.63096 .24715 m .63059 .2483 L .63106 .24711 L .668 .746 .909 r
F
.63004 .24755 m .63019 .24776 L .63096 .24715 L F
.63019 .24776 m .63059 .2483 L .63096 .24715 L F
.63119 .25031 m .63073 .25147 L .63141 .25046 L .668 .747 .91 r
F
.63115 .25032 m .63073 .25147 L .63119 .25031 L F
.63033 .25095 m .63073 .25147 L .63115 .25032 L F
.63108 .25035 m .63115 .25032 L .63117 .25029 L F
.63033 .25095 m .63115 .25032 L .63108 .25035 L F
.63033 .25095 m .62966 .25295 L .63146 .25246 L F
.62871 .24726 m .62806 .24832 L .62856 .24881 L .645 .736 .915 r
F
.63025 .25083 m .62931 .25176 L .63033 .25095 L .668 .747 .91 r
F
.63018 .25075 m .63009 .25085 L .63025 .25083 L F
.63009 .25085 m .62931 .25176 L .63025 .25083 L F
.62643 .24594 m .62783 .24622 L .6279 .24794 L .755 .473 .507 r
F
.629 .24812 m .62757 .24984 L .62946 .24968 L .668 .746 .909 r
F
.62873 .24807 m .62757 .24984 L .629 .24812 L F
.62775 .24796 m .62757 .24984 L .6289 .2478 L F
.62699 .26578 m .62684 .26302 L .62778 .26575 L .657 .402 .522 r
F
.62572 .24965 m .62341 .25442 L .62712 .25478 L .668 .746 .909 r
F
.62401 .24915 m .62341 .25442 L .62572 .24965 L F
.62341 .25442 m .62667 .25971 L .62712 .25478 L F
.62341 .25442 m .62112 .25917 L .62667 .25971 L F
.62417 .25241 m .62357 .25771 L .62589 .25292 L .668 .747 .91 r
F
.62914 .24275 m .61621 .24689 L .60209 .25835 L .645 .736 .915 r
F
.61621 .24689 m .59676 .25312 L .60055 .25684 L F
.61621 .24689 m .60055 .25684 L .60209 .25835 L F
.62529 .22595 m .62395 .22689 L .62446 .24166 L .369 .177 .485 r
F
.62434 .24473 m .62491 .24528 L .62498 .24711 L .948 .643 .425 r
F
.62633 .24839 m .62401 .24915 L .62572 .24965 L .668 .746 .909 r
F
.62606 .24814 m .62401 .24915 L .62633 .24839 L F
.62609 .24765 m .62548 .24758 L .62657 .24789 L F
.62548 .24758 m .62606 .24814 L .62657 .24789 L F
.62657 .24789 m .62606 .24814 L .62633 .24839 L F
.6273 .25807 m .63251 .26255 L .63109 .25776 L .668 .747 .91 r
F
.62776 .2531 m .6273 .25807 L .63109 .25776 L F
.62776 .2531 m .63109 .25776 L .62966 .25295 L F
.62848 .25559 m .62751 .26576 L .62977 .25569 L .644 .736 .916 r
F
.62751 .26576 m .62662 .27499 L .62813 .26574 L F
.62778 .26575 m .63251 .26255 L .63269 .26558 L .657 .402 .522 r
F
.62751 .26576 m .62813 .26574 L .62977 .25569 L .644 .736 .916 r
F
.63021 .25591 m .62662 .27499 L .62795 .27495 L F
.63026 .2555 m .63018 .2559 L .63021 .25591 L F
.63018 .2559 m .62662 .27499 L .63021 .25591 L F
.62563 .24743 m .6255 .24756 L .62609 .24765 L .668 .746 .909 r
F
.6255 .24756 m .62548 .24758 L .62609 .24765 L F
.62548 .24758 m .62504 .24805 L .62606 .24814 L F
.62504 .24805 m .62401 .24915 L .62527 .24853 L F
.62504 .24805 m .62527 .24853 L .62606 .24814 L F
.62327 .22813 m .62328 .22911 L .62379 .24376 L 0 0 .044 r
F
.62327 .22813 m .62379 .24376 L .62378 .24303 L F
.61621 .24689 m .5936 .24716 L .59676 .25312 L .645 .736 .915 r
F
.62914 .24275 m .62118 .24374 L .61621 .24689 L F
.62118 .24374 m .5936 .24716 L .61621 .24689 L F
.62572 .24965 m .62712 .25478 L .62757 .24984 L .668 .746 .909 r
F
.62589 .25292 m .6273 .25807 L .62776 .2531 L .668 .747 .91 r
F
.62516 .24541 m .62603 .24586 L .62609 .24765 L .862 .563 .481 r
F
.6277 .24844 m .62572 .24965 L .62757 .24984 L .668 .746 .909 r
F
.62657 .24789 m .62572 .24965 L .6277 .24844 L F
.62516 .24541 m .62609 .24765 L .62542 .24733 L .862 .563 .481 r
F
.62434 .24473 m .62443 .24659 L .62418 .24457 L .948 .643 .425 r
F
.62548 .24758 m .62258 .24835 L .62401 .24915 L .668 .746 .909 r
F
.62539 .2475 m .62258 .24835 L .62548 .24758 L F
.62472 .24698 m .62457 .24708 L .62563 .24743 L F
.62457 .24708 m .62258 .24835 L .62485 .24766 L F
.62457 .24708 m .62485 .24766 L .62563 .24743 L F
.62387 .24394 m .62395 .2458 L .62379 .24376 L .972 .694 .284 r
F
.62256 .26516 m .62126 .26248 L .62684 .26302 L .731 .459 .516 r
F
.62139 .265 m .62126 .26248 L .62256 .26516 L F
.62589 .25292 m .62357 .25771 L .6273 .25807 L .668 .747 .91 r
F
.62692 .25497 m .62625 .25628 L .6284 .2564 L .644 .736 .916 r
F
.62387 .24753 m .62152 .24731 L .62258 .24835 L .668 .746 .909 r
F
.62443 .24659 m .62427 .24644 L .62418 .24457 L .948 .643 .425 r
F
.62516 .24541 m .62542 .24733 L .62525 .24724 L .862 .563 .481 r
F
.62387 .24394 m .62418 .24457 L .62425 .24642 L .972 .694 .284 r
F
.62387 .24394 m .62425 .24642 L .62395 .2458 L F
.62603 .24586 m .62615 .24766 L .62609 .24765 L .755 .473 .507 r
F
.62418 .24457 m .62427 .24644 L .62425 .24642 L .948 .643 .425 r
F
.62434 .24473 m .62498 .24711 L .62443 .24659 L F
.62516 .24541 m .62525 .24724 L .62491 .24528 L .862 .563 .481 r
F
.62525 .24724 m .62506 .24715 L .62491 .24528 L F
.62506 .24715 m .62502 .24713 L .62491 .24528 L F
.62424 .24641 m .62386 .24643 L .62386 .24656 L .668 .746 .909 r
F
.62592 .25285 m .62417 .25241 L .62589 .25292 L .668 .747 .91 r
F
.62541 .2518 m .62417 .25241 L .62592 .25285 L F
.6262 .25086 m .62519 .25133 L .62675 .25113 L F
.62519 .25133 m .62541 .2518 L .62675 .25113 L F
.62675 .25113 m .62541 .2518 L .62592 .25285 L F
.62126 .26248 m .62108 .25924 L .62666 .25978 L .731 .459 .516 r
F
.62357 .25771 m .62684 .26302 L .6273 .25807 L .668 .747 .91 r
F
.62357 .25771 m .62126 .26248 L .62684 .26302 L F
.62625 .25628 m .62415 .26038 L .62722 .25825 L .644 .736 .916 r
F
.62415 .26038 m .62418 .26301 L .62722 .25825 L F
.62625 .25628 m .62722 .25825 L .6284 .2564 L F
.62806 .25997 m .62387 .26534 L .62751 .26576 L F
.62387 .26534 m .62344 .2659 L .62699 .26578 L F
.62387 .26534 m .62699 .26578 L .62751 .26576 L F
.63026 .2555 m .62795 .27495 L .63126 .25883 L F
.62966 .25633 m .62662 .27499 L .63026 .2555 L F
.62702 .26626 m .62778 .26575 L .6327 .26579 L .657 .402 .522 r
F
.62731 .26607 m .62729 .26577 L .62778 .26575 L F
.62702 .26626 m .62729 .26577 L .62731 .26607 L F
.62702 .26626 m .62699 .26578 L .62729 .26577 L F
.62415 .26038 m .62174 .26511 L .62418 .26301 L .644 .736 .916 r
F
.62174 .26511 m .61735 .2737 L .62264 .26541 L F
.62174 .26511 m .62264 .26541 L .62418 .26301 L F
.61553 .25689 m .61175 .26335 L .61766 .26532 L .645 .736 .915 r
F
.61764 .26375 m .62126 .26248 L .62139 .265 L .804 .517 .503 r
F
.61614 .26097 m .62108 .25924 L .62126 .26248 L F
.61764 .26375 m .61614 .26097 L .62126 .26248 L F
.61626 .26329 m .61614 .26097 L .61764 .26375 L F
.61614 .26097 m .61597 .25773 L .62108 .25924 L F
.62001 .25341 m .62112 .25917 L .62341 .25442 L .668 .746 .909 r
F
.62001 .25341 m .61603 .25766 L .62112 .25917 L F
.62015 .2567 m .62126 .26248 L .62357 .25771 L .668 .747 .91 r
F
.62015 .2567 m .61614 .26097 L .62126 .26248 L F
.62412 .25743 m .61595 .26462 L .62415 .26038 L .644 .736 .916 r
F
.62379 .24376 m .62386 .24563 L .62385 .2456 L .972 .694 .284 r
F
.62472 .24698 m .62386 .24656 L .62387 .24753 L .668 .746 .909 r
F
.62571 .25078 m .62519 .25133 L .6262 .25086 L .668 .747 .91 r
F
.62519 .25133 m .62417 .25241 L .62541 .2518 L F
.62491 .24528 m .62502 .24713 L .62498 .24711 L .862 .563 .481 r
F
.62386 .24643 m .6224 .24585 L .62371 .24649 L .668 .746 .909 r
F
.62395 .2458 m .62386 .24563 L .62379 .24376 L .972 .694 .284 r
F
.62803 .24486 m .62385 .24559 L .62386 .24643 L .668 .746 .909 r
F
.62385 .24559 m .6224 .24585 L .62386 .24643 L F
.62395 .22689 m .62378 .24282 L .6243 .24192 L 0 0 .377 r
F
.62327 .22813 m .62378 .24303 L .62378 .24282 L 0 0 .044 r
F
.6091 .24524 m .59284 .24086 L .5936 .24716 L .645 .736 .915 r
F
.62914 .24275 m .62021 .24229 L .6091 .24524 L F
.62021 .24229 m .59284 .24086 L .6091 .24524 L F
.62659 .22554 m .62529 .22595 L .62581 .2408 L .547 .31 .508 r
F
.62498 .24711 m .62518 .25036 L .62509 .25031 L .862 .563 .481 r
F
.62443 .24659 m .62498 .24711 L .62509 .25031 L .948 .643 .425 r
F
.62565 .25084 m .62499 .25092 L .62519 .25133 L .668 .747 .91 r
F
.62555 .25075 m .62499 .25092 L .62565 .25084 L F
.62519 .25133 m .62399 .25147 L .62417 .25241 L F
.62401 .24915 m .62001 .25341 L .62341 .25442 L .668 .746 .909 r
F
.62399 .25147 m .62274 .25161 L .624 .25231 L .668 .747 .91 r
F
.62399 .25147 m .624 .25231 L .62417 .25241 L F
.62499 .25092 m .62399 .25123 L .62519 .25133 L F
.62399 .25123 m .62274 .25161 L .62399 .25147 L F
.62399 .25123 m .62399 .25147 L .62519 .25133 L F
.62388 .24655 m .62386 .24656 L .62388 .24657 L .668 .746 .909 r
F
.62388 .24655 m .62388 .24657 L .62472 .24698 L F
.62674 .2548 m .62412 .25716 L .62692 .25497 L .644 .736 .916 r
F
.62412 .25716 m .62412 .2574 L .62692 .25497 L F
.61611 .26435 m .61595 .26462 L .61698 .26371 L F
.6169 .26366 m .61698 .26371 L .62692 .25497 L F
.61611 .26435 m .61698 .26371 L .6169 .26366 L F
.62417 .25241 m .62015 .2567 L .62357 .25771 L .668 .747 .91 r
F
.62412 .25716 m .61611 .26435 L .62412 .2574 L .644 .736 .916 r
F
.62713 .25431 m .62667 .25473 L .62723 .25437 L F
.62643 .24594 m .62654 .24773 L .62603 .24586 L .755 .473 .507 r
F
.62667 .25473 m .61618 .26423 L .62674 .2548 L .644 .736 .916 r
F
.61618 .26423 m .61611 .26435 L .62674 .2548 L F
.62667 .25473 m .62674 .2548 L .62723 .25437 L F
.62692 .25497 m .62412 .25743 L .62415 .26038 L F
.62723 .25437 m .62674 .2548 L .62692 .25497 L F
.6261 .25385 m .60884 .27088 L .62737 .2541 L F
.62654 .24773 m .62674 .25094 L .62615 .24766 L .755 .473 .507 r
F
.62674 .25094 m .62638 .25089 L .62615 .24766 L F
.62609 .24765 m .62632 .25088 L .6262 .25086 L F
.62443 .24659 m .62457 .24983 L .62427 .24644 L .948 .643 .425 r
F
.6249 .25022 m .62471 .25035 L .62549 .25069 L .668 .747 .91 r
F
.62471 .25035 m .62398 .25081 L .6249 .25074 L F
.62471 .25035 m .6249 .25074 L .62549 .25069 L F
.62654 .24773 m .62615 .24766 L .62603 .24586 L .755 .473 .507 r
F
.62803 .24486 m .62388 .24655 L .62472 .24698 L .668 .746 .909 r
F
.62395 .2458 m .62408 .24905 L .62386 .24563 L .972 .694 .284 r
F
.6249 .25074 m .62555 .25075 L .62549 .25069 L .668 .747 .91 r
F
.62398 .25081 m .62492 .25077 L .6249 .25074 L F
.62492 .25077 m .62555 .25075 L .6249 .25074 L F
.62398 .25081 m .62399 .25123 L .62499 .25092 L F
.6245 .24976 m .62443 .24969 L .62427 .24644 L .948 .643 .425 r
F
.62457 .24983 m .6245 .24976 L .62427 .24644 L F
.62542 .24733 m .62588 .2507 L .62525 .24724 L .862 .563 .481 r
F
.62789 .25168 m .62589 .25292 L .62776 .2531 L .668 .747 .91 r
F
.62643 .24594 m .6279 .24794 L .62654 .24773 L .755 .473 .507 r
F
.62803 .24486 m .62657 .24789 L .62695 .24808 L .668 .746 .909 r
F
.62775 .24796 m .62695 .24808 L .6277 .24844 L F
.62778 .26575 m .63269 .26558 L .6327 .26579 L .657 .402 .522 r
F
.62848 .25559 m .62977 .25569 L .62896 .25527 L .644 .736 .916 r
F
.62848 .25559 m .62994 .25461 L .62985 .2546 L F
.62825 .24618 m .62856 .25107 L .62783 .24622 L .629 .374 .513 r
F
.62675 .25113 m .62589 .25292 L .62789 .25168 L .668 .747 .91 r
F
.62684 .25096 m .6262 .25086 L .62675 .25113 L F
.62674 .25094 m .62693 .25401 L .62638 .25089 L .755 .473 .507 r
F
.6286 .25435 m .62692 .25497 L .6284 .2564 L .644 .736 .916 r
F
.62839 .2543 m .62692 .25497 L .6286 .25435 L F
.62725 .25433 m .62692 .25497 L .62862 .2542 L F
.62722 .25825 m .61735 .2737 L .62806 .25997 L F
.63126 .25883 m .62985 .26568 L .63269 .26558 L F
.62748 .26132 m .62702 .26626 L .6327 .26579 L .667 .747 .91 r
F
.63 .26372 m .62639 .2833 L .62818 .28324 L .644 .737 .917 r
F
.63131 .26807 m .62818 .28324 L .63584 .28299 L F
.63 .26372 m .62818 .28324 L .63131 .26807 L F
.63186 .2559 m .63488 .26004 L .6359 .25954 L .667 .747 .91 r
F
.63184 .25597 m .63488 .26004 L .63186 .2559 L F
.6379 .2611 m .63771 .25786 L .64245 .25553 L .474 .265 .514 r
F
.6379 .2611 m .64245 .25553 L .64265 .25877 L F
.63469 .25679 m .6379 .2611 L .64265 .25877 L .668 .747 .91 r
F
.63165 .25571 m .6359 .25954 L .63503 .25717 L .667 .747 .91 r
F
.63405 .26026 m .6381 .26435 L .63488 .26004 L F
.63583 .26323 m .6381 .26435 L .63405 .26026 L F
.63138 .25578 m .63488 .26004 L .63165 .25571 L F
.63142 .25585 m .63166 .25686 L .63153 .25604 L .644 .736 .916 r
F
.63166 .25686 m .63604 .27468 L .63175 .25643 L F
.63175 .25643 m .63231 .25735 L .63175 .25642 L F
.63311 .25869 m .63488 .26004 L .63138 .25578 L .667 .747 .91 r
F
.63055 .25408 m .63165 .25571 L .63129 .25349 L F
.6312 .25357 m .63126 .25357 L .6312 .25362 L .328 .148 .478 r
F
.63108 .25035 m .63126 .25352 L .6312 .25357 L F
.63126 .25352 m .63126 .25357 L .6312 .25357 L F
.63183 .24645 m .63196 .24777 L .63218 .2466 L .668 .746 .909 r
F
.63228 .24991 m .63304 .25168 L .63383 .25103 L .668 .747 .91 r
F
.63195 .24966 m .63223 .25018 L .63228 .24991 L F
.63223 .25018 m .63304 .25168 L .63228 .24991 L F
.6323 .24981 m .63383 .25103 L .63358 .25035 L F
.63195 .24966 m .63228 .24991 L .6323 .24981 L F
.63228 .24991 m .63383 .25103 L .6323 .24981 L F
.63253 .24867 m .63237 .24563 L .63238 .24559 L 0 0 .209 r
F
.63128 .24689 m .63167 .24989 L .63118 .24698 L .328 .148 .478 r
F
.63167 .24989 m .63161 .24993 L .63118 .24698 L F
.63189 .24479 m .6321 .24943 L .63177 .24496 L .067 0 .41 r
F
.6321 .24943 m .63205 .24951 L .63177 .24496 L F
.63247 .24893 m .63337 .24978 L .6331 .24905 L .668 .747 .91 r
F
.63244 .24893 m .63247 .24895 L .63247 .24893 L F
.63247 .24895 m .63337 .24978 L .63247 .24893 L F
.63244 .2453 m .63261 .24821 L .63241 .24542 L 0 0 .209 r
F
.63244 .2453 m .63256 .24469 L .63268 .2479 L F
.6323 .24981 m .63358 .25035 L .63247 .24896 L .668 .747 .91 r
F
.63358 .25035 m .63337 .24978 L .63244 .24893 L F
.63244 .2453 m .63268 .2479 L .63261 .24821 L 0 0 .209 r
F
.63261 .24821 m .6326 .24827 L .63241 .24542 L F
.63205 .24951 m .63199 .2496 L .63177 .24496 L .067 0 .41 r
F
.63241 .24542 m .6326 .24827 L .63254 .24858 L 0 0 .209 r
F
.63252 .24868 m .63237 .24563 L .63253 .24867 L F
.63252 .24868 m .6325 .24877 L .63237 .24563 L F
.6289 .2478 m .62873 .24807 L .629 .24812 L .668 .746 .909 r
F
.62825 .24618 m .62969 .24605 L .62975 .24768 L .629 .374 .513 r
F
.62825 .24618 m .62975 .24768 L .62881 .24781 L F
.6311 .24545 m .63118 .24698 L .63091 .24559 L .328 .148 .478 r
F
.63019 .24776 m .62946 .24968 L .63126 .24919 L .668 .746 .909 r
F
.63283 .24841 m .63761 .25195 L .64011 .24992 L F
.63283 .24841 m .64011 .24992 L .63408 .24739 L F
.63387 .24814 m .63515 .24945 L .63552 .24815 L .668 .747 .91 r
F
.63059 .2483 m .63126 .24919 L .63128 .24727 L .668 .746 .909 r
F
.63118 .24698 m .63134 .25015 L .63099 .24713 L .328 .148 .478 r
F
.63134 .25015 m .63116 .25029 L .63099 .24713 L F
.62992 .24798 m .62946 .24968 L .63019 .24776 L .668 .746 .909 r
F
.62897 .24802 m .62946 .24968 L .63004 .24755 L F
.62975 .24768 m .62998 .25083 L .62987 .25088 L .492 .27 .504 r
F
.62979 .24766 m .62998 .25083 L .62975 .24768 L F
.62896 .24825 m .62978 .24841 L .62987 .25088 L .629 .374 .513 r
F
.62881 .24781 m .62978 .24841 L .62896 .24825 L F
.62881 .24781 m .62975 .24768 L .62978 .24841 L F
.62825 .24618 m .62987 .25088 L .62856 .25107 L F
.63096 .24715 m .63114 .25031 L .63108 .25035 L .328 .148 .478 r
F
.62996 .24595 m .6307 .25052 L .63022 .25073 L .492 .27 .504 r
F
.63099 .24713 m .63116 .25029 L .63096 .24715 L .328 .148 .478 r
F
.63129 .25349 m .63136 .25392 L .63153 .25367 L .667 .747 .91 r
F
.62908 .251 m .62914 .2512 L .62987 .25088 L .668 .747 .91 r
F
.62914 .2512 m .62931 .25176 L .63018 .25075 L F
.62931 .25176 m .62966 .25295 L .63033 .25095 L F
.62856 .25107 m .62819 .25112 L .62783 .24622 L .629 .374 .513 r
F
.62674 .25094 m .62812 .25425 L .62693 .25401 L .755 .473 .507 r
F
.62654 .24773 m .62734 .25104 L .62674 .25094 L F
.62918 .25133 m .62776 .2531 L .62966 .25295 L .668 .747 .91 r
F
.62889 .25129 m .62776 .2531 L .62918 .25133 L F
.62794 .25116 m .62776 .2531 L .62908 .251 L F
.62684 .25096 m .62675 .25113 L .62794 .25114 L F
.62734 .25104 m .62812 .25425 L .62674 .25094 L .755 .473 .507 r
F
.62908 .251 m .62889 .25129 L .62918 .25133 L .668 .747 .91 r
F
.6295 .26347 m .62639 .2833 L .63 .26372 L .644 .737 .917 r
F
.62983 .25409 m .62848 .25559 L .62996 .25452 L .644 .736 .916 r
F
.62856 .25107 m .62987 .25088 L .62998 .25408 L .629 .374 .513 r
F
.62984 .25413 m .63035 .25407 L .62998 .25408 L .644 .736 .916 r
F
.62987 .25088 m .63006 .25405 L .62998 .25408 L .492 .27 .504 r
F
.62998 .25083 m .63017 .25401 L .62987 .25088 L F
.63042 .2539 m .63055 .25408 L .6312 .25357 L .667 .747 .91 r
F
.63033 .25394 m .63048 .25414 L .63035 .25394 L F
.62998 .25408 m .63096 .25399 L .6309 .25373 L .644 .736 .916 r
F
.63017 .25401 m .63017 .25401 L .63017 .25401 L .492 .27 .504 r
F
.63017 .25401 m .63017 .25401 L .62987 .25088 L F
.6381 .26435 m .6379 .2611 L .64265 .25877 L .474 .265 .514 r
F
.64265 .25877 m .64245 .25553 L .64622 .25247 L .334 .163 .494 r
F
.6381 .26435 m .64265 .25877 L .64285 .26202 L .474 .265 .514 r
F
.64265 .25877 m .64622 .25247 L .64642 .25571 L .334 .163 .494 r
F
.64285 .26202 m .64265 .25877 L .64642 .25571 L F
.63785 .25523 m .64265 .25877 L .64642 .25571 L .668 .747 .91 r
F
.63469 .25679 m .64265 .25877 L .63785 .25523 L F
.64285 .26202 m .64642 .25571 L .64663 .25896 L .334 .163 .494 r
F
.63805 .25848 m .64285 .26202 L .64663 .25896 L .667 .747 .91 r
F
.63146 .25246 m .63469 .25679 L .63785 .25523 L .668 .747 .91 r
F
.63761 .25195 m .64237 .25548 L .64613 .25243 L .668 .746 .909 r
F
.63785 .25523 m .64642 .25571 L .64037 .25318 L .668 .747 .91 r
F
.63304 .25168 m .63785 .25523 L .64037 .25318 L F
.64663 .25896 m .64642 .25571 L .64897 .25212 L .115 .007 .442 r
F
.64663 .25896 m .64897 .25212 L .64918 .25537 L F
.64057 .25643 m .64663 .25896 L .64918 .25537 L .667 .747 .91 r
F
.63805 .25848 m .64663 .25896 L .64057 .25643 L F
.63323 .25493 m .63805 .25848 L .64057 .25643 L F
.64642 .25571 m .64622 .25247 L .64876 .24888 L .115 .007 .442 r
F
.64642 .25571 m .64876 .24888 L .64897 .25212 L F
.64037 .25318 m .64642 .25571 L .64897 .25212 L .668 .747 .91 r
F
.64057 .25643 m .64918 .25537 L .64226 .25404 L .667 .747 .91 r
F
.63449 .2539 m .64057 .25643 L .64226 .25404 L F
.63323 .25493 m .64057 .25643 L .63449 .2539 L F
.63017 .25401 m .63007 .25406 L .63006 .25405 L .492 .27 .504 r
F
.63017 .25401 m .63006 .25405 L .62987 .25088 L F
.63017 .25401 m .63006 .25405 L .63017 .25401 L F
.65296 .26101 m .68894 .26985 L .65923 .25639 L .645 .736 .915 r
F
.63761 .25195 m .64613 .25243 L .64011 .24992 L .668 .746 .909 r
F
.64011 .24992 m .64613 .25243 L .64866 .24886 L F
.64037 .25318 m .64897 .25212 L .64206 .25079 L .668 .747 .91 r
F
.6343 .25065 m .64037 .25318 L .64206 .25079 L F
.63304 .25168 m .64037 .25318 L .6343 .25065 L F
.63534 .2527 m .64226 .25404 L .64302 .25145 L .667 .747 .91 r
F
.63449 .2539 m .64226 .25404 L .63534 .2527 L F
.63073 .25147 m .63146 .25246 L .63141 .25046 L .668 .747 .91 r
F
.63116 .25029 m .63133 .25346 L .63114 .25031 L .328 .148 .478 r
F
.63133 .25346 m .63131 .25348 L .63114 .25031 L F
.63117 .25029 m .63115 .25032 L .63119 .25031 L .668 .747 .91 r
F
.63134 .25015 m .63149 .25333 L .63116 .25029 L .328 .148 .478 r
F
.63116 .25029 m .63114 .25031 L .63096 .24715 L F
.62996 .24595 m .6306 .24846 L .63036 .24843 L .492 .27 .504 r
F
.6306 .24846 m .63108 .25035 L .63036 .24843 L F
.63036 .24843 m .63108 .25035 L .6307 .25052 L F
.63034 .24742 m .63096 .24715 L .63108 .25035 L F
.63118 .24698 m .63161 .24993 L .63134 .25015 L .328 .148 .478 r
F
.63117 .25029 m .63141 .25046 L .63194 .24967 L .668 .747 .91 r
F
.63141 .25046 m .63208 .25096 L .63195 .24967 L F
.63141 .25046 m .63195 .24967 L .63194 .24967 L F
.63128 .24689 m .63182 .24647 L .63194 .24967 L .328 .148 .478 r
F
.63128 .24689 m .63194 .24967 L .63167 .24989 L F
.63128 .24689 m .63206 .25288 L .63205 .25289 L F
.62914 .24275 m .62882 .24613 L .63012 .24601 L .645 .736 .915 r
F
.62803 .24486 m .63234 .2457 L .63252 .24489 L .668 .746 .909 r
F
.62803 .24486 m .63252 .24489 L .63256 .24469 L F
.6324 .24299 m .63244 .24439 L .6325 .24327 L .944 .685 .22 r
F
.62803 .24486 m .63256 .24469 L .63234 .24411 L .668 .746 .909 r
F
.63244 .24439 m .63254 .24754 L .63252 .24458 L .944 .685 .22 r
F
.63244 .24439 m .63252 .24458 L .6325 .24327 L F
.63254 .24754 m .63258 .24765 L .63253 .24462 L F
.63252 .24458 m .63253 .24462 L .6325 .24327 L F
.63254 .24754 m .63253 .24462 L .63252 .24458 L F
.63035 .25407 m .63096 .25399 L .63034 .25405 L .644 .736 .916 r
F
.63035 .25407 m .63034 .25405 L .62998 .25408 L F
.63004 .24755 m .62992 .24798 L .63019 .24776 L .668 .746 .909 r
F
.62996 .24595 m .63022 .25073 L .62969 .24605 L .492 .27 .504 r
F
.63022 .25073 m .63012 .25077 L .62969 .24605 L F
.6304 .25391 m .63029 .25396 L .62969 .24605 L F
.63029 .25396 m .63017 .25401 L .63017 .25401 L F
.63029 .25396 m .63017 .25401 L .62969 .24605 L F
.65923 .25639 m .68894 .26985 L .69763 .25882 L .645 .736 .915 r
F
.65923 .25639 m .69763 .25882 L .6635 .25081 L F
.64897 .25212 m .64876 .24888 L .64991 .245 L 0 0 .308 r
F
.64897 .25212 m .64991 .245 L .65012 .24825 L F
.64918 .25537 m .64897 .25212 L .65012 .24825 L F
.64011 .24992 m .64866 .24886 L .6418 .24753 L .668 .746 .909 r
F
.6418 .24753 m .64866 .24886 L .6498 .245 L F
.64206 .25079 m .64897 .25212 L .65012 .24825 L .668 .747 .91 r
F
.64918 .25537 m .65012 .24825 L .65033 .2515 L 0 0 .308 r
F
.64226 .25404 m .64918 .25537 L .65033 .2515 L .667 .747 .91 r
F
.64226 .25404 m .65033 .2515 L .64302 .25145 L F
.63534 .2527 m .64302 .25145 L .63571 .25141 L F
.63686 .25148 m .66354 .25916 L .6655 .25298 L .644 .736 .916 r
F
.63022 .25073 m .6304 .25391 L .63012 .25077 L .492 .27 .504 r
F
.63167 .24989 m .63194 .24967 L .63206 .25288 L .328 .148 .478 r
F
.63149 .25333 m .63133 .25346 L .63116 .25029 L F
.62896 .24798 m .62897 .24802 L .62914 .24795 L .668 .746 .909 r
F
.62896 .24798 m .62914 .24795 L .63004 .24755 L F
.62803 .24486 m .62896 .24798 L .63004 .24755 L F
.63255 .25216 m .63209 .25286 L .63289 .25223 L .667 .747 .91 r
F
.6321 .24943 m .63259 .2521 L .63225 .25261 L .067 0 .41 r
F
.63225 .25261 m .63214 .25276 L .63199 .2496 L F
.63208 .25096 m .63223 .25018 L .63195 .24967 L .668 .747 .91 r
F
.63225 .25261 m .63199 .2496 L .63205 .24951 L .067 0 .41 r
F
.63167 .24989 m .63206 .25299 L .63161 .24993 L .328 .148 .478 r
F
.6321 .24943 m .63225 .25261 L .63205 .24951 L .067 0 .41 r
F
.63194 .24967 m .63195 .24967 L .63195 .24966 L .668 .747 .91 r
F
.63199 .2496 m .63214 .25276 L .63194 .24967 L .067 0 .41 r
F
.63214 .25276 m .63215 .25288 L .63214 .25276 L F
.63214 .25276 m .63214 .25276 L .63194 .24967 L F
.63307 .25139 m .63534 .2527 L .63571 .25141 L .667 .747 .91 r
F
.63195 .24966 m .6323 .24981 L .63244 .24893 L .668 .747 .91 r
F
.63208 .25096 m .63304 .25168 L .63223 .25018 L F
.63228 .24917 m .63261 .25223 L .6321 .24943 L .067 0 .41 r
F
.63274 .25139 m .63261 .25207 L .63307 .25139 L .667 .747 .91 r
F
.63196 .24627 m .63228 .24917 L .6321 .24943 L .067 0 .41 r
F
.63202 .24617 m .63231 .24912 L .63196 .24627 L F
.63231 .24912 m .63228 .24917 L .63196 .24627 L F
.63241 .24542 m .63254 .24858 L .63238 .24559 L 0 0 .209 r
F
.63254 .24858 m .63253 .24867 L .63238 .24559 L F
.63202 .24617 m .63223 .24586 L .63242 .24897 L .067 0 .41 r
F
.63202 .24617 m .63242 .24897 L .63231 .24912 L F
.63261 .25207 m .63534 .2527 L .63307 .25139 L .667 .747 .91 r
F
.63255 .25216 m .63259 .25217 L .63261 .25207 L F
.63259 .25217 m .63534 .2527 L .63261 .25207 L F
.63261 .25207 m .63263 .25216 L .63261 .25223 L 0 0 .209 r
F
.63249 .24886 m .63262 .25201 L .63261 .25207 L F
.63262 .25201 m .63263 .25216 L .63261 .25207 L F
.63223 .24586 m .63238 .24597 L .63249 .24886 L .067 0 .41 r
F
.63242 .24897 m .63249 .24886 L .63261 .25223 L F
.63223 .24586 m .63249 .24886 L .63242 .24897 L F
.63258 .24765 m .63264 .24779 L .63254 .24466 L .944 .685 .22 r
F
.63253 .24462 m .63254 .24466 L .6325 .24327 L F
.63258 .24765 m .63254 .24466 L .63253 .24462 L F
.63256 .24469 m .63529 .24491 L .63268 .24405 L .668 .746 .909 r
F
.63252 .24489 m .63263 .24489 L .63256 .24469 L F
.63263 .24489 m .63529 .24491 L .63256 .24469 L F
.63118 .24698 m .63099 .24713 L .63091 .24559 L .328 .148 .478 r
F
.62969 .24605 m .62979 .24766 L .62975 .24768 L .492 .27 .504 r
F
.63234 .2457 m .63237 .24566 L .63252 .24489 L .668 .746 .909 r
F
.63239 .24425 m .63237 .24707 L .63244 .24439 L .944 .685 .22 r
F
.63237 .24707 m .6324 .24714 L .63244 .24439 L F
.63256 .24469 m .63264 .24781 L .63268 .2479 L F
.63244 .24439 m .6324 .24714 L .63254 .24754 L F
.62783 .24622 m .62796 .24793 L .6279 .24794 L .629 .374 .513 r
F
.62803 .24486 m .62775 .24796 L .6289 .2478 L .668 .746 .909 r
F
.63091 .24559 m .63099 .24713 L .63096 .24715 L .328 .148 .478 r
F
.62803 .24486 m .63004 .24755 L .63106 .24711 L .668 .746 .909 r
F
.62996 .24595 m .63091 .24559 L .63096 .24715 L .492 .27 .504 r
F
.6311 .24545 m .63128 .24689 L .63118 .24698 L .328 .148 .478 r
F
.6311 .24545 m .63182 .24647 L .63128 .24689 L F
.62803 .24486 m .63104 .24709 L .63183 .24645 L .668 .746 .909 r
F
.63104 .24709 m .63182 .24647 L .63183 .24645 L F
.63234 .2457 m .63236 .2457 L .63237 .24566 L F
.62803 .24486 m .63234 .24411 L .6321 .24346 L F
.62803 .24486 m .6321 .24346 L .63199 .24337 L F
.62803 .24486 m .63183 .24645 L .63234 .2457 L F
.63149 .22704 m .63088 .24106 L .63179 .24182 L .931 .625 .44 r
F
.63223 .24097 m .66196 .23224 L .65671 .22686 L .645 .736 .915 r
F
.62914 .24275 m .63391 .24123 L .63223 .24097 L F
.63391 .24123 m .66196 .23224 L .63223 .24097 L F
.62822 .24811 m .63217 .24662 L .63145 .24604 L .668 .747 .91 r
F
.62822 .24811 m .63256 .24875 L .63276 .24814 L F
.62822 .24811 m .63244 .24893 L .63256 .24875 L F
.62822 .24811 m .63263 .24814 L .63248 .24736 L F
.62822 .24811 m .63195 .24966 L .63244 .24893 L F
.63732 .24174 m .66545 .24465 L .66493 .23831 L .645 .736 .915 r
F
.62914 .24275 m .6519 .24394 L .63732 .24174 L F
.6519 .24394 m .66545 .24465 L .63732 .24174 L F
.6291 .22559 m .62786 .22543 L .62839 .24039 L .735 .457 .508 r
F
.63254 .24466 m .63264 .24779 L .63256 .24469 L .944 .685 .22 r
F
.63256 .24875 m .6328 .24899 L .63301 .24882 L .668 .747 .91 r
F
.63261 .24821 m .63268 .2479 L .6328 .25111 L 0 0 .209 r
F
.63274 .25139 m .6342 .2514 L .6329 .25058 L .667 .747 .91 r
F
.63279 .25113 m .6328 .25111 L .6328 .2513 L 0 0 .209 r
F
.63261 .24821 m .6328 .25111 L .63279 .25113 L F
.6329 .25058 m .6342 .2514 L .63314 .25053 L .667 .747 .91 r
F
.63264 .24779 m .63273 .25093 L .63264 .24781 L .944 .685 .22 r
F
.63231 .24912 m .63261 .25223 L .63228 .24917 L .067 0 .41 r
F
.63254 .24858 m .63274 .2506 L .63263 .25062 L 0 0 .209 r
F
.63266 .25139 m .63274 .25139 L .63267 .25174 L F
.63261 .24821 m .63279 .25113 L .6326 .24827 L F
.63279 .25113 m .6328 .2513 L .63279 .25113 L F
.63279 .25113 m .63279 .25113 L .6326 .24827 L F
.63244 .24893 m .6328 .24899 L .63256 .24875 L .668 .747 .91 r
F
.6326 .24827 m .63279 .25113 L .63254 .24858 L 0 0 .209 r
F
.63279 .25113 m .6328 .2513 L .63279 .25115 L F
.63279 .25113 m .63279 .25115 L .63254 .24858 L F
.63337 .24819 m .63497 .24889 L .63391 .24785 L .667 .747 .91 r
F
.63264 .25069 m .63273 .25093 L .63264 .24779 L .944 .685 .22 r
F
.62822 .24811 m .63248 .24736 L .63224 .24672 L .668 .747 .91 r
F
.63237 .24707 m .63222 .24667 L .63234 .24988 L .944 .685 .22 r
F
.63237 .24707 m .63234 .24988 L .63235 .24991 L F
.62822 .24811 m .63224 .24672 L .63222 .24667 L .668 .747 .91 r
F
.6321 .24346 m .63212 .24658 L .63222 .24667 L .931 .625 .44 r
F
.63205 .24205 m .63207 .24343 L .6321 .24346 L F
.63207 .24343 m .63212 .24658 L .6321 .24346 L F
.6324 .24299 m .63239 .24425 L .63244 .24439 L .944 .685 .22 r
F
.6321 .24346 m .63517 .24362 L .63206 .24334 L .668 .746 .909 r
F
.63234 .24411 m .6328 .24403 L .6321 .24346 L F
.6328 .24403 m .63517 .24362 L .6321 .24346 L F
.63217 .24662 m .63222 .24667 L .6322 .24661 L .668 .747 .91 r
F
.62822 .24811 m .63222 .24667 L .63217 .24662 L F
.63018 .25075 m .63033 .25095 L .63108 .25035 L F
.63256 .24875 m .63301 .24882 L .63284 .24834 L F
.63263 .24814 m .63268 .2479 L .63248 .24736 L F
.63264 .25069 m .63264 .24779 L .63258 .24765 L .944 .685 .22 r
F
.63254 .24754 m .63264 .25069 L .63258 .24765 L F
.63238 .24997 m .63314 .25053 L .63243 .24995 L .667 .747 .91 r
F
.63267 .25174 m .63264 .25193 L .6325 .24877 L 0 0 .209 r
F
.63215 .25288 m .6321 .25294 L .63194 .24967 L .067 0 .41 r
F
.62856 .25107 m .62998 .25408 L .62876 .25419 L .629 .374 .513 r
F
.6325 .24877 m .63264 .25209 L .63249 .24886 L 0 0 .209 r
F
.63264 .25209 m .63263 .25216 L .63249 .24886 L F
.62796 .24793 m .62841 .25422 L .6279 .24794 L .629 .374 .513 r
F
.62841 .25422 m .62837 .25423 L .6279 .24794 L F
.62748 .26132 m .6327 .26579 L .63128 .26101 L .667 .747 .91 r
F
.6284 .2564 m .62722 .25825 L .62806 .25997 L .644 .736 .916 r
F
.62794 .25635 m .62748 .26132 L .63128 .26101 L .667 .747 .91 r
F
.62794 .25635 m .63128 .26101 L .62984 .25619 L F
.62862 .2542 m .62848 .25559 L .62983 .25409 L .644 .736 .916 r
F
.62837 .25423 m .62835 .25423 L .6279 .24794 L .629 .374 .513 r
F
.62935 .25455 m .62794 .25635 L .62984 .25619 L .667 .747 .91 r
F
.62906 .25451 m .62794 .25635 L .62935 .25455 L F
.62812 .25436 m .62794 .25635 L .62925 .2542 L F
.62954 .26222 m .62841 .26232 L .62964 .26257 L .644 .737 .917 r
F
.62841 .26232 m .62841 .26232 L .62954 .26222 L F
.62841 .26232 m .62836 .26288 L .62964 .26257 L F
.62836 .26288 m .62639 .2833 L .6295 .26347 L F
.62836 .26288 m .6295 .26347 L .62964 .26257 L F
.61329 .26156 m .61614 .26097 L .61626 .26329 L .878 .579 .477 r
F
.61553 .25689 m .60921 .26251 L .61175 .26335 L .645 .736 .915 r
F
.61183 .25858 m .61597 .25773 L .61614 .26097 L .878 .579 .477 r
F
.61643 .26339 m .60166 .26671 L .60884 .27088 L .644 .736 .916 r
F
.61329 .26156 m .61183 .25858 L .61614 .26097 L .878 .579 .477 r
F
.61194 .26077 m .61183 .25858 L .61329 .26156 L F
.61716 .25182 m .61603 .25766 L .62001 .25341 L .668 .746 .909 r
F
.61727 .2551 m .61614 .26097 L .62015 .2567 L .668 .747 .91 r
F
.61183 .25858 m .61166 .25534 L .61597 .25773 L .878 .579 .477 r
F
.61716 .25182 m .61175 .25529 L .61603 .25766 L .668 .746 .909 r
F
.61727 .2551 m .61183 .25858 L .61614 .26097 L .668 .747 .91 r
F
.62544 .2545 m .61254 .26112 L .61643 .26339 L .644 .736 .916 r
F
.61238 .2612 m .60166 .26671 L .61494 .26372 L F
.62274 .25161 m .62015 .2567 L .62417 .25241 L .668 .747 .91 r
F
.62258 .24835 m .62001 .25341 L .62401 .24915 L .668 .746 .909 r
F
.62258 .24835 m .61716 .25182 L .62001 .25341 L F
.62274 .25161 m .61727 .2551 L .62015 .2567 L .668 .747 .91 r
F
.62246 .25477 m .60166 .26671 L .62544 .2545 L .644 .736 .916 r
F
.60981 .25867 m .61183 .25858 L .61194 .26077 L .951 .645 .421 r
F
.62737 .2541 m .62713 .25431 L .62723 .25437 L .644 .736 .916 r
F
.62607 .25617 m .62748 .26132 L .62794 .25635 L .667 .747 .91 r
F
.62801 .25115 m .62824 .25424 L .62812 .25425 L .629 .374 .513 r
F
.62812 .25436 m .62607 .25617 L .62794 .25635 L .667 .747 .91 r
F
.62813 .25113 m .62835 .25423 L .62801 .25115 L .629 .374 .513 r
F
.62835 .25423 m .62827 .25424 L .62801 .25115 L F
.62894 .26228 m .62885 .26228 L .62825 .25434 L F
.62828 .25434 m .62825 .25434 L .62801 .25115 L F
.62894 .26228 m .62825 .25434 L .62828 .25434 L F
.62686 .25454 m .62435 .25566 L .62607 .25617 L .667 .747 .91 r
F
.63114 .25031 m .63131 .25354 L .63108 .25035 L .328 .148 .478 r
F
.63006 .25358 m .63138 .25578 L .63165 .25571 L .667 .747 .91 r
F
.63131 .25354 m .63126 .25357 L .63108 .25035 L .328 .148 .478 r
F
.62868 .25126 m .62902 .25121 L .62898 .25116 L .667 .747 .91 r
F
.63022 .25073 m .6312 .25362 L .6304 .25392 L .492 .27 .504 r
F
.6307 .25052 m .6312 .25362 L .63022 .25073 L F
.6307 .25052 m .63108 .25035 L .6312 .25362 L F
.63134 .25015 m .63206 .25299 L .6315 .2534 L .328 .148 .478 r
F
.63161 .24993 m .63206 .25299 L .63134 .25015 L F
.6323 .24981 m .63247 .24896 L .63244 .24893 L .668 .747 .91 r
F
.63231 .24912 m .63242 .24897 L .63261 .25223 L .067 0 .41 r
F
.63194 .24967 m .6321 .25294 L .63206 .25299 L F
.62902 .25121 m .63262 .25063 L .62898 .25116 L .667 .747 .91 r
F
.62898 .25116 m .63262 .25063 L .63238 .24997 L F
.6287 .25131 m .63262 .25063 L .62868 .25126 L F
.62693 .25401 m .62659 .25395 L .62638 .25089 L .755 .473 .507 r
F
.62856 .25107 m .62876 .25419 L .62819 .25112 L .629 .374 .513 r
F
.62876 .25419 m .62841 .25422 L .62819 .25112 L F
.62794 .25114 m .62675 .25113 L .62789 .25168 L .668 .747 .91 r
F
.62734 .25104 m .62801 .25115 L .62812 .25425 L .755 .473 .507 r
F
.62542 .25048 m .62631 .25389 L .62557 .25351 L .862 .563 .481 r
F
.62549 .25069 m .62555 .25075 L .62581 .25067 L .668 .747 .91 r
F
.62509 .25031 m .62549 .25069 L .62581 .25067 L F
.62581 .25067 m .62555 .25075 L .62565 .25084 L F
.6258 .25066 m .62631 .25389 L .62542 .25048 L .862 .563 .481 r
F
.62588 .2507 m .62631 .25389 L .6258 .25066 L F
.62404 .24896 m .624 .24888 L .62386 .24563 L .972 .694 .284 r
F
.62386 .24563 m .624 .24888 L .62385 .2456 L F
.62325 .2457 m .62077 .24481 L .62091 .24611 L .668 .746 .909 r
F
.624 .24888 m .62399 .24887 L .62385 .2456 L .972 .694 .284 r
F
.62378 .24282 m .62384 .24467 L .62384 .24463 L 0 0 .044 r
F
.62529 .22595 m .62446 .24166 L .62551 .24099 L .369 .177 .485 r
F
.62395 .22689 m .6243 .24192 L .62446 .24166 L 0 0 .377 r
F
.62021 .24229 m .59456 .23464 L .59284 .24086 L .645 .736 .915 r
F
.62914 .24275 m .62347 .24142 L .62021 .24229 L F
.62347 .24142 m .59456 .23464 L .62021 .24229 L F
.6243 .24192 m .62378 .24282 L .62384 .24463 L 0 0 .377 r
F
.62373 .24483 m .62201 .2437 L .62077 .24481 L .668 .746 .909 r
F
.62385 .2456 m .62399 .24887 L .62396 .2488 L .972 .694 .284 r
F
.62384 .24487 m .62396 .24853 L .62395 .24813 L 0 0 .044 r
F
.62378 .24303 m .62384 .24502 L .62384 .24487 L F
.62384 .24502 m .62396 .24853 L .62384 .24487 L F
.62803 .24486 m .62413 .24411 L .62384 .24463 L .668 .746 .909 r
F
.62384 .24483 m .62384 .24463 L .62373 .24483 L F
.62803 .24486 m .62384 .24463 L .62384 .24483 L F
.6243 .24192 m .62384 .24463 L .62418 .24402 L 0 0 .377 r
F
.62378 .24303 m .62379 .24376 L .62385 .2456 L 0 0 .044 r
F
.62378 .24303 m .62385 .2456 L .62384 .24502 L F
.62378 .24303 m .62384 .24487 L .62378 .24282 L F
.62384 .24487 m .62384 .24471 L .62378 .24282 L F
.62803 .24486 m .62384 .24483 L .62385 .24559 L .668 .746 .909 r
F
.6249 .25022 m .62398 .25032 L .62398 .25081 L .668 .747 .91 r
F
.6279 .24794 m .62813 .25113 L .62801 .25115 L .629 .374 .513 r
F
.62803 .24486 m .62695 .24808 L .62775 .24796 L .668 .746 .909 r
F
.62654 .24773 m .6279 .24794 L .62801 .25115 L .755 .473 .507 r
F
.62654 .24773 m .62801 .25115 L .62734 .25104 L F
.62525 .24724 m .6258 .25066 L .62542 .25048 L .862 .563 .481 r
F
.62588 .2507 m .6258 .25066 L .62525 .24724 L F
.62443 .24659 m .62509 .25031 L .62457 .24983 L .948 .643 .425 r
F
.62502 .24713 m .6252 .25037 L .62498 .24711 L .862 .563 .481 r
F
.6252 .25037 m .62536 .2534 L .62518 .25036 L F
.6252 .25037 m .62518 .25036 L .62498 .24711 L F
.62419 .24631 m .62386 .24643 L .62424 .24641 L .668 .746 .909 r
F
.62395 .2458 m .62425 .24642 L .62436 .24962 L .972 .694 .284 r
F
.62395 .2458 m .62436 .24962 L .62421 .24933 L F
.6253 .25042 m .6252 .25037 L .62502 .24713 L .862 .563 .481 r
F
.62492 .25077 m .62499 .25092 L .62555 .25075 L .668 .747 .91 r
F
.6249 .25022 m .62549 .25069 L .62509 .25031 L F
.62533 .25043 m .62502 .24713 L .62506 .24715 L .862 .563 .481 r
F
.62557 .25351 m .6253 .25042 L .62533 .25043 L F
.6253 .25042 m .62502 .24713 L .62533 .25043 L F
.62389 .24973 m .62105 .24936 L .62167 .25057 L .668 .747 .91 r
F
.62395 .24805 m .62384 .24467 L .62384 .24471 L 0 0 .044 r
F
.62408 .24905 m .62404 .24896 L .62386 .24563 L .972 .694 .284 r
F
.62395 .2458 m .62421 .24933 L .62408 .24905 L F
.62581 .25067 m .62571 .25078 L .6262 .25086 L .668 .747 .91 r
F
.62563 .24743 m .62539 .2475 L .62548 .24758 L .668 .746 .909 r
F
.62542 .24733 m .62609 .24765 L .6262 .25086 L .862 .563 .481 r
F
.62588 .2507 m .6262 .25086 L .62631 .25389 L F
.62542 .24733 m .6262 .25086 L .62588 .2507 L F
.62384 .24487 m .62395 .24813 L .62384 .24471 L 0 0 .044 r
F
.62395 .24813 m .62395 .24805 L .62384 .24471 L F
.62384 .24502 m .62385 .2456 L .62396 .2488 L F
.62384 .24502 m .62396 .2488 L .62396 .24853 L F
.62615 .24766 m .62659 .25395 L .62609 .24765 L .755 .473 .507 r
F
.62694 .25438 m .62519 .25477 L .62686 .25454 L .667 .747 .91 r
F
.62659 .25395 m .62654 .25393 L .62609 .24765 L .755 .473 .507 r
F
.62389 .24973 m .62167 .25057 L .6249 .25022 L .668 .747 .91 r
F
.62398 .25081 m .62499 .25092 L .62492 .25077 L F
.62457 .24983 m .62509 .25031 L .62519 .25331 L .948 .643 .425 r
F
.62457 .24983 m .62519 .25331 L .62471 .25284 L F
.62509 .25031 m .62536 .2534 L .62519 .25331 L .862 .563 .481 r
F
.62518 .25036 m .62536 .2534 L .62509 .25031 L F
.6262 .25086 m .62643 .25391 L .62631 .25389 L .755 .473 .507 r
F
.62703 .25419 m .62632 .25407 L .62694 .25438 L .667 .747 .91 r
F
.62632 .25088 m .62654 .25393 L .6262 .25086 L .755 .473 .507 r
F
.62632 .25407 m .62519 .25477 L .62694 .25438 L .667 .747 .91 r
F
.626 .25392 m .62591 .25401 L .62632 .25407 L F
.62591 .25401 m .62519 .25477 L .62632 .25407 L F
.62654 .25393 m .62655 .25411 L .62643 .25391 L .755 .473 .507 r
F
.62519 .25477 m .62435 .25566 L .62686 .25454 L .667 .747 .91 r
F
.62654 .25393 m .62643 .25391 L .6262 .25086 L .755 .473 .507 r
F
.62557 .25351 m .62536 .2534 L .6252 .25037 L .862 .563 .481 r
F
.62557 .25351 m .6252 .25037 L .6253 .25042 L F
.62525 .24724 m .62557 .25351 L .62506 .24715 L F
.62865 .25122 m .62459 .25355 L .62869 .25129 L .644 .736 .916 r
F
.62459 .25355 m .62463 .25356 L .62869 .25129 L F
.62515 .25327 m .62463 .25356 L .62566 .25376 L F
.6261 .25385 m .62246 .25477 L .62544 .2545 L F
.62463 .25356 m .62246 .25477 L .6261 .25385 L F
.62471 .25284 m .62457 .25271 L .62443 .24969 L .948 .643 .425 r
F
.62471 .25284 m .62443 .24969 L .6245 .24976 L F
.62457 .24983 m .62471 .25284 L .6245 .24976 L F
.62433 .24957 m .62396 .24885 L .62397 .2497 L .668 .747 .91 r
F
.62436 .24962 m .62457 .25271 L .62446 .2526 L .948 .643 .425 r
F
.62425 .24642 m .62441 .24968 L .62436 .24962 L F
.62441 .24968 m .62457 .25271 L .62436 .24962 L F
.62152 .24731 m .61716 .25182 L .62258 .24835 L .668 .746 .909 r
F
.6236 .24891 m .62094 .24829 L .62258 .24909 L .668 .747 .91 r
F
.62803 .24486 m .62419 .24631 L .62424 .24641 L .668 .746 .909 r
F
.62384 .24471 m .62384 .24467 L .62378 .24282 L 0 0 .044 r
F
.62413 .24411 m .62197 .24232 L .62113 .24352 L .668 .746 .909 r
F
.62803 .24486 m .62453 .2434 L .62413 .24411 L F
.62427 .24644 m .62443 .24969 L .62425 .24642 L .948 .643 .425 r
F
.62443 .24969 m .62457 .25271 L .62441 .24968 L F
.62443 .24969 m .62441 .24968 L .62425 .24642 L F
.62496 .25019 m .62397 .2497 L .6249 .25022 L .668 .747 .91 r
F
.62822 .24811 m .62431 .24958 L .62496 .25019 L F
.62431 .24958 m .62397 .2497 L .62496 .25019 L F
.62822 .24811 m .62374 .24822 L .6236 .24891 L F
.62822 .24811 m .62398 .24885 L .62433 .24957 L F
.62397 .2497 m .62397 .24977 L .6249 .25022 L F
.62408 .24905 m .62446 .2526 L .6242 .25207 L .972 .694 .284 r
F
.62398 .24885 m .62396 .24885 L .62433 .24957 L .668 .747 .91 r
F
.62421 .24933 m .62446 .2526 L .62408 .24905 L .972 .694 .284 r
F
.62421 .24933 m .62436 .24962 L .62446 .2526 L F
.61503 .24975 m .61175 .25529 L .61716 .25182 L .668 .746 .909 r
F
.61514 .25302 m .61183 .25858 L .61727 .2551 L .668 .747 .91 r
F
.62167 .25057 m .61727 .2551 L .62274 .25161 L F
.62167 .25057 m .61514 .25302 L .61727 .2551 L F
.62865 .25122 m .61609 .25516 L .62246 .25477 L .644 .736 .916 r
F
.61609 .25516 m .61517 .25545 L .61571 .2554 L F
.61609 .25516 m .61571 .2554 L .62246 .25477 L F
.62862 .25116 m .6161 .25515 L .62865 .25122 L F
.6161 .25515 m .61517 .25545 L .61609 .25516 L F
.6161 .25515 m .61609 .25516 L .62865 .25122 L F
.62822 .24811 m .62382 .24808 L .62374 .24822 L .668 .747 .91 r
F
.6243 .24192 m .62435 .24371 L .62446 .24166 L 0 0 .377 r
F
.62435 .24371 m .62445 .24354 L .62446 .24166 L F
.62435 .24371 m .62415 .24748 L .62443 .24698 L F
.6243 .24192 m .62425 .24389 L .62435 .24371 L F
.62425 .24389 m .62415 .24748 L .62435 .24371 L F
.62445 .24354 m .62447 .2435 L .62446 .24166 L F
.6243 .24192 m .62395 .24784 L .62415 .24748 L F
.62453 .2434 m .62452 .24341 L .62413 .24411 L .668 .746 .909 r
F
.62803 .24486 m .62563 .24743 L .62657 .24789 L F
.62822 .24811 m .62423 .24734 L .62382 .24808 L .668 .747 .91 r
F
.62448 .24688 m .62456 .24673 L .62446 .24166 L 0 0 .377 r
F
.62443 .24698 m .62448 .24688 L .62447 .2435 L F
.62443 .24698 m .62447 .2435 L .62445 .24354 L F
.62371 .24649 m .62091 .24611 L .62152 .24731 L .668 .746 .909 r
F
.6224 .24585 m .62091 .24611 L .62371 .24649 L F
.62386 .24643 m .62152 .24731 L .62387 .24753 L F
.62374 .24724 m .62212 .24556 L .62128 .24676 L .668 .747 .91 r
F
.62395 .24803 m .62384 .24467 L .62395 .24805 L 0 0 .044 r
F
.62395 .24803 m .62395 .24793 L .62384 .24467 L F
.62384 .24463 m .62395 .24793 L .62395 .24784 L F
.62384 .24467 m .62395 .24793 L .62384 .24463 L F
.62418 .24402 m .62384 .24463 L .62395 .24784 L 0 0 .377 r
F
.62803 .24486 m .62472 .24698 L .62563 .24743 L .668 .746 .909 r
F
.62822 .24811 m .62463 .24662 L .62423 .24734 L .668 .747 .91 r
F
.62463 .24662 m .62463 .24987 L .62473 .24969 L 0 0 .377 r
F
.62446 .24166 m .62456 .24673 L .62463 .24662 L F
.62456 .24673 m .62463 .24987 L .62463 .24662 L F
.62822 .24811 m .62464 .24661 L .62463 .24662 L .668 .747 .91 r
F
.62423 .24734 m .62463 .24662 L .62374 .24724 L F
.62435 .24371 m .62443 .24698 L .62445 .24354 L 0 0 .377 r
F
.62062 .24075 m .59866 .22894 L .59456 .23464 L .645 .736 .915 r
F
.62914 .24275 m .62435 .24058 L .62062 .24075 L F
.62435 .24058 m .59866 .22894 L .62062 .24075 L F
.62786 .22543 m .62659 .22554 L .62712 .24045 L .65 .39 .512 r
F
.62803 .24486 m .62618 .24237 L .62532 .24285 L .668 .746 .909 r
F
.62618 .24237 m .62587 .24246 L .62532 .24285 L F
.62659 .22554 m .62581 .2408 L .62682 .24053 L .547 .31 .508 r
F
.62529 .22595 m .62551 .24099 L .62581 .2408 L .369 .177 .485 r
F
.62435 .24058 m .60489 .22415 L .59866 .22894 L .645 .736 .915 r
F
.62914 .24275 m .6262 .24049 L .62435 .24058 L F
.6262 .24049 m .60489 .22415 L .62435 .24058 L F
.62551 .24099 m .62452 .24341 L .62553 .2427 L .369 .177 .485 r
F
.62453 .2434 m .62497 .24259 L .62453 .24339 L .668 .746 .909 r
F
.62803 .24486 m .62532 .24285 L .62453 .2434 L F
.62532 .24285 m .62497 .24259 L .62453 .2434 L F
.62551 .24099 m .62553 .2427 L .62581 .2408 L .369 .177 .485 r
F
.60862 .25547 m .60846 .25223 L .61166 .25534 L .951 .645 .421 r
F
.61503 .24975 m .60856 .25219 L .61175 .25529 L .668 .746 .909 r
F
.60862 .25547 m .61166 .25534 L .61183 .25858 L .951 .645 .421 r
F
.61514 .25302 m .60862 .25547 L .61183 .25858 L .668 .747 .91 r
F
.60673 .25185 m .60846 .25223 L .60862 .25547 L .974 .689 .29 r
F
.60748 .25523 m .60673 .25185 L .60862 .25547 L F
.60696 .25506 m .60681 .25394 L .59412 .25739 L .644 .736 .916 r
F
.60735 .25499 m .60684 .254 L .60696 .25506 L F
.60684 .254 m .60681 .25394 L .60696 .25506 L F
.60655 .25142 m .60673 .25185 L .60684 .254 L .771 .587 .018 r
F
.60684 .254 m .60673 .25185 L .60748 .25523 L .974 .689 .29 r
F
.60673 .25185 m .60657 .24861 L .60846 .25223 L F
.61379 .24735 m .60856 .25219 L .61503 .24975 L .668 .746 .909 r
F
.61379 .24735 m .60668 .24859 L .60856 .25219 L F
.61389 .25061 m .60673 .25185 L .60862 .25547 L .668 .747 .91 r
F
.60776 .25368 m .5931 .25548 L .59407 .2573 L .644 .736 .916 r
F
.60776 .25368 m .59407 .2573 L .59412 .25739 L F
.62385 .24559 m .62373 .24483 L .62325 .2457 L .668 .746 .909 r
F
.62373 .24483 m .62077 .24481 L .62325 .2457 L F
.62464 .24661 m .62337 .24453 L .62212 .24556 L .668 .747 .91 r
F
.62822 .24811 m .62544 .24605 L .62464 .24661 L F
.62553 .2427 m .62452 .24341 L .62463 .24662 L .369 .177 .485 r
F
.62553 .2427 m .62463 .24662 L .62512 .24627 L F
.62822 .24811 m .62632 .24556 L .62544 .24605 L .668 .747 .91 r
F
.62632 .24556 m .62598 .24567 L .62544 .24605 L F
.62553 .2427 m .62582 .24249 L .62581 .2408 L .369 .177 .485 r
F
.62786 .22543 m .62712 .24045 L .62811 .24041 L .65 .39 .512 r
F
.62659 .22554 m .62682 .24053 L .62712 .24045 L .547 .31 .508 r
F
.62914 .24275 m .61281 .22063 L .60489 .22415 L .645 .736 .915 r
F
.62682 .24053 m .62581 .2408 L .62587 .24246 L .547 .31 .508 r
F
.62682 .24053 m .62587 .24246 L .62685 .24215 L F
.62682 .24053 m .62685 .24215 L .62712 .24045 L F
.62685 .24215 m .62713 .24206 L .62712 .24045 L F
.62551 .24099 m .62446 .24166 L .62452 .24341 L .369 .177 .485 r
F
.62602 .24216 m .62659 .24002 L .62479 .24051 L .668 .746 .909 r
F
.62803 .24486 m .6272 .24205 L .62602 .24216 L F
.6272 .24205 m .62659 .24002 L .62602 .24216 L F
.62786 .22543 m .62811 .24041 L .62839 .24039 L .65 .39 .512 r
F
.6291 .22559 m .62839 .24039 L .62937 .24054 L .735 .457 .508 r
F
.62914 .24275 m .62189 .21862 L .61281 .22063 L .645 .736 .915 r
F
.62811 .24041 m .62712 .24045 L .62717 .24205 L .65 .39 .512 r
F
.6242 .25207 m .62412 .25192 L .624 .24888 L .972 .694 .284 r
F
.6242 .25207 m .624 .24888 L .62404 .24896 L F
.62408 .24905 m .6242 .25207 L .62404 .24896 L F
.62396 .2488 m .62412 .25192 L .62406 .25179 L F
.62399 .24887 m .62412 .25192 L .62396 .2488 L F
.62396 .24853 m .62396 .2488 L .62406 .25179 L 0 0 .044 r
F
.62395 .24813 m .62406 .25179 L .62405 .25117 L F
.62396 .24853 m .62406 .25179 L .62395 .24813 L F
.624 .24888 m .62412 .25192 L .62399 .24887 L .972 .694 .284 r
F
.62858 .25111 m .62102 .25204 L .62859 .25112 L .644 .736 .916 r
F
.62102 .25204 m .621 .25205 L .62859 .25112 L F
.61389 .25061 m .60862 .25547 L .61514 .25302 L .668 .747 .91 r
F
.62152 .24731 m .61503 .24975 L .61716 .25182 L .668 .746 .909 r
F
.62105 .24936 m .61514 .25302 L .62167 .25057 L .668 .747 .91 r
F
.62105 .24936 m .61389 .25061 L .61514 .25302 L F
.60781 .25367 m .60776 .25368 L .62859 .25112 L .644 .736 .916 r
F
.62859 .25112 m .62099 .25206 L .62 .25269 L F
.62415 .26038 m .61764 .26375 L .62174 .26511 L F
.62256 .26516 m .62699 .26578 L .62702 .26626 L .731 .459 .516 r
F
.62375 .26096 m .62702 .26626 L .62748 .26132 L .667 .747 .91 r
F
.62714 .26244 m .62685 .2627 L .62695 .26281 L .644 .737 .917 r
F
.62686 .25454 m .62607 .25617 L .62812 .25436 L .667 .747 .91 r
F
.62607 .25617 m .62375 .26096 L .62748 .26132 L F
.62655 .25411 m .62711 .26207 L .62644 .25409 L .755 .473 .507 r
F
.62722 .26229 m .62546 .26259 L .62714 .26244 L .644 .737 .917 r
F
.62731 .26211 m .62702 .26218 L .62722 .26229 L F
.62702 .26218 m .62546 .26259 L .62722 .26229 L F
.62515 .25327 m .62566 .25376 L .6261 .25385 L .644 .736 .916 r
F
.62435 .25566 m .62375 .26096 L .62607 .25617 L .667 .747 .91 r
F
.626 .25392 m .62291 .25486 L .62435 .25566 L F
.62869 .25129 m .62515 .25327 L .6261 .25385 L .644 .736 .916 r
F
.62557 .25351 m .62631 .25389 L .62632 .25407 L .862 .563 .481 r
F
.62557 .25351 m .62632 .25407 L .6256 .25372 L F
.62471 .25284 m .62519 .25331 L .6252 .25353 L .948 .643 .425 r
F
.62512 .25345 m .62509 .25347 L .6252 .25353 L .667 .747 .91 r
F
.62509 .25347 m .62291 .25486 L .626 .25392 L F
.62471 .25284 m .6252 .25353 L .62473 .25308 L .948 .643 .425 r
F
.62459 .25355 m .62246 .25477 L .62463 .25356 L .644 .736 .916 r
F
.62512 .25345 m .62185 .25382 L .62291 .25486 L .667 .747 .91 r
F
.62471 .25284 m .62473 .25308 L .62472 .25307 L .948 .643 .425 r
F
.62582 .26156 m .62568 .26149 L .62519 .25331 L .862 .563 .481 r
F
.62519 .25331 m .62568 .26149 L .62547 .26138 L F
.62447 .25284 m .62447 .25284 L .62512 .25345 L .667 .747 .91 r
F
.62447 .25284 m .62185 .25382 L .62479 .25349 L F
.62447 .25284 m .62479 .25349 L .62512 .25345 L F
.63239 .24425 m .6321 .24346 L .63222 .24667 L .944 .685 .22 r
F
.63234 .2457 m .63238 .24597 L .63223 .24586 L .067 0 .41 r
F
.63234 .2457 m .63236 .24571 L .63236 .2457 L .668 .746 .909 r
F
.63234 .2457 m .63237 .24566 L .63238 .24597 L .067 0 .41 r
F
.63239 .24425 m .63222 .24667 L .63237 .24707 L .944 .685 .22 r
F
.6291 .22559 m .62937 .24054 L .62965 .24058 L .735 .457 .508 r
F
.63032 .22604 m .62965 .24058 L .6306 .24095 L .822 .528 .492 r
F
.63032 .22604 m .6306 .24095 L .63088 .24106 L F
.62914 .24275 m .63149 .21827 L .62189 .21862 L .645 .736 .915 r
F
.62914 .24275 m .64093 .21961 L .63149 .21827 L F
.62937 .24054 m .62839 .24039 L .62845 .24193 L .735 .457 .508 r
F
.63179 .24182 m .63181 .24322 L .63205 .24205 L .931 .625 .44 r
F
.63181 .24322 m .632 .24337 L .63205 .24205 L F
.632 .24337 m .63207 .24343 L .63205 .24205 L F
.63179 .24182 m .63093 .2425 L .63181 .24322 L F
.6324 .24299 m .63205 .24205 L .6321 .24346 L .944 .685 .22 r
F
.63133 .24283 m .63417 .24255 L .63214 .24233 L .668 .746 .909 r
F
.62803 .24486 m .63199 .24337 L .63133 .24283 L F
.63199 .24337 m .63417 .24255 L .63133 .24283 L F
.63188 .24638 m .63212 .24658 L .63207 .24343 L .931 .625 .44 r
F
.63188 .24638 m .63207 .24343 L .632 .24337 L F
.63201 .24232 m .63358 .24145 L .63333 .24147 L .668 .746 .909 r
F
.62914 .24275 m .64953 .22255 L .64093 .21961 L .645 .736 .915 r
F
.6306 .24095 m .62965 .24058 L .6297 .24206 L .822 .528 .492 r
F
.62803 .24486 m .63153 .24271 L .63144 .24268 L .668 .746 .909 r
F
.62914 .24275 m .65671 .22686 L .64953 .22255 L .645 .736 .915 r
F
.6306 .24095 m .6297 .24206 L .63036 .2423 L .822 .528 .492 r
F
.62803 .24486 m .63042 .24232 L .6294 .24203 L .668 .746 .909 r
F
.63042 .24232 m .63057 .24216 L .6297 .24206 L F
.63042 .24232 m .6297 .24206 L .6294 .24203 L F
.6306 .24095 m .63036 .2423 L .63062 .24239 L .822 .528 .492 r
F
.63179 .24182 m .63088 .24106 L .63093 .2425 L .931 .625 .44 r
F
.62803 .24486 m .63144 .24268 L .63042 .24232 L .668 .746 .909 r
F
.63093 .2425 m .63097 .24568 L .63105 .24571 L .822 .528 .492 r
F
.62822 .24811 m .63164 .24592 L .63062 .24555 L .668 .747 .91 r
F
.62822 .24811 m .63018 .25075 L .63117 .25029 L F
.62822 .24811 m .62794 .25116 L .62908 .251 L F
.62822 .24811 m .63117 .25029 L .63195 .24966 L F
.62822 .24811 m .62908 .251 L .63018 .25075 L F
.62861 .25115 m .63184 .24916 L .63092 .24883 L .667 .747 .91 r
F
.62864 .25121 m .63185 .24916 L .62861 .25115 L F
.63185 .24916 m .63184 .24916 L .62861 .25115 L F
.63237 .24707 m .63235 .24991 L .6324 .24714 L .944 .685 .22 r
F
.63235 .24991 m .63235 .24991 L .6324 .24714 L F
.6328 .24899 m .63515 .24945 L .63387 .24814 L .668 .747 .91 r
F
.63268 .2479 m .63273 .25093 L .6328 .25111 L .944 .685 .22 r
F
.63264 .24781 m .63273 .25093 L .63268 .2479 L F
.6331 .24905 m .6343 .25065 L .63515 .24945 L .668 .747 .91 r
F
.63337 .24978 m .6343 .25065 L .6331 .24905 L F
.63267 .25174 m .63252 .24868 L .63253 .24867 L 0 0 .209 r
F
.63267 .25174 m .6325 .24877 L .63252 .24868 L F
.63264 .25069 m .63235 .25008 L .63265 .25088 L .944 .685 .22 r
F
.63254 .24858 m .63267 .25174 L .63253 .24867 L 0 0 .209 r
F
.63254 .24754 m .63236 .24993 L .63264 .25069 L .944 .685 .22 r
F
.6324 .24714 m .63235 .24991 L .63254 .24754 L F
.63018 .25075 m .63108 .25035 L .63117 .25029 L .668 .747 .91 r
F
.62908 .251 m .62987 .25088 L .63018 .25075 L F
.62867 .25126 m .63243 .24995 L .63234 .24988 L .667 .747 .91 r
F
.63235 .24991 m .63235 .25008 L .63236 .24993 L .944 .685 .22 r
F
.63235 .24991 m .63236 .24993 L .63254 .24754 L F
.62868 .25126 m .63238 .24997 L .62867 .25126 L .667 .747 .91 r
F
.63238 .24997 m .63327 .24966 L .63238 .24997 L F
.63238 .24997 m .63238 .24997 L .62867 .25126 L F
.63327 .24966 m .63505 .24904 L .63327 .24966 L F
.63327 .24966 m .63327 .24966 L .62867 .25126 L F
.63089 .24249 m .63094 .24567 L .63093 .2425 L .822 .528 .492 r
F
.63094 .24567 m .63095 .24567 L .63093 .2425 L F
.63098 .24885 m .63101 .24887 L .63093 .2425 L F
.62939 .24203 m .62945 .24523 L .62967 .24206 L .735 .457 .508 r
F
.62822 .24811 m .63062 .24555 L .62982 .24527 L .668 .747 .91 r
F
.62822 .24811 m .62982 .24527 L .6296 .24525 L F
.63117 .25029 m .63194 .24967 L .63195 .24966 L F
.62864 .25121 m .63234 .24988 L .63179 .24943 L .667 .747 .91 r
F
.63188 .24638 m .63117 .24892 L .63194 .24955 L .931 .625 .44 r
F
.63188 .24638 m .63194 .24955 L .63212 .24658 L F
.63194 .24955 m .63216 .24974 L .63212 .24658 L F
.62864 .25121 m .63211 .24925 L .63185 .24916 L .667 .747 .91 r
F
.631 .2486 m .63168 .24807 L .63148 .24809 L F
.63094 .24567 m .63098 .24885 L .63095 .24567 L .822 .528 .492 r
F
.63097 .24568 m .63101 .24887 L .63105 .24571 L F
.63101 .24887 m .63108 .24889 L .63105 .24571 L F
.63105 .24571 m .63108 .24889 L .63117 .24892 L F
.60981 .25867 m .60862 .25547 L .61183 .25858 L .951 .645 .421 r
F
.60873 .25761 m .60862 .25547 L .60981 .25867 L F
.61076 .26148 m .59629 .26146 L .60166 .26671 L .644 .736 .916 r
F
.62246 .25477 m .60904 .2582 L .61076 .26148 L F
.60904 .2582 m .59629 .26146 L .61076 .26148 L F
.62862 .25116 m .60628 .2552 L .61517 .25545 L F
.60748 .25523 m .60862 .25547 L .60873 .25761 L .974 .689 .29 r
F
.60628 .2552 m .60727 .25618 L .61517 .25545 L .644 .736 .916 r
F
.61517 .25545 m .59412 .25739 L .59629 .26146 L F
.61517 .25545 m .59629 .26146 L .62246 .25477 L F
.60689 .2551 m .60748 .25523 L .60878 .25872 L .974 .689 .29 r
F
.60748 .25523 m .60873 .25761 L .60878 .25872 L F
.60878 .25872 m .60873 .25761 L .60981 .25867 L .951 .645 .421 r
F
.60628 .2552 m .59412 .25739 L .60727 .25618 L .644 .736 .916 r
F
.62892 .25107 m .62859 .25112 L .62862 .25116 L F
.62859 .25112 m .59412 .25739 L .62862 .25116 L F
.63074 .24877 m .63098 .24885 L .63089 .24249 L .822 .528 .492 r
F
.63085 .24247 m .63089 .24249 L .63088 .24106 L F
.63074 .24877 m .63089 .24249 L .63085 .24247 L F
.63057 .24216 m .63101 .24169 L .62953 .242 L .668 .746 .909 r
F
.62939 .24203 m .62967 .24206 L .62965 .24058 L .735 .457 .508 r
F
.6297 .24206 m .62953 .242 L .6294 .24203 L .668 .746 .909 r
F
.63057 .24216 m .62953 .242 L .6297 .24206 L F
.62943 .24197 m .63101 .24169 L .6295 .24183 L F
.6294 .24203 m .62953 .242 L .62943 .24197 L F
.62953 .242 m .63101 .24169 L .62943 .24197 L F
.6306 .24095 m .63062 .24239 L .63088 .24106 L .822 .528 .492 r
F
.63062 .24239 m .63074 .24877 L .63085 .24247 L F
.63062 .24239 m .63085 .24247 L .63088 .24106 L F
.6286 .25114 m .63092 .24883 L .63081 .2488 L .667 .747 .91 r
F
.62861 .25115 m .63113 .24862 L .6286 .25114 L F
.62867 .25126 m .63234 .24988 L .62864 .25121 L F
.6287 .25131 m .63274 .25139 L .6329 .25058 L F
.6284 .25136 m .62873 .25136 L .6287 .25131 L F
.62873 .25136 m .63274 .25139 L .6287 .25131 L F
.62875 .25139 m .6261 .25385 L .62737 .2541 L .644 .736 .916 r
F
.62892 .25107 m .62869 .25129 L .62875 .25139 L F
.62869 .25129 m .6261 .25385 L .62875 .25139 L F
.62875 .25139 m .62725 .25433 L .62887 .25158 L F
.62877 .25142 m .63255 .25216 L .63261 .25207 L .667 .747 .91 r
F
.6284 .25136 m .62878 .25143 L .62877 .25142 L F
.62878 .25143 m .63255 .25216 L .62877 .25142 L F
.6284 .25136 m .63261 .25207 L .63274 .25139 L F
.62878 .25143 m .63208 .25286 L .63255 .25216 L F
.62884 .25154 m .63206 .25288 L .62878 .25143 L F
.63206 .25288 m .63209 .25286 L .62878 .25143 L F
.62887 .25158 m .62829 .25256 L .62862 .2542 L .644 .736 .916 r
F
.6284 .25136 m .63129 .25349 L .63206 .25288 L .667 .747 .91 r
F
.629 .2518 m .63042 .2539 L .63129 .25349 L F
.62892 .25107 m .62929 .25228 L .6309 .25373 L .644 .736 .916 r
F
.62929 .25228 m .62984 .25413 L .63029 .25396 L F
.63006 .25358 m .63033 .25394 L .629 .2518 L .667 .747 .91 r
F
.63033 .25394 m .63035 .25394 L .629 .2518 L F
.63048 .25414 m .63055 .25408 L .629 .2518 L F
.62929 .25228 m .63029 .25396 L .6309 .25373 L .644 .736 .916 r
F
.63042 .2539 m .6312 .25357 L .63129 .25349 L .667 .747 .91 r
F
.62892 .25107 m .6309 .25373 L .6312 .25362 L .644 .736 .916 r
F
.63129 .25349 m .63323 .25493 L .63206 .25288 L .667 .747 .91 r
F
.63174 .25322 m .6312 .25362 L .63191 .25335 L .644 .736 .916 r
F
.63149 .25333 m .6315 .2534 L .63133 .25346 L .328 .148 .478 r
F
.6315 .2534 m .63134 .25352 L .63133 .25346 L F
.62892 .25107 m .6312 .25362 L .63174 .25322 L .644 .736 .916 r
F
.63153 .25367 m .63165 .25571 L .63323 .25493 L .667 .747 .91 r
F
.63136 .25392 m .63165 .25571 L .63153 .25367 L F
.63503 .25717 m .6359 .25954 L .63805 .25848 L F
.63488 .26004 m .6381 .26435 L .64285 .26202 L F
.63488 .26004 m .64285 .26202 L .63805 .25848 L F
.63165 .25571 m .63805 .25848 L .63323 .25493 L F
.6312 .25362 m .64501 .27277 L .63191 .25335 L .644 .736 .916 r
F
.6309 .25373 m .63095 .2538 L .6312 .25362 L F
.63095 .2538 m .64501 .27277 L .6312 .25362 L F
.63133 .25346 m .63134 .25352 L .63131 .25348 L .328 .148 .478 r
F
.63048 .25414 m .63165 .25571 L .63055 .25408 L .667 .747 .91 r
F
.63087 .25494 m .63604 .27468 L .63142 .25585 L .644 .736 .916 r
F
.62996 .25452 m .63604 .27468 L .63063 .25403 L F
.62984 .25619 m .63311 .25869 L .63138 .25578 L .667 .747 .91 r
F
.63142 .25585 m .63153 .25604 L .63122 .25417 L .644 .736 .916 r
F
.63166 .25686 m .63175 .25643 L .63122 .25417 L F
.63126 .25883 m .63269 .26558 L .63326 .26546 L F
.62984 .25619 m .63128 .26101 L .63405 .26026 L .667 .747 .91 r
F
.62984 .25619 m .63405 .26026 L .63311 .25869 L F
.63311 .25869 m .63405 .26026 L .63488 .26004 L F
.63122 .25417 m .63581 .26321 L .63653 .26134 L .644 .736 .916 r
F
.63128 .26101 m .63583 .26323 L .63405 .26026 L .667 .747 .91 r
F
.63581 .26321 m .64109 .2736 L .63956 .26949 L .644 .736 .916 r
F
.6327 .26579 m .63302 .26551 L .63671 .26472 L .575 .34 .522 r
F
.6327 .26579 m .63269 .26558 L .63302 .26551 L F
.63128 .26101 m .6327 .26579 L .63671 .26472 L .667 .747 .91 r
F
.63128 .26101 m .63671 .26472 L .63583 .26323 L F
.63165 .25571 m .63184 .25597 L .63186 .2559 L F
.63122 .25417 m .63175 .25643 L .63193 .25557 L .644 .736 .916 r
F
.63267 .25174 m .6328 .2513 L .63268 .25191 L 0 0 .209 r
F
.63279 .25115 m .6328 .2513 L .63267 .25174 L F
.63281 .25127 m .63331 .25209 L .63433 .25135 L .644 .736 .916 r
F
.63267 .25174 m .63268 .25191 L .63264 .25193 L 0 0 .209 r
F
.6328 .2513 m .63331 .25209 L .63281 .25127 L .644 .736 .916 r
F
.63267 .25194 m .63308 .25204 L .6328 .2513 L F
.63308 .25204 m .63331 .25209 L .6328 .2513 L F
.63273 .25093 m .63273 .25111 L .6328 .25111 L .944 .685 .22 r
F
.62892 .25107 m .63267 .25194 L .6328 .2513 L .644 .736 .916 r
F
.62892 .25107 m .6328 .2513 L .63279 .25127 L F
.63206 .25288 m .63449 .2539 L .63209 .25286 L .667 .747 .91 r
F
.63206 .25288 m .63323 .25493 L .63398 .25432 L F
.63206 .25288 m .63398 .25432 L .6337 .25357 L F
.63209 .25286 m .63449 .2539 L .63289 .25223 L F
.63268 .25191 m .63264 .25208 L .63264 .25193 L 0 0 .209 r
F
.63208 .25286 m .63209 .25286 L .63255 .25216 L .667 .747 .91 r
F
.63225 .25261 m .63261 .25223 L .63225 .25273 L .067 0 .41 r
F
.63259 .2521 m .63261 .25223 L .63225 .25261 L F
.63289 .25223 m .63449 .2539 L .63534 .2527 L .667 .747 .91 r
F
.63267 .25194 m .63304 .25292 L .6345 .25237 L .644 .736 .916 r
F
.63264 .25208 m .63264 .25209 L .63264 .25193 L 0 0 .209 r
F
.62892 .25107 m .63252 .25269 L .63267 .25194 L .644 .736 .916 r
F
.63252 .25269 m .63304 .25292 L .63267 .25194 L F
.63205 .25289 m .63206 .25288 L .63206 .25299 L .328 .148 .478 r
F
.63234 .25261 m .63191 .25335 L .63304 .25292 L .644 .736 .916 r
F
.63225 .25261 m .63225 .25273 L .63214 .25276 L .067 0 .41 r
F
.63225 .25273 m .63215 .25288 L .63214 .25276 L F
.62892 .25107 m .63184 .2533 L .63234 .25261 L .644 .736 .916 r
F
.63184 .2533 m .63191 .25335 L .63234 .25261 L F
.6337 .25357 m .63398 .25432 L .63449 .2539 L .667 .747 .91 r
F
.63191 .25335 m .65292 .26939 L .63304 .25292 L .644 .736 .916 r
F
.63191 .25335 m .64501 .27277 L .65292 .26939 L F
.63286 .25741 m .6329 .25834 L .63581 .26321 L F
.63193 .25557 m .6329 .25834 L .63286 .25741 L F
.63193 .25557 m .63231 .25735 L .6329 .25834 L F
.63264 .25209 m .63297 .26002 L .63263 .25216 L 0 0 .209 r
F
.63204 .26454 m .63584 .28299 L .64147 .2818 L .644 .737 .917 r
F
.63179 .26576 m .63584 .28299 L .63204 .26454 L F
.63096 .26301 m .63172 .2661 L .6311 .26282 L F
.63172 .2661 m .63584 .28299 L .63179 .26576 L F
.63172 .2661 m .63179 .26576 L .6311 .26282 L F
.63263 .25216 m .63296 .26008 L .63261 .25223 L 0 0 .209 r
F
.63214 .26406 m .64147 .2818 L .63757 .27134 L .644 .737 .917 r
F
.63207 .26442 m .64147 .2818 L .63214 .26406 L F
.6311 .26282 m .63204 .26454 L .63116 .26274 L F
.63204 .26454 m .64147 .2818 L .63207 .26442 L F
.63204 .26454 m .63207 .26442 L .63116 .26274 L F
.63268 .25191 m .6328 .2513 L .6331 .25938 L 0 0 .209 r
F
.62976 .26295 m .63013 .26416 L .63077 .26222 L .644 .737 .917 r
F
.63013 .26416 m .63584 .28299 L .63096 .26301 L F
.63013 .26416 m .63096 .26301 L .63077 .26222 L F
.63583 .26323 m .63671 .26472 L .6381 .26435 L .667 .747 .91 r
F
.63581 .26321 m .63956 .26949 L .63653 .26134 L .644 .736 .916 r
F
.63653 .26134 m .64109 .2736 L .64501 .27277 L F
.63487 .26412 m .64483 .28109 L .65275 .27772 L .644 .737 .917 r
F
.6315 .2534 m .6319 .2614 L .63134 .25352 L .328 .148 .478 r
F
.63183 .26181 m .63757 .27134 L .63487 .26412 L .644 .737 .917 r
F
.63159 .26163 m .63176 .2619 L .63183 .26181 L F
.63176 .2619 m .63757 .27134 L .63183 .26181 L F
.6321 .25294 m .6325 .26089 L .63206 .25299 L .067 0 .41 r
F
.63225 .25273 m .63261 .25223 L .63291 .26031 L F
.63116 .26274 m .63757 .27134 L .63176 .2619 L .644 .737 .917 r
F
.63022 .25406 m .62984 .25619 L .63138 .25578 L .667 .747 .91 r
F
.63018 .25401 m .63017 .25407 L .63022 .25406 L F
.62996 .25452 m .62966 .25633 L .63026 .2555 L .644 .736 .916 r
F
.63017 .25407 m .62984 .25619 L .63022 .25406 L .667 .747 .91 r
F
.62876 .25419 m .62998 .25408 L .62998 .2541 L .629 .374 .513 r
F
.634 .26181 m .65275 .27772 L .65909 .27309 L .644 .737 .917 r
F
.62925 .2542 m .62906 .25451 L .62935 .25455 L .667 .747 .91 r
F
.62984 .25413 m .62996 .25452 L .63063 .25403 L .644 .736 .916 r
F
.62896 .25527 m .62977 .25569 L .62994 .25461 L F
.62985 .2546 m .62994 .25461 L .62996 .25452 L F
.62931 .25439 m .62984 .25619 L .63018 .25401 L .667 .747 .91 r
F
.62876 .25427 m .62998 .2541 L .63028 .26215 L .629 .374 .513 r
F
.62876 .25427 m .63028 .26215 L .62927 .26224 L F
.62886 .2517 m .62862 .2542 L .62955 .25317 L .644 .736 .916 r
F
.6284 .25136 m .63138 .25578 L .63006 .25358 L .667 .747 .91 r
F
.6304 .25391 m .63084 .26194 L .63017 .25401 L .492 .27 .504 r
F
.63272 .26123 m .63207 .26199 L .634 .26181 L .644 .737 .917 r
F
.63084 .26194 m .63065 .26201 L .63017 .25401 L .492 .27 .504 r
F
.6319 .2614 m .63177 .2615 L .63134 .25352 L .328 .148 .478 r
F
.63134 .25352 m .63177 .2615 L .63131 .25354 L F
.63177 .2615 m .63175 .26151 L .63131 .25354 L F
.63131 .25354 m .63175 .26151 L .63126 .25357 L F
.63236 .26107 m .63162 .26165 L .63272 .26123 L .644 .737 .917 r
F
.63162 .26165 m .63207 .26199 L .63272 .26123 L F
.63116 .26274 m .63176 .2619 L .63161 .26165 L F
.63116 .26274 m .63207 .26442 L .63214 .26406 L F
.6311 .26282 m .63179 .26576 L .63204 .26454 L F
.63175 .26151 m .63371 .29758 L .63171 .26154 L .328 .148 .478 r
F
.63175 .26151 m .63171 .26154 L .63126 .25357 L F
.62835 .25423 m .62894 .26228 L .62827 .25424 L .629 .374 .513 r
F
.62899 .26227 m .62894 .26228 L .62836 .25432 L F
.62899 .26227 m .62836 .25432 L .62836 .25432 L F
.62899 .26227 m .62835 .25423 L .62837 .25423 L F
.63017 .25401 m .63065 .26201 L .63007 .25406 L .492 .27 .504 r
F
.63065 .26201 m .63057 .26204 L .63007 .25406 L F
.63063 .26202 m .62976 .26295 L .63077 .26222 L .644 .737 .917 r
F
.62998 .2541 m .6305 .26207 L .63028 .26215 L .492 .27 .504 r
F
.6296 .26241 m .62976 .26295 L .63063 .26202 L .644 .737 .917 r
F
.63007 .25406 m .63057 .26204 L .62998 .2541 L .492 .27 .504 r
F
.63057 .26204 m .63284 .29826 L .6305 .26207 L F
.63057 .26204 m .6305 .26207 L .62998 .2541 L F
.63304 .25292 m .65292 .26939 L .65924 .26475 L .644 .736 .916 r
F
.65292 .26939 m .68917 .27826 L .65924 .26475 L F
.63415 .2607 m .65909 .27309 L .6634 .26751 L .644 .737 .917 r
F
.63225 .25273 m .63291 .26031 L .63262 .26072 L .067 0 .41 r
F
.6325 .26089 m .63246 .26093 L .63206 .25299 L F
.63175 .25642 m .63231 .25735 L .63193 .25557 L .644 .736 .916 r
F
.63206 .25299 m .63246 .26093 L .63236 .26107 L .067 0 .41 r
F
.63215 .25288 m .63253 .26083 L .6321 .25294 L F
.63253 .26083 m .6325 .26089 L .6321 .25294 L F
.63225 .25273 m .63262 .26072 L .63215 .25288 L F
.63262 .26072 m .63253 .26083 L .63215 .25288 L F
.62841 .25422 m .62899 .26227 L .62837 .25423 L .629 .374 .513 r
F
.63293 .26066 m .63272 .26123 L .63366 .26088 L .644 .737 .917 r
F
.63087 .25494 m .63142 .25585 L .63106 .25439 L .644 .736 .916 r
F
.6312 .25362 m .63166 .26158 L .6315 .26169 L .328 .148 .478 r
F
.63126 .25357 m .63171 .26154 L .6312 .25362 L F
.63171 .26154 m .63371 .29758 L .63166 .26158 L F
.63171 .26154 m .63166 .26158 L .6312 .25362 L F
.63319 .26047 m .63366 .26088 L .63354 .26055 L .644 .737 .917 r
F
.62862 .2542 m .62839 .2543 L .6286 .25435 L .644 .736 .916 r
F
.62876 .25419 m .62927 .26224 L .62841 .25422 L .629 .374 .513 r
F
.62927 .26224 m .63161 .29878 L .62899 .26227 L F
.62927 .26224 m .62899 .26227 L .62841 .25422 L F
.62869 .25942 m .62954 .26222 L .63063 .26202 L .644 .737 .917 r
F
.62954 .26222 m .6296 .26241 L .63028 .26215 L F
.62954 .26222 m .63028 .26215 L .63063 .26202 L F
.63063 .26202 m .63077 .26222 L .6315 .26169 L F
.63077 .26222 m .63116 .26274 L .63161 .26165 L F
.63077 .26222 m .63161 .26165 L .6315 .26169 L F
.63077 .26222 m .6311 .26282 L .63116 .26274 L F
.63077 .26222 m .63096 .26301 L .6311 .26282 L F
.63082 .25473 m .63087 .25494 L .63106 .25439 L .644 .736 .916 r
F
.63063 .25403 m .63082 .25473 L .63096 .25399 L F
.63082 .25473 m .63106 .25439 L .63096 .25399 L F
.63106 .25439 m .63142 .25585 L .63122 .25417 L F
.6309 .25373 m .63106 .25439 L .63122 .25417 L F
.6304 .25392 m .6312 .25362 L .6315 .26169 L .492 .27 .504 r
F
.63084 .26194 m .6315 .26169 L .63284 .29826 L F
.6304 .25392 m .6315 .26169 L .63084 .26194 L F
.6345 .25237 m .65924 .26475 L .66354 .25916 L .644 .736 .916 r
F
.63304 .25292 m .65924 .26475 L .6345 .25237 L F
.68894 .26985 m .73153 .26677 L .69763 .25882 L .645 .736 .915 r
F
.65924 .26475 m .68917 .27826 L .69792 .2672 L .644 .736 .916 r
F
.65924 .26475 m .69792 .2672 L .66354 .25916 L F
.63646 .25983 m .6634 .26751 L .66537 .26134 L .644 .737 .917 r
F
.63268 .25191 m .6331 .25938 L .633 .25988 L 0 0 .209 r
F
.63296 .26008 m .63295 .26014 L .63261 .25223 L F
.63261 .25223 m .63295 .26014 L .63291 .26031 L F
.63297 .26002 m .63296 .26008 L .63263 .25216 L F
.633 .25988 m .63297 .26002 L .63264 .25209 L F
.633 .25988 m .63264 .25209 L .63264 .25208 L F
.63268 .25191 m .633 .25988 L .63264 .25208 L F
.63305 .25965 m .63415 .2607 L .63646 .25983 L .644 .737 .917 r
F
.63236 .26107 m .63272 .26123 L .63293 .26066 L F
.63159 .26163 m .63162 .26165 L .63236 .26107 L F
.63207 .26199 m .63487 .26412 L .634 .26181 L F
.63487 .26412 m .65275 .27772 L .63402 .26182 L F
.63487 .26412 m .63402 .26182 L .634 .26181 L F
.6328 .2513 m .63302 .25915 L .6328 .2513 L .944 .685 .22 r
F
.6315 .2534 m .63206 .25299 L .63236 .26107 L .328 .148 .478 r
F
.6319 .2614 m .63236 .26107 L .63371 .29758 L F
.6315 .2534 m .63236 .26107 L .6319 .2614 L F
.62869 .25942 m .63289 .2604 L .63305 .25965 L .644 .737 .917 r
F
.63289 .2604 m .63354 .26055 L .63305 .25965 L F
.63354 .26055 m .63415 .2607 L .63329 .25988 L F
.63354 .26055 m .63329 .25988 L .63305 .25965 L F
.6343 .25065 m .64206 .25079 L .63515 .24945 L .668 .747 .91 r
F
.63243 .24995 m .63559 .25011 L .63505 .24904 L .667 .747 .91 r
F
.6635 .25081 m .70176 .24654 L .66545 .24465 L .645 .736 .915 r
F
.63408 .24739 m .64011 .24992 L .6418 .24753 L .668 .746 .909 r
F
.6418 .24753 m .6498 .245 L .64255 .24496 L F
.63492 .2462 m .6418 .24753 L .64255 .24496 L F
.63408 .24739 m .6418 .24753 L .63492 .2462 L F
.64206 .25079 m .65012 .24825 L .64282 .2482 L .668 .747 .91 r
F
.63515 .24945 m .64206 .25079 L .64282 .2482 L F
.65012 .24825 m .64991 .245 L .64957 .2411 L .732 .555 0 r
F
.64255 .24496 m .6498 .245 L .64946 .24112 L .668 .746 .909 r
F
.63515 .24945 m .64282 .2482 L .63552 .24815 L .668 .747 .91 r
F
.65012 .24825 m .64957 .2411 L .64977 .24435 L .732 .555 0 r
F
.64282 .2482 m .65012 .24825 L .64977 .24435 L .668 .747 .91 r
F
.65033 .2515 m .65012 .24825 L .64977 .24435 L .732 .555 0 r
F
.64282 .2482 m .64977 .24435 L .64258 .2456 L .668 .747 .91 r
F
.63552 .24815 m .64282 .2482 L .64258 .2456 L F
.65033 .2515 m .64977 .24435 L .64998 .2476 L .732 .555 0 r
F
.64302 .25145 m .65033 .2515 L .64998 .2476 L .667 .747 .91 r
F
.64302 .25145 m .64998 .2476 L .64278 .24886 L F
.63559 .25011 m .64156 .24642 L .63497 .24889 L F
.63559 .25011 m .64278 .24886 L .64156 .24642 L F
.64255 .24496 m .64946 .24112 L .64231 .24237 L .668 .746 .909 r
F
.64231 .24237 m .64946 .24112 L .64765 .23748 L F
.64258 .2456 m .64977 .24435 L .64795 .24069 L .668 .747 .91 r
F
.64998 .2476 m .64977 .24435 L .64795 .24069 L .966 .679 .262 r
F
.64278 .24886 m .64816 .24395 L .64156 .24642 L .667 .747 .91 r
F
.64278 .24886 m .64998 .2476 L .64816 .24395 L F
.64998 .2476 m .64795 .24069 L .64816 .24395 L .966 .679 .262 r
F
.63295 .24978 m .66498 .24662 L .66198 .24053 L .644 .736 .916 r
F
.63236 .24993 m .63235 .25008 L .63264 .25069 L .944 .685 .22 r
F
.63216 .24974 m .63217 .24993 L .63226 .24982 L .931 .625 .44 r
F
.62892 .25107 m .63293 .25057 L .63225 .25 L .644 .736 .916 r
F
.62869 .25942 m .63293 .26066 L .63319 .26047 L .644 .737 .917 r
F
.62869 .25942 m .63236 .26107 L .63293 .26066 L F
.6315 .26169 m .63371 .29758 L .63284 .29826 L .328 .148 .478 r
F
.6315 .26169 m .63161 .26165 L .63159 .26163 L .644 .737 .917 r
F
.63166 .26158 m .63371 .29758 L .6315 .26169 L .328 .148 .478 r
F
.62869 .25942 m .63159 .26163 L .63236 .26107 L .644 .737 .917 r
F
.6319 .2614 m .63371 .29758 L .63177 .2615 L .328 .148 .478 r
F
.63236 .26107 m .63427 .29677 L .63371 .29758 L .067 0 .41 r
F
.63246 .26093 m .63427 .29677 L .63236 .26107 L F
.63177 .2615 m .63371 .29758 L .63175 .26151 L .328 .148 .478 r
F
.63217 .24993 m .63227 .25001 L .63226 .24982 L .931 .625 .44 r
F
.63212 .24658 m .63216 .24974 L .63222 .24667 L F
.63216 .24974 m .63226 .24982 L .63222 .24667 L F
.63222 .24667 m .63226 .24982 L .63234 .24988 L F
.63276 .24814 m .63301 .24882 L .63387 .24814 L .668 .747 .91 r
F
.63203 .24904 m .63309 .2496 L .63337 .24819 L .667 .747 .91 r
F
.63309 .2496 m .63497 .24889 L .63337 .24819 L F
.63387 .24814 m .63552 .24815 L .6354 .24693 L .668 .747 .91 r
F
.63492 .2462 m .64255 .24496 L .63529 .24491 L .668 .746 .909 r
F
.63529 .24491 m .64255 .24496 L .64231 .24237 L F
.63552 .24815 m .64258 .2456 L .63539 .24686 L .668 .747 .91 r
F
.63539 .24686 m .64258 .2456 L .64136 .24317 L F
.64977 .24435 m .64957 .2411 L .64775 .23744 L .966 .679 .262 r
F
.64258 .2456 m .64795 .24069 L .64136 .24317 L .668 .747 .91 r
F
.64977 .24435 m .64775 .23744 L .64795 .24069 L .966 .679 .262 r
F
.63387 .24814 m .6354 .24693 L .63539 .24686 L .668 .747 .91 r
F
.63263 .24489 m .63492 .2462 L .63529 .24491 L .668 .746 .909 r
F
.63539 .24686 m .64136 .24317 L .63478 .24564 L .668 .747 .91 r
F
.63497 .24889 m .63943 .24432 L .63391 .24785 L .667 .747 .91 r
F
.63497 .24889 m .64156 .24642 L .63943 .24432 L F
.63529 .24491 m .64231 .24237 L .63517 .24362 L .668 .746 .909 r
F
.63517 .24362 m .64231 .24237 L .64109 .23995 L F
.64231 .24237 m .64765 .23748 L .64109 .23995 L F
.64109 .23995 m .64765 .23748 L .64449 .23433 L F
.64136 .24317 m .64795 .24069 L .64478 .23753 L .668 .747 .91 r
F
.64795 .24069 m .64775 .23744 L .64457 .23428 L .953 .643 .406 r
F
.63517 .24362 m .64109 .23995 L .63456 .24241 L .668 .746 .909 r
F
.63478 .24564 m .64136 .24317 L .63924 .24107 L .668 .747 .91 r
F
.63456 .24241 m .64109 .23995 L .63898 .23785 L .668 .746 .909 r
F
.64109 .23995 m .64449 .23433 L .63898 .23785 L F
.64136 .24317 m .64478 .23753 L .63924 .24107 L .668 .747 .91 r
F
.64156 .24642 m .64498 .24078 L .63943 .24432 L .667 .747 .91 r
F
.64156 .24642 m .64816 .24395 L .64498 .24078 L F
.64795 .24069 m .64457 .23428 L .64478 .23753 L .953 .643 .406 r
F
.64816 .24395 m .64795 .24069 L .64478 .23753 L F
.64816 .24395 m .64478 .23753 L .64498 .24078 L F
.63251 .24901 m .66198 .24053 L .65669 .23513 L .644 .736 .916 r
F
.63068 .24558 m .62982 .24527 L .62994 .24849 L .822 .528 .492 r
F
.63068 .24558 m .62994 .24849 L .63074 .24877 L F
.63188 .24638 m .63105 .24571 L .63117 .24892 L .931 .625 .44 r
F
.63003 .248 m .63247 .24704 L .63075 .24652 L .667 .747 .91 r
F
.62992 .24823 m .63018 .24811 L .63003 .248 L F
.63018 .24811 m .63247 .24704 L .63003 .248 L F
.62405 .25117 m .62395 .24803 L .62395 .24805 L 0 0 .044 r
F
.62405 .25117 m .62405 .251 L .62395 .24793 L F
.62405 .25117 m .62395 .24793 L .62395 .24803 L F
.62395 .24813 m .62405 .25117 L .62395 .24805 L F
.62398 .25081 m .62248 .25048 L .62274 .25161 L .668 .747 .91 r
F
.62248 .25048 m .62167 .25057 L .62217 .25105 L F
.62248 .25048 m .62217 .25105 L .62274 .25161 L F
.62822 .24811 m .62684 .25096 L .62794 .25114 L F
.62398 .25081 m .62274 .25161 L .62399 .25123 L F
.62395 .24784 m .62405 .251 L .62405 .25085 L 0 0 .044 r
F
.62395 .24793 m .62405 .251 L .62395 .24784 L F
.62858 .25111 m .61937 .25061 L .60781 .25367 L .644 .736 .916 r
F
.62443 .24698 m .62405 .25085 L .6245 .25009 L 0 0 .377 r
F
.62415 .24748 m .62405 .25085 L .62443 .24698 L F
.62415 .24748 m .62395 .24784 L .62405 .25085 L F
.62855 .25105 m .61951 .25057 L .62858 .25111 L .644 .736 .916 r
F
.6063 .24797 m .60657 .24861 L .60673 .25185 L .771 .587 .018 r
F
.60655 .25142 m .6063 .24797 L .60673 .25185 L F
.60641 .25021 m .6063 .24797 L .60655 .25142 L F
.61361 .24801 m .60673 .25185 L .61389 .25061 L .668 .747 .91 r
F
.6063 .24797 m .60614 .24472 L .60657 .24861 L .771 .587 .018 r
F
.61351 .24477 m .60668 .24859 L .61379 .24735 L .668 .746 .909 r
F
.61351 .24477 m .60625 .24472 L .60668 .24859 L F
.61361 .24801 m .6063 .24797 L .60673 .25185 L .668 .747 .91 r
F
.62091 .24806 m .61389 .25061 L .62105 .24936 L F
.62091 .24611 m .61503 .24975 L .62152 .24731 L .668 .746 .909 r
F
.62091 .24611 m .61379 .24735 L .61503 .24975 L F
.62091 .24806 m .61361 .24801 L .61389 .25061 L .668 .747 .91 r
F
.61937 .25061 m .6065 .24992 L .60781 .25367 L .644 .736 .916 r
F
.62077 .24481 m .61351 .24477 L .61379 .24735 L .668 .746 .909 r
F
.61433 .24542 m .6063 .24797 L .61361 .24801 L .668 .747 .91 r
F
.61423 .24219 m .60625 .24472 L .61351 .24477 L .668 .746 .909 r
F
.61423 .24219 m .60731 .24084 L .60625 .24472 L F
.61433 .24542 m .60737 .24407 L .6063 .24797 L .668 .747 .91 r
F
.60719 .2475 m .6063 .24797 L .60641 .25021 L 0 0 .278 r
F
.6065 .24992 m .59234 .24915 L .6056 .25302 L .644 .736 .916 r
F
.6065 .24992 m .6056 .25302 L .60781 .25367 L F
.61951 .25057 m .60638 .24989 L .61937 .25061 L F
.60638 .24989 m .60638 .24991 L .61937 .25061 L F
.62855 .25105 m .63148 .24809 L .62992 .24823 L .667 .747 .91 r
F
.6286 .25114 m .63148 .24809 L .62855 .25105 L F
.59284 .24086 m .55829 .25154 L .5936 .24716 L .645 .736 .915 r
F
.60199 .24966 m .59407 .24292 L .59234 .24915 L .644 .736 .916 r
F
.6245 .25009 m .62463 .24987 L .62456 .24673 L 0 0 .377 r
F
.6245 .25009 m .62456 .24673 L .62448 .24688 L F
.62443 .24698 m .6245 .25009 L .62448 .24688 L F
.62258 .24909 m .62094 .24829 L .62105 .24936 L .668 .747 .91 r
F
.62258 .24909 m .62105 .24936 L .62389 .24973 L F
.62398 .25032 m .62248 .25048 L .62398 .25081 L F
.62822 .24811 m .62581 .25067 L .6262 .25086 L F
.62822 .24811 m .6262 .25086 L .62684 .25096 L F
.62822 .24811 m .62501 .25015 L .62606 .2504 L F
.62501 .25015 m .6249 .25022 L .62606 .2504 L F
.62606 .2504 m .6249 .25022 L .62581 .25067 L F
.62855 .25105 m .61946 .24885 L .60199 .24966 L .644 .736 .916 r
F
.6285 .25097 m .61946 .24885 L .62855 .25105 L F
.61951 .25057 m .61937 .25061 L .62858 .25111 L F
.62685 .24215 m .62587 .24246 L .62598 .24567 L .547 .31 .508 r
F
.62685 .24215 m .62598 .24567 L .62647 .24552 L F
.62553 .2427 m .62512 .24627 L .62558 .24595 L .369 .177 .485 r
F
.62553 .2427 m .62558 .24595 L .62582 .24249 L F
.62558 .24595 m .62562 .24913 L .62572 .24585 L F
.62558 .24595 m .62572 .24585 L .62582 .24249 L F
.62562 .24913 m .62588 .24897 L .62582 .24249 L F
.62822 .24811 m .62736 .24523 L .62632 .24556 L .668 .747 .91 r
F
.6269 .24538 m .62609 .24883 L .62695 .24861 L .547 .31 .508 r
F
.62685 .24215 m .62647 .24552 L .6269 .24538 L F
.62647 .24552 m .62609 .24883 L .6269 .24538 L F
.62713 .24206 m .62716 .24529 L .62717 .24205 L F
.62716 .24529 m .62718 .24529 L .62717 .24205 L F
.62807 .25025 m .62753 .24843 L .62707 .24858 L .667 .747 .91 r
F
.6272 .24854 m .62723 .24853 L .62723 .24852 L .547 .31 .508 r
F
.6272 .24854 m .62723 .24852 L .62717 .24205 L F
.6272 .24854 m .62723 .24852 L .6272 .24854 L F
.62647 .24552 m .62598 .24567 L .62609 .24883 L F
.62695 .24861 m .62707 .24858 L .62713 .24206 L F
.62707 .24858 m .6272 .24854 L .6272 .24854 L F
.62707 .24858 m .6272 .24854 L .62713 .24206 L F
.62558 .24595 m .62473 .24969 L .62562 .24913 L .369 .177 .485 r
F
.62512 .24627 m .62473 .24969 L .62558 .24595 L F
.62588 .24897 m .62592 .24894 L .62589 .24573 L F
.62588 .24897 m .62589 .24573 L .62587 .24575 L F
.62585 .24576 m .62588 .24897 L .62587 .24575 L F
.62587 .24246 m .62592 .24894 L .62609 .24883 L F
.62512 .24627 m .62463 .24662 L .62473 .24969 L F
.62464 .24661 m .62212 .24556 L .62374 .24724 L .668 .747 .91 r
F
.62423 .24734 m .62128 .24676 L .62382 .24808 L F
.62384 .24463 m .62201 .2437 L .62373 .24483 L .668 .746 .909 r
F
.62383 .24405 m .62201 .2437 L .62384 .24463 L F
.62201 .2437 m .62113 .24352 L .621 .24402 L F
.62201 .2437 m .621 .24402 L .62077 .24481 L F
.62077 .24481 m .61379 .24735 L .62091 .24611 L F
.62113 .24352 m .61351 .24477 L .62077 .24481 L F
.62113 .24352 m .61423 .24219 L .61351 .24477 L F
.62197 .24232 m .61423 .24219 L .62113 .24352 L F
.62197 .24232 m .61589 .23978 L .61423 .24219 L F
.62322 .2413 m .61589 .23978 L .62197 .24232 L F
.61589 .23978 m .60731 .24084 L .61423 .24219 L F
.62212 .24556 m .61433 .24542 L .62128 .24676 L .668 .747 .91 r
F
.62322 .2413 m .61838 .23772 L .61589 .23978 L .668 .746 .909 r
F
.62479 .24051 m .61838 .23772 L .62322 .2413 L F
.62479 .24051 m .62154 .23614 L .61838 .23772 L F
.61589 .23978 m .60979 .23723 L .60731 .24084 L F
.62212 .24556 m .616 .243 L .61433 .24542 L .668 .747 .91 r
F
.62337 .24453 m .616 .243 L .62212 .24556 L F
.61838 .23772 m .60979 .23723 L .61589 .23978 L .668 .746 .909 r
F
.62337 .24453 m .61851 .24093 L .616 .243 L .668 .747 .91 r
F
.62453 .24339 m .62197 .24232 L .62413 .24411 L .668 .746 .909 r
F
.62496 .24374 m .61851 .24093 L .62337 .24453 L .668 .747 .91 r
F
.62453 .24339 m .62322 .2413 L .62197 .24232 L .668 .746 .909 r
F
.62497 .24259 m .62322 .2413 L .62453 .24339 L F
.62453 .2434 m .62453 .24339 L .62452 .24341 L F
.62496 .24374 m .62169 .23934 L .61851 .24093 L .668 .747 .91 r
F
.61838 .23772 m .61353 .23412 L .60979 .23723 L .668 .746 .909 r
F
.62154 .23614 m .61353 .23412 L .61838 .23772 L F
.61851 .24093 m .60986 .24044 L .616 .243 L .668 .747 .91 r
F
.61362 .23732 m .6097 .23719 L .60986 .24044 L .32 .148 .485 r
F
.61362 .23732 m .61345 .23407 L .6097 .23719 L F
.62154 .23614 m .61827 .23175 L .61353 .23412 L .668 .746 .909 r
F
.61851 .24093 m .61362 .23732 L .60986 .24044 L .668 .747 .91 r
F
.62169 .23934 m .61362 .23732 L .61851 .24093 L F
.61329 .24056 m .61362 .23732 L .60986 .24044 L .32 .148 .485 r
F
.61377 .24019 m .61362 .23732 L .61329 .24056 L F
.62382 .24808 m .62128 .24676 L .62091 .24806 L .668 .747 .91 r
F
.62374 .24822 m .62289 .24824 L .62344 .24876 L F
.62289 .24824 m .62094 .24829 L .6236 .24891 L F
.62374 .24822 m .62091 .24806 L .62094 .24829 L F
.62382 .24808 m .62091 .24806 L .62374 .24822 L F
.60737 .24407 m .6072 .24082 L .60614 .24472 L 0 0 .278 r
F
.62128 .24676 m .61361 .24801 L .62091 .24806 L .668 .747 .91 r
F
.62128 .24676 m .61433 .24542 L .61361 .24801 L F
.60986 .24044 m .6072 .24082 L .60737 .24407 L .089 0 .427 r
F
.60986 .24044 m .6097 .23719 L .6072 .24082 L F
.616 .243 m .60737 .24407 L .61433 .24542 L .668 .747 .91 r
F
.616 .243 m .60986 .24044 L .60737 .24407 L F
.60946 .24378 m .60986 .24044 L .60737 .24407 L .089 0 .427 r
F
.61 .24305 m .60986 .24044 L .60946 .24378 L F
.60737 .24407 m .60614 .24472 L .6063 .24797 L 0 0 .278 r
F
.60719 .2475 m .60737 .24407 L .6063 .24797 L F
.60749 .24647 m .60737 .24407 L .60719 .2475 L F
.60526 .24951 m .59407 .24292 L .60199 .24966 L .644 .736 .916 r
F
.61946 .24885 m .60775 .24612 L .60526 .24951 L F
.60946 .24378 m .60737 .24407 L .60749 .24647 L .089 0 .427 r
F
.60775 .24612 m .59407 .24292 L .60526 .24951 L .644 .736 .916 r
F
.61946 .24885 m .60953 .24341 L .6076 .24608 L F
.60953 .24341 m .60852 .24286 L .60804 .24453 L F
.60953 .24341 m .60804 .24453 L .6076 .24608 L F
.61329 .24056 m .60986 .24044 L .61 .24305 L .32 .148 .485 r
F
.6236 .24866 m .5982 .2372 L .61946 .24885 L .644 .736 .916 r
F
.6236 .24866 m .61368 .24023 L .61029 .24266 L F
.61368 .24023 m .61269 .23939 L .6113 .24128 L F
.61368 .24023 m .6113 .24128 L .61029 .24266 L F
.62169 .23934 m .6184 .23493 L .61362 .23732 L .668 .747 .91 r
F
.6184 .23816 m .61362 .23732 L .61377 .24019 L .467 .255 .508 r
F
.62374 .24822 m .62344 .24876 L .6236 .24891 L .668 .747 .91 r
F
.62565 .24857 m .60447 .2324 L .6236 .24866 L .644 .736 .916 r
F
.6184 .23816 m .6184 .23493 L .61362 .23732 L .467 .255 .508 r
F
.61435 .23994 m .61793 .23704 L .61423 .23985 L .644 .736 .916 r
F
.62659 .24002 m .62154 .23614 L .62479 .24051 L .668 .746 .909 r
F
.62659 .24002 m .62515 .23516 L .62154 .23614 L F
.62515 .23516 m .61827 .23175 L .62154 .23614 L F
.62532 .23836 m .6184 .23493 L .62169 .23934 L .668 .747 .91 r
F
.62515 .23516 m .62369 .23027 L .61827 .23175 L .668 .746 .909 r
F
.62532 .23836 m .62385 .23345 L .6184 .23493 L .668 .747 .91 r
F
.62404 .23671 m .6184 .23493 L .61857 .23809 L .571 .333 .517 r
F
.62565 .24857 m .61862 .23808 L .61435 .23994 L .644 .736 .916 r
F
.62404 .23671 m .61857 .23809 L .62055 .23766 L .571 .333 .517 r
F
.61857 .23809 m .6184 .23493 L .6184 .23816 L .467 .255 .508 r
F
.6269 .24538 m .62695 .24861 L .62704 .24533 L .547 .31 .508 r
F
.62413 .24411 m .62383 .24405 L .62384 .24463 L .668 .746 .909 r
F
.62544 .24605 m .62496 .24374 L .62337 .24453 L .668 .747 .91 r
F
.62384 .24483 m .62373 .24483 L .62385 .24559 L .668 .746 .909 r
F
.62544 .24605 m .62337 .24453 L .62464 .24661 L .668 .747 .91 r
F
.6184 .23493 m .61345 .23407 L .61362 .23732 L .467 .255 .508 r
F
.6184 .23493 m .61822 .23168 L .61345 .23407 L F
.62702 .24851 m .61246 .22887 L .62565 .24857 L .644 .736 .916 r
F
.62822 .24811 m .62849 .24514 L .62737 .24525 L .668 .747 .91 r
F
.62937 .24054 m .62939 .24203 L .62965 .24058 L .735 .457 .508 r
F
.62965 .24058 m .62967 .24206 L .6297 .24206 L F
.62937 .24054 m .62924 .24201 L .62939 .24203 L F
.62937 .24054 m .62845 .24193 L .62924 .24201 L F
.62839 .24039 m .62841 .24193 L .62845 .24193 L .65 .39 .512 r
F
.62803 .24486 m .63036 .24005 L .62849 .23986 L .668 .746 .909 r
F
.62822 .24811 m .6296 .24525 L .62849 .24514 L .668 .747 .91 r
F
.62939 .24203 m .62904 .24519 L .62945 .24523 L .735 .457 .508 r
F
.6296 .24525 m .62856 .24514 L .62849 .24514 L .668 .747 .91 r
F
.62924 .24201 m .62896 .24518 L .62939 .24203 L .735 .457 .508 r
F
.62896 .24518 m .62868 .24835 L .62904 .24519 L F
.62896 .24518 m .62904 .24519 L .62939 .24203 L F
.62945 .24523 m .62971 .24526 L .62967 .24206 L F
.63062 .24239 m .62982 .24527 L .63068 .24558 L .822 .528 .492 r
F
.63036 .2423 m .62982 .24527 L .63062 .24239 L F
.6297 .24206 m .62971 .24526 L .62982 .24527 L .735 .457 .508 r
F
.62967 .24206 m .62971 .24526 L .6297 .24206 L F
.63036 .2423 m .6297 .24206 L .62982 .24527 L .822 .528 .492 r
F
.62924 .24201 m .62845 .24193 L .62856 .24514 L .735 .457 .508 r
F
.62896 .24518 m .62856 .24514 L .62868 .24835 L F
.62924 .24201 m .62856 .24514 L .62896 .24518 L F
.62845 .24193 m .62848 .24837 L .62868 .24835 L .65 .39 .512 r
F
.62971 .24503 m .63056 .24327 L .62851 .24513 L .668 .747 .91 r
F
.62856 .24514 m .62851 .24513 L .62849 .24514 L F
.62971 .24503 m .62851 .24513 L .62856 .24514 L F
.62849 .24513 m .63056 .24327 L .62868 .24309 L F
.62849 .24514 m .62851 .24513 L .62849 .24513 L F
.62851 .24513 m .63056 .24327 L .62849 .24513 L F
.6296 .24525 m .62971 .24503 L .62856 .24514 L F
.62945 .24523 m .62868 .24835 L .6295 .24844 L .735 .457 .508 r
F
.62904 .24519 m .62868 .24835 L .62945 .24523 L F
.62824 .24839 m .62848 .24837 L .62845 .24515 L .65 .39 .512 r
F
.62833 .24516 m .62845 .24515 L .62841 .24193 L F
.62824 .24839 m .62845 .24515 L .62833 .24516 L F
.62841 .24193 m .62848 .24837 L .62845 .24193 L F
.62811 .24041 m .62813 .24196 L .62839 .24039 L F
.62813 .24196 m .62841 .24193 L .62839 .24039 L F
.62811 .24041 m .62717 .24205 L .62813 .24196 L F
.62712 .24045 m .62713 .24206 L .62717 .24205 L .547 .31 .508 r
F
.62803 .24486 m .62849 .23986 L .62659 .24002 L .668 .746 .909 r
F
.62813 .24196 m .62729 .24526 L .62819 .24517 L .65 .39 .512 r
F
.62737 .24525 m .62852 .24486 L .62736 .24523 L .668 .747 .91 r
F
.62849 .24514 m .62852 .24486 L .62737 .24525 L F
.62813 .24196 m .62819 .24517 L .62841 .24193 L .65 .39 .512 r
F
.62819 .24517 m .62824 .24839 L .62833 .24516 L F
.62819 .24517 m .62833 .24516 L .62841 .24193 L F
.62716 .24529 m .6272 .24854 L .62718 .24529 L .547 .31 .508 r
F
.62819 .24517 m .62729 .24526 L .6274 .24847 L .65 .39 .512 r
F
.62819 .24517 m .6274 .24847 L .62824 .24839 L F
.62717 .24205 m .62723 .24853 L .6274 .24849 L .547 .31 .508 r
F
.62753 .24843 m .62887 .24634 L .62695 .2465 L .667 .747 .91 r
F
.62807 .25025 m .6285 .24812 L .62753 .24843 L F
.6285 .24812 m .62887 .24634 L .62753 .24843 L F
.62845 .25088 m .62887 .24634 L .62807 .25025 L F
.62824 .24839 m .6274 .24847 L .6274 .24849 L .65 .39 .512 r
F
.62707 .24858 m .62695 .2465 L .62599 .24676 L .667 .747 .91 r
F
.62753 .24843 m .62695 .2465 L .62707 .24858 L F
.62587 .24575 m .62589 .24573 L .62587 .24246 L .369 .177 .485 r
F
.62582 .24249 m .62585 .24576 L .62587 .24246 L F
.62585 .24576 m .62587 .24575 L .62587 .24246 L F
.62626 .24548 m .62677 .24324 L .62496 .24374 L .668 .747 .91 r
F
.62632 .24556 m .62635 .24541 L .62626 .24548 L F
.62635 .24541 m .62677 .24324 L .62626 .24548 L F
.6269 .24538 m .62704 .24533 L .62713 .24206 L .547 .31 .508 r
F
.62736 .24523 m .62677 .24324 L .62632 .24556 L .668 .747 .91 r
F
.62626 .24548 m .62496 .24374 L .6254 .24586 L F
.62598 .24567 m .6254 .24586 L .62544 .24605 L F
.62626 .24548 m .6254 .24586 L .62598 .24567 L F
.62632 .24556 m .62626 .24548 L .62598 .24567 L F
.62581 .2408 m .62582 .24249 L .62587 .24246 L .369 .177 .485 r
F
.62612 .24229 m .62556 .24153 L .62536 .24263 L .668 .746 .909 r
F
.62587 .24246 m .62536 .24263 L .62532 .24285 L F
.62612 .24229 m .62536 .24263 L .62587 .24246 L F
.62532 .24285 m .62556 .24153 L .62497 .24259 L F
.62497 .24259 m .62479 .24051 L .62322 .2413 L F
.62556 .24153 m .62479 .24051 L .62497 .24259 L F
.62677 .24324 m .62169 .23934 L .62496 .24374 L .668 .747 .91 r
F
.62618 .24237 m .62612 .24229 L .62587 .24246 L .668 .746 .909 r
F
.62677 .24324 m .62532 .23836 L .62169 .23934 L .668 .747 .91 r
F
.62385 .23345 m .61822 .23168 L .6184 .23493 L .571 .333 .517 r
F
.62404 .23671 m .62385 .23345 L .6184 .23493 L F
.62707 .24857 m .61497 .22831 L .61246 .22887 L .644 .736 .916 r
F
.62695 .2465 m .62186 .2426 L .62514 .24699 L .667 .747 .91 r
F
.62695 .2465 m .6255 .24162 L .62186 .2426 L F
.62813 .24196 m .62717 .24205 L .62729 .24526 L .65 .39 .512 r
F
.62685 .24215 m .6269 .24538 L .62713 .24206 L .547 .31 .508 r
F
.62736 .24523 m .62868 .24309 L .62677 .24324 L .668 .747 .91 r
F
.62852 .24486 m .62868 .24309 L .62736 .24523 L F
.62887 .24634 m .6255 .24162 L .62695 .2465 L .667 .747 .91 r
F
.6295 .24183 m .63207 .24056 L .63036 .24005 L .668 .746 .909 r
F
.63101 .24169 m .63207 .24056 L .6295 .24183 L F
.63036 .24005 m .62896 .23484 L .62849 .23986 L F
.63056 .24327 m .62915 .23804 L .62868 .24309 L .668 .747 .91 r
F
.62868 .24309 m .62532 .23836 L .62677 .24324 L F
.62849 .23986 m .62515 .23516 L .62659 .24002 L .668 .746 .909 r
F
.62849 .23986 m .62896 .23484 L .62515 .23516 L F
.62868 .24309 m .62915 .23804 L .62532 .23836 L .668 .747 .91 r
F
.62887 .24634 m .62933 .2413 L .6255 .24162 L .667 .747 .91 r
F
.6255 .24162 m .61857 .23819 L .62186 .2426 L F
.62385 .23345 m .62367 .23019 L .61822 .23168 L .571 .333 .517 r
F
.6255 .24162 m .62404 .23671 L .61857 .23819 L .667 .747 .91 r
F
.62896 .23484 m .62369 .23027 L .62515 .23516 L .668 .746 .909 r
F
.62915 .23804 m .62385 .23345 L .62532 .23836 L .668 .747 .91 r
F
.62933 .2413 m .62404 .23671 L .6255 .24162 L .667 .747 .91 r
F
.63036 .24005 m .6327 .23521 L .62896 .23484 L .668 .746 .909 r
F
.63088 .24106 m .63089 .24249 L .63093 .2425 L .822 .528 .492 r
F
.63042 .24232 m .63201 .24232 L .63057 .24216 L .668 .746 .909 r
F
.63144 .24268 m .63201 .24232 L .63042 .24232 L F
.63057 .24216 m .6335 .24136 L .63207 .24056 L F
.63201 .24232 m .6335 .24136 L .63057 .24216 L F
.63207 .24056 m .6327 .23521 L .63036 .24005 L F
.63207 .24056 m .63612 .23623 L .6327 .23521 L F
.63056 .24327 m .63291 .23841 L .62915 .23804 L .668 .747 .91 r
F
.6327 .23521 m .62942 .22979 L .62896 .23484 L .668 .746 .909 r
F
.63291 .23841 m .62961 .23296 L .62915 .23804 L .668 .747 .91 r
F
.62896 .23484 m .62942 .22979 L .62369 .23027 L .668 .746 .909 r
F
.62915 .23804 m .62961 .23296 L .62385 .23345 L .668 .747 .91 r
F
.62933 .2413 m .6298 .23622 L .62404 .23671 L .667 .747 .91 r
F
.6298 .23622 m .62385 .23345 L .62404 .23671 L .656 .397 .517 r
F
.62734 .24849 m .62161 .22685 L .61497 .22831 L .644 .736 .916 r
F
.62945 .24523 m .6295 .24844 L .62971 .24526 L .735 .457 .508 r
F
.6295 .24844 m .62974 .24847 L .62971 .24526 L F
.62982 .24527 m .62974 .24847 L .62994 .24849 L F
.62971 .24526 m .62974 .24847 L .62982 .24527 L F
.62845 .25088 m .63075 .24652 L .62887 .24634 L .667 .747 .91 r
F
.6284 .25136 m .62855 .25105 L .62845 .25088 L F
.62855 .25105 m .63075 .24652 L .62845 .25088 L F
.62397 .2497 m .62258 .24909 L .62389 .24973 L .668 .747 .91 r
F
.62396 .24885 m .62258 .24909 L .62397 .2497 L F
.62397 .2497 m .62389 .24973 L .62397 .24977 L F
.6285 .25097 m .6236 .24866 L .61946 .24885 L .644 .736 .916 r
F
.62892 .25107 m .62843 .25084 L .6285 .25097 L F
.62843 .25084 m .6236 .24866 L .6285 .25097 L F
.62892 .25107 m .62813 .24845 L .62734 .24849 L F
.62824 .24839 m .6274 .24849 L .62824 .24845 L .65 .39 .512 r
F
.62813 .24845 m .62161 .22685 L .62734 .24849 L .644 .736 .916 r
F
.6295 .24844 m .62868 .24835 L .62868 .24843 L .735 .457 .508 r
F
.62892 .25107 m .62716 .2482 L .62707 .24857 L .644 .736 .916 r
F
.62892 .25107 m .62565 .24857 L .6236 .24866 L F
.62892 .25107 m .62702 .24851 L .62565 .24857 L F
.62892 .25107 m .6285 .25097 L .62855 .25105 L F
.62892 .25107 m .62855 .25105 L .62858 .25111 L F
.63179 .24943 m .63234 .24988 L .63211 .24925 L .667 .747 .91 r
F
.63165 .2495 m .63295 .24978 L .63188 .24937 L .644 .736 .916 r
F
.62892 .25107 m .63225 .25 L .63165 .2495 L F
.63226 .24982 m .63227 .25001 L .63234 .24988 L .931 .625 .44 r
F
.63273 .25111 m .6328 .2513 L .6328 .25111 L .944 .685 .22 r
F
.6328 .25111 m .6328 .2513 L .6328 .2513 L F
.63255 .25062 m .63383 .25132 L .63293 .25057 L .644 .736 .916 r
F
.62892 .25107 m .63279 .25127 L .63255 .25062 L F
.63264 .25069 m .63265 .25088 L .63273 .25093 L .944 .685 .22 r
F
.63265 .25088 m .63273 .25111 L .63273 .25093 L F
.63279 .25127 m .63383 .25132 L .63255 .25062 L .644 .736 .916 r
F
.63265 .25088 m .63289 .25881 L .63273 .25111 L .944 .685 .22 r
F
.63234 .24988 m .63234 .24988 L .63179 .24943 L .667 .747 .91 r
F
.63235 .24991 m .63235 .25008 L .63235 .24991 L .944 .685 .22 r
F
.63194 .24955 m .63117 .24892 L .63117 .2491 L .931 .625 .44 r
F
.62892 .25107 m .63165 .2495 L .63117 .2491 L .644 .736 .916 r
F
.63101 .24903 m .63108 .24906 L .63108 .24889 L .822 .528 .492 r
F
.63099 .24902 m .63117 .2491 L .63103 .24898 L .644 .736 .916 r
F
.62892 .25107 m .63117 .2491 L .63099 .24902 L F
.63101 .24887 m .63101 .24903 L .63108 .24889 L .822 .528 .492 r
F
.63028 .26215 m .63284 .29826 L .63161 .29878 L .492 .27 .504 r
F
.6305 .26207 m .63284 .29826 L .63028 .26215 L F
.63065 .26201 m .63284 .29826 L .63057 .26204 L F
.62869 .25942 m .63063 .26202 L .63159 .26163 L .644 .737 .917 r
F
.63063 .26202 m .6315 .26169 L .63159 .26163 L F
.63084 .26194 m .63284 .29826 L .63065 .26201 L .492 .27 .504 r
F
.63101 .24903 m .63111 .25704 L .63108 .24906 L .822 .528 .492 r
F
.63111 .25704 m .63117 .25706 L .63108 .24906 L F
.63194 .24974 m .63117 .2491 L .63147 .25718 L .931 .625 .44 r
F
.63194 .24974 m .63147 .25718 L .6321 .2577 L F
.63194 .24955 m .63117 .2491 L .63194 .24974 L F
.63185 .24916 m .63211 .24925 L .63203 .24904 L .667 .747 .91 r
F
.63117 .24892 m .63117 .24909 L .63117 .2491 L .822 .528 .492 r
F
.63108 .24889 m .63108 .24906 L .63117 .24892 L F
.63108 .24906 m .63117 .25706 L .63117 .24909 L F
.63108 .24906 m .63117 .24909 L .63117 .24892 L F
.63148 .24809 m .63247 .24704 L .62992 .24823 L .667 .747 .91 r
F
.63074 .24877 m .62994 .24849 L .62994 .24862 L .822 .528 .492 r
F
.63181 .24322 m .63105 .24571 L .63188 .24638 L .931 .625 .44 r
F
.63264 .24779 m .63264 .24781 L .63256 .24469 L .944 .685 .22 r
F
.63181 .24322 m .63093 .2425 L .63105 .24571 L .931 .625 .44 r
F
.63181 .24322 m .63188 .24638 L .632 .24337 L F
.63252 .24489 m .63266 .24497 L .63263 .24489 L .668 .746 .909 r
F
.63072 .24544 m .63361 .24466 L .63124 .24488 L .668 .747 .91 r
F
.63062 .24555 m .63079 .2455 L .63072 .24544 L F
.63079 .2455 m .63361 .24466 L .63072 .24544 L F
.63266 .24497 m .63492 .2462 L .63263 .24489 L .668 .746 .909 r
F
.63164 .24592 m .63361 .24466 L .63062 .24555 L .668 .747 .91 r
F
.63214 .24233 m .63456 .24241 L .63358 .24145 L .668 .746 .909 r
F
.63417 .24255 m .63456 .24241 L .63214 .24233 L F
.63234 .24411 m .63256 .24469 L .63268 .24405 L F
.63124 .24488 m .63372 .24459 L .63228 .24378 L .668 .747 .91 r
F
.63361 .24466 m .63372 .24459 L .63124 .24488 L F
.6322 .24661 m .63487 .24582 L .63442 .24577 L F
.63224 .24672 m .63487 .24582 L .6322 .24661 L F
.63224 .24672 m .63297 .24728 L .63228 .24671 L F
.63248 .24736 m .63297 .24728 L .63224 .24672 L F
.63145 .24604 m .63288 .24635 L .63164 .24592 L F
.63217 .24662 m .63288 .24635 L .63145 .24604 L F
.63164 .24592 m .63462 .2457 L .63372 .24459 L F
.63288 .24635 m .63462 .2457 L .63164 .24592 L F
.63462 .2457 m .63471 .24557 L .63372 .24459 L F
.63206 .24334 m .63517 .24362 L .63456 .24241 L .668 .746 .909 r
F
.63456 .24241 m .63898 .23785 L .6335 .24136 L F
.6335 .24136 m .63898 .23785 L .63612 .23623 L F
.63478 .24564 m .63924 .24107 L .63372 .24459 L .668 .747 .91 r
F
.63372 .24459 m .63636 .23944 L .63228 .24378 L F
.63372 .24459 m .63924 .24107 L .63636 .23944 L F
.63214 .24233 m .63358 .24145 L .63201 .24232 L .668 .746 .909 r
F
.63333 .24147 m .63358 .24145 L .6335 .24136 L F
.6335 .24136 m .63612 .23623 L .63207 .24056 L F
.63228 .24378 m .63636 .23944 L .63291 .23841 L .668 .747 .91 r
F
.63898 .23785 m .64019 .23189 L .63612 .23623 L .668 .746 .909 r
F
.63898 .23785 m .64449 .23433 L .64019 .23189 L F
.63228 .24671 m .63539 .24686 L .63487 .24582 L .668 .747 .91 r
F
.63297 .24728 m .63539 .24686 L .63228 .24671 L F
.63442 .24577 m .63487 .24582 L .63478 .24564 L F
.63462 .2457 m .63478 .24564 L .63471 .24557 L F
.63248 .24736 m .63387 .24814 L .63539 .24686 L F
.63391 .24785 m .63655 .2427 L .63247 .24704 L .667 .747 .91 r
F
.63391 .24785 m .63943 .24432 L .63655 .2427 L F
.63612 .23623 m .64019 .23189 L .63505 .23034 L .668 .746 .909 r
F
.62962 .2452 m .63228 .24378 L .63056 .24327 L .668 .747 .91 r
F
.63062 .24555 m .63228 .24378 L .62962 .2452 L F
.63144 .24268 m .63214 .24233 L .63201 .24232 L .668 .746 .909 r
F
.63153 .24271 m .63214 .24233 L .63144 .24268 L F
.63199 .24337 m .6321 .24346 L .63206 .24334 L F
.63228 .24378 m .63291 .23841 L .63056 .24327 L .668 .747 .91 r
F
.63247 .24704 m .6331 .24167 L .63075 .24652 L .667 .747 .91 r
F
.63247 .24704 m .63655 .2427 L .6331 .24167 L F
.63924 .24107 m .64045 .23508 L .63636 .23944 L .668 .747 .91 r
F
.63924 .24107 m .64478 .23753 L .64045 .23508 L F
.64478 .23753 m .64457 .23428 L .64025 .23183 L .881 .577 .468 r
F
.63612 .23623 m .63505 .23034 L .6327 .23521 L .668 .746 .909 r
F
.63636 .23944 m .63528 .23352 L .63291 .23841 L .668 .747 .91 r
F
.63636 .23944 m .64045 .23508 L .63528 .23352 L F
.63943 .24432 m .64065 .23834 L .63655 .2427 L .667 .747 .91 r
F
.63943 .24432 m .64498 .24078 L .64065 .23834 L F
.64478 .23753 m .64025 .23183 L .64045 .23508 L .881 .577 .468 r
F
.64498 .24078 m .64478 .23753 L .64045 .23508 L F
.64045 .23508 m .64025 .23183 L .63509 .23027 L .805 .515 .497 r
F
.63655 .2427 m .63547 .23678 L .6331 .24167 L .667 .747 .91 r
F
.63655 .2427 m .64065 .23834 L .63547 .23678 L F
.64045 .23508 m .63509 .23027 L .63528 .23352 L .805 .515 .497 r
F
.64498 .24078 m .64045 .23508 L .64065 .23834 L .881 .577 .468 r
F
.64065 .23834 m .64045 .23508 L .63528 .23352 L .805 .515 .497 r
F
.64065 .23834 m .63528 .23352 L .63547 .23678 L F
.63013 .24869 m .64946 .2308 L .64079 .22785 L .644 .736 .916 r
F
.62892 .25107 m .63099 .24902 L .63013 .24869 L F
.63074 .24877 m .62994 .24862 L .63075 .24893 L .822 .528 .492 r
F
.63074 .24877 m .63075 .24893 L .63098 .24885 L F
.63075 .24893 m .63098 .24902 L .63098 .24885 L F
.63081 .2488 m .63113 .24862 L .631 .2486 L .667 .747 .91 r
F
.63092 .24883 m .63113 .24862 L .63081 .2488 L F
.63113 .24862 m .63168 .24807 L .631 .2486 L F
.63092 .24883 m .63203 .24904 L .63168 .24807 L F
.63184 .24916 m .63203 .24904 L .63092 .24883 L F
.62869 .25942 m .63194 .25757 L .63112 .25704 L .644 .737 .917 r
F
.63194 .25757 m .63216 .25744 L .63147 .25718 L F
.63194 .25757 m .63147 .25718 L .63112 .25704 L F
.63194 .24955 m .6321 .2577 L .63216 .24974 L .931 .625 .44 r
F
.6321 .2577 m .63228 .25786 L .63216 .24974 L F
.63098 .24885 m .63109 .25703 L .63101 .24887 L .822 .528 .492 r
F
.63227 .25001 m .63236 .25792 L .63235 .25008 L .931 .625 .44 r
F
.63236 .25792 m .63243 .25798 L .63235 .25008 L F
.63235 .25008 m .63243 .25798 L .63265 .25816 L F
.62869 .25942 m .63265 .25817 L .63194 .25757 L .644 .737 .917 r
F
.63235 .25008 m .63243 .25798 L .63235 .25008 L .931 .625 .44 r
F
.6325 .26089 m .63427 .29677 L .63246 .26093 L .067 0 .41 r
F
.63358 .25035 m .63383 .25103 L .6343 .25065 L .668 .747 .91 r
F
.63314 .25053 m .63571 .25141 L .63559 .25011 L .667 .747 .91 r
F
.6342 .2514 m .63571 .25141 L .63314 .25053 L F
.63358 .25035 m .6343 .25065 L .63337 .24978 L .668 .747 .91 r
F
.6635 .25081 m .69763 .25882 L .70176 .24654 L .645 .736 .915 r
F
.63571 .25141 m .64302 .25145 L .64278 .24886 L .667 .747 .91 r
F
.63571 .25141 m .64278 .24886 L .63559 .25011 L F
.63293 .25057 m .6655 .25298 L .66498 .24662 L .644 .736 .916 r
F
.63383 .25132 m .6655 .25298 L .63293 .25057 L F
.6345 .25237 m .66354 .25916 L .63686 .25148 L F
.63341 .25793 m .66485 .255 L .66184 .24892 L .644 .737 .917 r
F
.63217 .24993 m .63228 .25786 L .63227 .25001 L .931 .625 .44 r
F
.63265 .25088 m .63265 .25816 L .63289 .25881 L .944 .685 .22 r
F
.63302 .25915 m .63302 .25916 L .6328 .2513 L F
.6328 .2513 m .63302 .25916 L .6331 .25938 L F
.63273 .25111 m .63296 .259 L .6328 .2513 L F
.63296 .259 m .63302 .25915 L .6328 .2513 L F
.63289 .25881 m .63296 .259 L .63273 .25093 L F
.62869 .25942 m .63346 .25884 L .63265 .25817 L .644 .737 .917 r
F
.69763 .25882 m .73153 .26677 L .73807 .24844 L .645 .736 .915 r
F
.69763 .25882 m .73807 .24844 L .70176 .24654 L F
.66354 .25916 m .69792 .2672 L .70209 .25489 L .644 .736 .916 r
F
.66354 .25916 m .70209 .25489 L .6655 .25298 L F
.63522 .25862 m .66537 .26134 L .66485 .255 L .644 .737 .917 r
F
.62869 .25942 m .63863 .25994 L .63522 .25862 L F
.63863 .25994 m .66537 .26134 L .63522 .25862 L F
.63117 .24909 m .63124 .25709 L .63117 .2491 L .822 .528 .492 r
F
.63124 .25709 m .63156 .29312 L .63124 .25709 L F
.63124 .25709 m .63124 .25709 L .63117 .2491 L F
.63228 .25786 m .63281 .29358 L .63236 .25792 L .931 .625 .44 r
F
.63228 .25786 m .63236 .25792 L .63227 .25001 L F
.63265 .25817 m .63522 .25862 L .63341 .25793 L .644 .737 .917 r
F
.63346 .25884 m .63522 .25862 L .63265 .25817 L F
.63522 .25862 m .66485 .255 L .63341 .25793 L F
.63147 .25718 m .63156 .29312 L .63281 .29358 L .822 .528 .492 r
F
.63134 .25352 m .63131 .25354 L .63131 .25348 L .328 .148 .478 r
F
.63117 .2491 m .63124 .25709 L .63147 .25718 L .822 .528 .492 r
F
.63124 .25709 m .63156 .29312 L .63147 .25718 L F
.63243 .25798 m .63281 .29358 L .63243 .25798 L .931 .625 .44 r
F
.63243 .25798 m .63243 .25798 L .63235 .25008 L F
.63117 .25706 m .63124 .25709 L .63117 .24892 L .822 .528 .492 r
F
.63185 .24916 m .63203 .24904 L .63184 .24916 L .667 .747 .91 r
F
.63234 .24988 m .63309 .2496 L .63203 .24904 L F
.63263 .24814 m .63276 .24814 L .63268 .2479 L .668 .747 .91 r
F
.63276 .24814 m .63387 .24814 L .63248 .24736 L F
.63163 .24793 m .63337 .24819 L .63247 .24704 L .667 .747 .91 r
F
.63256 .24875 m .63284 .24834 L .63276 .24814 L .668 .747 .91 r
F
.63203 .24904 m .63337 .24819 L .63163 .24793 L .667 .747 .91 r
F
.63337 .24819 m .63391 .24785 L .63348 .24761 L F
.63337 .24819 m .63348 .24761 L .63247 .24704 L F
.63188 .24937 m .65669 .23513 L .63117 .2491 L .644 .736 .916 r
F
.63468 .249 m .63505 .24904 L .63497 .24889 L .667 .747 .91 r
F
.63446 .2493 m .66198 .24053 L .63251 .24901 L .644 .736 .916 r
F
.63449 .25038 m .66498 .24662 L .63295 .24978 L F
.63265 .25088 m .63235 .25008 L .63265 .25816 L .944 .685 .22 r
F
.63433 .25135 m .6345 .25237 L .63686 .25148 L .644 .736 .916 r
F
.6312 .25696 m .65654 .24352 L .64929 .2392 L .644 .737 .917 r
F
.63112 .25704 m .63123 .25698 L .6312 .25696 L F
.63123 .25698 m .65654 .24352 L .6312 .25696 L F
.63194 .25757 m .63341 .25793 L .63216 .25744 L F
.63265 .25817 m .63341 .25793 L .63194 .25757 L F
.63272 .26123 m .65909 .27309 L .63415 .2607 L F
.63262 .26072 m .63291 .26031 L .63427 .29677 L .067 0 .41 r
F
.63253 .26083 m .63427 .29677 L .6325 .26089 L F
.63262 .26072 m .63427 .29677 L .63253 .26083 L F
.63265 .25816 m .63281 .29358 L .634 .29456 L .931 .625 .44 r
F
.63243 .25798 m .63281 .29358 L .63265 .25816 L F
.62869 .25942 m .63112 .25704 L .63024 .2567 L .644 .737 .917 r
F
.62869 .25942 m .63024 .2567 L .6301 .25668 L F
.62964 .26257 m .6295 .26347 L .63 .26372 L F
.62927 .26224 m .63028 .26215 L .63161 .29878 L .629 .374 .513 r
F
.62894 .26228 m .63161 .29878 L .62885 .26228 L F
.62825 .25434 m .62885 .26228 L .62813 .25436 L F
.62885 .26228 m .63161 .29878 L .62875 .26229 L F
.62885 .26228 m .62875 .26229 L .62813 .25436 L F
.62143 .26572 m .62256 .26516 L .62702 .26626 L .731 .459 .516 r
F
.62143 .26572 m .62139 .265 L .62256 .26516 L F
.62375 .26096 m .62143 .26572 L .62702 .26626 L .667 .747 .91 r
F
.62546 .26259 m .62437 .26316 L .62438 .26366 L .644 .737 .917 r
F
.62561 .26245 m .62437 .26262 L .62546 .26259 L F
.62174 .26511 m .61595 .26462 L .61735 .2737 L .644 .736 .916 r
F
.61764 .26375 m .61595 .26462 L .62174 .26511 L F
.61764 .26375 m .62139 .265 L .62143 .26572 L .804 .517 .503 r
F
.62032 .25995 m .62143 .26572 L .62375 .26096 L .667 .747 .91 r
F
.62437 .26262 m .62269 .26285 L .62437 .26269 L .644 .737 .917 r
F
.62437 .26262 m .62437 .26269 L .62546 .26259 L F
.62512 .26146 m .62436 .2619 L .62561 .26245 L F
.62436 .2619 m .62269 .26285 L .62437 .26262 L F
.62436 .2619 m .62437 .26262 L .62561 .26245 L F
.61618 .26423 m .60884 .27088 L .61611 .26435 L .644 .736 .916 r
F
.61611 .26435 m .60884 .27088 L .61595 .26462 L F
.62435 .25566 m .62032 .25995 L .62375 .26096 L .667 .747 .91 r
F
.62291 .25486 m .62032 .25995 L .62435 .25566 L F
.62447 .25284 m .62122 .25261 L .62185 .25382 L F
.62411 .25211 m .62407 .25211 L .62447 .25284 L F
.62407 .25211 m .62122 .25261 L .62408 .25281 L F
.62407 .25211 m .62408 .25281 L .62447 .25284 L F
.62406 .25179 m .62407 .25202 L .62407 .25202 L .972 .694 .284 r
F
.62405 .25117 m .62406 .25179 L .62407 .25202 L 0 0 .044 r
F
.62405 .25117 m .62407 .25202 L .62406 .2514 L F
.62407 .25211 m .62109 .25131 L .62122 .25261 L .667 .747 .91 r
F
.62412 .25192 m .62413 .25215 L .62406 .25179 L .972 .694 .284 r
F
.62411 .25211 m .62407 .25202 L .62407 .25211 L .667 .747 .91 r
F
.62437 .26269 m .62437 .26284 L .62546 .26259 L .644 .737 .917 r
F
.61631 .26421 m .61626 .26329 L .61764 .26375 L .804 .517 .503 r
F
.61631 .26421 m .61764 .26375 L .62143 .26572 L F
.62032 .25995 m .61631 .26421 L .62143 .26572 L .667 .747 .91 r
F
.62166 .26343 m .62071 .26504 L .62546 .26259 L .644 .737 .917 r
F
.61595 .26462 m .61171 .27183 L .61735 .2737 L .644 .736 .916 r
F
.62635 .26397 m .61667 .27188 L .61709 .28201 L .644 .737 .917 r
F
.62695 .26281 m .62613 .26353 L .62635 .26397 L F
.62613 .26353 m .61667 .27188 L .62635 .26397 L F
.62413 .25215 m .62446 .26012 L .62407 .25202 L .972 .694 .284 r
F
.62685 .2627 m .62607 .2634 L .62695 .26281 L .644 .737 .917 r
F
.62607 .2634 m .61667 .27188 L .62613 .26353 L F
.62607 .2634 m .62613 .26353 L .62695 .26281 L F
.62421 .2523 m .62447 .25284 L .62474 .26068 L .972 .694 .284 r
F
.62508 .261 m .62496 .2609 L .62457 .25271 L .948 .643 .425 r
F
.6242 .25207 m .62446 .2526 L .62447 .25284 L .972 .694 .284 r
F
.6242 .25207 m .62447 .25284 L .62421 .2523 L F
.6242 .25207 m .62452 .26024 L .62412 .25192 L F
.62546 .26259 m .61759 .27032 L .62607 .2634 L .644 .737 .917 r
F
.61759 .27032 m .60856 .27919 L .61667 .27188 L F
.61759 .27032 m .61667 .27188 L .62607 .2634 L F
.62824 .26404 m .61709 .28201 L .62639 .2833 L F
.62788 .26369 m .61709 .28201 L .62824 .26404 L F
.62815 .26277 m .62771 .26353 L .62836 .26288 L F
.62771 .26353 m .61709 .28201 L .62788 .26369 L F
.62771 .26353 m .62788 .26369 L .62836 .26288 L F
.62457 .25271 m .62496 .2609 L .62446 .2526 L .948 .643 .425 r
F
.62714 .26244 m .61709 .28201 L .62841 .26232 L .644 .737 .917 r
F
.62841 .26232 m .62841 .26232 L .62841 .26232 L F
.62714 .26244 m .62841 .26232 L .62841 .26232 L F
.6266 .25412 m .62715 .26207 L .62655 .25411 L .755 .473 .507 r
F
.62662 .26249 m .62685 .2627 L .62714 .26244 L .644 .737 .917 r
F
.62619 .26188 m .62546 .26259 L .62731 .26211 L F
.62829 .25256 m .62725 .25433 L .62813 .25425 L .644 .736 .916 r
F
.62693 .25401 m .62812 .25425 L .62812 .25436 L .755 .473 .507 r
F
.62693 .25401 m .62812 .25436 L .62694 .25417 L F
.62812 .25436 m .62686 .25454 L .62812 .25436 L .667 .747 .91 r
F
.6284 .25136 m .62703 .25419 L .62812 .25436 L F
.62703 .25419 m .62686 .25454 L .62812 .25436 L F
.62693 .25401 m .62694 .25417 L .62659 .25395 L .755 .473 .507 r
F
.62694 .25417 m .62743 .26213 L .62661 .25412 L F
.62694 .25417 m .62661 .25412 L .62659 .25395 L F
.62694 .25417 m .62812 .25436 L .62841 .26232 L F
.62694 .25417 m .62841 .26232 L .62743 .26213 L F
.62812 .25425 m .62875 .26229 L .62841 .26232 L .629 .374 .513 r
F
.62743 .26213 m .62715 .26207 L .62659 .25395 L .755 .473 .507 r
F
.62869 .25942 m .62714 .26244 L .62841 .26232 L .644 .737 .917 r
F
.62715 .26207 m .62972 .29902 L .62711 .26207 L .755 .473 .507 r
F
.62715 .26207 m .62711 .26207 L .62655 .25411 L F
.62496 .2609 m .62487 .26081 L .62446 .2526 L .948 .643 .425 r
F
.62446 .2526 m .62487 .26081 L .62474 .26068 L F
.62557 .25351 m .62599 .26165 L .62536 .2534 L .862 .563 .481 r
F
.62599 .26165 m .62582 .26156 L .62536 .2534 L F
.62472 .25307 m .62508 .261 L .62459 .25295 L .948 .643 .425 r
F
.62421 .2523 m .62474 .26068 L .62452 .26024 L .972 .694 .284 r
F
.62472 .25307 m .62547 .26138 L .62508 .261 L .948 .643 .425 r
F
.62473 .25308 m .62547 .26138 L .62472 .25307 L F
.62473 .25308 m .6252 .25353 L .62547 .26138 L F
.6256 .25372 m .62632 .25407 L .62659 .26196 L .862 .563 .481 r
F
.62557 .25351 m .62659 .26196 L .62599 .26165 L F
.62711 .26207 m .62702 .26205 L .62644 .25409 L .755 .473 .507 r
F
.62538 .25361 m .62582 .26156 L .62521 .25353 L .862 .563 .481 r
F
.61254 .26112 m .61238 .2612 L .61643 .26339 L .644 .736 .916 r
F
.61238 .2612 m .61494 .26372 L .61643 .26339 L F
.612 .26182 m .61329 .26156 L .61631 .26421 L .878 .579 .477 r
F
.61329 .26156 m .61626 .26329 L .61631 .26421 L F
.62452 .26024 m .62446 .26012 L .62412 .25192 L .972 .694 .284 r
F
.6284 .25136 m .62411 .25211 L .62447 .25284 L .667 .747 .91 r
F
.62413 .25215 m .62407 .25202 L .62406 .25179 L .972 .694 .284 r
F
.6284 .25136 m .62406 .25133 L .62407 .25202 L .667 .747 .91 r
F
.6284 .25136 m .62407 .25202 L .62411 .25211 L F
.62471 .25284 m .62472 .25307 L .62457 .25271 L .948 .643 .425 r
F
.62472 .25307 m .62459 .25295 L .62457 .25271 L F
.6284 .25136 m .62447 .25284 L .62512 .25345 L .667 .747 .91 r
F
.6239 .25133 m .62145 .25002 L .62109 .25131 L F
.62405 .25117 m .62406 .25139 L .62405 .251 L 0 0 .044 r
F
.62406 .25139 m .62406 .25121 L .62405 .251 L F
.62407 .25202 m .62441 .26001 L .62434 .25987 L .972 .694 .284 r
F
.62415 .25396 m .62416 .25408 L .62406 .25121 L 0 0 .044 r
F
.62433 .25936 m .62416 .25408 L .62415 .25396 L F
.62433 .25936 m .62433 .25922 L .62416 .25408 L F
.62406 .25121 m .62406 .25121 L .62405 .251 L F
.62407 .25202 m .62441 .26001 L .62407 .25202 L .972 .694 .284 r
F
.62433 .25936 m .62406 .25121 L .62406 .25121 L 0 0 .044 r
F
.6284 .25136 m .62433 .25057 L .62406 .25106 L .667 .747 .91 r
F
.62406 .25133 m .62406 .25106 L .6239 .25133 L F
.6284 .25136 m .62406 .25106 L .62406 .25133 L F
.62433 .25057 m .62145 .25002 L .6239 .25133 L F
.62463 .24987 m .62463 .25002 L .62473 .24969 L 0 0 .377 r
F
.62463 .25002 m .62473 .24984 L .62473 .24969 L F
.62433 .25057 m .62229 .24881 L .62145 .25002 L .667 .747 .91 r
F
.6284 .25136 m .62474 .24983 L .62433 .25057 L F
.62474 .24983 m .62229 .24881 L .62433 .25057 L F
.6248 .25813 m .62489 .25798 L .62474 .24984 L 0 0 .377 r
F
.62473 .24984 m .62474 .24984 L .62473 .24969 L F
.6248 .25813 m .62474 .24984 L .62473 .24984 L F
.62463 .25002 m .6248 .25813 L .62473 .24984 L F
.62631 .25389 m .62692 .26203 L .62659 .26196 L .755 .473 .507 r
F
.62643 .25391 m .62702 .26205 L .62631 .25389 L F
.62702 .26205 m .62972 .29902 L .62692 .26203 L F
.62702 .26205 m .62692 .26203 L .62631 .25389 L F
.62869 .25942 m .62512 .26146 L .62523 .26169 L .644 .737 .917 r
F
.62619 .26188 m .62523 .26169 L .62561 .26245 L F
.62869 .25942 m .62523 .26169 L .62619 .26188 L F
.62869 .25942 m .62296 .26124 L .62296 .26124 L F
.62485 .26162 m .62296 .26124 L .62166 .26343 L F
.62869 .25942 m .62296 .26124 L .62485 .26162 L F
.62569 .26261 m .62607 .2634 L .62685 .2627 L F
.62546 .26259 m .62685 .2627 L .62662 .26249 L F
.62659 .26196 m .62972 .29902 L .62788 .29871 L .755 .473 .507 r
F
.62692 .26203 m .62972 .29902 L .62659 .26196 L F
.62496 .2609 m .62674 .29814 L .62487 .26081 L .948 .643 .425 r
F
.62474 .26068 m .62674 .29814 L .626 .29744 L F
.62487 .26081 m .62674 .29814 L .62474 .26068 L F
.62529 .27947 m .626 .29744 L .62531 .28066 L .972 .694 .284 r
F
.62446 .26012 m .62441 .26001 L .62407 .25202 L F
.62536 .2534 m .62538 .25361 L .62519 .25331 L .862 .563 .481 r
F
.62538 .25361 m .62521 .25353 L .62519 .25331 L F
.6284 .25136 m .62512 .25345 L .626 .25392 L .667 .747 .91 r
F
.62512 .25345 m .6252 .25353 L .626 .25392 L F
.62474 .24983 m .62355 .24778 L .62229 .24881 L F
.6284 .25136 m .62556 .24926 L .62474 .24983 L F
.62556 .24926 m .62355 .24778 L .62474 .24983 L F
.62562 .24913 m .62563 .24921 L .62588 .24897 L .369 .177 .485 r
F
.62563 .24921 m .62588 .24904 L .62588 .24897 L F
.62556 .24926 m .62514 .24699 L .62355 .24778 L .667 .747 .91 r
F
.62695 .24861 m .62609 .24883 L .62609 .24889 L .547 .31 .508 r
F
.6284 .25136 m .62647 .24877 L .62556 .24926 L .667 .747 .91 r
F
.62647 .24877 m .62609 .24889 L .62556 .24926 L F
.61745 .25835 m .61631 .26421 L .62032 .25995 L F
.612 .26182 m .61194 .26077 L .61329 .26156 L .878 .579 .477 r
F
.61745 .25835 m .612 .26182 L .61631 .26421 L .667 .747 .91 r
F
.62869 .25942 m .62087 .26038 L .61599 .26345 L .644 .737 .917 r
F
.62807 .25025 m .62707 .24858 L .62668 .2487 L .667 .747 .91 r
F
.62695 .24861 m .62609 .24889 L .62695 .24861 L .547 .31 .508 r
F
.6284 .25136 m .62807 .25025 L .62668 .2487 L .667 .747 .91 r
F
.62665 .24871 m .62668 .2487 L .62654 .24855 L F
.6284 .25136 m .62668 .2487 L .62665 .24871 L F
.6284 .25136 m .62654 .24855 L .62632 .24857 L F
.62599 .26165 m .62659 .26196 L .62788 .29871 L .862 .563 .481 r
F
.62711 .26207 m .62972 .29902 L .62702 .26205 L .755 .473 .507 r
F
.62869 .25942 m .62619 .26188 L .62731 .26211 L .644 .737 .917 r
F
.6284 .25136 m .626 .25392 L .62632 .25407 L .667 .747 .91 r
F
.62655 .25411 m .62644 .25409 L .62643 .25391 L .755 .473 .507 r
F
.62659 .25395 m .6266 .25412 L .62654 .25393 L F
.6266 .25412 m .62655 .25411 L .62654 .25393 L F
.6284 .25136 m .62632 .25407 L .62703 .25419 L .667 .747 .91 r
F
.62743 .26213 m .62972 .29902 L .62715 .26207 L .755 .473 .507 r
F
.5931 .25548 m .56408 .27172 L .59629 .26146 L .644 .736 .916 r
F
.60652 .26214 m .59201 .25751 L .59278 .26382 L .644 .737 .917 r
F
.62406 .25139 m .62433 .25936 L .62406 .25121 L 0 0 .044 r
F
.62406 .2514 m .62407 .25202 L .62434 .25987 L F
.62405 .251 m .62433 .25922 L .62405 .25085 L F
.62433 .25922 m .62433 .2591 L .62405 .25085 L F
.62405 .25117 m .62434 .25987 L .62433 .25936 L F
.62588 .24897 m .62595 .25718 L .62592 .24894 L .369 .177 .485 r
F
.62869 .25942 m .62287 .25912 L .62087 .26038 L .644 .737 .917 r
F
.62546 .26259 m .62607 .2634 L .62569 .26261 L F
.62599 .26165 m .62788 .29871 L .62582 .26156 L .862 .563 .481 r
F
.62508 .261 m .62674 .29814 L .62496 .2609 L .948 .643 .425 r
F
.62508 .261 m .62547 .26138 L .62674 .29814 L F
.62582 .26156 m .62788 .29871 L .62568 .26149 L .862 .563 .481 r
F
.62547 .26138 m .62788 .29871 L .62674 .29814 L F
.62568 .26149 m .62788 .29871 L .62547 .26138 L F
.60781 .25367 m .59234 .24915 L .5931 .25548 L .644 .736 .916 r
F
.60781 .25367 m .5931 .25548 L .60776 .25368 L F
.5931 .25548 m .55753 .25986 L .56408 .27172 L F
.59234 .24915 m .55753 .25986 L .5931 .25548 L F
.61531 .25627 m .612 .26182 L .61745 .25835 L .667 .747 .91 r
F
.60878 .25872 m .60981 .25867 L .612 .26182 L .951 .645 .421 r
F
.60981 .25867 m .61194 .26077 L .612 .26182 L F
.61531 .25627 m .60878 .25872 L .612 .26182 L .667 .747 .91 r
F
.62291 .25486 m .61745 .25835 L .62032 .25995 L F
.61406 .25386 m .60878 .25872 L .61531 .25627 L F
.60689 .2551 m .60684 .254 L .60748 .25523 L .974 .689 .29 r
F
.61406 .25386 m .60689 .2551 L .60878 .25872 L .667 .747 .91 r
F
.61881 .25891 m .59375 .25128 L .59201 .25751 L .644 .737 .917 r
F
.62405 .25085 m .62433 .2591 L .62433 .25893 L 0 0 .044 r
F
.6245 .25009 m .62405 .25085 L .62433 .25893 L 0 0 .377 r
F
.6245 .25009 m .62433 .25893 L .6247 .25831 L F
.62869 .25942 m .62409 .25835 L .62287 .25912 L .644 .737 .917 r
F
.60753 .24733 m .60719 .2475 L .60646 .25122 L 0 0 .278 r
F
.60646 .25122 m .60641 .25021 L .60655 .25142 L .771 .587 .018 r
F
.60719 .2475 m .60641 .25021 L .60646 .25122 L 0 0 .278 r
F
.60638 .24989 m .59234 .24915 L .60638 .24991 L .644 .736 .916 r
F
.62102 .25204 m .60781 .25367 L .621 .25205 L F
.60646 .25122 m .60655 .25142 L .60689 .2551 L .771 .587 .018 r
F
.62 .25269 m .60776 .25368 L .60681 .25394 L .644 .736 .916 r
F
.62 .25269 m .60681 .25394 L .60735 .25499 L F
.60655 .25142 m .60684 .254 L .60689 .2551 L .771 .587 .018 r
F
.62099 .25206 m .60776 .25368 L .62 .25269 L .644 .736 .916 r
F
.62185 .25382 m .61745 .25835 L .62291 .25486 L .667 .747 .91 r
F
.62185 .25382 m .61531 .25627 L .61745 .25835 L F
.62122 .25261 m .61531 .25627 L .62185 .25382 L F
.62122 .25261 m .61406 .25386 L .61531 .25627 L F
.61378 .25127 m .60689 .2551 L .61406 .25386 L F
.61378 .25127 m .60646 .25122 L .60689 .2551 L F
.62109 .25131 m .61406 .25386 L .62122 .25261 L F
.62109 .25131 m .61378 .25127 L .61406 .25386 L F
.6145 .24867 m .60646 .25122 L .61378 .25127 L F
.6145 .24867 m .60753 .24733 L .60646 .25122 L F
.62241 .25796 m .59789 .24557 L .59375 .25128 L .644 .737 .917 r
F
.62473 .24969 m .62489 .25798 L .62501 .25777 L 0 0 .377 r
F
.6245 .25009 m .6247 .25831 L .62463 .24987 L F
.6247 .25831 m .6248 .25813 L .62463 .24987 L F
.62592 .24894 m .62598 .25716 L .62609 .24883 L .369 .177 .485 r
F
.62869 .25942 m .62502 .25777 L .62409 .25835 L .644 .737 .917 r
F
.62574 .25731 m .62595 .25718 L .62588 .24903 L .369 .177 .485 r
F
.62574 .25731 m .62588 .24903 L .62588 .24904 L F
.62563 .24921 m .62574 .25731 L .62588 .24904 L F
.62562 .24913 m .62473 .24969 L .62501 .25777 L F
.62562 .24913 m .62501 .25777 L .62574 .25731 L F
.61003 .2437 m .60946 .24378 L .60753 .24733 L .089 0 .427 r
F
.60946 .24378 m .60749 .24647 L .60753 .24733 L F
.60753 .24733 m .60749 .24647 L .60719 .2475 L 0 0 .278 r
F
.6076 .24608 m .5982 .2372 L .59407 .24292 L .644 .736 .916 r
F
.60852 .24286 m .5982 .2372 L .6076 .24608 L F
.62145 .25002 m .61378 .25127 L .62109 .25131 L .667 .747 .91 r
F
.62145 .25002 m .6145 .24867 L .61378 .25127 L F
.61617 .24626 m .60753 .24733 L .6145 .24867 L F
.61617 .24626 m .61003 .2437 L .60753 .24733 L F
.62284 .25679 m .60418 .24079 L .59789 .24557 L .644 .737 .917 r
F
.62869 .25942 m .62565 .25711 L .62432 .25746 L F
.62836 .26288 m .62788 .26369 L .62824 .26404 L F
.62841 .26232 m .62815 .26277 L .62836 .26288 L F
.62743 .26213 m .62841 .26232 L .62972 .29902 L .755 .473 .507 r
F
.62598 .25716 m .62613 .25707 L .62609 .24883 L .369 .177 .485 r
F
.62695 .24861 m .62609 .24889 L .62637 .25692 L .547 .31 .508 r
F
.62695 .24861 m .62637 .25692 L .62708 .25673 L F
.62609 .24883 m .62613 .25707 L .62637 .25692 L .369 .177 .485 r
F
.62595 .25718 m .62598 .25716 L .62592 .24894 L F
.62406 .25133 m .62109 .25131 L .62407 .25211 L .667 .747 .91 r
F
.61857 .23819 m .6184 .23816 L .61379 .24058 L .467 .255 .508 r
F
.61862 .23808 m .61857 .23809 L .61435 .23994 L .644 .736 .916 r
F
.6184 .23816 m .61377 .24019 L .61379 .24058 L .467 .255 .508 r
F
.61379 .24058 m .61329 .24056 L .61003 .2437 L .32 .148 .485 r
F
.61329 .24056 m .61 .24305 L .61003 .2437 L F
.61003 .2437 m .61 .24305 L .60946 .24378 L .089 0 .427 r
F
.61029 .24266 m .60447 .2324 L .5982 .2372 L .644 .736 .916 r
F
.61269 .23939 m .60447 .2324 L .61029 .24266 L F
.61379 .24058 m .61377 .24019 L .61329 .24056 L .32 .148 .485 r
F
.61423 .23985 m .61246 .22887 L .60447 .2324 L .644 .736 .916 r
F
.62229 .24881 m .6145 .24867 L .62145 .25002 L .667 .747 .91 r
F
.62229 .24881 m .61617 .24626 L .6145 .24867 L F
.62355 .24778 m .61617 .24626 L .62229 .24881 L F
.62355 .24778 m .61868 .24419 L .61617 .24626 L F
.61868 .24419 m .61003 .2437 L .61617 .24626 L F
.61868 .24419 m .61379 .24058 L .61003 .2437 L F
.62186 .2426 m .61379 .24058 L .61868 .24419 L F
.62186 .2426 m .61857 .23819 L .61379 .24058 L F
.62509 .25669 m .61218 .23726 L .60418 .24079 L .644 .737 .917 r
F
.62723 .24853 m .62731 .25667 L .6274 .24849 L .547 .31 .508 r
F
.62869 .25942 m .62675 .25682 L .62565 .25711 L .644 .737 .917 r
F
.62731 .25667 m .62745 .25663 L .6274 .24849 L .547 .31 .508 r
F
.6295 .24844 m .62868 .24843 L .62951 .24855 L .735 .457 .508 r
F
.62848 .24837 m .62848 .24844 L .62868 .24835 L .65 .39 .512 r
F
.62848 .24844 m .62868 .24843 L .62868 .24835 L F
.62868 .24835 m .62868 .24843 L .62868 .24843 L F
.62824 .24839 m .62824 .24845 L .62848 .24837 L F
.62824 .24845 m .62848 .24844 L .62848 .24837 L F
.6296 .24525 m .62982 .24527 L .62962 .2452 L .668 .747 .91 r
F
.63075 .24652 m .62933 .2413 L .62887 .24634 L .667 .747 .91 r
F
.63075 .24652 m .6331 .24167 L .62933 .2413 L F
.6327 .23521 m .63505 .23034 L .62942 .22979 L .668 .746 .909 r
F
.63291 .23841 m .63528 .23352 L .62961 .23296 L .668 .747 .91 r
F
.6331 .24167 m .6298 .23622 L .62933 .2413 L .667 .747 .91 r
F
.6331 .24167 m .63547 .23678 L .6298 .23622 L F
.63528 .23352 m .63509 .23027 L .62943 .22971 L .731 .456 .511 r
F
.62961 .23296 m .62367 .23019 L .62385 .23345 L .656 .397 .517 r
F
.62961 .23296 m .62943 .22971 L .62367 .23019 L F
.63528 .23352 m .62943 .22971 L .62961 .23296 L .731 .456 .511 r
F
.63547 .23678 m .63528 .23352 L .62961 .23296 L F
.6298 .23622 m .62961 .23296 L .62385 .23345 L .656 .397 .517 r
F
.63547 .23678 m .62961 .23296 L .6298 .23622 L .731 .456 .511 r
F
.62892 .25107 m .63128 .2265 L .62161 .22685 L .644 .736 .916 r
F
.62824 .24845 m .6274 .24849 L .62769 .25657 L .65 .39 .512 r
F
.6284 .25136 m .62845 .25088 L .62807 .25025 L .667 .747 .91 r
F
.62829 .25256 m .62813 .25425 L .62862 .2542 L .644 .736 .916 r
F
.62824 .25424 m .62825 .25434 L .62812 .25425 L .629 .374 .513 r
F
.62825 .25434 m .62813 .25436 L .62812 .25425 L F
.62876 .25419 m .62998 .2541 L .62876 .25427 L F
.62836 .25432 m .62836 .25432 L .62835 .25423 L F
.62955 .25317 m .62862 .2542 L .62983 .25409 L .644 .736 .916 r
F
.6284 .25136 m .62812 .25436 L .62925 .2542 L .667 .747 .91 r
F
.62824 .24845 m .62769 .25657 L .62837 .25654 L .65 .39 .512 r
F
.6274 .24849 m .62745 .25663 L .62769 .25657 L .547 .31 .508 r
F
.62695 .24861 m .62708 .25673 L .62707 .24858 L F
.62708 .25673 m .62718 .25671 L .62707 .24858 L F
.62707 .24858 m .62718 .25671 L .6272 .24854 L F
.62718 .25671 m .62728 .25668 L .6272 .24854 L F
.62588 .24904 m .62588 .24903 L .62588 .24897 L .369 .177 .485 r
F
.6264 .24867 m .62514 .24699 L .62556 .24926 L .667 .747 .91 r
F
.6272 .24854 m .62728 .25668 L .62723 .24853 L .547 .31 .508 r
F
.62728 .25668 m .62731 .25667 L .62723 .24853 L F
.62716 .2482 m .61497 .22831 L .62682 .24815 L .644 .736 .916 r
F
.62055 .23766 m .61857 .23809 L .61857 .23819 L .571 .333 .517 r
F
.61862 .23808 m .61862 .23807 L .61857 .23809 L .644 .736 .916 r
F
.61862 .23807 m .61793 .23704 L .61435 .23994 L F
.61857 .23819 m .61857 .23809 L .6184 .23816 L .467 .255 .508 r
F
.61793 .23704 m .61246 .22887 L .61423 .23985 L .644 .736 .916 r
F
.62514 .24699 m .61868 .24419 L .62355 .24778 L .667 .747 .91 r
F
.62514 .24699 m .62186 .2426 L .61868 .24419 L F
.6266 .25662 m .62136 .23525 L .61218 .23726 L .644 .737 .917 r
F
.62869 .25942 m .62782 .25656 L .6266 .25662 L F
.62782 .25656 m .62136 .23525 L .6266 .25662 L F
.62998 .25408 m .63007 .25406 L .62998 .2541 L .492 .27 .504 r
F
.63006 .25405 m .63007 .25406 L .62998 .25408 L F
.6284 .25136 m .62931 .25439 L .63018 .25401 L .667 .747 .91 r
F
.62929 .25228 m .62886 .2517 L .62955 .25317 L .644 .736 .916 r
F
.62887 .25158 m .62886 .2517 L .62929 .25228 L F
.6284 .25136 m .63006 .25358 L .629 .2518 L .667 .747 .91 r
F
.62824 .24845 m .62837 .25654 L .62848 .24844 L .65 .39 .512 r
F
.62841 .26232 m .63161 .29878 L .62972 .29902 L .629 .374 .513 r
F
.62875 .26229 m .63161 .29878 L .62841 .26232 L F
.62869 .25942 m .62841 .26232 L .62954 .26222 L .644 .737 .917 r
F
.6284 .25136 m .62884 .25154 L .62878 .25143 L .667 .747 .91 r
F
.62837 .25654 m .62857 .25653 L .62848 .24844 L .65 .39 .512 r
F
.6284 .25136 m .6286 .25114 L .62855 .25105 L .667 .747 .91 r
F
.6284 .25136 m .62861 .25115 L .6286 .25114 L F
.6284 .25136 m .62864 .25121 L .62861 .25115 L F
.6284 .25136 m .62867 .25126 L .62864 .25121 L F
.6284 .25136 m .62868 .25126 L .62867 .25126 L F
.6284 .25136 m .6287 .25131 L .62868 .25126 L F
.62848 .24844 m .62857 .25653 L .62868 .24843 L .65 .39 .512 r
F
.62892 .25107 m .62858 .25111 L .62859 .25112 L .644 .736 .916 r
F
.62857 .25653 m .62874 .25652 L .62868 .24843 L .65 .39 .512 r
F
.62695 .24861 m .62695 .24861 L .62707 .24858 L .547 .31 .508 r
F
.62647 .24877 m .6264 .24867 L .62609 .24889 L .667 .747 .91 r
F
.62892 .25107 m .62875 .25139 L .62887 .25158 L .644 .736 .916 r
F
.62892 .25107 m .62887 .25158 L .62929 .25228 L F
.62916 .2485 m .64079 .22785 L .63128 .2265 L F
.62892 .25107 m .63015 .24865 L .62916 .2485 L F
.62994 .24849 m .62994 .24862 L .62994 .24862 L .735 .457 .508 r
F
.6295 .24844 m .62951 .24855 L .62974 .24847 L F
.62951 .24855 m .62975 .24859 L .62974 .24847 L F
.62896 .24847 m .62868 .24843 L .62874 .24994 L F
.62896 .24847 m .62874 .24994 L .62897 .25651 L F
.62951 .24855 m .62896 .24847 L .62897 .25651 L F
.62716 .2482 m .62682 .24815 L .62707 .24857 L .644 .736 .916 r
F
.62974 .24847 m .62984 .25664 L .62994 .24849 L .735 .457 .508 r
F
.62984 .25664 m .63 .25667 L .62994 .24849 L F
.62994 .24862 m .63 .25667 L .63024 .2567 L F
.62994 .24862 m .63 .25667 L .62994 .24862 L F
.62951 .24855 m .62897 .25651 L .62965 .25661 L F
.63075 .24893 m .62994 .24862 L .63024 .2567 L .822 .528 .492 r
F
.63089 .25696 m .63024 .2567 L .63156 .29312 L F
.63075 .24893 m .63024 .2567 L .63089 .25696 L F
.62951 .24855 m .62965 .25661 L .62975 .24859 L .735 .457 .508 r
F
.62869 .25942 m .6301 .25668 L .62897 .25651 L .644 .737 .917 r
F
.62899 .26227 m .63161 .29878 L .62894 .26228 L .629 .374 .513 r
F
.62965 .25661 m .63028 .29297 L .62984 .25664 L .735 .457 .508 r
F
.62965 .25661 m .62984 .25664 L .62975 .24859 L F
.6301 .25668 m .63021 .25646 L .62897 .25651 L .644 .737 .917 r
F
.6301 .25668 m .62897 .25651 L .62897 .25651 L F
.629 .25622 m .63033 .25623 L .6291 .2552 L F
.62897 .25651 m .62947 .25641 L .629 .25622 L F
.62947 .25641 m .63033 .25623 L .629 .25622 L F
.63021 .25646 m .63033 .25623 L .62897 .25651 L F
.62868 .24843 m .62874 .25652 L .62868 .24843 L .65 .39 .512 r
F
.62869 .25942 m .62897 .25651 L .62782 .25656 L .644 .737 .917 r
F
.62874 .25652 m .62898 .29308 L .62874 .25652 L .65 .39 .512 r
F
.62874 .25652 m .62874 .25652 L .62868 .24843 L F
.62897 .25651 m .62898 .29308 L .63028 .29297 L F
.62892 .25107 m .62878 .25111 L .62878 .25114 L .644 .736 .916 r
F
.62878 .25111 m .62862 .25116 L .62878 .25114 L F
.62878 .25114 m .62862 .25116 L .62865 .25122 L F
.62892 .25107 m .62865 .25122 L .62869 .25129 L F
.62868 .24843 m .62874 .25652 L .62897 .25651 L .65 .39 .512 r
F
.62874 .25652 m .62898 .29308 L .62897 .25651 L F
.62782 .25656 m .62897 .25651 L .62775 .25633 L .644 .737 .917 r
F
.62897 .25651 m .62897 .25651 L .62782 .25656 L F
.62668 .2487 m .62599 .24676 L .62514 .24699 L .667 .747 .91 r
F
.62707 .24858 m .62599 .24676 L .62668 .2487 L F
.62632 .24857 m .62654 .24855 L .62514 .24699 L F
.62775 .25633 m .63106 .2349 L .62136 .23525 L .644 .737 .917 r
F
.63015 .24865 m .64079 .22785 L .62916 .2485 L .644 .736 .916 r
F
.62897 .25651 m .63106 .2349 L .62775 .25633 L .644 .737 .917 r
F
.62984 .25664 m .63028 .29297 L .63 .25667 L .735 .457 .508 r
F
.62837 .25654 m .62898 .29308 L .62857 .25653 L .65 .39 .512 r
F
.62731 .25667 m .62765 .29348 L .62745 .25663 L .547 .31 .508 r
F
.62565 .25711 m .6266 .25662 L .62509 .25669 L .644 .737 .917 r
F
.62675 .25682 m .6266 .25662 L .62565 .25711 L F
.6266 .25662 m .61218 .23726 L .62509 .25669 L F
.62837 .25654 m .62769 .25657 L .62898 .29308 L .65 .39 .512 r
F
.62769 .25657 m .62765 .29348 L .62898 .29308 L .547 .31 .508 r
F
.62745 .25663 m .62765 .29348 L .62769 .25657 L F
.62432 .25746 m .62509 .25669 L .62284 .25679 L .644 .737 .917 r
F
.62565 .25711 m .62509 .25669 L .62432 .25746 L F
.62509 .25669 m .60418 .24079 L .62284 .25679 L F
.62857 .25653 m .62898 .29308 L .62874 .25652 L .65 .39 .512 r
F
.62598 .25716 m .62628 .29442 L .62613 .25707 L .369 .177 .485 r
F
.62409 .25835 m .62432 .25746 L .62241 .25796 L .644 .737 .917 r
F
.62502 .25777 m .62432 .25746 L .62409 .25835 L F
.62432 .25746 m .59789 .24557 L .62241 .25796 L F
.62708 .25673 m .62637 .25692 L .62765 .29348 L .547 .31 .508 r
F
.62637 .25692 m .62628 .29442 L .62765 .29348 L .369 .177 .485 r
F
.62613 .25707 m .62628 .29442 L .62637 .25692 L F
.62287 .25912 m .62241 .25796 L .61881 .25891 L .644 .737 .917 r
F
.62409 .25835 m .62241 .25796 L .62287 .25912 L F
.62241 .25796 m .59375 .25128 L .61881 .25891 L F
.62708 .25673 m .62765 .29348 L .62718 .25671 L .547 .31 .508 r
F
.62595 .25718 m .62628 .29442 L .62598 .25716 L .369 .177 .485 r
F
.62087 .26038 m .61881 .25891 L .60652 .26214 L .644 .737 .917 r
F
.62287 .25912 m .61881 .25891 L .62087 .26038 L F
.61881 .25891 m .59201 .25751 L .60652 .26214 L F
.62718 .25671 m .62765 .29348 L .62728 .25668 L .547 .31 .508 r
F
.62574 .25731 m .62628 .29442 L .62595 .25718 L .369 .177 .485 r
F
.61599 .26345 m .60652 .26214 L .59597 .26979 L .644 .737 .917 r
F
.62087 .26038 m .60652 .26214 L .61599 .26345 L F
.60652 .26214 m .59278 .26382 L .59368 .26551 L F
.60652 .26214 m .59368 .26551 L .59597 .26979 L F
.62728 .25668 m .62765 .29348 L .62731 .25667 L .547 .31 .508 r
F
.62529 .27947 m .62531 .28066 L .62446 .26012 L .972 .694 .284 r
F
.62452 .26024 m .62529 .27947 L .62446 .26012 L F
.62452 .26024 m .62474 .26068 L .626 .29744 L F
.62446 .26012 m .626 .29744 L .62441 .26001 L F
.62434 .25987 m .626 .29744 L .6256 .29661 L F
.62529 .28129 m .62559 .29564 L .62534 .28261 L 0 0 .377 r
F
.62441 .26001 m .626 .29744 L .62434 .25987 L .972 .694 .284 r
F
.62529 .28129 m .62534 .28261 L .62489 .25798 L 0 0 .377 r
F
.6248 .25813 m .62529 .28129 L .62489 .25798 L F
.61595 .26462 m .60884 .27088 L .61171 .27183 L .644 .736 .916 r
F
.62166 .26343 m .61599 .26345 L .60136 .27503 L .644 .737 .917 r
F
.62296 .26124 m .61599 .26345 L .62166 .26343 L F
.61599 .26345 m .59597 .26979 L .59987 .27359 L F
.61599 .26345 m .59987 .27359 L .60136 .27503 L F
.62574 .25731 m .62501 .25777 L .62628 .29442 L .369 .177 .485 r
F
.62501 .25777 m .62559 .29564 L .62628 .29442 L 0 0 .377 r
F
.62489 .25798 m .62559 .29564 L .62501 .25777 L F
.62433 .25936 m .6256 .29661 L .62433 .25922 L 0 0 .044 r
F
.62269 .26285 m .62166 .26343 L .62437 .26284 L .644 .737 .917 r
F
.62269 .26285 m .62437 .26284 L .62437 .26269 L F
.62166 .26343 m .60136 .27503 L .62071 .26504 L F
.6247 .25831 m .62559 .29564 L .6248 .25813 L 0 0 .377 r
F
.62433 .25922 m .6256 .29661 L .62433 .2591 L 0 0 .044 r
F
.62433 .25893 m .6256 .29661 L .62559 .29564 L F
.62433 .2591 m .6256 .29661 L .62433 .25893 L F
.62433 .25936 m .62434 .25987 L .6256 .29661 L F
.62438 .26366 m .60136 .27503 L .60856 .27919 L .644 .737 .917 r
F
.62437 .26316 m .60136 .27503 L .62438 .26366 L F
.63024 .2567 m .63028 .29297 L .63156 .29312 L .735 .457 .508 r
F
.63 .25667 m .63028 .29297 L .63024 .2567 L F
.63109 .25703 m .63111 .25704 L .63101 .24887 L .822 .528 .492 r
F
.63075 .24893 m .63156 .29312 L .63098 .24902 L F
.63024 .2567 m .64929 .2392 L .63011 .25665 L .644 .737 .917 r
F
.63112 .25704 m .6313 .25686 L .63024 .2567 L F
.6313 .25686 m .64929 .2392 L .63024 .2567 L F
.6301 .25668 m .63024 .2567 L .63011 .25665 L F
.62965 .25661 m .62897 .25651 L .63028 .29297 L .735 .457 .508 r
F
.63109 .25703 m .63156 .29312 L .63111 .25704 L .822 .528 .492 r
F
.63216 .25744 m .66184 .24892 L .65654 .24352 L .644 .737 .917 r
F
.63341 .25793 m .66184 .24892 L .63216 .25744 L F
.6321 .2577 m .63281 .29358 L .63228 .25786 L .931 .625 .44 r
F
.63148 .24809 m .63168 .24807 L .63163 .24793 L .667 .747 .91 r
F
.63099 .24902 m .64946 .2308 L .63013 .24869 L .644 .736 .916 r
F
.63216 .25744 m .65654 .24352 L .63112 .25704 L .644 .737 .917 r
F
.63117 .25706 m .63156 .29312 L .63124 .25709 L .822 .528 .492 r
F
.63117 .2491 m .65669 .23513 L .63103 .24898 L .644 .736 .916 r
F
.63165 .2495 m .63188 .24937 L .63117 .2491 L F
.6321 .2577 m .63147 .25718 L .63281 .29358 L .931 .625 .44 r
F
.63103 .24898 m .65669 .23513 L .64946 .2308 L .644 .736 .916 r
F
.63234 .24988 m .63505 .24904 L .63468 .249 L .667 .747 .91 r
F
.63188 .24937 m .63446 .2493 L .63251 .24901 L .644 .736 .916 r
F
.63243 .24995 m .63505 .24904 L .63234 .24988 L .667 .747 .91 r
F
.63295 .24978 m .63446 .2493 L .63188 .24937 L .644 .736 .916 r
F
.63227 .25001 m .63235 .25008 L .63234 .24988 L .931 .625 .44 r
F
.63234 .24988 m .63235 .25008 L .63235 .25008 L F
.63314 .25053 m .63559 .25011 L .63243 .24995 L .667 .747 .91 r
F
.63225 .25 m .63449 .25038 L .63295 .24978 L .644 .736 .916 r
F
.63262 .25063 m .63314 .25053 L .63238 .24997 L .667 .747 .91 r
F
.63293 .25057 m .63449 .25038 L .63225 .25 L .644 .736 .916 r
F
.63331 .25209 m .6345 .25237 L .63433 .25135 L F
.63033 .25623 m .64929 .2392 L .64059 .23625 L .644 .737 .917 r
F
.63011 .25665 m .63046 .25634 L .63033 .25623 L F
.63046 .25634 m .64929 .2392 L .63033 .25623 L F
.63111 .25704 m .63156 .29312 L .63117 .25706 L .822 .528 .492 r
F
.63235 .24991 m .63234 .24988 L .63235 .25008 L .944 .685 .22 r
F
.63225 .25 m .63295 .24978 L .63165 .2495 L .644 .736 .916 r
F
.6291 .2552 m .64059 .23625 L .63106 .2349 L .644 .737 .917 r
F
.63279 .25127 m .6328 .2513 L .63281 .25127 L .644 .736 .916 r
F
.63033 .25623 m .64059 .23625 L .6291 .2552 L .644 .737 .917 r
F
.63236 .25792 m .63281 .29358 L .63243 .25798 L .931 .625 .44 r
F
.63293 .26066 m .63366 .26088 L .63319 .26047 L .644 .737 .917 r
F
.63291 .26031 m .63446 .2958 L .63427 .29677 L 0 0 .209 r
F
.63295 .26014 m .63446 .2958 L .63291 .26031 L F
.63289 .25881 m .63265 .25816 L .634 .29456 L .944 .685 .22 r
F
.633 .25988 m .6331 .25938 L .63446 .2958 L 0 0 .209 r
F
.63296 .26008 m .63446 .2958 L .63295 .26014 L F
.63297 .26002 m .63446 .2958 L .63296 .26008 L F
.633 .25988 m .63446 .2958 L .63297 .26002 L F
.63302 .25915 m .634 .29456 L .63302 .25916 L .944 .685 .22 r
F
.63415 .2607 m .6634 .26751 L .63646 .25983 L .644 .737 .917 r
F
.6331 .25938 m .634 .29456 L .63446 .2958 L .944 .685 .22 r
F
.63302 .25916 m .634 .29456 L .6331 .25938 L F
.63354 .26055 m .63366 .26088 L .63415 .2607 L .644 .737 .917 r
F
.63757 .27134 m .64483 .28109 L .63487 .26412 L F
.63296 .259 m .634 .29456 L .63302 .25915 L .944 .685 .22 r
F
.63289 .25881 m .634 .29456 L .63296 .259 L F
.63757 .27134 m .64147 .2818 L .64483 .28109 L .644 .737 .917 r
F
.61667 .27188 m .60856 .27919 L .61173 .28024 L F
.61667 .27188 m .61173 .28024 L .61709 .28201 L F
.6247 .25831 m .62433 .25893 L .62559 .29564 L 0 0 .377 r
F
.22045 .54769 m .19729 .54887 L .21872 .55047 L .662 .802 .95 r
F
.19717 .55444 m .17495 .56153 L .19672 .56023 L .661 .803 .951 r
F
.21874 .55604 m .19717 .55444 L .19672 .56023 L F
.68889 .55013 m .67837 .56302 L .69493 .55431 L .657 .808 .956 r
F
.68889 .55013 m .66925 .55681 L .67837 .56302 L F
0 g
.67837 .56302 m
.69075 .56741 L
s
.26076 .55353 m .27638 .54432 L .25822 .551 L .661 .803 .951 r
F
.26076 .55353 m .28138 .54942 L .27638 .54432 L F
.34777 .2842 m .30474 .27993 L .33687 .29331 L .643 .738 .918 r
F
.28096 .54389 m .29415 .5321 L .27599 .5388 L .662 .802 .95 r
F
.28096 .54389 m .30152 .53979 L .29415 .5321 L F
.24181 .42369 m .21968 .4191 L .21948 .42582 L .667 .434 .558 r
F
.24181 .42369 m .24196 .41697 L .21968 .4191 L F
0 g
.19947 .42441 m
.21968 .4191 L
s
.34994 .26779 m .32344 .24965 L .30736 .26354 L .644 .737 .916 r
F
.36443 .26105 m .32344 .24965 L .34994 .26779 L F
.39925 .29657 m .39857 .27298 L .37975 .27362 L .643 .738 .918 r
F
.68537 .41541 m .6668 .40421 L .6517 .41471 L .656 .78 .94 r
F
.69805 .40997 m .6668 .40421 L .68537 .41541 L F
.46164 .29983 m .47602 .27413 L .45018 .28955 L .643 .738 .918 r
F
.46164 .29983 m .49311 .28978 L .47602 .27413 L F
0 g
.40136 .37174 m
.40208 .3544 L
s
.45131 .27308 m .45443 .24503 L .4364 .26481 L .644 .737 .916 r
F
.45131 .27308 m .47688 .25767 L .45443 .24503 L F
0 g
.39381 .37158 m
.39458 .35426 L
s
.76709 .42033 m .77367 .4007 L .75626 .41537 L .655 .781 .941 r
F
.76709 .42033 m .78995 .40828 L .77367 .4007 L F
.34027 .41162 m .3221 .42815 L .34663 .41946 L .656 .78 .939 r
F
.34027 .41162 m .31239 .41648 L .3221 .42815 L F
0 g
.3221 .42815 m
.33662 .43789 L
s
.71581 .54702 m .71313 .55885 L .7208 .54782 L .657 .808 .956 r
F
.71581 .54702 m .7032 .55728 L .71313 .55885 L F
.78002 .54447 m .78747 .53043 L .78841 .53601 L .263 .171 .558 r
F
.78095 .55004 m .78002 .54447 L .78841 .53601 L F
.76275 .54002 m .78002 .54447 L .78841 .53601 L .658 .807 .955 r
F
.75488 .54505 m .78002 .54447 L .76275 .54002 L F
0 g
.77085 .55028 m
.78002 .54447 L
s
.48874 .68557 m .4904 .68621 L .49007 .69099 L .929 .753 .272 r
F
.48874 .68557 m .48908 .68079 L .4904 .68621 L F
.50355 .68165 m .4904 .68621 L .50439 .68527 L .597 .767 .96 r
F
.50355 .68165 m .48908 .68079 L .4904 .68621 L F
0 g
.4904 .68621 m
.49401 .69072 L
s
.19717 .55444 m .17549 .55283 L .17495 .56153 L .661 .803 .951 r
F
.17555 .55845 m .17495 .56153 L .17501 .56713 L 0 0 .069 r
F
0 g
.17531 .56231 m
.17749 .56698 L
s
.17555 .55845 m .17549 .55283 L .17495 .56153 L 0 0 .069 r
F
.80135 .41823 m .7891 .40156 L .78995 .40828 L .957 .65 .409 r
F
.80221 .42495 m .80135 .41823 L .78995 .40828 L F
0 g
.80135 .41823 m
.80716 .4298 L
s
.51812 .6891 m .50682 .69351 L .51948 .69084 L .597 .767 .961 r
F
.51812 .6891 m .50408 .69005 L .50682 .69351 L F
.25795 .54546 m .2685 .53459 L .25419 .54337 L .662 .802 .95 r
F
.25795 .54546 m .27599 .5388 L .2685 .53459 L F
.37139 .4107 m .35626 .42605 L .37618 .41403 L .656 .78 .939 r
F
.37139 .4107 m .34663 .41946 L .35626 .42605 L F
.53409 .5668 m .5167 .56334 L .51726 .56894 L .671 .446 .571 r
F
0 g
.50149 .57315 m
.51726 .56894 L
s
.53409 .5668 m .53351 .56121 L .5167 .56334 L .671 .446 .571 r
F
0 g
.50096 .56755 m
.5167 .56334 L
s
.21887 .56163 m .19682 .56582 L .2186 .56451 L .661 .804 .952 r
F
.26455 .42489 m .24196 .41697 L .24181 .42369 L .734 .49 .56 r
F
0 g
.21968 .4191 m
.24196 .41697 L
s
.24196 .41697 m
.26467 .41819 L
s
.57392 .69118 m .57612 .68117 L .5759 .68595 L 0 0 .201 r
F
.57369 .69596 m .57392 .69118 L .5759 .68595 L F
.56014 .68859 m .57392 .69118 L .5759 .68595 L .597 .767 .96 r
F
0 g
.56915 .69585 m
.57392 .69118 L
s
.51838 .67774 m .50484 .68049 L .51878 .67955 L .598 .766 .96 r
F
.51838 .67774 m .504 .67688 L .50484 .68049 L F
.55674 .69648 m .57369 .69596 L .5599 .69337 L .597 .767 .961 r
F
.54451 .69233 m .55674 .69648 L .5599 .69337 L F
.54211 .69361 m .55674 .69648 L .54451 .69233 L F
.56025 .68379 m .57591 .68116 L .56152 .68031 L .598 .766 .96 r
F
.54652 .6812 m .56025 .68379 L .56152 .68031 L F
.26444 .43162 m .26455 .42489 L .24181 .42369 L .734 .49 .56 r
F
0 g
.26455 .42489 m
.28604 .42933 L
s
.55076 .56691 m .53351 .56121 L .53409 .5668 L .734 .492 .563 r
F
0 g
.5167 .56334 m
.53351 .56121 L
s
.53351 .56121 m
.55016 .56131 L
s
.55076 .56691 m
.56607 .56923 L
s
.53409 .5668 m
.55076 .56691 L
s
.73742 .54572 m .74611 .55468 L .75578 .55063 L .657 .808 .956 r
F
.48065 .40634 m .48037 .39965 L .48363 .38662 L 0 0 .26 r
F
0 g
.47492 .40708 m
.48037 .39965 L
s
.322 .25768 m .30688 .26334 L .30581 .27161 L .217 .032 .402 r
F
.322 .25768 m .32304 .24938 L .30688 .26334 L F
0 g
.29751 .2798 m
.30688 .26334 L
s
.22048 .55325 m .19717 .55444 L .21874 .55604 L .661 .803 .951 r
F
.4469 .4107 m .48065 .40634 L .45271 .40261 L .657 .779 .939 r
F
.19727 .56005 m .17501 .56713 L .19682 .56582 L .661 .804 .952 r
F
.21887 .56163 m .19727 .56005 L .19682 .56582 L F
.26094 .55911 m .27659 .54992 L .25841 .55659 L F
.26094 .55911 m .2816 .555 L .27659 .54992 L F
.28138 .54942 m .29467 .53759 L .27638 .54432 L .661 .803 .951 r
F
.28138 .54942 m .30207 .5453 L .29467 .53759 L F
.30207 .5453 m .30183 .53973 L .29443 .532 L .981 .704 .422 r
F
0 g
.30183 .53973 m
.30493 .5482 L
s
.49369 .28144 m .49426 .27314 L .47727 .25744 L .939 .671 .502 r
F
0 g
.49426 .27314 m
.50457 .29063 L
s
.23093 .65051 m .23592 .65808 L .23475 .65098 L .597 .767 .961 r
F
.23593 .64723 m .2376 .65097 L .23757 .64961 L F
.23977 .57571 m .23515 .64629 L .23344 .64637 L .636 .39 .528 r
F
.24337 .57451 m .24376 .57383 L .23748 .64495 L 0 0 .268 r
F
.23752 .64695 m .2385 .65096 L .24191 .65046 L .597 .767 .961 r
F
.23661 .64623 m .23755 .64859 L .23752 .64695 L F
.23755 .64859 m .2385 .65096 L .23752 .64695 L F
.24337 .57451 m .23748 .64495 L .23746 .64498 L 0 0 .268 r
F
.24337 .57451 m .23746 .64498 L .2371 .64551 L F
.24376 .57383 m .24376 .57303 L .23747 .64425 L .796 .683 .137 r
F
.2366 .64624 m .2385 .65096 L .23661 .64623 L .597 .767 .961 r
F
.23591 .64625 m .2385 .65096 L .23659 .64621 L F
.23528 .64628 m .23545 .64654 L .23591 .64625 L F
.23545 .64654 m .2385 .65096 L .23591 .64625 L F
.24266 .57507 m .24337 .57451 L .2371 .64551 L .269 .086 .437 r
F
.23593 .64723 m .23475 .65098 L .2376 .65097 L .597 .767 .961 r
F
.23977 .57571 m .24156 .57551 L .23526 .64628 L .636 .39 .528 r
F
.23977 .57571 m .23526 .64628 L .23515 .64629 L F
.24266 .57507 m .23706 .64553 L .23638 .64596 L .269 .086 .437 r
F
.24104 .64761 m .24191 .65046 L .24476 .6495 L .597 .767 .961 r
F
.23792 .57545 m .23977 .57571 L .23344 .64637 L .751 .492 .54 r
F
.23792 .57545 m .23344 .64637 L .23333 .64636 L F
.23545 .64654 m .23517 .64836 L .23593 .64723 L .597 .767 .961 r
F
.23517 .64836 m .23475 .65098 L .23593 .64723 L F
.23523 .64667 m .23475 .65098 L .23545 .64654 L F
.23526 .64628 m .23598 .65039 L .23486 .65082 L .487 .263 .5 r
F
.24156 .57551 m .23631 .64598 L .23526 .64628 L F
.2363 .64598 m .23528 .64628 L .23659 .64621 L .597 .767 .961 r
F
.23358 .64381 m .23528 .64628 L .2363 .64598 L F
.23528 .64628 m .23528 .64628 L .2363 .64598 L F
.24156 .57551 m .24266 .57507 L .23638 .64596 L .487 .263 .5 r
F
.23631 .64598 m .23638 .64596 L .23598 .65039 L F
.24156 .57551 m .23638 .64596 L .23631 .64598 L F
.23528 .64628 m .23523 .64667 L .23545 .64654 L .597 .767 .961 r
F
.23631 .64598 m .23598 .65039 L .23526 .64628 L .487 .263 .5 r
F
.23729 .6457 m .23765 .64706 L .23994 .64743 L .597 .767 .961 r
F
.23729 .6457 m .23994 .64743 L .23944 .64679 L F
.23358 .64381 m .2363 .64598 L .23729 .6457 L F
.2363 .64598 m .23765 .64706 L .23729 .6457 L F
.24266 .57507 m .2371 .64551 L .23706 .64553 L .269 .086 .437 r
F
.23833 .64536 m .24476 .6495 L .24686 .64816 L .597 .767 .961 r
F
.23358 .64381 m .23944 .64679 L .23833 .64536 L F
.23944 .64679 m .24476 .6495 L .23833 .64536 L F
.24376 .57303 m .24307 .57199 L .23675 .64333 L .991 .745 .452 r
F
.24376 .57383 m .23747 .64429 L .23748 .64495 L .796 .683 .137 r
F
.2397 .64495 m .24686 .64816 L .24805 .64651 L .597 .767 .961 r
F
.23358 .64381 m .24358 .64709 L .2397 .64495 L F
.24358 .64709 m .24686 .64816 L .2397 .64495 L F
.23399 .64635 m .23475 .65098 L .23528 .64628 L F
.23515 .64629 m .23526 .64628 L .23486 .65082 L .636 .39 .528 r
F
.23638 .64596 m .23672 .64984 L .23598 .65039 L .269 .086 .437 r
F
.23358 .64381 m .23399 .64635 L .23528 .64628 L .597 .767 .961 r
F
.2367 .57498 m .23792 .57545 L .23156 .64607 L .839 .573 .538 r
F
.2341 .64701 m .23093 .65051 L .23475 .65098 L .597 .767 .961 r
F
.23371 .64686 m .23093 .65051 L .2341 .64701 L F
.23262 .64624 m .23254 .64643 L .23401 .64647 L F
.23254 .64643 m .23093 .65051 L .23371 .64686 L F
.23254 .64643 m .23371 .64686 L .23401 .64647 L F
.23093 .65051 m .22831 .65715 L .23592 .65808 L F
.22729 .64959 m .22831 .65715 L .23093 .65051 L F
.2367 .57498 m .23148 .64604 L .23031 .64561 L .839 .573 .538 r
F
.2367 .57498 m .23156 .64607 L .23148 .64604 L F
.23792 .57545 m .23333 .64636 L .23156 .64607 L .751 .492 .54 r
F
.23529 .5737 m .23584 .57439 L .22943 .64507 L .98 .727 .476 r
F
.23199 .64783 m .22729 .64959 L .23093 .65051 L .597 .767 .961 r
F
.23153 .64732 m .22998 .64815 L .23199 .64783 L F
.22998 .64815 m .22729 .64959 L .2301 .64853 L F
.22998 .64815 m .2301 .64853 L .23199 .64783 L F
.23509 .57289 m .23529 .5737 L .22885 .64445 L .952 .765 .308 r
F
.23109 .64609 m .23071 .64644 L .23237 .64687 L .597 .767 .961 r
F
.22974 .64734 m .22729 .64959 L .22998 .64815 L F
.23584 .57439 m .2367 .57498 L .23031 .64561 L .913 .647 .523 r
F
.23584 .57439 m .23031 .64561 L .23026 .64558 L F
.23509 .57289 m .22884 .64441 L .22864 .64374 L .952 .765 .308 r
F
.23529 .5737 m .22939 .64503 L .22885 .64445 L .98 .727 .476 r
F
.23509 .57289 m .22885 .64445 L .22884 .64441 L .952 .765 .308 r
F
.23529 .5737 m .22943 .64507 L .22939 .64503 L .98 .727 .476 r
F
.23552 .57187 m .23509 .57289 L .22864 .64374 L 0 0 .188 r
F
.23109 .64609 m .22681 .64742 L .22729 .64959 L .597 .767 .961 r
F
.23006 .64546 m .22709 .64685 L .23109 .64609 L F
.22709 .64685 m .22406 .64827 L .22681 .64742 L F
.22709 .64685 m .22681 .64742 L .23109 .64609 L F
.23584 .57439 m .23026 .64558 L .22943 .64507 L .913 .647 .523 r
F
.23358 .64381 m .22235 .64645 L .22406 .64827 L .597 .767 .961 r
F
.22235 .64645 m .22148 .64665 L .2217 .64679 L F
.22235 .64645 m .2217 .64679 L .22406 .64827 L F
.23668 .57109 m .23552 .57187 L .22906 .64289 L .329 .133 .455 r
F
.22235 .64645 m .21971 .64483 L .22148 .64665 L .597 .767 .961 r
F
.23358 .64381 m .22632 .64434 L .22235 .64645 L F
.22632 .64434 m .21971 .64483 L .22235 .64645 L F
.22943 .64507 m .22988 .65024 L .22901 .64971 L .913 .647 .523 r
F
.22729 .64959 m .22105 .65532 L .22831 .65715 L .597 .767 .961 r
F
.22406 .64827 m .22105 .65532 L .22729 .64959 L F
.22406 .64827 m .21462 .6527 L .22105 .65532 L F
.22972 .65014 m .22074 .65149 L .22334 .65312 L .596 .768 .962 r
F
.23071 .64644 m .22974 .64734 L .23153 .64732 L .597 .767 .961 r
F
.22974 .64734 m .22998 .64815 L .23153 .64732 L F
.23026 .64558 m .22989 .65025 L .22943 .64507 L .913 .647 .523 r
F
.22989 .65025 m .22988 .65024 L .22943 .64507 L F
.22885 .64445 m .229 .6497 L .22843 .64905 L .98 .727 .476 r
F
.22889 .64959 m .22883 .6496 L .22901 .64971 L .596 .768 .962 r
F
.229 .6497 m .22881 .6495 L .22843 .64905 L .98 .727 .476 r
F
.23552 .57187 m .22866 .64369 L .22906 .64289 L 0 0 .188 r
F
.23552 .57187 m .22864 .64374 L .22866 .64369 L F
.23358 .64381 m .22487 .64329 L .21971 .64483 L .597 .767 .961 r
F
.22487 .64329 m .21889 .64293 L .21949 .64431 L F
.22487 .64329 m .21949 .64431 L .21971 .64483 L F
.23789 .57075 m .23668 .57109 L .23023 .64227 L .55 .315 .512 r
F
.22487 .64329 m .21906 .64109 L .21889 .64293 L .597 .767 .961 r
F
.23358 .64381 m .22781 .64273 L .22487 .64329 L F
.22781 .64273 m .21906 .64109 L .22487 .64329 L F
.23358 .64381 m .23006 .64546 L .23109 .64609 L F
.23026 .64558 m .23031 .64561 L .22989 .65025 L .913 .647 .523 r
F
.22972 .65014 m .22334 .65312 L .23065 .65072 L .596 .768 .962 r
F
.22989 .65025 m .22989 .65025 L .22989 .6503 L .913 .647 .523 r
F
.23026 .64558 m .22989 .65025 L .22989 .65025 L F
.22681 .64742 m .22406 .64827 L .22599 .64906 L .597 .767 .961 r
F
.22681 .64742 m .22599 .64906 L .22729 .64959 L F
.22148 .64665 m .21462 .6527 L .22406 .64827 L F
.22148 .64665 m .20945 .64948 L .21462 .6527 L F
.22788 .64901 m .21813 .64777 L .21897 .64967 L .596 .768 .962 r
F
.22864 .64374 m .22843 .64905 L .22823 .64826 L .952 .765 .308 r
F
.22884 .64441 m .22843 .64905 L .22864 .64374 L F
.22939 .64503 m .229 .64973 L .22885 .64445 L .98 .727 .476 r
F
.22884 .64441 m .22885 .64445 L .22843 .64905 L .952 .765 .308 r
F
.22939 .64503 m .22943 .64507 L .229 .64973 L .98 .727 .476 r
F
.2308 .65058 m .22989 .65025 L .23065 .65072 L .596 .768 .962 r
F
.23031 .64561 m .23112 .6507 L .22989 .65025 L .839 .573 .538 r
F
.23198 .65102 m .22659 .65444 L .23026 .65537 L .596 .768 .962 r
F
.23071 .64644 m .23153 .64732 L .23237 .64687 L .597 .767 .961 r
F
.23358 .64381 m .23109 .64609 L .23237 .64687 L F
.23148 .64604 m .23114 .65071 L .23031 .64561 L .839 .573 .538 r
F
.23114 .65071 m .23112 .6507 L .23031 .64561 L F
.23148 .64604 m .23156 .64607 L .23113 .65076 L F
.23204 .65085 m .23114 .65071 L .23198 .65102 L .596 .768 .962 r
F
.23237 .64687 m .23153 .64732 L .23199 .64783 L .597 .767 .961 r
F
.23156 .64607 m .23303 .65101 L .23114 .65071 L .751 .492 .54 r
F
.23331 .65106 m .23026 .65537 L .2341 .65584 L .596 .768 .962 r
F
.23333 .64636 m .23303 .65101 L .23156 .64607 L .751 .492 .54 r
F
.23333 .64636 m .23344 .64637 L .23303 .65101 L F
.23475 .65098 m .23592 .65808 L .24336 .65805 L .597 .767 .961 r
F
.23474 .65129 m .2341 .65584 L .23787 .65582 L .596 .768 .962 r
F
.23344 .64637 m .23486 .65082 L .23304 .65101 L .636 .39 .528 r
F
.23344 .64637 m .23304 .65101 L .23303 .65101 L F
.23292 .64865 m .23204 .65085 L .23331 .65106 L .596 .768 .962 r
F
.23303 .65101 m .23304 .65101 L .23303 .65101 L .636 .39 .528 r
F
.2345 .65094 m .23331 .65106 L .23474 .65129 L .596 .768 .962 r
F
.23292 .64865 m .2333 .651 L .2345 .65094 L F
.2333 .651 m .23331 .65106 L .2345 .65094 L F
.23331 .65106 m .2341 .65584 L .23474 .65129 L F
.23303 .65101 m .23026 .65537 L .23331 .65106 L F
.22502 .66861 m .23708 .66521 L .23644 .66999 L .733 .496 .57 r
F
.22502 .66861 m .22568 .66382 L .23708 .66521 L F
.22831 .65715 m .23707 .6651 L .23592 .65808 L .597 .767 .961 r
F
.22831 .65715 m .22572 .66372 L .23707 .6651 L F
.22435 .67341 m .23644 .66999 L .23579 .67479 L .733 .496 .57 r
F
.22435 .67341 m .22502 .66861 L .23644 .66999 L F
.22762 .66202 m .23644 .66999 L .23528 .66295 L .596 .768 .962 r
F
.22762 .66202 m .22502 .66861 L .23644 .66999 L F
.22696 .66684 m .23579 .67479 L .23462 .66777 L .595 .768 .962 r
F
.22696 .66684 m .22435 .67341 L .23579 .67479 L F
.23026 .65537 m .23528 .66295 L .2341 .65584 L .596 .768 .962 r
F
.23026 .65537 m .22762 .66202 L .23528 .66295 L F
.22959 .6602 m .23462 .66777 L .23344 .66067 L .595 .768 .962 r
F
.22959 .6602 m .22696 .66684 L .23462 .66777 L F
.23592 .65808 m .23707 .6651 L .24818 .66506 L .597 .767 .961 r
F
.23592 .65808 m .24818 .66506 L .24336 .65805 L F
.2341 .65584 m .23528 .66295 L .24277 .66292 L .596 .768 .962 r
F
.23473 .65707 m .23344 .66067 L .23721 .66066 L .595 .768 .962 r
F
.23644 .66999 m .23708 .66521 L .24825 .66516 L .668 .436 .56 r
F
.23644 .66999 m .24825 .66516 L .24762 .66995 L F
.23528 .66295 m .23644 .66999 L .24762 .66995 L .596 .768 .962 r
F
.23528 .66295 m .24762 .66995 L .24277 .66292 L F
.23579 .67479 m .23644 .66999 L .24762 .66995 L .668 .436 .56 r
F
.23579 .67479 m .24762 .66995 L .24698 .67475 L F
.23462 .66777 m .23579 .67479 L .24698 .67475 L .595 .768 .962 r
F
.23462 .66777 m .24698 .67475 L .24212 .66774 L F
.2341 .65584 m .24277 .66292 L .23787 .65582 L .596 .768 .962 r
F
.23344 .66067 m .23462 .66777 L .24212 .66774 L .595 .768 .962 r
F
.23344 .66067 m .24212 .66774 L .23721 .66066 L F
.23475 .65098 m .24336 .65805 L .2385 .65096 L .597 .767 .961 r
F
.23455 .65101 m .23787 .65582 L .23553 .65072 L .596 .768 .962 r
F
.23485 .65092 m .2345 .65555 L .23443 .65557 L .487 .263 .5 r
F
.23486 .65082 m .23485 .65092 L .23485 .65092 L F
.23485 .65092 m .2345 .65555 L .23485 .65092 L F
.23553 .65072 m .23787 .65582 L .2413 .65532 L .596 .768 .962 r
F
.23401 .64647 m .23371 .64686 L .2341 .64701 L .597 .767 .961 r
F
.23515 .64629 m .23486 .65082 L .23344 .64637 L .636 .39 .528 r
F
.2385 .65096 m .24336 .65805 L .25016 .65705 L .597 .767 .961 r
F
.23632 .65038 m .2413 .65532 L .24417 .65436 L .596 .768 .962 r
F
.23598 .65039 m .23669 .65015 L .236 .65058 L .269 .086 .437 r
F
.23292 .64865 m .23563 .65081 L .23632 .65038 L .596 .768 .962 r
F
.23486 .65082 m .23598 .65039 L .23596 .6506 L .487 .263 .5 r
F
.23563 .65081 m .2413 .65532 L .23642 .65047 L .596 .768 .962 r
F
.23487 .65091 m .23596 .6506 L .23555 .65525 L .487 .263 .5 r
F
.23486 .65082 m .23596 .6506 L .23487 .65091 L F
.23596 .6506 m .23642 .65047 L .23632 .65038 L .596 .768 .962 r
F
.23563 .65081 m .23642 .65047 L .23596 .6506 L F
.23598 .65039 m .23672 .64984 L .23669 .65015 L .269 .086 .437 r
F
.23757 .64961 m .2376 .65097 L .2385 .65096 L .597 .767 .961 r
F
.24191 .65046 m .25016 .65705 L .25586 .65516 L F
.2385 .65096 m .25016 .65705 L .24191 .65046 L F
.23684 .64993 m .24417 .65436 L .24628 .65301 L .596 .768 .962 r
F
.23672 .64984 m .23669 .65015 L .23669 .65015 L 0 0 .268 r
F
.23648 .65046 m .24417 .65436 L .23684 .64993 L .596 .768 .962 r
F
.23765 .64706 m .24191 .65046 L .24104 .64761 L .597 .767 .961 r
F
.24191 .65046 m .25586 .65516 L .24476 .6495 L F
.23717 .64944 m .24628 .65301 L .24748 .65136 L .596 .768 .962 r
F
.23672 .64984 m .23711 .64918 L .23707 .64959 L 0 0 .268 r
F
.23672 .64984 m .23707 .64959 L .23671 .65011 L F
.23672 .64984 m .23666 .65424 L .2363 .65477 L F
.23675 .64936 m .23676 .64936 L .23672 .64984 L .269 .086 .437 r
F
.23706 .64553 m .23676 .64936 L .23675 .64936 L F
.23706 .64553 m .2371 .64551 L .23676 .64936 L F
.2371 .64551 m .23711 .64918 L .23672 .64984 L 0 0 .268 r
F
.23659 .64621 m .2366 .64624 L .23661 .64623 L .597 .767 .961 r
F
.23706 .64553 m .23672 .64984 L .23638 .64596 L .269 .086 .437 r
F
.23707 .64959 m .24628 .65301 L .23717 .64944 L .596 .768 .962 r
F
.23684 .64993 m .23708 .65001 L .23707 .64959 L F
.23708 .65001 m .24628 .65301 L .23707 .64959 L F
.23711 .64918 m .2371 .64839 L .23706 .6489 L .796 .683 .137 r
F
.23292 .64865 m .23684 .64993 L .23707 .64959 L .596 .768 .962 r
F
.23292 .64865 m .23707 .64959 L .23707 .64942 L F
.23671 .65011 m .23707 .64959 L .23666 .65424 L 0 0 .268 r
F
.23671 .65704 m .23721 .66066 L .24065 .66015 L .595 .768 .962 r
F
.23544 .65603 m .23676 .65948 L .23671 .65704 L F
.23676 .65948 m .23721 .66066 L .23671 .65704 L F
.23711 .64918 m .23706 .6489 L .23707 .64958 L .796 .683 .137 r
F
.23711 .64918 m .23707 .64958 L .23707 .64959 L F
.23746 .64498 m .23748 .64495 L .23711 .64918 L 0 0 .268 r
F
.23746 .64498 m .23711 .64918 L .2371 .64551 L F
.24476 .6495 m .25586 .65516 L .26006 .65249 L .597 .767 .961 r
F
.24476 .6495 m .26006 .65249 L .24686 .64816 L F
.23752 .64892 m .24748 .65136 L .2477 .64952 L .596 .768 .962 r
F
.23748 .64495 m .2371 .64839 L .23711 .64918 L .796 .683 .137 r
F
.23292 .64865 m .23717 .64944 L .23731 .64923 L .596 .768 .962 r
F
.23292 .64865 m .23731 .64923 L .23705 .64889 L F
.23525 .65631 m .23677 .65967 L .23544 .65603 L .595 .768 .962 r
F
.23677 .65967 m .23721 .66066 L .23676 .65948 L F
.23677 .65967 m .23676 .65948 L .23544 .65603 L F
.23485 .65569 m .23677 .65972 L .23494 .65563 L F
.23677 .65972 m .23721 .66066 L .23677 .65967 L F
.23677 .65972 m .23677 .65967 L .23494 .65563 L F
.23707 .64958 m .23666 .6542 L .23707 .64959 L .796 .683 .137 r
F
.23381 .65575 m .23721 .66066 L .23479 .65556 L .595 .768 .962 r
F
.23443 .65557 m .23479 .65556 L .23475 .65548 L F
.23381 .65575 m .23479 .65556 L .23443 .65557 L F
.2345 .65094 m .23455 .65101 L .23485 .65092 L .596 .768 .962 r
F
.23304 .65101 m .23485 .65092 L .23443 .65557 L .636 .39 .528 r
F
.23409 .65616 m .23376 .65851 L .23473 .65707 L .595 .768 .962 r
F
.23376 .65851 m .23344 .66067 L .23473 .65707 L F
.23381 .65575 m .23377 .65636 L .23409 .65616 L F
.23377 .65636 m .23344 .66067 L .23409 .65616 L F
.23371 .65561 m .23371 .65578 L .23381 .65575 L F
.23371 .65578 m .23344 .66067 L .23381 .65575 L F
.23261 .65566 m .23344 .66067 L .23371 .65561 L F
.23204 .65085 m .23196 .65107 L .23303 .65101 L .596 .768 .962 r
F
.23196 .65107 m .23026 .65537 L .23303 .65101 L F
.2308 .65058 m .22659 .65444 L .23198 .65102 L F
.23113 .65076 m .23303 .65101 L .23261 .65566 L .751 .492 .54 r
F
.23268 .65608 m .22959 .6602 L .23344 .66067 L .595 .768 .962 r
F
.23261 .65566 m .2324 .65598 L .23268 .65608 L F
.2324 .65598 m .22959 .6602 L .23268 .65608 L F
.23065 .65072 m .22334 .65312 L .22659 .65444 L .596 .768 .962 r
F
.22989 .6503 m .23113 .65076 L .23072 .65536 L .839 .573 .538 r
F
.23137 .65573 m .22959 .6602 L .23261 .65566 L .595 .768 .962 r
F
.23113 .65076 m .23083 .65538 L .23072 .65536 L .751 .492 .54 r
F
.22989 .6503 m .23072 .65536 L .22955 .65493 L .839 .573 .538 r
F
.23113 .65076 m .23261 .65566 L .23083 .65538 L .751 .492 .54 r
F
.22105 .65532 m .22572 .66372 L .22831 .65715 L .597 .767 .961 r
F
.22659 .65444 m .22762 .66202 L .23026 .65537 L .596 .768 .962 r
F
.22105 .65532 m .21488 .661 L .22572 .66372 L .597 .767 .961 r
F
.22659 .65444 m .22032 .66018 L .22762 .66202 L .596 .768 .962 r
F
.22883 .6496 m .22074 .65149 L .22945 .65018 L F
.22901 .64971 m .22945 .65018 L .22972 .65014 L F
.22883 .6496 m .22945 .65018 L .22901 .64971 L F
.23092 .65685 m .22592 .65928 L .22959 .6602 L .595 .768 .962 r
F
.23126 .65599 m .23053 .65644 L .23092 .65685 L F
.23053 .65644 m .22592 .65928 L .23092 .65685 L F
.2286 .64965 m .21897 .64967 L .22074 .65149 L .596 .768 .962 r
F
.22843 .64909 m .21897 .64967 L .2286 .64965 L F
.2284 .64898 m .22833 .64898 L .22843 .64909 L F
.22833 .64898 m .21897 .64967 L .22843 .64909 L F
.23104 .65586 m .22592 .65928 L .23126 .65599 L .595 .768 .962 r
F
.23036 .65523 m .22984 .6557 L .23141 .65561 L F
.22867 .64726 m .22823 .64826 L .22822 .64839 L 0 0 .188 r
F
.2284 .64898 m .228 .64882 L .2279 .64901 L .596 .768 .962 r
F
.22823 .64826 m .22843 .64905 L .22843 .64909 L .952 .765 .308 r
F
.22823 .64826 m .22843 .64909 L .22822 .64841 L F
.22821 .64837 m .22667 .64827 L .2284 .64898 L .596 .768 .962 r
F
.22822 .64839 m .22801 .65374 L .2278 .65309 L .952 .765 .308 r
F
.22823 .64826 m .22822 .64841 L .22822 .64839 L F
.22822 .64841 m .22801 .65374 L .22822 .64839 L F
.21971 .64483 m .20945 .64948 L .22148 .64665 L .597 .767 .961 r
F
.22821 .64837 m .21831 .64592 L .21813 .64777 L .596 .768 .962 r
F
.22867 .64726 m .22822 .64839 L .22864 .64753 L 0 0 .188 r
F
.23668 .57109 m .22913 .64285 L .23023 .64227 L .329 .133 .455 r
F
.23668 .57109 m .22906 .64289 L .22913 .64285 L F
.23914 .57067 m .23789 .57075 L .23146 .64203 L .656 .407 .53 r
F
.23358 .64381 m .22831 .64208 L .22465 .64214 L .597 .767 .961 r
F
.23789 .57075 m .2303 .64226 L .23146 .64203 L .55 .315 .512 r
F
.23789 .57075 m .23023 .64227 L .2303 .64226 L F
.22512 .64104 m .22231 .63807 L .22023 .63943 L .597 .767 .961 r
F
.23358 .64381 m .23014 .64205 L .22831 .64208 L F
.23358 .64381 m .22517 .63709 L .22231 .63807 L F
.23914 .57067 m .23153 .64203 L .23273 .64201 L .656 .407 .53 r
F
.23914 .57067 m .23146 .64203 L .23153 .64203 L F
.23358 .64381 m .22861 .63658 L .22517 .63709 L .597 .767 .961 r
F
.24041 .57079 m .23914 .57067 L .23273 .64201 L .734 .476 .538 r
F
.24041 .57079 m .23273 .64201 L .2328 .64202 L F
.24041 .57079 m .2328 .64202 L .23402 .64218 L F
.23358 .64381 m .23239 .63655 L .22861 .63658 L .597 .767 .961 r
F
.23273 .64201 m .23109 .64617 L .23236 .64608 L .656 .407 .53 r
F
.23153 .64203 m .23109 .64617 L .23273 .64201 L F
.22831 .64208 m .22916 .64156 L .22512 .64104 L .597 .767 .961 r
F
.23014 .64205 m .22916 .64156 L .22831 .64208 L F
.22916 .64156 m .22231 .63807 L .22512 .64104 L F
.2328 .64202 m .23273 .64201 L .23236 .64608 L .734 .476 .538 r
F
.23153 .64203 m .23146 .64203 L .23109 .64617 L .656 .407 .53 r
F
.22465 .64214 m .22512 .64104 L .21906 .64109 L .597 .767 .961 r
F
.22831 .64208 m .22512 .64104 L .22465 .64214 L F
.22512 .64104 m .22023 .63943 L .2196 .64032 L F
.22512 .64104 m .2196 .64032 L .21906 .64109 L F
.23358 .64381 m .23262 .64624 L .23401 .64647 L F
.24376 .57303 m .23679 .64338 L .23747 .64425 L .991 .745 .452 r
F
.24376 .57383 m .23747 .64425 L .23747 .64429 L .796 .683 .137 r
F
.23811 .64408 m .24805 .64651 L .24827 .64468 L .597 .767 .961 r
F
.23358 .64381 m .2397 .64495 L .23811 .64408 L F
.2397 .64495 m .24805 .64651 L .23811 .64408 L F
.24307 .57199 m .24171 .57117 L .23536 .64256 L .896 .63 .527 r
F
.24307 .57199 m .23536 .64256 L .23543 .6426 L F
.24307 .57199 m .23543 .6426 L .23675 .64333 L F
.24376 .57303 m .23675 .64333 L .23679 .64338 L .991 .745 .452 r
F
.24171 .57117 m .23409 .6422 L .23536 .64256 L .807 .543 .539 r
F
.23503 .64247 m .24317 .63931 L .23993 .63797 L .597 .767 .961 r
F
.23358 .64381 m .2359 .64272 L .23503 .64247 L F
.2359 .64272 m .24317 .63931 L .23503 .64247 L F
.2359 .64272 m .24574 .64095 L .24317 .63931 L F
.23358 .64381 m .23694 .64302 L .2359 .64272 L F
.23694 .64302 m .24574 .64095 L .2359 .64272 L F
.24171 .57117 m .24041 .57079 L .23402 .64218 L .807 .543 .539 r
F
.24171 .57117 m .23402 .64218 L .23409 .6422 L F
.23358 .64381 m .23625 .63703 L .23239 .63655 L .597 .767 .961 r
F
.23358 .64381 m .23993 .63797 L .23625 .63703 L F
.23358 .64381 m .24748 .64278 L .24574 .64095 L F
.23358 .64381 m .24827 .64468 L .24748 .64278 L F
.23409 .6422 m .23402 .64218 L .23366 .64621 L .807 .543 .539 r
F
.23536 .64256 m .23366 .64621 L .235 .64658 L F
.23409 .6422 m .23366 .64621 L .23536 .64256 L F
.23543 .6426 m .23536 .64256 L .235 .64658 L .896 .63 .527 r
F
.23402 .64218 m .23236 .64608 L .23366 .64621 L .734 .476 .538 r
F
.2328 .64202 m .23236 .64608 L .23402 .64218 L F
.22906 .64289 m .22823 .64826 L .22867 .64726 L 0 0 .188 r
F
.22866 .64369 m .22823 .64826 L .22906 .64289 L F
.22866 .64369 m .22864 .64374 L .22823 .64826 L F
.22888 .65657 m .22592 .65928 L .22907 .65718 L .595 .768 .962 r
F
.21411 .66587 m .22568 .66382 L .22502 .66861 L .792 .552 .575 r
F
.21411 .66587 m .21478 .66108 L .22568 .66382 L F
.22032 .66018 m .22502 .66861 L .22762 .66202 L .596 .768 .962 r
F
.21343 .67068 m .22502 .66861 L .22435 .67341 L .792 .552 .575 r
F
.21343 .67068 m .21411 .66587 L .22502 .66861 L F
.22032 .66018 m .21411 .66587 L .22502 .66861 L .596 .768 .962 r
F
.21964 .665 m .22435 .67341 L .22696 .66684 L .595 .768 .962 r
F
.22592 .65928 m .22696 .66684 L .22959 .6602 L F
.22592 .65928 m .21964 .665 L .22696 .66684 L F
.22334 .65312 m .22032 .66018 L .22659 .65444 L .596 .768 .962 r
F
.22888 .65657 m .22267 .65796 L .22592 .65928 L .595 .768 .962 r
F
.22847 .65526 m .22267 .65796 L .22888 .65657 L F
.21462 .6527 m .21488 .661 L .22105 .65532 L .597 .767 .961 r
F
.21462 .6527 m .20525 .6571 L .21488 .661 L F
.22334 .65312 m .21384 .65756 L .22032 .66018 L .596 .768 .962 r
F
.22614 .65634 m .22006 .65633 L .22267 .65796 L .595 .768 .962 r
F
.22843 .64909 m .22804 .65378 L .22843 .64909 L .98 .727 .476 r
F
.22913 .65495 m .22695 .65473 L .22614 .65634 L .595 .768 .962 r
F
.22858 .65436 m .22695 .65473 L .22913 .65495 L F
.22858 .65435 m .22857 .65435 L .22858 .65436 L F
.22857 .65435 m .22695 .65473 L .22858 .65436 L F
.229 .64973 m .22989 .6503 L .22947 .6549 L .913 .647 .523 r
F
.229 .64973 m .22947 .6549 L .22864 .65439 L F
.22989 .6503 m .22955 .65493 L .22947 .6549 L .839 .573 .538 r
F
.23225 .6535 m .22847 .65526 L .22888 .65657 L .595 .768 .962 r
F
.22075 .72843 m .22243 .73138 L .22339 .72878 L .66 .81 .955 r
F
.22302 .726 m .22229 .72678 L .22339 .72878 L F
.22229 .72678 m .22075 .72843 L .22289 .72872 L F
.22229 .72678 m .22289 .72872 L .22339 .72878 L F
.22186 .72566 m .22075 .72843 L .22229 .72678 L F
.22196 .72569 m .22229 .72678 L .22302 .726 L F
.22186 .72566 m .22229 .72678 L .22196 .72569 L F
.229 .64973 m .22864 .65439 L .22858 .65436 L .913 .647 .523 r
F
.22843 .64909 m .229 .64973 L .22858 .65436 L .98 .727 .476 r
F
.22843 .64909 m .22858 .65436 L .22804 .65378 L F
.22074 .65149 m .21384 .65756 L .22334 .65312 L .596 .768 .962 r
F
.22055 .65622 m .21828 .65451 L .22006 .65633 L .595 .768 .962 r
F
.23225 .6535 m .22739 .65385 L .22695 .65473 L F
.22804 .65378 m .22804 .65378 L .22843 .64909 L .98 .727 .476 r
F
.22822 .64841 m .22843 .64909 L .22801 .65374 L .952 .765 .308 r
F
.22843 .64909 m .22804 .65378 L .22801 .65374 L .98 .727 .476 r
F
.20945 .64948 m .20525 .6571 L .21462 .6527 L .597 .767 .961 r
F
.22074 .65149 m .20864 .65432 L .21384 .65756 L .596 .768 .962 r
F
.22468 .65405 m .21745 .65262 L .21828 .65451 L .595 .768 .962 r
F
.23225 .6535 m .22639 .65315 L .22468 .65405 L F
.22639 .65315 m .21745 .65262 L .22468 .65405 L F
.21851 .73385 m .21845 .73089 L .22242 .73142 L .791 .529 .541 r
F
.22075 .72843 m .21849 .73086 L .22243 .73138 L .66 .81 .955 r
F
.2219 .72864 m .22079 .73142 L .22308 .72898 L F
.21842 .72775 m .21849 .73086 L .22075 .72843 L F
.2219 .72864 m .21845 .73074 L .22079 .73142 L F
.22097 .72815 m .21845 .73074 L .2219 .72864 L F
.22309 .72593 m .22186 .72566 L .22302 .726 L F
.22337 .72564 m .2228 .72564 L .22309 .72593 L F
.2228 .72564 m .22186 .72566 L .22309 .72593 L F
.22804 .65378 m .22214 .72501 L .22804 .65378 L .98 .727 .476 r
F
.22339 .72878 m .22657 .73137 L .22615 .72878 L .66 .81 .955 r
F
.22339 .72878 m .22243 .73138 L .22657 .73137 L F
.22439 .72624 m .22339 .72878 L .22615 .72878 L F
.22434 .72618 m .22431 .72625 L .22439 .72624 L F
.22431 .72625 m .22339 .72878 L .22439 .72624 L F
.22615 .72878 m .22657 .73137 L .23063 .73083 L F
.22615 .72878 m .23063 .73083 L .22886 .72842 L F
.22611 .72645 m .22615 .72878 L .22886 .72842 L F
.22573 .72618 m .22579 .72658 L .22611 .72645 L F
.22579 .72658 m .22615 .72878 L .22611 .72645 L F
.23303 .65101 m .23272 .65566 L .23261 .65566 L .636 .39 .528 r
F
.23304 .65101 m .23443 .65557 L .23273 .65566 L F
.23486 .65082 m .23555 .65525 L .2345 .65555 L .487 .263 .5 r
F
.23303 .65101 m .23304 .65101 L .23273 .65566 L .636 .39 .528 r
F
.23303 .65101 m .23273 .65566 L .23272 .65566 L F
.24336 .65805 m .24818 .66506 L .25834 .66358 L .597 .767 .961 r
F
.23787 .65582 m .24277 .66292 L .24961 .66193 L .596 .768 .962 r
F
.23225 .6535 m .24065 .66015 L .24158 .65985 L .595 .768 .962 r
F
.23946 .65714 m .24158 .65985 L .24352 .6592 L F
.23598 .65039 m .23628 .6548 L .2356 .65522 L .269 .086 .437 r
F
.23598 .65039 m .2356 .65522 L .23555 .65525 L F
.23225 .6535 m .24158 .65985 L .23946 .65714 L .595 .768 .962 r
F
.22878 .72669 m .23058 .72794 L .23057 .72742 L .66 .81 .955 r
F
.24336 .65805 m .25834 .66358 L .25016 .65705 L .597 .767 .961 r
F
.25016 .65705 m .25834 .66358 L .26687 .66077 L F
.2413 .65532 m .24961 .66193 L .25534 .66003 L .596 .768 .962 r
F
.23787 .65582 m .24961 .66193 L .2413 .65532 L F
.23809 .6554 m .24352 .6592 L .24563 .65786 L .595 .768 .962 r
F
.23225 .6535 m .23946 .65714 L .23809 .6554 L F
.23946 .65714 m .24352 .6592 L .23809 .6554 L F
.2371 .64839 m .23705 .64889 L .23706 .6489 L .991 .745 .452 r
F
.23747 .64425 m .23639 .64738 L .2371 .64839 L F
.23747 .64429 m .23747 .64425 L .2371 .64839 L .796 .683 .137 r
F
.23747 .64429 m .2371 .64839 L .23748 .64495 L F
.24686 .64816 m .26006 .65249 L .26249 .64921 L .597 .767 .961 r
F
.24686 .64816 m .26249 .64921 L .24805 .64651 L F
.2371 .64839 m .23639 .64738 L .23634 .64797 L .991 .745 .452 r
F
.23665 .64837 m .2477 .64952 L .24691 .64762 L .596 .768 .962 r
F
.23292 .64865 m .23705 .64889 L .23665 .64837 L F
.2371 .64839 m .23634 .64797 L .23705 .64889 L .991 .745 .452 r
F
.23705 .64889 m .2477 .64952 L .23665 .64837 L .596 .768 .962 r
F
.2413 .65532 m .25534 .66003 L .24417 .65436 L F
.23734 .65444 m .24563 .65786 L .24684 .65621 L .595 .768 .962 r
F
.23669 .65015 m .2363 .65477 L .23628 .6548 L 0 0 .268 r
F
.23669 .65015 m .2363 .65477 L .23669 .65015 L F
.236 .65058 m .23669 .65015 L .23628 .6548 L .269 .086 .437 r
F
.23225 .6535 m .23809 .6554 L .23734 .65444 L .595 .768 .962 r
F
.23809 .6554 m .24563 .65786 L .23734 .65444 L F
.23292 .64865 m .23648 .65046 L .23684 .64993 L .596 .768 .962 r
F
.23944 .64679 m .23994 .64743 L .24104 .64761 L .597 .767 .961 r
F
.23292 .64865 m .23701 .64835 L .23617 .64788 L .596 .768 .962 r
F
.23443 .65557 m .2293 .72512 L .22821 .72557 L .487 .263 .5 r
F
.23261 .65566 m .2281 .72559 L .22632 .7259 L .636 .39 .528 r
F
.22708 .726 m .22824 .72757 L .22878 .72669 L .66 .81 .955 r
F
.22573 .72618 m .22886 .72842 L .22708 .726 L F
.2356 .65522 m .23628 .6548 L .23011 .72452 L .269 .086 .437 r
F
.22779 .72628 m .22878 .72669 L .22847 .72577 L .66 .81 .955 r
F
.22878 .72669 m .23057 .72742 L .22906 .72623 L F
.22878 .72669 m .22906 .72623 L .22847 .72577 L F
.23057 .72742 m .23056 .7272 L .22909 .72618 L F
.22906 .72623 m .22909 .72618 L .22832 .72565 L F
.23057 .72742 m .22909 .72618 L .22906 .72623 L F
.2363 .65477 m .23049 .72391 L .23628 .6548 L 0 0 .268 r
F
.22878 .72669 m .22886 .72842 L .23058 .72794 L .66 .81 .955 r
F
.22886 .72842 m .23432 .7298 L .23132 .72773 L F
.23055 .72614 m .23132 .72773 L .23338 .72676 L F
.22856 .7257 m .23056 .7272 L .23055 .72614 L F
.22848 .72576 m .23056 .7272 L .22856 .7257 L F
.22886 .72842 m .23063 .73083 L .23432 .7298 L F
.23049 .72391 m .23049 .72391 L .23628 .6548 L 0 0 .268 r
F
.23628 .6548 m .23049 .72391 L .23011 .72452 L F
.23532 .66649 m .23627 .65775 L .23164 .71023 L F
.23627 .65775 m .23663 .65449 L .23164 .71023 L F
.23164 .71023 m .23663 .65449 L .23137 .71337 L F
.23292 .64865 m .2345 .65094 L .23553 .65072 L .596 .768 .962 r
F
.2345 .65094 m .23485 .65092 L .23553 .65072 L F
.23304 .65101 m .23486 .65082 L .23485 .65092 L .636 .39 .528 r
F
.23675 .64333 m .235 .64658 L .23639 .64738 L .896 .63 .527 r
F
.23543 .6426 m .235 .64658 L .23675 .64333 L F
.23679 .64338 m .23675 .64333 L .23639 .64738 L .991 .745 .452 r
F
.23679 .64338 m .23639 .64738 L .23747 .64425 L F
.235 .64658 m .23366 .64621 L .23361 .64683 L .807 .543 .539 r
F
.23292 .64865 m .23459 .64711 L .23363 .64684 L .596 .768 .962 r
F
.23666 .6542 m .23666 .6542 L .23707 .64959 L .796 .683 .137 r
F
.23707 .64959 m .23666 .6542 L .23666 .65424 L F
.23707 .64958 m .23664 .65355 L .23666 .6542 L F
.23225 .6535 m .24022 .65498 L .23815 .65385 L .595 .768 .962 r
F
.22708 .726 m .22779 .72628 L .22832 .72565 L .66 .81 .955 r
F
.22779 .72628 m .22847 .72577 L .22832 .72565 L F
.22665 .73437 m .22658 .73141 L .23065 .73087 L .665 .428 .55 r
F
.23072 .73383 m .23065 .73087 L .23437 .72983 L .586 .365 .547 r
F
.22716 .72897 m .22895 .7314 L .23143 .73071 L .66 .81 .955 r
F
.22823 .72867 m .23143 .73071 L .2284 .72862 L F
.22716 .72897 m .2276 .72915 L .22823 .72867 L F
.2276 .72915 m .23143 .73071 L .22823 .72867 L F
.2284 .72862 m .23143 .73071 L .2335 .72973 L F
.22942 .72814 m .2335 .72973 L .22944 .72813 L F
.2284 .72862 m .22904 .72876 L .22942 .72814 L F
.22904 .72876 m .2335 .72973 L .22942 .72814 L F
.23132 .72773 m .23432 .7298 L .23741 .72835 L F
.22944 .72813 m .2335 .72973 L .23502 .72854 L F
.23057 .72742 m .23058 .72794 L .23132 .72773 L F
.22944 .72813 m .23502 .72854 L .2302 .72753 L F
.22985 .72744 m .23013 .72817 L .22973 .72881 L 0 0 .268 r
F
.22935 .72516 m .23054 .72563 L .23054 .7256 L .66 .81 .955 r
F
.22935 .72516 m .23347 .72669 L .23237 .72538 L F
.22914 .72526 m .23338 .72676 L .22935 .72516 L F
.22832 .72565 m .22856 .7257 L .22914 .72526 L F
.22856 .7257 m .23338 .72676 L .22914 .72526 L F
.2356 .65522 m .23007 .72455 L .23555 .65525 L .269 .086 .437 r
F
.23494 .65563 m .23525 .65631 L .23544 .65603 L .595 .768 .962 r
F
.23475 .65548 m .23485 .65569 L .23494 .65563 L F
.2345 .65555 m .23555 .65525 L .22936 .72509 L .487 .263 .5 r
F
.23272 .65566 m .22811 .72559 L .23261 .65566 L .636 .39 .528 r
F
.22816 .72846 m .22716 .72897 L .2284 .72862 L .66 .81 .955 r
F
.22811 .72559 m .22792 .7285 L .2281 .72559 L .636 .39 .528 r
F
.22792 .7285 m .22792 .7285 L .2281 .72559 L F
.22704 .72593 m .22573 .72618 L .22708 .726 L .66 .81 .955 r
F
.22984 .6557 m .23039 .65629 L .23141 .65561 L .595 .768 .962 r
F
.23072 .65536 m .22622 .7259 L .22437 .72582 L .751 .492 .54 r
F
.22568 .72587 m .22573 .72618 L .22704 .72593 L .66 .81 .955 r
F
.23225 .6535 m .23036 .65523 L .23141 .65561 L .595 .768 .962 r
F
.22434 .72618 m .22615 .72878 L .22573 .72618 L .66 .81 .955 r
F
.22248 .73438 m .22658 .73141 L .22665 .73437 L .731 .48 .548 r
F
.22248 .73438 m .22242 .73142 L .22658 .73141 L F
.2258 .72915 m .22622 .73176 L .22895 .7314 L .66 .81 .955 r
F
.2258 .72915 m .22895 .7314 L .22716 .72897 L F
.23083 .65538 m .22623 .7259 L .23072 .65536 L .751 .492 .54 r
F
.22708 .72887 m .2258 .72915 L .22716 .72897 L .66 .81 .955 r
F
.22623 .7259 m .22603 .72882 L .22622 .7259 L .751 .492 .54 r
F
.22603 .72882 m .22603 .72882 L .22622 .7259 L F
.22606 .72882 m .2258 .72915 L .22708 .72887 L .66 .81 .955 r
F
.22574 .72881 m .22575 .72888 L .22606 .72882 L F
.22575 .72888 m .2258 .72915 L .22606 .72882 L F
.22606 .72882 m .22783 .72976 L .22596 .72995 L .636 .39 .528 r
F
.22632 .7259 m .22738 .72859 L .22606 .72882 L F
.22738 .72859 m .22783 .72976 L .22606 .72882 L F
.2244 .72915 m .22622 .73176 L .2258 .72915 L .66 .81 .955 r
F
.2253 .72356 m .22434 .72618 L .22573 .72618 L F
.22984 .6557 m .22888 .65657 L .23039 .65629 L .595 .768 .962 r
F
.22888 .65657 m .22907 .65718 L .23039 .65629 L F
.22947 .6549 m .22431 .7258 L .22308 .72549 L .839 .573 .538 r
F
.22436 .72614 m .22302 .726 L .22434 .72618 L .66 .81 .955 r
F
.22955 .65493 m .22431 .7258 L .22947 .6549 L .839 .573 .538 r
F
.22337 .72564 m .22302 .726 L .22436 .72614 L .66 .81 .955 r
F
.22308 .72898 m .22344 .73177 L .2244 .72915 L F
.22452 .72884 m .22308 .72898 L .2244 .72915 L F
.22431 .7258 m .22409 .72874 L .22431 .7258 L .839 .573 .538 r
F
.22409 .72874 m .22409 .72874 L .22431 .7258 L F
.22622 .7259 m .22603 .72882 L .22437 .72582 L .751 .492 .54 r
F
.22603 .72882 m .22596 .72995 L .22552 .7288 L F
.22603 .72882 m .22552 .7288 L .22437 .72582 L F
.22455 .72876 m .22411 .72874 L .22452 .72884 L .66 .81 .955 r
F
.2244 .72915 m .22344 .73177 L .22622 .73176 L F
.22437 .72582 m .22552 .7288 L .22411 .72874 L .751 .492 .54 r
F
.22537 .72653 m .2244 .72915 L .2258 .72915 L .66 .81 .955 r
F
.22411 .72874 m .22596 .72995 L .22402 .72971 L .751 .492 .54 r
F
.22552 .7288 m .22596 .72995 L .22411 .72874 L F
.22411 .72874 m .22308 .72898 L .22452 .72884 L .66 .81 .955 r
F
.22345 .72858 m .22333 .72871 L .22411 .72874 L F
.22333 .72871 m .22308 .72898 L .22411 .72874 L F
.22302 .726 m .22339 .72878 L .22434 .72618 L F
.21851 .73385 m .22242 .73142 L .22248 .73438 L .791 .529 .541 r
F
.22308 .72898 m .22079 .73142 L .22344 .73177 L .66 .81 .955 r
F
.22335 .72868 m .2219 .72864 L .22308 .72898 L F
.22345 .72858 m .22316 .72859 L .22335 .72868 L F
.22316 .72859 m .2219 .72864 L .22335 .72868 L F
.22308 .72549 m .22272 .7254 L .22337 .72564 L F
.22304 .72547 m .22308 .72549 L .22282 .72842 L .913 .647 .523 r
F
.22281 .72841 m .22282 .72842 L .22274 .72926 L F
.22304 .72547 m .22282 .72842 L .22281 .72841 L F
.22282 .72842 m .22402 .72971 L .22274 .72926 L .839 .573 .538 r
F
.22308 .72549 m .22379 .72866 L .22282 .72842 L F
.22379 .72866 m .22402 .72971 L .22282 .72842 L F
.22447 .72584 m .22337 .72564 L .22436 .72614 L .66 .81 .955 r
F
.22342 .72558 m .22337 .72564 L .22447 .72584 L F
.22431 .7258 m .22409 .72874 L .22308 .72549 L .839 .573 .538 r
F
.22409 .72874 m .22402 .72971 L .22379 .72866 L F
.22409 .72874 m .22379 .72866 L .22308 .72549 L F
.22186 .72566 m .21992 .72684 L .22075 .72843 L .66 .81 .955 r
F
.21992 .72684 m .21842 .72775 L .21937 .72803 L F
.21992 .72684 m .21937 .72803 L .22075 .72843 L F
.22801 .65374 m .22214 .725 L .22158 .72445 L .98 .727 .476 r
F
.22162 .72385 m .22157 .72442 L .22162 .72385 L .952 .765 .308 r
F
.22823 .64826 m .2278 .65309 L .22779 .65304 L F
.23292 .64865 m .22801 .64773 L .22821 .64837 L .596 .768 .962 r
F
.23292 .64865 m .22822 .64837 L .2284 .64898 L F
.22822 .64837 m .22821 .64837 L .22822 .64839 L F
.22822 .64837 m .22822 .64839 L .2284 .64898 L F
.22843 .64905 m .22843 .64909 L .22843 .64909 L .98 .727 .476 r
F
.22843 .64905 m .22881 .6495 L .22843 .64909 L F
.23292 .64865 m .2284 .64898 L .2286 .64965 L .596 .768 .962 r
F
.21971 .64483 m .20589 .64585 L .20945 .64948 L .597 .767 .961 r
F
.21889 .64293 m .20589 .64585 L .21971 .64483 L F
.2282 .64777 m .21948 .64426 L .21831 .64592 L .596 .768 .962 r
F
.23292 .64865 m .22864 .64753 L .2285 .64782 L F
.22864 .64753 m .22819 .65224 L .22822 .65219 L 0 0 .188 r
F
.22867 .64726 m .22864 .64753 L .22864 .64753 L F
.22864 .64753 m .22819 .65224 L .22864 .64753 L F
.23292 .64865 m .22897 .64736 L .22864 .64753 L .596 .768 .962 r
F
.2285 .64782 m .22864 .64753 L .2282 .64777 L F
.23023 .64227 m .22867 .64726 L .22985 .6465 L .329 .133 .455 r
F
.22913 .64285 m .22867 .64726 L .23023 .64227 L F
.22897 .64736 m .21948 .64426 L .2282 .64777 L .596 .768 .962 r
F
.23292 .64865 m .22889 .64959 L .22972 .65014 L F
.22889 .64959 m .22901 .64971 L .22972 .65014 L F
.22901 .64971 m .22989 .6503 L .229 .64973 L .913 .647 .523 r
F
.22988 .65024 m .22989 .6503 L .22901 .64971 L F
.22985 .6465 m .22867 .64726 L .22864 .64753 L .329 .133 .455 r
F
.22985 .6465 m .22864 .64753 L .22971 .64696 L F
.22913 .64285 m .22906 .64289 L .22867 .64726 L F
.22897 .64736 m .22158 .64289 L .21948 .64426 L .596 .768 .962 r
F
.23292 .64865 m .22966 .64699 L .22897 .64736 L F
.22966 .64699 m .22158 .64289 L .22897 .64736 L F
.22881 .6495 m .229 .64973 L .22843 .64909 L .98 .727 .476 r
F
.229 .6497 m .229 .64973 L .22881 .6495 L F
.22985 .6465 m .2298 .64692 L .22981 .64691 L .329 .133 .455 r
F
.22966 .64699 m .22445 .64191 L .22158 .64289 L .596 .768 .962 r
F
.23109 .64617 m .22985 .6465 L .22981 .64691 L .55 .315 .512 r
F
.23292 .64865 m .23056 .64677 L .22966 .64699 L .596 .768 .962 r
F
.23056 .64677 m .22981 .64691 L .22966 .64699 L F
.21897 .64967 m .20864 .65432 L .22074 .65149 L F
.22232 .65291 m .21762 .65078 L .21745 .65262 L .595 .768 .962 r
F
.22864 .64753 m .22822 .64839 L .22779 .65304 L 0 0 .188 r
F
.22864 .64753 m .22779 .65304 L .22819 .65224 L F
.23225 .6535 m .22568 .65227 L .22232 .65291 L .595 .768 .962 r
F
.22568 .65227 m .21762 .65078 L .22232 .65291 L F
.23292 .64865 m .22972 .65014 L .22989 .65025 L .596 .768 .962 r
F
.23109 .64617 m .22981 .64691 L .23103 .64668 L .55 .315 .512 r
F
.23146 .64203 m .22985 .6465 L .23109 .64617 L F
.2303 .64226 m .22985 .6465 L .23146 .64203 L F
.2303 .64226 m .23023 .64227 L .22985 .6465 L F
.23006 .64637 m .22791 .64139 L .22445 .64191 L .596 .768 .962 r
F
.23292 .64865 m .23155 .64667 L .23056 .64677 L F
.23236 .64608 m .23104 .64668 L .2323 .64666 L .656 .407 .53 r
F
.23155 .64667 m .2315 .64659 L .23104 .64668 L .596 .768 .962 r
F
.23155 .64667 m .23104 .64668 L .23056 .64677 L F
.23236 .64608 m .23109 .64617 L .23104 .64668 L .656 .407 .53 r
F
.22431 .7258 m .22431 .7258 L .22947 .6549 L .839 .573 .538 r
F
.22955 .65493 m .23072 .65536 L .22437 .72582 L F
.22431 .7258 m .22437 .72582 L .22402 .72971 L F
.22955 .65493 m .22437 .72582 L .22431 .7258 L F
.22864 .65439 m .22947 .6549 L .22308 .72549 L .913 .647 .523 r
F
.22864 .65439 m .22308 .72549 L .22304 .72547 L F
.22858 .65436 m .22304 .72547 L .22217 .72503 L F
.22256 .72523 m .22272 .7254 L .22308 .72549 L .66 .81 .955 r
F
.22245 .7253 m .2228 .72564 L .22337 .72564 L F
.2278 .65309 m .22801 .65374 L .22158 .72445 L .952 .765 .308 r
F
.22193 .72561 m .22092 .72518 L .22186 .72566 L .66 .81 .955 r
F
.22181 .72521 m .22092 .72518 L .22193 .72561 L F
.22181 .72485 m .22092 .72518 L .22237 .72522 L F
.22217 .72503 m .22237 .72522 L .22256 .72523 L F
.22181 .72485 m .22237 .72522 L .22217 .72503 L F
.22804 .65378 m .22214 .72501 L .22801 .65374 L .98 .727 .476 r
F
.2219 .72796 m .22129 .72803 L .22222 .72827 L .66 .81 .955 r
F
.22179 .72785 m .22173 .72787 L .2219 .72796 L F
.22173 .72787 m .22129 .72803 L .2219 .72796 L F
.2219 .72796 m .22274 .72926 L .22184 .7287 L .913 .647 .523 r
F
.22245 .7253 m .22186 .72566 L .2228 .72564 L .66 .81 .955 r
F
.22217 .72503 m .22262 .72831 L .2219 .72796 L .913 .647 .523 r
F
.22252 .72826 m .22201 .72801 L .22243 .72832 L .66 .81 .955 r
F
.22804 .65378 m .22858 .65436 L .22217 .72503 L .98 .727 .476 r
F
.22233 .72837 m .22097 .72815 L .2219 .72864 L .66 .81 .955 r
F
.22226 .7283 m .22097 .72815 L .22233 .72837 L F
.22129 .72803 m .22097 .72815 L .22226 .7283 L F
.22222 .72827 m .22226 .7283 L .22243 .72832 L F
.22129 .72803 m .22226 .7283 L .22222 .72827 L F
.22214 .72501 m .22217 .72503 L .2219 .72796 L .98 .727 .476 r
F
.2219 .72795 m .2219 .72796 L .22184 .7287 L F
.22214 .72501 m .2219 .72796 L .2219 .72795 L F
.22804 .65378 m .22217 .72503 L .22214 .72501 L F
.22245 .7253 m .22181 .72521 L .22193 .72561 L .66 .81 .955 r
F
.22256 .72523 m .22237 .72522 L .22245 .7253 L F
.22237 .72522 m .22181 .72521 L .22245 .7253 L F
.22179 .72785 m .22222 .72827 L .22243 .72832 L F
.22243 .72832 m .22226 .7283 L .22233 .72837 L F
.22243 .72832 m .2219 .72864 L .22316 .72859 L F
.22282 .72842 m .22316 .72859 L .22345 .72858 L F
.22243 .72832 m .22316 .72859 L .22282 .72842 L F
.22256 .72523 m .22245 .7253 L .22272 .7254 L F
.22304 .72547 m .22281 .72841 L .22217 .72503 L .913 .647 .523 r
F
.22281 .72841 m .22274 .72926 L .22262 .72831 L F
.22281 .72841 m .22262 .72831 L .22217 .72503 L F
.22262 .72831 m .22274 .72926 L .2219 .72796 L F
.22092 .72518 m .22047 .72564 L .22186 .72566 L .66 .81 .955 r
F
.22047 .72564 m .21842 .72775 L .21992 .72684 L F
.22047 .72564 m .21992 .72684 L .22186 .72566 L F
.22214 .72501 m .22214 .725 L .22801 .65374 L .98 .727 .476 r
F
.2278 .65309 m .22158 .72445 L .22157 .72442 L .952 .765 .308 r
F
.22162 .72385 m .22162 .72385 L .22779 .65304 L F
.2278 .65309 m .22162 .72385 L .22779 .65304 L F
.22214 .72501 m .22214 .72501 L .22804 .65378 L .98 .727 .476 r
F
.22157 .72442 m .22157 .72442 L .22779 .65304 L .952 .765 .308 r
F
.22779 .65304 m .22157 .72442 L .22135 .72374 L F
.20945 .64948 m .19748 .65229 L .20525 .6571 L .597 .767 .961 r
F
.21897 .64967 m .20505 .65069 L .20864 .65432 L .596 .768 .962 r
F
.21813 .64777 m .20505 .65069 L .21897 .64967 L F
.22139 .65148 m .2188 .64912 L .21762 .65078 L .595 .768 .962 r
F
.23225 .6535 m .22746 .65194 L .22568 .65227 L F
.22864 .65439 m .22304 .72547 L .22858 .65436 L .913 .647 .523 r
F
.22304 .72547 m .22304 .72547 L .22858 .65436 L F
.22281 .72841 m .22281 .72841 L .22304 .72547 L F
.22304 .72547 m .22304 .72547 L .22858 .65436 L F
.22281 .72841 m .22304 .72547 L .22304 .72547 L F
.22819 .65224 m .22779 .65304 L .22135 .72374 L 0 0 .188 r
F
.22181 .72485 m .22091 .72469 L .22092 .72518 L .66 .81 .955 r
F
.2253 .72356 m .22099 .72444 L .22181 .72485 L F
.22099 .72444 m .22029 .72458 L .22181 .72485 L F
.22143 .72777 m .22033 .72755 L .22149 .72796 L F
.2253 .72356 m .22009 .72391 L .22029 .72458 L F
.22009 .72391 m .22 .72392 L .22002 .72396 L F
.22009 .72391 m .22002 .72396 L .22029 .72458 L F
.22272 .72513 m .22196 .72493 L .22256 .72523 L F
.2253 .72356 m .22196 .72493 L .22272 .72513 L F
.2253 .72356 m .22181 .72485 L .22196 .72493 L F
.22214 .72501 m .2219 .72795 L .22214 .725 L .98 .727 .476 r
F
.2219 .72795 m .2219 .72795 L .22214 .725 L F
.2253 .72356 m .22256 .72523 L .22308 .72549 L .66 .81 .955 r
F
.22214 .725 m .22206 .72594 L .22199 .72486 L .98 .727 .476 r
F
.22206 .72594 m .2219 .72795 L .22199 .72486 L F
.22199 .72486 m .2219 .72795 L .22158 .72445 L F
.2219 .72795 m .22178 .72784 L .22158 .72445 L F
.22158 .72445 m .22178 .72784 L .22131 .72738 L F
.22214 .72501 m .22184 .7287 L .22214 .72501 L F
.22819 .65224 m .22135 .72374 L .22137 .72369 L 0 0 .188 r
F
.22819 .65224 m .22137 .72369 L .22822 .65219 L F
.22137 .72369 m .22138 .72369 L .22822 .65219 L F
.22822 .65219 m .22138 .72369 L .2218 .72278 L F
.22009 .72391 m .22006 .72323 L .22 .72392 L .66 .81 .955 r
F
.2253 .72356 m .22103 .72329 L .22009 .72391 L F
.22103 .72329 m .22006 .72323 L .22009 .72391 L F
.23225 .6535 m .22858 .65435 L .22913 .65495 L .595 .768 .962 r
F
.22667 .64827 m .21813 .64777 L .22788 .64901 L .596 .768 .962 r
F
.22746 .65194 m .22089 .64775 L .2188 .64912 L .595 .768 .962 r
F
.2298 .64692 m .22822 .65219 L .22931 .65161 L .329 .133 .455 r
F
.22971 .64696 m .22822 .65219 L .2298 .64692 L F
.22971 .64696 m .22864 .64753 L .22822 .65219 L F
.23225 .6535 m .2287 .6517 L .22746 .65194 L .595 .768 .962 r
F
.2287 .6517 m .22089 .64775 L .22746 .65194 L F
.22989 .65025 m .23113 .65076 L .22989 .6503 L .839 .573 .538 r
F
.23112 .6507 m .23113 .65076 L .22989 .65025 L F
.23292 .64865 m .22989 .65025 L .2308 .65058 L .596 .768 .962 r
F
.23103 .64668 m .23054 .65136 L .23104 .64668 L .55 .315 .512 r
F
.22801 .64773 m .21831 .64592 L .22821 .64837 L .596 .768 .962 r
F
.22662 .65065 m .22377 .64678 L .22089 .64775 L .595 .768 .962 r
F
.23103 .64668 m .22981 .64691 L .22939 .65157 L .55 .315 .512 r
F
.22989 .65025 m .22989 .6503 L .22988 .65024 L .913 .647 .523 r
F
.23103 .64668 m .22939 .65157 L .23054 .65136 L .55 .315 .512 r
F
.22981 .64691 m .22931 .65161 L .22939 .65157 L .329 .133 .455 r
F
.2298 .64692 m .22931 .65161 L .22981 .64691 L F
.23225 .6535 m .22955 .65136 L .22806 .65138 L .595 .768 .962 r
F
.2253 .72356 m .22308 .72549 L .22342 .72558 L .66 .81 .955 r
F
.2253 .72356 m .22342 .72558 L .22447 .72584 L F
.22623 .7259 m .22622 .7259 L .23072 .65536 L .751 .492 .54 r
F
.22811 .72559 m .2281 .72559 L .23261 .65566 L .636 .39 .528 r
F
.23141 .65561 m .23104 .65586 L .23126 .65599 L .595 .768 .962 r
F
.23225 .6535 m .23137 .65573 L .23261 .65566 L F
.23083 .65538 m .23261 .65566 L .22596 .72995 L .751 .492 .54 r
F
.22821 .72557 m .22704 .72593 L .22832 .72565 L .66 .81 .955 r
F
.23273 .65566 m .22821 .72557 L .22811 .72559 L .636 .39 .528 r
F
.22694 .72579 m .22704 .72593 L .22821 .72557 L .66 .81 .955 r
F
.22704 .72593 m .22727 .72594 L .22832 .72565 L F
.22795 .72849 m .22716 .72897 L .22816 .72846 L F
.22694 .72867 m .22708 .72886 L .22795 .72849 L F
.22708 .72886 m .22716 .72897 L .22795 .72849 L F
.22795 .72849 m .22899 .72935 L .22783 .72976 L .487 .263 .5 r
F
.22821 .72557 m .22874 .72816 L .22795 .72849 L F
.22874 .72816 m .22899 .72935 L .22795 .72849 L F
.23272 .65566 m .23273 .65566 L .22792 .7285 L .636 .39 .528 r
F
.22792 .7285 m .22792 .7285 L .22783 .72976 L F
.23272 .65566 m .22792 .7285 L .22792 .7285 L F
.22811 .72559 m .22821 .72557 L .22783 .72976 L F
.22704 .72593 m .22708 .726 L .22727 .72594 L .66 .81 .955 r
F
.2281 .72559 m .22792 .7285 L .22632 .7259 L .636 .39 .528 r
F
.22792 .7285 m .22738 .72859 L .22632 .7259 L F
.23273 .65566 m .23443 .65557 L .22821 .72557 L F
.2253 .72356 m .22821 .72557 L .22821 .72557 L .66 .81 .955 r
F
.22927 .72513 m .22821 .72557 L .22935 .72516 L F
.2253 .72356 m .22821 .72557 L .22927 .72513 L F
.2345 .65555 m .2293 .72512 L .23443 .65557 L .487 .263 .5 r
F
.22911 .72801 m .22816 .72846 L .22944 .72813 L .66 .81 .955 r
F
.22816 .72846 m .22911 .72829 L .22944 .72813 L F
.2293 .72512 m .2293 .72512 L .23443 .65557 L .487 .263 .5 r
F
.2345 .65555 m .22936 .72509 L .2293 .72512 L F
.23555 .65525 m .23007 .72455 L .22936 .72509 L .269 .086 .437 r
F
.2253 .72356 m .22935 .72516 L .2301 .72457 L .66 .81 .955 r
F
.2293 .72512 m .22909 .72802 L .2293 .72512 L .487 .263 .5 r
F
.22909 .72802 m .22908 .72802 L .2293 .72512 L F
.2293 .72512 m .22936 .72509 L .22911 .72801 L F
.2293 .72512 m .22911 .72801 L .22909 .72802 L F
.22935 .72516 m .23237 .72538 L .23038 .72467 L .66 .81 .955 r
F
.23007 .72455 m .22984 .72745 L .23007 .72455 L .269 .086 .437 r
F
.22984 .72745 m .22973 .72881 L .22984 .72745 L F
.22984 .72745 m .22984 .72745 L .23007 .72455 L F
.22983 .72746 m .22911 .72801 L .2302 .72753 L .66 .81 .955 r
F
.22936 .72509 m .22962 .72762 L .22911 .72801 L .269 .086 .437 r
F
.22911 .72801 m .22911 .72801 L .22983 .72746 L .66 .81 .955 r
F
.22911 .72801 m .22944 .72813 L .23014 .72758 L F
.22911 .72801 m .23014 .72758 L .2302 .72753 L F
.22953 .72502 m .23038 .72467 L .2301 .72457 L F
.22935 .72516 m .23038 .72467 L .22953 .72502 L F
.23007 .72455 m .22984 .72745 L .22936 .72509 L .269 .086 .437 r
F
.22984 .72745 m .22973 .72881 L .22962 .72762 L F
.22984 .72745 m .22962 .72762 L .22936 .72509 L F
.23062 .72687 m .2302 .72753 L .23063 .72687 L .66 .81 .955 r
F
.23011 .72452 m .23012 .72701 L .22985 .72744 L 0 0 .268 r
F
.23237 .72538 m .23202 .72497 L .2301 .72457 L .66 .81 .955 r
F
.23161 .72448 m .23489 .72557 L .23576 .72424 L F
.2301 .72457 m .23202 .72497 L .23161 .72448 L F
.23202 .72497 m .23489 .72557 L .23161 .72448 L F
.2301 .72457 m .23576 .72424 L .23053 .7239 L F
.23049 .72391 m .23024 .72681 L .23011 .72452 L 0 0 .268 r
F
.23024 .72681 m .23012 .72701 L .23011 .72452 L F
.23006 .72711 m .22985 .72744 L .23026 .72714 L .66 .81 .955 r
F
.23023 .72684 m .23026 .72714 L .23025 .72684 L F
.23007 .72455 m .23011 .72452 L .22985 .72744 L .269 .086 .437 r
F
.22984 .72745 m .22985 .72744 L .22973 .72881 L F
.23007 .72455 m .22985 .72744 L .22984 .72745 L F
.23049 .72391 m .23024 .72681 L .23049 .72391 L 0 0 .268 r
F
.23024 .72681 m .23024 .72681 L .23049 .72391 L F
.23025 .72656 m .23062 .72687 L .23065 .72656 L .66 .81 .955 r
F
.22824 .72757 m .22886 .72842 L .22878 .72669 L F
.22811 .72842 m .22816 .72846 L .22911 .72801 L F
.22816 .72846 m .2284 .72862 L .22911 .72829 L F
.22821 .72557 m .22832 .72565 L .22864 .7255 L F
.22821 .72557 m .22864 .7255 L .22935 .72516 L F
.22832 .72565 m .22848 .72576 L .22856 .7257 L F
.2293 .72512 m .22899 .72935 L .22821 .72557 L .487 .263 .5 r
F
.22537 .72653 m .23025 .72684 L .23025 .72656 L .66 .81 .955 r
F
.23025 .72684 m .23062 .72687 L .23025 .72656 L F
.23007 .72455 m .23007 .72455 L .23555 .65525 L .269 .086 .437 r
F
.2356 .65522 m .23011 .72452 L .23007 .72455 L F
.23137 .71337 m .23051 .72388 L .23049 .72391 L 0 0 .268 r
F
.2253 .72356 m .2301 .72457 L .23053 .7239 L .66 .81 .955 r
F
.23137 .71337 m .23666 .65424 L .23051 .72388 L 0 0 .268 r
F
.23666 .65424 m .2305 .72319 L .23051 .72388 L .796 .683 .137 r
F
.2253 .72356 m .23053 .7239 L .2306 .72327 L .66 .81 .955 r
F
.23055 .72321 m .2306 .72327 L .23061 .72321 L F
.2253 .72356 m .2306 .72327 L .23055 .72321 L F
.23656 .65438 m .23666 .65424 L .23575 .66249 L 0 0 .268 r
F
.23656 .65438 m .23575 .66249 L .23532 .66649 L F
.2365 .65447 m .23656 .65438 L .23532 .66649 L F
.25586 .65516 m .26687 .66077 L .2732 .65679 L .597 .767 .961 r
F
.25016 .65705 m .26687 .66077 L .25586 .65516 L F
.25586 .65516 m .2732 .65679 L .26006 .65249 L F
.24628 .65301 m .25957 .65735 L .26201 .65407 L .596 .768 .962 r
F
.24417 .65436 m .25957 .65735 L .24628 .65301 L F
.24628 .65301 m .26201 .65407 L .24748 .65136 L F
.23861 .65303 m .24705 .65438 L .24626 .65248 L .595 .768 .962 r
F
.23705 .64889 m .23592 .65263 L .2366 .65349 L .991 .745 .452 r
F
.23705 .64889 m .2366 .65349 L .23706 .6489 L F
.2366 .65349 m .2366 .6535 L .23706 .6489 L F
.23706 .6489 m .2366 .6535 L .23664 .65355 L F
.23707 .64958 m .23706 .6489 L .23664 .65355 L .796 .683 .137 r
F
.23225 .6535 m .23815 .65385 L .23689 .65316 L .595 .768 .962 r
F
.23024 .72621 m .23065 .72656 L .23035 .7262 L .66 .81 .955 r
F
.22537 .72653 m .23025 .72656 L .23024 .72621 L F
.23025 .72656 m .23065 .72656 L .23024 .72621 L F
.22985 .72744 m .2302 .72753 L .23062 .72687 L F
.22983 .72746 m .22984 .72746 L .22985 .72744 L F
.22984 .72746 m .2302 .72753 L .22985 .72744 L F
.23049 .72391 m .23051 .72388 L .23025 .7268 L 0 0 .268 r
F
.23024 .72681 m .23025 .7268 L .23013 .72817 L F
.23049 .72391 m .23025 .7268 L .23024 .72681 L F
.23024 .72681 m .23013 .72817 L .23024 .72681 L F
.23006 .72711 m .23026 .72714 L .23023 .72684 L .66 .81 .955 r
F
.23024 .72681 m .23013 .72817 L .23012 .72701 L 0 0 .268 r
F
.23025 .7268 m .23012 .7274 L .23013 .72817 L .796 .683 .137 r
F
.23051 .72388 m .23024 .7263 L .23025 .7268 L F
.23024 .7263 m .23012 .7274 L .23025 .7268 L F
.2253 .72356 m .22694 .72579 L .22821 .72557 L .66 .81 .955 r
F
.23634 .64797 m .23584 .65259 L .23592 .65263 L .896 .63 .527 r
F
.23633 .64797 m .23453 .65187 L .23583 .65258 L F
.23639 .64738 m .23618 .64789 L .23633 .64797 L F
.23618 .64789 m .23453 .65187 L .23633 .64797 L F
.23639 .64738 m .235 .64658 L .23494 .64721 L F
.23639 .64738 m .23494 .64721 L .23618 .64789 L F
.23542 .64747 m .24515 .64578 L .24256 .64414 L .596 .768 .962 r
F
.23292 .64865 m .23617 .64788 L .23542 .64747 L F
.23639 .64738 m .23633 .64797 L .23634 .64797 L .896 .63 .527 r
F
.23617 .64788 m .24515 .64578 L .23542 .64747 L .596 .768 .962 r
F
.23633 .64797 m .23583 .65258 L .23634 .64797 L .896 .63 .527 r
F
.23583 .65258 m .23584 .65259 L .23634 .64797 L F
.23705 .64889 m .23634 .64797 L .23592 .65263 L .991 .745 .452 r
F
.23717 .64944 m .24748 .65136 L .23752 .64892 L .596 .768 .962 r
F
.23509 .65218 m .2445 .65064 L .24191 .649 L .595 .768 .962 r
F
.23225 .6535 m .23594 .65264 L .23509 .65218 L F
.23594 .65264 m .2445 .65064 L .23509 .65218 L F
.23664 .65247 m .24626 .65248 L .2445 .65064 L F
.23225 .6535 m .23861 .65303 L .23664 .65247 L F
.23861 .65303 m .24626 .65248 L .23664 .65247 L F
.23225 .6535 m .23381 .65575 L .23475 .65548 L F
.23292 .64865 m .23559 .6474 L .23459 .64711 L .596 .768 .962 r
F
.23494 .64721 m .23444 .65184 L .23453 .65187 L .807 .543 .539 r
F
.235 .64658 m .23493 .64721 L .23494 .64721 L F
.23493 .64721 m .23444 .65184 L .23494 .64721 L F
.23459 .64711 m .24256 .64414 L .2393 .64279 L .596 .768 .962 r
F
.23559 .6474 m .24256 .64414 L .23459 .64711 L F
.23493 .64721 m .23319 .65149 L .23444 .65184 L .807 .543 .539 r
F
.23618 .64789 m .23494 .64721 L .23453 .65187 L .896 .63 .527 r
F
.23617 .64788 m .24691 .64762 L .24515 .64578 L .596 .768 .962 r
F
.23701 .64835 m .24691 .64762 L .23617 .64788 L F
.23705 .64889 m .23731 .64923 L .23752 .64892 L F
.23707 .64942 m .23707 .64959 L .23717 .64944 L F
.2343 .65163 m .24191 .649 L .23864 .64766 L .595 .768 .962 r
F
.23225 .6535 m .23583 .65183 L .2343 .65163 L F
.23583 .65183 m .24191 .649 L .2343 .65163 L F
.2253 .72356 m .22568 .72587 L .22704 .72593 L .66 .81 .955 r
F
.23225 .6535 m .23261 .65566 L .23371 .65561 L .595 .768 .962 r
F
.23361 .64683 m .2331 .65148 L .23319 .65149 L .734 .476 .538 r
F
.23366 .64621 m .2336 .64683 L .23361 .64683 L F
.2336 .64683 m .2331 .65148 L .23361 .64683 L F
.23366 .64621 m .23236 .64608 L .23231 .64666 L F
.23259 .6467 m .2356 .64185 L .23172 .64137 L .596 .768 .962 r
F
.23292 .64865 m .23363 .64683 L .23259 .6467 L F
.23366 .64621 m .23231 .64666 L .2336 .64683 L .734 .476 .538 r
F
.23363 .64683 m .2356 .64185 L .23259 .6467 L .596 .768 .962 r
F
.23493 .64721 m .23361 .64683 L .23319 .65149 L .807 .543 .539 r
F
.23114 .65071 m .23303 .65101 L .23113 .65076 L .751 .492 .54 r
F
.23303 .65101 m .23303 .65101 L .23114 .65071 L F
.2336 .64683 m .23189 .65132 L .2331 .65148 L .734 .476 .538 r
F
.235 .64658 m .23361 .64683 L .23493 .64721 L .807 .543 .539 r
F
.23465 .64705 m .2393 .64279 L .23374 .64655 L .596 .768 .962 r
F
.23225 .6535 m .23864 .64766 L .23494 .64672 L .595 .768 .962 r
F
.23666 .6542 m .2305 .72315 L .2305 .72319 L .796 .683 .137 r
F
.23663 .65449 m .23666 .65424 L .23137 .71337 L 0 0 .268 r
F
.23666 .6542 m .2305 .72319 L .23666 .65424 L .796 .683 .137 r
F
.2305 .72319 m .2305 .72319 L .23666 .65424 L F
.23666 .6542 m .2305 .72319 L .23666 .6542 L F
.2305 .72319 m .2305 .72319 L .23666 .6542 L F
.2253 .72356 m .23061 .72321 L .23032 .72254 L .66 .81 .955 r
F
.23319 .65149 m .22566 .72139 L .22694 .7214 L .734 .476 .538 r
F
.2253 .72356 m .2261 .72139 L .22495 .72138 L .66 .81 .955 r
F
.2331 .65148 m .22566 .72139 L .23319 .65149 L .734 .476 .538 r
F
.2253 .72356 m .22727 .72146 L .2261 .72139 L .66 .81 .955 r
F
.23453 .65187 m .22701 .72141 L .22832 .72163 L .807 .543 .539 r
F
.22727 .72146 m .22694 .7214 L .2261 .72139 L .66 .81 .955 r
F
.23444 .65184 m .227 .72141 L .23453 .65187 L .807 .543 .539 r
F
.23583 .65258 m .22839 .72167 L .23584 .65259 L .896 .63 .527 r
F
.22839 .72167 m .22839 .72167 L .23584 .65259 L F
.2253 .72356 m .22841 .72167 L .22832 .72163 L .66 .81 .955 r
F
.22727 .72146 m .22832 .72163 L .22746 .72126 L F
.2253 .72356 m .22832 .72163 L .22727 .72146 L F
.23444 .65184 m .23319 .65149 L .22694 .7214 L .807 .543 .539 r
F
.23592 .65263 m .22839 .72167 L .22976 .72226 L .896 .63 .527 r
F
.2253 .72356 m .23032 .72254 L .23025 .72248 L .66 .81 .955 r
F
.2366 .6535 m .22979 .72231 L .23664 .65355 L .991 .745 .452 r
F
.22979 .72231 m .2298 .72231 L .23664 .65355 L F
.23664 .65355 m .2298 .72231 L .2305 .72315 L F
.2363 .65477 m .2365 .65448 L .23534 .66622 L 0 0 .268 r
F
.2365 .65448 m .2365 .65447 L .23534 .66622 L F
.23534 .66622 m .2365 .65447 L .23532 .66649 L F
.2366 .65349 m .22979 .72231 L .2366 .6535 L .991 .745 .452 r
F
.22979 .72231 m .22979 .72231 L .2366 .6535 L F
.2366 .65349 m .23592 .65263 L .22976 .72226 L F
.2366 .65349 m .22976 .72226 L .22979 .72231 L F
.22933 .72208 m .23025 .72248 L .22969 .72195 L .66 .81 .955 r
F
.2253 .72356 m .23025 .72248 L .22933 .72208 L F
.23584 .65259 m .22839 .72167 L .23592 .65263 L .896 .63 .527 r
F
.2253 .72356 m .22933 .72208 L .22841 .72167 L .66 .81 .955 r
F
.2305 .72319 m .23024 .72608 L .23051 .72388 L .796 .683 .137 r
F
.23024 .72608 m .23012 .7274 L .23024 .7263 L F
.23024 .72608 m .23024 .7263 L .23051 .72388 L F
.23023 .72565 m .2307 .72617 L .23046 .72561 L .66 .81 .955 r
F
.2305 .72315 m .22972 .72545 L .23024 .72607 L .991 .745 .452 r
F
.22993 .7257 m .23024 .72589 L .23023 .72565 L .66 .81 .955 r
F
.23024 .72589 m .2307 .72617 L .23023 .72565 L F
.2305 .72319 m .23024 .72608 L .2305 .72319 L .796 .683 .137 r
F
.23024 .72608 m .23012 .7274 L .23024 .72608 L F
.23024 .72608 m .23024 .72608 L .2305 .72319 L F
.22537 .72653 m .23024 .72621 L .22993 .7257 L .66 .81 .955 r
F
.23024 .72621 m .23035 .7262 L .23024 .72607 L F
.23024 .72621 m .23024 .72607 L .22993 .7257 L F
.23035 .7262 m .2307 .72617 L .22993 .7257 L F
.22979 .72231 m .22951 .7252 L .2298 .72231 L .991 .745 .452 r
F
.2305 .72319 m .23024 .72608 L .2305 .72319 L .796 .683 .137 r
F
.23024 .72608 m .23024 .72608 L .2305 .72319 L F
.22986 .72562 m .23046 .72561 L .23028 .72553 L .66 .81 .955 r
F
.22537 .72653 m .22993 .7257 L .22986 .72562 L F
.22993 .7257 m .23046 .72561 L .22986 .72562 L F
.2298 .72231 m .22951 .7252 L .2305 .72315 L .991 .745 .452 r
F
.22951 .7252 m .22972 .72545 L .2305 .72315 L F
.22951 .7252 m .22951 .7252 L .2298 .72231 L F
.22976 .72226 m .22844 .72473 L .2295 .72519 L .896 .63 .527 r
F
.22979 .72231 m .22951 .7252 L .22979 .72231 L .991 .745 .452 r
F
.22537 .72653 m .22986 .72562 L .22928 .72509 L .66 .81 .955 r
F
.22986 .72562 m .23028 .72553 L .2295 .72519 L F
.22986 .72562 m .2295 .72519 L .22928 .72509 L F
.22979 .72231 m .22976 .72226 L .2295 .72519 L .991 .745 .452 r
F
.22951 .7252 m .2295 .72519 L .22939 .72641 L F
.22979 .72231 m .2295 .72519 L .22951 .7252 L F
.22951 .7252 m .22939 .72641 L .22951 .7252 L F
.22951 .7252 m .22951 .7252 L .22979 .72231 L F
.22938 .72505 m .23041 .72551 L .22978 .72491 L .66 .81 .955 r
F
.22928 .72509 m .22948 .72517 L .22938 .72505 L F
.22948 .72517 m .23041 .72551 L .22938 .72505 L F
.23028 .72553 m .23041 .72551 L .22928 .72509 L F
.22839 .72167 m .22808 .72457 L .22976 .72226 L .896 .63 .527 r
F
.22838 .7247 m .22978 .72491 L .22884 .72442 L .66 .81 .955 r
F
.22537 .72653 m .22928 .72509 L .22838 .7247 L F
.22928 .72509 m .22978 .72491 L .22838 .7247 L F
.22839 .72167 m .22807 .72457 L .22839 .72167 L .896 .63 .527 r
F
.22807 .72457 m .22796 .72563 L .22807 .72457 L F
.22807 .72457 m .22807 .72457 L .22839 .72167 L F
.22808 .72457 m .22796 .72563 L .22844 .72473 L F
.22808 .72457 m .22844 .72473 L .22976 .72226 L F
.22951 .7252 m .22939 .72641 L .22972 .72545 L .991 .745 .452 r
F
.22951 .7252 m .22939 .72641 L .22951 .7252 L F
.2295 .72519 m .22796 .72563 L .22939 .72641 L .896 .63 .527 r
F
.22844 .72473 m .22796 .72563 L .2295 .72519 L F
.23028 .72553 m .23046 .72561 L .23041 .72551 L .66 .81 .955 r
F
.22537 .72653 m .22838 .7247 L .22806 .72456 L F
.22537 .72653 m .22806 .72456 L .22733 .72444 L F
.22806 .72456 m .22659 .72528 L .22796 .72563 L .807 .543 .539 r
F
.22832 .72163 m .22701 .72438 L .22806 .72456 L F
.22701 .72438 m .22659 .72528 L .22806 .72456 L F
.22733 .72444 m .22806 .72456 L .22746 .7243 L .66 .81 .955 r
F
.23583 .65258 m .23453 .65187 L .22796 .72563 L .896 .63 .527 r
F
.22746 .7243 m .22884 .72442 L .22767 .72407 L .66 .81 .955 r
F
.22838 .7247 m .22884 .72442 L .22746 .7243 L F
.22839 .72167 m .22807 .72457 L .22839 .72167 L .896 .63 .527 r
F
.22807 .72457 m .22796 .72563 L .22808 .72457 L F
.22807 .72457 m .22808 .72457 L .22839 .72167 L F
.22839 .72167 m .22839 .72167 L .23592 .65263 L F
.22841 .72167 m .22969 .72195 L .22875 .72146 L .66 .81 .955 r
F
.22933 .72208 m .22969 .72195 L .22841 .72167 L F
.227 .72141 m .22694 .7214 L .22668 .72433 L .807 .543 .539 r
F
.227 .72141 m .22668 .72433 L .22669 .72433 L F
.22537 .72653 m .22733 .72444 L .22668 .72433 L .66 .81 .955 r
F
.22694 .7214 m .22563 .72432 L .22668 .72433 L .734 .476 .538 r
F
.22618 .72432 m .22668 .72433 L .22621 .72425 L .66 .81 .955 r
F
.22537 .72653 m .22668 .72433 L .22618 .72432 L F
.22566 .72139 m .22535 .72432 L .22566 .72139 L .734 .476 .538 r
F
.22535 .72432 m .22535 .72432 L .22566 .72139 L F
.22537 .72653 m .22618 .72432 L .22533 .72432 L .66 .81 .955 r
F
.22931 .65161 m .22822 .65219 L .2218 .72278 L .329 .133 .455 r
F
.2253 .72356 m .22174 .72282 L .22103 .72329 L .66 .81 .955 r
F
.22931 .65161 m .2218 .72278 L .22185 .72274 L .329 .133 .455 r
F
.22931 .65161 m .22185 .72274 L .22939 .65157 L F
.22185 .72274 m .22186 .72274 L .22939 .65157 L F
.22939 .65157 m .22186 .72274 L .22301 .72198 L F
.2253 .72356 m .22205 .72228 L .2209 .72264 L .66 .81 .955 r
F
.22205 .72228 m .22227 .72147 L .22124 .72196 L F
.2253 .72356 m .22301 .72198 L .22205 .72228 L F
.22301 .72198 m .22227 .72147 L .22205 .72228 L F
.23054 .65136 m .23055 .65135 L .23104 .64668 L .55 .315 .512 r
F
.23104 .64668 m .23055 .65135 L .23062 .65134 L F
.23292 .64865 m .2308 .65058 L .23114 .65071 L .596 .768 .962 r
F
.23155 .64667 m .23172 .64137 L .22791 .64139 L F
.23292 .64865 m .23259 .64666 L .23155 .64667 L F
.23236 .64608 m .2323 .64666 L .23231 .64666 L .656 .407 .53 r
F
.23259 .64666 m .23172 .64137 L .23155 .64667 L .596 .768 .962 r
F
.23292 .64865 m .23114 .65071 L .23204 .65085 L F
.23231 .64666 m .2318 .65132 L .23189 .65132 L .656 .407 .53 r
F
.2323 .64666 m .2318 .65132 L .23231 .64666 L F
.2323 .64666 m .23104 .64668 L .23062 .65134 L F
.23114 .65071 m .23113 .65076 L .23112 .6507 L .839 .573 .538 r
F
.2323 .64666 m .23062 .65134 L .2318 .65132 L .656 .407 .53 r
F
.2279 .64901 m .22667 .64827 L .22788 .64901 L .596 .768 .962 r
F
.228 .64882 m .22667 .64827 L .2279 .64901 L F
.23225 .6535 m .22724 .64626 L .22377 .64678 L .595 .768 .962 r
F
.23055 .65135 m .22307 .72196 L .23062 .65134 L .55 .315 .512 r
F
.22307 .72196 m .22307 .72196 L .23062 .65134 L F
.23062 .65134 m .22307 .72196 L .22428 .72157 L F
.23054 .65136 m .22307 .72196 L .23055 .65135 L F
.22307 .72196 m .22307 .72196 L .23055 .65135 L F
.23054 .65136 m .22939 .65157 L .22301 .72198 L F
.22068 .72555 m .22129 .72492 L .22053 .72552 L .66 .81 .955 r
F
.22185 .72274 m .2218 .72278 L .22153 .7257 L .329 .133 .455 r
F
.22073 .72623 m .22053 .72552 L .2201 .72619 L .66 .81 .955 r
F
.22135 .72374 m .22127 .72724 L .22109 .72666 L .952 .765 .308 r
F
.22137 .72369 m .22135 .72374 L .22109 .72666 L 0 0 .188 r
F
.22071 .72747 m .22003 .72688 L .22033 .72755 L .66 .81 .955 r
F
.22157 .72442 m .22158 .72445 L .22131 .72738 L .952 .765 .308 r
F
.22157 .72442 m .22131 .72738 L .22131 .72737 L F
.22304 .72547 m .22281 .72841 L .22304 .72547 L .913 .647 .523 r
F
.22157 .72442 m .22131 .72737 L .22157 .72442 L .952 .765 .308 r
F
.22129 .72736 m .22033 .72755 L .22143 .72777 L .66 .81 .955 r
F
.22131 .72737 m .22125 .72804 L .22131 .72737 L .952 .765 .308 r
F
.22131 .72737 m .22131 .72737 L .22157 .72442 L F
.2213 .72735 m .22101 .72682 L .22071 .72747 L .66 .81 .955 r
F
.22157 .72442 m .22125 .72804 L .22135 .72374 L .952 .765 .308 r
F
.22537 .72653 m .22113 .72681 L .2213 .72735 L .66 .81 .955 r
F
.22113 .72681 m .22101 .72682 L .2213 .72735 L F
.22101 .72682 m .22003 .72688 L .22071 .72747 L F
.22137 .72369 m .22109 .72666 L .22109 .72665 L 0 0 .188 r
F
.22137 .72369 m .22109 .72665 L .22138 .72369 L F
.22109 .72666 m .22109 .72667 L .22103 .72727 L .952 .765 .308 r
F
.22109 .72667 m .22125 .72804 L .22103 .72727 L F
.22109 .72665 m .22103 .72727 L .22109 .72665 L 0 0 .188 r
F
.22109 .72665 m .22109 .72665 L .22138 .72369 L F
.22101 .72682 m .22073 .72623 L .22003 .72688 L .66 .81 .955 r
F
.22537 .72653 m .22127 .72627 L .22101 .72682 L F
.22127 .72627 m .22073 .72623 L .22101 .72682 L F
.22073 .72623 m .2201 .72619 L .22005 .72668 L F
.22073 .72623 m .22005 .72668 L .22003 .72688 L F
.22537 .72653 m .22152 .72573 L .22133 .72615 L F
.22127 .72627 m .22092 .72611 L .22096 .72625 L F
.22537 .72653 m .22133 .72615 L .22127 .72627 L F
.22138 .72369 m .22109 .72665 L .2218 .72278 L 0 0 .188 r
F
.22109 .72665 m .22103 .72727 L .22117 .7265 L F
.22109 .72665 m .22117 .7265 L .2218 .72278 L F
.22301 .72198 m .22174 .72557 L .22274 .7249 L .329 .133 .455 r
F
.22307 .72196 m .22301 .72198 L .22274 .7249 L .55 .315 .512 r
F
.22307 .72196 m .22274 .7249 L .22275 .7249 L F
.22307 .72196 m .22275 .7249 L .22307 .72196 L F
.22537 .72653 m .22218 .72527 L .2215 .72572 L .66 .81 .955 r
F
.22186 .72274 m .22148 .7263 L .22301 .72198 L .329 .133 .455 r
F
.22191 .72517 m .22207 .72455 L .2218 .72512 L .66 .81 .955 r
F
.22342 .72558 m .22308 .72549 L .22337 .72564 L F
.22537 .72653 m .22268 .72492 L .22191 .72517 L F
.22268 .72492 m .22207 .72455 L .22191 .72517 L F
.22537 .72653 m .22293 .72484 L .22268 .72492 L F
.2253 .72356 m .22393 .72168 L .22301 .72198 L F
.23109 .64617 m .23103 .64668 L .23104 .64668 L .55 .315 .512 r
F
.23056 .64677 m .23147 .64655 L .23006 .64637 L .596 .768 .962 r
F
.2315 .64659 m .23147 .64655 L .23056 .64677 L F
.23147 .64655 m .22791 .64139 L .23006 .64637 L F
.23056 .64677 m .23037 .64662 L .22981 .64691 L F
.22985 .6465 m .22971 .64696 L .2298 .64692 L .329 .133 .455 r
F
.23037 .64662 m .22445 .64191 L .22966 .64699 L .596 .768 .962 r
F
.23225 .6535 m .23105 .64624 L .22724 .64626 L .595 .768 .962 r
F
.2318 .65132 m .23062 .65134 L .22428 .72157 L .656 .407 .53 r
F
.2318 .65132 m .22428 .72157 L .22434 .72156 L F
.2318 .65132 m .22434 .72156 L .23189 .65132 L F
.22434 .72156 m .22435 .72156 L .23189 .65132 L F
.23189 .65132 m .22435 .72156 L .2256 .72139 L F
.2253 .72356 m .22487 .72094 L .22351 .72112 L .66 .81 .955 r
F
.22428 .72157 m .22298 .72483 L .22402 .7245 L .55 .315 .512 r
F
.22275 .7249 m .22275 .7249 L .22307 .72196 L F
.22307 .72196 m .22275 .7249 L .22428 .72157 L F
.22275 .7249 m .22268 .72556 L .22298 .72483 L F
.22275 .7249 m .22298 .72483 L .22428 .72157 L F
.22293 .72484 m .22389 .72452 L .22269 .72468 L .66 .81 .955 r
F
.22537 .72653 m .2239 .72453 L .22293 .72484 L F
.2239 .72453 m .22389 .72452 L .22293 .72484 L F
.22307 .72196 m .22268 .72556 L .22307 .72196 L .55 .315 .512 r
F
.22269 .72468 m .22357 .72408 L .22232 .72443 L .66 .81 .955 r
F
.22389 .72452 m .22357 .72408 L .22269 .72468 L F
.22434 .72156 m .22428 .72157 L .22402 .7245 L .656 .407 .53 r
F
.22403 .7245 m .22402 .7245 L .22395 .72524 L F
.22434 .72156 m .22402 .7245 L .22403 .7245 L F
.22434 .72156 m .22403 .7245 L .22435 .72156 L F
.22403 .7245 m .22403 .7245 L .22435 .72156 L F
.2256 .72139 m .22429 .72446 L .22533 .72432 L F
.22439 .72422 m .22494 .7239 L .2245 .72396 L .66 .81 .955 r
F
.22537 .72653 m .22501 .72436 L .22389 .72452 L F
.22435 .72156 m .22395 .72524 L .2256 .72139 L .656 .407 .53 r
F
.22439 .72422 m .2245 .72396 L .22357 .72408 L .66 .81 .955 r
F
.22389 .72452 m .22439 .72422 L .22357 .72408 L F
.22501 .72436 m .22494 .7239 L .22389 .72452 L F
.22403 .7245 m .22395 .72524 L .22403 .7245 L .656 .407 .53 r
F
.22402 .7245 m .22268 .72556 L .22395 .72524 L .55 .315 .512 r
F
.22298 .72483 m .22268 .72556 L .22402 .7245 L F
.22275 .7249 m .22268 .72556 L .22275 .7249 L F
.22268 .72492 m .22232 .72443 L .22207 .72455 L .66 .81 .955 r
F
.22293 .72484 m .22232 .72443 L .22268 .72492 L F
.2218 .72278 m .22117 .7265 L .22153 .7257 L 0 0 .188 r
F
.2218 .72512 m .22207 .72455 L .22129 .72492 L .66 .81 .955 r
F
.22133 .72615 m .22092 .72611 L .22127 .72627 L F
.22153 .7257 m .22103 .72727 L .22148 .7263 L 0 0 .188 r
F
.22117 .7265 m .22103 .72727 L .22153 .7257 L F
.22274 .7249 m .22148 .7263 L .22268 .72556 L .329 .133 .455 r
F
.22174 .72557 m .22148 .7263 L .22274 .7249 L F
.22109 .72665 m .22109 .72666 L .22103 .72727 L 0 0 .188 r
F
.22133 .72615 m .2215 .72572 L .22092 .72611 L .66 .81 .955 r
F
.22152 .72573 m .2215 .72572 L .22133 .72615 L F
.22096 .72625 m .22092 .72611 L .22073 .72623 L F
.2215 .72572 m .22053 .72552 L .22073 .72623 L F
.22185 .72274 m .22154 .7257 L .22186 .72274 L .329 .133 .455 r
F
.22154 .7257 m .22148 .7263 L .22154 .7257 L F
.22154 .7257 m .22154 .7257 L .22186 .72274 L F
.22154 .7257 m .22153 .7257 L .22148 .7263 L F
.22185 .72274 m .22153 .7257 L .22154 .7257 L F
.2215 .72572 m .22191 .72517 L .22068 .72555 L .66 .81 .955 r
F
.22218 .72527 m .22191 .72517 L .2215 .72572 L F
.22191 .72517 m .22129 .72492 L .22068 .72555 L F
.22275 .7249 m .22274 .7249 L .22268 .72556 L .55 .315 .512 r
F
.23054 .65136 m .22301 .72198 L .22307 .72196 L F
.22301 .72198 m .22388 .72163 L .22273 .72179 L .66 .81 .955 r
F
.22393 .72168 m .22388 .72163 L .22301 .72198 L F
.22273 .72179 m .22351 .72112 L .22227 .72147 L F
.22388 .72163 m .22351 .72112 L .22273 .72179 L F
.2209 .72264 m .22131 .72198 L .22049 .72256 L F
.22205 .72228 m .22131 .72198 L .2209 .72264 L F
.22131 .72198 m .22124 .72196 L .22119 .722 L F
.22131 .72198 m .22119 .722 L .22049 .72256 L F
.22103 .72329 m .2209 .72264 L .22006 .72323 L F
.22174 .72282 m .2209 .72264 L .22103 .72329 L F
.2209 .72264 m .22049 .72256 L .22032 .72283 L F
.2209 .72264 m .22032 .72283 L .22006 .72323 L F
.22501 .72436 m .22533 .72432 L .22501 .72431 L F
.22537 .72653 m .22533 .72432 L .22501 .72436 L F
.22533 .72432 m .22395 .72524 L .22526 .72515 L .656 .407 .53 r
F
.22429 .72446 m .22395 .72524 L .22533 .72432 L F
.22566 .72139 m .22526 .72515 L .22694 .7214 L .734 .476 .538 r
F
.2336 .64683 m .23231 .64666 L .23189 .65132 L F
.23363 .64684 m .23465 .64705 L .23374 .64655 L .596 .768 .962 r
F
.23459 .64711 m .23465 .64705 L .23363 .64684 L F
.23225 .6535 m .23494 .64672 L .23105 .64624 L .595 .768 .962 r
F
.2331 .65148 m .23189 .65132 L .22526 .72515 L .734 .476 .538 r
F
.22501 .72431 m .22634 .7239 L .22494 .7239 L .66 .81 .955 r
F
.22618 .72432 m .22634 .7239 L .22501 .72431 L F
.22535 .72432 m .22526 .72515 L .22535 .72432 L .734 .476 .538 r
F
.22668 .72433 m .22526 .72515 L .22659 .72528 L F
.22563 .72432 m .22526 .72515 L .22668 .72433 L F
.227 .72141 m .22659 .72528 L .22701 .72141 L .807 .543 .539 r
F
.22701 .72141 m .22659 .72528 L .22832 .72163 L F
.22621 .72425 m .22767 .72407 L .22634 .7239 L .66 .81 .955 r
F
.22733 .72444 m .22767 .72407 L .22621 .72425 L F
.22669 .72433 m .22668 .72433 L .22659 .72528 L .807 .543 .539 r
F
.23444 .65184 m .22694 .7214 L .227 .72141 L F
.22746 .72126 m .22875 .72146 L .22759 .72112 L .66 .81 .955 r
F
.22841 .72167 m .22875 .72146 L .22746 .72126 L F
.227 .72141 m .22701 .72141 L .23453 .65187 L .807 .543 .539 r
F
.22614 .72127 m .22759 .72112 L .22626 .72094 L .66 .81 .955 r
F
.2261 .72139 m .22648 .72132 L .22614 .72127 L F
.22648 .72132 m .22759 .72112 L .22614 .72127 L F
.22727 .72146 m .22732 .7214 L .22694 .7214 L F
.22566 .72139 m .22566 .72139 L .23319 .65149 L .734 .476 .538 r
F
.22732 .7214 m .22759 .72112 L .2261 .72139 L .66 .81 .955 r
F
.22495 .72138 m .22626 .72094 L .22487 .72094 L F
.2261 .72139 m .22626 .72094 L .22495 .72138 L F
.23689 .65316 m .24233 .6541 L .23861 .65303 L .595 .768 .962 r
F
.23815 .65385 m .24233 .6541 L .23689 .65316 L F
.24233 .6541 m .24705 .65438 L .23861 .65303 L F
.23024 .72608 m .23012 .7274 L .23024 .72608 L .796 .683 .137 r
F
.22537 .72653 m .23006 .72711 L .23023 .72684 L .66 .81 .955 r
F
.23024 .72607 m .22939 .72641 L .23012 .7274 L .991 .745 .452 r
F
.22972 .72545 m .22939 .72641 L .23024 .72607 L F
.23056 .7272 m .23132 .72773 L .23055 .72614 L .66 .81 .955 r
F
.23035 .7262 m .23065 .72656 L .2307 .72617 L F
.23062 .72687 m .23063 .72687 L .23063 .72685 L F
.23062 .72687 m .23063 .72685 L .2307 .72617 L F
.22537 .72653 m .22983 .72746 L .22985 .72744 L F
.22537 .72653 m .22985 .72744 L .23006 .72711 L F
.2305 .72319 m .2305 .72315 L .23024 .72607 L .796 .683 .137 r
F
.23024 .72608 m .23024 .72607 L .23012 .7274 L F
.2305 .72319 m .23024 .72607 L .23024 .72608 L F
.23025 .72684 m .23026 .72714 L .23062 .72687 L .66 .81 .955 r
F
.22537 .72653 m .22911 .72801 L .22983 .72746 L F
.22909 .72802 m .22899 .72935 L .22908 .72802 L .487 .263 .5 r
F
.22909 .72802 m .22911 .72801 L .22899 .72935 L F
.22537 .72653 m .22811 .72842 L .22911 .72801 L .66 .81 .955 r
F
.22806 .65138 m .22905 .65096 L .22662 .65065 L .595 .768 .962 r
F
.22955 .65136 m .22905 .65096 L .22806 .65138 L F
.22905 .65096 m .22377 .64678 L .22662 .65065 L F
.22127 .72724 m .22125 .72804 L .22109 .72666 L .952 .765 .308 r
F
.22131 .72738 m .22143 .72777 L .22179 .72785 L .66 .81 .955 r
F
.22129 .72736 m .22143 .72777 L .22131 .72738 L F
.22091 .72469 m .22029 .72458 L .22076 .72502 L F
.22091 .72469 m .22076 .72502 L .22092 .72518 L F
.22568 .65227 m .22585 .65141 L .22139 .65148 L .595 .768 .962 r
F
.22746 .65194 m .22585 .65141 L .22568 .65227 L F
.22585 .65141 m .2188 .64912 L .22139 .65148 L F
.22131 .72737 m .22131 .72738 L .22125 .72804 L .952 .765 .308 r
F
.22149 .72796 m .22033 .72755 L .22097 .72815 L .66 .81 .955 r
F
.22179 .72785 m .22143 .72777 L .22149 .72796 L F
.22537 .72653 m .22129 .72736 L .22179 .72785 L F
.2219 .72795 m .22184 .7287 L .2219 .72795 L .98 .727 .476 r
F
.22281 .72841 m .22274 .72926 L .22281 .72841 L .913 .647 .523 r
F
.22537 .72653 m .22179 .72785 L .22201 .72801 L .66 .81 .955 r
F
.22537 .72653 m .22201 .72801 L .22252 .72826 L F
.2219 .72795 m .22184 .7287 L .22178 .72784 L .98 .727 .476 r
F
.22131 .72738 m .22184 .7287 L .22125 .72804 L F
.22178 .72784 m .22184 .7287 L .22131 .72738 L F
.22537 .72653 m .22243 .72832 L .22345 .72858 L .66 .81 .955 r
F
.22537 .72653 m .22345 .72858 L .22411 .72874 L F
.22537 .72653 m .22411 .72874 L .22455 .72876 L F
.22409 .72874 m .22402 .72971 L .22409 .72874 L .839 .573 .538 r
F
.22537 .72653 m .22574 .72881 L .22708 .72887 L .66 .81 .955 r
F
.22603 .72882 m .22596 .72995 L .22603 .72882 L .751 .492 .54 r
F
.22792 .7285 m .22783 .72976 L .22738 .72859 L .636 .39 .528 r
F
.22537 .72653 m .22694 .72867 L .22816 .72846 L .66 .81 .955 r
F
.22792 .7285 m .22783 .72976 L .22792 .7285 L .636 .39 .528 r
F
.23237 .72538 m .23489 .72557 L .23202 .72497 L .66 .81 .955 r
F
.23012 .72701 m .23013 .72817 L .22985 .72744 L 0 0 .268 r
F
.22911 .72801 m .22973 .72881 L .22899 .72935 L .269 .086 .437 r
F
.22962 .72762 m .22973 .72881 L .22911 .72801 L F
.23374 .64655 m .2393 .64279 L .2356 .64185 L .596 .768 .962 r
F
.24417 .65436 m .25534 .66003 L .25957 .65735 L F
.23815 .65385 m .24684 .65621 L .24705 .65438 L .595 .768 .962 r
F
.24022 .65498 m .24684 .65621 L .23815 .65385 L F
.23666 .6542 m .23664 .65355 L .2305 .72315 L .796 .683 .137 r
F
.23054 .7256 m .23338 .72676 L .23347 .72669 L .66 .81 .955 r
F
.23054 .72563 m .23338 .72676 L .23054 .7256 L F
.23237 .72538 m .23347 .72669 L .23489 .72557 L F
.23057 .72742 m .23132 .72773 L .23056 .7272 L F
.22695 .65473 m .22468 .65405 L .22055 .65622 L .595 .768 .962 r
F
.22739 .65385 m .22468 .65405 L .22695 .65473 L F
.22468 .65405 m .21828 .65451 L .22055 .65622 L F
.22695 .65473 m .22006 .65633 L .22614 .65634 L F
.22045 .54769 m .20068 .54327 L .19729 .54887 L .662 .802 .95 r
F
.22352 .54519 m .20068 .54327 L .22045 .54769 L F
.50323 .68643 m .49007 .69099 L .50408 .69005 L .597 .767 .961 r
F
.50323 .68643 m .48874 .68557 L .49007 .69099 L F
0 g
.49007 .69099 m
.49423 .69616 L
s
.24165 .43043 m .21948 .42582 L .21929 .43256 L .667 .434 .558 r
F
0 g
.19901 .43785 m
.21929 .43256 L
s
.24165 .43043 m .24181 .42369 L .21948 .42582 L .667 .434 .558 r
F
0 g
.19924 .43112 m
.21948 .42582 L
s
.66714 .41079 m .65134 .41459 L .65193 .42131 L .381 .228 .545 r
F
.66714 .41079 m .66652 .40404 L .65134 .41459 L F
0 g
.64121 .42655 m
.65134 .41459 L
s
.78095 .55004 m .78841 .53601 L .78936 .5416 L .263 .171 .558 r
F
.76366 .54561 m .78095 .55004 L .78936 .5416 L .657 .808 .956 r
F
.75578 .55063 m .78095 .55004 L .76366 .54561 L F
0 g
.76912 .5575 m
.78095 .55004 L
s
.51801 .68251 m .50439 .68527 L .51842 .68432 L .597 .767 .96 r
F
.51801 .68251 m .50355 .68165 L .50439 .68527 L F
.57369 .69596 m .5759 .68595 L .57567 .69075 L 0 0 .201 r
F
.5599 .69337 m .57369 .69596 L .57567 .69075 L .597 .767 .961 r
F
0 g
.56892 .70061 m
.57369 .69596 L
s
.19727 .56005 m .17555 .55845 L .17501 .56713 L .661 .804 .952 r
F
0 g
.17501 .56713 m
.17891 .57543 L
s
.56014 .68859 m .5759 .68595 L .56143 .68509 L .597 .767 .96 r
F
.54633 .68598 m .56014 .68859 L .56143 .68509 L F
.25822 .551 m .26885 .5401 L .25444 .54891 L .661 .803 .951 r
F
.25822 .551 m .27638 .54432 L .26885 .5401 L F
0 g
.51726 .56894 m
.53409 .5668 L
s
.68584 .42201 m .66714 .41079 L .65193 .42131 L .655 .781 .941 r
F
.69861 .41655 m .66714 .41079 L .68584 .42201 L F
.7553 .40881 m .75269 .38958 L .74213 .4058 L .656 .78 .94 r
F
.7553 .40881 m .77259 .39418 L .75269 .38958 L F
.54652 .6812 m .56152 .68031 L .54714 .67945 L .598 .766 .96 r
F
.7679 .42705 m .7745 .40747 L .75704 .4221 L .655 .782 .942 r
F
.7679 .42705 m .7908 .41503 L .7745 .40747 L F
.25419 .54337 m .259 .53155 L .24946 .54188 L .662 .802 .95 r
F
.25419 .54337 m .2685 .53459 L .259 .53155 L F
.71167 .54551 m .7032 .55728 L .71581 .54702 L .657 .808 .956 r
F
.71167 .54551 m .69493 .55431 L .7032 .55728 L F
.80221 .42495 m .78995 .40828 L .7908 .41503 L .957 .65 .409 r
F
0 g
.80221 .42495 m
.80803 .43648 L
s
.66328 .54353 m .6677 .54562 L .66847 .55121 L .964 .664 .252 r
F
.66328 .54353 m .66251 .53792 L .6677 .54562 L F
0 g
.6677 .54562 m
.67339 .54953 L
s
.68411 .53371 m .668 .54552 L .68748 .53885 L .658 .806 .954 r
F
.68411 .53371 m .66283 .53786 L .668 .54552 L F
.68917 .27826 m .73208 .27518 L .69792 .2672 L .644 .736 .916 r
F
.26444 .43162 m .24181 .42369 L .24165 .43043 L .734 .49 .56 r
F
0 g
.21948 .42582 m
.24181 .42369 L
s
.24181 .42369 m
.26455 .42489 L
s
.26444 .43162 m
.28597 .43604 L
s
.51918 .24533 m .5227 .25595 L .5222 .26421 L .904 .727 .225 r
F
.51918 .24533 m .5197 .23704 L .5227 .25595 L F
0 g
.5227 .25595 m
.52707 .26361 L
s
.20068 .54327 m .17575 .54725 L .19729 .54887 L .662 .802 .95 r
F
.55654 .23896 m .52323 .25589 L .55829 .25154 L .645 .736 .915 r
F
.55654 .23896 m .52025 .23707 L .52323 .25589 L F
.22061 .55885 m .19727 .56005 L .21887 .56163 L .661 .804 .952 r
F
0 g
.24165 .43043 m
.26444 .43162 L
s
.34872 .27588 m .322 .25768 L .30581 .27161 L .643 .737 .917 r
F
.36332 .26913 m .322 .25768 L .34872 .27588 L F
.73208 .27518 m .73204 .26689 L .73862 .24847 L 0 0 .277 r
F
0 g
.72639 .27385 m
.73204 .26689 L
s
.2816 .555 m .2949 .5432 L .27659 .54992 L .661 .804 .952 r
F
.2816 .555 m .30232 .55088 L .2949 .5432 L F
.30207 .5453 m .29443 .532 L .29467 .53759 L .981 .704 .422 r
F
.30232 .55088 m .30207 .5453 L .29467 .53759 L F
0 g
.30207 .5453 m
.30518 .55374 L
s
.45087 .28122 m .45401 .25307 L .43585 .27292 L .643 .737 .917 r
F
.45087 .28122 m .47665 .26576 L .45401 .25307 L F
0 g
.53222 .76251 m
.53222 .76363 L
s
.48065 .40634 m .48363 .38662 L .48392 .39334 L 0 0 .26 r
F
.48093 .41305 m .48065 .40634 L .48392 .39334 L F
.45271 .40261 m .48065 .40634 L .48392 .39334 L .657 .779 .939 r
F
0 g
.47516 .41379 m
.48065 .40634 L
s
.44712 .41741 m .48093 .41305 L .45294 .40934 L .656 .78 .939 r
F
.42191 .40968 m .44712 .41741 L .45294 .40934 L F
.41734 .4132 m .44712 .41741 L .42191 .40968 L F
.51772 .6873 m .50408 .69005 L .51812 .6891 L .597 .767 .961 r
F
.51772 .6873 m .50323 .68643 L .50408 .69005 L F
.22048 .55325 m .20058 .54883 L .19717 .55444 L .661 .803 .951 r
F
.22357 .55075 m .20058 .54883 L .22048 .55325 L F
0 g
.24307 .57199 m
.24396 .5619 L
s
.5599 .69337 m .57567 .69075 L .56118 .68988 L .597 .767 .961 r
F
.54607 .69077 m .5599 .69337 L .56118 .68988 L F
.54451 .69233 m .5599 .69337 L .54607 .69077 L F
.22352 .54519 m .20681 .53824 L .20068 .54327 L .662 .802 .95 r
F
.22774 .54317 m .20681 .53824 L .22352 .54519 L F
.69805 .40997 m .68592 .39592 L .6668 .40421 L .656 .78 .94 r
F
.71243 .40641 m .68592 .39592 L .69805 .40997 L F
0 g
.23552 .57187 m
.23639 .56232 L
s
.74227 .54367 m .75578 .55063 L .76366 .54561 L .657 .808 .956 r
F
.73742 .54572 m .75578 .55063 L .74227 .54367 L F
.54633 .68598 m .56143 .68509 L .54695 .68423 L .597 .767 .96 r
F
.50513 .67337 m .48963 .67603 L .504 .67688 L .598 .766 .96 r
F
.50513 .67337 m .49126 .67075 L .48963 .67603 L F
.49071 .67549 m .48941 .67601 L .48908 .68079 L 0 0 .128 r
F
0 g
.48991 .67809 m
.49059 .68088 L
s
.49071 .67549 m .49105 .67071 L .48941 .67601 L 0 0 .128 r
F
.51896 .67599 m .504 .67688 L .51838 .67774 L .598 .766 .96 r
F
.51896 .67599 m .50513 .67337 L .504 .67688 L F
.25841 .55659 m .26905 .54571 L .25462 .5545 L .661 .804 .952 r
F
.25841 .55659 m .27659 .54992 L .26905 .54571 L F
.54714 .67945 m .56084 .67668 L .54678 .67764 L .598 .766 .96 r
F
.54714 .67945 m .56152 .68031 L .56084 .67668 L F
.56152 .68031 m .57494 .67572 L .56084 .67668 L F
.56152 .68031 m .57591 .68116 L .57494 .67572 L F
.5759 .68595 m .57612 .68117 L .57515 .67571 L .884 .716 .202 r
F
0 g
.57435 .68586 m
.57564 .68245 L
s
.21929 .43256 m
.24165 .43043 L
s
.66777 .41755 m .65193 .42131 L .65253 .42805 L .381 .228 .545 r
F
.66777 .41755 m .66714 .41079 L .65193 .42131 L F
0 g
.64178 .43324 m
.65193 .42131 L
s
.24946 .54188 m .24815 .52992 L .24406 .54108 L .662 .802 .95 r
F
.24946 .54188 m .259 .53155 L .24815 .52992 L F
.25444 .54891 m .25929 .53706 L .24968 .54741 L .661 .803 .951 r
F
.25444 .54891 m .26885 .5401 L .25929 .53706 L F
.66405 .54915 m .66847 .55121 L .66925 .55681 L .964 .664 .252 r
F
.66405 .54915 m .66328 .54353 L .66847 .55121 L F
.6847 .53936 m .66847 .55121 L .68809 .54452 L .658 .807 .955 r
F
.6847 .53936 m .66328 .54353 L .66847 .55121 L F
0 g
.66847 .55121 m
.6742 .55512 L
s
.32097 .26602 m .30581 .27161 L .30474 .27993 L .217 .032 .402 r
F
.32097 .26602 m .322 .25768 L .30581 .27161 L F
0 g
.29643 .28804 m
.30581 .27161 L
s
.23728 .63729 m
.24307 .57199 L
s
.6865 .42874 m .66777 .41755 L .65253 .42805 L .655 .782 .942 r
F
0 g
.64235 .43996 m
.65253 .42805 L
s
.69929 .4233 m .66777 .41755 L .6865 .42874 L .655 .782 .942 r
F
0 g
.22964 .63657 m
.23552 .57187 L
s
.75626 .41537 m .75364 .39609 L .743 .41236 L .655 .781 .941 r
F
.75626 .41537 m .77367 .4007 L .75364 .39609 L F
.20058 .54883 m .17549 .55283 L .19717 .55444 L .661 .803 .951 r
F
.27599 .5388 m .28296 .52571 L .2685 .53459 L .662 .802 .95 r
F
.27599 .5388 m .29415 .5321 L .28296 .52571 L F
.49369 .28144 m .47727 .25744 L .47665 .26576 L .939 .671 .502 r
F
.49311 .28978 m .49369 .28144 L .47665 .26576 L F
0 g
.49369 .28144 m
.50403 .2989 L
s
.36443 .26105 m .34525 .23933 L .32344 .24965 L .644 .737 .916 r
F
.3816 .25721 m .34525 .23933 L .36443 .26105 L F
.4364 .26481 m .428 .23637 L .41896 .25916 L F
.4364 .26481 m .45443 .24503 L .428 .23637 L F
.30232 .55088 m .29467 .53759 L .2949 .5432 L .981 .704 .422 r
F
0 g
.30232 .55088 m
.30543 .55931 L
s
.22774 .54317 m .21527 .53413 L .20681 .53824 L .662 .802 .95 r
F
.23281 .54174 m .21527 .53413 L .22774 .54317 L F
.74213 .4058 m .73051 .38831 L .72749 .40498 L .656 .78 .94 r
F
.74213 .4058 m .75269 .38958 L .73051 .38831 L F
.22061 .55885 m .20069 .55444 L .19727 .56005 L .661 .804 .952 r
F
.22371 .55635 m .20069 .55444 L .22061 .55885 L F
.54607 .69077 m .56118 .68988 L .54669 .68902 L .597 .767 .961 r
F
.50468 .67813 m .48908 .68079 L .50355 .68165 L .597 .767 .96 r
F
.50468 .67813 m .49071 .67549 L .48908 .68079 L F
.49038 .68029 m .48908 .68079 L .48874 .68557 L 0 0 .128 r
F
0 g
.48958 .68287 m
.49027 .68566 L
s
.49038 .68029 m .49071 .67549 L .48908 .68079 L 0 0 .128 r
F
.5186 .68075 m .50355 .68165 L .51801 .68251 L .597 .767 .96 r
F
.5186 .68075 m .50468 .67813 L .50355 .68165 L F
.78841 .53601 m .78747 .53043 L .79182 .5215 L 0 0 .485 r
F
0 g
.78079 .5372 m
.78747 .53043 L
s
.30829 .39684 m .31244 .40302 L .31242 .40974 L .942 .722 .25 r
F
.30829 .39684 m .30832 .3901 L .31244 .40302 L F
0 g
.31244 .40302 m
.31728 .40889 L
s
.33792 .38951 m .31285 .40295 L .34049 .39811 L .658 .778 .938 r
F
.33792 .38951 m .30876 .39009 L .31285 .40295 L F
.24406 .54108 m .2367 .52982 L .23838 .54103 L .662 .802 .95 r
F
.24406 .54108 m .24815 .52992 L .2367 .52982 L F
.22357 .55075 m .20675 .54378 L .20058 .54883 L .661 .803 .951 r
F
.22782 .54871 m .20675 .54378 L .22357 .55075 L F
.54695 .68423 m .56074 .68146 L .54659 .68242 L .597 .767 .96 r
F
.54695 .68423 m .56143 .68509 L .56074 .68146 L F
.56143 .68509 m .57492 .6805 L .56074 .68146 L F
.56143 .68509 m .5759 .68595 L .57492 .6805 L F
.5759 .68595 m .57515 .67571 L .57492 .6805 L .884 .716 .202 r
F
.57567 .69075 m .5759 .68595 L .57492 .6805 L F
0 g
.57412 .69065 m
.57542 .68723 L
s
.52049 .67441 m .50513 .67337 L .51896 .67599 L .598 .766 .96 r
F
.48093 .41305 m .48392 .39334 L .48421 .40008 L 0 0 .26 r
F
.45294 .40934 m .48093 .41305 L .48421 .40008 L .656 .78 .939 r
F
0 g
.47205 .42506 m
.48093 .41305 L
s
.54678 .67764 m .55823 .67317 L .54546 .67589 L .598 .766 .96 r
F
.54678 .67764 m .56084 .67668 L .55823 .67317 L F
.59278 .26382 m .56369 .28003 L .59597 .26979 L .644 .737 .917 r
F
.59278 .26382 m .55712 .26818 L .56369 .28003 L F
.76275 .54002 m .78841 .53601 L .76829 .53435 L .658 .807 .955 r
F
.23281 .54174 m .22547 .53126 L .21527 .53413 L .662 .802 .95 r
F
.23838 .54103 m .22547 .53126 L .23281 .54174 L F
.6891 .28658 m .73213 .28352 L .69788 .27554 L .644 .737 .917 r
F
.65909 .27309 m .6891 .28658 L .69788 .27554 L F
.65275 .27772 m .6891 .28658 L .65909 .27309 L F
.71243 .40641 m .70769 .39048 L .68592 .39592 L .656 .78 .94 r
F
.72749 .40498 m .70769 .39048 L .71243 .40641 L F
.51867 .25367 m .5222 .26421 L .5217 .27252 L .904 .727 .225 r
F
.51867 .25367 m .51918 .24533 L .5222 .26421 L F
.55576 .24724 m .5222 .26421 L .55753 .25986 L .644 .736 .916 r
F
.55576 .24724 m .51918 .24533 L .5222 .26421 L F
0 g
.5222 .26421 m
.52661 .27192 L
s
.23838 .54103 m .2367 .52982 L .22547 .53126 L .662 .802 .95 r
F
0 g
.53627 .75903 m
.53627 .76024 L
s
.53604 .68734 m
.53626 .75584 L
s
.70867 .5434 m .69493 .55431 L .71167 .54551 L .657 .808 .956 r
F
.70867 .5434 m .68889 .55013 L .69493 .55431 L F
.69861 .41655 m .68639 .40247 L .66714 .41079 L .655 .781 .941 r
F
.71309 .41297 m .68639 .40247 L .69861 .41655 L F
.24968 .54741 m .24836 .53543 L .24424 .54661 L .661 .803 .951 r
F
.24968 .54741 m .25929 .53706 L .24836 .53543 L F
.36827 .40675 m .34663 .41946 L .37139 .4107 L .656 .78 .939 r
F
.36827 .40675 m .34027 .41162 L .34663 .41946 L F
.25462 .5545 m .25948 .54268 L .24985 .55301 L .661 .804 .952 r
F
.25462 .5545 m .26905 .54571 L .25948 .54268 L F
.20068 .54327 m .18073 .53881 L .17575 .54725 L .662 .802 .95 r
F
0 g
.52856 .75954 m
.52856 .76014 L
s
.52856 .75665 m
.52856 .75877 L
s
.5285 .68691 m
.52856 .75572 L
s
.6855 .54499 m .66925 .55681 L .68889 .55013 L .657 .808 .956 r
F
.6855 .54499 m .66405 .54915 L .66925 .55681 L F
0 g
.66925 .55681 m
.67837 .56302 L
s
.18051 .54436 m .17542 .54723 L .17549 .55283 L 0 0 .391 r
F
.18051 .54436 m .18043 .53874 L .17542 .54723 L F
0 g
.17488 .55595 m
.17542 .54723 L
s
.34777 .2842 m .32097 .26602 L .30474 .27993 L .643 .738 .918 r
F
0 g
.29535 .29632 m
.30474 .27993 L
s
.3624 .27746 m .32097 .26602 L .34777 .2842 L .643 .738 .918 r
F
.20069 .55444 m .17555 .55845 L .19727 .56005 L .661 .804 .952 r
F
.73208 .27518 m .73862 .24847 L .73868 .2568 L 0 0 .277 r
F
.73213 .28352 m .73208 .27518 L .73868 .2568 L F
.69792 .2672 m .73208 .27518 L .73868 .2568 L .644 .736 .916 r
F
0 g
.72638 .28218 m
.73208 .27518 L
s
.27638 .54432 m .28341 .53119 L .26885 .5401 L .661 .803 .951 r
F
.27638 .54432 m .29467 .53759 L .28341 .53119 L F
.72749 .40498 m .73051 .38831 L .70769 .39048 L .656 .78 .94 r
F
.45018 .28955 m .45332 .26146 L .43512 .28126 L .643 .738 .918 r
F
.45018 .28955 m .47602 .27413 L .45332 .26146 L F
.78995 .40828 m .7891 .40156 L .77285 .39396 L .881 .592 .493 r
F
0 g
.7891 .40156 m
.80048 .41154 L
s
.75704 .4221 m .75443 .40288 L .74376 .41911 L .655 .782 .942 r
F
.75704 .4221 m .7745 .40747 L .75443 .40288 L F
.50436 .68292 m .48874 .68557 L .50323 .68643 L .597 .767 .961 r
F
.50436 .68292 m .49038 .68029 L .48874 .68557 L F
0 g
.48874 .68557 m
.49007 .69099 L
s
.22782 .54871 m .21526 .53966 L .20675 .54378 L .661 .803 .951 r
F
.23292 .54729 m .21526 .53966 L .22782 .54871 L F
.5183 .68554 m .50323 .68643 L .51772 .6873 L .597 .767 .961 r
F
.5183 .68554 m .50436 .68292 L .50323 .68643 L F
.70546 .52955 m .68411 .53371 L .68748 .53885 L .658 .806 .954 r
F
.59284 .24086 m .55654 .23896 L .55829 .25154 L .645 .736 .915 r
F
.54669 .68902 m .56049 .68626 L .54633 .68721 L .597 .767 .961 r
F
.54669 .68902 m .56118 .68988 L .56049 .68626 L F
.56118 .68988 m .5747 .68531 L .56049 .68626 L F
.56118 .68988 m .57567 .69075 L .5747 .68531 L F
.57567 .69075 m .57492 .6805 L .5747 .68531 L .884 .716 .202 r
F
0 g
.57369 .69596 m
.57567 .69075 L
s
.52013 .67917 m .50468 .67813 L .5186 .68075 L .597 .767 .96 r
F
.78841 .53601 m .79182 .5215 L .79278 .5271 L 0 0 .485 r
F
.78936 .5416 m .78841 .53601 L .79278 .5271 L F
.76829 .53435 m .78841 .53601 L .79278 .5271 L .658 .807 .955 r
F
0 g
.78168 .5428 m
.78841 .53601 L
s
.52049 .67441 m .50815 .6702 L .50513 .67337 L .598 .766 .96 r
F
.52286 .67311 m .50815 .6702 L .52049 .67441 L F
.54659 .68242 m .55811 .67794 L .54526 .68066 L .597 .767 .96 r
F
.54659 .68242 m .56074 .68146 L .55811 .67794 L F
.54546 .67589 m .55386 .67002 L .54327 .67432 L .598 .766 .96 r
F
.54546 .67589 m .55823 .67317 L .55386 .67002 L F
.50815 .6702 m .49126 .67075 L .50513 .67337 L F
.22371 .55635 m .20686 .54941 L .20069 .55444 L .661 .804 .952 r
F
.22796 .55432 m .20686 .54941 L .22371 .55635 L F
.24424 .54661 m .23684 .53533 L .23853 .54657 L .661 .803 .951 r
F
.24424 .54661 m .24836 .53543 L .23684 .53533 L F
.56084 .67668 m .57107 .67044 L .55823 .67317 L .598 .766 .96 r
F
.56084 .67668 m .57494 .67572 L .57107 .67044 L F
.20681 .53824 m .18073 .53881 L .20068 .54327 L .662 .802 .95 r
F
.45271 .40261 m .48392 .39334 L .45473 .39392 L .657 .779 .939 r
F
.743 .41236 m .73131 .39482 L .72826 .41154 L .655 .781 .941 r
F
.743 .41236 m .75364 .39609 L .73131 .39482 L F
.76366 .54561 m .78936 .5416 L .76921 .53995 L .657 .808 .956 r
F
.74621 .54114 m .76366 .54561 L .76921 .53995 L F
.74227 .54367 m .76366 .54561 L .74621 .54114 L F
.30826 .40362 m .31242 .40974 L .31239 .41648 L .942 .722 .25 r
F
.30826 .40362 m .30829 .39684 L .31242 .40974 L F
.33765 .39626 m .31242 .40974 L .34024 .40488 L .657 .779 .939 r
F
.33765 .39626 m .30829 .39684 L .31242 .40974 L F
0 g
.31242 .40974 m
.31729 .41562 L
s
.23292 .54729 m .22553 .53678 L .21526 .53966 L .661 .803 .951 r
F
.23853 .54657 m .22553 .53678 L .23292 .54729 L F
.23853 .54657 m .23684 .53533 L .22553 .53678 L F
.24985 .55301 m .24853 .54106 L .24441 .55222 L .661 .804 .952 r
F
.24985 .55301 m .25948 .54268 L .24853 .54106 L F
.20058 .54883 m .18051 .54436 L .17549 .55283 L .661 .803 .951 r
F
.18058 .55 m .17549 .55283 L .17555 .55845 L 0 0 .391 r
F
.18058 .55 m .18051 .54436 L .17549 .55283 L F
0 g
.17495 .56153 m
.17549 .55283 L
s
.49311 .28978 m .47665 .26576 L .47602 .27413 L .939 .671 .502 r
F
0 g
.49311 .28978 m
.50348 .30721 L
s
.3816 .25721 m .37127 .2334 L .34525 .23933 L .644 .737 .916 r
F
.40023 .25656 m .37127 .2334 L .3816 .25721 L F
.36704 .38893 m .33792 .38951 L .34049 .39811 L .658 .778 .938 r
F
.41896 .25916 m .39956 .23238 L .40023 .25656 L .644 .737 .916 r
F
.41896 .25916 m .428 .23637 L .39956 .23238 L F
.27659 .54992 m .28363 .53682 L .26905 .54571 L .661 .804 .952 r
F
.27659 .54992 m .2949 .5432 L .28363 .53682 L F
.36332 .26913 m .34398 .24732 L .322 .25768 L .643 .737 .917 r
F
.38063 .26528 m .34398 .24732 L .36332 .26913 L F
.69929 .4233 m .68706 .40925 L .66777 .41755 L .655 .782 .942 r
F
.7138 .41972 m .68706 .40925 L .69929 .4233 L F
.71309 .41297 m .70832 .397 L .68639 .40247 L .655 .781 .941 r
F
.72826 .41154 m .70832 .397 L .71309 .41297 L F
.43585 .27292 m .42738 .24437 L .41827 .26724 L .643 .737 .917 r
F
.43585 .27292 m .45401 .25307 L .42738 .24437 L F
.52286 .67311 m .51288 .66758 L .50815 .6702 L .598 .766 .96 r
F
.52591 .67219 m .51288 .66758 L .52286 .67311 L F
.54327 .67432 m .54802 .66744 L .54036 .67304 L F
.54327 .67432 m .55386 .67002 L .54802 .66744 L F
.51984 .68396 m .50436 .68292 L .5183 .68554 L .597 .767 .961 r
F
.22796 .55432 m .21539 .5453 L .20686 .54941 L .661 .804 .952 r
F
.23307 .5529 m .21539 .5453 L .22796 .55432 L F
.70618 .53519 m .6847 .53936 L .68809 .54452 L .658 .807 .955 r
F
.52013 .67917 m .50772 .67494 L .50468 .67813 L .597 .767 .96 r
F
.52252 .67787 m .50772 .67494 L .52013 .67917 L F
.54633 .68721 m .55786 .68275 L .545 .68546 L .597 .767 .961 r
F
.54633 .68721 m .56049 .68626 L .55786 .68275 L F
0 g
.6291 .16257 m
.63117 .21828 L
s
.54526 .68066 m .55371 .67478 L .54306 .67909 L .597 .767 .96 r
F
.54526 .68066 m .55811 .67794 L .55371 .67478 L F
.50772 .67494 m .49071 .67549 L .50468 .67813 L F
0 g
.62172 .16243 m
.62366 .21855 L
s
.72826 .41154 m .73131 .39482 L .70832 .397 L .655 .781 .941 r
F
.78995 .40828 m .77285 .39396 L .77367 .4007 L .881 .592 .493 r
F
.7908 .41503 m .78995 .40828 L .77367 .4007 L F
0 g
.78995 .40828 m
.80135 .41823 L
s
.50815 .6702 m .49575 .66596 L .49126 .67075 L .598 .766 .96 r
F
.49523 .6707 m .49105 .67071 L .49071 .67549 L .06 0 .392 r
F
.49523 .6707 m .49556 .6659 L .49105 .67071 L F
0 g
.48941 .67601 m
.49105 .67071 L
s
.78936 .5416 m .79278 .5271 L .79374 .53271 L 0 0 .485 r
F
.76921 .53995 m .78936 .5416 L .79374 .53271 L .657 .808 .956 r
F
0 g
.78095 .55004 m
.78936 .5416 L
s
.29467 .53759 m .29443 .532 L .28318 .52557 L .922 .647 .502 r
F
0 g
.29443 .532 m
.30183 .53973 L
s
.56074 .68146 m .57103 .67521 L .55811 .67794 L .597 .767 .96 r
F
.56074 .68146 m .57492 .6805 L .57103 .67521 L F
.2685 .53459 m .26868 .52109 L .259 .53155 L .662 .802 .95 r
F
.2685 .53459 m .28296 .52571 L .26868 .52109 L F
.24441 .55222 m .23699 .54097 L .23868 .55218 L .661 .804 .952 r
F
.24441 .55222 m .24853 .54106 L .23699 .54097 L F
.57492 .6805 m .57515 .67571 L .57126 .6704 L .993 .75 .445 r
F
0 g
.57515 .67571 m
.57612 .68117 L
s
.40023 .25656 m .39956 .23238 L .37127 .2334 L .644 .737 .916 r
F
.20675 .54378 m .18051 .54436 L .20058 .54883 L .661 .803 .951 r
F
.55534 .25559 m .5217 .27252 L .55712 .26818 L .644 .737 .917 r
F
.55534 .25559 m .51867 .25367 L .5217 .27252 L F
0 g
.5217 .27252 m
.53182 .29013 L
s
.23307 .5529 m .22567 .54242 L .21539 .5453 L .661 .804 .952 r
F
.23868 .55218 m .22567 .54242 L .23307 .5529 L F
.52591 .67219 m .51899 .66572 L .51288 .66758 L .598 .766 .96 r
F
.52943 .6717 m .51899 .66572 L .52591 .67219 L F
.73213 .28352 m .73868 .2568 L .73875 .26517 L 0 0 .277 r
F
.69788 .27554 m .73213 .28352 L .73875 .26517 L .644 .737 .917 r
F
0 g
.71928 .29922 m
.73213 .28352 L
s
.23868 .55218 m .23699 .54097 L .22567 .54242 L .661 .804 .952 r
F
.54036 .67304 m .54111 .66563 L .53692 .67214 L .598 .766 .96 r
F
.54036 .67304 m .54802 .66744 L .54111 .66563 L F
.20069 .55444 m .18058 .55 L .17555 .55845 L .661 .804 .952 r
F
0 g
.17501 .56713 m
.17555 .55845 L
s
.45294 .40934 m .48421 .40008 L .45497 .40067 L .656 .78 .939 r
F
.42476 .40561 m .45294 .40934 L .45497 .40067 L F
.42191 .40968 m .45294 .40934 L .42476 .40561 L F
.68639 .40247 m .66652 .40404 L .66714 .41079 L .505 .317 .559 r
F
.68639 .40247 m .68573 .39571 L .66652 .40404 L F
0 g
.65134 .41459 m
.66652 .40404 L
s
.74376 .41911 m .73206 .40161 L .72899 .41829 L .655 .782 .942 r
F
.74376 .41911 m .75443 .40288 L .73206 .40161 L F
.33767 .40303 m .31239 .41648 L .34027 .41162 L .656 .78 .939 r
F
.33767 .40303 m .30826 .40362 L .31239 .41648 L F
0 g
.31239 .41648 m
.3221 .42815 L
s
.66242 .53491 m .66251 .53792 L .66328 .54353 L 0 0 .125 r
F
0 g
.66276 .53829 m
.66594 .54301 L
s
.66242 .53491 m .66165 .52928 L .66251 .53792 L 0 0 .125 r
F
.52252 .67787 m .51247 .67233 L .50772 .67494 L .597 .767 .96 r
F
.52559 .67694 m .51247 .67233 L .52252 .67787 L F
.68363 .52796 m .66283 .53786 L .68411 .53371 L .658 .806 .954 r
F
.68363 .52796 m .66198 .52926 L .66283 .53786 L F
.54306 .67909 m .54783 .67219 L .54012 .67781 L .597 .767 .96 r
F
.54306 .67909 m .55371 .67478 L .54783 .67219 L F
.59234 .24915 m .55576 .24724 L .55753 .25986 L .644 .736 .916 r
F
.52943 .6717 m .52607 .66473 L .51899 .66572 L .598 .766 .96 r
F
.53319 .67168 m .52607 .66473 L .52943 .6717 L F
.51984 .68396 m .5074 .67975 L .50436 .68292 L .597 .767 .961 r
F
.52222 .68267 m .5074 .67975 L .51984 .68396 L F
.53692 .67214 m .53362 .6647 L .53319 .67168 L .598 .766 .96 r
F
.53692 .67214 m .54111 .66563 L .53362 .6647 L F
.545 .68546 m .55346 .67959 L .54279 .68389 L .597 .767 .961 r
F
.545 .68546 m .55786 .68275 L .55346 .67959 L F
.5074 .67975 m .49038 .68029 L .50436 .68292 L F
.36697 .39567 m .33765 .39626 L .34024 .40488 L .657 .779 .939 r
F
.51288 .66758 m .49575 .66596 L .50815 .6702 L .598 .766 .96 r
F
.70702 .54081 m .68889 .55013 L .70867 .5434 L .657 .808 .956 r
F
.70702 .54081 m .6855 .54499 L .68889 .55013 L F
.69792 .2672 m .73868 .2568 L .70209 .25489 L .644 .736 .916 r
F
.49491 .67551 m .49071 .67549 L .49038 .68029 L .06 0 .392 r
F
.50772 .67494 m .49523 .6707 L .49071 .67549 L .597 .767 .96 r
F
.49491 .67551 m .49523 .6707 L .49071 .67549 L .06 0 .392 r
F
0 g
.48908 .68079 m
.49071 .67549 L
s
.56049 .68626 m .57079 .68002 L .55786 .68275 L .597 .767 .961 r
F
.56049 .68626 m .5747 .68531 L .57079 .68002 L F
.53319 .67168 m .53362 .6647 L .52607 .66473 L .598 .766 .96 r
F
.76829 .53435 m .79278 .5271 L .77112 .5284 L .658 .807 .955 r
F
.55823 .67317 m .56453 .66568 L .55386 .67002 L .598 .766 .96 r
F
.55823 .67317 m .57107 .67044 L .56453 .66568 L F
.7138 .41972 m .70903 .4038 L .68706 .40925 L .655 .782 .942 r
F
.72899 .41829 m .70903 .4038 L .7138 .41972 L F
.57492 .6805 m .57126 .6704 L .57103 .67521 L .993 .75 .445 r
F
.5747 .68531 m .57492 .6805 L .57103 .67521 L F
0 g
.57492 .6805 m
.5759 .68595 L
s
.29467 .53759 m .28318 .52557 L .28341 .53119 L .922 .647 .502 r
F
.2949 .5432 m .29467 .53759 L .28341 .53119 L F
0 g
.29467 .53759 m
.30207 .5453 L
s
.26885 .5401 m .26903 .52656 L .25929 .53706 L .661 .803 .951 r
F
.26885 .5401 m .28341 .53119 L .26903 .52656 L F
.20686 .54941 m .18058 .55 L .20069 .55444 L .661 .804 .952 r
F
.72899 .41829 m .73206 .40161 L .70903 .4038 L .655 .782 .942 r
F
.52559 .67694 m .51862 .67046 L .51247 .67233 L .597 .767 .96 r
F
.52913 .67646 m .51862 .67046 L .52559 .67694 L F
.7908 .41503 m .77367 .4007 L .7745 .40747 L .881 .592 .493 r
F
0 g
.7908 .41503 m
.80221 .42495 L
s
.54012 .67781 m .54088 .67037 L .53666 .6769 L .597 .767 .96 r
F
.54012 .67781 m .54783 .67219 L .54088 .67037 L F
.34398 .24732 m .32304 .24938 L .322 .25768 L .432 .209 .474 r
F
.34398 .24732 m .34496 .23899 L .32304 .24938 L F
0 g
.30688 .26334 m
.32304 .24938 L
s
.20681 .53824 m .18989 .53119 L .18073 .53881 L .662 .802 .95 r
F
.21527 .53413 m .18989 .53119 L .20681 .53824 L F
.45421 .38721 m .48319 .38663 L .48051 .37357 L .658 .778 .938 r
F
.48392 .39334 m .48363 .38662 L .48094 .3735 L .851 .644 .104 r
F
0 g
.48194 .39338 m
.48318 .38842 L
s
.47665 .26576 m .47727 .25744 L .4547 .24473 L .87 .6 .526 r
F
0 g
.47727 .25744 m
.49426 .27314 L
s
.3624 .27746 m .34299 .25569 L .32097 .26602 L .643 .738 .918 r
F
.37975 .27362 m .34299 .25569 L .3624 .27746 L F
.38063 .26528 m .37019 .24138 L .34398 .24732 L .643 .737 .917 r
F
.3994 .26463 m .37019 .24138 L .38063 .26528 L F
.41827 .26724 m .39871 .24037 L .3994 .26463 L F
.41827 .26724 m .42738 .24437 L .39871 .24037 L F
.43512 .28126 m .42661 .25277 L .41749 .27559 L .643 .738 .918 r
F
.43512 .28126 m .45332 .26146 L .42661 .25277 L F
.52222 .68267 m .51217 .67714 L .5074 .67975 L .597 .767 .961 r
F
.5253 .68175 m .51217 .67714 L .52222 .68267 L F
.54279 .68389 m .54757 .67701 L .53985 .68261 L F
.54279 .68389 m .55346 .67959 L .54757 .67701 L F
.52913 .67646 m .52575 .66947 L .51862 .67046 L .597 .767 .96 r
F
.53291 .67644 m .52575 .66947 L .52913 .67646 L F
.53666 .6769 m .53334 .66944 L .53291 .67644 L F
.53666 .6769 m .54088 .67037 L .53334 .66944 L F
.70526 .52667 m .68411 .53371 L .70546 .52955 L .658 .806 .954 r
F
.70526 .52667 m .68363 .52796 L .68411 .53371 L F
.68422 .5336 m .66328 .54353 L .6847 .53936 L .658 .807 .955 r
F
.68422 .5336 m .66242 .53491 L .66328 .54353 L F
.66319 .54055 m .66328 .54353 L .66405 .54915 L 0 0 .125 r
F
0 g
.66353 .5439 m
.66673 .54863 L
s
.66319 .54055 m .66242 .53491 L .66328 .54353 L 0 0 .125 r
F
.24762 .66995 m .24825 .66516 L .25846 .66368 L .586 .363 .544 r
F
0 g
.24432 .66518 m
.24825 .66516 L
s
.51247 .67233 m .49523 .6707 L .50772 .67494 L .597 .767 .96 r
F
.5074 .67975 m .49491 .67551 L .49038 .68029 L .597 .767 .961 r
F
0 g
.48874 .68557 m
.49038 .68029 L
s
.45421 .38721 m .48051 .37357 L .45226 .37852 L .658 .778 .938 r
F
.42519 .38778 m .45421 .38721 L .45226 .37852 L F
.62513 .38804 m .62458 .38133 L .64734 .37916 L .667 .434 .559 r
F
.6027 .38677 m .62458 .38133 L .62513 .38804 L .735 .485 .551 r
F
.6027 .38677 m .60219 .38005 L .62458 .38133 L F
.53291 .67644 m .53334 .66944 L .52575 .66947 L .597 .767 .96 r
F
.68706 .40925 m .66714 .41079 L .66777 .41755 L .505 .317 .559 r
F
0 g
.65253 .42805 m
.66777 .41755 L
s
.68706 .40925 m .68639 .40247 L .66714 .41079 L .505 .317 .559 r
F
0 g
.65193 .42131 m
.66714 .41079 L
s
.55811 .67794 m .56445 .67043 L .55371 .67478 L .597 .767 .96 r
F
.55811 .67794 m .57103 .67521 L .56445 .67043 L F
.5747 .68531 m .57103 .67521 L .57079 .68002 L .993 .75 .445 r
F
0 g
.5747 .68531 m
.57567 .69075 L
s
.62653 .36407 m .62461 .38108 L .64726 .37891 L .657 .779 .938 r
F
.61153 .36319 m .62461 .38108 L .62653 .36407 L F
.61153 .36319 m .60233 .3798 L .62461 .38108 L F
.76921 .53995 m .79374 .53271 L .77205 .53402 L .657 .808 .956 r
F
.74896 .53829 m .76921 .53995 L .77205 .53402 L F
.74621 .54114 m .76921 .53995 L .74896 .53829 L F
.259 .53155 m .2523 .51859 L .24815 .52992 L .662 .802 .95 r
F
.259 .53155 m .26868 .52109 L .2523 .51859 L F
.2949 .5432 m .28341 .53119 L .28363 .53682 L .922 .647 .502 r
F
0 g
.2949 .5432 m
.30232 .55088 L
s
.26905 .54571 m .26923 .53221 L .25948 .54268 L .661 .804 .952 r
F
.26905 .54571 m .28363 .53682 L .26923 .53221 L F
.3994 .26463 m .39871 .24037 L .37019 .24138 L .643 .737 .917 r
F
.36705 .40244 m .34027 .41162 L .36827 .40675 L .656 .78 .939 r
F
.36705 .40244 m .33767 .40303 L .34027 .41162 L F
.5253 .68175 m .51832 .67527 L .51217 .67714 L .597 .767 .961 r
F
.52885 .68126 m .51832 .67527 L .5253 .68175 L F
.53985 .68261 m .54061 .67519 L .53639 .68171 L F
.53985 .68261 m .54757 .67701 L .54061 .67519 L F
.42519 .38778 m .45226 .37852 L .42414 .38345 L .658 .778 .938 r
F
.64793 .38587 m .64734 .37916 L .66907 .37365 L .592 .379 .561 r
F
.62513 .38804 m .64734 .37916 L .64793 .38587 L .667 .434 .559 r
F
0 g
.62458 .38133 m
.64734 .37916 L
s
.6418 .3626 m .64726 .37891 L .66888 .37343 L .657 .779 .938 r
F
.62653 .36407 m .64726 .37891 L .6418 .3626 L F
.79278 .5271 m .79182 .5215 L .79179 .51273 L 0 0 .246 r
F
0 g
.78898 .52733 m
.79182 .5215 L
s
.76998 .52281 m .7915 .52152 L .79146 .51279 L .658 .806 .954 r
F
.20675 .54378 m .18972 .53672 L .18051 .54436 L .661 .803 .951 r
F
.21526 .53966 m .18972 .53672 L .20675 .54378 L F
.51288 .66758 m .50282 .66202 L .49575 .66596 L .598 .766 .96 r
F
.51899 .66572 m .50282 .66202 L .51288 .66758 L F
.18972 .53672 m .18043 .53874 L .18051 .54436 L .296 .151 .509 r
F
.18972 .53672 m .18963 .53109 L .18043 .53874 L F
0 g
.17542 .54723 m
.18043 .53874 L
s
.55386 .67002 m .55575 .66179 L .54802 .66744 L .598 .766 .96 r
F
.55386 .67002 m .56453 .66568 L .55575 .66179 L F
.52885 .68126 m .52546 .67429 L .51832 .67527 L .597 .767 .961 r
F
.53263 .68125 m .52546 .67429 L .52885 .68126 L F
.53639 .68171 m .53306 .67426 L .53263 .68125 L F
.53639 .68171 m .54061 .67519 L .53306 .67426 L F
.24762 .66995 m .25846 .66368 L .25784 .66848 L .586 .363 .544 r
F
.24698 .67475 m .24762 .66995 L .25784 .66848 L F
.24277 .66292 m .24762 .66995 L .25784 .66848 L .596 .768 .962 r
F
0 g
.24366 .66997 m
.24762 .66995 L
s
.77367 .4007 m .77285 .39396 L .75285 .38933 L .805 .535 .53 r
F
0 g
.77285 .39396 m
.7891 .40156 L
s
.59201 .25751 m .55712 .26818 L .59278 .26382 L .644 .737 .917 r
F
.59201 .25751 m .55534 .25559 L .55712 .26818 L F
.51217 .67714 m .49491 .67551 L .5074 .67975 L .597 .767 .961 r
F
.48392 .39334 m .48094 .3735 L .48123 .38025 L .851 .644 .104 r
F
.45473 .39392 m .48392 .39334 L .48123 .38025 L .657 .779 .939 r
F
.48421 .40008 m .48392 .39334 L .48123 .38025 L .851 .644 .104 r
F
0 g
.48221 .40012 m
.48346 .39514 L
s
.53263 .68125 m .53306 .67426 L .52546 .67429 L .597 .767 .961 r
F
.70599 .5323 m .6847 .53936 L .70618 .53519 L .658 .807 .955 r
F
.70599 .5323 m .68422 .5336 L .6847 .53936 L F
.68502 .53924 m .66405 .54915 L .6855 .54499 L .657 .808 .956 r
F
.68502 .53924 m .66319 .54055 L .66405 .54915 L F
0 g
.66405 .54915 m
.66925 .55681 L
s
.55786 .68275 m .5642 .67526 L .55346 .67959 L .597 .767 .961 r
F
.55786 .68275 m .57079 .68002 L .5642 .67526 L F
.69788 .27554 m .73875 .26517 L .70206 .26326 L .644 .737 .917 r
F
.6634 .26751 m .69788 .27554 L .70206 .26326 L F
.65909 .27309 m .69788 .27554 L .6634 .26751 L F
.50235 .66674 m .49556 .6659 L .49523 .6707 L .338 .163 .491 r
F
.50235 .66674 m .50267 .66193 L .49556 .6659 L F
0 g
.49105 .67071 m
.49556 .6659 L
s
.20442 .66197 m .21478 .66108 L .21411 .66587 L .849 .609 .575 r
F
.20442 .66197 m .20511 .65717 L .21478 .66108 L F
0 g
.21478 .66108 m
.21836 .66198 L
s
.25784 .66848 m .25846 .66368 L .26703 .66085 L .47 .261 .514 r
F
0 g
.24867 .6651 m
.25846 .66368 L
s
.76998 .52281 m .79146 .51279 L .76987 .517 L .658 .806 .954 r
F
.74844 .52409 m .76998 .52281 L .76987 .517 L F
.42476 .40561 m .45497 .40067 L .4257 .40126 L .656 .78 .939 r
F
.57103 .67521 m .57126 .6704 L .56469 .66562 L .935 .679 .526 r
F
0 g
.57126 .6704 m
.57515 .67571 L
s
.58203 .3821 m .60219 .38005 L .6027 .38677 L .802 .537 .537 r
F
.58203 .3821 m .58156 .37537 L .60219 .38005 L F
0 g
.60219 .38005 m
.62458 .38133 L
s
.21527 .53413 m .20261 .52497 L .18989 .53119 L .662 .802 .95 r
F
.22547 .53126 m .20261 .52497 L .21527 .53413 L F
.59774 .36001 m .60233 .3798 L .61153 .36319 L .657 .779 .938 r
F
.59774 .36001 m .5818 .37514 L .60233 .3798 L F
0 g
.23579 .67479 m
.23707 .67479 L
s
.23485 .67468 m
.23579 .67479 L
s
.36782 .38456 m .33792 .38951 L .36704 .38893 L .658 .778 .938 r
F
.45473 .39392 m .48123 .38025 L .45278 .38522 L .657 .779 .939 r
F
.42552 .39451 m .45473 .39392 L .45278 .38522 L F
.62568 .39478 m .62513 .38804 L .64793 .38587 L .667 .434 .559 r
F
.60321 .39351 m .62513 .38804 L .62568 .39478 L .735 .485 .551 r
F
.60321 .39351 m .6027 .38677 L .62513 .38804 L F
.62707 .37099 m .62513 .38804 L .64793 .38587 L .657 .779 .939 r
F
.61197 .37012 m .62513 .38804 L .62707 .37099 L F
.61197 .37012 m .6027 .38677 L .62513 .38804 L F
.25929 .53706 m .25254 .52407 L .24836 .53543 L .661 .803 .951 r
F
.25929 .53706 m .26903 .52656 L .25254 .52407 L F
.34299 .25569 m .322 .25768 L .32097 .26602 L .432 .209 .474 r
F
0 g
.30474 .27993 m
.32097 .26602 L
s
.34299 .25569 m .34398 .24732 L .322 .25768 L .432 .209 .474 r
F
0 g
.30581 .27161 m
.322 .25768 L
s
.74844 .52409 m .76987 .517 L .74833 .5212 L .658 .806 .954 r
F
.47665 .26576 m .4547 .24473 L .45401 .25307 L .87 .6 .526 r
F
.47602 .27413 m .47665 .26576 L .45401 .25307 L F
0 g
.47665 .26576 m
.49369 .28144 L
s
.51247 .67233 m .50235 .66674 L .49523 .6707 L .597 .767 .96 r
F
.51862 .67046 m .50235 .66674 L .51247 .67233 L F
.37975 .27362 m .36928 .24977 L .34299 .25569 L .643 .738 .918 r
F
.39857 .27298 m .36928 .24977 L .37975 .27362 L F
.41749 .27559 m .39787 .24877 L .39857 .27298 L F
.41749 .27559 m .42661 .25277 L .39787 .24877 L F
.79278 .5271 m .79179 .51273 L .79275 .51835 L 0 0 .246 r
F
.79374 .53271 m .79278 .5271 L .79275 .51835 L F
.77112 .5284 m .79278 .5271 L .79275 .51835 L .658 .807 .955 r
F
0 g
.78991 .53294 m
.79278 .5271 L
s
.55371 .67478 m .55562 .66653 L .54783 .67219 L .597 .767 .96 r
F
.55371 .67478 m .56445 .67043 L .55562 .66653 L F
.24815 .52992 m .23499 .51843 L .2367 .52982 L .662 .802 .95 r
F
.24815 .52992 m .2523 .51859 L .23499 .51843 L F
.21964 .665 m .21343 .67068 L .22435 .67341 L .595 .768 .962 r
F
0 g
.21835 .67191 m
.22435 .67341 L
s
.22435 .67341 m
.22592 .6736 L
s
.20686 .54941 m .18981 .54238 L .18058 .55 L .661 .804 .952 r
F
.21539 .5453 m .18981 .54238 L .20686 .54941 L F
.18981 .54238 m .18051 .54436 L .18058 .55 L .296 .151 .509 r
F
0 g
.17555 .55845 m
.18058 .55 L
s
.18981 .54238 m .18972 .53672 L .18051 .54436 L .296 .151 .509 r
F
0 g
.17549 .55283 m
.18051 .54436 L
s
.24698 .67475 m .25784 .66848 L .25721 .67328 L .586 .363 .544 r
F
.24212 .66774 m .24698 .67475 L .25721 .67328 L .595 .768 .962 r
F
0 g
.23707 .67479 m
.24698 .67475 L
s
.33931 .38074 m .30876 .39009 L .33792 .38951 L .658 .778 .938 r
F
.36782 .38456 m .33931 .38074 L .33792 .38951 L F
.42552 .39451 m .45278 .38522 L .42446 .39016 L .657 .779 .939 r
F
.64793 .38587 m .66907 .37365 L .6697 .38037 L .592 .379 .561 r
F
.64853 .39261 m .64793 .38587 L .6697 .38037 L F
.62568 .39478 m .64793 .38587 L .64853 .39261 L .667 .434 .559 r
F
.64244 .36952 m .64793 .38587 L .6697 .38037 L .657 .779 .939 r
F
.62707 .37099 m .64793 .38587 L .64244 .36952 L F
0 g
.62513 .38804 m
.64793 .38587 L
s
.50203 .67156 m .49523 .6707 L .49491 .67551 L .338 .163 .491 r
F
.50203 .67156 m .50235 .66674 L .49523 .6707 L F
0 g
.49071 .67549 m
.49523 .6707 L
s
.55975 .22647 m .52025 .23707 L .55654 .23896 L .645 .736 .915 r
F
.55975 .22647 m .5247 .21825 L .52025 .23707 L F
.52366 .22646 m .5197 .23704 L .51918 .24533 L 0 0 .103 r
F
0 g
.52028 .2407 m
.52103 .24543 L
s
.52366 .22646 m .52417 .21813 L .5197 .23704 L 0 0 .103 r
F
.51899 .66572 m .51201 .65919 L .50282 .66202 L .598 .766 .96 r
F
.52607 .66473 m .51201 .65919 L .51899 .66572 L F
.20372 .66678 m .21411 .66587 L .21343 .67068 L .849 .609 .575 r
F
.20372 .66678 m .20442 .66197 L .21411 .66587 L F
.21384 .65756 m .21411 .66587 L .22032 .66018 L .596 .768 .962 r
F
.21384 .65756 m .20442 .66197 L .21411 .66587 L F
0 g
.21411 .66587 m
.2177 .66677 L
s
.59456 .23464 m .55654 .23896 L .59284 .24086 L .645 .736 .915 r
F
.59456 .23464 m .55975 .22647 L .55654 .23896 L F
.54802 .66744 m .54535 .65904 L .54111 .66563 L .598 .766 .96 r
F
.54802 .66744 m .55575 .66179 L .54535 .65904 L F
.25784 .66848 m .26703 .66085 L .26642 .66566 L .47 .261 .514 r
F
.25721 .67328 m .25784 .66848 L .26642 .66566 L F
.24961 .66193 m .25784 .66848 L .26642 .66566 L .596 .768 .962 r
F
.24277 .66292 m .25784 .66848 L .24961 .66193 L F
0 g
.24799 .6699 m
.25784 .66848 L
s
.70682 .53793 m .6855 .54499 L .70702 .54081 L .657 .808 .956 r
F
.70682 .53793 m .68502 .53924 L .6855 .54499 L F
.57103 .67521 m .56469 .66562 L .56445 .67043 L .935 .679 .526 r
F
.57079 .68002 m .57103 .67521 L .56445 .67043 L F
0 g
.57103 .67521 m
.57492 .6805 L
s
.66545 .24465 m .70097 .23385 L .66493 .23831 L .645 .736 .915 r
F
.66545 .24465 m .70176 .24654 L .70097 .23385 L F
.28341 .53119 m .28318 .52557 L .26883 .52093 L .857 .591 .537 r
F
0 g
.28318 .52557 m
.29443 .532 L
s
.70176 .24654 m .73725 .22935 L .70097 .23385 L .645 .736 .915 r
F
.70176 .24654 m .73807 .24844 L .73725 .22935 L F
.73868 .2568 m .73862 .24847 L .7378 .22928 L .746 .597 .026 r
F
0 g
.7357 .25664 m
.73843 .24899 L
s
.77112 .5284 m .79275 .51835 L .77101 .52258 L .658 .807 .955 r
F
.74944 .5297 m .77112 .5284 L .77101 .52258 L F
.70832 .397 m .68573 .39571 L .68639 .40247 L .594 .381 .562 r
F
.70832 .397 m .70761 .39024 L .68573 .39571 L F
0 g
.66652 .40404 m
.68573 .39571 L
s
.74896 .53829 m .77205 .53402 L .75034 .53532 L .657 .808 .956 r
F
.77367 .4007 m .75285 .38933 L .75364 .39609 L .805 .535 .53 r
F
.7745 .40747 m .77367 .4007 L .75364 .39609 L F
0 g
.77367 .4007 m
.78995 .40828 L
s
.22547 .53126 m .21801 .5206 L .20261 .52497 L .662 .802 .95 r
F
.2367 .52982 m .21801 .5206 L .22547 .53126 L F
.33931 .38074 m .31061 .37689 L .30876 .39009 L .658 .778 .938 r
F
.31015 .38361 m .30832 .3901 L .30829 .39684 L 0 0 .111 r
F
0 g
.30896 .39209 m
.31046 .3968 L
s
.31015 .38361 m .31018 .37683 L .30832 .3901 L 0 0 .111 r
F
.48421 .40008 m .48123 .38025 L .48151 .38702 L .851 .644 .104 r
F
.45497 .40067 m .48421 .40008 L .48151 .38702 L .656 .78 .939 r
F
0 g
.48093 .41305 m
.48421 .40008 L
s
.39857 .27298 m .39787 .24877 L .36928 .24977 L .643 .738 .918 r
F
.2367 .52982 m .23499 .51843 L .21801 .5206 L .662 .802 .95 r
F
.21526 .53966 m .20252 .53048 L .18972 .53672 L .661 .803 .951 r
F
.22553 .53678 m .20252 .53048 L .21526 .53966 L F
.25948 .54268 m .25272 .52973 L .24853 .54106 L .661 .804 .952 r
F
.25948 .54268 m .26923 .53221 L .25272 .52973 L F
.42414 .38345 m .44643 .37042 L .42116 .37943 L .658 .778 .938 r
F
.42414 .38345 m .45226 .37852 L .44643 .37042 L F
.58251 .38886 m .6027 .38677 L .60321 .39351 L .802 .537 .537 r
F
.58251 .38886 m .58203 .3821 L .6027 .38677 L F
.59808 .36694 m .6027 .38677 L .61197 .37012 L .657 .779 .939 r
F
.59808 .36694 m .58203 .3821 L .6027 .38677 L F
0 g
.6027 .38677 m
.62513 .38804 L
s
.6697 .38037 m .66907 .37365 L .68839 .36513 L .502 .314 .557 r
F
0 g
.65914 .37617 m
.66907 .37365 L
s
.51217 .67714 m .50203 .67156 L .49491 .67551 L .597 .767 .961 r
F
0 g
.49038 .68029 m
.49491 .67551 L
s
.51832 .67527 m .50203 .67156 L .51217 .67714 L .597 .767 .961 r
F
.70654 .52369 m .68363 .52796 L .70526 .52667 L .658 .806 .954 r
F
.55346 .67959 m .55536 .67136 L .54757 .67701 L .597 .767 .961 r
F
.55346 .67959 m .5642 .67526 L .55536 .67136 L F
.65634 .35888 m .66888 .37343 L .68811 .36495 L .657 .779 .938 r
F
.6418 .3626 m .66888 .37343 L .65634 .35888 L F
.74944 .5297 m .77101 .52258 L .74934 .52679 L .658 .807 .955 r
F
.36775 .39129 m .33765 .39626 L .36697 .39567 L .657 .779 .939 r
F
.45497 .40067 m .48151 .38702 L .45301 .39199 L .656 .78 .939 r
F
.4257 .40126 m .45497 .40067 L .45301 .39199 L F
.62763 .37777 m .62568 .39478 L .64853 .39261 L .656 .78 .94 r
F
.6125 .3769 m .62568 .39478 L .62763 .37777 L F
.6125 .3769 m .60321 .39351 L .62568 .39478 L F
.52607 .66473 m .52267 .6577 L .51201 .65919 L .598 .766 .96 r
F
.53362 .6647 m .52267 .6577 L .52607 .66473 L F
.79374 .53271 m .79275 .51835 L .79371 .52398 L 0 0 .246 r
F
.77205 .53402 m .79374 .53271 L .79371 .52398 L .657 .808 .956 r
F
0 g
.78936 .5416 m
.79374 .53271 L
s
.54111 .66563 m .53406 .65764 L .53362 .6647 L .598 .766 .96 r
F
.54111 .66563 m .54535 .65904 L .53406 .65764 L F
.24836 .53543 m .23512 .5239 L .23684 .53533 L .661 .803 .951 r
F
.24836 .53543 m .25254 .52407 L .23512 .5239 L F
.21316 .66239 m .21343 .67068 L .21964 .665 L .595 .768 .962 r
F
.21316 .66239 m .20372 .66678 L .21343 .67068 L F
0 g
.21343 .67068 m
.21835 .67191 L
s
.51862 .67046 m .5116 .66391 L .50235 .66674 L .597 .767 .96 r
F
.52575 .66947 m .5116 .66391 L .51862 .67046 L F
.1966 .65714 m .20511 .65717 L .20442 .66197 L .909 .672 .567 r
F
.1966 .65714 m .1973 .65233 L .20511 .65717 L F
0 g
.20511 .65717 m
.21024 .65924 L
s
.54783 .67219 m .54515 .66377 L .54088 .67037 L .597 .767 .96 r
F
.54783 .67219 m .55562 .66653 L .54515 .66377 L F
.25721 .67328 m .26642 .66566 L .26581 .67048 L .47 .261 .514 r
F
.24897 .66675 m .25721 .67328 L .26581 .67048 L .595 .768 .962 r
F
.24212 .66774 m .25721 .67328 L .24897 .66675 L F
0 g
.24698 .67475 m
.25721 .67328 L
s
.57079 .68002 m .56445 .67043 L .5642 .67526 L .935 .679 .526 r
F
0 g
.57079 .68002 m
.5747 .68531 L
s
.26642 .66566 m .26703 .66085 L .2734 .65686 L .275 .097 .449 r
F
0 g
.25846 .66368 m
.26703 .66085 L
s
.53362 .6647 m .53406 .65764 L .52267 .6577 L .598 .766 .96 r
F
.68611 .52199 m .66198 .52926 L .68363 .52796 L .658 .806 .954 r
F
.70654 .52369 m .68611 .52199 L .68363 .52796 L F
.33905 .38746 m .30829 .39684 L .33765 .39626 L .657 .779 .939 r
F
.36775 .39129 m .33905 .38746 L .33765 .39626 L F
.74833 .5212 m .7668 .51172 L .74676 .51857 L .658 .806 .954 r
F
.74833 .5212 m .76987 .517 L .7668 .51172 L F
.4257 .40126 m .45301 .39199 L .42464 .39693 L .656 .78 .939 r
F
.28341 .53119 m .26883 .52093 L .26903 .52656 L .857 .591 .537 r
F
.28363 .53682 m .28341 .53119 L .26903 .52656 L F
0 g
.28341 .53119 m
.29467 .53759 L
s
.64853 .39261 m .6697 .38037 L .67034 .38712 L .592 .379 .561 r
F
.64303 .3763 m .64853 .39261 L .67034 .38712 L .656 .78 .94 r
F
.62763 .37777 m .64853 .39261 L .64303 .3763 L F
0 g
.62568 .39478 m
.64853 .39261 L
s
.77205 .53402 m .79371 .52398 L .77194 .52821 L .657 .808 .956 r
F
.75034 .53532 m .77205 .53402 L .77194 .52821 L F
.22553 .53678 m .21803 .5261 L .20252 .53048 L .661 .803 .951 r
F
.23684 .53533 m .21803 .5261 L .22553 .53678 L F
.37054 .38042 m .33931 .38074 L .36782 .38456 L .658 .778 .938 r
F
.21539 .5453 m .20263 .53614 L .18981 .54238 L .661 .804 .952 r
F
.22567 .54242 m .20263 .53614 L .21539 .5453 L F
.6634 .26751 m .70206 .26326 L .66537 .26134 L .644 .737 .917 r
F
.23684 .53533 m .23512 .5239 L .21803 .5261 L .661 .803 .951 r
F
.5116 .66391 m .50267 .66193 L .50235 .66674 L .491 .288 .532 r
F
.5116 .66391 m .51191 .65909 L .50267 .66193 L F
0 g
.49556 .6659 m
.50267 .66193 L
s
.68611 .52199 m .66557 .52027 L .66198 .52926 L .658 .806 .954 r
F
.66604 .5259 m .66165 .52928 L .66242 .53491 L 0 0 .429 r
F
.66604 .5259 m .66526 .52025 L .66165 .52928 L F
0 g
.66165 .52928 m
.66251 .53792 L
s
.70903 .4038 m .68639 .40247 L .68706 .40925 L .594 .381 .562 r
F
0 g
.66777 .41755 m
.68706 .40925 L
s
.70903 .4038 m .70832 .397 L .68639 .40247 L .594 .381 .562 r
F
0 g
.66714 .41079 m
.68639 .40247 L
s
.75364 .39609 m .75285 .38933 L .73056 .38805 L .735 .484 .549 r
F
0 g
.75285 .38933 m
.77285 .39396 L
s
.7745 .40747 m .75364 .39609 L .75443 .40288 L .805 .535 .53 r
F
0 g
.7745 .40747 m
.7908 .41503 L
s
.47602 .27413 m .45401 .25307 L .45332 .26146 L .87 .6 .526 r
F
0 g
.47602 .27413 m
.49311 .28978 L
s
.56445 .67043 m .56469 .66562 L .55587 .6617 L .863 .609 .554 r
F
0 g
.56469 .66562 m
.57126 .6704 L
s
.33905 .38746 m .31015 .38361 L .30829 .39684 L .657 .779 .939 r
F
.31012 .39042 m .30829 .39684 L .30826 .40362 L 0 0 .111 r
F
0 g
.30893 .39885 m
.31044 .40357 L
s
.31012 .39042 m .31015 .38361 L .30829 .39684 L 0 0 .111 r
F
.70728 .52931 m .68422 .5336 L .70599 .5323 L .658 .807 .955 r
F
.52575 .66947 m .52233 .66241 L .5116 .66391 L .597 .767 .96 r
F
.53334 .66944 m .52233 .66241 L .52575 .66947 L F
.54088 .67037 m .53378 .66236 L .53334 .66944 L F
.54088 .67037 m .54515 .66377 L .53378 .66236 L F
.75034 .53532 m .77194 .52821 L .75024 .53242 L .657 .808 .956 r
F
.51832 .67527 m .51129 .66874 L .50203 .67156 L .597 .767 .961 r
F
.52546 .67429 m .51129 .66874 L .51832 .67527 L F
.19589 .66196 m .20442 .66197 L .20372 .66678 L .909 .672 .567 r
F
.19589 .66196 m .1966 .65714 L .20442 .66197 L F
.20864 .65432 m .20442 .66197 L .21384 .65756 L .596 .768 .962 r
F
.20864 .65432 m .1966 .65714 L .20442 .66197 L F
0 g
.20442 .66197 m
.20959 .66405 L
s
.54757 .67701 m .54488 .66861 L .54061 .67519 L .597 .767 .961 r
F
.54757 .67701 m .55536 .67136 L .54488 .66861 L F
.42446 .39016 m .44691 .37709 L .42146 .38614 L .657 .779 .939 r
F
.42446 .39016 m .45278 .38522 L .44691 .37709 L F
.24853 .54106 m .23527 .52957 L .23699 .54097 L .661 .804 .952 r
F
.24853 .54106 m .25272 .52973 L .23527 .52957 L F
.55898 .23472 m .51918 .24533 L .55576 .24724 L .644 .736 .916 r
F
.55898 .23472 m .52366 .22646 L .51918 .24533 L F
.52315 .23483 m .51918 .24533 L .51867 .25367 L 0 0 .103 r
F
0 g
.51977 .24902 m
.52053 .25377 L
s
.52315 .23483 m .52366 .22646 L .51918 .24533 L 0 0 .103 r
F
.56444 .3743 m .58156 .37537 L .58203 .3821 L .873 .594 .511 r
F
.56444 .3743 m .564 .36754 L .58156 .37537 L F
0 g
.58156 .37537 m
.58769 .37676 L
s
.59859 .37373 m .60321 .39351 L .6125 .3769 L .656 .78 .94 r
F
.59859 .37373 m .58251 .38886 L .60321 .39351 L F
0 g
.60321 .39351 m
.62568 .39478 L
s
.64244 .36952 m .6697 .38037 L .65708 .36579 L .657 .779 .939 r
F
.6697 .38037 m .68839 .36513 L .68907 .37186 L .502 .314 .557 r
F
.67034 .38712 m .6697 .38037 L .68907 .37186 L F
.65708 .36579 m .6697 .38037 L .68907 .37186 L .657 .779 .939 r
F
0 g
.65969 .3829 m
.6697 .38037 L
s
.59407 .24292 m .55576 .24724 L .59234 .24915 L .644 .736 .916 r
F
.59407 .24292 m .55898 .23472 L .55576 .24724 L F
.26642 .66566 m .2734 .65686 L .27279 .66167 L .275 .097 .449 r
F
.26581 .67048 m .26642 .66566 L .27279 .66167 L F
.25534 .66003 m .26642 .66566 L .27279 .66167 L .596 .768 .962 r
F
.24961 .66193 m .26642 .66566 L .25534 .66003 L F
0 g
.25784 .66848 m
.26642 .66566 L
s
.53334 .66944 m .53378 .66236 L .52233 .66241 L .597 .767 .96 r
F
.58607 .35473 m .5818 .37514 L .59774 .36001 L .657 .779 .938 r
F
.58607 .35473 m .56433 .36736 L .5818 .37514 L F
.6655 .25298 m .7013 .24215 L .66498 .24662 L .644 .736 .916 r
F
.6655 .25298 m .70209 .25489 L .7013 .24215 L F
.36783 .39806 m .33767 .40303 L .36705 .40244 L .656 .78 .939 r
F
.70209 .25489 m .73786 .23764 L .7013 .24215 L .644 .736 .916 r
F
.70209 .25489 m .73868 .2568 L .73786 .23764 L F
.70922 .52081 m .68611 .52199 L .70654 .52369 L .658 .806 .954 r
F
.73868 .2568 m .7378 .22928 L .73786 .23764 L .746 .597 .026 r
F
.73875 .26517 m .73868 .2568 L .73786 .23764 L F
0 g
.73573 .26502 m
.7385 .25732 L
s
.68671 .52761 m .66242 .53491 L .68422 .5336 L .658 .807 .955 r
F
.70728 .52931 m .68671 .52761 L .68422 .5336 L F
.45226 .37852 m .47195 .36132 L .44643 .37042 L .658 .778 .938 r
F
.45226 .37852 m .48051 .37357 L .47195 .36132 L F
.37019 .24138 m .34496 .23899 L .34398 .24732 L .563 .321 .507 r
F
.37019 .24138 m .37111 .23304 L .34496 .23899 L F
0 g
.32304 .24938 m
.34496 .23899 L
s
.3936 .51851 m .39322 .5129 L .41025 .51072 L .669 .441 .566 r
F
.37645 .51835 m .39322 .5129 L .3936 .51851 L .734 .491 .56 r
F
.37645 .51835 m .37609 .51273 L .39322 .5129 L F
.20252 .53048 m .18963 .53109 L .18972 .53672 L .477 .29 .547 r
F
.20252 .53048 m .20242 .52483 L .18963 .53109 L F
0 g
.18043 .53874 m
.18963 .53109 L
s
.74934 .52679 m .76793 .51728 L .74776 .52416 L .658 .807 .955 r
F
.74934 .52679 m .77101 .52258 L .76793 .51728 L F
.76987 .517 m .78697 .50482 L .7668 .51172 L .658 .806 .954 r
F
.76987 .517 m .79146 .51279 L .78697 .50482 L F
.39278 .50117 m .39321 .51273 L .41016 .51056 L .662 .803 .95 r
F
.38133 .50104 m .39321 .51273 L .39278 .50117 L F
.38133 .50104 m .37617 .51255 L .39321 .51273 L F
.28363 .53682 m .26903 .52656 L .26923 .53221 L .857 .591 .537 r
F
0 g
.28363 .53682 m
.2949 .5432 L
s
.73131 .39482 m .70761 .39024 L .70832 .397 L .667 .434 .559 r
F
.73131 .39482 m .73056 .38805 L .70761 .39024 L F
0 g
.68573 .39571 m
.70761 .39024 L
s
.45401 .25307 m .4547 .24473 L .42814 .23602 L .802 .535 .534 r
F
0 g
.4547 .24473 m
.47727 .25744 L
s
.41065 .51633 m .41025 .51072 L .42609 .50632 L .593 .384 .567 r
F
.3936 .51851 m .41025 .51072 L .41065 .51633 L .669 .441 .566 r
F
0 g
.39322 .5129 m
.41025 .51072 L
s
.22567 .54242 m .21816 .53177 L .20263 .53614 L .661 .804 .952 r
F
.23699 .54097 m .21816 .53177 L .22567 .54242 L F
.51129 .66874 m .50235 .66674 L .50203 .67156 L .491 .288 .532 r
F
0 g
.49491 .67551 m
.50203 .67156 L
s
.51129 .66874 m .5116 .66391 L .50235 .66674 L .491 .288 .532 r
F
0 g
.49523 .6707 m
.50235 .66674 L
s
.40416 .49971 m .41016 .51056 L .42592 .50618 L .662 .803 .95 r
F
.39278 .50117 m .41016 .51056 L .40416 .49971 L F
.42116 .37943 m .43707 .36347 L .41645 .376 L .658 .778 .938 r
F
.42116 .37943 m .44643 .37042 L .43707 .36347 L F
.59866 .22894 m .55975 .22647 L .59456 .23464 L .645 .736 .915 r
F
.56445 .67043 m .55587 .6617 L .55562 .66653 L .863 .609 .554 r
F
.5642 .67526 m .56445 .67043 L .55562 .66653 L F
0 g
.56445 .67043 m
.57103 .67521 L
s
.33907 .39425 m .30826 .40362 L .33767 .40303 L .656 .78 .939 r
F
.36783 .39806 m .33907 .39425 L .33767 .40303 L F
.23699 .54097 m .23527 .52957 L .21816 .53177 L .661 .804 .952 r
F
.66493 .23831 m .69521 .22159 L .66196 .23224 L .645 .736 .915 r
F
.66493 .23831 m .70097 .23385 L .69521 .22159 L F
.68671 .52761 m .66604 .5259 L .66242 .53491 L .658 .807 .955 r
F
.66682 .53157 m .66242 .53491 L .66319 .54055 L 0 0 .429 r
F
.66682 .53157 m .66604 .5259 L .66242 .53491 L F
0 g
.66242 .53491 m
.66328 .54353 L
s
.52546 .67429 m .52203 .66725 L .51129 .66874 L .597 .767 .961 r
F
.53306 .67426 m .52203 .66725 L .52546 .67429 L F
.54061 .67519 m .5335 .6672 L .53306 .67426 L F
.54061 .67519 m .54488 .66861 L .5335 .6672 L F
.74676 .51857 m .76095 .50734 L .74382 .51641 L .658 .806 .954 r
F
.74676 .51857 m .7668 .51172 L .76095 .50734 L F
.70812 .53495 m .68502 .53924 L .70682 .53793 L .657 .808 .956 r
F
.75364 .39609 m .73056 .38805 L .73131 .39482 L .735 .484 .549 r
F
0 g
.70761 .39024 m
.73056 .38805 L
s
.73056 .38805 m
.75285 .38933 L
s
.37049 .38714 m .33905 .38746 L .36775 .39129 L .657 .779 .939 r
F
.20795 .65916 m .20372 .66678 L .21316 .66239 L .595 .768 .962 r
F
.20795 .65916 m .19589 .66196 L .20372 .66678 L F
0 g
.20372 .66678 m
.21343 .67068 L
s
.26581 .67048 m .27279 .66167 L .27218 .6665 L .275 .097 .449 r
F
.25471 .66486 m .26581 .67048 L .27218 .6665 L .595 .768 .962 r
F
.24897 .66675 m .26581 .67048 L .25471 .66486 L F
0 g
.25721 .67328 m
.26581 .67048 L
s
.53306 .67426 m .5335 .6672 L .52203 .66725 L .597 .767 .961 r
F
.75443 .40288 m .75364 .39609 L .73131 .39482 L .735 .484 .549 r
F
0 g
.75364 .39609 m
.77367 .4007 L
s
.33907 .39425 m .31012 .39042 L .30826 .40362 L .656 .78 .939 r
F
0 g
.30826 .40362 m
.31239 .41648 L
s
.36027 .51583 m .37609 .51273 L .37645 .51835 L .797 .539 .549 r
F
.36027 .51583 m .35994 .5102 L .37609 .51273 L F
0 g
.37609 .51273 m
.39322 .5129 L
s
.70997 .52642 m .68671 .52761 L .70728 .52931 L .658 .807 .955 r
F
.68753 .53326 m .66319 .54055 L .68502 .53924 L .657 .808 .956 r
F
.70812 .53495 m .68753 .53326 L .68502 .53924 L F
.39399 .52414 m .3936 .51851 L .41065 .51633 L .669 .441 .566 r
F
.37681 .52398 m .3936 .51851 L .39399 .52414 L .734 .491 .56 r
F
.37681 .52398 m .37645 .51835 L .3936 .51851 L F
.39317 .50692 m .3936 .51851 L .41065 .51633 L .661 .803 .951 r
F
.38164 .5068 m .3936 .51851 L .39317 .50692 L F
.38164 .5068 m .37645 .51835 L .3936 .51851 L F
.37055 .49932 m .37617 .51255 L .38133 .50104 L .662 .803 .95 r
F
.37055 .49932 m .3601 .51004 L .37617 .51255 L F
.20263 .53614 m .18972 .53672 L .18981 .54238 L .477 .29 .547 r
F
0 g
.18058 .55 m
.18981 .54238 L
s
.20263 .53614 m .20252 .53048 L .18972 .53672 L .477 .29 .547 r
F
0 g
.18051 .54436 m
.18972 .53672 L
s
.42464 .39693 m .44714 .38388 L .42164 .39291 L .656 .78 .939 r
F
.42464 .39693 m .45301 .39199 L .44714 .38388 L F
.37054 .38042 m .34464 .3724 L .33931 .38074 L .658 .778 .938 r
F
.37503 .37681 m .34464 .3724 L .37054 .38042 L F
.56489 .38109 m .58203 .3821 L .58251 .38886 L .873 .594 .511 r
F
.56489 .38109 m .56444 .3743 L .58203 .3821 L F
.58633 .36164 m .58203 .3821 L .59808 .36694 L .657 .779 .939 r
F
.58633 .36164 m .56444 .3743 L .58203 .3821 L F
0 g
.58203 .3821 m
.58821 .3835 L
s
.67034 .38712 m .68907 .37186 L .68974 .37863 L .502 .314 .557 r
F
.6577 .37257 m .67034 .38712 L .68974 .37863 L .656 .78 .94 r
F
.64303 .3763 m .67034 .38712 L .6577 .37257 L F
0 g
.64853 .39261 m
.67034 .38712 L
s
.26903 .52656 m .26883 .52093 L .25236 .51842 L .795 .541 .553 r
F
0 g
.26883 .52093 m
.28318 .52557 L
s
.75024 .53242 m .76886 .52293 L .74865 .5298 L .657 .808 .956 r
F
.75024 .53242 m .77194 .52821 L .76886 .52293 L F
.77101 .52258 m .78824 .51036 L .76793 .51728 L .658 .807 .955 r
F
.77101 .52258 m .79275 .51835 L .78824 .51036 L F
.79275 .51835 m .79179 .51273 L .78728 .50471 L .929 .624 .156 r
F
0 g
.7918 .51599 m
.7918 .51667 L
s
.19118 .6517 m .1973 .65233 L .1966 .65714 L .971 .745 .539 r
F
.19118 .6517 m .1919 .64688 L .1973 .65233 L F
0 g
.1973 .65233 m
.20274 .6557 L
s
.52233 .66241 m .51191 .65909 L .5116 .66391 L .592 .372 .551 r
F
.52233 .66241 m .52262 .65759 L .51191 .65909 L F
0 g
.50267 .66193 m
.51191 .65909 L
s
.20589 .64585 m .19748 .65229 L .20945 .64948 L .597 .767 .961 r
F
.20589 .64585 m .1921 .64686 L .19748 .65229 L F
.72701 .54901 m .72881 .54928 L .73338 .6205 L .753 .483 .523 r
F
.73547 .62085 m .73297 .62527 L .73687 .62524 L .601 .765 .958 r
F
.73513 .62079 m .73297 .62527 L .73547 .62085 L F
.73511 .62079 m .73297 .62527 L .73513 .62079 L F
.7339 .62076 m .73297 .62527 L .7353 .6204 L F
.72701 .54901 m .73326 .62048 L .73153 .62018 L .753 .483 .523 r
F
.72701 .54901 m .73338 .6205 L .73326 .62048 L F
.72881 .54928 m .73519 .6204 L .73338 .6205 L .638 .394 .533 r
F
.72522 .54792 m .72592 .54853 L .73042 .61971 L .947 .644 .431 r
F
.7336 .62222 m .72917 .62479 L .73297 .62527 L .601 .765 .958 r
F
.73303 .62177 m .72917 .62479 L .7336 .62222 L F
.73242 .62056 m .73207 .62101 L .73382 .62115 L F
.72486 .54721 m .72522 .54792 L .7297 .61914 L .965 .686 .26 r
F
.73131 .622 m .72917 .62479 L .73174 .62277 L .601 .765 .958 r
F
.72592 .54853 m .72701 .54901 L .73153 .62018 L .857 .566 .495 r
F
.72592 .54853 m .73153 .62018 L .73146 .62015 L F
.73131 .622 m .72907 .62274 L .72917 .62479 L .601 .765 .958 r
F
.72907 .62274 m .72574 .62383 L .72894 .62472 L F
.72907 .62274 m .72894 .62472 L .72917 .62479 L F
.72486 .54721 m .72968 .61911 L .72934 .6185 L .965 .686 .26 r
F
.72486 .54721 m .7297 .61914 L .72968 .61911 L F
.7249 .54637 m .72486 .54721 L .72934 .6185 L 0 0 .132 r
F
.73091 .62129 m .72911 .62218 L .73131 .622 L .601 .765 .958 r
F
.72911 .62218 m .72574 .62383 L .72907 .62274 L F
.72911 .62218 m .72907 .62274 L .73131 .622 L F
.73125 .62006 m .72574 .62383 L .73242 .62056 L F
.72592 .54853 m .73146 .62015 L .73042 .61971 L .857 .566 .495 r
F
.72522 .54792 m .73037 .61967 L .7297 .61914 L .947 .644 .431 r
F
.72522 .54792 m .73042 .61971 L .73037 .61967 L F
.73451 .61783 m .72659 .621 L .72574 .62383 L .601 .765 .958 r
F
.72659 .621 m .72289 .62247 L .72459 .62329 L F
.72659 .621 m .72459 .62329 L .72574 .62383 L F
.72564 .54532 m .7249 .54637 L .72939 .61777 L .076 0 .438 r
F
.73451 .61783 m .72814 .61921 L .72659 .621 L .601 .765 .958 r
F
.72917 .62479 m .73144 .63262 L .73297 .62527 L F
.72917 .62479 m .72389 .63166 L .73144 .63262 L F
.72574 .62383 m .72389 .63166 L .72917 .62479 L F
.72574 .62383 m .71705 .62978 L .72389 .63166 L F
.72289 .62247 m .71705 .62978 L .72574 .62383 L F
.73031 .62437 m .72071 .62568 L .72279 .62737 L .6 .765 .958 r
F
.7249 .54637 m .72935 .61846 L .72939 .61777 L 0 0 .132 r
F
.7249 .54637 m .72934 .6185 L .72935 .61846 L F
.72181 .62058 m .71969 .61891 L .72083 .62079 L .601 .765 .958 r
F
.73451 .61783 m .72675 .6184 L .72181 .62058 L F
.72675 .6184 m .71969 .61891 L .72181 .62058 L F
.73451 .61783 m .73125 .62006 L .73242 .62056 L F
.73042 .61971 m .73182 .62485 L .73071 .62438 L .857 .566 .495 r
F
.73258 .62518 m .72565 .62873 L .72911 .62969 L .6 .765 .958 r
F
.73242 .62056 m .73091 .62129 L .73131 .622 L .601 .765 .958 r
F
.73207 .62101 m .73131 .622 L .73303 .62177 L F
.73131 .622 m .73174 .62277 L .73303 .62177 L F
.73146 .62015 m .73183 .62486 L .73042 .61971 L .857 .566 .495 r
F
.73183 .62486 m .73182 .62485 L .73042 .61971 L F
.73146 .62015 m .73153 .62018 L .73183 .62486 L F
.73153 .62473 m .72565 .62873 L .73258 .62518 L .6 .765 .958 r
F
.73183 .62486 m .73183 .62486 L .73183 .62491 L .857 .566 .495 r
F
.73146 .62015 m .73183 .62486 L .73183 .62486 L F
.73153 .62473 m .72279 .62737 L .72565 .62873 L .6 .765 .958 r
F
.7297 .61914 m .7307 .62438 L .73 .62382 L .947 .644 .431 r
F
.72934 .6185 m .73 .62382 L .72964 .62314 L .965 .686 .26 r
F
.72993 .6237 m .72071 .62568 L .73031 .62437 L .6 .765 .958 r
F
.73 .62382 m .72988 .62361 L .72964 .62314 L .965 .686 .26 r
F
.72988 .62206 m .73 .62382 L .72979 .62217 L F
.73 .62382 m .73 .62382 L .72979 .62217 L F
.72954 .62006 m .72964 .62314 L .72968 .62233 L 0 0 .132 r
F
.72564 .54532 m .72944 .61772 L .73017 .61689 L .076 0 .438 r
F
.72564 .54532 m .72939 .61777 L .72944 .61772 L F
.73451 .61783 m .72565 .61731 L .71969 .61891 L .601 .765 .958 r
F
.72565 .61731 m .71956 .61695 L .71966 .61838 L F
.72565 .61731 m .71966 .61838 L .71969 .61891 L F
.72838 .54416 m .72705 .54451 L .73162 .61624 L .566 .34 .531 r
F
.72289 .62247 m .71136 .62708 L .71705 .62978 L .601 .765 .958 r
F
.72083 .62079 m .71136 .62708 L .72289 .62247 L F
.72777 .62416 m .71957 .62379 L .72071 .62568 L .6 .765 .958 r
F
.73207 .62101 m .73303 .62177 L .73382 .62115 L .601 .765 .958 r
F
.73382 .62115 m .73303 .62177 L .7336 .62222 L F
.73451 .61783 m .73242 .62056 L .73382 .62115 L F
.73326 .62048 m .73367 .62517 L .73153 .62018 L .753 .483 .523 r
F
.72939 .61777 m .72964 .62314 L .72954 .62006 L 0 0 .132 r
F
.7296 .62377 m .72381 .62349 L .72777 .62416 L .6 .765 .958 r
F
.72968 .61911 m .7297 .61914 L .73 .62382 L .965 .686 .26 r
F
.73 .62382 m .73 .62382 L .73 .62384 L F
.72968 .61911 m .73 .62382 L .73 .62382 L F
.72659 .621 m .72181 .62058 L .72289 .62247 L .601 .765 .958 r
F
.72181 .62058 m .721 .62094 L .72289 .62247 L F
.72958 .62307 m .71944 .62183 L .71957 .62379 L .6 .765 .958 r
F
.72935 .61846 m .72964 .62314 L .72939 .61777 L 0 0 .132 r
F
.72935 .61846 m .72934 .6185 L .72964 .62314 L F
.73037 .61967 m .73071 .62444 L .7297 .61914 L .947 .644 .431 r
F
.73037 .61967 m .73042 .61971 L .73071 .62444 L F
.73271 .62501 m .73183 .62486 L .73258 .62518 L .6 .765 .958 r
F
.73153 .62018 m .73367 .62517 L .73183 .62486 L .753 .483 .523 r
F
.73297 .62527 m .73144 .63262 L .7392 .63257 L .601 .765 .958 r
F
.73297 .62527 m .7392 .63257 L .73687 .62524 L F
.73396 .62522 m .72911 .62969 L .73293 .63017 L .6 .765 .958 r
F
.73326 .62048 m .73338 .6205 L .73368 .62517 L .753 .483 .523 r
F
.73338 .6205 m .7356 .62497 L .73369 .62517 L .638 .394 .533 r
F
.73397 .62516 m .73368 .62517 L .73396 .62522 L .6 .765 .958 r
F
.73368 .62517 m .73369 .62517 L .73368 .62517 L .638 .394 .533 r
F
.73338 .6205 m .73369 .62517 L .73368 .62517 L F
.73448 .62272 m .73271 .62501 L .73368 .62517 L .6 .765 .958 r
F
.73448 .62272 m .73368 .62517 L .73397 .62516 L F
.73368 .62517 m .72911 .62969 L .73396 .62522 L F
.72988 .64483 m .72992 .64 L .74155 .63994 L .668 .437 .561 r
F
.73144 .63262 m .72994 .63989 L .74151 .63983 L .601 .765 .958 r
F
.72988 .64483 m .74155 .63994 L .74153 .64477 L .668 .437 .561 r
F
.73144 .63262 m .74151 .63983 L .7392 .63257 L .601 .765 .958 r
F
.72984 .64968 m .72988 .64483 L .74153 .64477 L .668 .437 .561 r
F
.7314 .63754 m .72988 .64483 L .74153 .64477 L .6 .765 .958 r
F
.72984 .64968 m .74153 .64477 L .74151 .64962 L .668 .437 .561 r
F
.7314 .63754 m .74153 .64477 L .7392 .6375 L .6 .765 .958 r
F
.73136 .6424 m .72984 .64968 L .74151 .64962 L .599 .766 .959 r
F
.73136 .6424 m .74151 .64962 L .73918 .64236 L F
.73293 .63017 m .7314 .63754 L .7392 .6375 L .6 .765 .958 r
F
.73293 .63017 m .7392 .6375 L .73685 .63015 L F
.73289 .63505 m .73136 .6424 L .73918 .64236 L .599 .766 .959 r
F
.73289 .63505 m .73918 .64236 L .73682 .63503 L F
.73369 .62517 m .7356 .62497 L .73561 .62507 L .638 .394 .533 r
F
.73526 .62516 m .73293 .63017 L .73685 .63015 L .6 .765 .958 r
F
.73448 .62272 m .73389 .62552 L .73526 .62516 L F
.73389 .62552 m .73293 .63017 L .73526 .62516 L F
.7356 .62497 m .73561 .62507 L .73561 .62507 L .519 .305 .529 r
F
.73069 .54907 m .73651 .62008 L .7353 .6204 L F
.73739 .62109 m .73687 .62524 L .74061 .62472 L .601 .765 .958 r
F
.73673 .62034 m .7368 .62278 L .73739 .62109 L F
.7368 .62278 m .73687 .62524 L .73739 .62109 L F
.72881 .54928 m .73069 .54907 L .7353 .6204 L .638 .394 .533 r
F
.72881 .54928 m .7353 .6204 L .73519 .6204 L F
.73342 .54734 m .73366 .54651 L .73838 .61829 L 0 0 .297 r
F
.73781 .6199 m .74061 .62472 L .74097 .62461 L .601 .765 .958 r
F
.73946 .62092 m .74097 .62461 L .74394 .62372 L F
.73781 .6199 m .74097 .62461 L .73946 .62092 L F
.73777 .62001 m .74061 .62472 L .73781 .6199 L F
.73283 .54804 m .73342 .54734 L .73813 .61901 L .157 .044 .463 r
F
.73718 .61991 m .74061 .62472 L .73764 .61979 L .601 .765 .958 r
F
.73678 .62029 m .74061 .62472 L .73718 .61991 L F
.73651 .6201 m .74061 .62472 L .73659 .62006 L F
.73194 .54862 m .73746 .61962 L .73659 .62006 L .379 .203 .512 r
F
.73069 .54907 m .73194 .54862 L .73659 .62006 L .519 .305 .529 r
F
.73069 .54907 m .73659 .62006 L .73651 .62008 L F
.73283 .54804 m .73809 .61904 L .73751 .61959 L .157 .044 .463 r
F
.73825 .61922 m .74394 .62372 L .74664 .62233 L .601 .765 .958 r
F
.73194 .54862 m .73283 .54804 L .73751 .61959 L .379 .203 .512 r
F
.73194 .54862 m .73751 .61959 L .73746 .61962 L F
.73451 .61783 m .73741 .61965 L .73825 .61922 L .601 .765 .958 r
F
.73283 .54804 m .73813 .61901 L .73809 .61904 L .157 .044 .463 r
F
.73342 .54734 m .73838 .61829 L .73837 .61833 L 0 0 .297 r
F
.73342 .54734 m .73837 .61833 L .73813 .61901 L F
.73366 .54651 m .73327 .54544 L .73799 .61733 L .925 .667 .181 r
F
.73741 .61965 m .73946 .62092 L .73825 .61922 L .601 .765 .958 r
F
.74043 .61901 m .74664 .62233 L .74852 .62062 L F
.73451 .61783 m .74365 .62122 L .74043 .61901 L F
.74365 .62122 m .74664 .62233 L .74043 .61901 L F
.73451 .61783 m .7365 .62008 L .73764 .61979 L F
.73746 .61962 m .73751 .61959 L .7378 .62396 L .379 .203 .512 r
F
.73659 .62006 m .73678 .62029 L .73718 .61991 L .601 .765 .958 r
F
.73672 .62032 m .73672 .62035 L .73673 .62034 L F
.73746 .61962 m .7378 .62396 L .73659 .62006 L .379 .203 .512 r
F
.73764 .61979 m .73777 .62001 L .73781 .6199 L .601 .765 .958 r
F
.73751 .61959 m .73841 .62328 L .7378 .62396 L .157 .044 .463 r
F
.73809 .61904 m .73841 .62328 L .73751 .61959 L F
.73366 .54651 m .73801 .61739 L .73838 .61829 L .925 .667 .181 r
F
.73911 .61811 m .74852 .62062 L .74945 .61872 L .601 .765 .958 r
F
.73451 .61783 m .74043 .61901 L .73911 .61811 L F
.74043 .61901 m .74852 .62062 L .73911 .61811 L F
.73327 .54544 m .73214 .54459 L .73683 .61654 L .928 .626 .449 r
F
.73327 .54544 m .73683 .61654 L .73689 .61658 L F
.73327 .54544 m .73689 .61658 L .73799 .61733 L F
.73366 .54651 m .73799 .61733 L .73801 .61739 L .925 .667 .181 r
F
.73214 .54459 m .73566 .61617 L .73683 .61654 L .818 .533 .507 r
F
.73653 .61645 m .74621 .61316 L .74336 .61178 L .601 .765 .958 r
F
.73451 .61783 m .73734 .6167 L .73653 .61645 L F
.73734 .6167 m .74621 .61316 L .73653 .61645 L F
.7365 .62008 m .73651 .6201 L .73659 .62006 L F
.73672 .62035 m .73687 .62524 L .73673 .62034 L F
.73451 .61783 m .73532 .6204 L .73672 .62032 L F
.73532 .6204 m .73687 .62524 L .73672 .62032 L F
.73659 .62006 m .7378 .62396 L .73688 .62453 L .379 .203 .512 r
F
.73651 .62008 m .73659 .62006 L .73688 .62453 L .519 .305 .529 r
F
.73651 .62008 m .73688 .62453 L .7353 .6204 L F
.73734 .6167 m .74826 .61486 L .74621 .61316 L .601 .765 .958 r
F
.73451 .61783 m .7383 .61701 L .73734 .6167 L F
.7383 .61701 m .74826 .61486 L .73734 .6167 L F
.73214 .54459 m .73093 .5442 L .7356 .61615 L .818 .533 .507 r
F
.73214 .54459 m .7356 .61615 L .73566 .61617 L F
.73093 .5442 m .73438 .61599 L .7356 .61615 L .735 .468 .525 r
F
.73488 .61605 m .7399 .61081 L .73606 .61032 L .601 .765 .958 r
F
.73451 .61783 m .73578 .61617 L .73488 .61605 L F
.73578 .61617 m .7399 .61081 L .73488 .61605 L F
.73451 .61783 m .73396 .62047 L .73532 .6204 L F
.73451 .61783 m .74336 .61178 L .7399 .61081 L F
.73451 .61783 m .74936 .61675 L .74826 .61486 L F
.73451 .61783 m .74945 .61872 L .74936 .61675 L F
.7356 .61615 m .73458 .62008 L .73586 .62021 L .735 .468 .525 r
F
.72565 .61731 m .72045 .61504 L .71956 .61695 L .601 .765 .958 r
F
.73451 .61783 m .72892 .61672 L .72565 .61731 L F
.72892 .61672 m .72045 .61504 L .72565 .61731 L F
.72705 .54451 m .73025 .61685 L .73162 .61624 L .414 .228 .517 r
F
.72705 .54451 m .72564 .54532 L .73017 .61689 L F
.72705 .54451 m .73017 .61689 L .73025 .61685 L F
.72967 .54407 m .72838 .54416 L .73299 .616 L .657 .408 .532 r
F
.73451 .61783 m .7297 .61605 L .72586 .61612 L .601 .765 .958 r
F
.72838 .54416 m .73169 .61623 L .73299 .616 L .566 .34 .531 r
F
.72838 .54416 m .73162 .61624 L .73169 .61623 L F
.7297 .61605 m .725 .6119 L .7223 .61332 L .601 .765 .958 r
F
.73451 .61783 m .7316 .61602 L .7297 .61605 L F
.7316 .61602 m .725 .6119 L .7297 .61605 L F
.73451 .61783 m .72835 .61089 L .725 .6119 L F
.72967 .54407 m .73306 .616 L .73431 .61598 L .657 .408 .532 r
F
.72967 .54407 m .73299 .616 L .73306 .616 L F
.73451 .61783 m .73212 .61035 L .72835 .61089 L .601 .765 .958 r
F
.73093 .5442 m .72967 .54407 L .73431 .61598 L .735 .468 .525 r
F
.73093 .5442 m .73431 .61598 L .73438 .61599 L F
.73451 .61783 m .73606 .61032 L .73212 .61035 L .601 .765 .958 r
F
.73431 .61598 m .73325 .62017 L .73458 .62008 L .657 .408 .532 r
F
.73306 .616 m .73325 .62017 L .73431 .61598 L F
.73306 .616 m .73299 .616 L .73325 .62017 L F
.72586 .61612 m .72678 .61497 L .72045 .61504 L .601 .765 .958 r
F
.7297 .61605 m .72678 .61497 L .72586 .61612 L F
.72678 .61497 m .7223 .61332 L .72131 .61424 L F
.72678 .61497 m .72131 .61424 L .72045 .61504 L F
.73438 .61599 m .73431 .61598 L .73458 .62008 L .735 .468 .525 r
F
.73299 .616 m .73189 .62051 L .73325 .62017 L .566 .34 .531 r
F
.73169 .61623 m .73189 .62051 L .73299 .616 L F
.73438 .61599 m .73458 .62008 L .7356 .61615 L .735 .468 .525 r
F
.73566 .61617 m .7356 .61615 L .73586 .62021 L .818 .533 .507 r
F
.73683 .61654 m .73586 .62021 L .7371 .62059 L F
.73566 .61617 m .73586 .62021 L .73683 .61654 L F
.73689 .61658 m .73683 .61654 L .7371 .62059 L .928 .626 .449 r
F
.73799 .61733 m .7371 .62059 L .73826 .62142 L F
.73689 .61658 m .7371 .62059 L .73799 .61733 L F
.73801 .61739 m .73799 .61733 L .73826 .62142 L .925 .667 .181 r
F
.73946 .62092 m .74394 .62372 L .739 .61982 L .601 .765 .958 r
F
.73946 .62092 m .739 .61982 L .73825 .61922 L F
.73809 .61904 m .73813 .61901 L .73841 .62328 L .157 .044 .463 r
F
.73837 .61833 m .73838 .61829 L .73865 .62247 L 0 0 .297 r
F
.73813 .61901 m .73865 .62247 L .73841 .62328 L F
.73837 .61833 m .73865 .62247 L .73813 .61901 L F
.73838 .61829 m .73826 .62142 L .73865 .62247 L .925 .667 .181 r
F
.73801 .61739 m .73826 .62142 L .73838 .61829 L F
.7353 .6204 m .73511 .62079 L .73532 .6204 L .601 .765 .958 r
F
.73532 .6204 m .73513 .62079 L .73547 .62085 L F
.73519 .6204 m .7353 .6204 L .7356 .62497 L .638 .394 .533 r
F
.7353 .6204 m .73688 .62453 L .7356 .62497 L .519 .305 .529 r
F
.73511 .62079 m .73513 .62079 L .73532 .6204 L .601 .765 .958 r
F
.73396 .62047 m .7339 .62076 L .7353 .6204 L F
.73519 .6204 m .7356 .62497 L .73338 .6205 L .638 .394 .533 r
F
.73687 .62524 m .7392 .63257 L .74666 .63153 L .601 .765 .958 r
F
.73639 .62487 m .73685 .63015 L .74062 .62962 L .6 .765 .958 r
F
.7356 .62497 m .73689 .62474 L .73561 .62507 L .519 .305 .529 r
F
.73448 .62272 m .73526 .62516 L .73639 .62487 L .6 .765 .958 r
F
.73526 .62516 m .73685 .63015 L .73639 .62487 L F
.7356 .62497 m .73688 .62453 L .73689 .62474 L .519 .305 .529 r
F
.73687 .62524 m .74666 .63153 L .74061 .62472 L .601 .765 .958 r
F
.7392 .63257 m .74151 .63983 L .75265 .63829 L F
.7392 .63257 m .75265 .63829 L .74666 .63153 L F
.73685 .63015 m .7392 .6375 L .7467 .63646 L .6 .765 .958 r
F
.73685 .63015 m .7467 .63646 L .74062 .62962 L F
.74153 .64477 m .74155 .63994 L .75273 .63839 L .595 .378 .556 r
F
.74153 .64477 m .75273 .63839 L .75273 .64323 L F
.7392 .6375 m .74153 .64477 L .75273 .64323 L .6 .765 .958 r
F
.7392 .6375 m .75273 .64323 L .7467 .63646 L F
.73682 .63503 m .73918 .64236 L .74669 .64133 L .599 .766 .959 r
F
.73682 .63503 m .74669 .64133 L .74059 .6345 L F
.73735 .62451 m .74062 .62962 L .74397 .62862 L .6 .765 .958 r
F
.73688 .62453 m .7369 .62474 L .73689 .62474 L .379 .203 .512 r
F
.73647 .62495 m .74062 .62962 L .73735 .62451 L .6 .765 .958 r
F
.74061 .62472 m .74666 .63153 L .75331 .62957 L .601 .765 .958 r
F
.73818 .62409 m .74397 .62862 L .74669 .62723 L .6 .765 .958 r
F
.73688 .62453 m .7378 .62396 L .73782 .62427 L .379 .203 .512 r
F
.73782 .62427 m .74397 .62862 L .73818 .62409 L .6 .765 .958 r
F
.73735 .62451 m .73748 .62459 L .73782 .62427 L F
.73748 .62459 m .74397 .62862 L .73782 .62427 L F
.7378 .62396 m .73841 .62328 L .73843 .62369 L .157 .044 .463 r
F
.73806 .62404 m .73782 .62427 L .73818 .62409 L .6 .765 .958 r
F
.73771 .63128 m .73682 .63503 L .74059 .6345 L .599 .766 .959 r
F
.74151 .64962 m .74153 .64477 L .75273 .64323 L .595 .378 .556 r
F
.74151 .64962 m .75273 .64323 L .75272 .64809 L F
.73918 .64236 m .74151 .64962 L .75272 .64809 L .599 .766 .959 r
F
.73918 .64236 m .75272 .64809 L .74669 .64133 L F
.74394 .62372 m .75331 .62957 L .75871 .62679 L .601 .765 .958 r
F
.74061 .62472 m .75331 .62957 L .74394 .62372 L F
.73849 .62352 m .74669 .62723 L .74858 .62552 L .6 .765 .958 r
F
.73828 .62412 m .74669 .62723 L .73849 .62352 L F
.73843 .62369 m .739 .62767 L .73876 .62834 L 0 0 .297 r
F
.73841 .62328 m .73845 .62363 L .73843 .62369 L F
.73845 .62363 m .739 .62767 L .73843 .62369 L F
.74394 .62372 m .75871 .62679 L .74664 .62233 L .601 .765 .958 r
F
.73869 .62297 m .74858 .62552 L .74952 .62361 L .6 .765 .958 r
F
.73841 .62328 m .73869 .62297 L .73845 .62363 L 0 0 .297 r
F
.73841 .62328 m .73876 .62834 L .73874 .62838 L F
.73869 .62297 m .74858 .62552 L .73869 .62297 L .6 .765 .958 r
F
.73849 .62352 m .73895 .62361 L .73869 .62297 L F
.73895 .62361 m .74858 .62552 L .73869 .62297 L F
.73865 .62247 m .73826 .62142 L .73829 .62202 L .925 .667 .181 r
F
.73448 .62272 m .73849 .62352 L .73869 .62297 L .6 .765 .958 r
F
.73448 .62272 m .73869 .62297 L .73868 .62297 L F
.7378 .62396 m .73843 .62369 L .73782 .62427 L .157 .044 .463 r
F
.73448 .62272 m .73828 .62412 L .73849 .62352 L .6 .765 .958 r
F
.73841 .62328 m .73865 .62247 L .73869 .62297 L 0 0 .297 r
F
.73845 .62363 m .73869 .62297 L .739 .62767 L F
.73819 .62994 m .74059 .6345 L .74395 .63351 L .599 .766 .959 r
F
.73804 .63036 m .74059 .6345 L .73819 .62994 L F
.73678 .63023 m .74059 .6345 L .73753 .62953 L F
.74666 .63153 m .75265 .63829 L .7626 .63536 L .601 .765 .958 r
F
.74062 .62962 m .7467 .63646 L .7534 .63449 L .6 .765 .958 r
F
.73978 .62958 m .74395 .63351 L .74667 .63211 L .599 .766 .959 r
F
.73782 .62427 m .73817 .62893 L .73782 .62427 L .157 .044 .463 r
F
.73812 .62897 m .74053 .63139 L .73978 .62958 L .599 .766 .959 r
F
.73753 .62953 m .74053 .63139 L .73812 .62897 L F
.73817 .62893 m .73816 .62893 L .73782 .62427 L .157 .044 .463 r
F
.74666 .63153 m .7626 .63536 L .75331 .62957 L .601 .765 .958 r
F
.75331 .62957 m .7626 .63536 L .77072 .63124 L F
.74397 .62862 m .7534 .63449 L .75883 .63171 L .6 .765 .958 r
F
.74062 .62962 m .7534 .63449 L .74397 .62862 L F
.73938 .62859 m .74667 .63211 L .74857 .63041 L .599 .766 .959 r
F
.73782 .62427 m .73816 .62893 L .73813 .62896 L .157 .044 .463 r
F
.73782 .62427 m .73874 .62838 L .73817 .62893 L F
.73693 .62472 m .73782 .62427 L .73813 .62896 L .379 .203 .512 r
F
.73688 .62453 m .73813 .62896 L .73726 .6294 L F
.73689 .62474 m .73725 .6294 L .7372 .62943 L F
.73561 .62507 m .73689 .62474 L .7372 .62943 L .519 .305 .529 r
F
.73732 .6294 m .73678 .63023 L .73753 .62953 L .599 .766 .959 r
F
.73728 .62941 m .73678 .63023 L .73732 .6294 L F
.73642 .62982 m .73678 .63023 L .73729 .62938 L F
.73678 .63023 m .73681 .63381 L .73771 .63128 L F
.73681 .63381 m .73682 .63503 L .73771 .63128 L F
.73642 .62982 m .73647 .63053 L .73678 .63023 L F
.73647 .63053 m .73682 .63503 L .73678 .63023 L F
.73561 .62507 m .7372 .62943 L .73599 .62974 L .519 .305 .529 r
F
.73369 .62517 m .73561 .62507 L .73591 .62976 L .638 .394 .533 r
F
.73634 .62974 m .73533 .63037 L .73642 .62982 L .599 .766 .959 r
F
.73617 .62975 m .73533 .63037 L .73634 .62974 L F
.73519 .62995 m .73533 .63037 L .73628 .62967 L F
.73533 .63037 m .73682 .63503 L .73642 .62982 L F
.73369 .62517 m .73591 .62976 L .73411 .62985 L .638 .394 .533 r
F
.73271 .62501 m .73254 .62523 L .73368 .62517 L .6 .765 .958 r
F
.73254 .62523 m .72911 .62969 L .73368 .62517 L F
.73183 .62491 m .73368 .62517 L .73398 .62986 L .753 .483 .523 r
F
.73523 .63008 m .73289 .63505 L .73682 .63503 L .599 .766 .959 r
F
.73514 .63006 m .73289 .63505 L .73523 .63008 L F
.73515 .6298 m .73389 .63029 L .73519 .62995 L F
.73398 .62986 m .73389 .63029 L .73515 .6298 L F
.73389 .63029 m .73289 .63505 L .73519 .62995 L F
.72389 .63166 m .72994 .63989 L .73144 .63262 L .601 .765 .958 r
F
.72911 .62969 m .7314 .63754 L .73293 .63017 L .6 .765 .958 r
F
.72389 .63166 m .71867 .63847 L .72994 .63989 L .601 .765 .958 r
F
.72911 .62969 m .7238 .63658 L .7314 .63754 L .6 .765 .958 r
F
.73051 .6243 m .72279 .62737 L .73153 .62473 L F
.73071 .62444 m .73183 .62491 L .73213 .62955 L .857 .566 .495 r
F
.7337 .63119 m .72907 .63457 L .73289 .63505 L .599 .766 .959 r
F
.73389 .63029 m .73326 .63085 L .7337 .63119 L F
.73326 .63085 m .72907 .63457 L .7337 .63119 L F
.73051 .6243 m .73019 .62416 L .73031 .62437 L .6 .765 .958 r
F
.73 .62384 m .73071 .62444 L .73101 .62907 L .947 .644 .431 r
F
.73364 .63018 m .73309 .63071 L .73389 .63029 L .599 .766 .959 r
F
.73309 .63071 m .72907 .63457 L .73326 .63085 L F
.73309 .63071 m .73326 .63085 L .73389 .63029 L F
.72993 .6237 m .72964 .62318 L .7296 .62377 L .6 .765 .958 r
F
.73175 .6311 m .72907 .63457 L .73208 .63168 L .599 .766 .959 r
F
.71854 .64341 m .72992 .64 L .72988 .64483 L .734 .491 .561 r
F
.71854 .64341 m .71859 .63857 L .72992 .64 L F
.7238 .63658 m .72988 .64483 L .7314 .63754 L .6 .765 .958 r
F
.71849 .64825 m .72988 .64483 L .72984 .64968 L .734 .491 .561 r
F
.71849 .64825 m .71854 .64341 L .72988 .64483 L F
.7238 .63658 m .71854 .64341 L .72988 .64483 L .6 .765 .958 r
F
.72375 .64145 m .72984 .64968 L .73136 .6424 L .599 .766 .959 r
F
.72907 .63457 m .73136 .6424 L .73289 .63505 L F
.72907 .63457 m .72375 .64145 L .73136 .6424 L F
.72565 .62873 m .7238 .63658 L .72911 .62969 L .6 .765 .958 r
F
.73175 .6311 m .72561 .63361 L .72907 .63457 L .599 .766 .959 r
F
.73108 .6299 m .72974 .63081 L .73175 .6311 L F
.72974 .63081 m .72561 .63361 L .72967 .63195 L F
.72974 .63081 m .72967 .63195 L .73175 .6311 L F
.72964 .62314 m .72996 .62792 L .72993 .62788 L .965 .686 .26 r
F
.73448 .62272 m .72965 .62307 L .72964 .62318 L .6 .765 .958 r
F
.72964 .62314 m .72988 .62361 L .72964 .62319 L .965 .686 .26 r
F
.73448 .62272 m .72964 .62318 L .72993 .6237 L .6 .765 .958 r
F
.72964 .62314 m .73029 .62851 L .72996 .62792 L .965 .686 .26 r
F
.72965 .62307 m .7292 .62241 L .72958 .62307 L .6 .765 .958 r
F
.73044 .6213 m .72968 .62233 L .72969 .62246 L .076 0 .438 r
F
.73448 .62272 m .7297 .62244 L .72965 .62307 L .6 .765 .958 r
F
.73071 .62444 m .73107 .6291 L .73101 .62907 L .857 .566 .495 r
F
.73 .62384 m .73101 .62907 L .73034 .62855 L .947 .644 .431 r
F
.73071 .62444 m .73213 .62955 L .73107 .6291 L .857 .566 .495 r
F
.73183 .62491 m .73224 .62957 L .73213 .62955 L .753 .483 .523 r
F
.73368 .62517 m .73409 .62986 L .73398 .62986 L .638 .394 .533 r
F
.73368 .62517 m .73369 .62517 L .73411 .62985 L F
.73368 .62517 m .73411 .62985 L .73409 .62986 L F
.73183 .62491 m .73398 .62986 L .73224 .62957 L .753 .483 .523 r
F
.73445 .62762 m .72983 .62944 L .72974 .63081 L .599 .766 .959 r
F
.72964 .62319 m .73 .62384 L .73029 .62851 L .965 .686 .26 r
F
.73 .62384 m .73034 .62855 L .73029 .62851 L .947 .644 .431 r
F
.71705 .62978 m .71867 .63847 L .72389 .63166 L .601 .765 .958 r
F
.71705 .62978 m .70844 .63566 L .71867 .63847 L F
.72565 .62873 m .71691 .63469 L .7238 .63658 L .6 .765 .958 r
F
.72279 .62737 m .71691 .63469 L .72565 .62873 L F
.73445 .62762 m .72844 .6289 L .72698 .63057 L .599 .766 .959 r
F
.71136 .62708 m .70844 .63566 L .71705 .62978 L .601 .765 .958 r
F
.72279 .62737 m .71119 .63198 L .71691 .63469 L .6 .765 .958 r
F
.72121 .63045 m .71952 .62869 L .72066 .63057 L .599 .766 .959 r
F
.73445 .62762 m .72636 .62819 L .72121 .63045 L F
.72636 .62819 m .71952 .62869 L .72121 .63045 L F
.73445 .62762 m .73108 .6299 L .73175 .6311 L F
.73266 .62993 m .73175 .6311 L .73364 .63018 L F
.73175 .6311 m .73208 .63168 L .73364 .63018 L F
.73459 .70368 m .73674 .70636 L .73729 .70368 L .656 .814 .96 r
F
.73648 .70098 m .73729 .70368 L .73784 .70098 L F
.73596 .70173 m .73459 .70368 L .73715 .70368 L F
.73526 .7008 m .73459 .70368 L .73596 .70173 L F
.73541 .70082 m .73596 .70173 L .73648 .70098 L F
.73526 .7008 m .73596 .70173 L .73541 .70082 L F
.7297 .62244 m .72969 .62246 L .72965 .62307 L .6 .765 .958 r
F
.72968 .62247 m .72964 .62318 L .72993 .62788 L 0 0 .132 r
F
.72969 .62246 m .72993 .62788 L .72998 .62719 L F
.72968 .62233 m .72968 .62247 L .72969 .62246 L F
.72968 .62247 m .72993 .62788 L .72969 .62246 L F
.72814 .61921 m .72181 .62058 L .72659 .621 L .601 .765 .958 r
F
.72181 .62058 m .72083 .62079 L .721 .62094 L F
.72083 .62079 m .70722 .62374 L .71136 .62708 L F
.71969 .61891 m .70722 .62374 L .72083 .62079 L F
.72969 .62243 m .72033 .61991 L .71944 .62183 L .6 .765 .958 r
F
.73044 .6213 m .72969 .62246 L .73046 .62157 L .076 0 .438 r
F
.72988 .62206 m .72979 .62217 L .72934 .6185 L .965 .686 .26 r
F
.72968 .61911 m .72988 .62206 L .72934 .6185 L F
.73017 .61689 m .72968 .62233 L .73044 .6213 L .076 0 .438 r
F
.73448 .62272 m .72973 .62178 L .72969 .62243 L .6 .765 .958 r
F
.72944 .61772 m .72968 .62233 L .73017 .61689 L .076 0 .438 r
F
.72944 .61772 m .72939 .61777 L .72968 .62233 L F
.72973 .62178 m .72033 .61991 L .72969 .62243 L .6 .765 .958 r
F
.72071 .62568 m .71119 .63198 L .72279 .62737 L F
.73445 .62762 m .72435 .62702 L .71952 .62869 L .599 .766 .959 r
F
.72435 .62702 m .71939 .62672 L .71946 .62788 L F
.72435 .62702 m .71946 .62788 L .71952 .62869 L F
.73183 .62486 m .73368 .62517 L .73183 .62491 L .753 .483 .523 r
F
.73367 .62517 m .73368 .62517 L .73183 .62486 L F
.73448 .62272 m .73153 .62473 L .73183 .62486 L .6 .765 .958 r
F
.73448 .62272 m .73183 .62486 L .73271 .62501 L F
.73448 .62272 m .72993 .6237 L .73019 .62416 L F
.73448 .62272 m .73057 .62427 L .73153 .62473 L F
.73448 .62272 m .73019 .62416 L .73051 .6243 L F
.7285 .62153 m .7222 .61819 L .72033 .61991 L F
.73448 .62272 m .73087 .62139 L .7302 .62187 L F
.73189 .62051 m .73046 .62157 L .7318 .62098 L .414 .228 .517 r
F
.73087 .62139 m .73068 .62132 L .73046 .62157 L .6 .765 .958 r
F
.73087 .62139 m .73046 .62157 L .7302 .62187 L F
.73189 .62051 m .73044 .6213 L .73046 .62157 L .414 .228 .517 r
F
.73057 .62427 m .73071 .62438 L .73153 .62473 L .6 .765 .958 r
F
.73071 .62438 m .73183 .62491 L .73071 .62444 L .857 .566 .495 r
F
.73182 .62485 m .73183 .62491 L .73071 .62438 L F
.73037 .6212 m .72491 .61677 L .7222 .61819 L .6 .765 .958 r
F
.73448 .62272 m .73173 .62101 L .73087 .62139 L F
.73189 .62051 m .73191 .62093 L .73191 .62093 L .414 .228 .517 r
F
.73325 .62017 m .73189 .62051 L .73191 .62093 L .566 .34 .531 r
F
.73325 .62017 m .73191 .62093 L .73315 .62071 L F
.73162 .61624 m .73044 .6213 L .73189 .62051 L .414 .228 .517 r
F
.73025 .61685 m .73044 .6213 L .73162 .61624 L F
.73025 .61685 m .73017 .61689 L .73044 .6213 L F
.73173 .62101 m .72828 .61575 L .72491 .61677 L .6 .765 .958 r
F
.73448 .62272 m .73275 .62078 L .73173 .62101 L F
.73299 .62991 m .73364 .63018 L .73398 .62986 L .599 .766 .959 r
F
.73398 .62986 m .73364 .63018 L .73389 .63029 L F
.73648 .70098 m .73596 .70173 L .73729 .70368 L .656 .814 .96 r
F
.73596 .70173 m .73715 .70368 L .73729 .70368 L F
.73729 .70368 m .73674 .70636 L .7409 .70581 L F
.73729 .70368 m .7409 .70581 L .74006 .70331 L F
.73784 .70098 m .73729 .70368 L .74006 .70331 L F
.73784 .70098 m .74006 .70331 L .73923 .7008 L F
.73723 .70939 m .73674 .7064 L .74091 .70585 L .666 .428 .551 r
F
.73723 .70939 m .74091 .70585 L .7414 .70884 L F
.73833 .70399 m .73778 .70669 L .74057 .70633 L .655 .815 .96 r
F
.73697 .70399 m .73778 .70669 L .73833 .70399 L F
.73316 .70939 m .73674 .7064 L .73723 .70939 L .731 .473 .537 r
F
.73316 .70939 m .73267 .7064 L .73674 .7064 L F
.73459 .70368 m .7327 .70636 L .73674 .70636 L .656 .814 .96 r
F
.73697 .70399 m .73506 .70669 L .73778 .70669 L .655 .815 .96 r
F
.73833 .70399 m .74057 .70633 L .73972 .70381 L F
.73574 .7038 m .73506 .70669 L .73693 .70404 L F
.73682 .70397 m .73693 .70404 L .73697 .70399 L F
.73574 .7038 m .73693 .70404 L .73682 .70397 L F
.73526 .7008 m .73426 .7016 L .73459 .70368 L .656 .814 .96 r
F
.73426 .7016 m .73215 .70331 L .73413 .70361 L F
.73426 .7016 m .73413 .70361 L .73459 .70368 L F
.73425 .70044 m .73215 .70331 L .73426 .7016 L F
.73434 .70047 m .73426 .7016 L .73526 .7008 L F
.73425 .70044 m .73426 .7016 L .73434 .70047 L F
.72996 .62792 m .73477 .69977 L .72993 .62788 L .965 .686 .26 r
F
.73477 .69977 m .73477 .69977 L .72993 .62788 L F
.72993 .62788 m .73477 .69977 L .73442 .69919 L F
.73524 .70318 m .73472 .70345 L .73559 .70375 L .655 .815 .96 r
F
.72996 .62792 m .73029 .62851 L .73479 .69979 L .965 .686 .26 r
F
.73535 .70073 m .73434 .70047 L .73526 .7008 L .656 .814 .96 r
F
.73434 .70047 m .73425 .70044 L .73434 .70047 L F
.73434 .70047 m .73434 .70047 L .73526 .7008 L F
.72996 .62792 m .73479 .69979 L .73477 .69977 L .965 .686 .26 r
F
.71136 .62708 m .69992 .63164 L .70844 .63566 L .601 .765 .958 r
F
.70722 .62374 m .69992 .63164 L .71136 .62708 L F
.72071 .62568 m .70702 .62863 L .71119 .63198 L .6 .765 .958 r
F
.71957 .62379 m .70702 .62863 L .72071 .62568 L F
.72435 .62702 m .72028 .62481 L .71939 .62672 L .599 .766 .959 r
F
.72968 .62233 m .72998 .62719 L .72998 .62715 L 0 0 .132 r
F
.72988 .62361 m .73 .62384 L .72964 .62319 L .965 .686 .26 r
F
.73 .62382 m .73 .62384 L .72988 .62361 L F
.73 .62382 m .73071 .62444 L .73 .62384 L .947 .644 .431 r
F
.73057 .62427 m .73051 .6243 L .73071 .62438 L .6 .765 .958 r
F
.7307 .62438 m .73071 .62444 L .73 .62382 L .947 .644 .431 r
F
.73 .62382 m .73 .62384 L .73 .62382 L .965 .686 .26 r
F
.73046 .62157 m .72969 .62246 L .72998 .62715 L .076 0 .438 r
F
.73046 .62157 m .72998 .62715 L .73071 .62632 L F
.73445 .62762 m .72808 .62636 L .72435 .62702 L .599 .766 .959 r
F
.72808 .62636 m .72028 .62481 L .72435 .62702 L F
.73612 .7035 m .73524 .70318 L .73574 .7038 L .655 .815 .96 r
F
.73101 .62907 m .73659 .7006 L .73551 .70027 L .857 .566 .495 r
F
.73213 .62955 m .73842 .7007 L .73664 .70061 L .753 .483 .523 r
F
.73784 .70097 m .73648 .70098 L .73784 .70098 L .656 .814 .96 r
F
.73224 .62957 m .73842 .7007 L .73213 .62955 L .753 .483 .523 r
F
.73842 .7007 m .73842 .7007 L .73213 .62955 L F
.73266 .62993 m .73364 .63018 L .73299 .62991 L .599 .766 .959 r
F
.73445 .62762 m .73266 .62993 L .73398 .62986 L F
.73224 .62957 m .73398 .62986 L .73852 .7007 L .753 .483 .523 r
F
.7392 .70074 m .73784 .70098 L .73923 .7008 L .656 .814 .96 r
F
.73969 .7037 m .73833 .70399 L .73972 .70381 L .655 .815 .96 r
F
.73842 .7007 m .73871 .70365 L .73868 .70365 L .753 .483 .523 r
F
.7384 .70363 m .73833 .70399 L .73969 .7037 L .655 .815 .96 r
F
.74006 .70331 m .7409 .70581 L .74488 .70475 L .656 .814 .96 r
F
.7414 .70884 m .74091 .70585 L .74491 .70479 L .595 .38 .559 r
F
.73972 .70381 m .74057 .70633 L .74324 .70561 L .655 .815 .96 r
F
.73871 .70365 m .74075 .70459 L .73878 .70479 L .638 .394 .533 r
F
.73852 .7007 m .74008 .70341 L .73871 .70365 L F
.73962 .70349 m .73871 .70365 L .73969 .7037 L .655 .815 .96 r
F
.74006 .70331 m .74488 .70475 L .74272 .7026 L .656 .814 .96 r
F
.73972 .70381 m .74324 .70561 L .74106 .70345 L .655 .815 .96 r
F
.74089 .70327 m .73972 .70381 L .74106 .70345 L F
.73916 .70059 m .73875 .70071 L .7392 .70074 L .656 .814 .96 r
F
.73981 .7011 m .74006 .70331 L .74272 .7026 L F
.73812 .62897 m .73978 .62958 L .73901 .62852 L .599 .766 .959 r
F
.73817 .62893 m .74332 .69865 L .73816 .62893 L .157 .044 .463 r
F
.73901 .62852 m .73978 .62958 L .73938 .62859 L .599 .766 .959 r
F
.73561 .62507 m .73599 .62974 L .73561 .62507 L .519 .305 .529 r
F
.73599 .62974 m .73599 .62974 L .73561 .62507 L F
.73561 .62507 m .73599 .62974 L .73591 .62976 L F
.7369 .62474 m .73726 .6294 L .73689 .62474 L .379 .203 .512 r
F
.73726 .6294 m .73725 .6294 L .73689 .62474 L F
.73445 .62762 m .73812 .62897 L .73901 .62852 L .599 .766 .959 r
F
.74397 .62862 m .75883 .63171 L .74669 .62723 L .6 .765 .958 r
F
.73909 .62789 m .74857 .63041 L .7495 .62851 L .599 .766 .959 r
F
.73782 .62427 m .73843 .62369 L .73874 .62838 L .157 .044 .463 r
F
.73445 .62762 m .73938 .62859 L .73909 .62789 L .599 .766 .959 r
F
.73938 .62859 m .74857 .63041 L .73909 .62789 L F
.73865 .62247 m .73829 .62202 L .73868 .62297 L .925 .667 .181 r
F
.73865 .62247 m .73868 .62297 L .73869 .62297 L F
.74664 .62233 m .75871 .62679 L .7625 .6234 L .601 .765 .958 r
F
.74664 .62233 m .7625 .6234 L .74852 .62062 L F
.73886 .6224 m .74952 .62361 L .74943 .62164 L .6 .765 .958 r
F
.73448 .62272 m .73978 .62303 L .73886 .6224 L F
.73978 .62303 m .74952 .62361 L .73886 .6224 L F
.74332 .69865 m .74332 .69865 L .73816 .62893 L .157 .044 .463 r
F
.73726 .6294 m .74268 .69931 L .73725 .6294 L .379 .203 .512 r
F
.74255 .70095 m .74272 .7026 L .74509 .7016 L .656 .814 .96 r
F
.74272 .7026 m .74488 .70475 L .74843 .70325 L F
.74272 .7026 m .74582 .70296 L .74509 .7016 L F
.74582 .70296 m .74843 .70325 L .74527 .70169 L F
.74582 .70296 m .74527 .70169 L .74509 .7016 L F
.74274 .7004 m .74509 .7016 L .7452 .70153 L F
.742 .70006 m .74273 .70043 L .74274 .7004 L F
.74273 .70043 m .74509 .7016 L .74274 .7004 L F
.74199 .70007 m .74273 .70043 L .742 .70006 L F
.74273 .70043 m .74509 .7016 L .74273 .70043 L F
.74273 .70043 m .74273 .70043 L .742 .70006 L F
.73876 .62834 m .74359 .6979 L .73874 .62838 L 0 0 .297 r
F
.74208 .69997 m .7452 .70153 L .74461 .70018 L .656 .814 .96 r
F
.74174 .69994 m .742 .70006 L .74208 .69997 L F
.742 .70006 m .7452 .70153 L .74208 .69997 L F
.73816 .62893 m .74332 .69865 L .73813 .62896 L .157 .044 .463 r
F
.73817 .62893 m .73874 .62838 L .74335 .69862 L F
.74186 .7002 m .74509 .7016 L .74199 .70007 L .656 .814 .96 r
F
.74077 .7005 m .74509 .7016 L .7415 .70005 L F
.74359 .6979 m .74359 .6979 L .73874 .62838 L 0 0 .297 r
F
.73874 .62838 m .74359 .6979 L .74335 .69862 L F
.75331 .62957 m .77072 .63124 L .75871 .62679 L .601 .765 .958 r
F
.74669 .62723 m .75883 .63171 L .76265 .62831 L .6 .765 .958 r
F
.74669 .62723 m .76265 .62831 L .74858 .62552 L F
.7394 .62726 m .7495 .62851 L .74942 .62654 L .599 .766 .959 r
F
.73868 .62297 m .73897 .6276 L .73869 .62297 L .925 .667 .181 r
F
.73897 .6276 m .73897 .62761 L .73869 .62297 L F
.73869 .62297 m .73897 .62761 L .739 .62767 L F
.73868 .62297 m .7386 .62672 L .73897 .6276 L F
.73445 .62762 m .74045 .62797 L .7394 .62726 L .599 .766 .959 r
F
.74045 .62797 m .7495 .62851 L .7394 .62726 L F
.73817 .62893 m .74335 .69862 L .74332 .69865 L .157 .044 .463 r
F
.73725 .6294 m .74268 .69931 L .7372 .62943 L .379 .203 .512 r
F
.74268 .69931 m .74267 .69931 L .7372 .62943 L F
.74332 .69865 m .74331 .69865 L .73813 .62896 L .157 .044 .463 r
F
.73813 .62896 m .74331 .69865 L .74273 .69928 L F
.74268 .69931 m .74268 .69931 L .73725 .6294 L .379 .203 .512 r
F
.7372 .62943 m .74267 .69931 L .74179 .69987 L F
.7427 .69933 m .74442 .69975 L .74427 .69939 L .656 .814 .96 r
F
.74421 .69924 m .74783 .69953 L .74702 .69907 L F
.7427 .69933 m .74427 .69939 L .74421 .69924 L F
.74427 .69939 m .74783 .69953 L .74421 .69924 L F
.73876 .62834 m .73898 .62772 L .74084 .65813 L 0 0 .297 r
F
.73898 .62772 m .739 .62767 L .74084 .65813 L F
.74084 .65813 m .739 .62767 L .74361 .69786 L F
.73876 .62834 m .74361 .69786 L .74359 .6979 L F
.73826 .62142 m .73829 .62201 L .73829 .62202 L .928 .626 .449 r
F
.74852 .62062 m .7625 .6234 L .7644 .61961 L .601 .765 .958 r
F
.74852 .62062 m .7644 .61961 L .74945 .61872 L F
.73816 .62192 m .74943 .62164 L .74832 .61974 L .6 .765 .958 r
F
.73448 .62272 m .73886 .6224 L .73816 .62192 L F
.73886 .6224 m .74943 .62164 L .73816 .62192 L F
.73826 .62142 m .7371 .62059 L .73714 .62123 L .928 .626 .449 r
F
.7378 .62396 m .73782 .62427 L .73782 .62427 L .157 .044 .463 r
F
.73448 .62272 m .73782 .62427 L .73806 .62404 L .6 .765 .958 r
F
.73829 .62201 m .73745 .62593 L .73852 .62666 L .928 .626 .449 r
F
.73829 .62202 m .7385 .62601 L .73856 .62599 L F
.7385 .62601 m .73853 .62667 L .73856 .62599 L F
.73856 .62599 m .73853 .62667 L .7386 .62672 L F
.73445 .62762 m .73861 .62672 L .73791 .62624 L .599 .766 .959 r
F
.74174 .69994 m .74701 .70037 L .74301 .6994 L .656 .814 .96 r
F
.74197 .6998 m .74301 .6994 L .7427 .69933 L F
.74174 .69994 m .74301 .6994 L .74197 .6998 L F
.73628 .62967 m .73617 .62975 L .73634 .62974 L .599 .766 .959 r
F
.73599 .62974 m .7372 .62943 L .74179 .69987 L .519 .305 .529 r
F
.74143 .70067 m .74224 .70188 L .74255 .70095 L .656 .814 .96 r
F
.74117 .70093 m .74272 .7026 L .74143 .70067 L F
.74067 .70056 m .74272 .7026 L .74077 .7005 L F
.73959 .70071 m .74272 .7026 L .74056 .70045 L F
.73923 .7008 m .73927 .70082 L .73959 .70071 L F
.73927 .70082 m .74272 .7026 L .73959 .70071 L F
.73943 .70133 m .74006 .70331 L .73981 .7011 L F
.73924 .70084 m .74006 .70331 L .73927 .70082 L F
.73875 .70071 m .73784 .70098 L .7392 .70074 L F
.74064 .70332 m .74008 .70341 L .73852 .7007 L .638 .394 .533 r
F
.73962 .70349 m .73972 .70381 L .74089 .70327 L .655 .815 .96 r
F
.73409 .62986 m .74038 .70038 L .73398 .62986 L .638 .394 .533 r
F
.74038 .70038 m .74064 .70332 L .74037 .70038 L F
.74064 .70332 m .74064 .70332 L .74037 .70038 L F
.74048 .70037 m .74157 .70297 L .74067 .70331 L .519 .305 .529 r
F
.7415 .70005 m .74186 .7002 L .74174 .69994 L .656 .814 .96 r
F
.74056 .70045 m .74077 .7005 L .7415 .70005 L F
.74077 .7005 m .74117 .70093 L .74143 .70067 L F
.74056 .70045 m .74067 .70056 L .74077 .7005 L F
.74171 .6999 m .74195 .70282 L .74048 .70037 L .519 .305 .529 r
F
.74199 .70281 m .74197 .70282 L .74226 .70294 L .655 .815 .96 r
F
.74197 .70282 m .74089 .70327 L .74146 .70314 L F
.74197 .70282 m .74146 .70314 L .74226 .70294 L F
.74541 .70777 m .74491 .70479 L .74848 .70328 L .512 .324 .562 r
F
.7414 .70884 m .74491 .70479 L .74541 .70777 L .595 .38 .559 r
F
.74106 .70345 m .74324 .70561 L .74562 .70461 L .655 .815 .96 r
F
.74224 .70295 m .74562 .70461 L .74226 .70294 L F
.74106 .70345 m .74163 .70359 L .74224 .70295 L F
.74163 .70359 m .74562 .70461 L .74224 .70295 L F
.74226 .70294 m .74562 .70461 L .74755 .70337 L F
.74226 .70294 m .74305 .70301 L .74322 .70233 L F
.74305 .70301 m .74755 .70337 L .74328 .70234 L F
.74305 .70301 m .74328 .70234 L .74322 .70233 L F
.74509 .7016 m .74843 .70325 L .7513 .70141 L .656 .814 .96 r
F
.74322 .70233 m .74755 .70337 L .74889 .70199 L .655 .815 .96 r
F
.74322 .70233 m .74889 .70199 L .74389 .70163 L F
.74273 .69928 m .74334 .70178 L .74292 .70223 L .157 .044 .463 r
F
.74179 .69987 m .74262 .70242 L .74198 .70282 L .379 .203 .512 r
F
.74195 .70282 m .74157 .70297 L .74048 .70037 L .519 .305 .529 r
F
.74089 .70327 m .74188 .7031 L .74226 .70294 L .655 .815 .96 r
F
.74172 .69989 m .74179 .69987 L .74198 .70282 L .519 .305 .529 r
F
.74196 .70282 m .74198 .70282 L .74207 .70417 L F
.74172 .69989 m .74198 .70282 L .74196 .70282 L F
.74267 .69932 m .74174 .69994 L .7427 .69933 L .656 .814 .96 r
F
.74038 .70038 m .74037 .70038 L .73398 .62986 L .638 .394 .533 r
F
.73591 .62976 m .74171 .6999 L .74048 .70037 L .519 .305 .529 r
F
.73599 .62974 m .74179 .69987 L .74172 .69989 L F
.73599 .62974 m .74172 .69989 L .73599 .62974 L F
.74172 .69989 m .74172 .69989 L .73599 .62974 L F
.73398 .62986 m .74037 .70038 L .73852 .7007 L .638 .394 .533 r
F
.74048 .70037 m .73923 .7008 L .74056 .70045 L .656 .814 .96 r
F
.73916 .70059 m .73923 .7008 L .74048 .70037 L F
.73409 .62986 m .73411 .62985 L .74038 .70038 L .638 .394 .533 r
F
.74038 .70038 m .74038 .70038 L .74075 .70459 L F
.73409 .62986 m .74038 .70038 L .74038 .70038 L F
.74048 .70037 m .74056 .70045 L .74093 .70029 L .656 .814 .96 r
F
.73519 .62995 m .73514 .63006 L .73523 .63008 L .599 .766 .959 r
F
.73411 .62985 m .73591 .62976 L .74075 .70459 L .638 .394 .533 r
F
.73599 .62974 m .74172 .69989 L .73591 .62976 L .519 .305 .529 r
F
.74172 .69989 m .74207 .70417 L .74171 .6999 L F
.74172 .69989 m .74171 .6999 L .73591 .62976 L F
.73839 .69828 m .74048 .70037 L .74048 .70036 L .656 .814 .96 r
F
.74168 .69991 m .74048 .70036 L .74174 .69994 L F
.73839 .69828 m .74048 .70036 L .74168 .69991 L F
.74048 .70037 m .74093 .70029 L .74174 .69994 L F
.73839 .69828 m .7417 .69992 L .74267 .69932 L F
.7417 .69992 m .74174 .69994 L .74267 .69932 L F
.74142 .68314 m .74053 .66576 L .74273 .69928 L .379 .203 .512 r
F
.74269 .6993 m .74273 .69928 L .74292 .70223 L F
.74142 .68314 m .74273 .69928 L .74269 .6993 L F
.7429 .70224 m .74292 .70223 L .74301 .70361 L F
.74142 .68314 m .74269 .6993 L .74268 .69931 L F
.73839 .69828 m .74267 .69932 L .74336 .69864 L .656 .814 .96 r
F
.74267 .69932 m .7427 .69933 L .74277 .69925 L F
.74267 .69932 m .74277 .69925 L .74336 .69864 L F
.74268 .69931 m .74292 .70223 L .7429 .70224 L .379 .203 .512 r
F
.74269 .6993 m .74292 .70223 L .74268 .69931 L F
.74224 .70188 m .74272 .7026 L .74255 .70095 L .656 .814 .96 r
F
.74289 .70225 m .74199 .70281 L .74322 .70233 L .655 .815 .96 r
F
.74199 .70281 m .74199 .70281 L .74289 .70225 L F
.74199 .70281 m .74226 .70294 L .74315 .70237 L F
.74199 .70281 m .74315 .70237 L .74322 .70233 L F
.74387 .70163 m .74322 .70233 L .74389 .70163 L F
.74174 .69994 m .74199 .70007 L .742 .70006 L .656 .814 .96 r
F
.74267 .69931 m .7429 .70224 L .74179 .69987 L .379 .203 .512 r
F
.74186 .7002 m .74199 .70007 L .74174 .69994 L .656 .814 .96 r
F
.7429 .70224 m .74262 .70242 L .74179 .69987 L .379 .203 .512 r
F
.7427 .69933 m .74834 .699 L .74336 .69864 L .656 .814 .96 r
F
.74332 .69865 m .74335 .69862 L .74354 .70156 L .157 .044 .463 r
F
.74332 .69865 m .74354 .70156 L .74353 .70158 L F
.74335 .69862 m .74372 .70105 L .74354 .70156 L 0 0 .297 r
F
.74268 .69931 m .7429 .70224 L .74267 .69931 L .379 .203 .512 r
F
.7429 .70224 m .74301 .70361 L .7429 .70224 L F
.7429 .70224 m .7429 .70224 L .74267 .69931 L F
.74332 .69865 m .74353 .70158 L .74331 .69865 L .157 .044 .463 r
F
.74353 .70158 m .74363 .70295 L .74353 .70158 L F
.74353 .70158 m .74353 .70158 L .74331 .69865 L F
.74377 .70133 m .74387 .70163 L .74403 .70133 L .655 .815 .96 r
F
.74331 .69865 m .74353 .70158 L .74273 .69928 L .157 .044 .463 r
F
.7435 .70161 m .74292 .70223 L .74387 .70163 L .655 .815 .96 r
F
.74353 .70158 m .74363 .70295 L .74334 .70178 L .157 .044 .463 r
F
.74353 .70158 m .74334 .70178 L .74273 .69928 L F
.74336 .69864 m .74834 .699 L .74899 .69757 L .656 .814 .96 r
F
.74336 .69864 m .74899 .69757 L .74369 .69793 L F
.73839 .69828 m .74336 .69864 L .74369 .69793 L F
.739 .62767 m .74323 .697 L .74361 .69786 L .925 .667 .181 r
F
.73839 .69828 m .74369 .69793 L .74365 .69724 L .656 .814 .96 r
F
.74359 .6979 m .7438 .70082 L .74359 .6979 L 0 0 .297 r
F
.74377 .70133 m .74403 .70133 L .74394 .70114 L .655 .815 .96 r
F
.7438 .70082 m .7438 .70082 L .74359 .6979 L 0 0 .297 r
F
.74268 .69931 m .7429 .70224 L .74268 .69931 L .379 .203 .512 r
F
.7429 .70224 m .74301 .70361 L .7429 .70224 L F
.7429 .70224 m .7429 .70224 L .74268 .69931 L F
.74332 .69865 m .74353 .70158 L .74332 .69865 L .157 .044 .463 r
F
.74353 .70158 m .74363 .70295 L .74353 .70158 L F
.74353 .70158 m .74353 .70158 L .74332 .69865 L F
.74292 .70223 m .74322 .70233 L .74387 .70163 L .655 .815 .96 r
F
.74289 .70225 m .7429 .70225 L .74292 .70223 L F
.7429 .70225 m .74322 .70233 L .74292 .70223 L F
.74172 .69989 m .74207 .70417 L .74172 .69989 L .519 .305 .529 r
F
.74044 .70117 m .74064 .70332 L .73898 .70127 L .638 .394 .533 r
F
.73927 .70082 m .73943 .70133 L .73981 .7011 L .656 .814 .96 r
F
.74044 .70117 m .73898 .70127 L .73852 .7007 L .638 .394 .533 r
F
.73923 .7008 m .73924 .70084 L .73927 .70082 L .656 .814 .96 r
F
.74037 .70038 m .74044 .70117 L .73852 .7007 L .638 .394 .533 r
F
.73888 .70128 m .74375 .70095 L .7436 .70034 L .655 .815 .96 r
F
.74375 .70095 m .74386 .70094 L .7438 .70081 L F
.7438 .70082 m .74372 .70105 L .74335 .69862 L 0 0 .297 r
F
.74375 .70095 m .7438 .70081 L .7436 .70034 L .655 .815 .96 r
F
.74359 .6979 m .7438 .70082 L .74335 .69862 L 0 0 .297 r
F
.74375 .70095 m .74377 .70133 L .74386 .70094 L .655 .815 .96 r
F
.7438 .70082 m .74389 .70215 L .74372 .70105 L 0 0 .297 r
F
.7438 .70082 m .74389 .70215 L .7438 .70082 L F
.73888 .70128 m .74363 .70133 L .74375 .70095 L .655 .815 .96 r
F
.74363 .70133 m .74377 .70133 L .74375 .70095 L F
.7435 .70161 m .74387 .70163 L .74377 .70133 L F
.74372 .70105 m .74389 .70215 L .74354 .70156 L 0 0 .297 r
F
.74359 .6979 m .74361 .69786 L .7436 .69801 L F
.73726 .6294 m .74053 .66576 L .74142 .68314 L .379 .203 .512 r
F
.73729 .62938 m .73728 .62941 L .73732 .6294 L .599 .766 .959 r
F
.73753 .62953 m .73804 .63036 L .73819 .62994 L F
.73726 .6294 m .73813 .62896 L .74053 .66576 L .379 .203 .512 r
F
.73448 .62272 m .73735 .62451 L .73782 .62427 L .6 .765 .958 r
F
.73688 .62453 m .73782 .62427 L .73693 .62472 L .379 .203 .512 r
F
.73826 .62142 m .73714 .62123 L .73829 .62201 L .928 .626 .449 r
F
.7371 .62059 m .73713 .62122 L .73714 .62123 L .818 .533 .507 r
F
.73448 .62272 m .73774 .62142 L .73681 .62112 L .6 .765 .958 r
F
.73448 .62272 m .73647 .62495 L .73735 .62451 L F
.73586 .62021 m .73458 .62008 L .73461 .62066 L .735 .468 .525 r
F
.73448 .62272 m .73592 .62084 L .7359 .62083 L .6 .765 .958 r
F
.73448 .62272 m .7359 .62083 L .7349 .6207 L F
.7371 .62059 m .73586 .62021 L .7359 .62083 L .818 .533 .507 r
F
.7371 .62059 m .7359 .62083 L .73699 .62118 L F
.73592 .62084 m .74339 .61665 L .7399 .61567 L .6 .765 .958 r
F
.73448 .62272 m .73681 .62112 L .73592 .62084 L F
.73681 .62112 m .74339 .61665 L .73592 .62084 L F
.73838 .62117 m .74832 .61974 L .74626 .61803 L F
.73448 .62272 m .74042 .62144 L .73838 .62117 L F
.74042 .62144 m .74832 .61974 L .73838 .62117 L F
.73839 .69828 m .73916 .70059 L .74048 .70037 L .656 .814 .96 r
F
.73445 .62762 m .73642 .62982 L .73729 .62938 L .599 .766 .959 r
F
.73445 .62762 m .73753 .62953 L .73812 .62897 L F
.7359 .62083 m .73613 .62552 L .7362 .62553 L .735 .468 .525 r
F
.73445 .62762 m .7373 .62568 L .73607 .62552 L .599 .766 .959 r
F
.73589 .62083 m .73612 .62552 L .7359 .62083 L .735 .468 .525 r
F
.73713 .62122 m .7362 .62553 L .73736 .6259 L .818 .533 .507 r
F
.73714 .62123 m .73737 .6259 L .73745 .62593 L F
.73445 .62762 m .73815 .62615 L .7371 .62582 L .599 .766 .959 r
F
.73713 .62122 m .73736 .6259 L .73714 .62123 L .818 .533 .507 r
F
.75871 .62679 m .77072 .63124 L .77644 .62617 L .601 .765 .958 r
F
.75871 .62679 m .77644 .62617 L .7625 .6234 L F
.74858 .62552 m .76265 .62831 L .76456 .6245 L .6 .765 .958 r
F
.74858 .62552 m .76456 .6245 L .74952 .62361 L F
.73861 .62672 m .74942 .62654 L .7483 .62464 L .599 .766 .959 r
F
.73445 .62762 m .7394 .62726 L .73861 .62672 L F
.7394 .62726 m .74942 .62654 L .73861 .62672 L F
.7421 .69632 m .7421 .69632 L .73853 .62667 L .928 .626 .449 r
F
.7421 .69632 m .73853 .62667 L .73853 .62667 L F
.73839 .69828 m .74211 .69633 L .74204 .69629 L .656 .814 .96 r
F
.73888 .70128 m .74322 .6998 L .74249 .69939 L .655 .815 .96 r
F
.73852 .62666 m .7421 .69632 L .73853 .62667 L .928 .626 .449 r
F
.73839 .69828 m .74286 .69675 L .74268 .69665 L .656 .814 .96 r
F
.7386 .62672 m .7421 .69632 L .74321 .69695 L .928 .626 .449 r
F
.74211 .69633 m .74308 .69649 L .74215 .69631 L .656 .814 .96 r
F
.73839 .69828 m .74268 .69665 L .74211 .69633 L F
.74268 .69665 m .74308 .69649 L .74211 .69633 L F
.73852 .62666 m .73745 .62593 L .74204 .69629 L .928 .626 .449 r
F
.73897 .6276 m .7386 .62672 L .74321 .69695 L .925 .667 .181 r
F
.73897 .6276 m .74321 .69695 L .74323 .69699 L F
.73897 .62761 m .74323 .69699 L .739 .62767 L F
.74323 .69699 m .74323 .697 L .739 .62767 L F
.73897 .6276 m .74323 .69699 L .73897 .62761 L F
.74323 .69699 m .74323 .69699 L .73897 .62761 L F
.73839 .69828 m .74365 .69724 L .74326 .69662 L .656 .814 .96 r
F
.73888 .70128 m .74249 .69939 L .74223 .69924 L .655 .815 .96 r
F
.74361 .69786 m .74352 .70017 L .7438 .70081 L .925 .667 .181 r
F
.74323 .69699 m .74341 .69991 L .74323 .697 L F
.74341 .69991 m .74341 .69991 L .74323 .697 L F
.74323 .69699 m .74321 .69695 L .7434 .6999 L F
.74323 .69699 m .7434 .6999 L .74341 .69991 L F
.74323 .69699 m .74341 .69991 L .74323 .69699 L F
.73888 .70128 m .7436 .70034 L .74322 .6998 L .655 .815 .96 r
F
.7436 .70034 m .74404 .70025 L .7434 .6999 L F
.7436 .70034 m .7434 .6999 L .74322 .6998 L F
.74323 .697 m .74341 .69991 L .74361 .69786 L .925 .667 .181 r
F
.74341 .69991 m .74349 .70113 L .74352 .70017 L F
.74341 .69991 m .74352 .70017 L .74361 .69786 L F
.74341 .69991 m .74349 .70113 L .74341 .69991 L F
.74341 .69991 m .74341 .69991 L .74323 .69699 L F
.74334 .69976 m .74418 .70023 L .74378 .69961 L .655 .815 .96 r
F
.74321 .69695 m .74255 .69942 L .7434 .6999 L .928 .626 .449 r
F
.74322 .6998 m .74339 .69987 L .74334 .69976 L .655 .815 .96 r
F
.74339 .69987 m .74418 .70023 L .74334 .69976 L F
.74404 .70025 m .74418 .70023 L .74322 .6998 L F
.7434 .6999 m .7423 .70033 L .74349 .70113 L .928 .626 .449 r
F
.74255 .69942 m .7423 .70033 L .7434 .6999 L F
.74223 .69924 m .74103 .69996 L .7423 .70033 L .818 .533 .507 r
F
.74204 .69629 m .74128 .69906 L .74223 .69924 L F
.73888 .70128 m .74223 .69924 L .74157 .69911 L .655 .815 .96 r
F
.74128 .69906 m .74103 .69996 L .74223 .69924 L .818 .533 .507 r
F
.74157 .69911 m .74223 .69924 L .74174 .69897 L .655 .815 .96 r
F
.7421 .69632 m .7423 .70033 L .74321 .69695 L .928 .626 .449 r
F
.74174 .69897 m .74305 .6991 L .74203 .69874 L .655 .815 .96 r
F
.74249 .69939 m .74305 .6991 L .74174 .69897 L F
.7421 .69632 m .74204 .69629 L .74223 .69924 L .928 .626 .449 r
F
.74225 .69925 m .74223 .69924 L .7423 .70033 L F
.7421 .69632 m .74223 .69924 L .74225 .69925 L F
.73852 .62666 m .74204 .69629 L .7421 .69632 L F
.7421 .69632 m .74225 .69925 L .7421 .69632 L F
.7421 .69632 m .7421 .69632 L .73853 .62667 L F
.74268 .69665 m .74326 .69662 L .74308 .69649 L .656 .814 .96 r
F
.74286 .69675 m .74326 .69662 L .74268 .69665 L F
.74215 .69631 m .74308 .69649 L .74253 .69611 L F
.73736 .6259 m .74084 .69606 L .73737 .6259 L .818 .533 .507 r
F
.73839 .69828 m .74204 .69629 L .74108 .6961 L .656 .814 .96 r
F
.74084 .69606 m .74084 .69606 L .73737 .6259 L .818 .533 .507 r
F
.73745 .62593 m .74085 .69606 L .74204 .69629 L F
.73737 .6259 m .74084 .69606 L .73745 .62593 L F
.74084 .69606 m .74085 .69606 L .73745 .62593 L F
.73839 .69828 m .74108 .6961 L .74078 .69605 L .656 .814 .96 r
F
.74078 .69605 m .73996 .69899 L .74097 .699 L .735 .468 .525 r
F
.73888 .70128 m .74049 .69899 L .73966 .69898 L .655 .815 .96 r
F
.73839 .69828 m .74078 .69605 L .73996 .69604 L .656 .814 .96 r
F
.73445 .62762 m .73607 .62552 L .73492 .62536 L .599 .766 .959 r
F
.73169 .61623 m .73162 .61624 L .73189 .62051 L .566 .34 .531 r
F
.73267 .62069 m .73207 .61521 L .72828 .61575 L .6 .765 .958 r
F
.73448 .62272 m .73382 .62068 L .73267 .62069 L F
.73458 .62008 m .73325 .62017 L .73329 .62068 L .657 .408 .532 r
F
.73458 .62008 m .73329 .62068 L .73447 .62067 L F
.73325 .62017 m .73328 .62069 L .73329 .62068 L .566 .34 .531 r
F
.73325 .62017 m .73315 .62071 L .73328 .62069 L F
.73382 .62068 m .73207 .61521 L .73267 .62069 L .6 .765 .958 r
F
.73382 .62068 m .73604 .61518 L .73207 .61521 L F
.73448 .62272 m .7349 .62066 L .73382 .62068 L F
.73458 .62008 m .73447 .62067 L .7346 .62066 L .657 .408 .532 r
F
.73458 .62008 m .73483 .62536 L .73492 .62536 L F
.7349 .62066 m .73604 .61518 L .73382 .62068 L .6 .765 .958 r
F
.7346 .62066 m .73359 .62538 L .73483 .62536 L .657 .408 .532 r
F
.73447 .62067 m .73359 .62538 L .7346 .62066 L F
.73447 .62067 m .73329 .62068 L .73359 .62538 L F
.73224 .62957 m .73852 .7007 L .73842 .7007 L .753 .483 .523 r
F
.73839 .69828 m .73787 .70081 L .73916 .70059 L .656 .814 .96 r
F
.73839 .69828 m .73674 .70062 L .7379 .70067 L F
.73107 .6291 m .73659 .7006 L .73101 .62907 L .857 .566 .495 r
F
.73659 .7006 m .73659 .7006 L .73101 .62907 L F
.73107 .6291 m .73213 .62955 L .73664 .70061 L F
.73107 .6291 m .73664 .70061 L .73659 .7006 L F
.73839 .69828 m .7358 .70036 L .73674 .70062 L .656 .814 .96 r
F
.7358 .70036 m .73556 .70056 L .73664 .70061 L F
.7358 .70036 m .73664 .70061 L .73674 .70062 L F
.73673 .70064 m .73648 .70098 L .73784 .70097 L F
.73719 .70367 m .73574 .7038 L .73697 .70399 L .655 .815 .96 r
F
.73659 .7006 m .73664 .70061 L .73683 .70356 L .857 .566 .495 r
F
.73659 .7006 m .73683 .70356 L .73682 .70356 L F
.73842 .7007 m .73852 .7007 L .73871 .70365 L .753 .483 .523 r
F
.73842 .7007 m .73868 .70365 L .73842 .7007 L F
.73868 .70365 m .73878 .70479 L .73868 .70365 L F
.73868 .70365 m .73868 .70365 L .73842 .7007 L F
.73683 .70356 m .73574 .7038 L .73719 .70367 L .655 .815 .96 r
F
.73625 .70339 m .73608 .70352 L .73683 .70356 L F
.73608 .70352 m .73574 .7038 L .73683 .70356 L F
.73664 .70061 m .73818 .70362 L .73683 .70356 L .753 .483 .523 r
F
.7384 .70363 m .73697 .70399 L .73833 .70399 L .655 .815 .96 r
F
.73787 .70081 m .73784 .70098 L .73916 .70059 L .656 .814 .96 r
F
.7379 .70067 m .73673 .70064 L .73784 .70097 L F
.73674 .70062 m .73673 .70064 L .7379 .70067 L F
.73842 .7007 m .73868 .70365 L .73664 .70061 L .753 .483 .523 r
F
.73868 .70365 m .73818 .70362 L .73664 .70061 L F
.73888 .70128 m .73726 .70358 L .7384 .70363 L .655 .815 .96 r
F
.73726 .70358 m .73697 .70399 L .7384 .70363 L F
.73868 .70365 m .73878 .70479 L .73818 .70362 L .753 .483 .523 r
F
.73683 .70356 m .73878 .70479 L .73689 .70454 L F
.73726 .70358 m .73683 .70356 L .73719 .70367 L .655 .815 .96 r
F
.73818 .70362 m .73878 .70479 L .73683 .70356 L .753 .483 .523 r
F
.73659 .7006 m .73682 .70356 L .73659 .7006 L .857 .566 .495 r
F
.73682 .70356 m .73689 .70454 L .73682 .70356 L F
.73682 .70356 m .73682 .70356 L .73659 .7006 L F
.73496 .70007 m .73434 .7004 L .73535 .70073 L .656 .814 .96 r
F
.73434 .7004 m .73425 .70044 L .73434 .70047 L F
.73434 .7004 m .73434 .70047 L .73535 .70073 L F
.72998 .62719 m .72993 .62788 L .73442 .69919 L 0 0 .132 r
F
.73029 .62851 m .73547 .70025 L .73479 .69979 L .947 .644 .431 r
F
.7351 .7 m .73352 .69994 L .73425 .70044 L .656 .814 .96 r
F
.73034 .62855 m .73548 .70025 L .73029 .62851 L .947 .644 .431 r
F
.73548 .70025 m .73547 .70025 L .73029 .62851 L F
.73651 .70094 m .73526 .7008 L .73648 .70098 L .656 .814 .96 r
F
.73674 .70062 m .73614 .70069 L .73651 .70094 L F
.73614 .70069 m .73526 .7008 L .73651 .70094 L F
.73034 .62855 m .73101 .62907 L .73551 .70027 L .947 .644 .431 r
F
.73556 .70056 m .73526 .7008 L .73614 .70069 L .656 .814 .96 r
F
.73597 .70058 m .73614 .70069 L .73674 .70062 L F
.73556 .70056 m .73614 .70069 L .73597 .70058 L F
.73548 .70025 m .7357 .70322 L .73569 .70322 L .947 .644 .431 r
F
.73034 .62855 m .73548 .70026 L .73548 .70025 L F
.73548 .70026 m .7357 .70322 L .73548 .70025 L F
.73548 .70026 m .73551 .70027 L .7357 .70322 L F
.73034 .62855 m .73551 .70027 L .73548 .70026 L F
.73569 .70322 m .7357 .70322 L .73575 .70407 L F
.7345 .69961 m .73352 .69994 L .7351 .7 L .656 .814 .96 r
F
.73477 .69977 m .73497 .70274 L .73477 .69977 L .965 .686 .26 r
F
.73457 .70274 m .73456 .70288 L .73535 .70312 L .655 .815 .96 r
F
.73497 .70274 m .73502 .7035 L .73497 .70274 L .965 .686 .26 r
F
.73497 .70274 m .73497 .70274 L .73477 .69977 L F
.73546 .70306 m .73509 .70293 L .73535 .70312 L .655 .815 .96 r
F
.73509 .70293 m .73457 .70274 L .73514 .70302 L F
.73509 .70293 m .73514 .70302 L .73535 .70312 L F
.73546 .70306 m .73524 .70318 L .73612 .7035 L F
.73548 .70025 m .73575 .70407 L .73547 .70025 L .947 .644 .431 r
F
.73477 .69977 m .73479 .69979 L .73497 .70274 L .965 .686 .26 r
F
.73477 .69977 m .73497 .70274 L .73497 .70274 L F
.73551 .70027 m .73614 .70221 L .73564 .70238 L .857 .566 .495 r
F
.73614 .70221 m .73655 .70348 L .73564 .70238 L F
.73564 .70238 m .73655 .70348 L .7357 .70322 L F
.73659 .7006 m .73689 .70454 L .73551 .70027 L F
.73479 .69979 m .73569 .70322 L .73497 .70274 L .947 .644 .431 r
F
.73573 .70042 m .73519 .70018 L .73535 .70073 L .656 .814 .96 r
F
.73519 .70018 m .73496 .70007 L .73498 .70012 L F
.73519 .70018 m .73498 .70012 L .73535 .70073 L F
.7351 .7 m .73496 .70007 L .73573 .70042 L F
.73547 .70025 m .73569 .70322 L .73479 .69979 L .947 .644 .431 r
F
.72998 .62719 m .73442 .69919 L .73442 .69916 L 0 0 .132 r
F
.72998 .62719 m .73442 .69916 L .72998 .62715 L F
.73442 .69916 m .73442 .69916 L .72998 .62715 L F
.72998 .62715 m .73442 .69916 L .73139 .64952 L F
.73442 .69916 m .73442 .69914 L .73139 .64952 L F
.73139 .64952 m .73442 .69914 L .73447 .69845 L F
.73839 .69828 m .7339 .69917 L .73352 .69994 L .656 .814 .96 r
F
.7339 .69917 m .73312 .69932 L .73342 .69978 L F
.7339 .69917 m .73342 .69978 L .73352 .69994 L F
.73477 .69977 m .73497 .70274 L .73442 .69919 L .965 .686 .26 r
F
.73497 .70274 m .7349 .70262 L .73442 .69919 L F
.73839 .69828 m .7345 .69961 L .7351 .7 L .656 .814 .96 r
F
.73839 .69828 m .7351 .7 L .73573 .70042 L F
.73442 .69919 m .7349 .70262 L .73461 .70214 L .965 .686 .26 r
F
.72381 .62349 m .71957 .62379 L .72777 .62416 L .6 .765 .958 r
F
.72808 .62636 m .72215 .62309 L .72028 .62481 L .599 .766 .959 r
F
.73046 .62157 m .73071 .62632 L .73076 .62626 L .076 0 .438 r
F
.73046 .62157 m .73071 .62632 L .73046 .62157 L F
.73445 .62762 m .73007 .626 L .72808 .62636 L .599 .766 .959 r
F
.73007 .626 m .72215 .62309 L .72808 .62636 L F
.73328 .62069 m .7335 .6254 L .73329 .62068 L .566 .34 .531 r
F
.73839 .69828 m .73439 .69855 L .7339 .69917 L .656 .814 .96 r
F
.73183 .62486 m .73183 .62491 L .73182 .62485 L .857 .566 .495 r
F
.73191 .62093 m .73076 .62626 L .73212 .62567 L .414 .228 .517 r
F
.7318 .62098 m .73076 .62626 L .73191 .62093 L F
.7318 .62098 m .73046 .62157 L .73076 .62626 L F
.7292 .62241 m .71944 .62183 L .72958 .62307 L .6 .765 .958 r
F
.72965 .62307 m .72381 .62349 L .7296 .62377 L F
.73445 .62762 m .72486 .62167 L .72215 .62309 L .599 .766 .959 r
F
.73191 .62093 m .73212 .62567 L .73221 .62563 L .414 .228 .517 r
F
.73191 .62093 m .73212 .62567 L .73191 .62093 L F
.73328 .62069 m .73221 .62563 L .7335 .6254 L .566 .34 .531 r
F
.73315 .62071 m .73221 .62563 L .73328 .62069 L F
.7302 .62187 m .73037 .6212 L .7285 .62153 L .6 .765 .958 r
F
.73037 .6212 m .7222 .61819 L .7285 .62153 L F
.73275 .62078 m .73191 .62093 L .73173 .62101 L F
.73315 .62071 m .73191 .62093 L .73221 .62563 L .566 .34 .531 r
F
.7297 .62244 m .72969 .62243 L .72969 .62246 L .6 .765 .958 r
F
.72968 .62233 m .72964 .62314 L .72964 .62318 L 0 0 .132 r
F
.72968 .62233 m .72964 .62318 L .72968 .62247 L F
.72969 .62243 m .7292 .62241 L .72965 .62307 L .6 .765 .958 r
F
.73445 .62762 m .72824 .62066 L .72486 .62167 L .599 .766 .959 r
F
.7335 .6254 m .7335 .6254 L .73329 .62068 L .566 .34 .531 r
F
.73329 .62068 m .7335 .6254 L .73359 .62538 L F
.73275 .62078 m .73261 .62062 L .73191 .62093 L .6 .765 .958 r
F
.73189 .62051 m .7318 .62098 L .73191 .62093 L .414 .228 .517 r
F
.73261 .62062 m .72828 .61575 L .73173 .62101 L .6 .765 .958 r
F
.73087 .62139 m .73167 .62097 L .73037 .6212 L F
.73173 .62101 m .73167 .62097 L .73087 .62139 L F
.73167 .62097 m .72491 .61677 L .73037 .6212 L F
.73044 .6213 m .73046 .62157 L .73046 .62157 L .076 0 .438 r
F
.73068 .62132 m .73037 .6212 L .7302 .62187 L .6 .765 .958 r
F
.73445 .62762 m .73204 .62012 L .72824 .62066 L .599 .766 .959 r
F
.73071 .62632 m .7345 .69841 L .73076 .62626 L .076 0 .438 r
F
.7345 .69841 m .73451 .69841 L .73076 .62626 L F
.73076 .62626 m .73451 .69841 L .73526 .69746 L F
.73317 .69863 m .7334 .69792 L .73308 .69863 L .656 .814 .96 r
F
.73071 .62632 m .72998 .62715 L .73447 .69845 L .076 0 .438 r
F
.73839 .69828 m .73481 .69802 L .73439 .69855 L .656 .814 .96 r
F
.73399 .70224 m .73354 .70163 L .73358 .70232 L .655 .815 .96 r
F
.73442 .69916 m .73442 .69919 L .73461 .70214 L 0 0 .132 r
F
.73442 .69916 m .73461 .70214 L .73461 .70214 L F
.73442 .69916 m .73461 .70214 L .73442 .69916 L F
.73519 .7031 m .73398 .70294 L .73524 .70318 L .655 .815 .96 r
F
.73457 .70274 m .73358 .70232 L .73398 .70294 L F
.73888 .70128 m .73461 .70212 L .73457 .70274 L F
.73461 .70212 m .73358 .70232 L .73457 .70274 L F
.73442 .69916 m .73461 .70214 L .73442 .69914 L 0 0 .132 r
F
.73461 .70214 m .73461 .70215 L .73465 .70282 L .965 .686 .26 r
F
.73461 .70215 m .73502 .7035 L .73465 .70282 L F
.73461 .70214 m .73465 .70282 L .73461 .70213 L 0 0 .132 r
F
.73461 .70214 m .73461 .70213 L .73442 .69914 L F
.73461 .70214 m .73465 .70282 L .73461 .70214 L F
.73461 .70214 m .73461 .70214 L .73442 .69916 L F
.73461 .70212 m .73453 .70157 L .73399 .70224 L .655 .815 .96 r
F
.73888 .70128 m .73465 .70156 L .73461 .70212 L F
.73442 .69914 m .73465 .70282 L .73447 .69845 L 0 0 .132 r
F
.73465 .70156 m .73453 .70157 L .73461 .70212 L .655 .815 .96 r
F
.73453 .70157 m .73354 .70163 L .73399 .70224 L F
.7345 .69841 m .73447 .69845 L .73466 .7014 L .076 0 .438 r
F
.7345 .69841 m .73466 .7014 L .73466 .70139 L F
.73453 .70157 m .73386 .70092 L .73354 .70163 L .655 .815 .96 r
F
.73466 .7014 m .73465 .70282 L .73469 .70202 L 0 0 .132 r
F
.73447 .69845 m .73462 .70201 L .73466 .7014 L F
.73462 .70201 m .73465 .70282 L .73466 .7014 L F
.73888 .70128 m .73498 .701 L .73466 .7014 L .655 .815 .96 r
F
.73465 .70156 m .73466 .7014 L .73453 .70157 L F
.73888 .70128 m .73466 .7014 L .73465 .70156 L F
.73071 .62632 m .73447 .69845 L .7345 .69841 L .076 0 .438 r
F
.73212 .62567 m .73076 .62626 L .73526 .69746 L .414 .228 .517 r
F
.73839 .69828 m .73518 .6975 L .73432 .69799 L .656 .814 .96 r
F
.73212 .62567 m .73526 .69746 L .73532 .69742 L .414 .228 .517 r
F
.73212 .62567 m .73532 .69742 L .73221 .62563 L F
.73532 .69742 m .73533 .69742 L .73221 .62563 L F
.73221 .62563 m .73533 .69742 L .73673 .69663 L F
.73839 .69828 m .73569 .69694 L .73443 .69732 L .656 .814 .96 r
F
.73507 .69664 m .7362 .69611 L .73502 .69661 L F
.7335 .6254 m .7368 .69661 L .73359 .62538 L .566 .34 .531 r
F
.73839 .69828 m .73673 .69663 L .73569 .69694 L .656 .814 .96 r
F
.73888 .70128 m .73692 .69958 L .73624 .69997 L .655 .815 .96 r
F
.73446 .70096 m .73453 .70022 L .73386 .70092 L F
.73888 .70128 m .73542 .70044 L .73498 .701 L F
.73544 .70041 m .73469 .70202 L .73548 .70102 L .076 0 .438 r
F
.73526 .69746 m .73479 .70123 L .73544 .70041 L F
.73479 .70123 m .73469 .70202 L .73544 .70041 L F
.73451 .69841 m .73466 .70139 L .73526 .69746 L F
.73466 .70139 m .73469 .70202 L .73479 .70123 L F
.73466 .70139 m .73479 .70123 L .73526 .69746 L F
.73542 .70044 m .73549 .6996 L .73453 .70022 L .655 .815 .96 r
F
.73532 .69742 m .73546 .7004 L .73533 .69742 L .414 .228 .517 r
F
.73546 .7004 m .73548 .70102 L .73546 .7004 L F
.73546 .7004 m .73546 .7004 L .73533 .69742 L F
.73888 .70128 m .73624 .69997 L .73542 .70044 L .655 .815 .96 r
F
.73673 .69663 m .7357 .70027 L .73692 .69958 L .414 .228 .517 r
F
.73624 .69997 m .73592 .69981 L .73544 .70041 L .655 .815 .96 r
F
.73624 .69997 m .73544 .70041 L .73542 .70044 L F
.73533 .69742 m .73546 .7004 L .73673 .69663 L .414 .228 .517 r
F
.73546 .7004 m .73548 .70102 L .7357 .70027 L F
.73546 .7004 m .7357 .70027 L .73673 .69663 L F
.73592 .69981 m .73549 .6996 L .73542 .70042 L .655 .815 .96 r
F
.73544 .70041 m .73542 .70042 L .73542 .70044 L F
.73592 .69981 m .73542 .70042 L .73544 .70041 L F
.73498 .701 m .7354 .70043 L .73446 .70096 L F
.73542 .70044 m .7354 .70043 L .73498 .701 L F
.73466 .70139 m .73466 .70139 L .73451 .69841 L .076 0 .438 r
F
.7354 .70043 m .73453 .70022 L .73446 .70096 L .655 .815 .96 r
F
.73532 .69742 m .73526 .69746 L .73544 .70041 L .414 .228 .517 r
F
.73546 .7004 m .73544 .70041 L .73548 .70102 L F
.73532 .69742 m .73544 .70041 L .73546 .7004 L F
.73692 .69958 m .73548 .70102 L .73696 .70025 L F
.7357 .70027 m .73548 .70102 L .73692 .69958 L F
.73888 .70128 m .73712 .69953 L .73692 .69958 L .655 .815 .96 r
F
.73624 .69997 m .73692 .69958 L .73601 .69986 L F
.73601 .69986 m .73669 .69909 L .73549 .6996 L F
.7368 .69661 m .7368 .69661 L .73359 .62538 L .566 .34 .531 r
F
.73359 .62538 m .7368 .69661 L .73813 .69622 L F
.7335 .6254 m .7368 .69661 L .7335 .6254 L F
.7368 .69661 m .7368 .69661 L .7335 .6254 L F
.7335 .6254 m .73221 .62563 L .73673 .69663 L F
.7368 .69661 m .73673 .69663 L .73692 .69958 L F
.7368 .69661 m .73692 .69958 L .73693 .69958 L F
.73839 .69828 m .73774 .69633 L .73673 .69663 L .656 .814 .96 r
F
.73445 .62762 m .73398 .62986 L .73515 .6298 L .599 .766 .959 r
F
.73445 .62762 m .73519 .62995 L .73628 .62967 L F
.73586 .62021 m .73589 .62083 L .7359 .62083 L .735 .468 .525 r
F
.73589 .62083 m .73461 .62066 L .73492 .62536 L F
.73586 .62021 m .73461 .62066 L .73589 .62083 L F
.7349 .6207 m .7359 .62083 L .73493 .62053 L .6 .765 .958 r
F
.73493 .62053 m .7399 .61567 L .73604 .61518 L F
.73592 .62084 m .7399 .61567 L .73493 .62053 L F
.73445 .62762 m .73601 .6201 L .73204 .62012 L .599 .766 .959 r
F
.73483 .62536 m .73819 .69621 L .73492 .62536 L .657 .408 .532 r
F
.73819 .69621 m .73819 .69621 L .73492 .62536 L F
.73492 .62536 m .73819 .69621 L .73947 .69603 L F
.73483 .62536 m .73359 .62538 L .73813 .69622 L F
.73483 .62536 m .73813 .69622 L .73819 .69621 L F
.73839 .69828 m .73894 .69557 L .73754 .69575 L .656 .814 .96 r
F
.7368 .69661 m .73693 .69958 L .73813 .69622 L .566 .34 .531 r
F
.73693 .69958 m .73696 .70025 L .73718 .69951 L F
.73693 .69958 m .73718 .69951 L .73813 .69622 L F
.7368 .69661 m .73693 .69958 L .7368 .69661 L F
.73693 .69958 m .73693 .69958 L .7368 .69661 L F
.73888 .70128 m .73819 .69921 L .73712 .69953 L .655 .815 .96 r
F
.73832 .69917 m .73696 .70025 L .73836 .69992 L .566 .34 .531 r
F
.73813 .69622 m .73718 .69951 L .73832 .69917 L F
.73718 .69951 m .73696 .70025 L .73832 .69917 L F
.73819 .69621 m .73833 .69917 L .73819 .69621 L .657 .408 .532 r
F
.7362 .62553 m .73954 .69603 L .74078 .69605 L .735 .468 .525 r
F
.73612 .62552 m .73954 .69603 L .73613 .62552 L F
.73954 .69603 m .73954 .69603 L .73613 .62552 L F
.73839 .69828 m .73996 .69604 L .73884 .69602 L .656 .814 .96 r
F
.73613 .62552 m .73972 .69983 L .7362 .62553 L .735 .468 .525 r
F
.73612 .62552 m .73492 .62536 L .73972 .69983 L F
.73884 .69602 m .74029 .69557 L .73894 .69557 L .656 .814 .96 r
F
.73996 .69604 m .74029 .69557 L .73884 .69602 L F
.73954 .69603 m .73972 .69983 L .73954 .69603 L .735 .468 .525 r
F
.73947 .69603 m .73833 .69917 L .73966 .69898 L .657 .408 .532 r
F
.73819 .69621 m .73833 .69917 L .73947 .69603 L F
.73819 .69621 m .73813 .69622 L .73832 .69917 L F
.73888 .70128 m .73937 .69885 L .73819 .69921 L .655 .815 .96 r
F
.73833 .69917 m .73832 .69917 L .73836 .69992 L .657 .408 .532 r
F
.73819 .69621 m .73832 .69917 L .73833 .69917 L F
.73818 .69919 m .73943 .69855 L .73803 .69874 L .655 .815 .96 r
F
.73819 .69921 m .73824 .69918 L .73818 .69919 L F
.73824 .69918 m .73943 .69855 L .73818 .69919 L F
.73937 .69885 m .73943 .69855 L .73819 .69921 L F
.7368 .69661 m .73696 .70025 L .7368 .69661 L .566 .34 .531 r
F
.73712 .69953 m .73803 .69874 L .73669 .69909 L .655 .815 .96 r
F
.73819 .69921 m .73803 .69874 L .73712 .69953 L F
.73693 .69958 m .73692 .69958 L .73696 .70025 L .566 .34 .531 r
F
.7335 .6254 m .73673 .69663 L .7368 .69661 L F
.73673 .69663 m .73772 .69627 L .73654 .69644 L .656 .814 .96 r
F
.73774 .69633 m .73772 .69627 L .73673 .69663 L F
.73654 .69644 m .73754 .69575 L .7362 .69611 L F
.73772 .69627 m .73754 .69575 L .73654 .69644 L F
.73712 .69953 m .73669 .69909 L .73601 .69986 L .655 .815 .96 r
F
.73693 .69958 m .73696 .70025 L .73693 .69958 L .566 .34 .531 r
F
.73569 .69694 m .73654 .69644 L .73507 .69664 L .656 .814 .96 r
F
.73673 .69663 m .73654 .69644 L .73569 .69694 L F
.73654 .69644 m .7362 .69611 L .73507 .69664 L F
.73443 .69732 m .73507 .69664 L .73406 .69723 L F
.73569 .69694 m .73507 .69664 L .73443 .69732 L F
.73507 .69664 m .73502 .69661 L .73495 .69665 L F
.73507 .69664 m .73495 .69665 L .73406 .69723 L F
.73432 .69799 m .73443 .69732 L .7334 .69792 L F
.73518 .6975 m .73443 .69732 L .73432 .69799 L F
.73443 .69732 m .73406 .69723 L .73379 .69751 L F
.73443 .69732 m .73379 .69751 L .7334 .69792 L F
.73498 .701 m .73386 .70092 L .73453 .70157 L .655 .815 .96 r
F
.7345 .69841 m .73466 .70139 L .73451 .69841 L .076 0 .438 r
F
.73466 .70139 m .73469 .70202 L .73466 .70139 L F
.73466 .70139 m .73466 .7014 L .73469 .70202 L F
.73439 .69855 m .73432 .69799 L .73317 .69863 L .656 .814 .96 r
F
.73481 .69802 m .73432 .69799 L .73439 .69855 L F
.73432 .69799 m .7334 .69792 L .73317 .69863 L F
.7339 .69917 m .73317 .69863 L .73312 .69932 L F
.73439 .69855 m .73317 .69863 L .7339 .69917 L F
.73317 .69863 m .73308 .69863 L .73308 .69868 L F
.73317 .69863 m .73308 .69868 L .73312 .69932 L F
.73484 .70265 m .73509 .70293 L .73497 .70274 L .655 .815 .96 r
F
.73497 .70274 m .73502 .7035 L .7349 .70262 L .965 .686 .26 r
F
.73484 .70265 m .73457 .70274 L .73509 .70293 L .655 .815 .96 r
F
.73497 .70274 m .73509 .70293 L .73546 .70306 L F
.73888 .70128 m .7349 .70263 L .73546 .70306 L F
.7349 .70263 m .73484 .70265 L .73497 .70274 L F
.7349 .70263 m .73497 .70274 L .73546 .70306 L F
.73457 .70274 m .73435 .70282 L .73456 .70288 L F
.73461 .70214 m .73461 .70214 L .73465 .70282 L 0 0 .132 r
F
.73497 .70274 m .73497 .70274 L .73502 .7035 L .965 .686 .26 r
F
.73524 .70318 m .73398 .70294 L .73472 .70345 L .655 .815 .96 r
F
.73535 .70312 m .73519 .7031 L .73524 .70318 L F
.73435 .70282 m .73398 .70294 L .73535 .70312 L F
.73888 .70128 m .73625 .70339 L .73683 .70356 L F
.73888 .70128 m .73683 .70356 L .73726 .70358 L F
.73682 .70356 m .73683 .70356 L .73689 .70454 L .857 .566 .495 r
F
.73492 .62536 m .73492 .62536 L .73496 .62514 L .599 .766 .959 r
F
.73589 .62083 m .73492 .62536 L .73612 .62552 L .735 .468 .525 r
F
.73492 .62536 m .73608 .6255 L .73563 .62535 L .599 .766 .959 r
F
.73492 .62536 m .73563 .62535 L .73496 .62514 L F
.73934 .69903 m .73966 .69898 L .73935 .69898 L .655 .815 .96 r
F
.73888 .70128 m .73966 .69898 L .73934 .69903 L F
.73966 .69898 m .73836 .69992 L .73972 .69983 L .657 .408 .532 r
F
.73833 .69917 m .73836 .69992 L .73966 .69898 L F
.73954 .69603 m .73972 .69983 L .74078 .69605 L .735 .468 .525 r
F
.73935 .69898 m .7408 .69855 L .73943 .69855 L .655 .815 .96 r
F
.74049 .69899 m .7408 .69855 L .73935 .69898 L F
.74084 .69606 m .74099 .699 L .74085 .69606 L .818 .533 .507 r
F
.74099 .699 m .74099 .699 L .74085 .69606 L F
.73888 .70128 m .74157 .69911 L .74054 .69891 L .655 .815 .96 r
F
.74084 .69606 m .74103 .69996 L .74084 .69606 L .818 .533 .507 r
F
.74085 .69606 m .74103 .69996 L .74204 .69629 L F
.73736 .6259 m .7362 .62553 L .74103 .69996 L F
.74054 .69891 m .74203 .69874 L .7408 .69855 L .655 .815 .96 r
F
.74157 .69911 m .74203 .69874 L .74054 .69891 L F
.74099 .699 m .74103 .69996 L .74099 .699 L .818 .533 .507 r
F
.74097 .699 m .73972 .69983 L .74103 .69996 L .735 .468 .525 r
F
.73996 .69899 m .73972 .69983 L .74097 .699 L F
.73996 .69604 m .74078 .69605 L .74006 .6959 L .656 .814 .96 r
F
.74006 .6959 m .74152 .69575 L .74029 .69557 L F
.74108 .6961 m .74152 .69575 L .74006 .6959 L F
.74108 .6961 m .74204 .69629 L .74134 .6959 L F
.73853 .62667 m .7421 .69632 L .7386 .62672 L .928 .626 .449 r
F
.74134 .6959 m .74253 .69611 L .74152 .69575 L .656 .814 .96 r
F
.74211 .69633 m .74253 .69611 L .74134 .6959 L F
.74225 .69925 m .74225 .69925 L .7421 .69632 L .928 .626 .449 r
F
.74225 .69925 m .7421 .69632 L .7421 .69632 L F
.73853 .62667 m .73853 .62667 L .73829 .62202 L F
.73736 .6259 m .73737 .6259 L .73714 .62123 L .818 .533 .507 r
F
.73612 .62552 m .73613 .62552 L .7359 .62083 L .735 .468 .525 r
F
.73699 .62118 m .7362 .62553 L .73713 .62122 L .818 .533 .507 r
F
.73699 .62118 m .7359 .62083 L .7362 .62553 L F
.73829 .62201 m .73714 .62123 L .73745 .62593 L .928 .626 .449 r
F
.73829 .62201 m .73852 .62666 L .73829 .62202 L F
.73852 .62666 m .73853 .62667 L .73829 .62202 L F
.73868 .62297 m .73829 .62202 L .7386 .62672 L .925 .667 .181 r
F
.73868 .62297 m .73869 .62297 L .73869 .62297 L .6 .765 .958 r
F
.73634 .62517 m .74337 .62156 L .73988 .62059 L .599 .766 .959 r
F
.73608 .6255 m .73649 .62528 L .73634 .62517 L F
.73649 .62528 m .74337 .62156 L .73634 .62517 L F
.73607 .62552 m .7361 .6255 L .73608 .6255 L F
.7361 .6255 m .74337 .62156 L .73608 .6255 L F
.7371 .62582 m .73882 .62588 L .7373 .62568 L F
.73815 .62615 m .73882 .62588 L .7371 .62582 L F
.7373 .62568 m .74624 .62294 L .74337 .62156 L F
.73882 .62588 m .74624 .62294 L .7373 .62568 L F
.7373 .62568 m .74337 .62156 L .73607 .62552 L F
.7371 .62059 m .73699 .62118 L .73713 .62122 L .818 .533 .507 r
F
.73607 .62552 m .73608 .6255 L .73492 .62536 L .599 .766 .959 r
F
.73496 .62514 m .73634 .62517 L .73513 .62435 L F
.73608 .6255 m .73634 .62517 L .73496 .62514 L F
.73681 .62112 m .74626 .61803 L .74339 .61665 L .6 .765 .958 r
F
.73774 .62142 m .74626 .61803 L .73681 .62112 L F
.73513 .62435 m .73988 .62059 L .73601 .6201 L .599 .766 .959 r
F
.73634 .62517 m .73988 .62059 L .73513 .62435 L F
.74225 .69925 m .7423 .70033 L .74225 .69925 L .928 .626 .449 r
F
.74249 .69939 m .74334 .69976 L .74305 .6991 L .655 .815 .96 r
F
.74322 .6998 m .74334 .69976 L .74249 .69939 L F
.74334 .69976 m .74378 .69961 L .74306 .6991 L F
.74334 .69976 m .74306 .6991 L .74305 .6991 L F
.73888 .70128 m .7435 .70161 L .74377 .70133 L F
.7438 .70081 m .74349 .70113 L .74389 .70215 L .925 .667 .181 r
F
.74352 .70017 m .74349 .70113 L .7438 .70081 L F
.7436 .70034 m .74422 .70092 L .74418 .70023 L .655 .815 .96 r
F
.74386 .70094 m .74422 .70092 L .7436 .70034 L F
.74341 .69991 m .74349 .70113 L .74341 .69991 L .925 .667 .181 r
F
.74377 .70133 m .74394 .70114 L .74386 .70094 L .655 .815 .96 r
F
.74387 .70163 m .74389 .70163 L .74389 .70162 L F
.74387 .70163 m .74389 .70162 L .74403 .70133 L F
.74386 .70094 m .74403 .70133 L .74422 .70092 L F
.74341 .69991 m .7434 .6999 L .74349 .70113 L .925 .667 .181 r
F
.74353 .70158 m .74354 .70156 L .74363 .70295 L .157 .044 .463 r
F
.73888 .70128 m .74289 .70225 L .74292 .70223 L .655 .815 .96 r
F
.73888 .70128 m .74292 .70223 L .7435 .70161 L F
.7429 .70224 m .74301 .70361 L .74262 .70242 L .379 .203 .512 r
F
.73888 .70128 m .74199 .70281 L .74289 .70225 L .655 .815 .96 r
F
.74354 .70156 m .74389 .70215 L .74363 .70295 L 0 0 .297 r
F
.74292 .70223 m .74363 .70295 L .74301 .70361 L .157 .044 .463 r
F
.74334 .70178 m .74363 .70295 L .74292 .70223 L F
.74198 .70282 m .74301 .70361 L .74207 .70417 L .379 .203 .512 r
F
.74262 .70242 m .74301 .70361 L .74198 .70282 L F
.74195 .70282 m .74207 .70417 L .74157 .70297 L .519 .305 .529 r
F
.73888 .70128 m .74086 .70324 L .74199 .70281 L .655 .815 .96 r
F
.74086 .70324 m .74089 .70327 L .74199 .70281 L F
.74089 .70327 m .74106 .70345 L .74188 .7031 L F
.74064 .70332 m .74075 .70459 L .74064 .70332 L .638 .394 .533 r
F
.73888 .70128 m .73962 .70349 L .74067 .70331 L .655 .815 .96 r
F
.74086 .70324 m .74067 .70331 L .74089 .70327 L F
.73888 .70128 m .74067 .70331 L .74086 .70324 L F
.74067 .70331 m .74207 .70417 L .74075 .70459 L .519 .305 .529 r
F
.74157 .70297 m .74207 .70417 L .74067 .70331 L F
.73791 .62624 m .7483 .62464 L .74624 .62294 L .599 .766 .959 r
F
.73861 .62672 m .7483 .62464 L .73791 .62624 L F
.74427 .69939 m .74701 .70037 L .74783 .69953 L .656 .814 .96 r
F
.74442 .69975 m .74701 .70037 L .74427 .69939 L F
.74702 .69907 m .74783 .69953 L .74834 .699 L F
.74461 .70018 m .7452 .70153 L .74701 .70037 L F
.74064 .70332 m .74075 .70459 L .74008 .70341 L .638 .394 .533 r
F
.74008 .70341 m .74075 .70459 L .73871 .70365 L F
.73888 .70128 m .7384 .70363 L .73871 .70365 L .655 .815 .96 r
F
.73888 .70128 m .73871 .70365 L .73962 .70349 L F
.73868 .70365 m .73871 .70365 L .73878 .70479 L .753 .483 .523 r
F
.73888 .70128 m .73546 .70306 L .7357 .70322 L .655 .815 .96 r
F
.73625 .70339 m .7357 .70322 L .73612 .7035 L F
.73888 .70128 m .7357 .70322 L .73625 .70339 L F
.7357 .70322 m .73689 .70454 L .73575 .70407 L .857 .566 .495 r
F
.73655 .70348 m .73689 .70454 L .7357 .70322 L F
.73524 .70318 m .73559 .70375 L .73574 .7038 L .655 .815 .96 r
F
.7349 .70262 m .73502 .7035 L .73461 .70214 L .965 .686 .26 r
F
.73497 .70274 m .73575 .70407 L .73502 .7035 L .947 .644 .431 r
F
.73569 .70322 m .73575 .70407 L .73497 .70274 L F
.72698 .63057 m .72121 .63045 L .72274 .63225 L .599 .766 .959 r
F
.72844 .6289 m .72121 .63045 L .72698 .63057 L F
.72121 .63045 m .72066 .63057 L .72076 .63065 L F
.72121 .63045 m .72076 .63065 L .72274 .63225 L F
.72974 .63081 m .72698 .63057 L .72561 .63361 L F
.72983 .62944 m .72698 .63057 L .72974 .63081 L F
.72698 .63057 m .72274 .63225 L .72469 .63318 L F
.72698 .63057 m .72469 .63318 L .72561 .63361 L F
.73978 .62958 m .74667 .63211 L .73938 .62859 L F
.74053 .63139 m .74395 .63351 L .73978 .62958 L F
.5642 .67526 m .55562 .66653 L .55536 .67136 L .863 .609 .554 r
F
0 g
.5642 .67526 m
.57079 .68002 L
s
.41065 .51633 m .42609 .50632 L .42652 .51193 L .593 .384 .567 r
F
.41106 .52196 m .41065 .51633 L .42652 .51193 L F
.39399 .52414 m .41065 .51633 L .41106 .52196 L .669 .441 .566 r
F
.40463 .50545 m .41065 .51633 L .42652 .51193 L .661 .803 .951 r
F
.39317 .50692 m .41065 .51633 L .40463 .50545 L F
0 g
.3936 .51851 m
.41065 .51633 L
s
.55562 .66653 m .55587 .6617 L .54542 .65894 L .797 .549 .563 r
F
0 g
.55587 .6617 m
.56469 .66562 L
s
.70922 .52081 m .69141 .5162 L .68611 .52199 L .658 .806 .954 r
F
.71312 .51823 m .69141 .5162 L .70922 .52081 L F
.27279 .66167 m .2734 .65686 L .2771 .65195 L 0 0 .287 r
F
0 g
.26703 .66085 m
.2734 .65686 L
s
.45278 .38522 m .47261 .36796 L .44691 .37709 L .657 .779 .939 r
F
.45278 .38522 m .48123 .38025 L .47261 .36796 L F
.26006 .65249 m .2732 .65679 L .27689 .65191 L .597 .767 .961 r
F
.23721 .66066 m .24212 .66774 L .24897 .66675 L .595 .768 .962 r
F
.73206 .40161 m .70832 .397 L .70903 .4038 L .667 .434 .559 r
F
0 g
.68706 .40925 m
.70903 .4038 L
s
.73206 .40161 m .73131 .39482 L .70832 .397 L .667 .434 .559 r
F
0 g
.68639 .40247 m
.70832 .397 L
s
.68753 .53326 m .66682 .53157 L .66319 .54055 L .657 .808 .956 r
F
0 g
.66319 .54055 m
.66405 .54915 L
s
.74776 .52416 m .76205 .5129 L .7448 .52199 L .658 .807 .955 r
F
.74776 .52416 m .76793 .51728 L .76205 .5129 L F
.48123 .38025 m .48094 .3735 L .47234 .36118 L .986 .708 .367 r
F
0 g
.48094 .3735 m
.48363 .38662 L
s
.42652 .51193 m .42609 .50632 L .43973 .49996 L .496 .312 .561 r
F
0 g
.41653 .50898 m
.42609 .50632 L
s
.55857 .24309 m .51867 .25367 L .55534 .25559 L .644 .737 .917 r
F
.55857 .24309 m .52315 .23483 L .51867 .25367 L F
0 g
.51867 .25367 m
.5217 .27252 L
s
.42146 .38614 m .43749 .37013 L .41673 .3827 L .657 .779 .939 r
F
.42146 .38614 m .44691 .37709 L .43749 .37013 L F
.34464 .3724 m .31061 .37689 L .33931 .38074 L .658 .778 .938 r
F
.59375 .25128 m .55534 .25559 L .59201 .25751 L .644 .737 .917 r
F
.59375 .25128 m .55857 .24309 L .55534 .25559 L F
.41474 .49675 m .42592 .50618 L .43949 .49985 L .662 .803 .95 r
F
.40416 .49971 m .42592 .50618 L .41474 .49675 L F
.74382 .51641 m .75272 .50418 L .7397 .51485 L .658 .806 .954 r
F
.74382 .51641 m .76095 .50734 L .75272 .50418 L F
.66537 .26134 m .70126 .25054 L .66485 .255 L .644 .737 .917 r
F
.66537 .26134 m .70206 .26326 L .70126 .25054 L F
.70206 .26326 m .73793 .24605 L .70126 .25054 L F
.70206 .26326 m .73875 .26517 L .73793 .24605 L F
.68907 .37186 m .68839 .36513 L .70406 .35408 L .379 .226 .544 r
F
0 g
.67792 .36975 m
.68839 .36513 L
s
.73875 .26517 m .73786 .23764 L .73793 .24605 L .746 .597 .026 r
F
0 g
.73213 .28352 m
.73875 .26517 L
s
.75443 .40288 m .73131 .39482 L .73206 .40161 L .735 .484 .549 r
F
0 g
.70832 .397 m
.73131 .39482 L
s
.73131 .39482 m
.75364 .39609 L
s
.75443 .40288 m
.7745 .40747 L
s
.36928 .24977 m .34398 .24732 L .34299 .25569 L .563 .321 .507 r
F
0 g
.32097 .26602 m
.34299 .25569 L
s
.36928 .24977 m .37019 .24138 L .34398 .24732 L .563 .321 .507 r
F
0 g
.322 .25768 m
.34398 .24732 L
s
.69141 .5162 m .66557 .52027 L .68611 .52199 L .658 .806 .954 r
F
.37057 .39393 m .33907 .39425 L .36783 .39806 L .656 .78 .939 r
F
.66922 .35314 m .68811 .36495 L .7037 .35396 L .657 .779 .938 r
F
.65634 .35888 m .68811 .36495 L .66922 .35314 L F
.41645 .376 m .42479 .3582 L .41033 .37341 L .658 .778 .938 r
F
.41645 .376 m .43707 .36347 L .42479 .3582 L F
.45401 .25307 m .42814 .23602 L .42738 .24437 L .802 .535 .534 r
F
.45332 .26146 m .45401 .25307 L .42738 .24437 L F
0 g
.45401 .25307 m
.47665 .26576 L
s
.36061 .52147 m .37645 .51835 L .37681 .52398 L .797 .539 .549 r
F
.36061 .52147 m .36027 .51583 L .37645 .51835 L F
.3708 .50509 m .37645 .51835 L .38164 .5068 L .661 .803 .951 r
F
.3708 .50509 m .36027 .51583 L .37645 .51835 L F
0 g
.37645 .51835 m
.3936 .51851 L
s
.71082 .53207 m .68753 .53326 L .70812 .53495 L .657 .808 .956 r
F
0 g
.73206 .40161 m
.75443 .40288 L
s
.39355 .51258 m .39399 .52414 L .41106 .52196 L .66 .804 .952 r
F
.38201 .51246 m .39399 .52414 L .39355 .51258 L F
.38201 .51246 m .37681 .52398 L .39399 .52414 L F
.19047 .65653 m .1966 .65714 L .19589 .66196 L .971 .745 .539 r
F
.19047 .65653 m .19118 .6517 L .1966 .65714 L F
.20505 .65069 m .1966 .65714 L .20864 .65432 L .596 .768 .962 r
F
.20505 .65069 m .19118 .6517 L .1966 .65714 L F
0 g
.1966 .65714 m
.20208 .66052 L
s
.52203 .66725 m .5116 .66391 L .51129 .66874 L .592 .372 .551 r
F
0 g
.50203 .67156 m
.51129 .66874 L
s
.52203 .66725 m .52233 .66241 L .5116 .66391 L .592 .372 .551 r
F
0 g
.50235 .66674 m
.5116 .66391 L
s
.22267 .65796 m .21964 .665 L .22592 .65928 L .595 .768 .962 r
F
.22267 .65796 m .21316 .66239 L .21964 .665 L F
.26903 .52656 m .25236 .51842 L .25254 .52407 L .795 .541 .553 r
F
.26923 .53221 m .26903 .52656 L .25254 .52407 L F
0 g
.26903 .52656 m
.28341 .53119 L
s
.24065 .66015 m .24897 .66675 L .25471 .66486 L .595 .768 .962 r
F
.23721 .66066 m .24897 .66675 L .24065 .66015 L F
.77194 .52821 m .7892 .51602 L .76886 .52293 L .657 .808 .956 r
F
.77194 .52821 m .79371 .52398 L .7892 .51602 L F
.55562 .66653 m .54542 .65894 L .54515 .66377 L .797 .549 .563 r
F
.55536 .67136 m .55562 .66653 L .54515 .66377 L F
0 g
.55562 .66653 m
.56445 .67043 L
s
.79275 .51835 m .78728 .50471 L .78824 .51036 L .929 .624 .156 r
F
.79371 .52398 m .79275 .51835 L .78824 .51036 L F
0 g
.79276 .52161 m
.79276 .52231 L
s
.27279 .66167 m .2771 .65195 L .2765 .65678 L 0 0 .287 r
F
.27218 .6665 m .27279 .66167 L .2765 .65678 L F
.25957 .65735 m .27279 .66167 L .2765 .65678 L .596 .768 .962 r
F
.25534 .66003 m .27279 .66167 L .25957 .65735 L F
0 g
.26642 .66566 m
.27279 .66167 L
s
.5982 .2372 m .55898 .23472 L .59407 .24292 L .644 .736 .916 r
F
.41106 .52196 m .42652 .51193 L .42695 .51757 L .593 .384 .567 r
F
.40503 .51111 m .41106 .52196 L .42695 .51757 L .66 .804 .952 r
F
.39355 .51258 m .41106 .52196 L .40503 .51111 L F
0 g
.39399 .52414 m
.41106 .52196 L
s
.66498 .24662 m .69549 .22985 L .66198 .24053 L .644 .736 .916 r
F
.66498 .24662 m .7013 .24215 L .69549 .22985 L F
.70997 .52642 m .69205 .5218 L .68671 .52761 L .658 .807 .955 r
F
.7139 .52384 m .69205 .5218 L .70997 .52642 L F
.53378 .66236 m .52262 .65759 L .52233 .66241 L .668 .437 .561 r
F
.53378 .66236 m .53406 .65754 L .52262 .65759 L F
0 g
.51191 .65909 m
.52262 .65759 L
s
.58682 .36845 m .58251 .38886 L .59859 .37373 L .656 .78 .94 r
F
.58682 .36845 m .56489 .38109 L .58251 .38886 L F
0 g
.58251 .38886 m
.60321 .39351 L
s
.37049 .38714 m .34441 .3791 L .33905 .38746 L .657 .779 .939 r
F
.37501 .38352 m .34441 .3791 L .37049 .38714 L F
0 g
.7326 .53527 m
.73327 .54544 L
s
.54515 .66377 m .54542 .65894 L .53406 .65754 L .734 .493 .565 r
F
0 g
.54542 .65894 m
.55587 .6617 L
s
.71312 .51823 m .6992 .511 L .69141 .5162 L .658 .806 .954 r
F
.71797 .51614 m .6992 .511 L .71312 .51823 L F
0 g
.72503 .5357 m
.72564 .54532 L
s
.21803 .5261 m .20242 .52483 L .20252 .53048 L .588 .376 .561 r
F
.21803 .5261 m .2179 .52044 L .20242 .52483 L F
0 g
.18963 .53109 m
.20242 .52483 L
s
.74865 .5298 m .76297 .51856 L .74569 .52764 L .657 .808 .956 r
F
.74865 .5298 m .76886 .52293 L .76297 .51856 L F
.37503 .37681 m .35358 .36509 L .34464 .3724 L .658 .778 .938 r
F
.38099 .37399 m .35358 .36509 L .37503 .37681 L F
.59866 .22894 m .56778 .21494 L .55975 .22647 L .645 .736 .915 r
F
.60489 .22415 m .56778 .21494 L .59866 .22894 L F
.45301 .39199 m .47289 .37477 L .44714 .38388 L .656 .78 .939 r
F
.45301 .39199 m .48151 .38702 L .47289 .37477 L F
.42652 .51193 m .43973 .49996 L .44018 .50559 L .496 .312 .561 r
F
.42695 .51757 m .42652 .51193 L .44018 .50559 L F
.41527 .50249 m .42652 .51193 L .44018 .50559 L .661 .803 .951 r
F
.40463 .50545 m .42652 .51193 L .41527 .50249 L F
0 g
.41689 .5146 m
.42652 .51193 L
s
.66196 .23224 m .68479 .21067 L .65671 .22686 L .645 .736 .915 r
F
.66196 .23224 m .69521 .22159 L .68479 .21067 L F
0 g
.70903 .4038 m
.73206 .40161 L
s
.56778 .21494 m .5247 .21825 L .55975 .22647 L .645 .736 .915 r
F
.7397 .51485 m .74265 .50247 L .7347 .51401 L .658 .806 .954 r
F
.7397 .51485 m .75272 .50418 L .74265 .50247 L F
.54515 .66377 m .53406 .65754 L .53378 .66236 L .734 .493 .565 r
F
0 g
.53406 .65754 m
.54542 .65894 L
s
.52262 .65759 m
.53406 .65754 L
s
.7448 .52199 m .75376 .50973 L .74066 .52043 L .658 .807 .955 r
F
.7448 .52199 m .76205 .5129 L .75376 .50973 L F
.39871 .24037 m .37111 .23304 L .37019 .24138 L .657 .403 .524 r
F
.39871 .24037 m .39955 .23201 L .37111 .23304 L F
0 g
.34496 .23899 m
.37111 .23304 L
s
.73327 .54544 m
.73754 .61051 L
s
.70097 .23385 m .7289 .2108 L .69521 .22159 L .645 .736 .915 r
F
.70097 .23385 m .73725 .22935 L .7289 .2108 L F
.42738 .24437 m .42814 .23602 L .39955 .23201 L .733 .471 .532 r
F
0 g
.42814 .23602 m
.4547 .24473 L
s
.48123 .38025 m .47234 .36118 L .47261 .36796 L .986 .708 .367 r
F
.48151 .38702 m .48123 .38025 L .47261 .36796 L F
0 g
.48123 .38025 m
.48392 .39334 L
s
.72564 .54532 m
.72977 .61068 L
s
.69205 .5218 m .66604 .5259 L .68671 .52761 L .658 .807 .955 r
F
.20436 .65553 m .19589 .66196 L .20795 .65916 L .595 .768 .962 r
F
.20436 .65553 m .19047 .65653 L .19589 .66196 L F
0 g
.19589 .66196 m
.20372 .66678 L
s
.42164 .39291 m .4377 .37694 L .41689 .38948 L .656 .78 .939 r
F
.42164 .39291 m .44714 .38388 L .4377 .37694 L F
.7668 .51172 m .77827 .49818 L .76095 .50734 L .658 .806 .954 r
F
.7668 .51172 m .78697 .50482 L .77827 .49818 L F
.34441 .3791 m .31015 .38361 L .33905 .38746 L .657 .779 .939 r
F
.37115 .51076 m .37681 .52398 L .38201 .51246 L .66 .804 .952 r
F
.37115 .51076 m .36061 .52147 L .37681 .52398 L F
0 g
.37681 .52398 m
.39399 .52414 L
s
.34613 .5111 m .35994 .5102 L .36027 .51583 L .861 .591 .529 r
F
.34613 .5111 m .34581 .50545 L .35994 .5102 L F
0 g
.35994 .5102 m
.36501 .51099 L
s
.55536 .67136 m .54515 .66377 L .54488 .66861 L .797 .549 .563 r
F
0 g
.55536 .67136 m
.5642 .67526 L
s
.27218 .6665 m .2765 .65678 L .27589 .66162 L 0 0 .287 r
F
.25894 .66219 m .27218 .6665 L .27589 .66162 L .595 .768 .962 r
F
.25471 .66486 m .27218 .6665 L .25894 .66219 L F
0 g
.26581 .67048 m
.27218 .6665 L
s
.36116 .49613 m .3601 .51004 L .37055 .49932 L .662 .803 .95 r
F
.36116 .49613 m .34604 .50531 L .3601 .51004 L F
.26923 .53221 m .25254 .52407 L .25272 .52973 L .795 .541 .553 r
F
0 g
.26923 .53221 m
.28363 .53682 L
s
.68907 .37186 m .70406 .35408 L .70477 .36085 L .379 .226 .544 r
F
.68974 .37863 m .68907 .37186 L .70477 .36085 L F
.67006 .36003 m .68907 .37186 L .70477 .36085 L .657 .779 .939 r
F
.65708 .36579 m .68907 .37186 L .67006 .36003 L F
0 g
.6785 .3765 m
.68907 .37186 L
s
.25254 .52407 m .25236 .51842 L .23496 .51825 L .734 .492 .562 r
F
0 g
.25236 .51842 m
.26883 .52093 L
s
.79371 .52398 m .78824 .51036 L .7892 .51602 L .929 .624 .156 r
F
0 g
.79371 .52398 m
.79374 .53271 L
s
.26006 .65249 m .27689 .65191 L .26249 .64921 L .597 .767 .961 r
F
.71797 .51614 m .70894 .50677 L .6992 .511 L .658 .806 .954 r
F
.72344 .51468 m .70894 .50677 L .71797 .51614 L F
.5335 .6672 m .52233 .66241 L .52203 .66725 L .668 .437 .561 r
F
0 g
.51129 .66874 m
.52203 .66725 L
s
.5335 .6672 m .53378 .66236 L .52233 .66241 L .668 .437 .561 r
F
0 g
.5116 .66391 m
.52233 .66241 L
s
.41033 .37341 m .41043 .35499 L .40321 .37184 L .658 .778 .938 r
F
.41033 .37341 m .42479 .3582 L .41043 .35499 L F
.54488 .66861 m .54515 .66377 L .53378 .66236 L .734 .493 .565 r
F
0 g
.54515 .66377 m
.55562 .66653 L
s
.41673 .3827 m .42512 .36484 L .41056 .3801 L .657 .779 .939 r
F
.41673 .3827 m .43749 .37013 L .42512 .36484 L F
.22006 .65633 m .21316 .66239 L .22267 .65796 L .595 .768 .962 r
F
.22006 .65633 m .20795 .65916 L .21316 .66239 L F
.71082 .53207 m .69287 .52747 L .68753 .53326 L .657 .808 .956 r
F
.71475 .52949 m .69287 .52747 L .71082 .53207 L F
.24352 .6592 m .25471 .66486 L .25894 .66219 L .595 .768 .962 r
F
.24065 .66015 m .25471 .66486 L .24352 .6592 L F
.7347 .51401 m .73147 .50234 L .72915 .51396 L .658 .806 .954 r
F
.7347 .51401 m .74265 .50247 L .73147 .50234 L F
.7139 .52384 m .69989 .51659 L .69205 .5218 L .658 .807 .955 r
F
.71878 .52174 m .69989 .51659 L .7139 .52384 L F
.21816 .53177 m .20252 .53048 L .20263 .53614 L .588 .376 .561 r
F
0 g
.18981 .54238 m
.20263 .53614 L
s
.21816 .53177 m .21803 .5261 L .20252 .53048 L .588 .376 .561 r
F
0 g
.18972 .53672 m
.20252 .53048 L
s
.54488 .66861 m .53378 .66236 L .5335 .6672 L .734 .493 .565 r
F
0 g
.53378 .66236 m
.54515 .66377 L
s
.54488 .66861 m
.55536 .67136 L
s
.52233 .66241 m
.53378 .66236 L
s
.42695 .51757 m .44018 .50559 L .44063 .51123 L .496 .312 .561 r
F
.41569 .50815 m .42695 .51757 L .44063 .51123 L .66 .804 .952 r
F
.40503 .51111 m .42695 .51757 L .41569 .50815 L F
0 g
.41106 .52196 m
.42695 .51757 L
s
.55111 .36382 m .564 .36754 L .56444 .3743 L .946 .655 .457 r
F
.55111 .36382 m .55068 .35703 L .564 .36754 L F
0 g
.564 .36754 m
.57085 .3706 L
s
.72344 .51468 m .71995 .50381 L .70894 .50677 L .658 .806 .954 r
F
.72915 .51396 m .71995 .50381 L .72344 .51468 L F
.38099 .37399 m .36554 .35933 L .35358 .36509 L .658 .778 .938 r
F
.388 .37214 m .36554 .35933 L .38099 .37399 L F
.37057 .39393 m .34445 .38591 L .33907 .39425 L .656 .78 .939 r
F
.3751 .39031 m .34445 .38591 L .37057 .39393 L F
.57729 .34766 m .56433 .36736 L .58607 .35473 L .657 .779 .938 r
F
.57729 .34766 m .55108 .35689 L .56433 .36736 L F
.44643 .37042 m .45798 .35076 L .43707 .36347 L .658 .778 .938 r
F
.44643 .37042 m .47195 .36132 L .45798 .35076 L F
.72915 .51396 m .73147 .50234 L .71995 .50381 L .658 .806 .954 r
F
.63109 .34979 m .62787 .36394 L .6418 .3626 L .657 .779 .938 r
F
.63187 .34636 m .6418 .3626 L .63621 .34594 L F
.6285 .34669 m .63109 .34979 L .63187 .34636 L F
.63109 .34979 m .6418 .3626 L .63187 .34636 L F
.63427 .29677 m .63446 .2958 L .63572 .32945 L 0 0 .209 r
F
.63621 .34594 m .6418 .3626 L .64883 .3608 L .657 .779 .938 r
F
.64497 .35157 m .64883 .3608 L .65634 .35888 L F
.63621 .34594 m .64883 .3608 L .64497 .35157 L F
.6285 .34669 m .62787 .36394 L .63109 .34979 L F
.62906 .35357 m .62724 .36956 L .64244 .36952 L .657 .779 .939 r
F
.62724 .36956 m .62707 .37099 L .62725 .37098 L F
.62724 .36956 m .62725 .37098 L .64244 .36952 L F
.6285 .34669 m .627 .35999 L .62787 .36394 L .657 .779 .938 r
F
.627 .35999 m .62653 .36407 L .62703 .36402 L F
.627 .35999 m .62703 .36402 L .62787 .36394 L F
.62092 .34623 m .62653 .36407 L .6285 .34669 L F
.62092 .34623 m .61153 .36319 L .62653 .36407 L F
.62143 .35312 m .62707 .37099 L .62906 .35357 L .657 .779 .939 r
F
.62143 .35312 m .61197 .37012 L .62707 .37099 L F
.62198 .35994 m .62763 .37777 L .62963 .36039 L .656 .78 .94 r
F
.62973 .33581 m .62092 .34623 L .6285 .34669 L .657 .779 .938 r
F
.62821 .33308 m .6268 .33562 L .62973 .33581 L F
.6268 .33562 m .62092 .34623 L .62683 .33924 L F
.6268 .33562 m .62683 .33924 L .62973 .33581 L F
.6256 .29661 m .62695 .33082 L .62676 .33047 L .972 .694 .284 r
F
.62821 .33308 m .62679 .33423 L .6268 .33562 L .657 .779 .938 r
F
.62749 .33179 m .62226 .33675 L .62821 .33308 L F
.62226 .33675 m .61397 .34461 L .62079 .33909 L F
.62226 .33675 m .62079 .33909 L .62821 .33308 L F
.6256 .29661 m .626 .29744 L .62716 .3312 L .972 .694 .284 r
F
.6256 .29661 m .62716 .3312 L .62695 .33082 L F
.626 .29744 m .62674 .29814 L .62791 .3318 L .948 .643 .425 r
F
.6286 .33236 m .62749 .33179 L .62821 .33308 L .657 .779 .938 r
F
.62791 .3318 m .62749 .33179 L .6286 .33236 L F
.62767 .33161 m .6276 .33168 L .62791 .3318 L F
.6276 .33168 m .62749 .33179 L .62791 .3318 L F
.62674 .29814 m .62788 .29871 L .62906 .33227 L .862 .563 .481 r
F
.62674 .29814 m .62906 .33227 L .62846 .33203 L F
.626 .29744 m .62791 .3318 L .62752 .33149 L .948 .643 .425 r
F
.62788 .29871 m .63091 .33249 L .62995 .33237 L .755 .473 .507 r
F
.63008 .33269 m .62821 .33308 L .62973 .33581 L .657 .779 .938 r
F
.63012 .33239 m .62971 .33254 L .63008 .33269 L F
.62971 .33254 m .62821 .33308 L .63008 .33269 L F
.62906 .35357 m .64244 .36952 L .63682 .35282 L .657 .779 .939 r
F
.62963 .36039 m .62763 .37777 L .64303 .3763 L .656 .78 .94 r
F
.62963 .36039 m .64303 .3763 L .63741 .35964 L F
.62788 .29871 m .62972 .29902 L .63091 .33249 L .755 .473 .507 r
F
.63237 .33446 m .6285 .34669 L .63621 .34594 L .657 .779 .938 r
F
.63161 .29878 m .63342 .33196 L .63282 .3322 L .492 .27 .504 r
F
.62972 .29902 m .63182 .33235 L .63091 .33249 L .629 .374 .513 r
F
.63284 .29826 m .63371 .29758 L .63496 .33106 L .328 .148 .478 r
F
.63371 .29758 m .63427 .29677 L .63552 .33032 L .067 0 .41 r
F
.63371 .29758 m .63552 .33032 L .63523 .33071 L F
.63427 .29677 m .63572 .32945 L .63562 .3299 L 0 0 .209 r
F
.63427 .29677 m .63562 .3299 L .63552 .33032 L F
.63446 .2958 m .634 .29456 L .63526 .32835 L .944 .685 .22 r
F
.63374 .33266 m .63621 .34594 L .64199 .34445 L .657 .779 .938 r
F
.63374 .33266 m .64199 .34445 L .6402 .34016 L F
.6335 .33297 m .63621 .34594 L .63374 .33266 L F
.6333 .33225 m .63621 .34594 L .63335 .33221 L F
.63282 .3322 m .63621 .34594 L .63328 .33214 L F
.63167 .33237 m .63175 .33264 L .63282 .3322 L F
.63175 .33264 m .63621 .34594 L .63282 .3322 L F
.63161 .29878 m .63284 .29826 L .63407 .3317 L .492 .27 .504 r
F
.63335 .33221 m .6335 .33297 L .63374 .33266 L .657 .779 .938 r
F
.63161 .29878 m .63407 .3317 L .63342 .33196 L .492 .27 .504 r
F
.62972 .29902 m .63161 .29878 L .63282 .3322 L .629 .374 .513 r
F
.62972 .29902 m .63282 .3322 L .63182 .33235 L F
.63284 .29826 m .63449 .33139 L .63407 .3317 L .328 .148 .478 r
F
.63051 .32892 m .64355 .34405 L .65002 .34113 L .657 .779 .938 r
F
.63284 .29826 m .63496 .33106 L .63449 .33139 L .328 .148 .478 r
F
.63371 .29758 m .63523 .33071 L .63496 .33106 L .067 0 .41 r
F
.63051 .32892 m .65002 .34113 L .65179 .33985 L .657 .779 .938 r
F
.64148 .33267 m .65179 .33985 L .6552 .33737 L F
.63051 .32892 m .65179 .33985 L .64148 .33267 L F
.63755 .32994 m .6552 .33737 L .65872 .33302 L F
.63051 .32892 m .64148 .33267 L .63755 .32994 L F
.64148 .33267 m .6552 .33737 L .63755 .32994 L F
.634 .29456 m .63281 .29358 L .63406 .32751 L .931 .625 .44 r
F
.63274 .34068 m .62906 .35357 L .63682 .35282 L .657 .779 .939 r
F
.63449 .33139 m .63496 .33106 L .63519 .33747 L .328 .148 .478 r
F
.63446 .2958 m .63526 .32835 L .6355 .32892 L .944 .685 .22 r
F
.63446 .2958 m .6355 .32892 L .63572 .32945 L F
.63846 .32877 m .65872 .33302 L .66035 .32836 L .657 .779 .938 r
F
.63051 .32892 m .64767 .33141 L .63846 .32877 L F
.64767 .33141 m .65872 .33302 L .63846 .32877 L F
.63392 .33913 m .63454 .34205 L .63489 .34052 L .657 .779 .939 r
F
.63454 .34205 m .63682 .35282 L .63489 .34052 L F
.63374 .33937 m .63445 .34246 L .63392 .33913 L F
.63445 .34246 m .63682 .35282 L .63454 .34205 L F
.63445 .34246 m .63454 .34205 L .63392 .33913 L F
.63621 .34594 m .65634 .35888 L .64355 .34405 L .657 .779 .938 r
F
.63489 .34052 m .63682 .35282 L .64247 .35137 L .657 .779 .939 r
F
.63562 .3299 m .63587 .33623 L .63552 .33032 L 0 0 .209 r
F
.63496 .34023 m .64247 .35137 L .64047 .34659 L .657 .779 .939 r
F
.63491 .34045 m .64247 .35137 L .63496 .34023 L F
.63392 .33913 m .64247 .35137 L .63396 .33908 L F
.63235 .3395 m .63682 .35282 L .63357 .33863 L F
.63342 .33196 m .63407 .3317 L .63431 .3381 L .492 .27 .504 r
F
.63342 .33196 m .63431 .3381 L .63377 .33832 L F
.6402 .34016 m .64199 .34445 L .64355 .34405 L .657 .779 .938 r
F
.63516 .3383 m .63955 .34442 L .63763 .33983 L .657 .779 .939 r
F
.63552 .33032 m .6358 .33657 L .63576 .33673 L 0 0 .209 r
F
.6355 .32892 m .6357 .33523 L .63572 .32945 L .944 .685 .22 r
F
.63374 .33851 m .64037 .34637 L .63516 .3383 L .657 .779 .939 r
F
.64037 .34637 m .63955 .34442 L .63516 .3383 L F
.63357 .33863 m .64421 .35092 L .63374 .33851 L F
.63407 .3317 m .63446 .33799 L .63431 .3381 L .328 .148 .478 r
F
.63195 .33322 m .63126 .33592 L .63237 .33446 L .657 .779 .938 r
F
.63126 .33592 m .6285 .34669 L .63237 .33446 L F
.63182 .33235 m .63282 .3322 L .63305 .33861 L .629 .374 .513 r
F
.63155 .3335 m .6285 .34669 L .63195 .33322 L .657 .779 .938 r
F
.63182 .33235 m .63305 .33861 L .63223 .33873 L .629 .374 .513 r
F
.63552 .33705 m .63529 .33734 L .63496 .33106 L .067 0 .41 r
F
.63496 .33106 m .63529 .33734 L .63519 .33747 L F
.63449 .33139 m .63519 .33747 L .63481 .33774 L .328 .148 .478 r
F
.63449 .33139 m .63481 .33774 L .63407 .3317 L F
.64355 .34405 m .65634 .35888 L .66922 .35314 L .657 .779 .938 r
F
.64355 .34405 m .66922 .35314 L .65002 .34113 L F
.63456 .33792 m .65073 .34799 L .6349 .33768 L .657 .779 .939 r
F
.63432 .35048 m .63209 .36015 L .63741 .35964 L .656 .78 .94 r
F
.63481 .33774 m .63446 .33799 L .63407 .3317 L .328 .148 .478 r
F
.63464 .33797 m .6335 .33854 L .63516 .3383 L .657 .779 .939 r
F
.63282 .3322 m .63327 .33852 L .63305 .33861 L .492 .27 .504 r
F
.63342 .33846 m .6335 .33854 L .63464 .33797 L .657 .779 .939 r
F
.63328 .33214 m .6333 .33225 L .63335 .33221 L .657 .779 .938 r
F
.63342 .33196 m .63377 .33832 L .63282 .3322 L .492 .27 .504 r
F
.63258 .34532 m .63209 .36015 L .63432 .35048 L .656 .78 .94 r
F
.63144 .34238 m .62906 .35357 L .63274 .34068 L .657 .779 .939 r
F
.63174 .34566 m .63209 .36015 L .63258 .34532 L .656 .78 .94 r
F
.63217 .33897 m .63144 .34238 L .63274 .34068 L .657 .779 .939 r
F
.63159 .3327 m .6285 .34669 L .63175 .33264 L .657 .779 .938 r
F
.63009 .33261 m .6285 .34669 L .63167 .33237 L F
.63091 .33249 m .63147 .33884 L .63114 .33889 L .629 .374 .513 r
F
.62868 .33223 m .62821 .33308 L .63012 .33239 L .657 .779 .938 r
F
.62995 .33237 m .63091 .33249 L .63114 .33889 L .755 .473 .507 r
F
.63173 .33896 m .63065 .33958 L .63208 .339 L .657 .779 .939 r
F
.63072 .33895 m .63065 .33958 L .63209 .33875 L F
.63065 .33958 m .62906 .35357 L .63199 .33977 L F
.63108 .3394 m .63199 .33977 L .63217 .33897 L F
.63065 .33958 m .63199 .33977 L .63108 .3394 L F
.62674 .29814 m .62846 .33203 L .62791 .3318 L .862 .563 .481 r
F
.62788 .29871 m .62995 .33237 L .62906 .33227 L .755 .473 .507 r
F
.63051 .32892 m .62767 .33161 L .62839 .33219 L .657 .779 .938 r
F
.63051 .32892 m .62839 .33219 L .62868 .33223 L F
.62846 .33203 m .62879 .33848 L .62791 .3318 L .862 .563 .481 r
F
.63175 .34601 m .62963 .36039 L .63209 .36015 L .656 .78 .94 r
F
.63165 .34597 m .62963 .36039 L .63175 .34601 L F
.63136 .34532 m .6313 .34583 L .63174 .34536 L F
.6313 .34583 m .62963 .36039 L .63165 .34597 L F
.6313 .34583 m .63165 .34597 L .63174 .34536 L F
.62767 .33161 m .62441 .33334 L .62226 .33675 L .657 .779 .938 r
F
.626 .29744 m .62752 .33149 L .62716 .3312 L .948 .643 .425 r
F
.63051 .32892 m .62692 .331 L .62767 .33161 L .657 .779 .938 r
F
.62692 .331 m .60813 .34192 L .62767 .33161 L F
.63029 .3428 m .62143 .35312 L .62906 .35357 L .657 .779 .939 r
F
.63058 .34018 m .6296 .34157 L .63029 .3428 L F
.6296 .34157 m .62143 .35312 L .63029 .3428 L F
.62559 .29564 m .62676 .33034 L .62675 .33003 L 0 0 .044 r
F
.62559 .29564 m .6256 .29661 L .62676 .33047 L F
.62559 .29564 m .62676 .33047 L .62676 .33034 L F
.63051 .32892 m .62209 .33189 L .60813 .34192 L .657 .779 .938 r
F
.62209 .33189 m .60377 .33834 L .60731 .34125 L F
.62209 .33189 m .60731 .34125 L .60813 .34192 L F
.62765 .29348 m .62628 .29442 L .62745 .32848 L .369 .177 .485 r
F
.63024 .33991 m .62939 .3412 L .63058 .34018 L .657 .779 .939 r
F
.62939 .3412 m .62143 .35312 L .6296 .34157 L F
.62939 .3412 m .6296 .34157 L .63058 .34018 L F
.62943 .33874 m .62923 .33909 L .63069 .33924 L F
.62695 .33082 m .62721 .3373 L .62676 .33047 L .972 .694 .284 r
F
.62872 .34001 m .62143 .35312 L .62939 .3412 L .657 .779 .939 r
F
.62752 .33149 m .62781 .33795 L .62716 .3312 L .948 .643 .425 r
F
.6268 .33562 m .61397 .34461 L .62092 .34623 L .657 .779 .938 r
F
.62703 .34305 m .62129 .34502 L .62143 .35312 L .657 .779 .939 r
F
.62923 .33909 m .62701 .34075 L .62703 .34305 L F
.62701 .34075 m .62129 .34502 L .62703 .34305 L F
.62833 .33837 m .627 .33962 L .62923 .33909 L F
.627 .33962 m .62129 .34502 L .62701 .34075 L F
.627 .33962 m .62701 .34075 L .62923 .33909 L F
.62676 .33047 m .62705 .33701 L .62698 .33688 L .972 .694 .284 r
F
.62628 .29442 m .62559 .29564 L .62675 .3296 L 0 0 .377 r
F
.62628 .29442 m .62675 .3296 L .62711 .32903 L F
.62559 .29564 m .62675 .33003 L .62675 .3296 L 0 0 .044 r
F
.62209 .33189 m .60121 .3341 L .60377 .33834 L .657 .779 .938 r
F
.63051 .32892 m .62532 .32984 L .62209 .33189 L F
.62532 .32984 m .60121 .3341 L .62209 .33189 L F
.62781 .33795 m .62751 .33771 L .62716 .3312 L .948 .643 .425 r
F
.61397 .34461 m .61153 .36319 L .62092 .34623 L .657 .779 .938 r
F
.61397 .34461 m .59774 .36001 L .61153 .36319 L F
.60813 .34192 m .59774 .36001 L .61397 .34461 L F
.62129 .34502 m .60855 .3488 L .61443 .35149 L .657 .779 .939 r
F
.62752 .33149 m .62791 .3318 L .62813 .33821 L .948 .643 .425 r
F
.62752 .33149 m .62813 .33821 L .62781 .33795 L F
.62791 .3318 m .62833 .33829 L .62813 .33821 L .862 .563 .481 r
F
.62879 .33848 m .62833 .33829 L .62791 .3318 L F
.62995 .33237 m .63114 .33889 L .63034 .3388 L .755 .473 .507 r
F
.62906 .33227 m .6296 .33871 L .62928 .33867 L F
.62995 .33237 m .63034 .3388 L .62906 .33227 L F
.63034 .3388 m .6296 .33871 L .62906 .33227 L F
.62868 .33223 m .62839 .33219 L .6286 .33236 L .657 .779 .938 r
F
.62846 .33203 m .62906 .33227 L .62928 .33867 L .862 .563 .481 r
F
.62945 .33869 m .62861 .3386 L .62923 .33909 L .657 .779 .939 r
F
.62846 .33203 m .62928 .33867 L .62879 .33848 L .862 .563 .481 r
F
.63109 .33576 m .62861 .3386 L .62945 .33869 L .657 .779 .939 r
F
.62923 .33909 m .62872 .34001 L .63024 .33991 L F
.62872 .34001 m .62939 .3412 L .63024 .33991 L F
.62923 .33909 m .63024 .33991 L .63069 .33924 L F
.62814 .33854 m .62486 .33936 L .62129 .34502 L F
.63109 .33576 m .62658 .33836 L .62814 .33854 L F
.62658 .33836 m .62486 .33936 L .62814 .33854 L F
.62721 .3373 m .62705 .33701 L .62676 .33047 L .972 .694 .284 r
F
.62716 .3312 m .62751 .33771 L .62738 .33761 L .948 .643 .425 r
F
.62695 .33082 m .62716 .3312 L .62738 .33761 L .972 .694 .284 r
F
.62695 .33082 m .62738 .33761 L .62721 .3373 L F
.62226 .33675 m .60813 .34192 L .61397 .34461 L .657 .779 .938 r
F
.62628 .29442 m .62711 .32903 L .62745 .32848 L 0 0 .377 r
F
.61603 .33148 m .60063 .32948 L .60121 .3341 L .657 .779 .938 r
F
.63051 .32892 m .62409 .32904 L .61603 .33148 L F
.62409 .32904 m .60063 .32948 L .61603 .33148 L F
.62898 .29308 m .62765 .29348 L .62885 .3276 L .547 .31 .508 r
F
.63109 .33576 m .62601 .33754 L .62486 .33936 L .657 .779 .939 r
F
.63084 .34982 m .62198 .35994 L .62963 .36039 L .656 .78 .94 r
F
.63118 .34691 m .63008 .34846 L .63084 .34982 L F
.63008 .34846 m .62198 .35994 L .63084 .34982 L F
.62765 .29348 m .62745 .32848 L .62817 .32803 L .369 .177 .485 r
F
.62409 .32904 m .6021 .3248 L .60063 .32948 L .657 .779 .938 r
F
.63051 .32892 m .62644 .32833 L .62409 .32904 L F
.62644 .32833 m .6021 .3248 L .62409 .32904 L F
.62675 .33003 m .62697 .33651 L .62675 .3296 L 0 0 .044 r
F
.62697 .33651 m .62697 .33617 L .62675 .3296 L F
.62675 .33003 m .62698 .33688 L .62697 .33651 L F
.62676 .33034 m .62698 .33688 L .62675 .33003 L F
.62679 .33423 m .61397 .34461 L .6268 .33562 L .657 .779 .938 r
F
.62676 .33034 m .62676 .33047 L .62698 .33688 L 0 0 .044 r
F
.63109 .33576 m .62447 .33692 L .62034 .33953 L .657 .779 .939 r
F
.6313 .34583 m .63079 .3466 L .63118 .34691 L .656 .78 .94 r
F
.63079 .3466 m .62984 .34804 L .63118 .34691 L F
.62984 .34804 m .62198 .35994 L .63008 .34846 L F
.62984 .34804 m .63008 .34846 L .63118 .34691 L F
.62986 .34585 m .62924 .34696 L .6307 .34652 L F
.62924 .34696 m .62725 .35051 L .62967 .34772 L F
.62924 .34696 m .62967 .34772 L .6307 .34652 L F
.62705 .33701 m .62734 .34357 L .62698 .33688 L .972 .694 .284 r
F
.62721 .3373 m .62738 .33761 L .6276 .34404 L F
.62725 .35051 m .62727 .35194 L .62984 .34804 L .656 .78 .94 r
F
.62725 .35051 m .62984 .34804 L .62971 .3478 L F
.62725 .35051 m .63079 .3466 L .6307 .34652 L F
.62879 .33848 m .62928 .33867 L .62951 .34511 L .862 .563 .481 r
F
.62879 .33848 m .62951 .34511 L .62912 .34495 L F
.63109 .33576 m .62943 .33874 L .63069 .33924 L .657 .779 .939 r
F
.63034 .3388 m .63074 .34525 L .6296 .33871 L .755 .473 .507 r
F
.62129 .34502 m .61685 .35205 L .62143 .35312 L .657 .779 .939 r
F
.61443 .35149 m .61197 .37012 L .62143 .35312 L F
.62725 .35051 m .62032 .3533 L .62198 .35994 L .656 .78 .94 r
F
.62781 .33795 m .62813 .33821 L .62836 .34464 L .948 .643 .425 r
F
.62986 .34585 m .62723 .34764 L .62725 .35051 L .656 .78 .94 r
F
.62964 .34567 m .62723 .34764 L .62986 .34585 L F
.62908 .34506 m .62723 .3468 L .63023 .34519 L F
.62723 .3468 m .62032 .3533 L .62723 .34764 L F
.62723 .3468 m .62723 .34764 L .63023 .34519 L F
.62734 .34357 m .62728 .34347 L .62698 .33688 L .972 .694 .284 r
F
.60377 .33834 m .58607 .35473 L .60813 .34192 L .657 .779 .938 r
F
.60377 .33834 m .57729 .34766 L .58607 .35473 L F
.60121 .3341 m .57729 .34766 L .60377 .33834 L F
.61234 .33906 m .601 .33632 L .60158 .34095 L .657 .779 .939 r
F
.62711 .32903 m .62675 .3296 L .62697 .33601 L 0 0 .377 r
F
.62711 .32903 m .62697 .33601 L .62727 .33554 L F
.62675 .3296 m .62697 .33617 L .62697 .33601 L 0 0 .044 r
F
.63109 .33576 m .62617 .33585 L .62447 .33692 L .657 .779 .939 r
F
.62781 .33795 m .62836 .34464 L .6281 .34444 L .948 .643 .425 r
F
.63074 .34525 m .63015 .34518 L .6296 .33871 L .755 .473 .507 r
F
.62721 .3373 m .6276 .34404 L .62747 .3438 L .972 .694 .284 r
F
.62751 .33771 m .62787 .34425 L .62738 .33761 L .948 .643 .425 r
F
.62787 .34425 m .62776 .34417 L .62738 .33761 L F
.62738 .33761 m .62776 .34417 L .6276 .34404 L F
.62441 .33334 m .60813 .34192 L .62226 .33675 L .657 .779 .938 r
F
.62277 .33591 m .60248 .33163 L .601 .33632 L .657 .779 .939 r
F
.62711 .32903 m .62727 .33554 L .62745 .32848 L 0 0 .377 r
F
.62727 .33554 m .62755 .33509 L .62745 .32848 L F
.62349 .3279 m .60552 .32037 L .6021 .3248 L .657 .779 .938 r
F
.63051 .32892 m .62658 .32758 L .62349 .3279 L F
.62658 .32758 m .60552 .32037 L .62349 .3279 L F
.63028 .29297 m .62898 .29308 L .63019 .32719 L .65 .39 .512 r
F
.63109 .33576 m .6272 .3352 L .62617 .33585 L .657 .779 .939 r
F
.62928 .33867 m .6299 .34515 L .62951 .34511 L .755 .473 .507 r
F
.63023 .34519 m .62964 .34567 L .62986 .34585 L .656 .78 .94 r
F
.62971 .3478 m .62984 .34804 L .63079 .3466 L F
.63014 .34536 m .62986 .34585 L .6313 .34583 L F
.62986 .34585 m .6307 .34652 L .6313 .34583 L F
.6296 .33871 m .63015 .34518 L .62928 .33867 L .755 .473 .507 r
F
.63136 .34532 m .63014 .34536 L .6313 .34583 L .656 .78 .94 r
F
.63023 .34519 m .63014 .34536 L .63136 .34532 L F
.63015 .34518 m .63224 .36976 L .6299 .34515 L .755 .473 .507 r
F
.63015 .34518 m .6299 .34515 L .62928 .33867 L F
.63069 .33924 m .63024 .33991 L .63058 .34018 L .657 .779 .939 r
F
.63034 .3388 m .63114 .33889 L .63137 .34532 L .755 .473 .507 r
F
.63034 .3388 m .63137 .34532 L .63074 .34525 L F
.63114 .33889 m .63203 .34522 L .63137 .34532 L .629 .374 .513 r
F
.63167 .34262 m .63023 .34519 L .63136 .34532 L .656 .78 .94 r
F
.62813 .33821 m .62876 .34481 L .62836 .34464 L .862 .563 .481 r
F
.62833 .33829 m .62876 .34481 L .62813 .33821 L F
.62874 .33846 m .62833 .33837 L .62861 .3386 L .657 .779 .939 r
F
.62838 .33831 m .62833 .33837 L .62874 .33846 L F
.62879 .33848 m .62912 .34495 L .62833 .33829 L .862 .563 .481 r
F
.62912 .34495 m .62876 .34481 L .62833 .33829 L F
.63167 .34262 m .62771 .3449 L .62908 .34506 L .656 .78 .94 r
F
.62951 .34511 m .63224 .36976 L .63036 .36946 L .755 .473 .507 r
F
.6299 .34515 m .63224 .36976 L .62951 .34511 L F
.6307 .34652 m .63079 .3466 L .6313 .34583 L .656 .78 .94 r
F
.63074 .34525 m .63224 .36976 L .63015 .34518 L .755 .473 .507 r
F
.63167 .34262 m .62908 .34506 L .63023 .34519 L .656 .78 .94 r
F
.63109 .33576 m .62838 .33831 L .62874 .33846 L .657 .779 .939 r
F
.63074 .34525 m .63137 .34532 L .63224 .36976 L .755 .473 .507 r
F
.63223 .33873 m .63147 .33884 L .63091 .33249 L .629 .374 .513 r
F
.63109 .33576 m .63072 .33895 L .63209 .33875 L .657 .779 .939 r
F
.63175 .33264 m .63155 .3335 L .63195 .33322 L .657 .779 .938 r
F
.63167 .33237 m .63159 .3327 L .63175 .33264 L F
.63182 .33235 m .63223 .33873 L .63091 .33249 L .629 .374 .513 r
F
.63051 .32892 m .63167 .33237 L .63328 .33214 L .657 .779 .938 r
F
.63051 .32892 m .63009 .33261 L .63167 .33237 L F
.63051 .32892 m .62868 .33223 L .63012 .33239 L F
.62781 .33795 m .6281 .34444 L .62751 .33771 L .948 .643 .425 r
F
.6281 .34444 m .62787 .34425 L .62751 .33771 L F
.62129 .34502 m .61443 .35149 L .61685 .35205 L .657 .779 .939 r
F
.62721 .34519 m .62578 .34468 L .62445 .34678 L .656 .78 .94 r
F
.63167 .34262 m .6272 .34418 L .62721 .34519 L F
.6272 .34418 m .62578 .34468 L .62721 .34519 L F
.62698 .33688 m .62728 .34347 L .6272 .34332 L .972 .694 .284 r
F
.62697 .33651 m .62698 .33688 L .6272 .34332 L 0 0 .044 r
F
.62908 .34506 m .62376 .34787 L .62032 .3533 L .656 .78 .94 r
F
.62771 .3449 m .62445 .34678 L .62908 .34506 L F
.61443 .35149 m .59808 .36694 L .61197 .37012 L .657 .779 .939 r
F
.60855 .3488 m .59808 .36694 L .61443 .35149 L F
.62445 .34678 m .60908 .35563 L .62376 .34787 L .656 .78 .94 r
F
.62445 .34678 m .62376 .34787 L .62908 .34506 L F
.62219 .33447 m .60592 .32719 L .60248 .33163 L .657 .779 .939 r
F
.62765 .29348 m .62817 .32803 L .62885 .3276 L .369 .177 .485 r
F
.63051 .32892 m .61067 .31651 L .60552 .32037 L .657 .779 .938 r
F
.62817 .32803 m .62745 .32848 L .62768 .3349 L .369 .177 .485 r
F
.62817 .32803 m .62768 .3349 L .62819 .33457 L F
.62745 .32848 m .62755 .33509 L .62768 .3349 L 0 0 .377 r
F
.63109 .33576 m .62611 .33406 L .62219 .33447 L .657 .779 .939 r
F
.62611 .33406 m .60592 .32719 L .62219 .33447 L F
.634 .29456 m .63468 .32794 L .63526 .32835 L .931 .625 .44 r
F
.63575 .328 m .66035 .32836 L .65994 .32372 L .657 .779 .938 r
F
.63051 .32892 m .63846 .32877 L .63575 .328 L F
.63846 .32877 m .66035 .32836 L .63575 .328 L F
.63281 .29358 m .63156 .29312 L .6328 .32715 L .822 .528 .492 r
F
.6335 .33854 m .63235 .3395 L .63357 .33863 L .657 .779 .939 r
F
.63377 .33832 m .63327 .33852 L .63282 .3322 L .492 .27 .504 r
F
.63109 .33576 m .63209 .33875 L .6335 .33854 L .657 .779 .939 r
F
.63209 .33875 m .63235 .3395 L .6335 .33854 L F
.6335 .33854 m .63357 .33863 L .63374 .33851 L F
.63357 .33863 m .63374 .33937 L .63392 .33913 L F
.63377 .33832 m .63411 .34471 L .63327 .33852 L .492 .27 .504 r
F
.63396 .33908 m .63491 .34045 L .63496 .34023 L .657 .779 .939 r
F
.63481 .33774 m .63513 .34412 L .63446 .33799 L .328 .148 .478 r
F
.63109 .33576 m .6351 .33778 L .63598 .33742 L .657 .779 .939 r
F
.6351 .33778 m .65262 .34662 L .63598 .33742 L F
.6349 .33768 m .65073 .34799 L .65262 .34662 L F
.63523 .33071 m .63552 .33705 L .63496 .33106 L .067 0 .41 r
F
.63523 .33071 m .63552 .33032 L .63576 .33673 L F
.65002 .34113 m .66922 .35314 L .6796 .34571 L .657 .779 .938 r
F
.65002 .34113 m .6796 .34571 L .6552 .33737 L F
.63583 .33664 m .65595 .34422 L .65867 .34088 L .657 .779 .939 r
F
.63523 .33071 m .63576 .33673 L .63552 .33705 L .067 0 .41 r
F
.63109 .33576 m .63538 .33722 L .63583 .33664 L .657 .779 .939 r
F
.63538 .33722 m .64259 .33968 L .63583 .33664 L F
.63587 .33623 m .6358 .33657 L .63552 .33032 L 0 0 .209 r
F
.63848 .33683 m .65867 .34088 L .65059 .33857 L .657 .779 .939 r
F
.63109 .33576 m .63908 .33724 L .63848 .33683 L F
.63908 .33724 m .65867 .34088 L .63848 .33683 L F
.634 .29456 m .63406 .32751 L .63468 .32794 L .931 .625 .44 r
F
.63507 .32731 m .65994 .32372 L .65752 .31941 L .657 .779 .938 r
F
.63051 .32892 m .63829 .32755 L .63507 .32731 L F
.63829 .32755 m .65994 .32372 L .63507 .32731 L F
.63209 .33875 m .63173 .33896 L .63217 .33897 L .657 .779 .939 r
F
.63173 .33896 m .63208 .339 L .63217 .33897 L F
.63223 .33873 m .63263 .34514 L .63147 .33884 L .629 .374 .513 r
F
.63263 .34514 m .63203 .34522 L .63147 .33884 L F
.63147 .33884 m .63203 .34522 L .63114 .33889 L F
.63338 .34536 m .63454 .3495 L .63375 .3451 L .656 .78 .94 r
F
.63454 .3495 m .63741 .35964 L .63469 .34885 L F
.63454 .3495 m .63469 .34885 L .63375 .3451 L F
.63258 .34532 m .63274 .34581 L .63328 .34504 L F
.6358 .33657 m .63607 .34286 L .63576 .33673 L 0 0 .209 r
F
.63432 .35048 m .63741 .35964 L .63454 .3495 L .656 .78 .94 r
F
.63682 .35282 m .64244 .36952 L .65708 .36579 L .657 .779 .939 r
F
.63682 .35282 m .65708 .36579 L .64421 .35092 L F
.63512 .34698 m .63741 .35964 L .64291 .35823 L .656 .78 .94 r
F
.63415 .34558 m .6348 .34839 L .63512 .34698 L F
.6348 .34839 m .63741 .35964 L .63512 .34698 L F
.64259 .33968 m .64105 .33861 L .63583 .33664 L .657 .779 .939 r
F
.63598 .33742 m .65262 .34662 L .64259 .33968 L F
.63562 .3299 m .63572 .32945 L .63596 .33586 L 0 0 .209 r
F
.63572 .32945 m .63588 .33566 L .63596 .33586 L .944 .685 .22 r
F
.63562 .3299 m .63596 .33586 L .63587 .33623 L 0 0 .209 r
F
.63109 .33576 m .65059 .33857 L .64052 .3357 L .657 .779 .939 r
F
.6552 .33737 m .68675 .33709 L .65872 .33302 L .657 .779 .938 r
F
.64013 .33559 m .661 .33557 L .65686 .33527 L .657 .779 .939 r
F
.63109 .33576 m .64052 .3357 L .64013 .33559 L F
.64052 .3357 m .661 .33557 L .64013 .33559 L F
.63281 .29358 m .6328 .32715 L .63344 .32733 L .822 .528 .492 r
F
.63281 .29358 m .63344 .32733 L .63406 .32751 L F
.63348 .3272 m .65752 .31941 L .65322 .31573 L .657 .779 .938 r
F
.63051 .32892 m .63507 .32731 L .63348 .3272 L F
.63507 .32731 m .65752 .31941 L .63348 .3272 L F
.63156 .29312 m .63028 .29297 L .63151 .32706 L .735 .457 .508 r
F
.63223 .33873 m .63238 .33871 L .63244 .34206 L .629 .374 .513 r
F
.63238 .33871 m .63305 .33861 L .63244 .34206 L F
.63274 .34581 m .63432 .35048 L .63338 .34536 L .656 .78 .94 r
F
.63274 .34581 m .63338 .34536 L .63328 .34504 L F
.63252 .34515 m .63258 .34532 L .63328 .34504 L F
.64037 .34637 m .64421 .35092 L .63955 .34442 L .657 .779 .939 r
F
.63513 .34477 m .63998 .35127 L .63799 .34654 L .656 .78 .94 r
F
.63472 .34483 m .64073 .35305 L .63513 .34477 L F
.63419 .34552 m .64073 .35305 L .63472 .34483 L F
.64073 .35305 m .63998 .35127 L .63513 .34477 L F
.63398 .3458 m .63741 .35964 L .63415 .34558 L F
.63419 .34552 m .64291 .35823 L .64073 .35305 L F
.63379 .34507 m .63415 .34558 L .63419 .34552 L F
.63415 .34558 m .64291 .35823 L .63419 .34552 L F
.63529 .33734 m .63563 .34364 L .63519 .33747 L .067 0 .41 r
F
.63375 .3451 m .63394 .34585 L .63379 .34507 L .656 .78 .94 r
F
.63394 .34585 m .63741 .35964 L .63398 .3458 L F
.63394 .34585 m .63398 .3458 L .63379 .34507 L F
.63552 .33705 m .63576 .33673 L .636 .34316 L .067 0 .41 r
F
.63519 .33747 m .63555 .34375 L .63543 .3439 L F
.63244 .34206 m .63305 .33861 L .63328 .34504 L .629 .374 .513 r
F
.63244 .34206 m .63328 .34504 L .63263 .34514 L F
.63446 .33799 m .63485 .34431 L .63431 .3381 L .328 .148 .478 r
F
.63485 .34431 m .63473 .3444 L .63431 .3381 L F
.63431 .3381 m .63473 .3444 L .63454 .34453 L F
.63327 .33852 m .63372 .34486 L .63305 .33861 L .492 .27 .504 r
F
.63372 .34486 m .63355 .34493 L .63305 .33861 L F
.63305 .33861 m .63355 .34493 L .63328 .34504 L F
.63513 .34412 m .63485 .34431 L .63446 .33799 L .328 .148 .478 r
F
.63411 .34471 m .63372 .34486 L .63327 .33852 L .492 .27 .504 r
F
.63763 .33983 m .64421 .35092 L .65073 .34799 L .657 .779 .939 r
F
.63955 .34442 m .64421 .35092 L .63763 .33983 L F
.64047 .34659 m .64247 .35137 L .64421 .35092 L F
.65872 .33302 m .68675 .33709 L .69015 .32781 L .657 .779 .938 r
F
.65872 .33302 m .69015 .32781 L .66035 .32836 L F
.64051 .3341 m .66113 .33519 L .66072 .33054 L .657 .779 .939 r
F
.6357 .33523 m .63588 .33566 L .63572 .32945 L .944 .685 .22 r
F
.6355 .32892 m .6355 .33476 L .6357 .33523 L F
.63109 .33576 m .65686 .33527 L .64051 .3341 L .657 .779 .939 r
F
.65686 .33527 m .66113 .33519 L .64051 .3341 L F
.63156 .29312 m .63151 .32706 L .63217 .3271 L .735 .457 .508 r
F
.63156 .29312 m .63217 .3271 L .6328 .32715 L F
.63028 .29297 m .63019 .32719 L .63087 .32712 L .65 .39 .512 r
F
.63028 .29297 m .63087 .32712 L .63151 .32706 L F
.63071 .32714 m .6403 .31124 L .63256 .31076 L .657 .779 .938 r
F
.63051 .32892 m .63154 .32705 L .63071 .32714 L F
.63154 .32705 m .6403 .31124 L .63071 .32714 L F
.63495 .34425 m .63799 .34654 L .63757 .34554 L .656 .78 .94 r
F
.63377 .33832 m .63431 .3381 L .63454 .34453 L .492 .27 .504 r
F
.63372 .34498 m .63419 .34552 L .63472 .34483 L .656 .78 .94 r
F
.63357 .33863 m .63392 .33913 L .63396 .33908 L .657 .779 .939 r
F
.63377 .33832 m .63454 .34453 L .63411 .34471 L .492 .27 .504 r
F
.63167 .34262 m .63372 .34498 L .63513 .34477 L .656 .78 .94 r
F
.63432 .35048 m .63454 .3495 L .63338 .34536 L F
.63411 .34471 m .63454 .34453 L .63544 .36901 L .492 .27 .504 r
F
.64421 .35092 m .67006 .36003 L .65073 .34799 L .657 .779 .939 r
F
.63581 .34402 m .65337 .35336 L .64372 .3467 L .656 .78 .94 r
F
.63481 .33774 m .63543 .3439 L .63513 .34412 L .328 .148 .478 r
F
.63167 .34262 m .63509 .34431 L .63581 .34402 L .656 .78 .94 r
F
.63509 .34431 m .65337 .35336 L .63581 .34402 L F
.63167 .34262 m .63464 .34446 L .63495 .34425 L F
.63464 .34446 m .63799 .34654 L .63495 .34425 L F
.63481 .33774 m .63519 .33747 L .63543 .3439 L .328 .148 .478 r
F
.63513 .34412 m .63543 .3439 L .63634 .36835 L F
.63167 .34262 m .63252 .34515 L .63328 .34504 L .656 .78 .94 r
F
.63167 .34262 m .63328 .34504 L .63364 .3449 L F
.63252 .34515 m .63174 .34566 L .63258 .34532 L F
.63173 .34527 m .63174 .34566 L .63252 .34515 L F
.63263 .34514 m .63417 .36953 L .63203 .34522 L .629 .374 .513 r
F
.63174 .34536 m .63165 .34597 L .63175 .34601 L .656 .78 .94 r
F
.63167 .34262 m .63136 .34532 L .63174 .34536 L F
.63137 .34532 m .63417 .36953 L .63224 .36976 L .629 .374 .513 r
F
.63203 .34522 m .63417 .36953 L .63137 .34532 L F
.63167 .34262 m .63173 .34527 L .63252 .34515 L .656 .78 .94 r
F
.63109 .33576 m .63342 .33846 L .63464 .33797 L .657 .779 .939 r
F
.63109 .33576 m .63456 .33792 L .6349 .33768 L F
.63552 .33705 m .636 .34316 L .63581 .34341 L .067 0 .41 r
F
.63563 .34364 m .63555 .34375 L .63519 .33747 L F
.63552 .33705 m .63581 .34341 L .63529 .33734 L F
.63581 .34341 m .63563 .34364 L .63529 .33734 L F
.63167 .34262 m .64372 .3467 L .63986 .34405 L .656 .78 .94 r
F
.64259 .33968 m .65262 .34662 L .65595 .34422 L .657 .779 .939 r
F
.66922 .35314 m .7037 .35396 L .6796 .34571 L .657 .779 .938 r
F
.65073 .34799 m .6805 .35258 L .65595 .34422 L .657 .779 .939 r
F
.63941 .34373 m .65951 .34746 L .65352 .34576 L .656 .78 .94 r
F
.63167 .34262 m .63986 .34405 L .63941 .34373 L F
.63986 .34405 m .65951 .34746 L .63941 .34373 L F
.63051 .32892 m .64735 .31294 L .6403 .31124 L .657 .779 .938 r
F
.63051 .32892 m .65322 .31573 L .64735 .31294 L F
.63217 .3271 m .63228 .33351 L .6328 .32715 L .735 .457 .508 r
F
.63109 .33576 m .64051 .3341 L .64035 .33409 L .657 .779 .939 r
F
.63481 .33428 m .63529 .33461 L .63526 .32835 L .931 .625 .44 r
F
.63526 .32835 m .63529 .33461 L .6355 .33476 L F
.6355 .32892 m .63526 .32835 L .6355 .33476 L .944 .685 .22 r
F
.63109 .33576 m .66066 .33043 L .64013 .33259 L .657 .779 .939 r
F
.63263 .34514 m .63328 .34504 L .63417 .36953 L .629 .374 .513 r
F
.64259 .33968 m .65595 .34422 L .64105 .33861 L .657 .779 .939 r
F
.6796 .34571 m .7037 .35396 L .71458 .34113 L .657 .779 .938 r
F
.6796 .34571 m .71458 .34113 L .68675 .33709 L F
.6552 .33737 m .6796 .34571 L .68675 .33709 L F
.65595 .34422 m .6805 .35258 L .68771 .34393 L .657 .779 .939 r
F
.65595 .34422 m .68771 .34393 L .6595 .33986 L F
.6418 .34243 m .66013 .34671 L .66177 .34205 L .656 .78 .94 r
F
.63587 .33623 m .6362 .34229 L .63613 .34259 L 0 0 .209 r
F
.63607 .34286 m .63604 .34298 L .63576 .33673 L F
.63576 .33673 m .63604 .34298 L .636 .34316 L F
.63578 .33304 m .65829 .32622 L .65397 .32253 L .657 .779 .939 r
F
.63406 .32751 m .63407 .33386 L .63429 .33392 L .822 .528 .492 r
F
.63468 .32794 m .63481 .33428 L .63526 .32835 L .931 .625 .44 r
F
.63468 .32794 m .63406 .32751 L .63429 .33392 L F
.63468 .32794 m .63429 .33392 L .63481 .33428 L F
.63109 .33576 m .64013 .33259 L .63578 .33304 L .657 .779 .939 r
F
.64013 .33259 m .65829 .32622 L .63578 .33304 L F
.63087 .32712 m .63098 .33355 L .63151 .32706 L .65 .39 .512 r
F
.62721 .3373 m .62747 .3438 L .62705 .33701 L .972 .694 .284 r
F
.62747 .3438 m .62734 .34357 L .62705 .33701 L F
.63167 .34262 m .62361 .34404 L .61859 .34719 L .656 .78 .94 r
F
.62832 .34461 m .62836 .34464 L .62846 .34774 L .948 .643 .425 r
F
.62832 .34461 m .62846 .34774 L .6292 .3689 L F
.6281 .34444 m .62832 .34461 L .6292 .3689 L F
.6281 .34444 m .6292 .3689 L .62787 .34425 L F
.62836 .34464 m .63036 .36946 L .6292 .3689 L .862 .563 .481 r
F
.62876 .34481 m .63036 .36946 L .62836 .34464 L F
.62697 .33651 m .6272 .34332 L .6272 .34303 L 0 0 .044 r
F
.60813 .34192 m .58607 .35473 L .59774 .36001 L .657 .779 .938 r
F
.62034 .33953 m .61234 .33906 L .60416 .34521 L .657 .779 .939 r
F
.61234 .33906 m .60228 .34209 L .60416 .34521 L F
.62486 .33936 m .62034 .33953 L .60855 .3488 L F
.62034 .33953 m .60416 .34521 L .60729 .34777 L F
.62034 .33953 m .60729 .34777 L .60855 .3488 L F
.62486 .33936 m .60855 .3488 L .62129 .34502 L F
.60416 .34521 m .58633 .36164 L .60855 .3488 L F
.60416 .34521 m .5775 .35456 L .58633 .36164 L F
.60158 .34095 m .5775 .35456 L .60416 .34521 L F
.62361 .34404 m .60153 .34319 L .60211 .34781 L .656 .78 .94 r
F
.62697 .33617 m .62719 .34276 L .62697 .33601 L 0 0 .044 r
F
.62719 .34276 m .62719 .34264 L .62697 .33601 L F
.62697 .33651 m .6272 .34303 L .62697 .33617 L F
.6272 .34303 m .62719 .34276 L .62697 .33617 L F
.63167 .34262 m .62568 .34273 L .62361 .34404 L .656 .78 .94 r
F
.62568 .34273 m .60153 .34319 L .62361 .34404 L F
.62817 .32803 m .62819 .33457 L .62827 .33452 L .369 .177 .485 r
F
.62898 .29308 m .62885 .3276 L .62954 .32739 L .547 .31 .508 r
F
.63051 .32892 m .61721 .31349 L .61067 .31651 L .657 .779 .938 r
F
.62817 .32803 m .62827 .33452 L .62885 .3276 L .369 .177 .485 r
F
.62827 .33452 m .62883 .33417 L .62885 .3276 L F
.63109 .33576 m .61111 .32332 L .60592 .32719 L .657 .779 .939 r
F
.62819 .33457 m .62821 .34114 L .62827 .33452 L .369 .177 .485 r
F
.62727 .33554 m .62743 .34208 L .62755 .33509 L 0 0 .377 r
F
.62743 .34208 m .62765 .34173 L .62755 .33509 L F
.62697 .33601 m .62719 .34264 L .62719 .34245 L 0 0 .044 r
F
.62727 .33554 m .62697 .33601 L .62719 .34245 L 0 0 .377 r
F
.62727 .33554 m .62719 .34245 L .62743 .34208 L F
.62568 .34273 m .62519 .34169 L .62145 .34281 L .656 .78 .94 r
F
.63167 .34262 m .62694 .34194 L .62568 .34273 L F
.62694 .34194 m .62519 .34169 L .62568 .34273 L F
.62898 .29308 m .62954 .32739 L .63019 .32719 L .547 .31 .508 r
F
.63051 .32892 m .62468 .31153 L .61721 .31349 L .657 .779 .938 r
F
.62954 .32739 m .62885 .3276 L .62907 .33401 L .547 .31 .508 r
F
.62954 .32739 m .62907 .33401 L .62964 .33384 L F
.62885 .3276 m .62883 .33417 L .62907 .33401 L .369 .177 .485 r
F
.63109 .33576 m .6177 .32029 L .61111 .32332 L .657 .779 .939 r
F
.62827 .33452 m .62836 .34104 L .62883 .33417 L .369 .177 .485 r
F
.62787 .34425 m .6292 .3689 L .62776 .34417 L .948 .643 .425 r
F
.6276 .34404 m .6292 .3689 L .62844 .36821 L F
.62776 .34417 m .6292 .3689 L .6276 .34404 L F
.62912 .34495 m .63036 .36946 L .62876 .34481 L .862 .563 .481 r
F
.62447 .33692 m .62277 .33591 L .61234 .33906 L .657 .779 .939 r
F
.62277 .33591 m .601 .33632 L .61234 .33906 L F
.62447 .33692 m .61234 .33906 L .62034 .33953 L F
.61234 .33906 m .60158 .34095 L .60228 .34209 L F
.6209 .34107 m .60646 .33408 L .60301 .33851 L .656 .78 .94 r
F
.62755 .33509 m .62765 .34173 L .62768 .3349 L 0 0 .377 r
F
.62765 .34173 m .62775 .34158 L .62768 .3349 L F
.62768 .3349 m .62775 .34158 L .6279 .34134 L F
.63051 .32892 m .63256 .31076 L .62468 .31153 L .657 .779 .938 r
F
.62954 .32739 m .62964 .33384 L .63019 .32719 L .547 .31 .508 r
F
.62964 .33384 m .63018 .33368 L .63019 .32719 L F
.63019 .32719 m .63018 .33368 L .63042 .33361 L F
.63109 .33576 m .62522 .31832 L .6177 .32029 L .657 .779 .939 r
F
.63098 .33355 m .63151 .33349 L .63151 .32706 L .65 .39 .512 r
F
.63151 .32706 m .63151 .33349 L .63174 .33347 L F
.63217 .3271 m .63151 .32706 L .63174 .33347 L .735 .457 .508 r
F
.63087 .32712 m .63019 .32719 L .63042 .33361 L .65 .39 .512 r
F
.63087 .32712 m .63042 .33361 L .63098 .33355 L F
.63109 .33576 m .63316 .31755 L .62522 .31832 L .657 .779 .939 r
F
.63018 .33368 m .63017 .34019 L .63042 .33361 L .547 .31 .508 r
F
.62694 .34194 m .62717 .3411 L .62519 .34169 L .656 .78 .94 r
F
.63167 .34262 m .62789 .34134 L .62694 .34194 L F
.62789 .34134 m .62717 .3411 L .62694 .34194 L F
.62912 .34495 m .62951 .34511 L .63036 .36946 L .862 .563 .481 r
F
.62836 .34104 m .62881 .34077 L .62883 .33417 L .369 .177 .485 r
F
.62821 .34114 m .62825 .34111 L .62827 .33452 L F
.62827 .33452 m .62825 .34111 L .62836 .34104 L F
.62581 .335 m .60248 .33163 L .62277 .33591 L .657 .779 .939 r
F
.62601 .33754 m .62034 .33953 L .62486 .33936 L F
.62564 .34058 m .61166 .33022 L .60646 .33408 L .656 .78 .94 r
F
.62819 .33457 m .62768 .3349 L .6279 .34134 L .369 .177 .485 r
F
.62819 .33457 m .6279 .34134 L .62821 .34114 L F
.62964 .33384 m .62907 .33401 L .6293 .34046 L .547 .31 .508 r
F
.62789 .34134 m .62854 .34068 L .62717 .3411 L .656 .78 .94 r
F
.63167 .34262 m .62874 .34081 L .62789 .34134 L F
.62874 .34081 m .62854 .34068 L .62789 .34134 L F
.62883 .33417 m .62881 .34077 L .62907 .33401 L .369 .177 .485 r
F
.62881 .34077 m .629 .34064 L .62907 .33401 L F
.62964 .33384 m .6293 .34046 L .62975 .34032 L .547 .31 .508 r
F
.62907 .33401 m .629 .34064 L .6293 .34046 L .369 .177 .485 r
F
.62617 .33585 m .62581 .335 L .62277 .33591 L .657 .779 .939 r
F
.62617 .33585 m .62277 .33591 L .62447 .33692 L F
.62798 .34033 m .61826 .32719 L .61166 .33022 L .656 .78 .94 r
F
.63167 .34262 m .62954 .34017 L .62798 .34033 L F
.62954 .34017 m .61826 .32719 L .62798 .34033 L F
.63098 .33355 m .63042 .33361 L .63065 .34005 L .65 .39 .512 r
F
.63098 .33355 m .63065 .34005 L .63109 .34 L F
.63017 .34019 m .63036 .34014 L .63042 .33361 L .547 .31 .508 r
F
.63042 .33361 m .63036 .34014 L .63065 .34005 L F
.62964 .33384 m .62975 .34032 L .63018 .33368 L F
.62975 .34032 m .63017 .34019 L .63018 .33368 L F
.6272 .3352 m .62581 .335 L .62617 .33585 L .657 .779 .939 r
F
.63167 .34262 m .6258 .32522 L .61826 .32719 L .656 .78 .94 r
F
.63228 .33351 m .6328 .33355 L .6328 .32715 L .735 .457 .508 r
F
.63217 .3271 m .63174 .33347 L .63228 .33351 L F
.63344 .32733 m .63356 .33372 L .63406 .32751 L .822 .528 .492 r
F
.63356 .33372 m .63407 .33386 L .63406 .32751 L F
.6328 .32715 m .6328 .33355 L .63303 .33356 L .735 .457 .508 r
F
.63344 .32733 m .6328 .32715 L .63303 .33356 L .822 .528 .492 r
F
.63344 .32733 m .63303 .33356 L .63356 .33372 L F
.63109 .33576 m .64095 .31803 L .63316 .31755 L .657 .779 .939 r
F
.63109 .33576 m .64805 .31973 L .64095 .31803 L F
.63109 .33576 m .65397 .32253 L .64805 .31973 L F
.63151 .33349 m .6315 .33996 L .63174 .33347 L .65 .39 .512 r
F
.6315 .33996 m .63169 .33994 L .63174 .33347 L F
.63174 .33347 m .63169 .33994 L .63197 .33991 L F
.63098 .33355 m .63109 .34 L .63151 .33349 L F
.63109 .34 m .6315 .33996 L .63151 .33349 L F
.63167 .34262 m .63198 .33991 L .63072 .33982 L .656 .78 .94 r
F
.63587 .33623 m .63613 .34259 L .6358 .33657 L 0 0 .209 r
F
.63613 .34259 m .63607 .34286 L .6358 .33657 L F
.63167 .34262 m .63941 .34373 L .63764 .34251 L .656 .78 .94 r
F
.63228 .33351 m .63174 .33347 L .63197 .33991 L .735 .457 .508 r
F
.64179 .34242 m .66177 .34205 L .66177 .34204 L .656 .78 .94 r
F
.63167 .34262 m .6418 .34243 L .64179 .34242 L F
.6418 .34243 m .66177 .34205 L .64179 .34242 L F
.63407 .33386 m .63408 .34024 L .63429 .33392 L .822 .528 .492 r
F
.63588 .33566 m .63604 .34191 L .63596 .33586 L .944 .685 .22 r
F
.63587 .33623 m .63596 .33586 L .6362 .34229 L 0 0 .209 r
F
.63604 .34191 m .6361 .34206 L .63596 .33586 L .944 .685 .22 r
F
.63596 .33586 m .6361 .34206 L .6362 .34229 L F
.63835 .34145 m .66177 .34204 L .64273 .34068 L .656 .78 .94 r
F
.63589 .34157 m .63604 .34191 L .63588 .33566 L .944 .685 .22 r
F
.63167 .34262 m .64179 .34242 L .63835 .34145 L .656 .78 .94 r
F
.64179 .34242 m .66177 .34204 L .63835 .34145 L F
.63356 .33372 m .63303 .33356 L .63326 .34 L .822 .528 .492 r
F
.63328 .34504 m .63338 .34536 L .63372 .34498 L .656 .78 .94 r
F
.63338 .34536 m .63375 .3451 L .63372 .34498 L F
.63372 .34486 m .63544 .36901 L .63355 .34493 L .492 .27 .504 r
F
.63364 .3449 m .63328 .34504 L .63372 .34498 L .656 .78 .94 r
F
.63328 .34504 m .63544 .36901 L .63417 .36953 L .492 .27 .504 r
F
.63355 .34493 m .63544 .36901 L .63328 .34504 L F
.63372 .34498 m .63375 .3451 L .63379 .34507 L .656 .78 .94 r
F
.63377 .34484 m .63379 .3459 L .63372 .34486 L .492 .27 .504 r
F
.63411 .34471 m .63379 .3459 L .63377 .34484 L F
.63379 .34507 m .63398 .3458 L .63415 .34558 L .656 .78 .94 r
F
.63411 .34471 m .63544 .36901 L .63379 .3459 L .492 .27 .504 r
F
.63356 .33372 m .63326 .34 L .63369 .34012 L .822 .528 .492 r
F
.63408 .34024 m .63426 .34029 L .63429 .33392 L F
.63481 .33428 m .63429 .33392 L .63453 .34036 L .931 .625 .44 r
F
.63481 .33428 m .63453 .34036 L .63493 .34064 L F
.63429 .33392 m .63426 .34029 L .63453 .34036 L .822 .528 .492 r
F
.64035 .33409 m .66072 .33054 L .66066 .33043 L .657 .779 .939 r
F
.64051 .3341 m .66072 .33054 L .64035 .33409 L F
.64013 .33259 m .66066 .33043 L .65829 .32622 L F
.63529 .33461 m .63531 .3409 L .6355 .33476 L .931 .625 .44 r
F
.63531 .3409 m .63548 .34102 L .6355 .33476 L F
.6355 .33476 m .63548 .34102 L .63574 .3412 L F
.63356 .33372 m .63369 .34012 L .63407 .33386 L .822 .528 .492 r
F
.63369 .34012 m .63408 .34024 L .63407 .33386 L F
.6357 .33523 m .6355 .33476 L .63574 .3412 L .944 .685 .22 r
F
.6357 .33523 m .63574 .3412 L .63589 .34157 L F
.63481 .33428 m .63493 .34064 L .63529 .33461 L .931 .625 .44 r
F
.63493 .34064 m .63531 .3409 L .63529 .33461 L F
.63303 .33356 m .63299 .33998 L .63326 .34 L .735 .457 .508 r
F
.6357 .33523 m .63589 .34157 L .63588 .33566 L .944 .685 .22 r
F
.63314 .33999 m .64867 .32663 L .64156 .32493 L .656 .78 .94 r
F
.63167 .34262 m .63437 .34008 L .63314 .33999 L F
.63437 .34008 m .64867 .32663 L .63314 .33999 L F
.64052 .3357 m .6595 .33986 L .661 .33557 L .657 .779 .939 r
F
.65059 .33857 m .6595 .33986 L .64052 .3357 L F
.63437 .34008 m .6546 .32941 L .64867 .32663 L .656 .78 .94 r
F
.63167 .34262 m .63589 .34019 L .63437 .34008 L F
.63589 .34019 m .6546 .32941 L .63437 .34008 L F
.6328 .33355 m .63281 .33997 L .63303 .33356 L .735 .457 .508 r
F
.63281 .33997 m .63299 .33998 L .63303 .33356 L F
.63228 .33351 m .63197 .33991 L .6324 .33994 L F
.63228 .33351 m .6324 .33994 L .6328 .33355 L F
.6324 .33994 m .63281 .33997 L .6328 .33355 L F
.63167 .34262 m .64156 .32493 L .63375 .32445 L .656 .78 .94 r
F
.63167 .34262 m .65892 .3331 L .6546 .32941 L F
.65686 .33527 m .661 .33557 L .66113 .33519 L .657 .779 .939 r
F
.65059 .33857 m .65867 .34088 L .6595 .33986 L F
.68675 .33709 m .71991 .32725 L .69015 .32781 L .657 .779 .938 r
F
.6595 .33986 m .69114 .33463 L .66113 .33519 L .657 .779 .939 r
F
.63167 .34262 m .66136 .33741 L .65892 .3331 L .656 .78 .94 r
F
.63281 .33997 m .63283 .3638 L .63299 .33998 L .735 .457 .508 r
F
.63326 .34 m .63283 .3638 L .63414 .36395 L F
.63299 .33998 m .63283 .3638 L .63326 .34 L F
.63369 .34012 m .63326 .34 L .63414 .36395 L .822 .528 .492 r
F
.63408 .34024 m .63414 .36395 L .63426 .34029 L F
.6324 .33994 m .63197 .33991 L .63283 .3638 L .735 .457 .508 r
F
.68675 .33709 m .71458 .34113 L .71991 .32725 L .657 .779 .938 r
F
.6595 .33986 m .68771 .34393 L .69114 .33463 L .657 .779 .939 r
F
.64273 .34068 m .66177 .34204 L .66136 .33741 L .656 .78 .94 r
F
.63072 .33982 m .63375 .32445 L .6258 .32522 L F
.63198 .33991 m .63375 .32445 L .63072 .33982 L F
.6324 .33994 m .63283 .3638 L .63281 .33997 L .735 .457 .508 r
F
.63109 .34 m .63065 .34005 L .6315 .3639 L .65 .39 .512 r
F
.62881 .34077 m .62872 .36522 L .629 .34064 L .369 .177 .485 r
F
.62975 .34032 m .6293 .34046 L .63013 .3643 L .547 .31 .508 r
F
.62717 .3411 m .62798 .34033 L .62564 .34058 L .656 .78 .94 r
F
.62854 .34068 m .62798 .34033 L .62717 .3411 L F
.62798 .34033 m .61166 .33022 L .62564 .34058 L F
.6315 .33996 m .6315 .3639 L .63169 .33994 L .65 .39 .512 r
F
.6293 .34046 m .62872 .36522 L .63013 .3643 L .369 .177 .485 r
F
.629 .34064 m .62872 .36522 L .6293 .34046 L F
.63017 .34019 m .63013 .3643 L .63036 .34014 L .547 .31 .508 r
F
.62519 .34169 m .62564 .34058 L .6209 .34107 L .656 .78 .94 r
F
.62717 .3411 m .62564 .34058 L .62519 .34169 L F
.62564 .34058 m .60646 .33408 L .6209 .34107 L F
.63197 .33991 m .6315 .3639 L .63283 .3638 L .65 .39 .512 r
F
.63169 .33994 m .6315 .3639 L .63197 .33991 L F
.62836 .34104 m .62872 .36522 L .62881 .34077 L .369 .177 .485 r
F
.63065 .34005 m .63013 .3643 L .6315 .3639 L .547 .31 .508 r
F
.63036 .34014 m .63013 .3643 L .63065 .34005 L F
.62145 .34281 m .6209 .34107 L .60153 .34319 L .656 .78 .94 r
F
.62519 .34169 m .6209 .34107 L .62145 .34281 L F
.6209 .34107 m .60301 .33851 L .60156 .34311 L F
.6209 .34107 m .60156 .34311 L .60153 .34319 L F
.63109 .34 m .6315 .3639 L .6315 .33996 L .65 .39 .512 r
F
.62821 .34114 m .62824 .35109 L .62825 .34111 L .369 .177 .485 r
F
.62836 .34104 m .62824 .35109 L .62862 .3582 L F
.62825 .34111 m .62824 .35109 L .62836 .34104 L F
.60855 .3488 m .58633 .36164 L .59808 .36694 L .657 .779 .939 r
F
.61859 .34719 m .60864 .34666 L .60469 .35205 L .656 .78 .94 r
F
.62361 .34404 m .60864 .34666 L .61859 .34719 L F
.60864 .34666 m .60211 .34781 L .60253 .3485 L F
.60864 .34666 m .60253 .3485 L .60469 .35205 L F
.62975 .34032 m .63013 .3643 L .63017 .34019 L .547 .31 .508 r
F
.63485 .34431 m .63634 .36835 L .63473 .3444 L .328 .148 .478 r
F
.63454 .34453 m .63634 .36835 L .63544 .36901 L F
.63473 .3444 m .63634 .36835 L .63454 .34453 L F
.63513 .34412 m .63634 .36835 L .63485 .34431 L F
.63493 .34064 m .63453 .34036 L .63541 .36439 L .931 .625 .44 r
F
.63764 .34251 m .65352 .34576 L .6418 .34243 L .656 .78 .94 r
F
.63941 .34373 m .65352 .34576 L .63764 .34251 L F
.65352 .34576 m .66013 .34671 L .6418 .34243 L F
.63453 .34036 m .63414 .36395 L .63541 .36439 L .822 .528 .492 r
F
.63426 .34029 m .63414 .36395 L .63453 .34036 L F
.63543 .3439 m .63691 .36755 L .63634 .36835 L .067 0 .41 r
F
.63555 .34375 m .63691 .36755 L .63543 .3439 L F
.63531 .3409 m .63541 .36439 L .63548 .34102 L .931 .625 .44 r
F
.63581 .34341 m .636 .34316 L .63691 .36755 L .067 0 .41 r
F
.63563 .34364 m .63691 .36755 L .63555 .34375 L F
.63581 .34341 m .63691 .36755 L .63563 .34364 L F
.63574 .3412 m .63541 .36439 L .63664 .36536 L .931 .625 .44 r
F
.63548 .34102 m .63541 .36439 L .63574 .3412 L F
.65073 .34799 m .67006 .36003 L .6805 .35258 L .657 .779 .939 r
F
.63986 .34405 m .65657 .35106 L .65951 .34746 L .656 .78 .94 r
F
.64372 .3467 m .65657 .35106 L .63986 .34405 L F
.65352 .34576 m .65951 .34746 L .66013 .34671 L F
.63369 .34012 m .63414 .36395 L .63408 .34024 L .822 .528 .492 r
F
.63589 .34157 m .63574 .3412 L .63664 .36536 L .944 .685 .22 r
F
.64421 .35092 m .65708 .36579 L .67006 .36003 L .657 .779 .939 r
F
.63757 .34554 m .65135 .35482 L .65337 .35336 L .656 .78 .94 r
F
.63799 .34654 m .65135 .35482 L .63757 .34554 L F
.64372 .3467 m .65337 .35336 L .65657 .35106 L F
.63493 .34064 m .63541 .36439 L .63531 .3409 L .931 .625 .44 r
F
.64073 .35305 m .64481 .35775 L .63998 .35127 L .656 .78 .94 r
F
.63607 .34286 m .63711 .36659 L .63604 .34298 L 0 0 .209 r
F
.636 .34316 m .63711 .36659 L .63691 .36755 L F
.63604 .34298 m .63711 .36659 L .636 .34316 L F
.63613 .34259 m .63711 .36659 L .63607 .34286 L F
.63604 .34191 m .63664 .36536 L .6361 .34206 L .944 .685 .22 r
F
.63613 .34259 m .6362 .34229 L .63711 .36659 L 0 0 .209 r
F
.6362 .34229 m .63664 .36536 L .63711 .36659 L .944 .685 .22 r
F
.6361 .34206 m .63664 .36536 L .6362 .34229 L F
.63799 .34654 m .64481 .35775 L .65135 .35482 L .656 .78 .94 r
F
.63998 .35127 m .64481 .35775 L .63799 .34654 L F
.64073 .35305 m .64291 .35823 L .64481 .35775 L F
.63589 .34157 m .63664 .36536 L .63604 .34191 L .944 .685 .22 r
F
.62747 .3438 m .6276 .34404 L .62844 .36821 L .972 .694 .284 r
F
.62734 .34357 m .62844 .36821 L .62728 .34347 L F
.6272 .34332 m .62844 .36821 L .62802 .36739 L F
.62728 .34347 m .62844 .36821 L .6272 .34332 L F
.62747 .3438 m .62844 .36821 L .62734 .34357 L F
.62765 .34173 m .62801 .36643 L .62775 .34158 L 0 0 .377 r
F
.6272 .34303 m .6272 .34332 L .62802 .36739 L 0 0 .044 r
F
.6279 .34134 m .62801 .36643 L .62872 .36522 L 0 0 .377 r
F
.62775 .34158 m .62801 .36643 L .6279 .34134 L F
.62445 .34678 m .61859 .34719 L .60908 .35563 L .656 .78 .94 r
F
.62578 .34468 m .61859 .34719 L .62445 .34678 L F
.61859 .34719 m .60469 .35205 L .60738 .35425 L F
.61859 .34719 m .60738 .35425 L .60908 .35563 L F
.62821 .34114 m .6279 .34134 L .62824 .35109 L .369 .177 .485 r
F
.62743 .34208 m .62801 .36643 L .62765 .34173 L 0 0 .377 r
F
.62032 .3533 m .60908 .35563 L .61498 .35832 L .656 .78 .94 r
F
.62376 .34787 m .60908 .35563 L .62032 .3533 L F
.62719 .34276 m .62802 .36739 L .62719 .34264 L 0 0 .044 r
F
.62723 .34764 m .62032 .3533 L .62725 .35051 L .656 .78 .94 r
F
.62719 .34245 m .62802 .36739 L .62801 .36643 L 0 0 .044 r
F
.62719 .34264 m .62802 .36739 L .62719 .34245 L F
.62032 .3533 m .61498 .35832 L .61686 .35875 L .656 .78 .94 r
F
.62032 .3533 m .61686 .35875 L .62198 .35994 L F
.62743 .34208 m .62719 .34245 L .62801 .36643 L 0 0 .377 r
F
.62725 .35051 m .62198 .35994 L .62727 .35194 L .656 .78 .94 r
F
.6272 .34303 m .62802 .36739 L .62719 .34276 L 0 0 .044 r
F
.62862 .3582 m .62824 .35109 L .62872 .36522 L .369 .177 .485 r
F
.42738 .24437 m .39955 .23201 L .39871 .24037 L .733 .471 .532 r
F
0 g
.39955 .23201 m
.42814 .23602 L
s
.37111 .23304 m
.39955 .23201 L
s
.74066 .52043 m .74363 .50802 L .73562 .5196 L .658 .807 .955 r
F
.74066 .52043 m .75376 .50973 L .74363 .50802 L F
.74569 .52764 m .75468 .5154 L .74155 .52609 L .657 .808 .956 r
F
.74569 .52764 m .76297 .51856 L .75468 .5154 L F
.69141 .5162 m .67344 .51154 L .66557 .52027 L .658 .806 .954 r
F
.45332 .26146 m .42738 .24437 L .42661 .25277 L .802 .535 .534 r
F
0 g
.45332 .26146 m
.47602 .27413 L
s
.67396 .51714 m .66526 .52025 L .66604 .5259 L .212 .125 .534 r
F
.67396 .51714 m .67317 .51147 L .66526 .52025 L F
0 g
.66165 .52928 m
.66526 .52025 L
s
.23512 .5239 m .2179 .52044 L .21803 .5261 L .668 .439 .564 r
F
.23512 .5239 m .23496 .51825 L .2179 .52044 L F
0 g
.20242 .52483 m
.2179 .52044 L
s
.37501 .38352 m .35341 .37177 L .34441 .3791 L .657 .779 .939 r
F
.38101 .38068 m .35341 .37177 L .37501 .38352 L F
.18857 .64601 m .1919 .64688 L .19118 .6517 L .996 .808 .446 r
F
.18857 .64601 m .18929 .64117 L .1919 .64688 L F
0 g
.1919 .64688 m
.1963 .65133 L
s
.2042 .64206 m .1921 .64686 L .20589 .64585 L .597 .767 .961 r
F
.2042 .64206 m .18951 .64119 L .1921 .64686 L F
.69287 .52747 m .66682 .53157 L .68753 .53326 L .657 .808 .956 r
F
.39234 .48941 m .39278 .50117 L .39552 .50082 L .662 .803 .95 r
F
.39624 .49281 m .39552 .50082 L .40416 .49971 L F
.39234 .48941 m .39552 .50082 L .39624 .49281 L F
.3966 .48886 m .40416 .49971 L .39808 .48868 L F
.39234 .48941 m .39624 .49281 L .3966 .48886 L F
.39624 .49281 m .40416 .49971 L .3966 .48886 L F
.3997 .42644 m .39978 .42554 L .39762 .47761 L 0 0 .006 r
F
.39273 .49514 m .39317 .50692 L .40463 .50545 L .661 .803 .951 r
F
.39273 .49514 m .40463 .50545 L .3985 .4944 L F
.39359 .42823 m .39545 .42852 L .39323 .48051 L .753 .483 .524 r
F
.39472 .4826 m .39234 .48941 L .39808 .48868 L .662 .803 .95 r
F
.39405 .48137 m .39335 .48465 L .39472 .4826 L F
.39335 .48465 m .39234 .48941 L .39472 .4826 L F
.39311 .50083 m .40503 .51111 L .3989 .50009 L .66 .804 .952 r
F
.39359 .42823 m .39323 .48051 L .39269 .48047 L .753 .483 .524 r
F
.39545 .42852 m .39457 .48027 L .39323 .48051 L .631 .379 .518 r
F
.3973 .42829 m .39846 .42781 L .3963 .47968 L .484 .259 .497 r
F
.39925 .42719 m .3997 .42644 L .39755 .4784 L 0 0 .327 r
F
.3959 .48085 m .39808 .48868 L .4034 .48718 L .662 .803 .95 r
F
.39564 .48125 m .39808 .48868 L .3959 .48085 L F
.39522 .48049 m .39808 .48868 L .39535 .48039 L F
.39354 .48045 m .39808 .48868 L .39511 .48018 L F
.3973 .42829 m .3963 .47968 L .39595 .47982 L .484 .259 .497 r
F
.39545 .42852 m .3973 .42829 L .39511 .48018 L .631 .379 .518 r
F
.39545 .42852 m .39511 .48018 L .39457 .48027 L F
.39846 .42781 m .39686 .47925 L .3963 .47968 L .286 .104 .449 r
F
.3973 .42829 m .39595 .47982 L .39511 .48018 L .484 .259 .497 r
F
.39915 .48088 m .4034 .48718 L .40796 .48502 L .662 .803 .95 r
F
.39359 .42823 m .39269 .48047 L .39133 .48039 L .753 .483 .524 r
F
.39189 .47746 m .39568 .48066 L .39915 .48088 L .662 .803 .95 r
F
.39568 .48066 m .4034 .48718 L .39915 .48088 L F
.39059 .48939 m .39278 .50117 L .39234 .48941 L F
.38657 .48934 m .39258 .5008 L .39059 .48939 L F
.39258 .5008 m .39278 .50117 L .39059 .48939 L F
.39095 .42539 m .39108 .42629 L .38875 .47888 L .875 .7 .179 r
F
.38657 .48934 m .38133 .50104 L .39265 .50117 L .662 .803 .95 r
F
.39258 .5008 m .39265 .50117 L .39278 .50117 L F
.38657 .48934 m .39265 .50117 L .39258 .5008 L F
.38692 .49507 m .39317 .50692 L .39273 .49514 L .661 .803 .951 r
F
.38692 .49507 m .38164 .5068 L .39317 .50692 L F
.39158 .42705 m .3924 .42771 L .39011 .48002 L .929 .648 .486 r
F
.3921 .48298 m .38657 .48934 L .39234 .48941 L .662 .803 .95 r
F
.39203 .48118 m .3914 .48212 L .3921 .48298 L F
.3914 .48212 m .38657 .48934 L .3921 .48298 L F
.39108 .42629 m .39158 .42705 L .38927 .47951 L .989 .724 .411 r
F
.39175 .48101 m .3912 .48188 L .39203 .48118 L .662 .803 .95 r
F
.3912 .48188 m .38657 .48934 L .3914 .48212 L F
.3912 .48188 m .3914 .48212 L .39203 .48118 L F
.39067 .48019 m .39061 .48032 L .39201 .48059 L F
.39061 .48032 m .38657 .48934 L .39175 .48101 L F
.39061 .48032 m .39175 .48101 L .39201 .48059 L F
.3873 .50076 m .39355 .51258 L .39311 .50083 L .66 .804 .952 r
F
.39158 .42705 m .38987 .47987 L .38927 .47951 L .929 .648 .486 r
F
.39158 .42705 m .39011 .48002 L .38987 .47987 L F
.3924 .42771 m .39359 .42823 L .39133 .48039 L .849 .569 .514 r
F
.3924 .42771 m .39133 .48039 L .39099 .48028 L F
.39108 .42629 m .38912 .47933 L .38875 .47888 L .989 .724 .411 r
F
.39108 .42629 m .38927 .47951 L .38912 .47933 L F
.39095 .42539 m .38871 .47866 L .38862 .4781 L .875 .7 .179 r
F
.39095 .42539 m .38875 .47888 L .38871 .47866 L F
.39149 .42425 m .39095 .42539 L .38862 .4781 L 0 0 .269 r
F
.39067 .48019 m .38481 .48528 L .38657 .48934 L .662 .803 .95 r
F
.38956 .47985 m .38547 .48404 L .39067 .48019 L F
.38547 .48404 m .38115 .48847 L .38481 .48528 L F
.38547 .48404 m .38481 .48528 L .39067 .48019 L F
.39356 .48174 m .39234 .48941 L .39405 .48137 L F
.39353 .48085 m .39234 .48941 L .39371 .48077 L F
.39353 .48052 m .39234 .48941 L .39358 .48053 L F
.39201 .48072 m .39234 .48941 L .39354 .48045 L F
.3925 .48914 m .38692 .49507 L .39273 .49514 L .661 .803 .951 r
F
.39062 .48684 m .38692 .49507 L .3925 .48914 L F
.38481 .48528 m .38296 .48876 L .38657 .48934 L .662 .803 .95 r
F
.3924 .42771 m .39099 .48028 L .39011 .48002 L .849 .569 .514 r
F
.39189 .47746 m .37644 .48685 L .38115 .48847 L .662 .803 .95 r
F
.39189 .47746 m .3843 .48029 L .37644 .48685 L F
.3843 .48029 m .37277 .48458 L .37537 .48619 L F
.3843 .48029 m .37537 .48619 L .37644 .48685 L F
.39274 .42339 m .39149 .42425 L .38916 .47708 L .339 .143 .462 r
F
.38912 .47933 m .38892 .48477 L .38875 .47888 L .989 .724 .411 r
F
.38115 .48847 m .38133 .50104 L .38657 .48934 L .662 .803 .95 r
F
.39062 .48684 m .38413 .49148 L .38692 .49507 L .661 .803 .951 r
F
.39037 .48654 m .38909 .48755 L .39062 .48684 L F
.38909 .48755 m .38413 .49148 L .38915 .48789 L F
.38909 .48755 m .38915 .48789 L .39062 .48684 L F
.38871 .47866 m .38875 .47888 L .38851 .48427 L .875 .7 .179 r
F
.39084 .48599 m .39029 .48644 L .39097 .48607 L .661 .803 .951 r
F
.39029 .48644 m .38413 .49148 L .39037 .48654 L F
.39029 .48644 m .39037 .48654 L .39097 .48607 L F
.38912 .47933 m .38927 .47951 L .38903 .4849 L .989 .724 .411 r
F
.39133 .48039 m .39158 .4858 L .3911 .48577 L .753 .483 .524 r
F
.39239 .48616 m .39062 .48684 L .3925 .48914 L .661 .803 .951 r
F
.39201 .48059 m .39175 .48101 L .39203 .48118 L .662 .803 .95 r
F
.39189 .47746 m .39201 .48072 L .39354 .48045 L F
.39269 .48047 m .3926 .48587 L .39133 .48039 L .753 .483 .524 r
F
.39238 .48585 m .3911 .48577 L .39239 .48616 L .661 .803 .951 r
F
.3911 .48577 m .39062 .48684 L .39239 .48616 L F
.3926 .48587 m .39158 .4858 L .39133 .48039 L .753 .483 .524 r
F
.39474 .48762 m .39273 .49514 L .3985 .4944 L .661 .803 .951 r
F
.39457 .48027 m .39511 .48018 L .39488 .48557 L .631 .379 .518 r
F
.39382 .48594 m .39257 .49085 L .39474 .48762 L .661 .803 .951 r
F
.39372 .48577 m .39368 .48593 L .39382 .48594 L F
.39368 .48593 m .39257 .49085 L .39382 .48594 L F
.39269 .48047 m .39323 .48051 L .393 .48589 L .753 .483 .524 r
F
.39269 .48047 m .393 .48589 L .3926 .48587 L F
.39238 .486 m .39257 .49085 L .39372 .48577 L .661 .803 .951 r
F
.39257 .49085 m .39273 .49514 L .39474 .48762 L F
.39311 .50083 m .39355 .51258 L .40503 .51111 L .66 .804 .952 r
F
.39808 .48868 m .40416 .49971 L .41474 .49675 L .662 .803 .95 r
F
.39808 .48868 m .41474 .49675 L .4034 .48718 L F
.39702 .48715 m .3985 .4944 L .40386 .4929 L .661 .803 .951 r
F
.39702 .48715 m .40386 .4929 L .40386 .4929 L F
.39683 .48931 m .3985 .4944 L .39702 .48715 L F
.39554 .48643 m .39678 .48977 L .39577 .4861 L F
.39678 .48977 m .3985 .4944 L .39683 .48931 L F
.39678 .48977 m .39683 .48931 L .39577 .4861 L F
.39862 .47915 m .40796 .48502 L .41143 .48235 L .662 .803 .95 r
F
.39846 .42781 m .39925 .42719 L .39709 .47908 L .286 .104 .449 r
F
.39846 .42781 m .39709 .47908 L .39686 .47925 L F
.39925 .42719 m .39742 .47859 L .39709 .47908 L 0 0 .327 r
F
.39189 .47746 m .40001 .48128 L .39862 .47915 L .662 .803 .95 r
F
.40001 .48128 m .40796 .48502 L .39862 .47915 L F
.39925 .42719 m .39755 .4784 L .39742 .47859 L 0 0 .327 r
F
.3997 .42644 m .3976 .47784 L .39755 .4784 L 0 0 .006 r
F
.39786 .47798 m .41143 .48235 L .4136 .47933 L .662 .803 .95 r
F
.39189 .47746 m .39862 .47915 L .39786 .47798 L F
.39862 .47915 m .41143 .48235 L .39786 .47798 L F
.3997 .42644 m .39762 .47761 L .3976 .47784 L 0 0 .006 r
F
.39978 .42554 m .39917 .42439 L .397 .47665 L .99 .735 .374 r
F
.39577 .4861 m .39683 .48931 L .39702 .48715 L .661 .803 .951 r
F
.39517 .48574 m .39548 .48653 L .39526 .48567 L F
.39548 .48653 m .3985 .4944 L .39554 .48643 L F
.39548 .48653 m .39554 .48643 L .39526 .48567 L F
.39742 .47859 m .39723 .48393 L .39709 .47908 L 0 0 .327 r
F
.39476 .49265 m .39311 .50083 L .39608 .50045 L .66 .804 .952 r
F
.39651 .49578 m .39608 .50045 L .3989 .50009 L F
.39476 .49265 m .39608 .50045 L .39651 .49578 L F
.4034 .48718 m .41474 .49675 L .42382 .49248 L .662 .803 .95 r
F
.39718 .48546 m .40386 .4929 L .40845 .49073 L .661 .803 .951 r
F
.39323 .48051 m .39348 .48581 L .393 .48589 L .631 .379 .518 r
F
.39457 .48027 m .39488 .48557 L .39448 .48564 L F
.39595 .47982 m .3963 .47968 L .39607 .48507 L .484 .259 .497 r
F
.39607 .48507 m .39702 .48715 L .39621 .48501 L .661 .803 .951 r
F
.39505 .48549 m .39526 .48567 L .39607 .48507 L F
.39526 .48567 m .39702 .48715 L .39607 .48507 L F
.39488 .48557 m .39414 .48652 L .39509 .48553 L F
.39414 .48652 m .3985 .4944 L .39517 .48574 L F
.39414 .48652 m .39517 .48574 L .39509 .48553 L F
.39399 .49125 m .39364 .49431 L .39476 .49265 L .66 .804 .952 r
F
.3939 .4911 m .39389 .49129 L .39399 .49125 L F
.39389 .49129 m .39364 .49431 L .39399 .49125 L F
.39364 .49431 m .39311 .50083 L .39476 .49265 L F
.39488 .48557 m .39506 .4908 L .39466 .49097 L .484 .259 .497 r
F
.39621 .48501 m .39702 .48715 L .39718 .48546 L .661 .803 .951 r
F
.39511 .48018 m .39518 .48544 L .39488 .48557 L .484 .259 .497 r
F
.39686 .47925 m .3967 .4846 L .3963 .47968 L .286 .104 .449 r
F
.3967 .4846 m .39627 .48491 L .3963 .47968 L F
.3963 .47968 m .39627 .48491 L .39607 .48507 L F
.39595 .47982 m .39607 .48507 L .39582 .48517 L .484 .259 .497 r
F
.4034 .48718 m .42382 .49248 L .40796 .48502 L .662 .803 .95 r
F
.39727 .4844 m .40845 .49073 L .41195 .48805 L .661 .803 .951 r
F
.39709 .47908 m .39699 .48429 L .39687 .48447 L 0 0 .327 r
F
.39686 .47925 m .39709 .47908 L .39687 .48447 L .286 .104 .449 r
F
.39686 .47925 m .39687 .48447 L .3967 .4846 L F
.39535 .48039 m .39564 .48125 L .3959 .48085 L .662 .803 .95 r
F
.39511 .48018 m .39522 .48049 L .39535 .48039 L F
.39595 .47982 m .39582 .48517 L .39511 .48018 L .484 .259 .497 r
F
.39582 .48517 m .39518 .48544 L .39511 .48018 L F
.39372 .48577 m .39385 .486 L .39488 .48557 L .661 .803 .951 r
F
.39385 .486 m .39414 .48652 L .39488 .48557 L F
.39371 .48077 m .39356 .48174 L .39405 .48137 L .662 .803 .95 r
F
.39358 .48053 m .39353 .48085 L .39371 .48077 L F
.39354 .48045 m .39353 .48052 L .39358 .48053 L F
.40796 .48502 m .42382 .49248 L .4308 .48718 L F
.40796 .48502 m .4308 .48718 L .41143 .48235 L F
.40334 .48411 m .41195 .48805 L .41412 .48502 L .661 .803 .951 r
F
.39457 .48027 m .39448 .48564 L .39323 .48051 L .631 .379 .518 r
F
.39448 .48564 m .39381 .48575 L .39323 .48051 L F
.39439 .49102 m .39372 .49113 L .39348 .48581 L F
.39381 .48575 m .39348 .48581 L .39323 .48051 L F
.39439 .49102 m .39348 .48581 L .39381 .48575 L F
.39978 .42554 m .39718 .47692 L .39762 .47761 L .99 .735 .374 r
F
.39789 .47712 m .4136 .47933 L .41429 .47617 L .662 .803 .95 r
F
.39189 .47746 m .39986 .47815 L .39789 .47712 L F
.39986 .47815 m .4136 .47933 L .39789 .47712 L F
.39723 .48393 m .39699 .48429 L .39709 .47908 L 0 0 .327 r
F
.39755 .4784 m .39735 .48359 L .39733 .48378 L 0 0 .006 r
F
.39742 .47859 m .39755 .4784 L .39733 .48378 L 0 0 .327 r
F
.39742 .47859 m .39733 .48378 L .39723 .48393 L F
.39228 .48316 m .39781 .48363 L .39732 .48287 L .661 .803 .951 r
F
.39228 .48316 m .39852 .48471 L .39804 .48397 L F
.39228 .48316 m .40138 .48444 L .40022 .48384 L F
.3968 .48429 m .39678 .48468 L .39727 .4844 L F
.39228 .48316 m .39678 .48468 L .3968 .48429 L F
.39228 .48316 m .39621 .48501 L .39678 .48468 L F
.39621 .48501 m .39718 .48546 L .39726 .48457 L F
.39621 .48501 m .39726 .48457 L .39727 .4844 L F
.3985 .4944 m .40463 .50545 L .41527 .50249 L F
.3985 .4944 m .41527 .50249 L .40386 .4929 L F
.39681 .4924 m .3989 .50009 L .40391 .49868 L .66 .804 .952 r
F
.39564 .49136 m .39666 .4941 L .39681 .4924 L F
.39666 .4941 m .3989 .50009 L .39681 .4924 L F
.39718 .48546 m .40845 .49073 L .39727 .4844 L .661 .803 .951 r
F
.39702 .48715 m .40386 .4929 L .39718 .48546 L F
.39739 .48317 m .39717 .48852 L .39735 .48359 L 0 0 .006 r
F
.39682 .49235 m .40391 .49868 L .40334 .49781 L .66 .804 .952 r
F
.39681 .4924 m .40391 .49868 L .39682 .49235 L F
.39545 .49164 m .39662 .49452 L .39564 .49136 L F
.39662 .49452 m .3989 .50009 L .39666 .4941 L F
.39662 .49452 m .39666 .4941 L .39564 .49136 L F
.39735 .48359 m .39714 .48879 L .39733 .48378 L 0 0 .006 r
F
.39508 .49104 m .39538 .49174 L .39517 .49097 L .66 .804 .952 r
F
.39538 .49174 m .3989 .50009 L .39545 .49164 L F
.39538 .49174 m .39545 .49164 L .39517 .49097 L F
.39564 .49136 m .39681 .4924 L .39682 .49235 L F
.3967 .4846 m .39687 .48447 L .39664 .48987 L .286 .104 .449 r
F
.39423 .49168 m .39476 .49265 L .39508 .49104 L .66 .804 .952 r
F
.39476 .49265 m .3989 .50009 L .39538 .49174 L F
.39476 .49265 m .39538 .49174 L .39508 .49104 L F
.39699 .48429 m .39688 .48953 L .39687 .48447 L 0 0 .327 r
F
.39448 .48564 m .39439 .49102 L .39381 .48575 L .631 .379 .518 r
F
.39597 .49042 m .40309 .49742 L .3996 .49211 L .66 .804 .952 r
F
.39688 .48953 m .3968 .48964 L .39687 .48447 L 0 0 .327 r
F
.39687 .48447 m .3968 .48964 L .39664 .48987 L F
.39723 .48393 m .39704 .48929 L .39699 .48429 L F
.39704 .48929 m .39688 .48953 L .39699 .48429 L F
.39917 .42439 m .39604 .47615 L .397 .47665 L .912 .629 .494 r
F
.39978 .42554 m .397 .47665 L .39718 .47692 L .99 .735 .374 r
F
.39669 .47649 m .41429 .47617 L .41345 .47309 L .662 .803 .95 r
F
.39189 .47746 m .39789 .47712 L .39669 .47649 L F
.39789 .47712 m .41429 .47617 L .39669 .47649 L F
.39917 .42439 m .39787 .42348 L .39566 .47595 L .912 .629 .494 r
F
.3976 .47784 m .39739 .48311 L .39739 .48317 L 0 0 .006 r
F
.3976 .47784 m .39762 .47761 L .3974 .483 L F
.3976 .47784 m .3974 .483 L .39739 .48311 L F
.3976 .47784 m .39739 .48317 L .39755 .4784 L F
.4136 .47933 m .43518 .48118 L .43666 .47488 L .662 .803 .95 r
F
.41143 .48235 m .43518 .48118 L .4136 .47933 L F
.4136 .47933 m .43666 .47488 L .41429 .47617 L F
.39748 .48211 m .41482 .48186 L .41398 .47877 L .661 .803 .951 r
F
.39739 .48317 m .39735 .48359 L .39755 .4784 L 0 0 .006 r
F
.39762 .47761 m .39691 .48225 L .3974 .483 L .99 .735 .374 r
F
.39706 .48219 m .39748 .48219 L .39748 .48211 L .661 .803 .951 r
F
.39748 .48219 m .41482 .48186 L .39748 .48211 L F
.39718 .47692 m .39686 .48218 L .39691 .48225 L .99 .735 .374 r
F
.3969 .48223 m .39826 .48282 L .39706 .48219 L .661 .803 .951 r
F
.39228 .48316 m .39732 .48287 L .3969 .48223 L F
.39732 .48287 m .39826 .48282 L .3969 .48223 L F
.39826 .48282 m .41482 .48186 L .39706 .48219 L F
.39917 .42439 m .39566 .47595 L .39604 .47615 L .912 .629 .494 r
F
.39787 .42348 m .39471 .47576 L .39566 .47595 L .814 .537 .519 r
F
.39189 .47746 m .39585 .47599 L .3947 .47575 L .662 .803 .95 r
F
.39607 .48507 m .39612 .49027 L .39584 .49047 L .286 .104 .449 r
F
.39526 .48567 m .39554 .48643 L .39577 .4861 L .661 .803 .951 r
F
.39582 .48517 m .39568 .49054 L .39518 .48544 L .484 .259 .497 r
F
.39568 .49054 m .39526 .49072 L .39518 .48544 L F
.39509 .48553 m .39517 .48574 L .39526 .48567 L .661 .803 .951 r
F
.39518 .48544 m .39526 .49072 L .39488 .48557 L .484 .259 .497 r
F
.39526 .49072 m .39506 .4908 L .39488 .48557 L F
.395 .49083 m .39517 .49097 L .39584 .49047 L .66 .804 .952 r
F
.39517 .49097 m .40427 .49858 L .39584 .49047 L F
.39582 .48517 m .39607 .48507 L .39584 .49047 L .484 .259 .497 r
F
.39568 .49054 m .39584 .49047 L .3954 .50111 L F
.39582 .48517 m .39584 .49047 L .39568 .49054 L F
.40386 .4929 m .40386 .4929 L .40386 .4929 L .661 .803 .951 r
F
.41474 .49675 m .43949 .49985 L .42382 .49248 L .662 .803 .95 r
F
.40386 .4929 m .41527 .50249 L .42441 .49821 L .661 .803 .951 r
F
.40386 .4929 m .42441 .49821 L .40845 .49073 L F
.39705 .48996 m .40886 .49642 L .41237 .49375 L .66 .804 .952 r
F
.3967 .4846 m .39664 .48987 L .39653 .48996 L .286 .104 .449 r
F
.3967 .4846 m .39653 .48996 L .39627 .48491 L F
.39653 .48996 m .39625 .49017 L .39627 .48491 L F
.39627 .48491 m .39625 .49017 L .39607 .48507 L F
.39666 .48986 m .39597 .49042 L .39705 .48996 L .66 .804 .952 r
F
.39594 .4904 m .39597 .49042 L .39666 .48986 L F
.39597 .49042 m .40886 .49642 L .39705 .48996 L F
.39584 .49047 m .40313 .49749 L .39597 .49042 L F
.40313 .49749 m .40309 .49742 L .39597 .49042 L F
.39625 .49017 m .3962 .5005 L .39612 .49027 L .286 .104 .449 r
F
.39625 .49017 m .39612 .49027 L .39607 .48507 L F
.393 .48589 m .39341 .49118 L .39277 .49129 L .631 .379 .518 r
F
.39276 .4913 m .39311 .50083 L .39388 .49136 L .66 .804 .952 r
F
.39277 .49129 m .39388 .49136 L .3939 .4911 L F
.39276 .4913 m .39388 .49136 L .39277 .49129 L F
.3926 .48587 m .393 .48589 L .39277 .49129 L .753 .483 .524 r
F
.3926 .48587 m .39277 .49129 L .3925 .49128 L F
.39003 .48545 m .39 .48548 L .3911 .48577 L .661 .803 .951 r
F
.39 .48548 m .38892 .48659 L .39084 .48599 L F
.38892 .48659 m .38413 .49148 L .38907 .48744 L F
.38892 .48659 m .38907 .48744 L .39084 .48599 L F
.39154 .49138 m .38941 .49609 L .3925 .49167 L .66 .804 .952 r
F
.38941 .49609 m .3873 .50076 L .38954 .49687 L F
.38941 .49609 m .38954 .49687 L .39254 .49168 L F
.3925 .49167 m .39254 .49168 L .39276 .49129 L F
.38941 .49609 m .39254 .49168 L .3925 .49167 L F
.39099 .48028 m .39084 .4857 L .39011 .48002 L .849 .569 .514 r
F
.39084 .4857 m .39019 .4855 L .39011 .48002 L F
.38987 .47987 m .3897 .4853 L .38927 .47951 L .929 .648 .486 r
F
.3897 .4853 m .38925 .48503 L .38927 .47951 L F
.38927 .47951 m .38925 .48503 L .38903 .4849 L F
.39011 .48002 m .39019 .4855 L .38987 .4854 L .849 .569 .514 r
F
.38115 .48847 m .37055 .49932 L .38133 .50104 L .662 .803 .95 r
F
.37644 .48685 m .37055 .49932 L .38115 .48847 L F
.38413 .49148 m .37673 .49258 L .38146 .4942 L .661 .803 .951 r
F
.38987 .47987 m .39011 .48002 L .38987 .4854 L .929 .648 .486 r
F
.38892 .48659 m .38679 .48649 L .38413 .49148 L .661 .803 .951 r
F
.39 .48548 m .38879 .48586 L .38892 .48659 L F
.38879 .48586 m .38679 .48649 L .38892 .48659 L F
.3843 .48029 m .37039 .48182 L .37277 .48458 L .662 .803 .95 r
F
.39189 .47746 m .38711 .47843 L .3843 .48029 L F
.38711 .47843 m .37039 .48182 L .3843 .48029 L F
.38922 .48501 m .38679 .48649 L .39 .48548 L .661 .803 .951 r
F
.3897 .4853 m .38987 .4854 L .38964 .49081 L .929 .648 .486 r
F
.39281 .49271 m .3873 .50076 L .39311 .50083 L .66 .804 .952 r
F
.39236 .49244 m .39159 .49371 L .39281 .49271 L F
.39159 .49371 m .3873 .50076 L .39188 .49407 L F
.39159 .49371 m .39188 .49407 L .39281 .49271 L F
.38987 .47987 m .38987 .4854 L .3897 .4853 L .929 .648 .486 r
F
.38912 .47933 m .38903 .4849 L .38892 .48477 L .989 .724 .411 r
F
.38892 .48477 m .38865 .48443 L .38875 .47888 L F
.39149 .42425 m .38877 .47782 L .38916 .47708 L 0 0 .269 r
F
.39149 .42425 m .38862 .4781 L .38877 .47782 L F
.3775 .48038 m .36946 .47876 L .37039 .48182 L .662 .803 .95 r
F
.39189 .47746 m .38544 .47784 L .3775 .48038 L F
.38544 .47784 m .36946 .47876 L .3775 .48038 L F
.39401 .42301 m .39274 .42339 L .39043 .47624 L .545 .308 .506 r
F
.38901 .48514 m .38764 .48489 L .38679 .48649 L .661 .803 .951 r
F
.39099 .48028 m .39133 .48039 L .3911 .48577 L .849 .569 .514 r
F
.39099 .48028 m .3911 .48577 L .39084 .4857 L F
.39228 .48316 m .38787 .4848 L .38901 .48514 L .661 .803 .951 r
F
.38787 .4848 m .38764 .48489 L .38901 .48514 L F
.39254 .49168 m .39216 .49233 L .39278 .49175 L .66 .804 .952 r
F
.38871 .47866 m .38849 .48411 L .38862 .4781 L .875 .7 .179 r
F
.38481 .48528 m .38115 .48847 L .38296 .48876 L .662 .803 .95 r
F
.37644 .48685 m .36116 .49613 L .37055 .49932 L F
.37277 .48458 m .36116 .49613 L .37644 .48685 L F
.38856 .48454 m .37355 .48695 L .37303 .49031 L .661 .803 .951 r
F
.38849 .48411 m .38841 .4837 L .38862 .4781 L .875 .7 .179 r
F
.38871 .47866 m .38851 .48427 L .38849 .48411 L F
.38875 .47888 m .38865 .48443 L .38851 .48427 L .989 .724 .411 r
F
.39228 .48316 m .38846 .48394 L .38856 .48454 L .661 .803 .951 r
F
.38846 .48394 m .37355 .48695 L .38856 .48454 L F
.37355 .48695 m .37064 .48754 L .37087 .48781 L F
.37355 .48695 m .37087 .48781 L .37303 .49031 L F
.39189 .47746 m .38956 .47985 L .39067 .48019 L .662 .803 .95 r
F
.38544 .47784 m .37006 .47559 L .36946 .47876 L F
.39189 .47746 m .38772 .47711 L .38544 .47784 L F
.38772 .47711 m .37006 .47559 L .38544 .47784 L F
.39146 .49355 m .3873 .50076 L .39159 .49371 L .66 .804 .952 r
F
.39 .48548 m .39084 .48599 L .3911 .48577 L .661 .803 .951 r
F
.39097 .48607 m .39037 .48654 L .39062 .48684 L F
.3911 .48577 m .39084 .48599 L .39097 .48607 L F
.39084 .4857 m .3911 .48577 L .39086 .49118 L .849 .569 .514 r
F
.38146 .4942 m .38164 .5068 L .38692 .49507 L .661 .803 .951 r
F
.38941 .49609 m .38184 .49989 L .3873 .50076 L .66 .804 .952 r
F
.38897 .49363 m .38184 .49989 L .38941 .49609 L F
.38413 .49148 m .38259 .49438 L .38692 .49507 L .661 .803 .951 r
F
.38882 .49279 m .38279 .49892 L .38897 .4936 L .66 .804 .952 r
F
.38279 .49892 m .38266 .49917 L .38897 .49363 L F
.38925 .48503 m .38923 .49056 L .38903 .4849 L .929 .648 .486 r
F
.38897 .4936 m .38897 .49363 L .39115 .49172 L .66 .804 .952 r
F
.38897 .4936 m .39115 .49172 L .39115 .49172 L F
.39086 .49118 m .38882 .49279 L .39154 .49138 L F
.39051 .49107 m .39043 .49115 L .39086 .49118 L F
.39043 .49115 m .38882 .49279 L .39086 .49118 L F
.38882 .49279 m .38897 .4936 L .39154 .49138 L F
.39134 .49183 m .38897 .49363 L .38941 .49609 L F
.39115 .49172 m .38897 .49363 L .39134 .49183 L F
.39086 .49118 m .39232 .50181 L .39042 .50152 L .753 .483 .524 r
F
.3911 .48577 m .39151 .49122 L .39086 .49118 L F
.39115 .49172 m .39115 .49172 L .39154 .49138 L .66 .804 .952 r
F
.39154 .49138 m .39115 .49172 L .39134 .49183 L F
.39084 .4857 m .39086 .49118 L .39069 .49113 L .849 .569 .514 r
F
.39084 .4857 m .39069 .49113 L .39019 .4855 L F
.39069 .49113 m .39027 .491 L .39019 .4855 L F
.3926 .48587 m .3925 .49128 L .39158 .4858 L .753 .483 .524 r
F
.3925 .49128 m .39183 .49124 L .39158 .4858 L F
.3911 .48577 m .3911 .48577 L .39238 .48585 L .661 .803 .951 r
F
.39158 .4858 m .39183 .49124 L .3911 .48577 L .753 .483 .524 r
F
.39183 .49124 m .39151 .49122 L .3911 .48577 L F
.39267 .48888 m .39051 .49107 L .39086 .49118 L .66 .804 .952 r
F
.39161 .49122 m .39086 .49118 L .39154 .49138 L F
.39267 .48888 m .39086 .49118 L .39161 .49122 L F
.39216 .49233 m .39146 .49355 L .39236 .49244 L F
.39146 .49355 m .39159 .49371 L .39236 .49244 L F
.39161 .49122 m .39154 .49138 L .39276 .49129 L F
.39154 .49138 m .3925 .49167 L .39276 .49129 L F
.39183 .49124 m .39232 .50181 L .39151 .49122 L .753 .483 .524 r
F
.39151 .49122 m .39232 .50181 L .39086 .49118 L F
.3897 .4853 m .38964 .49081 L .38952 .49074 L .929 .648 .486 r
F
.38146 .4942 m .3708 .50509 L .38164 .5068 L .661 .803 .951 r
F
.37673 .49258 m .3708 .50509 L .38146 .4942 L F
.38279 .49892 m .37709 .49827 L .38184 .49989 L .66 .804 .952 r
F
.39019 .4855 m .39027 .491 L .38987 .4854 L .849 .569 .514 r
F
.39027 .491 m .39006 .49094 L .38987 .4854 L F
.38987 .4854 m .39006 .49094 L .38964 .49081 L F
.38992 .49167 m .38601 .4929 L .38279 .49892 L .66 .804 .952 r
F
.38929 .49091 m .38601 .4929 L .38992 .49167 L F
.38279 .49892 m .38897 .49363 L .38897 .4936 L F
.38923 .49056 m .38909 .49048 L .38903 .4849 L .929 .648 .486 r
F
.38903 .4849 m .38909 .49048 L .38879 .4903 L F
.3897 .4853 m .38952 .49074 L .38925 .48503 L F
.38952 .49074 m .38923 .49056 L .38925 .48503 L F
.38413 .49148 m .38146 .4942 L .38259 .49438 L .661 .803 .951 r
F
.38929 .49091 m .38704 .49096 L .38601 .4929 L .66 .804 .952 r
F
.39267 .48888 m .3888 .49031 L .38929 .49091 L F
.3888 .49031 m .38704 .49096 L .38929 .49091 L F
.38865 .48443 m .38854 .49 L .38851 .48427 L .989 .724 .411 r
F
.38854 .49 m .38846 .48989 L .38851 .48427 L F
.38851 .48427 m .38846 .48989 L .38827 .48967 L F
.38892 .48477 m .38872 .49022 L .38865 .48443 L F
.38872 .49022 m .38854 .49 L .38865 .48443 L F
.38679 .48649 m .38218 .48691 L .37673 .49258 L .661 .803 .951 r
F
.38218 .48691 m .3751 .49158 L .37673 .49258 L F
.37673 .49258 m .36135 .50189 L .3708 .50509 L F
.37303 .49031 m .36135 .50189 L .37673 .49258 L F
.38006 .49354 m .37099 .49326 L .3734 .49601 L .66 .804 .952 r
F
.38892 .48477 m .38903 .4849 L .38879 .4903 L .989 .724 .411 r
F
.38892 .48477 m .38879 .4903 L .38872 .49022 L F
.38679 .48649 m .37673 .49258 L .38413 .49148 L .661 .803 .951 r
F
.37277 .48458 m .35379 .49165 L .36116 .49613 L .662 .803 .95 r
F
.37039 .48182 m .35379 .49165 L .37277 .48458 L F
.37355 .48695 m .3697 .48447 L .37064 .48754 L .661 .803 .951 r
F
.38862 .4781 m .38841 .4837 L .38838 .48349 L .875 .7 .179 r
F
.38877 .47782 m .38862 .4781 L .38838 .48349 L 0 0 .269 r
F
.38877 .47782 m .38838 .48349 L .38849 .48329 L F
.39274 .42339 m .38916 .47708 L .38951 .47685 L .339 .143 .462 r
F
.38432 .47681 m .37216 .47254 L .37006 .47559 L .662 .803 .95 r
F
.39189 .47746 m .38755 .47638 L .38432 .47681 L F
.38755 .47638 m .37216 .47254 L .38432 .47681 L F
.39529 .42292 m .39401 .42301 L .39173 .47582 L .652 .396 .519 r
F
.39228 .48316 m .38745 .48344 L .38592 .48445 L .661 .803 .951 r
F
.39267 .48888 m .38761 .4899 L .38704 .49096 L .66 .804 .952 r
F
.39267 .48888 m .38929 .49091 L .38992 .49167 L F
.39228 .48316 m .38922 .48501 L .39 .48548 L .661 .803 .951 r
F
.39228 .48316 m .3911 .48577 L .39238 .48585 L F
.39228 .48316 m .39003 .48545 L .3911 .48577 L F
.39189 .47746 m .39067 .48019 L .39201 .48059 L .662 .803 .95 r
F
.39189 .47746 m .39354 .48045 L .39511 .48018 L F
.39274 .42339 m .38951 .47685 L .39043 .47624 L .339 .143 .462 r
F
.39189 .47746 m .37561 .46981 L .37216 .47254 L .662 .803 .95 r
F
.39189 .47746 m .3802 .4676 L .37561 .46981 L F
.39401 .42301 m .39079 .47612 L .39173 .47582 L .545 .308 .506 r
F
.39401 .42301 m .39043 .47624 L .39079 .47612 L F
.39189 .47746 m .3856 .46607 L .3802 .4676 L .662 .803 .95 r
F
.39529 .42292 m .39173 .47582 L .39209 .47577 L .652 .396 .519 r
F
.39189 .47746 m .39143 .46531 L .3856 .46607 L .662 .803 .95 r
F
.39787 .42348 m .39658 .42306 L .39434 .47568 L .814 .537 .519 r
F
.39375 .49168 m .39421 .50159 L .39362 .49389 L .631 .379 .518 r
F
.42382 .49248 m .43949 .49985 L .44998 .49197 L .662 .803 .95 r
F
.42382 .49248 m .44998 .49197 L .4308 .48718 L F
.40845 .49073 m .42441 .49821 L .43143 .49289 L .661 .803 .951 r
F
.40845 .49073 m .43143 .49289 L .41195 .48805 L F
.40214 .48968 m .41237 .49375 L .41455 .49073 L .66 .804 .952 r
F
.39368 .49114 m .39341 .49118 L .393 .48589 L .631 .379 .518 r
F
.39348 .48581 m .39372 .49113 L .393 .48589 L F
.39372 .49113 m .39375 .49168 L .39368 .49114 L F
.39372 .49113 m .39368 .49114 L .393 .48589 L F
.4308 .48718 m .44998 .49197 L .45665 .48303 L .662 .803 .95 r
F
.4308 .48718 m .45665 .48303 L .43518 .48118 L F
.41143 .48235 m .4308 .48718 L .43518 .48118 L F
.41195 .48805 m .43143 .49289 L .43585 .48687 L .661 .803 .951 r
F
.41195 .48805 m .43585 .48687 L .41412 .48502 L F
.41394 .48764 m .41455 .49073 L .41525 .48757 L .66 .804 .952 r
F
.39228 .48316 m .39505 .48549 L .39621 .48501 L .661 .803 .951 r
F
.39228 .48316 m .39372 .48577 L .39509 .48553 L F
.39787 .42348 m .39434 .47568 L .39471 .47576 L .814 .537 .519 r
F
.39658 .42306 m .39339 .47566 L .39434 .47568 L .735 .467 .523 r
F
.39365 .47566 m .4075 .46798 L .40278 .46631 L .662 .803 .95 r
F
.39189 .47746 m .39481 .47569 L .39365 .47566 L F
.39481 .47569 m .4075 .46798 L .39365 .47566 L F
.3994 .48893 m .40214 .48968 L .40615 .48899 L .66 .804 .952 r
F
.39714 .48879 m .39713 .48892 L .39733 .48378 L 0 0 .006 r
F
.39733 .48378 m .39713 .48892 L .39711 .48919 L F
.39723 .48393 m .39733 .48378 L .39711 .48919 L 0 0 .327 r
F
.39723 .48393 m .39711 .48919 L .39704 .48929 L F
.39448 .48564 m .39488 .48557 L .39466 .49097 L .631 .379 .518 r
F
.39399 .49125 m .39423 .49168 L .39491 .49093 L .66 .804 .952 r
F
.39399 .49125 m .39491 .49093 L .39466 .49097 L F
.39423 .49168 m .39508 .49104 L .395 .49083 L F
.39439 .49102 m .39466 .49097 L .39421 .50159 L .631 .379 .518 r
F
.39448 .48564 m .39466 .49097 L .39439 .49102 L F
.39466 .49097 m .39491 .49093 L .395 .49083 L .66 .804 .952 r
F
.39267 .48888 m .40059 .48955 L .3994 .48893 L F
.40059 .48955 m .40214 .48968 L .3994 .48893 L F
.39653 .47573 m .41345 .47309 L .41114 .4703 L .662 .803 .95 r
F
.39189 .47746 m .39999 .47582 L .39653 .47573 L F
.39999 .47582 m .41345 .47309 L .39653 .47573 L F
.39658 .42306 m .39529 .42292 L .39303 .47565 L .735 .467 .523 r
F
.39604 .47615 m .39544 .48135 L .39571 .48149 L .912 .629 .494 r
F
.39228 .48316 m .39616 .48172 L .39544 .48135 L .661 .803 .951 r
F
.39717 .48852 m .39714 .48879 L .39735 .48359 L 0 0 .006 r
F
.39863 .48853 m .40615 .48899 L .40275 .48829 L .66 .804 .952 r
F
.39267 .48888 m .3994 .48893 L .39863 .48853 L F
.3994 .48893 m .40615 .48899 L .39863 .48853 L F
.39267 .48888 m .39847 .49031 L .40117 .48985 L F
.40059 .48955 m .40117 .48985 L .40214 .48968 L F
.39267 .48888 m .40117 .48985 L .40059 .48955 L F
.39767 .48116 m .41398 .47877 L .41166 .47597 L .661 .803 .951 r
F
.39471 .47576 m .39434 .47568 L .39411 .48107 L .814 .537 .519 r
F
.397 .47665 m .39643 .48186 L .39678 .48204 L .912 .629 .494 r
F
.39571 .48149 m .39643 .48186 L .397 .47665 L F
.39718 .47692 m .397 .47665 L .39678 .48204 L .99 .735 .374 r
F
.39718 .47692 m .39678 .48204 L .39686 .48218 L F
.39718 .47692 m .39691 .48225 L .39762 .47761 L F
.39616 .48172 m .39833 .48194 L .39656 .48157 L .661 .803 .951 r
F
.39228 .48316 m .39706 .48219 L .39616 .48172 L F
.39706 .48219 m .39833 .48194 L .39616 .48172 L F
.39604 .47615 m .39571 .48149 L .397 .47665 L .912 .629 .494 r
F
.39267 .48888 m .39594 .4904 L .39666 .48986 L .66 .804 .952 r
F
.39267 .48888 m .395 .49083 L .39597 .49042 L F
.39571 .48149 m .39539 .48685 L .39643 .48186 L .912 .629 .494 r
F
.39517 .49097 m .39545 .49164 L .39564 .49136 L .66 .804 .952 r
F
.39568 .49054 m .3954 .50111 L .39526 .49072 L .484 .259 .497 r
F
.395 .49083 m .39508 .49104 L .39517 .49097 L .66 .804 .952 r
F
.39526 .49072 m .3954 .50111 L .39506 .4908 L .484 .259 .497 r
F
.39466 .49097 m .3954 .50111 L .39421 .50159 L F
.39506 .4908 m .3954 .50111 L .39466 .49097 L F
.40334 .48411 m .41412 .48502 L .41476 .48213 L .661 .803 .951 r
F
.39905 .48485 m .41195 .48805 L .40334 .48411 L F
.43518 .48118 m .45665 .48303 L .459 .47359 L .662 .803 .95 r
F
.43518 .48118 m .459 .47359 L .43666 .47488 L F
.41412 .48502 m .43585 .48687 L .43734 .48056 L .661 .803 .951 r
F
.41412 .48502 m .43734 .48056 L .41482 .48186 L F
.39917 .48757 m .41525 .48757 L .41441 .48449 L .66 .804 .952 r
F
.39664 .48758 m .39696 .48808 L .3974 .483 L .99 .735 .374 r
F
.39739 .48317 m .39718 .48841 L .39717 .48852 L 0 0 .006 r
F
.39739 .48311 m .39718 .48841 L .39739 .48317 L F
.39739 .48311 m .3974 .483 L .39718 .48841 L F
.3974 .483 m .39696 .48808 L .39718 .48841 L .99 .735 .374 r
F
.39267 .48888 m .40275 .48829 L .39917 .48757 L .66 .804 .952 r
F
.40275 .48829 m .41525 .48757 L .39917 .48757 L F
.3939 .4911 m .39399 .49125 L .39466 .49097 L F
.39439 .49102 m .39421 .50159 L .39372 .49113 L .631 .379 .518 r
F
.39267 .48888 m .3939 .4911 L .395 .49083 L .66 .804 .952 r
F
.3939 .4911 m .39466 .49097 L .395 .49083 L F
.39216 .49233 m .39236 .49244 L .39278 .49175 L F
.39278 .49175 m .39236 .49244 L .39281 .49271 L F
.39277 .49129 m .39421 .50159 L .39232 .50181 L .631 .379 .518 r
F
.39341 .49118 m .39421 .50159 L .39277 .49129 L F
.39544 .48135 m .39474 .48666 L .39521 .48676 L .814 .537 .519 r
F
.39539 .48685 m .39585 .48709 L .39643 .48186 L .912 .629 .494 r
F
.39656 .48157 m .40168 .48126 L .39767 .48116 L .661 .803 .951 r
F
.39833 .48194 m .40168 .48126 L .39656 .48157 L F
.40168 .48126 m .41398 .47877 L .39767 .48116 L F
.39643 .48186 m .39585 .48709 L .39678 .48204 L .912 .629 .494 r
F
.39585 .48709 m .39608 .48721 L .39678 .48204 L F
.39678 .48204 m .39608 .48721 L .39655 .48745 L F
.39567 .48111 m .41166 .47597 L .408 .47365 L .661 .803 .951 r
F
.39767 .48116 m .41166 .47597 L .39567 .48111 L F
.39571 .48149 m .39544 .48135 L .39521 .48676 L .912 .629 .494 r
F
.39571 .48149 m .39521 .48676 L .39539 .48685 L F
.39691 .48225 m .39664 .48758 L .3974 .483 L .99 .735 .374 r
F
.39691 .48225 m .39655 .48745 L .39664 .48758 L F
.39686 .48218 m .39655 .48745 L .39691 .48225 L F
.39804 .48397 m .39905 .48485 L .40138 .48444 L .661 .803 .951 r
F
.39852 .48471 m .39905 .48485 L .39804 .48397 L F
.39686 .48218 m .39678 .48204 L .39655 .48745 L .99 .735 .374 r
F
.39732 .48287 m .40334 .48411 L .41482 .48186 L .661 .803 .951 r
F
.39781 .48363 m .40334 .48411 L .39732 .48287 L F
.39483 .48668 m .40841 .47938 L .40365 .47771 L .66 .804 .952 r
F
.39267 .48888 m .39594 .48691 L .39483 .48668 L F
.40022 .48384 m .40138 .48444 L .40334 .48411 L .661 .803 .951 r
F
.39594 .48691 m .40841 .47938 L .39483 .48668 L .66 .804 .952 r
F
.39228 .48316 m .39544 .48135 L .39532 .48132 L .661 .803 .951 r
F
.39471 .47576 m .39411 .48107 L .3943 .48111 L .814 .537 .519 r
F
.39566 .47595 m .39509 .48127 L .39544 .48135 L F
.39228 .48316 m .39532 .48132 L .39429 .48111 L .661 .803 .951 r
F
.39439 .48113 m .39388 .48649 L .39406 .48652 L .814 .537 .519 r
F
.39471 .47576 m .3943 .48111 L .39439 .48113 L F
.3943 .48111 m .39388 .48649 L .39439 .48113 L F
.39267 .48888 m .39276 .4913 L .3939 .4911 L .66 .804 .952 r
F
.39471 .47576 m .39439 .48113 L .39566 .47595 L .814 .537 .519 r
F
.39439 .48113 m .39406 .48652 L .39509 .48127 L F
.39406 .48652 m .39452 .48662 L .39509 .48127 L F
.39439 .48113 m .39509 .48127 L .39566 .47595 L F
.39658 .42306 m .39303 .47565 L .39339 .47566 L .735 .467 .523 r
F
.39529 .42292 m .39209 .47577 L .39303 .47565 L .652 .396 .519 r
F
.39268 .47569 m .40278 .46631 L .39729 .4654 L .662 .803 .95 r
F
.39189 .47746 m .39376 .47555 L .39268 .47569 L F
.39376 .47555 m .40278 .46631 L .39268 .47569 L F
.39303 .47565 m .39246 .48109 L .3928 .48104 L .652 .396 .519 r
F
.39228 .48316 m .39326 .48098 L .3922 .48112 L .661 .803 .951 r
F
.39189 .47746 m .39283 .47537 L .3918 .47516 L .662 .803 .95 r
F
.38218 .48691 m .37303 .49031 L .3751 .49158 L .661 .803 .951 r
F
.35379 .49165 m .34604 .50531 L .36116 .49613 L .662 .803 .95 r
F
.37303 .49031 m .35393 .4974 L .36135 .50189 L .661 .803 .951 r
F
.37064 .48754 m .35393 .4974 L .37303 .49031 L F
.38472 .49048 m .37006 .49019 L .37099 .49326 L .66 .804 .952 r
F
.38849 .48411 m .38851 .48427 L .38827 .48967 L .875 .7 .179 r
F
.38849 .48411 m .38827 .48967 L .38826 .48957 L F
.38838 .48349 m .38819 .48918 L .38814 .4889 L F
.38849 .48411 m .38826 .48957 L .38841 .4837 L F
.38826 .48957 m .38821 .48931 L .38841 .4837 L F
.38841 .4837 m .38821 .48931 L .38838 .48349 L F
.38821 .48931 m .38819 .48918 L .38838 .48349 L F
.39267 .48888 m .38663 .48923 L .38472 .49048 L .66 .804 .952 r
F
.38663 .48923 m .37006 .49019 L .38472 .49048 L F
.39209 .47577 m .39176 .48118 L .39303 .47565 L .652 .396 .519 r
F
.38389 .48365 m .38292 .48237 L .3697 .48447 L .661 .803 .951 r
F
.38877 .47782 m .38849 .48329 L .38916 .47708 L 0 0 .269 r
F
.38849 .48329 m .38878 .48274 L .38916 .47708 L F
.38951 .47685 m .38916 .47708 L .38892 .48247 L .339 .143 .462 r
F
.39228 .48316 m .38838 .48283 L .38745 .48344 L .661 .803 .951 r
F
.38854 .49 m .38835 .50037 L .38846 .48989 L .989 .724 .411 r
F
.38827 .48967 m .38835 .50037 L .38784 .49962 L F
.38846 .48989 m .38835 .50037 L .38827 .48967 L F
.38872 .49022 m .38835 .50037 L .38854 .49 L F
.38951 .47685 m .38892 .48247 L .38918 .4823 L .339 .143 .462 r
F
.38292 .48237 m .37242 .47823 L .37031 .48129 L .661 .803 .951 r
F
.38916 .47708 m .38878 .48274 L .38892 .48247 L 0 0 .269 r
F
.39228 .48316 m .38691 .48183 L .38292 .48237 L .661 .803 .951 r
F
.38691 .48183 m .37242 .47823 L .38292 .48237 L F
.39209 .47577 m .39173 .47582 L .39149 .48122 L .652 .396 .519 r
F
.38951 .47685 m .38918 .4823 L .39043 .47624 L .339 .143 .462 r
F
.38918 .4823 m .38986 .48185 L .39043 .47624 L F
.39228 .48316 m .3759 .4755 L .37242 .47823 L .661 .803 .951 r
F
.39079 .47612 m .39043 .47624 L .3902 .48163 L .545 .308 .506 r
F
.39079 .47612 m .3902 .48163 L .39046 .48155 L F
.39043 .47624 m .38986 .48185 L .3902 .48163 L .339 .143 .462 r
F
.39228 .48316 m .38052 .47328 L .3759 .4755 L .661 .803 .951 r
F
.39079 .47612 m .39046 .48155 L .39173 .47582 L .545 .308 .506 r
F
.39046 .48155 m .39115 .48133 L .39173 .47582 L F
.39173 .47582 m .39115 .48133 L .39149 .48122 L F
.39228 .48316 m .38595 .47174 L .38052 .47328 L .661 .803 .951 r
F
.39209 .47577 m .39149 .48122 L .39176 .48118 L .652 .396 .519 r
F
.39176 .48118 m .39246 .48109 L .39303 .47565 L F
.3918 .47516 m .39729 .4654 L .39143 .46531 L .662 .803 .95 r
F
.39283 .47537 m .39729 .4654 L .3918 .47516 L F
.39228 .48316 m .39182 .47098 L .38595 .47174 L .661 .803 .951 r
F
.38918 .4823 m .38892 .48247 L .38868 .48788 L .339 .143 .462 r
F
.38849 .48329 m .38821 .48877 L .38878 .48274 L 0 0 .269 r
F
.38821 .48877 m .3884 .48842 L .38878 .48274 L F
.38849 .48329 m .38838 .48349 L .38814 .4889 L F
.38849 .48329 m .38814 .4889 L .38821 .48877 L F
.39267 .48888 m .38779 .48847 L .38663 .48923 L .66 .804 .952 r
F
.38292 .48237 m .36977 .48413 L .3697 .48447 L .661 .803 .951 r
F
.38592 .48445 m .38389 .48365 L .37355 .48695 L F
.38389 .48365 m .3697 .48447 L .37355 .48695 L F
.38598 .48831 m .37278 .48397 L .37067 .48702 L .66 .804 .952 r
F
.38878 .48274 m .3884 .48842 L .38892 .48247 L 0 0 .269 r
F
.3884 .48842 m .38849 .48825 L .38892 .48247 L F
.38892 .48247 m .38849 .48825 L .38868 .48788 L F
.39267 .48888 m .3879 .4877 L .38598 .48831 L .66 .804 .952 r
F
.38764 .48489 m .38218 .48691 L .38679 .48649 L .661 .803 .951 r
F
.3879 .4877 m .37278 .48397 L .38598 .48831 L .66 .804 .952 r
F
.39046 .48155 m .39013 .48699 L .39115 .48133 L .545 .308 .506 r
F
.39027 .491 m .39042 .50152 L .39006 .49094 L .849 .569 .514 r
F
.38964 .49081 m .39042 .50152 L .38919 .50101 L F
.39006 .49094 m .39042 .50152 L .38964 .49081 L F
.38918 .4823 m .38868 .48788 L .38885 .48777 L .339 .143 .462 r
F
.37039 .48182 m .34895 .48617 L .35379 .49165 L .662 .803 .95 r
F
.36946 .47876 m .34895 .48617 L .37039 .48182 L F
.38292 .48237 m .37031 .48129 L .36977 .48413 L .661 .803 .951 r
F
.38627 .4873 m .37627 .48124 L .37278 .48397 L .66 .804 .952 r
F
.38918 .4823 m .38885 .48777 L .38986 .48185 L .339 .143 .462 r
F
.38885 .48777 m .38929 .48749 L .38986 .48185 L F
.38986 .48185 m .38929 .48749 L .3902 .48163 L F
.38929 .48749 m .3895 .48734 L .3902 .48163 L F
.39267 .48888 m .38923 .48728 L .3879 .4877 L .66 .804 .952 r
F
.39069 .49113 m .39086 .49118 L .39042 .50152 L .849 .569 .514 r
F
.39069 .49113 m .39042 .50152 L .39027 .491 L F
.39013 .48699 m .39057 .48685 L .39115 .48133 L .545 .308 .506 r
F
.38745 .48344 m .38685 .4827 L .38389 .48365 L .661 .803 .951 r
F
.38685 .4827 m .38292 .48237 L .38389 .48365 L F
.38745 .48344 m .38389 .48365 L .38592 .48445 L F
.38719 .48633 m .38089 .47902 L .37627 .48124 L .66 .804 .952 r
F
.39115 .48133 m .39057 .48685 L .39149 .48122 L .545 .308 .506 r
F
.39267 .48888 m .39033 .48693 L .38923 .48728 L .66 .804 .952 r
F
.39057 .48685 m .39079 .48678 L .39149 .48122 L .545 .308 .506 r
F
.39149 .48122 m .39079 .48678 L .39126 .48663 L F
.39176 .48118 m .39149 .48122 L .39126 .48663 L .652 .396 .519 r
F
.39176 .48118 m .39126 .48663 L .39143 .48661 L F
.38838 .48283 m .38685 .4827 L .38745 .48344 L .661 .803 .951 r
F
.3902 .48163 m .3895 .48734 L .38996 .48704 L .339 .143 .462 r
F
.39046 .48155 m .3902 .48163 L .38996 .48704 L .545 .308 .506 r
F
.39046 .48155 m .38996 .48704 L .39013 .48699 L F
.39033 .48693 m .38633 .47749 L .38089 .47902 L .66 .804 .952 r
F
.39267 .48888 m .39139 .48659 L .39033 .48693 L F
.39139 .48659 m .38633 .47749 L .39033 .48693 L F
.39013 .48699 m .38996 .48704 L .38954 .49677 L .545 .308 .506 r
F
.39057 .48685 m .38954 .49677 L .39079 .48678 L F
.38923 .48728 m .38969 .48639 L .38719 .48633 L .66 .804 .952 r
F
.39033 .48693 m .38969 .48639 L .38923 .48728 L F
.38969 .48639 m .38089 .47902 L .38719 .48633 L F
.39279 .48408 m .39261 .48596 L .39372 .48577 L .661 .803 .951 r
F
.39228 .48316 m .39261 .48596 L .39279 .48408 L F
.39228 .48316 m .39238 .486 L .39261 .48596 L F
.39307 .48105 m .39377 .48107 L .39434 .47568 L .735 .467 .523 r
F
.39434 .47568 m .39377 .48107 L .39411 .48107 L F
.3947 .47575 m .41114 .4703 L .4075 .46798 L .662 .803 .95 r
F
.39585 .47599 m .41114 .4703 L .3947 .47575 L F
.39604 .47615 m .39566 .47595 L .39544 .48135 L .912 .629 .494 r
F
.39228 .48316 m .40324 .47197 L .39772 .47106 L .661 .803 .951 r
F
.39307 .48105 m .3928 .48104 L .39257 .48645 L .735 .467 .523 r
F
.39267 .48888 m .39161 .49122 L .39276 .49129 L .66 .804 .952 r
F
.3925 .49128 m .39232 .50181 L .39183 .49124 L .753 .483 .524 r
F
.39176 .48118 m .39143 .48661 L .39246 .48109 L .652 .396 .519 r
F
.39143 .48661 m .39188 .48655 L .39246 .48109 L F
.39339 .47566 m .39303 .47565 L .3928 .48104 L .735 .467 .523 r
F
.39339 .47566 m .3928 .48104 L .39307 .48105 L F
.3922 .48112 m .39329 .48091 L .39218 .48068 L .661 .803 .951 r
F
.39326 .48098 m .39329 .48091 L .3922 .48112 L F
.3928 .48104 m .39188 .48655 L .39257 .48645 L .652 .396 .519 r
F
.39246 .48109 m .39188 .48655 L .3928 .48104 L F
.39218 .48068 m .39235 .48039 L .39204 .47675 L .661 .803 .951 r
F
.3932 .47892 m .39307 .48105 L .39384 .47781 L .735 .467 .523 r
F
.3932 .47892 m .39384 .47781 L .39434 .47568 L F
.39339 .47566 m .3932 .47892 L .39434 .47568 L F
.39235 .48039 m .39772 .47106 L .39204 .47675 L .661 .803 .951 r
F
.39204 .47675 m .39772 .47106 L .39182 .47098 L F
.39329 .48091 m .39772 .47106 L .39218 .48068 L F
.39267 .48888 m .39221 .47673 L .38633 .47749 L .66 .804 .952 r
F
.39274 .48646 m .39257 .48645 L .39214 .4963 L .735 .467 .523 r
F
.39307 .48105 m .39257 .48645 L .39274 .48646 L F
.39126 .48663 m .38954 .49677 L .39084 .4964 L .545 .308 .506 r
F
.39079 .48678 m .38954 .49677 L .39126 .48663 L F
.3879 .4877 m .3886 .48699 L .38627 .4873 L .66 .804 .952 r
F
.38923 .48728 m .3886 .48699 L .3879 .4877 L F
.3886 .48699 m .37627 .48124 L .38627 .4873 L F
.39143 .48661 m .39084 .4964 L .39188 .48655 L .652 .396 .519 r
F
.39013 .48699 m .38954 .49677 L .39057 .48685 L .545 .308 .506 r
F
.38885 .48777 m .38868 .48788 L .38825 .49762 L .339 .143 .462 r
F
.38663 .48923 m .3815 .48794 L .37006 .49019 L .66 .804 .952 r
F
.38779 .48847 m .3815 .48794 L .38663 .48923 L F
.35379 .49165 m .33494 .49867 L .34604 .50531 L .662 .803 .95 r
F
.34895 .48617 m .33494 .49867 L .35379 .49165 L F
.37064 .48754 m .34906 .49191 L .35393 .4974 L .661 .803 .951 r
F
.3697 .48447 m .34906 .49191 L .37064 .48754 L F
.3815 .48794 m .37067 .48702 L .3702 .48945 L .66 .804 .952 r
F
.3815 .48794 m .3702 .48945 L .37006 .49019 L F
.39143 .48661 m .39126 .48663 L .39084 .4964 L .652 .396 .519 r
F
.38879 .4903 m .38919 .50101 L .38835 .50037 L .929 .648 .486 r
F
.38909 .49048 m .38919 .50101 L .38879 .4903 L F
.38872 .49022 m .38879 .4903 L .38835 .50037 L .989 .724 .411 r
F
.38885 .48777 m .38825 .49762 L .38929 .48749 L .339 .143 .462 r
F
.39307 .48105 m .39274 .48646 L .39377 .48107 L .735 .467 .523 r
F
.39267 .48888 m .39375 .48648 L .39324 .48647 L .66 .804 .952 r
F
.39274 .48646 m .39319 .48647 L .39377 .48107 L .735 .467 .523 r
F
.39258 .48646 m .39327 .48636 L .39258 .48645 L .66 .804 .952 r
F
.39267 .48888 m .39324 .48647 L .39258 .48646 L F
.39324 .48647 m .39327 .48636 L .39258 .48646 L F
.39377 .48107 m .39319 .48647 L .39411 .48107 L .735 .467 .523 r
F
.39276 .49129 m .39254 .49168 L .39278 .49175 L .66 .804 .952 r
F
.3925 .49128 m .39277 .49129 L .39232 .50181 L .753 .483 .524 r
F
.39432 .48108 m .408 .47365 L .40324 .47197 L .661 .803 .951 r
F
.39567 .48111 m .408 .47365 L .39432 .48108 L F
.39509 .48127 m .39452 .48662 L .39544 .48135 L .814 .537 .519 r
F
.39452 .48662 m .39474 .48666 L .39544 .48135 L F
.3943 .48111 m .39411 .48107 L .39388 .48649 L F
.39535 .4813 m .39767 .48116 L .39567 .48111 L .661 .803 .951 r
F
.39616 .48172 m .39767 .48116 L .39535 .4813 L F
.39411 .48107 m .39342 .48648 L .39388 .48649 L .735 .467 .523 r
F
.39375 .48648 m .40365 .47771 L .39812 .47681 L .66 .804 .952 r
F
.39267 .48888 m .39499 .48651 L .39375 .48648 L F
.39499 .48651 m .40365 .47771 L .39375 .48648 L F
.39375 .49168 m .39362 .49389 L .39341 .49118 L .631 .379 .518 r
F
.39375 .49168 m .39341 .49118 L .39368 .49114 L F
.40334 .48411 m .41476 .48213 L .41482 .48186 L .661 .803 .951 r
F
.39267 .48888 m .41208 .48169 L .40841 .47938 L .66 .804 .952 r
F
.39267 .48888 m .41441 .48449 L .41208 .48169 L F
.39388 .48649 m .39214 .4963 L .39346 .49644 L .735 .467 .523 r
F
.39342 .48648 m .39214 .4963 L .39388 .48649 L F
.39319 .48647 m .39214 .4963 L .39342 .48648 L F
.39319 .48647 m .39342 .48648 L .39411 .48107 L F
.39274 .48646 m .39214 .4963 L .39319 .48647 L F
.39324 .48647 m .39376 .48646 L .39327 .48636 L .66 .804 .952 r
F
.39375 .48648 m .39376 .48646 L .39324 .48647 L F
.39258 .48645 m .39327 .48636 L .39257 .48622 L F
.39257 .48645 m .39084 .4964 L .39214 .4963 L .652 .396 .519 r
F
.39188 .48655 m .39084 .4964 L .39257 .48645 L F
.39429 .48111 m .39567 .48111 L .39432 .48108 L .661 .803 .951 r
F
.39532 .48132 m .39567 .48111 L .39429 .48111 L F
.39532 .48132 m .39544 .48135 L .39535 .4813 L F
.39257 .48622 m .39812 .47681 L .39221 .47673 L .66 .804 .952 r
F
.39376 .48646 m .39812 .47681 L .39257 .48622 L F
.39406 .48652 m .39346 .49644 L .39452 .48662 L .814 .537 .519 r
F
.39452 .48662 m .39346 .49644 L .39474 .48666 L F
.39521 .48676 m .39346 .49644 L .39478 .49685 L F
.39474 .48666 m .39346 .49644 L .39521 .48676 L F
.39539 .48685 m .39478 .49685 L .39585 .48709 L .912 .629 .494 r
F
.39585 .48709 m .39478 .49685 L .39608 .48721 L F
.39584 .49047 m .3962 .5005 L .3954 .50111 L .286 .104 .449 r
F
.39612 .49027 m .3962 .5005 L .39584 .49047 L F
.39653 .48996 m .3962 .5005 L .39625 .49017 L F
.39655 .48745 m .39478 .49685 L .39612 .49775 L .912 .629 .494 r
F
.39608 .48721 m .39478 .49685 L .39655 .48745 L F
.39539 .48685 m .39521 .48676 L .39478 .49685 L F
.39406 .48652 m .39388 .48649 L .39346 .49644 L .814 .537 .519 r
F
.40275 .48829 m .40615 .48899 L .41394 .48764 L .66 .804 .952 r
F
.40214 .48968 m .41455 .49073 L .41394 .48764 L F
.39847 .49031 m .41237 .49375 L .40214 .48968 L F
.38826 .48957 m .38827 .48967 L .38784 .49962 L .875 .7 .179 r
F
.38814 .4889 m .38784 .49962 L .3877 .49873 L F
.38819 .48918 m .38784 .49962 L .38814 .4889 L F
.38826 .48957 m .38784 .49962 L .38821 .48931 L F
.38821 .48931 m .38784 .49962 L .38819 .48918 L F
.3884 .48842 m .3877 .49873 L .38849 .48825 L 0 0 .269 r
F
.38704 .49096 m .38472 .49048 L .38006 .49354 L .66 .804 .952 r
F
.38761 .4899 m .38472 .49048 L .38704 .49096 L F
.38472 .49048 m .37099 .49326 L .38006 .49354 L F
.38923 .49056 m .38919 .50101 L .38909 .49048 L .929 .648 .486 r
F
.38929 .48749 m .38825 .49762 L .3895 .48734 L .339 .143 .462 r
F
.38868 .48788 m .3877 .49873 L .38825 .49762 L 0 0 .269 r
F
.38849 .48825 m .3877 .49873 L .38868 .48788 L F
.38601 .4929 m .38006 .49354 L .37709 .49827 L .66 .804 .952 r
F
.38704 .49096 m .38006 .49354 L .38601 .4929 L F
.38006 .49354 m .3734 .49601 L .3749 .49693 L F
.38006 .49354 m .3749 .49693 L .37709 .49827 L F
.38952 .49074 m .38919 .50101 L .38923 .49056 L .929 .648 .486 r
F
.38952 .49074 m .38964 .49081 L .38919 .50101 L F
.38996 .48704 m .38825 .49762 L .38954 .49677 L .339 .143 .462 r
F
.3895 .48734 m .38825 .49762 L .38996 .48704 L F
.38601 .4929 m .37709 .49827 L .38279 .49892 L .66 .804 .952 r
F
.38821 .48877 m .3877 .49873 L .3884 .48842 L 0 0 .269 r
F
.38279 .49892 m .38184 .49989 L .38266 .49917 L .66 .804 .952 r
F
.38821 .48877 m .38814 .4889 L .3877 .49873 L 0 0 .269 r
F
.39688 .48953 m .39667 .49976 L .3968 .48964 L 0 0 .327 r
F
.39653 .48996 m .39664 .48987 L .3962 .5005 L .286 .104 .449 r
F
.39664 .48987 m .39667 .49976 L .3962 .5005 L 0 0 .327 r
F
.3968 .48964 m .39667 .49976 L .39664 .48987 L F
.39664 .48758 m .39612 .49775 L .39696 .48808 L .99 .735 .374 r
F
.40313 .49749 m .40427 .49858 L .40309 .49742 L .66 .804 .952 r
F
.39714 .48879 m .39674 .49888 L .39713 .48892 L 0 0 .006 r
F
.39711 .48919 m .39674 .49888 L .39667 .49976 L F
.39713 .48892 m .39674 .49888 L .39711 .48919 L F
.39717 .48852 m .39674 .49888 L .39714 .48879 L F
.39704 .48929 m .39667 .49976 L .39688 .48953 L 0 0 .327 r
F
.39717 .48852 m .39718 .48841 L .39674 .49888 L 0 0 .006 r
F
.39704 .48929 m .39711 .48919 L .39667 .49976 L 0 0 .327 r
F
.39718 .48841 m .39612 .49775 L .39674 .49888 L .99 .735 .374 r
F
.39696 .48808 m .39612 .49775 L .39718 .48841 L F
.3996 .49211 m .40427 .49858 L .40886 .49642 L .66 .804 .952 r
F
.40309 .49742 m .40427 .49858 L .3996 .49211 L F
.39664 .48758 m .39655 .48745 L .39612 .49775 L .99 .735 .374 r
F
.40334 .49781 m .40391 .49868 L .40427 .49858 L .66 .804 .952 r
F
.76793 .51728 m .77949 .5037 L .76205 .5129 L .658 .807 .955 r
F
.76793 .51728 m .78824 .51036 L .77949 .5037 L F
.34464 .3724 m .31843 .36428 L .31061 .37689 L .658 .778 .938 r
F
.34645 .51676 m .36027 .51583 L .36061 .52147 L .861 .591 .529 r
F
.34645 .51676 m .34613 .5111 L .36027 .51583 L F
.36135 .50189 m .36027 .51583 L .3708 .50509 L .661 .803 .951 r
F
.36135 .50189 m .34613 .5111 L .36027 .51583 L F
0 g
.36027 .51583 m
.36538 .51662 L
s
.2765 .65678 m .2771 .65195 L .27787 .64644 L 0 0 0 r
F
0 g
.2734 .65686 m
.2771 .65195 L
s
.25957 .65735 m .2765 .65678 L .26201 .65407 L .596 .768 .962 r
F
.26249 .64921 m .27689 .65191 L .27765 .64643 L .597 .767 .961 r
F
.31802 .37096 m .31018 .37683 L .31015 .38361 L 0 0 .384 r
F
.31802 .37096 m .31803 .36415 L .31018 .37683 L F
0 g
.30832 .3901 m
.31018 .37683 L
s
.44018 .50559 m .43973 .49996 L .45027 .49204 L .353 .208 .541 r
F
0 g
.4303 .50436 m
.43973 .49996 L
s
.25254 .52407 m .23496 .51825 L .23512 .5239 L .734 .492 .562 r
F
0 g
.2179 .52044 m
.23496 .51825 L
s
.23496 .51825 m
.25236 .51842 L
s
.59789 .24557 m .55857 .24309 L .59375 .25128 L .644 .737 .917 r
F
.40321 .37184 m .39503 .35409 L .39559 .37141 L .658 .778 .938 r
F
.40321 .37184 m .41043 .35499 L .39503 .35409 L F
0 g
.52203 .66725 m
.5335 .6672 L
s
.5335 .6672 m
.54488 .66861 L
s
.66485 .255 m .69544 .23827 L .66184 .24892 L .644 .737 .917 r
F
.66485 .255 m .70126 .25054 L .69544 .23827 L F
.25272 .52973 m .25254 .52407 L .23512 .5239 L .734 .492 .562 r
F
0 g
.25254 .52407 m
.26903 .52656 L
s
.48151 .38702 m .47261 .36796 L .47289 .37477 L .986 .708 .367 r
F
0 g
.48151 .38702 m
.48421 .40008 L
s
.71878 .52174 m .7097 .51234 L .69989 .51659 L .658 .807 .955 r
F
.72429 .52027 m .7097 .51234 L .71878 .52174 L F
.34445 .38591 m .31012 .39042 L .33907 .39425 L .656 .78 .939 r
F
.5356 .76727 m .53905 .76336 L .53937 .76628 L .597 .383 .562 r
F
.53937 .76628 m .53905 .76336 L .54232 .76195 L .509 .32 .56 r
F
.388 .37214 m .3797 .35557 L .36554 .35933 L .658 .778 .938 r
F
.39559 .37141 m .3797 .35557 L .388 .37214 L F
.68974 .37863 m .70477 .36085 L .70548 .36763 L .379 .226 .544 r
F
.6707 .36682 m .68974 .37863 L .70548 .36763 L .656 .78 .94 r
F
.6577 .37257 m .68974 .37863 L .6707 .36682 L F
0 g
.67034 .38712 m
.68974 .37863 L
s
.71475 .52949 m .70073 .52227 L .69287 .52747 L .657 .808 .956 r
F
.71964 .5274 m .70073 .52227 L .71475 .52949 L F
.5982 .2372 m .56708 .22315 L .55898 .23472 L .644 .736 .916 r
F
.60447 .2324 m .56708 .22315 L .5982 .2372 L F
.39559 .37141 m .39503 .35409 L .3797 .35557 L .658 .778 .938 r
F
.73562 .5196 m .73238 .5079 L .73003 .51954 L .658 .807 .955 r
F
.73562 .5196 m .74363 .50802 L .73238 .5079 L F
.60489 .22415 m .58018 .20521 L .56778 .21494 L .645 .736 .915 r
F
.61281 .22063 m .58018 .20521 L .60489 .22415 L F
.66198 .24053 m .68499 .21889 L .65669 .23513 L .644 .736 .916 r
F
.66198 .24053 m .69549 .22985 L .68499 .21889 L F
.53191 .77072 m .5316 .7678 L .5356 .76727 L .668 .435 .558 r
F
.52793 .77074 m .5316 .7678 L .53191 .77072 L .731 .481 .55 r
F
.52793 .77074 m .52762 .76782 L .5316 .7678 L F
.53174 .76532 m .5316 .7678 L .5356 .76727 L .657 .813 .959 r
F
.52909 .76533 m .5316 .7678 L .53174 .76532 L F
.52909 .76533 m .52762 .76782 L .5316 .7678 L F
.65671 .22686 m .67039 .20187 L .64953 .22255 L .645 .736 .915 r
F
.65671 .22686 m .68479 .21067 L .67039 .20187 L F
.6992 .511 m .67344 .51154 L .69141 .5162 L .658 .806 .954 r
F
.53591 .7702 m .5356 .76727 L .53937 .76628 L .597 .383 .562 r
F
.53191 .77072 m .5356 .76727 L .53591 .7702 L .668 .435 .558 r
F
.53442 .76497 m .5356 .76727 L .53937 .76628 L .657 .813 .959 r
F
.53174 .76532 m .5356 .76727 L .53442 .76497 L F
0 g
.5316 .7678 m
.5356 .76727 L
s
.41056 .3801 m .41067 .36163 L .40339 .37853 L .657 .779 .939 r
F
.41056 .3801 m .42512 .36484 L .41067 .36163 L F
.41689 .38948 m .42531 .37167 L .41072 .3869 L .656 .78 .939 r
F
.41689 .38948 m .4377 .37694 L .42531 .37167 L F
.56708 .22315 m .52366 .22646 L .55898 .23472 L .644 .736 .916 r
F
.52081 .76637 m .52364 .76441 L .52394 .76733 L .86 .578 .509 r
F
.52081 .76637 m .52051 .76344 L .52364 .76441 L F
0 g
.52364 .76441 m
.52674 .76482 L
s
.39787 .24877 m .37019 .24138 L .36928 .24977 L .657 .403 .524 r
F
0 g
.34299 .25569 m
.36928 .24977 L
s
.39787 .24877 m .39871 .24037 L .37019 .24138 L .657 .403 .524 r
F
0 g
.34398 .24732 m
.37019 .24138 L
s
.52428 .76141 m .52368 .76438 L .52636 .76206 L .657 .813 .958 r
F
.52428 .76141 m .52056 .76341 L .52368 .76438 L F
.72429 .52027 m .72079 .50937 L .7097 .51234 L .658 .807 .955 r
F
.73003 .51954 m .72079 .50937 L .72429 .52027 L F
.42661 .25277 m .42738 .24437 L .39871 .24037 L .733 .471 .532 r
F
0 g
.42738 .24437 m
.45401 .25307 L
s
.7013 .24215 m .72945 .21903 L .69549 .22985 L .644 .736 .916 r
F
.7013 .24215 m .73786 .23764 L .72945 .21903 L F
.52424 .77026 m .52762 .76782 L .52793 .77074 L .793 .527 .535 r
F
.52424 .77026 m .52394 .76733 L .52762 .76782 L F
.52663 .765 m .52762 .76782 L .52909 .76533 L .657 .813 .959 r
F
.52663 .765 m .52394 .76733 L .52762 .76782 L F
0 g
.52762 .76782 m
.5316 .7678 L
s
.18785 .65086 m .19118 .6517 L .19047 .65653 L .996 .808 .446 r
F
.18785 .65086 m .18857 .64601 L .19118 .6517 L F
.20335 .64689 m .19118 .6517 L .20505 .65069 L .596 .768 .962 r
F
.20335 .64689 m .18857 .64601 L .19118 .6517 L F
0 g
.19118 .6517 m
.19562 .65616 L
s
.73003 .51954 m .73238 .5079 L .72079 .50937 L .658 .807 .955 r
F
.74155 .52609 m .74454 .5137 L .7365 .52525 L .657 .808 .956 r
F
.74155 .52609 m .75468 .5154 L .74454 .5137 L F
.21828 .65451 m .20795 .65916 L .22006 .65633 L .595 .768 .962 r
F
.21828 .65451 m .20436 .65553 L .20795 .65916 L F
.69205 .5218 m .67396 .51714 L .66604 .5259 L .658 .807 .955 r
F
.67476 .52283 m .66604 .5259 L .66682 .53157 L .212 .125 .534 r
F
.67476 .52283 m .67396 .51714 L .66604 .5259 L F
0 g
.66242 .53491 m
.66604 .5259 L
s
.54264 .76487 m .54232 .76195 L .54488 .76024 L .382 .23 .547 r
F
.53937 .76628 m .54232 .76195 L .54264 .76487 L .509 .32 .56 r
F
0 g
.53924 .76328 m
.54232 .76195 L
s
.53968 .7692 m .53937 .76628 L .54264 .76487 L .509 .32 .56 r
F
.53591 .7702 m .53937 .76628 L .53968 .7692 L .597 .383 .562 r
F
.53693 .7643 m .53937 .76628 L .54264 .76487 L .657 .813 .959 r
F
.53442 .76497 m .53937 .76628 L .53693 .7643 L F
0 g
.5356 .76727 m
.53937 .76628 L
s
.23527 .52957 m .21803 .5261 L .21816 .53177 L .668 .439 .564 r
F
0 g
.20263 .53614 m
.21816 .53177 L
s
.23527 .52957 m .23512 .5239 L .21803 .5261 L .668 .439 .564 r
F
0 g
.20252 .53048 m
.21803 .5261 L
s
.2765 .65678 m .27787 .64644 L .27727 .65128 L 0 0 0 r
F
.27589 .66162 m .2765 .65678 L .27727 .65128 L F
.26201 .65407 m .2765 .65678 L .27727 .65128 L .596 .768 .962 r
F
0 g
.27279 .66167 m
.2765 .65678 L
s
.21889 .64293 m .2042 .64206 L .20589 .64585 L .597 .767 .961 r
F
.25894 .66219 m .27589 .66162 L .26138 .65892 L .595 .768 .962 r
F
.24563 .65786 m .25894 .66219 L .26138 .65892 L F
.24352 .6592 m .25894 .66219 L .24563 .65786 L F
.55153 .37063 m .56444 .3743 L .56489 .38109 L .946 .655 .457 r
F
.55153 .37063 m .55111 .36382 L .56444 .3743 L F
.5775 .35456 m .56444 .3743 L .58633 .36164 L .657 .779 .939 r
F
.5775 .35456 m .55111 .36382 L .56444 .3743 L F
0 g
.56444 .3743 m
.57135 .37737 L
s
.76886 .52293 m .78044 .50938 L .76297 .51856 L .657 .808 .956 r
F
.76886 .52293 m .7892 .51602 L .78044 .50938 L F
.26249 .64921 m .27765 .64643 L .26296 .64555 L .597 .767 .961 r
F
.24805 .64651 m .26249 .64921 L .26296 .64555 L F
.38101 .38068 m .36546 .366 L .35341 .37177 L .657 .779 .939 r
F
.38808 .37883 m .36546 .366 L .38101 .38068 L F
.56778 .21494 m .5365 .20077 L .5247 .21825 L .645 .736 .915 r
F
.36169 .50757 m .36061 .52147 L .37115 .51076 L .66 .804 .952 r
F
.36169 .50757 m .34645 .51676 L .36061 .52147 L F
0 g
.36061 .52147 m
.37681 .52398 L
s
.44691 .37709 m .45855 .35738 L .43749 .37013 L .657 .779 .939 r
F
.44691 .37709 m .47261 .36796 L .45855 .35738 L F
.44018 .50559 m .45027 .49204 L .45074 .49768 L .353 .208 .541 r
F
.44063 .51123 m .44018 .50559 L .45074 .49768 L F
.42441 .49821 m .44018 .50559 L .45074 .49768 L .661 .803 .951 r
F
.41527 .50249 m .44018 .50559 L .42441 .49821 L F
0 g
.43068 .51 m
.44018 .50559 L
s
.53205 .76824 m .53191 .77072 L .53591 .7702 L .656 .814 .959 r
F
.5294 .76826 m .53191 .77072 L .53205 .76824 L F
.5294 .76826 m .52793 .77074 L .53191 .77072 L F
.53554 .20892 m .52417 .21813 L .52366 .22646 L 0 0 .337 r
F
.53554 .20892 m .53602 .20055 L .52417 .21813 L F
0 g
.5197 .23704 m
.52417 .21813 L
s
.39917 .42439 m
.40016 .40051 L
s
.25272 .52973 m .23512 .5239 L .23527 .52957 L .734 .492 .562 r
F
0 g
.21803 .5261 m
.23512 .5239 L
s
.23512 .5239 m
.25254 .52407 L
s
.25272 .52973 m
.26923 .53221 L
s
.53473 .76789 m .53591 .7702 L .53968 .7692 L .656 .814 .959 r
F
.53205 .76824 m .53591 .7702 L .53473 .76789 L F
0 g
.53191 .77072 m
.53591 .7702 L
s
.39149 .42425 m
.39253 .40066 L
s
.23527 .52957 m
.25272 .52973 L
s
.3751 .39031 m .35347 .37859 L .34445 .38591 L .656 .78 .939 r
F
.38112 .38748 m .35347 .37859 L .3751 .39031 L F
.35358 .36509 m .31843 .36428 L .34464 .3724 L .658 .778 .938 r
F
.52111 .76929 m .52394 .76733 L .52424 .77026 L .86 .578 .509 r
F
.52111 .76929 m .52081 .76637 L .52394 .76733 L F
.52454 .76436 m .52394 .76733 L .52663 .765 L .657 .813 .959 r
F
.52454 .76436 m .52081 .76637 L .52394 .76733 L F
0 g
.52394 .76733 m
.52762 .76782 L
s
.71964 .5274 m .71055 .51803 L .70073 .52227 L .657 .808 .956 r
F
.72515 .52593 m .71055 .51803 L .71964 .5274 L F
.73786 .23764 m .7378 .22928 L .72941 .21064 L .977 .716 .31 r
F
0 g
.7378 .22928 m
.73862 .24847 L
s
.52694 .76793 m .52793 .77074 L .5294 .76826 L .656 .814 .959 r
F
.52694 .76793 m .52424 .77026 L .52793 .77074 L F
0 g
.52793 .77074 m
.53191 .77072 L
s
.51843 .76499 m .52051 .76344 L .52081 .76637 L .932 .634 .456 r
F
.51843 .76499 m .51813 .76206 L .52051 .76344 L F
0 g
.52051 .76344 m
.52364 .76441 L
s
.34441 .3791 m .31802 .37096 L .31015 .38361 L .657 .779 .939 r
F
.318 .3778 m .31015 .38361 L .31012 .39042 L 0 0 .384 r
F
.318 .3778 m .31802 .37096 L .31015 .38361 L F
0 g
.30829 .39684 m
.31015 .38361 L
s
.5227 .76049 m .52056 .76341 L .52428 .76141 L .657 .813 .958 r
F
.5227 .76049 m .5182 .76204 L .52056 .76341 L F
.54264 .76487 m .54488 .76024 L .5452 .76316 L .382 .23 .547 r
F
.54296 .7678 m .54264 .76487 L .5452 .76316 L F
.53968 .7692 m .54264 .76487 L .54296 .7678 L .509 .32 .56 r
F
.53912 .76336 m .54264 .76487 L .5452 .76316 L .657 .813 .959 r
F
.53693 .7643 m .54264 .76487 L .53912 .76336 L F
0 g
.53937 .76628 m
.54264 .76487 L
s
.78824 .51036 m .78728 .50471 L .77853 .49804 L .954 .637 .391 r
F
0 g
.78728 .50471 m
.79179 .51273 L
s
.53725 .76722 m .53968 .7692 L .54296 .7678 L .656 .814 .959 r
F
.53473 .76789 m .53968 .7692 L .53725 .76722 L F
0 g
.53591 .7702 m
.53968 .7692 L
s
.40339 .37853 m .39516 .36073 L .39572 .3781 L .657 .779 .939 r
F
.40339 .37853 m .41067 .36163 L .39516 .36073 L F
.76095 .50734 m .76591 .49336 L .75272 .50418 L .658 .806 .954 r
F
.76095 .50734 m .77827 .49818 L .76591 .49336 L F
.7365 .52525 m .73326 .51358 L .73091 .5252 L .657 .808 .956 r
F
.7365 .52525 m .74454 .5137 L .73326 .51358 L F
0 g
.39747 .46543 m
.39917 .42439 L
s
.69989 .51659 m .67396 .51714 L .69205 .5218 L .658 .807 .955 r
F
0 g
.38967 .46554 m
.39149 .42425 L
s
.5452 .76316 m .54488 .76024 L .54655 .75832 L .168 .08 .504 r
F
0 g
.54232 .76195 m
.54488 .76024 L
s
.54046 .75928 m .54481 .76022 L .54647 .75832 L .657 .813 .958 r
F
.53877 .76042 m .54481 .76022 L .54046 .75928 L F
.42661 .25277 m .39871 .24037 L .39787 .24877 L .733 .471 .532 r
F
0 g
.39871 .24037 m
.42738 .24437 L
s
.42661 .25277 m
.45332 .26146 L
s
.37019 .24138 m
.39871 .24037 L
s
.38808 .37883 m .37972 .36222 L .36546 .366 L .657 .779 .939 r
F
.39572 .3781 m .37972 .36222 L .38808 .37883 L F
.20265 .65174 m .19047 .65653 L .20436 .65553 L .595 .768 .962 r
F
.20265 .65174 m .18785 .65086 L .19047 .65653 L F
0 g
.19047 .65653 m
.19589 .66196 L
s
.72515 .52593 m .72166 .51506 L .71055 .51803 L .657 .808 .956 r
F
.73091 .5252 m .72166 .51506 L .72515 .52593 L F
.52485 .76729 m .52424 .77026 L .52694 .76793 L .656 .814 .959 r
F
.52485 .76729 m .52111 .76929 L .52424 .77026 L F
0 g
.52424 .77026 m
.52793 .77074 L
s
.21813 .64777 m .20335 .64689 L .20505 .65069 L .596 .768 .962 r
F
.27589 .66162 m .27727 .65128 L .27666 .65614 L 0 0 0 r
F
.26138 .65892 m .27589 .66162 L .27666 .65614 L .595 .768 .962 r
F
0 g
.27218 .6665 m
.27589 .66162 L
s
.73091 .5252 m .73326 .51358 L .72166 .51506 L .657 .808 .956 r
F
.39572 .3781 m .39516 .36073 L .37972 .36222 L .657 .779 .939 r
F
.26201 .65407 m .27727 .65128 L .26248 .6504 L .596 .768 .962 r
F
.24748 .65136 m .26201 .65407 L .26248 .6504 L F
.41072 .3869 m .41083 .36846 L .40353 .38533 L .656 .78 .939 r
F
.41072 .3869 m .42531 .37167 L .41083 .36846 L F
.69287 .52747 m .67476 .52283 L .66682 .53157 L .657 .808 .956 r
F
0 g
.66319 .54055 m
.66682 .53157 L
s
.51873 .76792 m .52081 .76637 L .52111 .76929 L .932 .634 .456 r
F
.51873 .76792 m .51843 .76499 L .52081 .76637 L F
.52296 .76344 m .52081 .76637 L .52454 .76436 L .657 .813 .959 r
F
.52296 .76344 m .51843 .76499 L .52081 .76637 L F
0 g
.52081 .76637 m
.52394 .76733 L
s
.21816 .53177 m
.23527 .52957 L
s
.61281 .22063 m .59611 .198 L .58018 .20521 L .645 .736 .915 r
F
.62189 .21862 m .59611 .198 L .61281 .22063 L F
.24805 .64651 m .26296 .64555 L .24827 .64468 L .597 .767 .961 r
F
.54296 .7678 m .5452 .76316 L .54552 .76608 L .382 .23 .547 r
F
.53943 .76629 m .54296 .7678 L .54552 .76608 L .656 .814 .959 r
F
.53725 .76722 m .54296 .7678 L .53943 .76629 L F
0 g
.53968 .7692 m
.54296 .7678 L
s
.64953 .22255 m .65301 .19587 L .64093 .21961 L .645 .736 .915 r
F
.64953 .22255 m .67039 .20187 L .65301 .19587 L F
.33496 .50444 m .34581 .50545 L .34613 .5111 L .928 .647 .488 r
F
.33496 .50444 m .33466 .49877 L .34581 .50545 L F
0 g
.34581 .50545 m
.35202 .50753 L
s
.44063 .51123 m .45074 .49768 L .45121 .50334 L .353 .208 .541 r
F
.42485 .50387 m .44063 .51123 L .45121 .50334 L .66 .804 .952 r
F
.41569 .50815 m .44063 .51123 L .42485 .50387 L F
0 g
.42695 .51757 m
.44063 .51123 L
s
.5452 .76316 m .54655 .75832 L .54687 .76125 L .168 .08 .504 r
F
.54552 .76608 m .5452 .76316 L .54687 .76125 L F
.54082 .76221 m .5452 .76316 L .54687 .76125 L .657 .813 .959 r
F
.53912 .76336 m .5452 .76316 L .54082 .76221 L F
0 g
.54264 .76487 m
.5452 .76316 L
s
.52721 .75895 m .5227 .76049 L .52428 .76141 L .657 .813 .958 r
F
.51697 .76329 m .51813 .76206 L .51843 .76499 L .978 .679 .329 r
F
.51697 .76329 m .51667 .76036 L .51813 .76206 L F
0 g
.51813 .76206 m
.52051 .76344 L
s
.52174 .75936 m .5182 .76204 L .5227 .76049 L .657 .813 .958 r
F
.52174 .75936 m .51675 .76035 L .5182 .76204 L F
.57798 .36139 m .56489 .38109 L .58682 .36845 L .656 .78 .94 r
F
.57798 .36139 m .55153 .37063 L .56489 .38109 L F
0 g
.56489 .38109 m
.58251 .38886 L
s
.62198 .35994 m .6125 .3769 L .62763 .37777 L .656 .78 .94 r
F
.52829 .76234 m .52454 .76436 L .52663 .765 L .657 .813 .959 r
F
.38112 .38748 m .36554 .37283 L .35347 .37859 L .656 .78 .939 r
F
.38819 .38563 m .36554 .37283 L .38112 .38748 L F
.59789 .24557 m .56668 .23154 L .55857 .24309 L .644 .737 .917 r
F
.60418 .24079 m .56668 .23154 L .59789 .24557 L F
.70477 .36085 m .70406 .35408 L .715 .34119 L .189 .092 .506 r
F
0 g
.6948 .36061 m
.70406 .35408 L
s
.54046 .75928 m .54647 .75832 L .54157 .75801 L .657 .813 .958 r
F
.44714 .38388 m .4588 .36421 L .4377 .37694 L .656 .78 .939 r
F
.44714 .38388 m .47289 .37477 L .4588 .36421 L F
.5322 .76575 m .53205 .76824 L .53473 .76789 L .656 .814 .959 r
F
.53087 .76576 m .53205 .76824 L .5322 .76575 L F
.53087 .76576 m .5294 .76826 L .53205 .76824 L F
.60447 .2324 m .57956 .21338 L .56708 .22315 L .644 .736 .916 r
F
.61246 .22887 m .57956 .21338 L .60447 .2324 L F
.66184 .24892 m .68491 .22732 L .65654 .24352 L .644 .737 .917 r
F
.66184 .24892 m .69544 .23827 L .68491 .22732 L F
.53354 .76558 m .53473 .76789 L .53725 .76722 L .656 .814 .959 r
F
.5322 .76575 m .53473 .76789 L .53354 .76558 L F
.65669 .23513 m .67048 .21006 L .64946 .2308 L .644 .736 .916 r
F
.65669 .23513 m .68499 .21889 L .67048 .21006 L F
.78824 .51036 m .77853 .49804 L .77949 .5037 L .954 .637 .391 r
F
.7892 .51602 m .78824 .51036 L .77949 .5037 L F
0 g
.78824 .51036 m
.79275 .51835 L
s
.56668 .23154 m .52315 .23483 L .55857 .24309 L .644 .737 .917 r
F
.52326 .76637 m .52111 .76929 L .52485 .76729 L .656 .814 .959 r
F
.52326 .76637 m .51873 .76792 L .52111 .76929 L F
0 g
.52111 .76929 m
.52424 .77026 L
s
.76205 .5129 m .76705 .49888 L .75376 .50973 L .658 .807 .955 r
F
.76205 .5129 m .77949 .5037 L .76705 .49888 L F
.54687 .76125 m .54655 .75832 L .54721 .75634 L 0 0 .362 r
F
0 g
.54488 .76024 m
.54655 .75832 L
s
.54157 .75801 m .54647 .75832 L .54713 .75635 L .657 .813 .958 r
F
.52964 .7656 m .5294 .76826 L .53087 .76576 L .656 .814 .959 r
F
.52964 .7656 m .52694 .76793 L .5294 .76826 L F
0 g
.36928 .24977 m
.39787 .24877 L
s
.22596 .72995 m
.22606 .72882 L
s
.35341 .37177 m .31802 .37096 L .34441 .3791 L .657 .779 .939 r
F
.63741 .35964 m .64303 .3763 L .6577 .37257 L .656 .78 .94 r
F
0 g
.39787 .24877 m
.42661 .25277 L
s
.70126 .25054 m .72949 .22747 L .69544 .23827 L .644 .737 .917 r
F
.70126 .25054 m .73793 .24605 L .72949 .22747 L F
.5348 .76524 m .53725 .76722 L .53943 .76629 L .656 .814 .959 r
F
.53354 .76558 m .53725 .76722 L .5348 .76524 L F
.70073 .52227 m .67476 .52283 L .69287 .52747 L .657 .808 .956 r
F
.34445 .38591 m .318 .3778 L .31012 .39042 L .656 .78 .939 r
F
0 g
.30826 .40362 m
.31012 .39042 L
s
.21745 .65262 m .20436 .65553 L .21828 .65451 L .595 .768 .962 r
F
.21745 .65262 m .20265 .65174 L .20436 .65553 L F
.54552 .76608 m .54687 .76125 L .54719 .76417 L .168 .08 .504 r
F
.54114 .76514 m .54552 .76608 L .54719 .76417 L .656 .814 .959 r
F
.53943 .76629 m .54552 .76608 L .54114 .76514 L F
0 g
.54296 .7678 m
.54552 .76608 L
s
.5275 .76188 m .52454 .76436 L .52829 .76234 L .657 .813 .959 r
F
.5275 .76188 m .52296 .76344 L .52454 .76436 L F
.40353 .38533 m .39529 .36757 L .39585 .3849 L .656 .78 .939 r
F
.40353 .38533 m .41083 .36846 L .39529 .36757 L F
.52673 .75838 m .5227 .76049 L .52721 .75895 L .657 .813 .958 r
F
.52673 .75838 m .52174 .75936 L .5227 .76049 L F
.26138 .65892 m .27666 .65614 L .26186 .65526 L .595 .768 .962 r
F
.24684 .65621 m .26138 .65892 L .26186 .65526 L F
.24563 .65786 m .26138 .65892 L .24684 .65621 L F
.51727 .76622 m .51843 .76499 L .51873 .76792 L .978 .679 .329 r
F
.51727 .76622 m .51697 .76329 L .51843 .76499 L F
.52199 .7623 m .51843 .76499 L .52296 .76344 L .657 .813 .959 r
F
.52199 .7623 m .51697 .76329 L .51843 .76499 L F
0 g
.51843 .76499 m
.52081 .76637 L
s
.6992 .511 m .6851 .50367 L .67344 .51154 L .658 .806 .954 r
F
.70894 .50677 m .6851 .50367 L .6992 .511 L F
.5286 .76527 m .52694 .76793 L .52964 .7656 L .656 .814 .959 r
F
.5286 .76527 m .52485 .76729 L .52694 .76793 L F
.24748 .65136 m .26248 .6504 L .2477 .64952 L .596 .768 .962 r
F
.18897 .64045 m .18929 .64117 L .18857 .64601 L .769 .701 .161 r
F
.18897 .64045 m .18969 .6356 L .18929 .64117 L F
0 g
.18929 .64117 m
.19158 .64619 L
s
.20451 .63837 m .18951 .64119 L .2042 .64206 L .597 .767 .961 r
F
.20451 .63837 m .18991 .63564 L .18951 .64119 L F
.21906 .64109 m .2042 .64206 L .21889 .64293 L F
.21906 .64109 m .20451 .63837 L .2042 .64206 L F
.62189 .21862 m .61446 .19386 L .59611 .198 L .645 .736 .915 r
F
.63149 .21827 m .61446 .19386 L .62189 .21862 L F
.64093 .21961 m .6339 .19313 L .63149 .21827 L F
.64093 .21961 m .65301 .19587 L .6339 .19313 L F
.54082 .76221 m .54687 .76125 L .54193 .76094 L .657 .813 .959 r
F
.24827 .64468 m .26143 .64175 L .24748 .64278 L .597 .767 .961 r
F
.24827 .64468 m .26296 .64555 L .26143 .64175 L F
.56708 .22315 m .53554 .20892 L .52366 .22646 L .644 .736 .916 r
F
.53506 .21733 m .52366 .22646 L .52315 .23483 L 0 0 .337 r
F
.53506 .21733 m .53554 .20892 L .52366 .22646 L F
0 g
.51918 .24533 m
.52366 .22646 L
s
.26296 .64555 m .27541 .64072 L .26143 .64175 L .597 .767 .961 r
F
.26296 .64555 m .27765 .64643 L .27541 .64072 L F
.54157 .75801 m .54713 .75635 L .542 .7567 L .657 .813 .958 r
F
.38819 .38563 m .37982 .36906 L .36554 .37283 L .656 .78 .939 r
F
.39585 .3849 m .37982 .36906 L .38819 .38563 L F
.5359 .76477 m .53943 .76629 L .54114 .76514 L .656 .814 .959 r
F
.5348 .76524 m .53943 .76629 L .5359 .76477 L F
.27727 .65128 m .27787 .64644 L .27562 .64071 L .986 .8 .403 r
F
0 g
.2772 .65128 m
.27723 .65104 L
s
.43707 .36347 m .43951 .3427 L .42479 .3582 L .658 .778 .938 r
F
.43707 .36347 m .45798 .35076 L .43951 .3427 L F
.61498 .35832 m .6125 .3769 L .62198 .35994 L .656 .78 .94 r
F
.61498 .35832 m .59859 .37373 L .6125 .3769 L F
.33526 .51013 m .34613 .5111 L .34645 .51676 L .928 .647 .488 r
F
.33526 .51013 m .33496 .50444 L .34613 .5111 L F
.35393 .4974 m .34613 .5111 L .36135 .50189 L .661 .803 .951 r
F
.35393 .4974 m .33496 .50444 L .34613 .5111 L F
0 g
.34613 .5111 m
.35238 .51319 L
s
.54687 .76125 m .54721 .75634 L .54753 .75927 L 0 0 .362 r
F
.54719 .76417 m .54687 .76125 L .54753 .75927 L F
.54193 .76094 m .54687 .76125 L .54753 .75927 L .657 .813 .959 r
F
0 g
.5452 .76316 m
.54687 .76125 L
s
.70825 .64059 m .71859 .63857 L .71854 .64341 L .8 .547 .555 r
F
.70825 .64059 m .70831 .63575 L .71859 .63857 L F
0 g
.71859 .63857 m
.72194 .639 L
s
.39585 .3849 m .39529 .36757 L .37982 .36906 L .656 .78 .939 r
F
.58018 .20521 m .5365 .20077 L .56778 .21494 L .645 .736 .915 r
F
.73786 .23764 m .72941 .21064 L .72945 .21903 L .977 .716 .31 r
F
.73793 .24605 m .73786 .23764 L .72945 .21903 L F
0 g
.73786 .23764 m
.73868 .2568 L
s
.51654 .76138 m .51667 .76036 L .51697 .76329 L .806 .582 .021 r
F
.51654 .76138 m .51624 .75845 L .51667 .76036 L F
0 g
.51667 .76036 m
.51813 .76206 L
s
.52146 .7581 m .51675 .76035 L .52174 .75936 L .657 .813 .958 r
F
.52146 .7581 m .51632 .75845 L .51675 .76035 L F
.47261 .36796 m .47234 .36118 L .4583 .35057 L .94 .656 .473 r
F
0 g
.47234 .36118 m
.48094 .3735 L
s
.63149 .21827 m .6339 .19313 L .61446 .19386 L .645 .736 .915 r
F
.69521 .22159 m .71341 .19417 L .68479 .21067 L F
.69521 .22159 m .7289 .2108 L .71341 .19417 L F
.5278 .76481 m .52485 .76729 L .5286 .76527 L .656 .814 .959 r
F
.5278 .76481 m .52326 .76637 L .52485 .76729 L F
.52701 .76131 m .52296 .76344 L .5275 .76188 L .657 .813 .959 r
F
.52701 .76131 m .52199 .7623 L .52296 .76344 L F
.52229 .76523 m .51873 .76792 L .52326 .76637 L .656 .814 .959 r
F
.52229 .76523 m .51727 .76622 L .51873 .76792 L F
0 g
.51873 .76792 m
.52111 .76929 L
s
.52659 .75775 m .52174 .75936 L .52673 .75838 L .657 .813 .958 r
F
.52659 .75775 m .52146 .7581 L .52174 .75936 L F
.45074 .49768 m .45027 .49204 L .45697 .48305 L .11 .034 .481 r
F
0 g
.44254 .49785 m
.45027 .49204 L
s
.75272 .50418 m .75073 .49074 L .74265 .50247 L .658 .806 .954 r
F
.75272 .50418 m .76591 .49336 L .75073 .49074 L F
.7892 .51602 m .77949 .5037 L .78044 .50938 L .954 .637 .391 r
F
0 g
.7892 .51602 m
.79371 .52398 L
s
.54114 .76514 m .54719 .76417 L .54225 .76387 L .656 .814 .959 r
F
.53675 .7642 m .54114 .76514 L .54225 .76387 L F
.5359 .76477 m .54114 .76514 L .53675 .7642 L F
0 g
.53222 .76363 m
.53409 .76344 L
s
.53222 .76363 m
.53222 .76363 L
s
.53037 .76339 m
.53222 .76363 L
s
.542 .7567 m .54713 .75635 L .54674 .75444 L .657 .813 .958 r
F
.54753 .75927 m .54721 .75634 L .54682 .75443 L .781 .561 0 r
F
0 g
.54655 .75832 m
.54714 .75657 L
s
.54193 .76094 m .54753 .75927 L .54237 .75962 L .657 .813 .959 r
F
.53699 .76063 m .54193 .76094 L .54237 .75962 L F
.76297 .51856 m .76799 .50458 L .75468 .5154 L .657 .808 .956 r
F
.76297 .51856 m .78044 .50938 L .76799 .50458 L F
.542 .7567 m .54674 .75444 L .54174 .75543 L .657 .813 .958 r
F
.53687 .75705 m .542 .7567 L .54174 .75543 L F
.54719 .76417 m .54753 .75927 L .54786 .7622 L 0 0 .362 r
F
.54225 .76387 m .54719 .76417 L .54786 .7622 L .656 .814 .959 r
F
0 g
.54552 .76608 m
.54719 .76417 L
s
.70477 .36085 m .715 .34119 L .71573 .34798 L .189 .092 .506 r
F
.70548 .36763 m .70477 .36085 L .71573 .34798 L F
.6805 .35258 m .70477 .36085 L .71573 .34798 L .657 .779 .939 r
F
.67006 .36003 m .70477 .36085 L .6805 .35258 L F
0 g
.69543 .3674 m
.70477 .36085 L
s
.53235 .76326 m .5322 .76575 L .53354 .76558 L .656 .814 .959 r
F
.53235 .76326 m .53087 .76576 L .5322 .76575 L F
.53235 .76326 m .53354 .76558 L .5348 .76524 L F
0 g
.53409 .76344 m
.5353 .76305 L
s
.24684 .65621 m .26186 .65526 L .24705 .65438 L .595 .768 .962 r
F
.18825 .64531 m .18857 .64601 L .18785 .65086 L .769 .701 .161 r
F
.18825 .64531 m .18897 .64045 L .18857 .64601 L F
.20366 .64319 m .18857 .64601 L .20335 .64689 L .596 .768 .962 r
F
.20366 .64319 m .18897 .64045 L .18857 .64601 L F
0 g
.18857 .64601 m
.19088 .65104 L
s
.51683 .76432 m .51697 .76329 L .51727 .76622 L .806 .582 .021 r
F
.51683 .76432 m .51654 .76138 L .51697 .76329 L F
.52171 .76103 m .51697 .76329 L .52199 .7623 L .657 .813 .959 r
F
.52171 .76103 m .51654 .76138 L .51697 .76329 L F
0 g
.51697 .76329 m
.51843 .76499 L
s
.53687 .75705 m .54174 .75543 L .53673 .75641 L .657 .813 .958 r
F
.53235 .76326 m .52964 .7656 L .53087 .76576 L .656 .814 .959 r
F
0 g
.52921 .76296 m
.53037 .76339 L
s
.21831 .64592 m .20335 .64689 L .21813 .64777 L .596 .768 .962 r
F
.21831 .64592 m .20366 .64319 L .20335 .64689 L F
0 g
.5353 .76305 m
.53613 .76254 L
s
.53235 .76326 m .5348 .76524 L .5359 .76477 L .656 .814 .959 r
F
.3873 .50076 m .38201 .51246 L .39355 .51258 L .66 .804 .952 r
F
0 g
.52843 .76243 m
.52921 .76296 L
s
.2477 .64952 m .26094 .64659 L .24691 .64762 L .596 .768 .962 r
F
.2477 .64952 m .26248 .6504 L .26094 .64659 L F
.69989 .51659 m .68571 .50925 L .67396 .51714 L .658 .807 .955 r
F
.7097 .51234 m .68571 .50925 L .69989 .51659 L F
.26248 .6504 m .27501 .64556 L .26094 .64659 L .596 .768 .962 r
F
.26248 .6504 m .27727 .65128 L .27501 .64556 L F
.68571 .50925 m .67317 .51147 L .67396 .51714 L .396 .252 .565 r
F
.68571 .50925 m .68489 .50356 L .67317 .51147 L F
0 g
.66526 .52025 m
.67317 .51147 L
s
.35347 .37859 m .318 .3778 L .34445 .38591 L .656 .78 .939 r
F
.27727 .65128 m .27562 .64071 L .27501 .64556 L .986 .8 .403 r
F
.27666 .65614 m .27727 .65128 L .27501 .64556 L F
0 g
.27659 .65613 m
.27662 .6559 L
s
.61246 .22887 m .59562 .20615 L .57956 .21338 L .644 .736 .916 r
F
.62161 .22685 m .59562 .20615 L .61246 .22887 L F
.52732 .76424 m .52326 .76637 L .5278 .76481 L .656 .814 .959 r
F
.52732 .76424 m .52229 .76523 L .52326 .76637 L F
.22023 .63943 m .20451 .63837 L .21906 .64109 L .597 .767 .961 r
F
.64481 .35775 m .6577 .37257 L .6707 .36682 L .656 .78 .94 r
F
.63741 .35964 m .6577 .37257 L .64481 .35775 L F
.53235 .76326 m .5286 .76527 L .52964 .7656 L .656 .814 .959 r
F
.64946 .2308 m .65297 .20403 L .64079 .22785 L .644 .736 .916 r
F
.64946 .2308 m .67048 .21006 L .65297 .20403 L F
.24748 .64278 m .25797 .63807 L .24574 .64095 L .597 .767 .961 r
F
.24748 .64278 m .26143 .64175 L .25797 .63807 L F
.3989 .50009 m .40503 .51111 L .41569 .50815 L .66 .804 .952 r
F
.52687 .76068 m .52199 .7623 L .52701 .76131 L .657 .813 .959 r
F
.52687 .76068 m .52171 .76103 L .52199 .7623 L F
.70818 .64544 m .71854 .64341 L .71849 .64825 L .8 .547 .555 r
F
.70818 .64544 m .70825 .64059 L .71854 .64341 L F
.71691 .63469 m .71854 .64341 L .7238 .63658 L .6 .765 .958 r
F
.71691 .63469 m .70825 .64059 L .71854 .64341 L F
0 g
.71854 .64341 m
.72589 .64433 L
s
.53699 .76063 m .54237 .75962 L .53721 .75997 L .657 .813 .959 r
F
.52681 .75709 m .52146 .7581 L .52659 .75775 L .657 .813 .958 r
F
.53235 .76326 m .5359 .76477 L .53675 .7642 L .656 .814 .959 r
F
0 g
.53613 .76254 m
.53665 .76192 L
s
.52799 .7618 m
.52843 .76243 L
s
.54753 .75927 m .54682 .75443 L .54714 .75735 L .781 .561 0 r
F
.54237 .75962 m .54753 .75927 L .54714 .75735 L .657 .813 .959 r
F
.54786 .7622 m .54753 .75927 L .54714 .75735 L .781 .561 0 r
F
0 g
.54687 .76125 m
.54746 .75949 L
s
.53673 .75641 m .54079 .75429 L .53626 .75584 L .657 .813 .958 r
F
0 g
.53626 .75615 m
.53626 .75857 L
s
.53673 .75641 m .54174 .75543 L .54079 .75429 L .657 .813 .958 r
F
.54225 .76387 m .54786 .7622 L .54269 .76255 L .656 .814 .959 r
F
.53731 .76356 m .54225 .76387 L .54269 .76255 L F
.53675 .7642 m .54225 .76387 L .53731 .76356 L F
.52187 .75678 m .51632 .75845 L .52146 .7581 L .657 .813 .958 r
F
.52681 .75709 m .52187 .75678 L .52146 .7581 L F
.35426 .5031 m .34645 .51676 L .36169 .50757 L .66 .804 .952 r
F
.35426 .5031 m .33526 .51013 L .34645 .51676 L F
0 g
.34645 .51676 m
.36061 .52147 L
s
.53235 .76326 m .5278 .76481 L .5286 .76527 L .656 .814 .959 r
F
0 g
.22939 .72641 m
.2295 .72519 L
s
.54237 .75962 m .54714 .75735 L .54211 .75834 L .657 .813 .959 r
F
.53721 .75997 m .54237 .75962 L .54211 .75834 L F
.52187 .75678 m .51693 .75647 L .51632 .75845 L .657 .813 .958 r
F
0 g
.22148 .7263 m
.22153 .7257 L
s
.22162 .72476 m
.2218 .72278 L
s
.2219 .72165 m
.22822 .65219 L
s
.51716 .7594 m .51624 .75845 L .51654 .76138 L 0 0 .342 r
F
.51716 .7594 m .51686 .75646 L .51624 .75845 L F
.69968 .63656 m .70831 .63575 L .70825 .64059 L .871 .609 .54 r
F
.69968 .63656 m .69975 .63171 L .70831 .63575 L F
0 g
.70831 .63575 m
.71333 .63713 L
s
.53235 .76326 m .53675 .7642 L .53731 .76356 L .656 .814 .959 r
F
.35358 .36509 m .33178 .35316 L .31843 .36428 L .658 .778 .938 r
F
.36554 .35933 m .33178 .35316 L .35358 .36509 L F
.60418 .24079 m .5792 .2218 L .56668 .23154 L .644 .737 .917 r
F
.61218 .23726 m .5792 .2218 L .60418 .24079 L F
.75273 .64323 m .75273 .63839 L .76274 .63545 L .506 .307 .545 r
F
0 g
.74889 .63892 m
.75273 .63839 L
s
.52201 .76396 m .51727 .76622 L .52229 .76523 L .656 .814 .959 r
F
.52201 .76396 m .51683 .76432 L .51727 .76622 L F
0 g
.51727 .76622 m
.51873 .76792 L
s
.52735 .75645 m .52187 .75678 L .52681 .75709 L .657 .813 .958 r
F
.53721 .75997 m .54211 .75834 L .53707 .75933 L .657 .813 .959 r
F
0 g
.53665 .76192 m
.53679 .76119 L
s
.54174 .75543 m .54533 .75273 L .54079 .75429 L .657 .813 .958 r
F
.54174 .75543 m .54674 .75444 L .54533 .75273 L F
.65654 .24352 m .67036 .2185 L .64929 .2392 L .644 .737 .917 r
F
.65654 .24352 m .68491 .22732 L .67036 .2185 L F
0 g
.52793 .76106 m
.52799 .7618 L
s
.43749 .37013 m .43995 .3493 L .42512 .36484 L .657 .779 .939 r
F
.43749 .37013 m .45855 .35738 L .43995 .3493 L F
.70894 .50677 m .69977 .49725 L .6851 .50367 L .658 .806 .954 r
F
.71995 .50381 m .69977 .49725 L .70894 .50677 L F
.53626 .75584 m .53922 .75336 L .53547 .75538 L .657 .813 .958 r
F
.53626 .75584 m .54079 .75429 L .53922 .75336 L F
.53235 .76326 m .52732 .76424 L .5278 .76481 L .656 .814 .959 r
F
.38184 .49989 m .38201 .51246 L .3873 .50076 L .66 .804 .952 r
F
.38184 .49989 m .37115 .51076 L .38201 .51246 L F
.45074 .49768 m .45697 .48305 L .45745 .48871 L .11 .034 .481 r
F
.45121 .50334 m .45074 .49768 L .45745 .48871 L F
.43143 .49289 m .45074 .49768 L .45745 .48871 L .661 .803 .951 r
F
.42441 .49821 m .45074 .49768 L .43143 .49289 L F
0 g
.44296 .50351 m
.45074 .49768 L
s
.74044 .64963 m
.74151 .64962 L
s
.72375 .64145 m .71849 .64825 L .72984 .64968 L .599 .766 .959 r
F
0 g
.72984 .64968 m
.73131 .64967 L
s
.47261 .36796 m .4583 .35057 L .45855 .35738 L .94 .656 .473 r
F
.47289 .37477 m .47261 .36796 L .45855 .35738 L F
0 g
.47261 .36796 m
.48123 .38025 L
s
.52718 .76361 m .52229 .76523 L .52732 .76424 L .656 .814 .959 r
F
.52718 .76361 m .52201 .76396 L .52229 .76523 L F
.53731 .76356 m .54269 .76255 L .53752 .7629 L F
.53235 .76326 m .53731 .76356 L .53752 .7629 L F
.52709 .76002 m .52171 .76103 L .52687 .76068 L .657 .813 .959 r
F
.54714 .75735 m .54682 .75443 L .5454 .75271 L .976 .675 .313 r
F
0 g
.54682 .75443 m
.54721 .75634 L
s
.75376 .50973 m .75178 .49626 L .74363 .50802 L .658 .807 .955 r
F
.75376 .50973 m .76705 .49888 L .75178 .49626 L F
.52735 .75645 m .52296 .7555 L .52187 .75678 L .657 .813 .958 r
F
.5282 .75588 m .52296 .7555 L .52735 .75645 L F
.54298 .35127 m .55068 .35703 L .55111 .36382 L .981 .7 .329 r
F
.54298 .35127 m .54257 .34445 L .55068 .35703 L F
0 g
.55068 .35703 m
.55677 .36183 L
s
.20296 .64805 m .18785 .65086 L .20265 .65174 L .595 .768 .962 r
F
.20296 .64805 m .18825 .64531 L .18785 .65086 L F
0 g
.18785 .65086 m
.19047 .65653 L
s
.54786 .7622 m .54714 .75735 L .54747 .76029 L .781 .561 0 r
F
.54269 .76255 m .54786 .7622 L .54747 .76029 L .656 .814 .959 r
F
0 g
.54719 .76417 m
.54786 .7622 L
s
.53707 .75933 m .54115 .7572 L .53659 .75876 L .657 .813 .959 r
F
.53707 .75933 m .54211 .75834 L .54115 .7572 L F
.52213 .75971 m .51654 .76138 L .52171 .76103 L F
.52709 .76002 m .52213 .75971 L .52171 .76103 L F
.21762 .65078 m .20265 .65174 L .21745 .65262 L .595 .768 .962 r
F
.21762 .65078 m .20296 .64805 L .20265 .65174 L F
0 g
.53627 .76024 m
.53679 .76119 L
s
.57204 .33925 m .55108 .35689 L .57729 .34766 L .657 .779 .938 r
F
.57204 .33925 m .543 .34438 L .55108 .35689 L F
.53547 .75538 m .53714 .75271 L .53443 .75505 L .657 .813 .958 r
F
.53547 .75538 m .53922 .75336 L .53714 .75271 L F
0 g
.52793 .76106 m
.52856 .76014 L
s
.24705 .65438 m .26031 .65146 L .24626 .65248 L .595 .768 .962 r
F
.24705 .65438 m .26186 .65526 L .26031 .65146 L F
.26186 .65526 m .27439 .65043 L .26031 .65146 L F
.26186 .65526 m .27666 .65614 L .27439 .65043 L F
.52296 .7555 m .51693 .75647 L .52187 .75678 L .657 .813 .958 r
F
.54269 .76255 m .54747 .76029 L .54243 .76128 L .656 .814 .959 r
F
.53752 .7629 m .54269 .76255 L .54243 .76128 L F
.53235 .76326 m .52718 .76361 L .52732 .76424 L F
.60908 .35563 m .59859 .37373 L .61498 .35832 L .656 .78 .94 r
F
.60908 .35563 m .58682 .36845 L .59859 .37373 L F
.27666 .65614 m .27501 .64556 L .27439 .65043 L .986 .8 .403 r
F
0 g
.27589 .66162 m
.27666 .65614 L
s
.51746 .76233 m .51654 .76138 L .51683 .76432 L 0 0 .342 r
F
.52213 .75971 m .51716 .7594 L .51654 .76138 L .657 .813 .959 r
F
.51746 .76233 m .51716 .7594 L .51654 .76138 L 0 0 .342 r
F
.21948 .64426 m .20366 .64319 L .21831 .64592 L .596 .768 .962 r
F
.22023 .63943 m .20681 .63503 L .20451 .63837 L .597 .767 .961 r
F
.22231 .63807 m .20681 .63503 L .22023 .63943 L F
.62161 .22685 m .61411 .202 L .59562 .20615 L .644 .736 .916 r
F
.63128 .2265 m .61411 .202 L .62161 .22685 L F
.24691 .64762 m .25746 .6429 L .24515 .64578 L .596 .768 .962 r
F
.24691 .64762 m .26094 .64659 L .25746 .6429 L F
.56668 .23154 m .53506 .21733 L .52315 .23483 L .644 .737 .917 r
F
0 g
.51867 .25367 m
.52315 .23483 L
s
.64079 .22785 m .6337 .20128 L .63128 .2265 L .644 .736 .916 r
F
.64079 .22785 m .65297 .20403 L .6337 .20128 L F
.24574 .64095 m .25283 .63477 L .24317 .63931 L .597 .767 .961 r
F
.24574 .64095 m .25797 .63807 L .25283 .63477 L F
.74265 .50247 m .73383 .49053 L .73147 .50234 L .658 .806 .954 r
F
.74265 .50247 m .75073 .49074 L .73383 .49053 L F
.20681 .63503 m .18991 .63564 L .20451 .63837 L .597 .767 .961 r
F
.5282 .75588 m .52466 .75435 L .52296 .7555 L .657 .813 .958 r
F
.52929 .75541 m .52466 .75435 L .5282 .75588 L F
.71685 .63956 m .71849 .64825 L .72375 .64145 L .599 .766 .959 r
F
.71685 .63956 m .70818 .64544 L .71849 .64825 L F
0 g
.71849 .64825 m
.72984 .64968 L
s
.53752 .7629 m .54243 .76128 L .53739 .76227 L .656 .814 .959 r
F
.53235 .76326 m .53752 .7629 L .53739 .76227 L F
.70073 .52227 m .68653 .51495 L .67476 .52283 L .657 .808 .956 r
F
.71055 .51803 m .68653 .51495 L .70073 .52227 L F
.52764 .75937 m .52213 .75971 L .52709 .76002 L .657 .813 .959 r
F
.54211 .75834 m .54572 .75564 L .54115 .7572 L F
.54211 .75834 m .54714 .75735 L .54572 .75564 L F
.40427 .49858 m .41569 .50815 L .42485 .50387 L .66 .804 .952 r
F
.3989 .50009 m .41569 .50815 L .40427 .49858 L F
.68653 .51495 m .67396 .51714 L .67476 .52283 L .396 .252 .565 r
F
0 g
.66682 .53157 m
.67476 .52283 L
s
.68653 .51495 m .68571 .50925 L .67396 .51714 L .396 .252 .565 r
F
0 g
.66604 .5259 m
.67396 .51714 L
s
.74769 .64877 m
.74769 .64877 L
s
.74151 .64962 m
.74769 .64877 L
s
.53443 .75505 m .53469 .75237 L .53321 .75489 L .657 .813 .958 r
F
.53443 .75505 m .53714 .75271 L .53469 .75237 L F
.26143 .64175 m .27027 .63519 L .25797 .63807 L .597 .767 .961 r
F
.26143 .64175 m .27541 .64072 L .27027 .63519 L F
.54079 .75429 m .54298 .75134 L .53922 .75336 L .657 .813 .958 r
F
.54079 .75429 m .54533 .75273 L .54298 .75134 L F
.53659 .75876 m .53958 .75627 L .53581 .7583 L .657 .813 .959 r
F
.53659 .75876 m .54115 .7572 L .53958 .75627 L F
.70548 .36763 m .71573 .34798 L .71646 .35479 L .189 .092 .506 r
F
.68117 .35939 m .70548 .36763 L .71646 .35479 L .656 .78 .94 r
F
.6707 .36682 m .70548 .36763 L .68117 .35939 L F
0 g
.68974 .37863 m
.70548 .36763 L
s
.53235 .76326 m .52739 .76295 L .52718 .76361 L .656 .814 .959 r
F
.53235 .76326 m .52795 .76231 L .52739 .76295 L F
.53235 .76326 m .5288 .76173 L .52795 .76231 L F
.53235 .76326 m .52989 .76126 L .5288 .76173 L F
.53235 .76326 m .53116 .76093 L .52989 .76126 L F
.53235 .76326 m .5325 .76075 L .53116 .76093 L F
.53235 .76326 m .53384 .76074 L .5325 .76075 L F
.53235 .76326 m .53507 .76091 L .53384 .76074 L F
.53235 .76326 m .53612 .76123 L .53507 .76091 L F
.53235 .76326 m .53691 .7617 L .53612 .76123 L F
.53235 .76326 m .53739 .76227 L .53691 .7617 L F
.52929 .75541 m .52683 .75341 L .52466 .75435 L .657 .813 .958 r
F
.53054 .75507 m .52683 .75341 L .52929 .75541 L F
.73793 .24605 m .72945 .21903 L .72949 .22747 L .977 .716 .31 r
F
0 g
.73793 .24605 m
.73875 .26517 L
s
.53321 .75489 m .53203 .75238 L .53188 .75489 L .657 .813 .958 r
F
.53321 .75489 m .53469 .75237 L .53203 .75238 L F
.57956 .21338 m .53554 .20892 L .56708 .22315 L .644 .736 .916 r
F
.52739 .76295 m .52201 .76396 L .52718 .76361 L .656 .814 .959 r
F
.54714 .75735 m .5454 .75271 L .54572 .75564 L .976 .675 .313 r
F
.54747 .76029 m .54714 .75735 L .54572 .75564 L F
0 g
.54714 .75735 m
.54753 .75927 L
s
.6996 .64141 m .70825 .64059 L .70818 .64544 L .871 .609 .54 r
F
.6996 .64141 m .69968 .63656 L .70825 .64059 L F
.71119 .63198 m .70825 .64059 L .71691 .63469 L .6 .765 .958 r
F
.71119 .63198 m .69968 .63656 L .70825 .64059 L F
0 g
.70825 .64059 m
.71329 .64197 L
s
.53503 .7595 m
.53627 .76024 L
s
.53627 .76024 m
.53627 .76024 L
s
.53054 .75507 m .52935 .75274 L .52683 .75341 L .657 .813 .958 r
F
.53188 .75489 m .52935 .75274 L .53054 .75507 L F
.63128 .2265 m .6337 .20128 L .61411 .202 L .644 .736 .916 r
F
0 g
.52856 .76014 m
.52856 .76014 L
s
.52856 .76014 m
.52988 .75943 L
s
.53188 .75489 m .53203 .75238 L .52935 .75274 L .657 .813 .958 r
F
.75273 .64323 m .76274 .63545 L .76275 .6403 L .506 .307 .545 r
F
.75272 .64809 m .75273 .64323 L .76275 .6403 L F
.7467 .63646 m .75273 .64323 L .76275 .6403 L .6 .765 .958 r
F
0 g
.74886 .64376 m
.75273 .64323 L
s
.52764 .75937 m .52322 .75842 L .52213 .75971 L .657 .813 .959 r
F
.52849 .7588 m .52322 .75842 L .52764 .75937 L F
.52296 .7555 m .51857 .75455 L .51693 .75647 L .657 .813 .958 r
F
.5188 .75747 m .51686 .75646 L .51716 .7594 L .153 .066 .496 r
F
.5188 .75747 m .5185 .75454 L .51686 .75646 L F
0 g
.51624 .75845 m
.51686 .75646 L
s
.69549 .22985 m .71384 .20234 L .68499 .21889 L .644 .736 .916 r
F
.69549 .22985 m .72945 .21903 L .71384 .20234 L F
.53739 .76227 m .54147 .76014 L .53691 .7617 L .656 .814 .959 r
F
.53739 .76227 m .54243 .76128 L .54147 .76014 L F
.52243 .76264 m .51683 .76432 L .52201 .76396 L F
.52739 .76295 m .52243 .76264 L .52201 .76396 L F
.77949 .5037 m .77853 .49804 L .76611 .4932 L .879 .585 .486 r
F
0 g
.77853 .49804 m
.78728 .50471 L
s
.53581 .7583 m .53748 .75562 L .53476 .75797 L .657 .813 .959 r
F
.53581 .7583 m .53958 .75627 L .53748 .75562 L F
.52322 .75842 m .51716 .7594 L .52213 .75971 L F
.71995 .50381 m .71642 .49276 L .69977 .49725 L .658 .806 .954 r
F
.73147 .50234 m .71642 .49276 L .71995 .50381 L F
.52243 .76264 m .51746 .76233 L .51683 .76432 L .656 .814 .959 r
F
0 g
.51683 .76432 m
.51727 .76622 L
s
.52466 .75435 m .51857 .75455 L .52296 .7555 L .657 .813 .958 r
F
.52849 .7588 m .52493 .75727 L .52322 .75842 L .657 .813 .959 r
F
.52958 .75833 m .52493 .75727 L .52849 .7588 L F
.52795 .76231 m .52243 .76264 L .52739 .76295 L .656 .814 .959 r
F
.54243 .76128 m .54604 .75857 L .54147 .76014 L F
.54243 .76128 m .54747 .76029 L .54604 .75857 L F
0 g
.53376 .75916 m
.53503 .7595 L
s
.33146 .35982 m .31803 .36415 L .31802 .37096 L .29 .134 .49 r
F
.33146 .35982 m .33145 .35298 L .31803 .36415 L F
0 g
.31018 .37683 m
.31803 .36415 L
s
.45121 .50334 m .45745 .48871 L .45794 .49439 L .11 .034 .481 r
F
.43188 .49857 m .45121 .50334 L .45794 .49439 L .66 .804 .952 r
F
.42485 .50387 m .45121 .50334 L .43188 .49857 L F
0 g
.44063 .51123 m
.45121 .50334 L
s
.73147 .50234 m .73383 .49053 L .71642 .49276 L .658 .806 .954 r
F
.7097 .51234 m .70048 .5028 L .68571 .50925 L .658 .807 .955 r
F
.72079 .50937 m .70048 .5028 L .7097 .51234 L F
0 g
.52988 .75943 m
.53119 .75912 L
s
.53476 .75797 m .53502 .75528 L .53353 .75781 L .657 .813 .959 r
F
.53476 .75797 m .53748 .75562 L .53502 .75528 L F
.54572 .75564 m .5454 .75271 L .54304 .7513 L .934 .633 .448 r
F
0 g
.5454 .75271 m
.54682 .75443 L
s
.54115 .7572 m .54336 .75424 L .53958 .75627 L .657 .813 .959 r
F
.54115 .7572 m .54572 .75564 L .54336 .75424 L F
.53922 .75336 m .53986 .75035 L .53714 .75271 L .657 .813 .958 r
F
.53922 .75336 m .54298 .75134 L .53986 .75035 L F
.53691 .7617 m .53989 .75921 L .53612 .76123 L .656 .814 .959 r
F
.53691 .7617 m .54147 .76014 L .53989 .75921 L F
.75468 .5154 m .7527 .50197 L .74454 .5137 L .657 .808 .956 r
F
.75468 .5154 m .76799 .50458 L .7527 .50197 L F
.22231 .63807 m .21096 .63228 L .20681 .63503 L .597 .767 .961 r
F
.22517 .63709 m .21096 .63228 L .22231 .63807 L F
.35341 .37177 m .33146 .35982 L .31802 .37096 L .657 .779 .939 r
F
.36546 .366 m .33146 .35982 L .35341 .37177 L F
.52958 .75833 m .52712 .75632 L .52493 .75727 L .657 .813 .959 r
F
.53085 .75799 m .52712 .75632 L .52958 .75833 L F
0 g
.53248 .75904 m
.53376 .75916 L
s
.42479 .3582 m .41781 .33778 L .41043 .35499 L .658 .778 .938 r
F
.42479 .3582 m .43951 .3427 L .41781 .33778 L F
.24317 .63931 m .24634 .63208 L .23993 .63797 L .597 .767 .961 r
F
.24317 .63931 m .25283 .63477 L .24634 .63208 L F
0 g
.53119 .75912 m
.53248 .75904 L
s
.53353 .75781 m .53234 .75529 L .53219 .75781 L .657 .813 .959 r
F
.53353 .75781 m .53502 .75528 L .53234 .75529 L F
.54747 .76029 m .54572 .75564 L .54604 .75857 L .976 .675 .313 r
F
0 g
.54747 .76029 m
.54786 .7622 L
s
.2188 .64912 m .20296 .64805 L .21762 .65078 L .595 .768 .962 r
F
.4377 .37694 m .44016 .35616 L .42531 .37167 L .656 .78 .939 r
F
.4377 .37694 m .4588 .36421 L .44016 .35616 L F
.21948 .64426 m .20597 .63984 L .20366 .64319 L .596 .768 .962 r
F
.22158 .64289 m .20597 .63984 L .21948 .64426 L F
.24626 .65248 m .25682 .64778 L .2445 .65064 L .595 .768 .962 r
F
.24626 .65248 m .26031 .65146 L .25682 .64778 L F
.53085 .75799 m .52965 .75565 L .52712 .75632 L .657 .813 .959 r
F
.53219 .75781 m .52965 .75565 L .53085 .75799 L F
.53219 .75781 m .53234 .75529 L .52965 .75565 L F
.52795 .76231 m .52353 .76136 L .52243 .76264 L .656 .814 .959 r
F
.5288 .76173 m .52353 .76136 L .52795 .76231 L F
.24515 .64578 m .25228 .63959 L .24256 .64414 L .596 .768 .962 r
F
.24515 .64578 m .25746 .6429 L .25228 .63959 L F
.20597 .63984 m .18897 .64045 L .20366 .64319 L F
.61218 .23726 m .59529 .21458 L .5792 .2218 L .644 .737 .917 r
F
.62136 .23525 m .59529 .21458 L .61218 .23726 L F
.5191 .76041 m .51716 .7594 L .51746 .76233 L .153 .066 .496 r
F
.52322 .75842 m .5188 .75747 L .51716 .7594 L .657 .813 .959 r
F
.5191 .76041 m .5188 .75747 L .51716 .7594 L .153 .066 .496 r
F
0 g
.51654 .76138 m
.51716 .7594 L
s
.64929 .2392 m .6528 .21248 L .64059 .23625 L .644 .737 .917 r
F
.64929 .2392 m .67036 .2185 L .6528 .21248 L F
.20681 .63503 m .19332 .63061 L .18991 .63564 L .597 .767 .961 r
F
.37709 .49827 m .37115 .51076 L .38184 .49989 L .66 .804 .952 r
F
.37709 .49827 m .36169 .50757 L .37115 .51076 L F
.19239 .63541 m .18969 .6356 L .18897 .64045 L 0 0 .229 r
F
0 g
.18934 .64044 m
.18939 .63984 L
s
.19239 .63541 m .19311 .63054 L .18969 .6356 L 0 0 .229 r
F
.53612 .76123 m .5378 .75855 L .53507 .76091 L .656 .814 .959 r
F
.53612 .76123 m .53989 .75921 L .5378 .75855 L F
.26094 .64659 m .26984 .64001 L .25746 .6429 L .596 .768 .962 r
F
.26094 .64659 m .27501 .64556 L .26984 .64001 L F
.47289 .37477 m .45855 .35738 L .4588 .36421 L .94 .656 .473 r
F
0 g
.47289 .37477 m
.48151 .38702 L
s
.52466 .75435 m .5211 .75282 L .51857 .75455 L .657 .813 .958 r
F
.52683 .75341 m .5211 .75282 L .52466 .75435 L F
.32755 .49626 m .33466 .49877 L .33496 .50444 L .983 .701 .398 r
F
.32755 .49626 m .32725 .49057 L .33466 .49877 L F
0 g
.33466 .49877 m
.34062 .50234 L
s
.52353 .76136 m .51746 .76233 L .52243 .76264 L .656 .814 .959 r
F
.34895 .48617 m .32758 .49051 L .33494 .49867 L .662 .803 .95 r
F
.54339 .35812 m .55111 .36382 L .55153 .37063 L .981 .7 .329 r
F
.54339 .35812 m .54298 .35127 L .55111 .36382 L F
.57221 .34613 m .55111 .36382 L .5775 .35456 L .657 .779 .939 r
F
.57221 .34613 m .54298 .35127 L .55111 .36382 L F
0 g
.55111 .36382 m
.55723 .36864 L
s
.52493 .75727 m .5188 .75747 L .52322 .75842 L .657 .813 .959 r
F
.74363 .50802 m .73476 .49606 L .73238 .5079 L .658 .807 .955 r
F
.74363 .50802 m .75178 .49626 L .73476 .49606 L F
.27501 .64556 m .27562 .64071 L .27046 .63514 L .978 .748 .52 r
F
0 g
.27562 .64071 m
.27787 .64644 L
s
.5288 .76173 m .52523 .76021 L .52353 .76136 L .656 .814 .959 r
F
.52989 .76126 m .52523 .76021 L .5288 .76173 L F
.71113 .63685 m .70818 .64544 L .71685 .63956 L .599 .766 .959 r
F
.71113 .63685 m .6996 .64141 L .70818 .64544 L F
0 g
.70818 .64544 m
.71849 .64825 L
s
.53714 .75271 m .53617 .74985 L .53469 .75237 L .657 .813 .958 r
F
.53714 .75271 m .53986 .75035 L .53617 .74985 L F
.69341 .63157 m .69975 .63171 L .69968 .63656 L .947 .681 .5 r
F
.69341 .63157 m .69349 .62671 L .69975 .63171 L F
0 g
.69975 .63171 m
.70529 .63433 L
s
.53507 .76091 m .53533 .75822 L .53384 .76074 L .656 .814 .959 r
F
.53507 .76091 m .5378 .75855 L .53533 .75822 L F
.75272 .64809 m .76275 .6403 L .76275 .64517 L .506 .307 .545 r
F
.74669 .64133 m .75272 .64809 L .76275 .64517 L .599 .766 .959 r
F
0 g
.74769 .64877 m
.75272 .64809 L
s
.70722 .62374 m .6937 .62667 L .69992 .63164 L .601 .765 .958 r
F
.54572 .75564 m .54304 .7513 L .54336 .75424 L .934 .633 .448 r
F
.54604 .75857 m .54572 .75564 L .54336 .75424 L F
0 g
.54572 .75564 m
.54714 .75735 L
s
.54147 .76014 m .54368 .75718 L .53989 .75921 L .656 .814 .959 r
F
.54147 .76014 m .54604 .75857 L .54368 .75718 L F
.53958 .75627 m .54022 .75325 L .53748 .75562 L .657 .813 .959 r
F
.53958 .75627 m .54336 .75424 L .54022 .75325 L F
.52135 .75574 m .5185 .75454 L .5188 .75747 L .374 .222 .543 r
F
.52135 .75574 m .52105 .7528 L .5185 .75454 L F
0 g
.51686 .75646 m
.5185 .75454 L
s
.76275 .6403 m .76274 .63545 L .7709 .6313 L .383 .211 .521 r
F
0 g
.75365 .63812 m
.76274 .63545 L
s
.65135 .35482 m .6707 .36682 L .68117 .35939 L .656 .78 .94 r
F
.64481 .35775 m .6707 .36682 L .65135 .35482 L F
.52989 .76126 m .52743 .75926 L .52523 .76021 L .656 .814 .959 r
F
.53116 .76093 m .52743 .75926 L .52989 .76126 L F
.22517 .63709 m .21668 .63031 L .21096 .63228 L .597 .767 .961 r
F
.22861 .63658 m .21668 .63031 L .22517 .63709 L F
.53384 .76074 m .53265 .75823 L .5325 .76075 L .656 .814 .959 r
F
.53384 .76074 m .53533 .75822 L .53265 .75823 L F
.52683 .75341 m .52437 .7514 L .5211 .75282 L .657 .813 .958 r
F
.52935 .75274 m .52437 .7514 L .52683 .75341 L F
.23993 .63797 m .23896 .63018 L .23625 .63703 L .597 .767 .961 r
F
.23993 .63797 m .24634 .63208 L .23896 .63018 L F
.77949 .5037 m .76611 .4932 L .76705 .49888 L .879 .585 .486 r
F
.78044 .50938 m .77949 .5037 L .76705 .49888 L F
0 g
.77949 .5037 m
.78824 .51036 L
s
.53116 .76093 m .52996 .75859 L .52743 .75926 L .656 .814 .959 r
F
.5325 .76075 m .52996 .75859 L .53116 .76093 L F
.5325 .76075 m .53265 .75823 L .52996 .75859 L F
.53469 .75237 m .53218 .74986 L .53203 .75238 L .657 .813 .958 r
F
.53469 .75237 m .53617 .74985 L .53218 .74986 L F
.52353 .76136 m .5191 .76041 L .51746 .76233 L .656 .814 .959 r
F
0 g
.51683 .76432 m
.51746 .76233 L
s
.54336 .75424 m .54304 .7513 L .5399 .75032 L .862 .577 .504 r
F
0 g
.54304 .7513 m
.5454 .75271 L
s
.72079 .50937 m .71723 .49829 L .70048 .5028 L .658 .807 .955 r
F
.73238 .5079 m .71723 .49829 L .72079 .50937 L F
.52935 .75274 m .52815 .75039 L .52437 .7514 L .657 .813 .958 r
F
.53203 .75238 m .52815 .75039 L .52935 .75274 L F
.52493 .75727 m .52135 .75574 L .5188 .75747 L .657 .813 .959 r
F
.52712 .75632 m .52135 .75574 L .52493 .75727 L F
.53203 .75238 m .53218 .74986 L .52815 .75039 L .657 .813 .958 r
F
.36554 .35933 m .3498 .34439 L .33178 .35316 L .658 .778 .938 r
F
.3797 .35557 m .3498 .34439 L .36554 .35933 L F
.52523 .76021 m .5191 .76041 L .52353 .76136 L .656 .814 .959 r
F
.22158 .64289 m .21015 .63709 L .20597 .63984 L .596 .768 .962 r
F
.22445 .64191 m .21015 .63709 L .22158 .64289 L F
.71055 .51803 m .70132 .50852 L .68653 .51495 L .657 .808 .956 r
F
.72166 .51506 m .70132 .50852 L .71055 .51803 L F
.40886 .49642 m .42485 .50387 L .43188 .49857 L .66 .804 .952 r
F
.40427 .49858 m .42485 .50387 L .40886 .49642 L F
.24256 .64414 m .24575 .63689 L .2393 .64279 L .596 .768 .962 r
F
.24256 .64414 m .25228 .63959 L .24575 .63689 L F
.53748 .75562 m .53651 .75275 L .53502 .75528 L .657 .813 .959 r
F
.53748 .75562 m .54022 .75325 L .53651 .75275 L F
.73238 .5079 m .73476 .49606 L .71723 .49829 L .658 .807 .955 r
F
.22861 .63658 m .22359 .62927 L .21668 .63031 L .597 .767 .961 r
F
.23239 .63655 m .22359 .62927 L .22861 .63658 L F
.2188 .64912 m .20527 .64471 L .20296 .64805 L .595 .768 .962 r
F
.22089 .64775 m .20527 .64471 L .2188 .64912 L F
.23625 .63703 m .23119 .62922 L .23239 .63655 L .597 .767 .961 r
F
.23625 .63703 m .23896 .63018 L .23119 .62922 L F
.2445 .65064 m .25164 .64447 L .24191 .649 L .595 .768 .962 r
F
.2445 .65064 m .25682 .64778 L .25164 .64447 L F
.20527 .64471 m .18825 .64531 L .20296 .64805 L F
.54604 .75857 m .54336 .75424 L .54368 .75718 L .934 .633 .448 r
F
0 g
.54604 .75857 m
.54747 .76029 L
s
.53989 .75921 m .54054 .75619 L .5378 .75855 L .656 .814 .959 r
F
.53989 .75921 m .54368 .75718 L .54054 .75619 L F
0 g
.63265 .25816 m
.634 .29456 L
s
.52166 .75868 m .5188 .75747 L .5191 .76041 L .374 .222 .543 r
F
.52166 .75868 m .52135 .75574 L .5188 .75747 L F
0 g
.51716 .7594 m
.5188 .75747 L
s
.21096 .63228 m .19332 .63061 L .20681 .63503 L .597 .767 .961 r
F
.62136 .23525 m .61383 .21045 L .59529 .21458 L .644 .737 .917 r
F
.63106 .2349 m .61383 .21045 L .62136 .23525 L F
.20597 .63984 m .19239 .63541 L .18897 .64045 L .596 .768 .962 r
F
.19167 .64028 m .18897 .64045 L .18825 .64531 L 0 0 .229 r
F
0 g
.18862 .6453 m
.18867 .6447 L
s
.19167 .64028 m .19239 .63541 L .18897 .64045 L 0 0 .229 r
F
.64059 .23625 m .63348 .20972 L .63106 .2349 L .644 .737 .917 r
F
.64059 .23625 m .6528 .21248 L .63348 .20972 L F
.26031 .65146 m .26921 .64489 L .25682 .64778 L .595 .768 .962 r
F
.26031 .65146 m .27439 .65043 L .26921 .64489 L F
.23239 .63655 m .23119 .62922 L .22359 .62927 L .597 .767 .961 r
F
0 g
.62501 .25777 m
.62628 .29442 L
s
.25797 .63807 m .26257 .6302 L .25283 .63477 L .597 .767 .961 r
F
.25797 .63807 m .27027 .63519 L .26257 .6302 L F
.33147 .36667 m .31802 .37096 L .318 .3778 L .29 .134 .49 r
F
.33147 .36667 m .33146 .35982 L .31802 .37096 L F
0 g
.31015 .38361 m
.31802 .37096 L
s
.52712 .75632 m .52464 .75431 L .52135 .75574 L .657 .813 .959 r
F
.52965 .75565 m .52464 .75431 L .52712 .75632 L F
.27501 .64556 m .27046 .63514 L .26984 .64001 L .978 .748 .52 r
F
.27439 .65043 m .27501 .64556 L .26984 .64001 L F
0 g
.27501 .64556 m
.27727 .65128 L
s
.52464 .75431 m .52105 .7528 L .52135 .75574 L .505 .315 .557 r
F
.52464 .75431 m .52434 .75137 L .52105 .7528 L F
0 g
.5185 .75454 m
.52105 .7528 L
s
.53502 .75528 m .53249 .75276 L .53234 .75529 L .657 .813 .959 r
F
.53502 .75528 m .53651 .75275 L .53249 .75276 L F
.32784 .50197 m .33496 .50444 L .33526 .51013 L .983 .701 .398 r
F
.32784 .50197 m .32755 .49626 L .33496 .50444 L F
.34906 .49191 m .33496 .50444 L .35393 .4974 L .661 .803 .951 r
F
.34906 .49191 m .32755 .49626 L .33496 .50444 L F
0 g
.33496 .50444 m
.34096 .50802 L
s
.69333 .63643 m .69968 .63656 L .6996 .64141 L .947 .681 .5 r
F
.69333 .63643 m .69341 .63157 L .69968 .63656 L F
.70702 .62863 m .69968 .63656 L .71119 .63198 L .6 .765 .958 r
F
.70702 .62863 m .69341 .63157 L .69968 .63656 L F
0 g
.69968 .63656 m
.70525 .63918 L
s
.35347 .37859 m .33147 .36667 L .318 .3778 L .656 .78 .939 r
F
0 g
.31012 .39042 m
.318 .3778 L
s
.36554 .37283 m .33147 .36667 L .35347 .37859 L .656 .78 .939 r
F
.54336 .75424 m .5399 .75032 L .54022 .75325 L .862 .577 .504 r
F
.54368 .75718 m .54336 .75424 L .54022 .75325 L F
0 g
.54336 .75424 m
.54572 .75564 L
s
.74454 .5137 m .73565 .50178 L .73326 .51358 L .657 .808 .956 r
F
.74454 .5137 m .7527 .50197 L .73565 .50178 L F
.5792 .2218 m .53506 .21733 L .56668 .23154 L .644 .737 .917 r
F
.52523 .76021 m .52166 .75868 L .5191 .76041 L .656 .814 .959 r
F
0 g
.51746 .76233 m
.5191 .76041 L
s
.52743 .75926 m .52166 .75868 L .52523 .76021 L .656 .814 .959 r
F
.42512 .36484 m .4181 .34436 L .41067 .36163 L .657 .779 .939 r
F
.42512 .36484 m .43995 .3493 L .4181 .34436 L F
.52965 .75565 m .52844 .7533 L .52464 .75431 L .657 .813 .959 r
F
.53234 .75529 m .52844 .7533 L .52965 .75565 L F
.76275 .6403 m .7709 .6313 L .77091 .63617 L .383 .211 .521 r
F
.76275 .64517 m .76275 .6403 L .77091 .63617 L F
.7534 .63449 m .76275 .6403 L .77091 .63617 L .6 .765 .958 r
F
.7467 .63646 m .76275 .6403 L .7534 .63449 L F
0 g
.7536 .64298 m
.76275 .6403 L
s
.58018 .20521 m .555 .18591 L .5365 .20077 L .645 .736 .915 r
F
.59611 .198 m .555 .18591 L .58018 .20521 L F
.63106 .2349 m .63348 .20972 L .61383 .21045 L .644 .737 .917 r
F
.53234 .75529 m .53249 .75276 L .52844 .7533 L .657 .813 .959 r
F
.54022 .75325 m .5399 .75032 L .53619 .74981 L .794 .526 .532 r
F
0 g
.5399 .75032 m
.54304 .7513 L
s
.69544 .23827 m .71384 .2108 L .68491 .22732 L .644 .737 .917 r
F
.69544 .23827 m .72949 .22747 L .71384 .2108 L F
.22445 .64191 m .21591 .63511 L .21015 .63709 L .596 .768 .962 r
F
.22791 .64139 m .21591 .63511 L .22445 .64191 L F
0 g
.634 .29456 m
.63461 .31089 L
s
.68479 .21067 m .69174 .18071 L .67039 .20187 L .645 .736 .915 r
F
.68479 .21067 m .71341 .19417 L .69174 .18071 L F
.5378 .75855 m .53683 .75569 L .53533 .75822 L .656 .814 .959 r
F
.5378 .75855 m .54054 .75619 L .53683 .75569 L F
.2393 .64279 m .23832 .63498 L .2356 .64185 L .596 .768 .962 r
F
.2393 .64279 m .24575 .63689 L .23832 .63498 L F
0 g
.62628 .29442 m
.62686 .31132 L
s
.57268 .35298 m .55153 .37063 L .57798 .36139 L .656 .78 .94 r
F
.57268 .35298 m .54339 .35812 L .55153 .37063 L F
0 g
.55153 .37063 m
.56489 .38109 L
s
.70048 .5028 m .68489 .50356 L .68571 .50925 L .512 .332 .573 r
F
.70048 .5028 m .69963 .49711 L .68489 .50356 L F
0 g
.67317 .51147 m
.68489 .50356 L
s
.78044 .50938 m .76705 .49888 L .76799 .50458 L .879 .585 .486 r
F
0 g
.78044 .50938 m
.7892 .51602 L
s
.41043 .35499 m .39446 .33639 L .39503 .35409 L .658 .778 .938 r
F
.41043 .35499 m .41781 .33778 L .39446 .33639 L F
.52743 .75926 m .52495 .75725 L .52166 .75868 L .656 .814 .959 r
F
.52996 .75859 m .52495 .75725 L .52743 .75926 L F
.60469 .35205 m .58682 .36845 L .60908 .35563 L .656 .78 .94 r
F
.60469 .35205 m .57798 .36139 L .58682 .36845 L F
.22089 .64775 m .20945 .64196 L .20527 .64471 L .595 .768 .962 r
F
.22377 .64678 m .20945 .64196 L .22089 .64775 L F
.24191 .649 m .2451 .64177 L .23864 .64766 L F
.24191 .649 m .25164 .64447 L .2451 .64177 L F
.52844 .7533 m .52434 .75137 L .52464 .75431 L .595 .38 .559 r
F
.52844 .7533 m .52813 .75036 L .52434 .75137 L F
0 g
.52105 .7528 m
.52434 .75137 L
s
.52495 .75725 m .52135 .75574 L .52166 .75868 L .505 .315 .557 r
F
0 g
.5191 .76041 m
.52166 .75868 L
s
.52495 .75725 m .52464 .75431 L .52135 .75574 L .505 .315 .557 r
F
0 g
.5188 .75747 m
.52135 .75574 L
s
.53533 .75822 m .53281 .75571 L .53265 .75823 L .656 .814 .959 r
F
.53533 .75822 m .53683 .75569 L .53281 .75571 L F
.72166 .51506 m .7181 .50401 L .70132 .50852 L .657 .808 .956 r
F
.73326 .51358 m .7181 .50401 L .72166 .51506 L F
.45745 .48871 m .45697 .48305 L .45933 .47358 L 0 0 .303 r
F
0 g
.45211 .48957 m
.45697 .48305 L
s
.22791 .64139 m .22285 .63407 L .21591 .63511 L .596 .768 .962 r
F
.23172 .64137 m .22285 .63407 L .22791 .64139 L F
.54368 .75718 m .54022 .75325 L .54054 .75619 L .862 .577 .504 r
F
0 g
.54368 .75718 m
.54604 .75857 L
s
.2356 .64185 m .2305 .63402 L .23172 .64137 L .596 .768 .962 r
F
.2356 .64185 m .23832 .63498 L .2305 .63402 L F
.53651 .75275 m .53619 .74981 L .53218 .74983 L .731 .479 .547 r
F
.54022 .75325 m .53619 .74981 L .53651 .75275 L .794 .526 .532 r
F
0 g
.53619 .74981 m
.5399 .75032 L
s
.52996 .75859 m .52875 .75624 L .52495 .75725 L .656 .814 .959 r
F
.53265 .75823 m .52875 .75624 L .52996 .75859 L F
.53265 .75823 m .53281 .75571 L .52875 .75624 L F
.21015 .63709 m .19239 .63541 L .20597 .63984 L .596 .768 .962 r
F
.73326 .51358 m .73565 .50178 L .7181 .50401 L .657 .808 .956 r
F
.20527 .64471 m .19167 .64028 L .18825 .64531 L .595 .768 .962 r
F
0 g
.18785 .65086 m
.18825 .64531 L
s
.23172 .64137 m .2305 .63402 L .22285 .63407 L .596 .768 .962 r
F
.54054 .75619 m .54022 .75325 L .53651 .75275 L .794 .526 .532 r
F
0 g
.54022 .75325 m
.54336 .75424 L
s
.25746 .6429 m .26208 .63501 L .25228 .63959 L .596 .768 .962 r
F
.25746 .6429 m .26984 .64001 L .26208 .63501 L F
.53249 .75276 m .52813 .75036 L .52844 .7533 L .667 .432 .556 r
F
.53249 .75276 m .53218 .74983 L .52813 .75036 L F
0 g
.52434 .75137 m
.52813 .75036 L
s
.27439 .65043 m .26984 .64001 L .26921 .64489 L .978 .748 .52 r
F
0 g
.27439 .65043 m
.27666 .65614 L
s
.43143 .49289 m .45745 .48871 L .43585 .48687 L .661 .803 .951 r
F
.53651 .75275 m .53218 .74983 L .53249 .75276 L .731 .479 .547 r
F
0 g
.52813 .75036 m
.53218 .74983 L
s
.53218 .74983 m
.53619 .74981 L
s
.71573 .34798 m .715 .34119 L .72036 .32724 L 0 0 .398 r
F
0 g
.70843 .34893 m
.715 .34119 L
s
.70696 .63351 m .6996 .64141 L .71113 .63685 L .599 .766 .959 r
F
.70696 .63351 m .69333 .63643 L .6996 .64141 L F
0 g
.6996 .64141 m
.70818 .64544 L
s
.3797 .35557 m .37122 .33865 L .3498 .34439 L .658 .778 .938 r
F
.39503 .35409 m .37122 .33865 L .3797 .35557 L F
.55418 .19401 m .53602 .20055 L .53554 .20892 L .271 .089 .44 r
F
.55418 .19401 m .55462 .18561 L .53602 .20055 L F
0 g
.52417 .21813 m
.53602 .20055 L
s
.3734 .49601 m .36169 .50757 L .37709 .49827 L .66 .804 .952 r
F
.3734 .49601 m .35426 .5031 L .36169 .50757 L F
.36546 .366 m .3496 .35102 L .33146 .35982 L .657 .779 .939 r
F
.37972 .36222 m .3496 .35102 L .36546 .366 L F
.6805 .35258 m .71573 .34798 L .68771 .34393 L F
.76275 .64517 m .77091 .63617 L .77093 .64104 L .383 .211 .521 r
F
.75339 .63936 m .76275 .64517 L .77093 .64104 L .599 .766 .959 r
F
.74669 .64133 m .76275 .64517 L .75339 .63936 L F
0 g
.75272 .64809 m
.76275 .64517 L
s
.34938 .49762 m .33526 .51013 L .35426 .5031 L .66 .804 .952 r
F
.34938 .49762 m .32784 .50197 L .33526 .51013 L F
0 g
.33526 .51013 m
.34645 .51676 L
s
.52875 .75624 m .52464 .75431 L .52495 .75725 L .595 .38 .559 r
F
.52875 .75624 m .52844 .7533 L .52464 .75431 L F
0 g
.52135 .75574 m
.52464 .75431 L
s
.52166 .75868 m
.52495 .75725 L
s
.22377 .64678 m .21521 .63999 L .20945 .64196 L .595 .768 .962 r
F
.22724 .64626 m .21521 .63999 L .22377 .64678 L F
.23864 .64766 m .23766 .63987 L .23494 .64672 L F
.23864 .64766 m .2451 .64177 L .23766 .63987 L F
.72945 .21903 m .72941 .21064 L .71384 .19392 L .96 .67 .441 r
F
0 g
.72941 .21064 m
.7378 .22928 L
s
.39503 .35409 m .39446 .33639 L .37122 .33865 L .658 .778 .938 r
F
.60121 .3341 m .57204 .33925 L .57729 .34766 L .657 .779 .938 r
F
.53683 .75569 m .53651 .75275 L .53249 .75276 L .731 .479 .547 r
F
.54054 .75619 m .53651 .75275 L .53683 .75569 L .794 .526 .532 r
F
0 g
.53651 .75275 m
.54022 .75325 L
s
.54054 .75619 m
.54368 .75718 L
s
.45855 .35738 m .4583 .35057 L .43973 .34247 L .87 .594 .517 r
F
0 g
.4583 .35057 m
.47234 .36118 L
s
.70132 .50852 m .68571 .50925 L .68653 .51495 L .512 .332 .573 r
F
0 g
.67476 .52283 m
.68653 .51495 L
s
.70132 .50852 m .70048 .5028 L .68571 .50925 L .512 .332 .573 r
F
0 g
.67396 .51714 m
.68571 .50925 L
s
.21096 .63228 m .19952 .62645 L .19332 .63061 L .597 .767 .961 r
F
.21668 .63031 m .19952 .62645 L .21096 .63228 L F
.53281 .75571 m .52844 .7533 L .52875 .75624 L .667 .432 .556 r
F
.53281 .75571 m .53249 .75276 L .52844 .7533 L F
0 g
.52464 .75431 m
.52844 .7533 L
s
.76705 .49888 m .76611 .4932 L .75086 .49057 L .804 .533 .529 r
F
0 g
.76611 .4932 m
.77853 .49804 L
s
.42531 .37167 m .41827 .35124 L .41083 .36846 L .656 .78 .939 r
F
.42531 .37167 m .44016 .35616 L .41827 .35124 L F
.25283 .63477 m .25281 .62613 L .24634 .63208 L .597 .767 .961 r
F
.25283 .63477 m .26257 .6302 L .25281 .62613 L F
.53683 .75569 m .53249 .75276 L .53281 .75571 L .731 .479 .547 r
F
0 g
.52844 .7533 m
.53249 .75276 L
s
.53249 .75276 m
.53651 .75275 L
s
.53683 .75569 m
.54054 .75619 L
s
.22724 .64626 m .22217 .63895 L .21521 .63999 L .595 .768 .962 r
F
.23105 .64624 m .22217 .63895 L .22724 .64626 L F
.68988 .62594 m .69349 .62671 L .69341 .63157 L .992 .743 .387 r
F
.68988 .62594 m .68997 .62107 L .69349 .62671 L F
0 g
.69349 .62671 m
.69826 .63052 L
s
.23494 .64672 m .22983 .63891 L .23105 .64624 L .595 .768 .962 r
F
.23494 .64672 m .23766 .63987 L .22983 .63891 L F
.70492 .61998 m .6937 .62667 L .70722 .62374 L .601 .765 .958 r
F
.70492 .61998 m .69019 .62105 L .6937 .62667 L F
.20945 .64196 m .19167 .64028 L .20527 .64471 L .595 .768 .962 r
F
.45745 .48871 m .45933 .47358 L .45982 .47926 L 0 0 .303 r
F
.45794 .49439 m .45745 .48871 L .45982 .47926 L F
.43585 .48687 m .45745 .48871 L .45982 .47926 L .661 .803 .951 r
F
0 g
.45256 .49525 m
.45745 .48871 L
s
.77091 .63617 m .7709 .6313 L .77665 .62621 L .183 .059 .466 r
F
0 g
.76286 .63539 m
.7709 .6313 L
s
.23105 .64624 m .22983 .63891 L .22217 .63895 L .595 .768 .962 r
F
0 g
.52495 .75725 m
.52875 .75624 L
s
.72561 .63361 m .72375 .64145 L .72907 .63457 L .599 .766 .959 r
F
.72561 .63361 m .71685 .63956 L .72375 .64145 L F
.25682 .64778 m .26145 .6399 L .25164 .64447 L .595 .768 .962 r
F
.25682 .64778 m .26921 .64489 L .26145 .6399 L F
.19863 .63124 m .19311 .63054 L .19239 .63541 L .239 .059 .424 r
F
.19863 .63124 m .19935 .62637 L .19311 .63054 L F
0 g
.18969 .6356 m
.19311 .63054 L
s
.53281 .75571 m
.53683 .75569 L
s
.26984 .64001 m .27046 .63514 L .26272 .63013 L .917 .674 .557 r
F
0 g
.27046 .63514 m
.27562 .64071 L
s
.41067 .36163 m .39459 .34297 L .39516 .36073 L .657 .779 .939 r
F
.41067 .36163 m .4181 .34436 L .39459 .34297 L F
.43188 .49857 m .45794 .49439 L .4363 .49256 L .66 .804 .952 r
F
.41237 .49375 m .43188 .49857 L .4363 .49256 L F
.40886 .49642 m .43188 .49857 L .41237 .49375 L F
0 g
.52875 .75624 m
.53281 .75571 L
s
.57956 .21338 m .55418 .19401 L .53554 .20892 L .644 .736 .916 r
F
.59562 .20615 m .55418 .19401 L .57956 .21338 L F
.68499 .21889 m .692 .18883 L .67048 .21006 L F
.68499 .21889 m .71384 .20234 L .692 .18883 L F
.71573 .34798 m .72036 .32724 L .72111 .33407 L 0 0 .398 r
F
.71646 .35479 m .71573 .34798 L .72111 .33407 L F
.68771 .34393 m .71573 .34798 L .72111 .33407 L .657 .779 .939 r
F
0 g
.70911 .35575 m
.71573 .34798 L
s
.36554 .37283 m .34965 .35789 L .33147 .36667 L .656 .78 .939 r
F
.37982 .36906 m .34965 .35789 L .36554 .37283 L F
.21015 .63709 m .19863 .63124 L .19239 .63541 L .596 .768 .962 r
F
.21591 .63511 m .19863 .63124 L .21015 .63709 L F
.37972 .36222 m .37117 .34525 L .3496 .35102 L .657 .779 .939 r
F
.39516 .36073 m .37117 .34525 L .37972 .36222 L F
.68117 .35939 m .71646 .35479 L .68839 .35076 L .656 .78 .94 r
F
.65657 .35106 m .68117 .35939 L .68839 .35076 L F
.65135 .35482 m .68117 .35939 L .65657 .35106 L F
.25228 .63959 m .25226 .63092 L .24575 .63689 L .596 .768 .962 r
F
.25228 .63959 m .26208 .63501 L .25226 .63092 L F
.68979 .63082 m .69341 .63157 L .69333 .63643 L .992 .743 .387 r
F
.68979 .63082 m .68988 .62594 L .69341 .63157 L F
.7047 .62487 m .69341 .63157 L .70702 .62863 L .6 .765 .958 r
F
.7047 .62487 m .68988 .62594 L .69341 .63157 L F
0 g
.69341 .63157 m
.69821 .63539 L
s
.72274 .63225 m .71685 .63956 L .72561 .63361 L .599 .766 .959 r
F
.72274 .63225 m .71113 .63685 L .71685 .63956 L F
.76705 .49888 m .75086 .49057 L .75178 .49626 L .804 .533 .529 r
F
.76799 .50458 m .76705 .49888 L .75178 .49626 L F
0 g
.76705 .49888 m
.77949 .5037 L
s
.74059 .6345 m .74669 .64133 L .75339 .63936 L .599 .766 .959 r
F
.60158 .34095 m .57221 .34613 L .5775 .35456 L .657 .779 .939 r
F
.77091 .63617 m .77665 .62621 L .77667 .63109 L .183 .059 .466 r
F
.77093 .64104 m .77091 .63617 L .77667 .63109 L F
.75883 .63171 m .77091 .63617 L .77667 .63109 L .6 .765 .958 r
F
.7534 .63449 m .77091 .63617 L .75883 .63171 L F
0 g
.76282 .64026 m
.77091 .63617 L
s
.19792 .63612 m .19239 .63541 L .19167 .64028 L .239 .059 .424 r
F
.19792 .63612 m .19863 .63124 L .19239 .63541 L F
0 g
.18897 .64045 m
.19239 .63541 L
s
.21668 .63031 m .20812 .62347 L .19952 .62645 L .597 .767 .961 r
F
.22359 .62927 m .20812 .62347 L .21668 .63031 L F
.39516 .36073 m .39459 .34297 L .37117 .34525 L .657 .779 .939 r
F
.45855 .35738 m .43973 .34247 L .43995 .3493 L .87 .594 .517 r
F
.4588 .36421 m .45855 .35738 L .43995 .3493 L F
0 g
.45855 .35738 m
.47261 .36796 L
s
.45794 .49439 m .45982 .47926 L .46031 .48496 L 0 0 .303 r
F
.4363 .49256 m .45794 .49439 L .46031 .48496 L .66 .804 .952 r
F
0 g
.45121 .50334 m
.45794 .49439 L
s
.24634 .63208 m .24169 .62326 L .23896 .63018 L .597 .767 .961 r
F
.24634 .63208 m .25281 .62613 L .24169 .62326 L F
.26984 .64001 m .26272 .63013 L .26208 .63501 L .917 .674 .557 r
F
.26921 .64489 m .26984 .64001 L .26208 .63501 L F
0 g
.26984 .64001 m
.27501 .64556 L
s
.71723 .49829 m .69963 .49711 L .70048 .5028 L .597 .391 .572 r
F
.71723 .49829 m .71636 .49259 L .69963 .49711 L F
0 g
.68489 .50356 m
.69963 .49711 L
s
.55375 .20245 m .53554 .20892 L .53506 .21733 L .271 .089 .44 r
F
.55375 .20245 m .55418 .19401 L .53554 .20892 L F
0 g
.52366 .22646 m
.53554 .20892 L
s
.72945 .21903 m .71384 .19392 L .71384 .20234 L .96 .67 .441 r
F
.72949 .22747 m .72945 .21903 L .71384 .20234 L F
0 g
.72945 .21903 m
.73786 .23764 L
s
.59611 .198 m .57901 .17483 L .555 .18591 L .645 .736 .915 r
F
.61446 .19386 m .57901 .17483 L .59611 .198 L F
.3496 .35102 m .33145 .35298 L .33146 .35982 L .466 .27 .529 r
F
.3496 .35102 m .34956 .34417 L .33145 .35298 L F
0 g
.31803 .36415 m
.33145 .35298 L
s
.41083 .36846 m .39472 .34986 L .39529 .36757 L .656 .78 .939 r
F
.41083 .36846 m .41827 .35124 L .39472 .34986 L F
.67039 .20187 m .66541 .17151 L .65301 .19587 L .645 .736 .915 r
F
.67039 .20187 m .69174 .18071 L .66541 .17151 L F
.20945 .64196 m .19792 .63612 L .19167 .64028 L .595 .768 .962 r
F
0 g
.18825 .64531 m
.19167 .64028 L
s
.21521 .63999 m .19792 .63612 L .20945 .64196 L .595 .768 .962 r
F
.25164 .64447 m .25162 .63582 L .2451 .64177 L F
.25164 .64447 m .26145 .6399 L .25162 .63582 L F
.70463 .62975 m .69333 .63643 L .70696 .63351 L .599 .766 .959 r
F
.70463 .62975 m .68979 .63082 L .69333 .63643 L F
0 g
.69333 .63643 m
.6996 .64141 L
s
.32446 .48709 m .32725 .49057 L .32755 .49626 L .911 .676 .174 r
F
.32446 .48709 m .32417 .48137 L .32725 .49057 L F
0 g
.32725 .49057 m
.33164 .49543 L
s
.347 .48005 m .32758 .49051 L .34895 .48617 L .662 .803 .95 r
F
.347 .48005 m .32451 .48135 L .32758 .49051 L F
.22359 .62927 m .21851 .62188 L .20812 .62347 L .597 .767 .961 r
F
.23119 .62922 m .21851 .62188 L .22359 .62927 L F
.23896 .63018 m .22997 .62181 L .23119 .62922 L F
.23896 .63018 m .24169 .62326 L .22997 .62181 L F
.77093 .64104 m .77667 .63109 L .77669 .63598 L .183 .059 .466 r
F
.75884 .63659 m .77093 .64104 L .77669 .63598 L .599 .766 .959 r
F
.75339 .63936 m .77093 .64104 L .75884 .63659 L F
0 g
.76275 .64517 m
.77093 .64104 L
s
.54073 .33746 m .54257 .34445 L .54298 .35127 L .803 .603 .043 r
F
.54073 .33746 m .54032 .3306 L .54257 .34445 L F
0 g
.54257 .34445 m
.54656 .35064 L
s
.57072 .33004 m .543 .34438 L .57204 .33925 L .657 .779 .938 r
F
.57072 .33004 m .54077 .3306 L .543 .34438 L F
.71969 .61891 m .70492 .61998 L .70722 .62374 L .601 .765 .958 r
F
.76799 .50458 m .75178 .49626 L .7527 .50197 L .804 .533 .529 r
F
0 g
.76799 .50458 m
.78044 .50938 L
s
.75178 .49626 m .75086 .49057 L .73386 .49036 L .735 .486 .551 r
F
0 g
.75086 .49057 m
.76611 .4932 L
s
.37099 .49326 m .35426 .5031 L .3734 .49601 L .66 .804 .952 r
F
.37099 .49326 m .34938 .49762 L .35426 .5031 L F
.21591 .63511 m .20728 .62825 L .19863 .63124 L .596 .768 .962 r
F
.22285 .63407 m .20728 .62825 L .21591 .63511 L F
.71646 .35479 m .72111 .33407 L .72186 .34091 L 0 0 .398 r
F
.68839 .35076 m .71646 .35479 L .72186 .34091 L .656 .78 .94 r
F
0 g
.70548 .36763 m
.71646 .35479 L
s
.43585 .48687 m .45982 .47926 L .43734 .48056 L .661 .803 .951 r
F
.24575 .63689 m .24107 .62805 L .23832 .63498 L .596 .768 .962 r
F
.24575 .63689 m .25226 .63092 L .24107 .62805 L F
.26921 .64489 m .26208 .63501 L .26145 .6399 L .917 .674 .557 r
F
0 g
.26921 .64489 m
.27439 .65043 L
s
.37982 .36906 m .37126 .35214 L .34965 .35789 L .656 .78 .939 r
F
.39529 .36757 m .37126 .35214 L .37982 .36906 L F
.72066 .63057 m .71113 .63685 L .72274 .63225 L .599 .766 .959 r
F
.72066 .63057 m .70696 .63351 L .71113 .63685 L F
.23119 .62922 m .22997 .62181 L .21851 .62188 L .597 .767 .961 r
F
.74395 .63351 m .75339 .63936 L .75884 .63659 L .599 .766 .959 r
F
.74059 .6345 m .75339 .63936 L .74395 .63351 L F
.60211 .34781 m .57798 .36139 L .60469 .35205 L .656 .78 .94 r
F
.60211 .34781 m .57268 .35298 L .57798 .36139 L F
.7181 .50401 m .70048 .5028 L .70132 .50852 L .597 .391 .572 r
F
0 g
.68653 .51495 m
.70132 .50852 L
s
.7181 .50401 m .71723 .49829 L .70048 .5028 L .597 .391 .572 r
F
0 g
.68571 .50925 m
.70048 .5028 L
s
.39529 .36757 m .39472 .34986 L .37126 .35214 L .656 .78 .939 r
F
.4588 .36421 m .43995 .3493 L .44016 .35616 L .87 .594 .517 r
F
0 g
.4588 .36421 m
.47289 .37477 L
s
.5792 .2218 m .55375 .20245 L .53506 .21733 L .644 .737 .917 r
F
0 g
.52315 .23483 m
.53506 .21733 L
s
.59529 .21458 m .55375 .20245 L .5792 .2218 L .644 .737 .917 r
F
.68491 .22732 m .69194 .19731 L .67036 .2185 L F
.68491 .22732 m .71384 .2108 L .69194 .19731 L F
.20728 .62825 m .19935 .62637 L .19863 .63124 L .454 .241 .5 r
F
.20728 .62825 m .20799 .62337 L .19935 .62637 L F
0 g
.19311 .63054 m
.19935 .62637 L
s
.26208 .63501 m .26272 .63013 L .25291 .62604 L .854 .609 .567 r
F
0 g
.26272 .63013 m
.27046 .63514 L
s
.73476 .49606 m .71636 .49259 L .71723 .49829 L .668 .44 .565 r
F
.73476 .49606 m .73386 .49036 L .71636 .49259 L F
0 g
.69963 .49711 m
.71636 .49259 L
s
.68936 .62004 m .68997 .62107 L .68988 .62594 L .801 .648 .094 r
F
.68936 .62004 m .68945 .61516 L .68997 .62107 L F
0 g
.68997 .62107 m
.69287 .62572 L
s
.70462 .61606 m .69019 .62105 L .70492 .61998 L .601 .765 .958 r
F
.70462 .61606 m .68968 .61517 L .69019 .62105 L F
.22285 .63407 m .21774 .62666 L .20728 .62825 L .596 .768 .962 r
F
.2305 .63402 m .21774 .62666 L .22285 .63407 L F
.71957 .62379 m .7047 .62487 L .70702 .62863 L .6 .765 .958 r
F
.23832 .63498 m .22928 .62659 L .2305 .63402 L .596 .768 .962 r
F
.23832 .63498 m .24107 .62805 L .22928 .62659 L F
.32475 .49282 m .32755 .49626 L .32784 .50197 L .911 .676 .174 r
F
.32475 .49282 m .32446 .48709 L .32755 .49626 L F
.34709 .48578 m .32755 .49626 L .34906 .49191 L .661 .803 .951 r
F
.34709 .48578 m .32446 .48709 L .32755 .49626 L F
0 g
.32755 .49626 m
.33197 .50114 L
s
.36946 .47876 m .347 .48005 L .34895 .48617 L .662 .803 .95 r
F
.77667 .63109 m .77665 .62621 L .77957 .62051 L 0 0 .323 r
F
0 g
.77092 .63129 m
.77665 .62621 L
s
.75883 .63171 m .77667 .63109 L .76265 .62831 L .6 .765 .958 r
F
.7625 .6234 m .77644 .62617 L .77935 .62049 L .601 .765 .958 r
F
.21521 .63999 m .20657 .63314 L .19792 .63612 L .595 .768 .962 r
F
.22217 .63895 m .20657 .63314 L .21521 .63999 L F
.75178 .49626 m .73386 .49036 L .73476 .49606 L .735 .486 .551 r
F
0 g
.71636 .49259 m
.73386 .49036 L
s
.73386 .49036 m
.75086 .49057 L
s
.34965 .35789 m .33146 .35982 L .33147 .36667 L .466 .27 .529 r
F
0 g
.318 .3778 m
.33147 .36667 L
s
.34965 .35789 m .3496 .35102 L .33146 .35982 L .466 .27 .529 r
F
0 g
.31802 .37096 m
.33146 .35982 L
s
.2451 .64177 m .2404 .63295 L .23766 .63987 L .595 .768 .962 r
F
.2451 .64177 m .25162 .63582 L .2404 .63295 L F
.7527 .50197 m .75178 .49626 L .73476 .49606 L .735 .486 .551 r
F
0 g
.75178 .49626 m
.76705 .49888 L
s
.2305 .63402 m .22928 .62659 L .21774 .62666 L .596 .768 .962 r
F
.4363 .49256 m .46031 .48496 L .43779 .48626 L .66 .804 .952 r
F
.41455 .49073 m .4363 .49256 L .43779 .48626 L F
.41237 .49375 m .4363 .49256 L .41455 .49073 L F
.68771 .34393 m .72111 .33407 L .69114 .33463 L .657 .779 .939 r
F
.54114 .34434 m .54298 .35127 L .54339 .35812 L .803 .603 .043 r
F
.54114 .34434 m .54073 .33746 L .54298 .35127 L F
.57088 .33689 m .54298 .35127 L .57221 .34613 L .657 .779 .939 r
F
.57088 .33689 m .54073 .33746 L .54298 .35127 L F
0 g
.54298 .35127 m
.547 .35749 L
s
.72949 .22747 m .71384 .20234 L .71384 .2108 L .96 .67 .441 r
F
0 g
.72949 .22747 m
.73793 .24605 L
s
.61446 .19386 m .60682 .16846 L .57901 .17483 L .645 .736 .915 r
F
.6339 .19313 m .60682 .16846 L .61446 .19386 L F
.20657 .63314 m .19863 .63124 L .19792 .63612 L .454 .241 .5 r
F
0 g
.19167 .64028 m
.19792 .63612 L
s
.20657 .63314 m .20728 .62825 L .19863 .63124 L .454 .241 .5 r
F
0 g
.19239 .63541 m
.19863 .63124 L
s
.60063 .32948 m .57204 .33925 L .60121 .3341 L .657 .779 .938 r
F
.60063 .32948 m .57072 .33004 L .57204 .33925 L F
.65301 .19587 m .63637 .16731 L .6339 .19313 L .645 .736 .915 r
F
.65301 .19587 m .66541 .17151 L .63637 .16731 L F
.43666 .47488 m .459 .47359 L .45678 .4643 L .662 .803 .95 r
F
.45982 .47926 m .45933 .47358 L .45711 .46424 L .832 .608 .058 r
F
0 g
.45789 .47937 m
.45902 .47483 L
s
.59562 .20615 m .57838 .1829 L .55418 .19401 L .644 .736 .916 r
F
.61411 .202 m .57838 .1829 L .59562 .20615 L F
.26208 .63501 m .25291 .62604 L .25226 .63092 L .854 .609 .567 r
F
.26145 .6399 m .26208 .63501 L .25226 .63092 L F
0 g
.26208 .63501 m
.26984 .64001 L
s
.67048 .21006 m .66547 .17958 L .65297 .20403 L .644 .736 .916 r
F
.67048 .21006 m .692 .18883 L .66547 .17958 L F
.68927 .62493 m .68988 .62594 L .68979 .63082 L .801 .648 .094 r
F
.68927 .62493 m .68936 .62004 L .68988 .62594 L F
.7044 .62093 m .68988 .62594 L .7047 .62487 L .6 .765 .958 r
F
.7044 .62093 m .68936 .62004 L .68988 .62594 L F
0 g
.68988 .62594 m
.6928 .6306 L
s
.22217 .63895 m .21705 .63156 L .20657 .63314 L .595 .768 .962 r
F
.22983 .63891 m .21705 .63156 L .22217 .63895 L F
.71952 .62869 m .70696 .63351 L .72066 .63057 L .599 .766 .959 r
F
.71952 .62869 m .70463 .62975 L .70696 .63351 L F
.23766 .63987 m .2286 .63149 L .22983 .63891 L .595 .768 .962 r
F
.23766 .63987 m .2404 .63295 L .2286 .63149 L F
.43995 .3493 m .43973 .34247 L .41792 .33751 L .802 .537 .538 r
F
0 g
.43973 .34247 m
.4583 .35057 L
s
.73565 .50178 m .71723 .49829 L .7181 .50401 L .668 .44 .565 r
F
0 g
.70132 .50852 m
.7181 .50401 L
s
.73565 .50178 m .73476 .49606 L .71723 .49829 L .668 .44 .565 r
F
0 g
.70048 .5028 m
.71723 .49829 L
s
.77667 .63109 m .77957 .62051 L .7796 .6254 L 0 0 .323 r
F
.77669 .63598 m .77667 .63109 L .7796 .6254 L F
.76265 .62831 m .77667 .63109 L .7796 .6254 L .6 .765 .958 r
F
0 g
.77091 .63617 m
.77667 .63109 L
s
.71956 .61695 m .70492 .61998 L .71969 .61891 L .601 .765 .958 r
F
.71956 .61695 m .70462 .61606 L .70492 .61998 L F
.75884 .63659 m .77669 .63598 L .76265 .6332 L .599 .766 .959 r
F
.74667 .63211 m .75884 .63659 L .76265 .6332 L F
.74395 .63351 m .75884 .63659 L .74667 .63211 L F
.34742 .4915 m .32784 .50197 L .34938 .49762 L .66 .804 .952 r
F
.34742 .4915 m .32475 .49282 L .32784 .50197 L F
0 g
.32784 .50197 m
.33526 .51013 L
s
.7625 .6234 m .77935 .62049 L .7644 .61961 L .601 .765 .958 r
F
.3697 .48447 m .34709 .48578 L .34906 .49191 L .661 .803 .951 r
F
.22983 .63891 m .2286 .63149 L .21705 .63156 L .595 .768 .962 r
F
.7527 .50197 m .73476 .49606 L .73565 .50178 L .735 .486 .551 r
F
0 g
.71723 .49829 m
.73476 .49606 L
s
.73476 .49606 m
.75178 .49626 L
s
.7527 .50197 m
.76799 .50458 L
s
.43666 .47488 m .45678 .4643 L .43508 .4687 L .662 .803 .95 r
F
.41429 .47617 m .43666 .47488 L .43508 .4687 L F
0 g
.73565 .50178 m
.7527 .50197 L
s
.6339 .19313 m .63637 .16731 L .60682 .16846 L .645 .736 .915 r
F
.68839 .35076 m .72186 .34091 L .69183 .34148 L .656 .78 .94 r
F
.66013 .34671 m .68839 .35076 L .69183 .34148 L F
.65657 .35106 m .68839 .35076 L .66013 .34671 L F
.21774 .62666 m .20799 .62337 L .20728 .62825 L .579 .352 .535 r
F
.21774 .62666 m .21844 .62177 L .20799 .62337 L F
0 g
.19935 .62637 m
.20799 .62337 L
s
.41429 .47617 m .43508 .4687 L .41345 .47309 L .662 .803 .95 r
F
.26145 .6399 m .25226 .63092 L .25162 .63582 L .854 .609 .567 r
F
0 g
.26145 .6399 m
.26921 .64489 L
s
.25226 .63092 m .25291 .62604 L .24173 .62316 L .794 .55 .568 r
F
0 g
.25291 .62604 m
.26272 .63013 L
s
.57135 .34376 m .54339 .35812 L .57268 .35298 L .656 .78 .94 r
F
.57135 .34376 m .54114 .34434 L .54339 .35812 L F
0 g
.54339 .35812 m
.55153 .37063 L
s
.70433 .62583 m .68979 .63082 L .70463 .62975 L .599 .766 .959 r
F
.70433 .62583 m .68927 .62493 L .68979 .63082 L F
0 g
.68979 .63082 m
.69333 .63643 L
s
.45982 .47926 m .45711 .46424 L .4576 .46994 L .832 .608 .058 r
F
.43734 .48056 m .45982 .47926 L .4576 .46994 L .661 .803 .951 r
F
.46031 .48496 m .45982 .47926 L .4576 .46994 L .832 .608 .058 r
F
0 g
.45837 .48507 m
.45951 .48051 L
s
.71944 .62183 m .7047 .62487 L .71957 .62379 L .6 .765 .958 r
F
.71944 .62183 m .7044 .62093 L .7047 .62487 L F
.77669 .63598 m .7796 .6254 L .77963 .6303 L 0 0 .323 r
F
.76265 .6332 m .77669 .63598 L .77963 .6303 L .599 .766 .959 r
F
0 g
.77093 .64104 m
.77669 .63598 L
s
.76265 .62831 m .7796 .6254 L .76456 .6245 L .6 .765 .958 r
F
0 g
.7181 .50401 m
.73565 .50178 L
s
.601 .33632 m .57221 .34613 L .60158 .34095 L .657 .779 .939 r
F
.601 .33632 m .57088 .33689 L .57221 .34613 L F
.37006 .49019 m .34938 .49762 L .37099 .49326 L .66 .804 .952 r
F
.37006 .49019 m .34742 .4915 L .34938 .49762 L F
.43734 .48056 m .4576 .46994 L .43576 .47436 L .661 .803 .951 r
F
.41482 .48186 m .43734 .48056 L .43576 .47436 L F
.37117 .34525 m .34956 .34417 L .3496 .35102 L .579 .358 .544 r
F
.37117 .34525 m .37109 .33839 L .34956 .34417 L F
0 g
.33145 .35298 m
.34956 .34417 L
s
.41455 .49073 m .43779 .48626 L .41525 .48757 L .66 .804 .952 r
F
.43995 .3493 m .41792 .33751 L .4181 .34436 L .802 .537 .538 r
F
.44016 .35616 m .43995 .3493 L .4181 .34436 L F
0 g
.43995 .3493 m
.45855 .35738 L
s
.57838 .1829 m .55462 .18561 L .55418 .19401 L .445 .226 .486 r
F
.57838 .1829 m .57875 .17448 L .55462 .18561 L F
0 g
.53602 .20055 m
.55462 .18561 L
s
.72111 .33407 m .72036 .32724 L .71965 .31318 L 0 0 .126 r
F
0 g
.71771 .33413 m
.72036 .32724 L
s
.21705 .63156 m .20728 .62825 L .20657 .63314 L .579 .352 .535 r
F
0 g
.19792 .63612 m
.20657 .63314 L
s
.21705 .63156 m .21774 .62666 L .20728 .62825 L .579 .352 .535 r
F
0 g
.19863 .63124 m
.20728 .62825 L
s
.69015 .32781 m .71991 .32725 L .7192 .31326 L .657 .779 .938 r
F
.25226 .63092 m .24173 .62316 L .24107 .62805 L .794 .55 .568 r
F
.25162 .63582 m .25226 .63092 L .24107 .62805 L F
0 g
.25226 .63092 m
.26208 .63501 L
s
.37006 .47559 m .347 .48005 L .36946 .47876 L .662 .803 .95 r
F
0 g
.73871 .70365 m
.73878 .70479 L
s
.71384 .20234 m .71384 .19392 L .69206 .18039 L .886 .596 .491 r
F
0 g
.71384 .19392 m
.72941 .21064 L
s
.59529 .21458 m .578 .19137 L .55375 .20245 L .644 .737 .917 r
F
.61383 .21045 m .578 .19137 L .59529 .21458 L F
.61411 .202 m .60641 .1765 L .57838 .1829 L .644 .736 .916 r
F
.6337 .20128 m .60641 .1765 L .61411 .202 L F
.65297 .20403 m .6362 .17536 L .6337 .20128 L F
.65297 .20403 m .66547 .17958 L .6362 .17536 L F
.41482 .48186 m .43576 .47436 L .41398 .47877 L .661 .803 .951 r
F
.67036 .2185 m .66533 .18808 L .6528 .21248 L .644 .737 .917 r
F
.67036 .2185 m .69194 .19731 L .66533 .18808 L F
.71939 .62672 m .70463 .62975 L .71952 .62869 L .599 .766 .959 r
F
.71939 .62672 m .70433 .62583 L .70463 .62975 L F
.46031 .48496 m .4576 .46994 L .45809 .47567 L .832 .608 .058 r
F
.43779 .48626 m .46031 .48496 L .45809 .47567 L .66 .804 .952 r
F
0 g
.45794 .49439 m
.46031 .48496 L
s
.22928 .62659 m .21844 .62177 L .21774 .62666 L .665 .429 .553 r
F
.22928 .62659 m .22996 .6217 L .21844 .62177 L F
0 g
.20799 .62337 m
.21844 .62177 L
s
.24107 .62805 m .24173 .62316 L .22996 .6217 L .734 .493 .563 r
F
0 g
.24173 .62316 m
.25291 .62604 L
s
.76265 .6332 m .77963 .6303 L .76456 .6294 L .599 .766 .959 r
F
.74857 .63041 m .76265 .6332 L .76456 .6294 L F
.74667 .63211 m .76265 .6332 L .74857 .63041 L F
.70636 .61224 m .68968 .61517 L .70462 .61606 L .601 .765 .958 r
F
.70636 .61224 m .69222 .60943 L .68968 .61517 L F
.69193 .61428 m .68945 .61516 L .68936 .62004 L 0 0 .267 r
F
0 g
.68979 .61907 m
.68988 .62007 L
s
.69193 .61428 m .69201 .60938 L .68945 .61516 L 0 0 .267 r
F
.72045 .61504 m .70462 .61606 L .71956 .61695 L .601 .765 .958 r
F
.72045 .61504 m .70636 .61224 L .70462 .61606 L F
.69015 .32781 m .7192 .31326 L .68951 .3185 L .657 .779 .938 r
F
.66035 .32836 m .69015 .32781 L .68951 .3185 L F
.74945 .61872 m .76427 .61567 L .74936 .61675 L .601 .765 .958 r
F
.74945 .61872 m .7644 .61961 L .76427 .61567 L F
.7644 .61961 m .77921 .61459 L .76427 .61567 L F
.7644 .61961 m .77935 .62049 L .77921 .61459 L F
.7796 .6254 m .77957 .62051 L .77944 .61457 L .723 .585 .009 r
F
0 g
.77714 .62525 m
.77953 .6206 L
s
.34811 .4737 m .32451 .48135 L .347 .48005 L .662 .803 .95 r
F
.37006 .47559 m .34811 .4737 L .347 .48005 L F
.41345 .47309 m .43053 .46307 L .41114 .4703 L F
.41345 .47309 m .43508 .4687 L .43053 .46307 L F
.24107 .62805 m .22996 .6217 L .22928 .62659 L .734 .493 .563 r
F
0 g
.22996 .6217 m
.24173 .62316 L
s
.21844 .62177 m
.22996 .6217 L
s
.43779 .48626 m .45809 .47567 L .43621 .48008 L .66 .804 .952 r
F
.41525 .48757 m .43779 .48626 L .43621 .48008 L F
.6337 .20128 m .6362 .17536 L .60641 .1765 L .644 .736 .916 r
F
.60153 .34319 m .57268 .35298 L .60211 .34781 L .656 .78 .94 r
F
.60153 .34319 m .57135 .34376 L .57268 .35298 L F
.66035 .32836 m .68951 .3185 L .65994 .32372 L .657 .779 .938 r
F
.25162 .63582 m .24107 .62805 L .2404 .63295 L .794 .55 .568 r
F
0 g
.25162 .63582 m
.26145 .6399 L
s
.34811 .4737 m .32603 .47181 L .32451 .48135 L .662 .803 .95 r
F
.32599 .47752 m .32417 .48137 L .32446 .48709 L 0 0 .199 r
F
0 g
.32498 .4838 m
.32605 .48699 L
s
.32599 .47752 m .3257 .47178 L .32417 .48137 L 0 0 .199 r
F
.37126 .35214 m .3496 .35102 L .34965 .35789 L .579 .358 .544 r
F
0 g
.33147 .36667 m
.34965 .35789 L
s
.37126 .35214 m .37117 .34525 L .3496 .35102 L .579 .358 .544 r
F
0 g
.33146 .35982 m
.3496 .35102 L
s
.4181 .34436 m .41792 .33751 L .39446 .33612 L .735 .483 .547 r
F
0 g
.41792 .33751 m
.43973 .34247 L
s
.44016 .35616 m .4181 .34436 L .41827 .35124 L .802 .537 .538 r
F
0 g
.44016 .35616 m
.4588 .36421 L
s
.37031 .48129 m .34709 .48578 L .3697 .48447 L .661 .803 .951 r
F
.2286 .63149 m .21774 .62666 L .21705 .63156 L .665 .429 .553 r
F
0 g
.20657 .63314 m
.21705 .63156 L
s
.2286 .63149 m .22928 .62659 L .21774 .62666 L .665 .429 .553 r
F
0 g
.20728 .62825 m
.21774 .62666 L
s
.2404 .63295 m .24107 .62805 L .22928 .62659 L .734 .493 .563 r
F
0 g
.24107 .62805 m
.25226 .63092 L
s
.41525 .48757 m .43621 .48008 L .41441 .48449 L .66 .804 .952 r
F
.74857 .63041 m .76456 .6294 L .7495 .62851 L .599 .766 .959 r
F
.70615 .6171 m .68936 .62004 L .7044 .62093 L .6 .765 .958 r
F
.70615 .6171 m .69193 .61428 L .68936 .62004 L F
.69184 .61919 m .68936 .62004 L .68927 .62493 L 0 0 .267 r
F
0 g
.68971 .62396 m
.6898 .62496 L
s
.69184 .61919 m .69193 .61428 L .68936 .62004 L 0 0 .267 r
F
.72111 .33407 m .71965 .31318 L .72041 .32003 L 0 0 .126 r
F
.72186 .34091 m .72111 .33407 L .72041 .32003 L F
.69114 .33463 m .72111 .33407 L .72041 .32003 L .657 .779 .939 r
F
0 g
.71844 .34098 m
.72111 .33407 L
s
.72033 .61991 m .7044 .62093 L .71944 .62183 L .6 .765 .958 r
F
.72033 .61991 m .70615 .6171 L .7044 .62093 L F
.74952 .62361 m .76442 .62056 L .74943 .62164 L F
.74952 .62361 m .76456 .6245 L .76442 .62056 L F
.76456 .6245 m .77946 .61947 L .76442 .62056 L F
.76456 .6245 m .7796 .6254 L .77946 .61947 L F
.7796 .6254 m .77944 .61457 L .77946 .61947 L .723 .585 .009 r
F
.77963 .6303 m .7796 .6254 L .77946 .61947 L F
0 g
.77715 .63015 m
.77955 .62548 L
s
.7223 .61332 m .70636 .61224 L .72045 .61504 L .601 .765 .958 r
F
.74936 .61675 m .76209 .61186 L .74826 .61486 L F
.74936 .61675 m .76427 .61567 L .76209 .61186 L F
.66013 .34671 m .69183 .34148 L .66177 .34205 L .656 .78 .94 r
F
.37216 .47254 m .34811 .4737 L .37006 .47559 L .662 .803 .95 r
F
.2404 .63295 m .22928 .62659 L .2286 .63149 L .734 .493 .563 r
F
0 g
.22928 .62659 m
.24107 .62805 L
s
.2404 .63295 m
.25162 .63582 L
s
.21774 .62666 m
.22928 .62659 L
s
.34821 .47941 m .32446 .48709 L .34709 .48578 L .661 .803 .951 r
F
.37031 .48129 m .34821 .47941 L .34709 .48578 L F
.41398 .47877 m .43118 .46872 L .41166 .47597 L F
.41398 .47877 m .43576 .47436 L .43118 .46872 L F
.43508 .4687 m .45007 .4558 L .43053 .46307 L .662 .803 .95 r
F
.43508 .4687 m .45678 .4643 L .45007 .4558 L F
.39459 .34297 m .37109 .33839 L .37117 .34525 L .664 .425 .549 r
F
.39459 .34297 m .39446 .33612 L .37109 .33839 L F
0 g
.34956 .34417 m
.37109 .33839 L
s
.7434 .6999 m
.74349 .70113 L
s
.7386 .62672 m
.74319 .69657 L
s
.6021 .3248 m .57072 .33004 L .60063 .32948 L .657 .779 .938 r
F
.69114 .33463 m .72041 .32003 L .6905 .3253 L .657 .779 .939 r
F
.66113 .33519 m .69114 .33463 L .6905 .3253 L F
0 g
.73544 .70041 m
.73548 .70102 L
s
.73526 .69746 m
.7354 .69966 L
s
.73076 .62626 m
.7352 .69653 L
s
.578 .19137 m .55418 .19401 L .55375 .20245 L .445 .226 .486 r
F
0 g
.53506 .21733 m
.55375 .20245 L
s
.578 .19137 m .57838 .1829 L .55418 .19401 L .445 .226 .486 r
F
0 g
.53554 .20892 m
.55418 .19401 L
s
.22665 .73437 m .23065 .73087 L .23072 .73383 L .665 .428 .55 r
F
.71384 .20234 m .69206 .18039 L .692 .18883 L .886 .596 .491 r
F
.71384 .2108 m .71384 .20234 L .692 .18883 L F
0 g
.71384 .20234 m
.72945 .21903 L
s
.61383 .21045 m .60611 .18499 L .578 .19137 L .644 .737 .917 r
F
.63348 .20972 m .60611 .18499 L .61383 .21045 L F
.6528 .21248 m .63598 .18385 L .63348 .20972 L F
.6528 .21248 m .66533 .18808 L .63598 .18385 L F
0 g
.21705 .63156 m
.2286 .63149 L
s
.34821 .47941 m .32599 .47752 L .32446 .48709 L .661 .803 .951 r
F
.32628 .48327 m .32446 .48709 L .32475 .49282 L 0 0 .199 r
F
0 g
.32528 .48952 m
.32636 .49273 L
s
.32628 .48327 m .32599 .47752 L .32446 .48709 L 0 0 .199 r
F
0 g
.2286 .63149 m
.2404 .63295 L
s
.41114 .4703 m .42329 .45839 L .4075 .46798 L .662 .803 .95 r
F
.41114 .4703 m .43053 .46307 L .42329 .45839 L F
.37067 .48702 m .34742 .4915 L .37006 .49019 L .66 .804 .952 r
F
.4181 .34436 m .39446 .33612 L .39459 .34297 L .735 .483 .547 r
F
0 g
.37109 .33839 m
.39446 .33612 L
s
.39446 .33612 m
.41792 .33751 L
s
.57349 .32064 m .54077 .3306 L .57072 .33004 L .657 .779 .938 r
F
.6021 .3248 m .57349 .32064 L .57072 .33004 L F
.66113 .33519 m .6905 .3253 L .66072 .33054 L .657 .779 .939 r
F
.70608 .622 m .68927 .62493 L .70433 .62583 L .599 .766 .959 r
F
.70608 .622 m .69184 .61919 L .68927 .62493 L F
0 g
.68927 .62493 m
.68979 .63082 L
s
.72028 .62481 m .70433 .62583 L .71939 .62672 L .599 .766 .959 r
F
.72028 .62481 m .70608 .622 L .70433 .62583 L F
.23444 .73279 m .23437 .72983 L .23747 .72837 L .477 .281 .535 r
F
.23072 .73383 m .23437 .72983 L .23444 .73279 L .586 .365 .547 r
F
0 g
.23172 .73057 m
.23437 .72983 L
s
.7495 .62851 m .76443 .62547 L .74942 .62654 L .599 .766 .959 r
F
.7495 .62851 m .76456 .6294 L .76443 .62547 L F
.76456 .6294 m .77949 .62439 L .76443 .62547 L F
.76456 .6294 m .77963 .6303 L .77949 .62439 L F
.77963 .6303 m .77946 .61947 L .77949 .62439 L .723 .585 .009 r
F
0 g
.77669 .63598 m
.77963 .6303 L
s
.7222 .61819 m .70615 .6171 L .72033 .61991 L .6 .765 .958 r
F
.41827 .35124 m .4181 .34436 L .39459 .34297 L .735 .483 .547 r
F
0 g
.4181 .34436 m
.43995 .3493 L
s
.7223 .61332 m .71004 .60878 L .70636 .61224 L .601 .765 .958 r
F
.725 .6119 m .71004 .60878 L .7223 .61332 L F
.74943 .62164 m .76224 .61674 L .74832 .61974 L .6 .765 .958 r
F
.74943 .62164 m .76442 .62056 L .76224 .61674 L F
.74826 .61486 m .75801 .60845 L .74621 .61316 L .601 .765 .958 r
F
.74826 .61486 m .76209 .61186 L .75801 .60845 L F
.71004 .60878 m .69222 .60943 L .70636 .61224 L F
.22672 .73733 m .22665 .73437 L .23072 .73383 L .665 .428 .55 r
F
.22255 .73734 m .22665 .73437 L .22672 .73733 L .731 .48 .548 r
F
.22255 .73734 m .22248 .73438 L .22665 .73437 L F
.22622 .73176 m .22665 .73437 L .23072 .73383 L .66 .81 .955 r
F
.22344 .73177 m .22665 .73437 L .22622 .73176 L F
.22344 .73177 m .22248 .73438 L .22665 .73437 L F
.76427 .61567 m .776 .60885 L .76209 .61186 L .601 .765 .958 r
F
.76427 .61567 m .77921 .61459 L .776 .60885 L F
.2308 .73679 m .23072 .73383 L .23444 .73279 L .586 .365 .547 r
F
.22672 .73733 m .23072 .73383 L .2308 .73679 L .665 .428 .55 r
F
.22895 .7314 m .23072 .73383 L .23444 .73279 L .66 .81 .955 r
F
.22622 .73176 m .23072 .73383 L .22895 .7314 L F
0 g
.22665 .73437 m
.23072 .73383 L
s
.57349 .32064 m .54468 .31646 L .54077 .3306 L .657 .779 .938 r
F
.37242 .47823 m .34821 .47941 L .37031 .48129 L .661 .803 .951 r
F
.54466 .32328 m .54032 .3306 L .54073 .33746 L 0 0 .291 r
F
0 g
.54117 .33586 m
.54143 .33744 L
s
.54466 .32328 m .54424 .3164 L .54032 .3306 L 0 0 .291 r
F
.215 .73283 m .21845 .73089 L .21851 .73385 L .852 .58 .527 r
F
.215 .73283 m .21494 .72987 L .21845 .73089 L F
0 g
.21845 .73089 m
.21943 .73102 L
s
.34854 .48515 m .32475 .49282 L .34742 .4915 L .66 .804 .952 r
F
.37067 .48702 m .34854 .48515 L .34742 .4915 L F
.21842 .72775 m .21499 .72984 L .21849 .73086 L .66 .81 .955 r
F
.72186 .34091 m .72041 .32003 L .72116 .32691 L 0 0 .126 r
F
.69183 .34148 m .72186 .34091 L .72116 .32691 L .656 .78 .94 r
F
0 g
.71646 .35479 m
.72186 .34091 L
s
.63348 .20972 m .63598 .18385 L .60611 .18499 L .644 .737 .917 r
F
.21857 .73682 m .22248 .73438 L .22255 .73734 L .791 .529 .541 r
F
.21857 .73682 m .21851 .73385 L .22248 .73438 L F
.22079 .73142 m .22248 .73438 L .22344 .73177 L .66 .81 .955 r
F
.22079 .73142 m .21851 .73385 L .22248 .73438 L F
0 g
.22248 .73438 m
.22665 .73437 L
s
.41441 .48449 m .43163 .47446 L .41208 .48169 L .66 .804 .952 r
F
.41441 .48449 m .43621 .48008 L .43163 .47446 L F
.43576 .47436 m .45084 .46142 L .43118 .46872 L .661 .803 .951 r
F
.43576 .47436 m .4576 .46994 L .45084 .46142 L F
.4576 .46994 m .45711 .46424 L .45036 .45569 L .981 .689 .339 r
F
0 g
.45711 .46424 m
.45933 .47358 L
s
.23754 .73133 m .23747 .72837 L .23975 .72658 L .304 .15 .501 r
F
.23444 .73279 m .23747 .72837 L .23754 .73133 L .477 .281 .535 r
F
0 g
.23437 .72983 m
.23747 .72837 L
s
.23451 .73575 m .23444 .73279 L .23754 .73133 L .477 .281 .535 r
F
.2308 .73679 m .23444 .73279 L .23451 .73575 L .586 .365 .547 r
F
.23143 .73071 m .23444 .73279 L .23754 .73133 L .66 .81 .955 r
F
.22895 .7314 m .23444 .73279 L .23143 .73071 L F
0 g
.23072 .73383 m
.23444 .73279 L
s
.23338 .72676 m .23741 .72835 L .23968 .72656 L .66 .81 .955 r
F
.23132 .72773 m .23741 .72835 L .23338 .72676 L F
.39175 .5749 m .39005 .57904 L .39399 .57901 L .599 .766 .959 r
F
.39134 .57414 m .39081 .57615 L .39175 .5749 L F
.39081 .57615 m .39005 .57904 L .39175 .5749 L F
.39232 .50181 m .39105 .57387 L .38924 .57397 L .631 .379 .518 r
F
.3962 .5005 m .39667 .49976 L .39366 .57238 L 0 0 .327 r
F
.39346 .57459 m .39399 .57901 L .39765 .57844 L .599 .766 .959 r
F
.39259 .5738 m .39329 .57639 L .39346 .57459 L F
.39329 .57639 m .39399 .57901 L .39346 .57459 L F
.39232 .50181 m .39421 .50159 L .39116 .57386 L .631 .379 .518 r
F
.39232 .50181 m .39116 .57386 L .39105 .57387 L F
.3954 .50111 m .39315 .57303 L .39238 .5735 L .286 .104 .449 r
F
.39667 .49976 m .39674 .49888 L .39374 .57161 L 0 0 .006 r
F
.39358 .57332 m .39765 .57844 L .39798 .57833 L .599 .766 .959 r
F
.3955 .57441 m .39798 .57833 L .40077 .57738 L F
.39358 .57332 m .39798 .57833 L .3955 .57441 L F
.39356 .57344 m .39765 .57844 L .39358 .57332 L F
.39238 .5735 m .39765 .57844 L .39337 .57321 L F
.3923 .57352 m .39231 .57354 L .39238 .5735 L F
.39231 .57354 m .39765 .57844 L .39238 .5735 L F
.3954 .50111 m .3962 .5005 L .39319 .573 L .286 .104 .449 r
F
.39421 .50159 m .39231 .57352 L .39116 .57386 L .484 .259 .497 r
F
.39421 .50159 m .3954 .50111 L .39238 .5735 L F
.3923 .57352 m .39118 .57386 L .39257 .57378 L .599 .766 .959 r
F
.39118 .57386 m .39399 .57901 L .39257 .57378 L F
.39231 .57352 m .39238 .5735 L .39219 .57803 L .484 .259 .497 r
F
.39421 .50159 m .39238 .5735 L .39231 .57352 L F
.3897 .57113 m .39118 .57385 L .3923 .57352 L .599 .766 .959 r
F
.39118 .57385 m .39118 .57386 L .3923 .57352 L F
.3897 .57113 m .3923 .57352 L .39337 .57321 L F
.39258 .57381 m .39399 .57901 L .39259 .5738 L F
.3954 .50111 m .39319 .573 L .39315 .57303 L .286 .104 .449 r
F
.3962 .5005 m .39364 .57241 L .39319 .573 L 0 0 .327 r
F
.39451 .57284 m .40077 .57738 L .40314 .57589 L .599 .766 .959 r
F
.3897 .57113 m .3955 .57441 L .39451 .57284 L F
.3955 .57441 m .40077 .57738 L .39451 .57284 L F
.39667 .49976 m .39374 .57161 L .39373 .57165 L 0 0 .006 r
F
.39667 .49976 m .39373 .57165 L .39366 .57238 L F
.3962 .5005 m .39366 .57238 L .39364 .57241 L 0 0 .327 r
F
.39674 .49888 m .39612 .49775 L .39309 .5706 L .99 .735 .374 r
F
.39257 .57378 m .39258 .57381 L .39259 .5738 L .599 .766 .959 r
F
.39315 .57303 m .39301 .57743 L .39238 .5735 L .286 .104 .449 r
F
.396 .57238 m .40314 .57589 L .40461 .57407 L .599 .766 .959 r
F
.3897 .57113 m .39983 .57472 L .396 .57238 L F
.39983 .57472 m .40314 .57589 L .396 .57238 L F
.39109 .57429 m .39005 .57904 L .39134 .57414 L F
.39231 .57352 m .39219 .57803 L .39116 .57386 L .484 .259 .497 r
F
.39238 .5735 m .39301 .57743 L .39219 .57803 L .286 .104 .449 r
F
.39674 .49888 m .39313 .57065 L .39374 .57161 L .99 .735 .374 r
F
.39443 .57142 m .40461 .57407 L .40506 .57205 L .599 .766 .959 r
F
.3897 .57113 m .396 .57238 L .39443 .57142 L F
.396 .57238 m .40461 .57407 L .39443 .57142 L F
.39612 .49775 m .39478 .49685 L .39172 .56976 L .912 .629 .494 r
F
.39612 .49775 m .39172 .56976 L .39179 .5698 L F
.39612 .49775 m .39179 .5698 L .39309 .5706 L F
.39674 .49888 m .39309 .5706 L .39313 .57065 L .99 .735 .374 r
F
.39478 .49685 m .39044 .56936 L .39172 .56976 L .814 .537 .519 r
F
.39139 .56966 m .40035 .56614 L .39711 .56467 L .599 .766 .959 r
F
.3897 .57113 m .39227 .56993 L .39139 .56966 L F
.39227 .56993 m .40035 .56614 L .39139 .56966 L F
.3897 .57113 m .38982 .57393 L .39118 .57386 L F
.39227 .56993 m .40286 .56794 L .40035 .56614 L F
.3897 .57113 m .39333 .57025 L .39227 .56993 L F
.39333 .57025 m .40286 .56794 L .39227 .56993 L F
.39478 .49685 m .39346 .49644 L .39037 .56934 L .814 .537 .519 r
F
.39478 .49685 m .39037 .56934 L .39044 .56936 L F
.39042 .50152 m .39232 .50181 L .38924 .57397 L .753 .483 .524 r
F
.38985 .57466 m .38608 .57854 L .39005 .57904 L .599 .766 .959 r
F
.38983 .57407 m .38946 .57451 L .38985 .57466 L F
.38946 .57451 m .38608 .57854 L .38985 .57466 L F
.38919 .50101 m .39042 .50152 L .38729 .57364 L .849 .569 .514 r
F
.38838 .57382 m .38828 .57403 L .38983 .57407 L .599 .766 .959 r
F
.38828 .57403 m .38608 .57854 L .38946 .57451 L F
.38828 .57403 m .38946 .57451 L .38983 .57407 L F
.38919 .50101 m .38721 .57361 L .38604 .57314 L .849 .569 .514 r
F
.38919 .50101 m .38729 .57364 L .38721 .57361 L F
.39042 .50152 m .38924 .57397 L .38912 .57395 L .753 .483 .524 r
F
.38835 .50037 m .38919 .50101 L .38604 .57314 L .929 .648 .486 r
F
.38753 .57557 m .38236 .57753 L .38608 .57854 L .599 .766 .959 r
F
.38804 .57452 m .3871 .57502 L .38753 .57557 L F
.3877 .49873 m .38784 .49962 L .38464 .57186 L .875 .7 .179 r
F
.38538 .57593 m .38236 .57753 L .38545 .57636 L .599 .766 .959 r
F
.38767 .57426 m .38689 .57475 L .38804 .57452 L F
.38534 .5757 m .38236 .57753 L .38538 .57593 L F
.3869 .57357 m .3868 .57366 L .38838 .57382 L F
.3868 .57366 m .38236 .57753 L .38767 .57426 L F
.3868 .57366 m .38767 .57426 L .38838 .57382 L F
.38689 .57475 m .38534 .5757 L .3871 .57502 L F
.38534 .5757 m .38538 .57593 L .3871 .57502 L F
.3871 .57502 m .38538 .57593 L .38753 .57557 L F
.38538 .57593 m .38545 .57636 L .38753 .57557 L F
.38835 .50037 m .38598 .5731 L .38517 .57254 L .929 .648 .486 r
F
.38835 .50037 m .38604 .57314 L .38598 .5731 L F
.39042 .50152 m .38912 .57395 L .38729 .57364 L .753 .483 .524 r
F
.3897 .57113 m .38249 .57451 L .38236 .57753 L .599 .766 .959 r
F
.38249 .57451 m .37913 .57609 L .38106 .57696 L F
.38249 .57451 m .38106 .57696 L .38236 .57753 L F
.3877 .49873 m .38463 .57181 L .3845 .57108 L .875 .7 .179 r
F
.38784 .49962 m .38514 .5725 L .38464 .57186 L .989 .724 .411 r
F
.3877 .49873 m .38464 .57186 L .38463 .57181 L .875 .7 .179 r
F
.38784 .49962 m .38835 .50037 L .38517 .57254 L .989 .724 .411 r
F
.38784 .49962 m .38517 .57254 L .38514 .5725 L F
.38825 .49762 m .3877 .49873 L .3845 .57108 L 0 0 .269 r
F
.3897 .57113 m .38361 .57261 L .38249 .57451 L .599 .766 .959 r
F
.37754 .57409 m .37497 .57231 L .37661 .57431 L F
.3897 .57113 m .38198 .57175 L .37754 .57409 L F
.38198 .57175 m .37497 .57231 L .37754 .57409 L F
.38517 .57254 m .38582 .57787 L .38496 .57728 L .929 .648 .486 r
F
.38236 .57753 m .38251 .58586 L .38608 .57854 L .599 .766 .959 r
F
.38236 .57753 m .37509 .58387 L .38251 .58586 L F
.37913 .57609 m .37509 .58387 L .38236 .57753 L F
.37913 .57609 m .36864 .58101 L .37509 .58387 L F
.38566 .57776 m .37604 .57928 L .37857 .58107 L .598 .766 .96 r
F
.38598 .5731 m .38583 .57788 L .38517 .57254 L .929 .648 .486 r
F
.38583 .57788 m .38582 .57787 L .38517 .57254 L F
.38464 .57186 m .38496 .57728 L .38443 .57656 L .989 .724 .411 r
F
.38486 .57715 m .38479 .57717 L .38496 .57728 L .598 .766 .96 r
F
.38496 .57728 m .38478 .57705 L .38443 .57656 L .989 .724 .411 r
F
.38445 .57541 m .38443 .57656 L .3843 .5757 L .875 .7 .179 r
F
.38825 .49762 m .38453 .57103 L .38506 .57014 L 0 0 .269 r
F
.38825 .49762 m .3845 .57108 L .38453 .57103 L F
.3897 .57113 m .38059 .57059 L .37497 .57231 L .599 .766 .959 r
F
.38059 .57059 m .37433 .57022 L .3748 .57174 L F
.38059 .57059 m .3748 .57174 L .37497 .57231 L F
.39084 .4964 m .38954 .49677 L .38636 .56945 L .545 .308 .506 r
F
.37661 .57431 m .36864 .58101 L .37913 .57609 L .599 .766 .959 r
F
.38433 .57728 m .37439 .57727 L .37604 .57928 L .598 .766 .96 r
F
.38689 .57475 m .3871 .57502 L .38804 .57452 L .599 .766 .959 r
F
.38721 .57361 m .38708 .57838 L .38604 .57314 L .849 .569 .514 r
F
.38708 .57838 m .38707 .57837 L .38604 .57314 L F
.38463 .57181 m .38443 .57656 L .3845 .57108 L .875 .7 .179 r
F
.38455 .57723 m .38267 .57662 L .38433 .57728 L .598 .766 .96 r
F
.38514 .5725 m .38496 .57728 L .38464 .57186 L .989 .724 .411 r
F
.38479 .57717 m .37604 .57928 L .38537 .5778 L .598 .766 .96 r
F
.38496 .57728 m .38537 .5778 L .38566 .57776 L F
.38479 .57717 m .38537 .5778 L .38496 .57728 L F
.38443 .5766 m .38267 .57662 L .38455 .57723 L F
.38441 .57648 m .38434 .57648 L .38443 .5766 L F
.38434 .57648 m .38267 .57662 L .38443 .5766 L F
.38608 .57854 m .3904 .58686 L .39005 .57904 L .599 .766 .959 r
F
.38608 .57854 m .38251 .58586 L .3904 .58686 L F
.38657 .57839 m .37857 .58107 L .38183 .58251 L .598 .766 .96 r
F
.38566 .57776 m .37857 .58107 L .38657 .57839 L F
.37842 .59813 m .39075 .59471 L .39027 .59962 L .734 .49 .559 r
F
.37842 .59813 m .37892 .59322 L .39075 .59471 L F
.38251 .58586 m .39074 .59459 L .3904 .58686 L .599 .766 .959 r
F
.38251 .58586 m .37897 .59311 L .39074 .59459 L F
.37793 .60305 m .39027 .59962 L .38979 .60454 L .734 .49 .559 r
F
.37793 .60305 m .37842 .59813 L .39027 .59962 L F
.38198 .59087 m .39027 .59962 L .38992 .59187 L .598 .766 .96 r
F
.38198 .59087 m .37842 .59813 L .39027 .59962 L F
.38149 .59581 m .38979 .60454 L .38944 .59681 L .598 .767 .96 r
F
.38149 .59581 m .37793 .60305 L .38979 .60454 L F
.38558 .58352 m .38198 .59087 L .38992 .59187 L .598 .766 .96 r
F
.37509 .58387 m .37897 .59311 L .38251 .58586 L .599 .766 .959 r
F
.38183 .58251 m .38198 .59087 L .38558 .58352 L .598 .766 .96 r
F
.38509 .58848 m .38149 .59581 L .38944 .59681 L .598 .767 .96 r
F
.36728 .59516 m .37892 .59322 L .37842 .59813 L .798 .548 .561 r
F
.36728 .59516 m .36779 .59024 L .37892 .59322 L F
.37509 .58387 m .36789 .59015 L .37897 .59311 L .599 .766 .959 r
F
.37452 .58887 m .37842 .59813 L .38198 .59087 L .598 .766 .96 r
F
.38183 .58251 m .37452 .58887 L .38198 .59087 L F
.38133 .58747 m .38149 .59581 L .38509 .58848 L .598 .767 .96 r
F
.38802 .57854 m .38183 .58251 L .38558 .58352 L .598 .766 .96 r
F
.38729 .57364 m .38903 .57871 L .38708 .57838 L .753 .483 .524 r
F
.38838 .57382 m .38767 .57426 L .38804 .57452 L .599 .766 .959 r
F
.38912 .57395 m .38903 .57871 L .38729 .57364 L .753 .483 .524 r
F
.38933 .57876 m .38558 .58352 L .38957 .58403 L .598 .766 .96 r
F
.38912 .57395 m .38924 .57397 L .38903 .57871 L .753 .483 .524 r
F
.38982 .57393 m .39005 .57904 L .39118 .57386 L .599 .766 .959 r
F
.38924 .57397 m .39097 .57849 L .38905 .57871 L .631 .379 .518 r
F
.38933 .57869 m .38903 .57871 L .38933 .57876 L .598 .766 .96 r
F
.38903 .57871 m .38905 .57871 L .38903 .57871 L .631 .379 .518 r
F
.38924 .57397 m .38905 .57871 L .38903 .57871 L F
.38921 .5761 m .38802 .57854 L .38903 .57871 L .598 .766 .96 r
F
.38921 .5761 m .38903 .57871 L .38933 .57869 L F
.38903 .57871 m .38558 .58352 L .38933 .57876 L F
.38558 .58352 m .38992 .59187 L .38957 .58403 L F
.38509 .58848 m .38944 .59681 L .38908 .58899 L .598 .767 .96 r
F
.3904 .58686 m .39074 .59459 L .40244 .5945 L .599 .766 .959 r
F
.3904 .58686 m .40244 .5945 L .39824 .5868 L F
.39005 .57904 m .3904 .58686 L .39824 .5868 L F
.38957 .58403 m .38992 .59187 L .39781 .5918 L .598 .766 .96 r
F
.38957 .58403 m .39781 .5918 L .39353 .58399 L F
.38905 .57871 m .39097 .57849 L .39096 .5786 L .631 .379 .518 r
F
.39005 .57904 m .39824 .5868 L .39399 .57901 L .599 .766 .959 r
F
.39063 .5787 m .38957 .58403 L .39353 .58399 L .598 .766 .96 r
F
.38921 .5761 m .38934 .57908 L .39063 .5787 L F
.38934 .57908 m .38957 .58403 L .39063 .5787 L F
.39089 .58501 m .38908 .58899 L .39306 .58895 L .598 .767 .96 r
F
.39033 .584 m .38968 .58659 L .39089 .58501 L F
.38968 .58659 m .38908 .58899 L .39089 .58501 L F
.39027 .59962 m .39075 .59471 L .40251 .59462 L .665 .428 .552 r
F
.39027 .59962 m .40251 .59462 L .40204 .59953 L F
.38979 .60454 m .39027 .59962 L .40204 .59953 L F
.38992 .59187 m .39027 .59962 L .40204 .59953 L .598 .766 .96 r
F
.38979 .60454 m .40204 .59953 L .40158 .60446 L .665 .428 .552 r
F
.38992 .59187 m .40204 .59953 L .39781 .5918 L .598 .766 .96 r
F
.38944 .59681 m .38979 .60454 L .40158 .60446 L .598 .767 .96 r
F
.38944 .59681 m .40158 .60446 L .39734 .59675 L F
.38908 .58899 m .38944 .59681 L .39734 .59675 L F
.38908 .58899 m .39734 .59675 L .39306 .58895 L F
.39399 .57901 m .39824 .5868 L .40552 .58568 L .599 .766 .959 r
F
.39218 .57882 m .39353 .58399 L .39721 .58343 L .598 .766 .96 r
F
.39132 .57995 m .39353 .58399 L .39218 .57882 L F
.39219 .57803 m .39218 .57824 L .39218 .57824 L .286 .104 .449 r
F
.39118 .57386 m .39109 .57429 L .39134 .57414 L .599 .766 .959 r
F
.39116 .57386 m .39219 .57803 L .39097 .57849 L .484 .259 .497 r
F
.39105 .57387 m .39116 .57386 L .39097 .57849 L .631 .379 .518 r
F
.39105 .57387 m .39097 .57849 L .38924 .57397 L F
.39399 .57901 m .40552 .58568 L .39765 .57844 L .599 .766 .959 r
F
.39273 .57808 m .39721 .58343 L .40035 .58236 L .598 .766 .96 r
F
.39097 .57849 m .39219 .57803 L .39218 .57824 L .484 .259 .497 r
F
.39219 .57803 m .39301 .57743 L .393 .57774 L .286 .104 .449 r
F
.39259 .57799 m .39218 .57824 L .39273 .57808 L .598 .766 .96 r
F
.3917 .57838 m .39721 .58343 L .39273 .57808 L F
.3918 .57847 m .39132 .57995 L .39218 .57882 L F
.39824 .5868 m .40244 .5945 L .41332 .59284 L .599 .766 .959 r
F
.39824 .5868 m .41332 .59284 L .40552 .58568 L F
.39353 .58399 m .39781 .5918 L .40514 .59068 L .598 .766 .96 r
F
.39765 .57844 m .40552 .58568 L .41175 .58357 L .599 .766 .959 r
F
.39318 .5775 m .40035 .58236 L .40274 .58087 L .598 .766 .96 r
F
.39301 .57743 m .393 .57774 L .393 .57774 L 0 0 .327 r
F
.38921 .5761 m .39274 .57808 L .39318 .5775 L .598 .766 .96 r
F
.39274 .57808 m .40035 .58236 L .39318 .5775 L F
.39301 .57743 m .39349 .57671 L .39347 .57712 L 0 0 .327 r
F
.39301 .57743 m .39347 .57712 L .39303 .5777 L F
.40077 .57738 m .41175 .58357 L .41651 .58061 L .599 .766 .959 r
F
.39765 .57844 m .41175 .58357 L .40077 .57738 L F
.39359 .57696 m .40274 .58087 L .40422 .57904 L .598 .766 .96 r
F
.39315 .57303 m .39319 .573 L .39301 .57743 L .286 .104 .449 r
F
.39319 .573 m .39349 .57671 L .39301 .57743 L 0 0 .327 r
F
.39347 .57712 m .40274 .58087 L .39359 .57696 L .598 .766 .96 r
F
.39318 .5775 m .39343 .57758 L .39347 .57712 L F
.39343 .57758 m .40274 .58087 L .39347 .57712 L F
.39349 .57671 m .39356 .57585 L .39354 .57636 L 0 0 .006 r
F
.39298 .58496 m .39306 .58895 L .39674 .58839 L .598 .767 .96 r
F
.39177 .58385 m .39273 .58766 L .39298 .58496 L F
.39273 .58766 m .39306 .58895 L .39298 .58496 L F
.39349 .57671 m .39354 .57636 L .39347 .57712 L 0 0 .006 r
F
.39349 .57671 m .39347 .57712 L .39347 .57712 L F
.39366 .57238 m .39356 .57585 L .39349 .57671 L F
.39364 .57241 m .39366 .57238 L .39349 .57671 L 0 0 .327 r
F
.39337 .57321 m .39356 .57344 L .39358 .57332 L .599 .766 .959 r
F
.39364 .57241 m .39349 .57671 L .39319 .573 L 0 0 .327 r
F
.40077 .57738 m .41651 .58061 L .40314 .57589 L .599 .766 .959 r
F
.39354 .57635 m .40422 .57904 L .40467 .57701 L .598 .766 .96 r
F
.38921 .5761 m .39397 .57703 L .39354 .57635 L F
.39397 .57703 m .40422 .57904 L .39354 .57635 L F
.39347 .57712 m .39354 .57636 L .39334 .58112 L 0 0 .006 r
F
.39153 .58417 m .39271 .58787 L .39177 .58385 L .598 .767 .96 r
F
.39271 .58787 m .39306 .58895 L .39273 .58766 L F
.39271 .58787 m .39273 .58766 L .39177 .58385 L F
.39033 .584 m .39267 .58826 L .39129 .58342 L F
.39267 .58826 m .39306 .58895 L .39271 .58787 L F
.39267 .58826 m .39271 .58787 L .39129 .58342 L F
.39347 .57712 m .39328 .58183 L .39347 .57712 L 0 0 .006 r
F
.39097 .57849 m .39218 .57824 L .39096 .5786 L .484 .259 .497 r
F
.39097 .57849 m .39096 .5786 L .39096 .5786 L F
.38921 .5761 m .39083 .57906 L .3918 .57847 L .598 .766 .96 r
F
.39083 .57906 m .39132 .57995 L .3918 .57847 L F
.39096 .5786 m .39218 .57824 L .39198 .583 L .484 .259 .497 r
F
.39143 .58316 m .39674 .58839 L .39775 .58804 L .598 .767 .96 r
F
.39111 .58325 m .39674 .58839 L .39143 .58316 L F
.39096 .5786 m .39198 .583 L .39084 .58333 L .484 .259 .497 r
F
.39218 .57824 m .3928 .5825 L .39203 .58297 L .286 .104 .449 r
F
.39218 .57824 m .39203 .58297 L .39198 .583 L F
.39218 .57824 m .39203 .58297 L .39218 .57824 L F
.39096 .5786 m .39084 .58334 L .39076 .58336 L .484 .259 .497 r
F
.39353 .58399 m .40514 .59068 L .39721 .58343 L .598 .766 .96 r
F
.3921 .58297 m .39775 .58804 L .39586 .58507 L .598 .767 .96 r
F
.39096 .5786 m .39084 .58333 L .39096 .5786 L .484 .259 .497 r
F
.39084 .58333 m .39084 .58334 L .39096 .5786 L F
.38903 .57871 m .38905 .57871 L .38896 .58346 L .631 .379 .518 r
F
.38903 .57871 m .38896 .58346 L .38895 .58346 L F
.38905 .57871 m .39096 .5786 L .39076 .58336 L F
.3912 .58333 m .39033 .584 L .39129 .58342 L .598 .767 .96 r
F
.39 .5834 m .39033 .584 L .3912 .58333 L F
.39009 .58356 m .38996 .58423 L .39033 .584 L F
.38996 .58423 m .38908 .58899 L .39033 .584 L F
.39 .5834 m .38997 .58359 L .39009 .58356 L F
.38997 .58359 m .38908 .58899 L .39009 .58356 L F
.38883 .58346 m .38908 .58899 L .39 .5834 L F
.38802 .57854 m .3879 .57877 L .38903 .57871 L .598 .766 .96 r
F
.3879 .57877 m .38558 .58352 L .38903 .57871 L F
.38667 .57831 m .38183 .58251 L .38802 .57854 L F
.38708 .57843 m .38903 .57871 L .38883 .58346 L .753 .483 .524 r
F
.38496 .5773 m .38583 .57793 L .38562 .58263 L .929 .648 .486 r
F
.3889 .58488 m .38509 .58848 L .38908 .58899 L .598 .767 .96 r
F
.38836 .58451 m .38509 .58848 L .3889 .58488 L F
.38857 .58381 m .38509 .58848 L .38885 .58392 L F
.38751 .58354 m .38509 .58848 L .38857 .58381 L F
.38708 .57843 m .38699 .58315 L .38688 .58313 L .753 .483 .524 r
F
.38583 .57793 m .38708 .57843 L .38688 .58313 L .849 .569 .514 r
F
.38583 .57793 m .38688 .58313 L .3857 .58266 L F
.38708 .57843 m .38883 .58346 L .38699 .58315 L .753 .483 .524 r
F
.3869 .58478 m .38133 .58747 L .38509 .58848 L .598 .767 .96 r
F
.38872 .58107 m .38591 .58351 L .3869 .58478 L F
.38249 .57451 m .37754 .57409 L .37913 .57609 L .599 .766 .959 r
F
.37754 .57409 m .37682 .57446 L .37913 .57609 L F
.37661 .57431 m .36359 .57747 L .36864 .58101 L F
.38389 .57652 m .37375 .57518 L .37439 .57727 L .598 .766 .96 r
F
.38434 .57648 m .38394 .57644 L .38389 .57652 L F
.38394 .57644 m .37375 .57518 L .38389 .57652 L F
.38486 .57461 m .3843 .5757 L .38429 .57583 L 0 0 .269 r
F
.3843 .5757 m .38443 .57656 L .38443 .5766 L .875 .7 .179 r
F
.38379 .57578 m .37375 .57518 L .38434 .57648 L .598 .766 .96 r
F
.38267 .57662 m .37439 .57727 L .38433 .57728 L F
.3843 .57585 m .38443 .5766 L .38422 .58136 L .875 .7 .179 r
F
.3843 .5757 m .38443 .5766 L .3843 .57585 L F
.38441 .57648 m .38379 .57578 L .38434 .57648 L .598 .766 .96 r
F
.38496 .57728 m .38496 .57728 L .38464 .57186 L .989 .724 .411 r
F
.38463 .57181 m .38464 .57186 L .38443 .57656 L .875 .7 .179 r
F
.38514 .5725 m .38517 .57254 L .38496 .5773 L .989 .724 .411 r
F
.38598 .5731 m .38604 .57314 L .38583 .57793 L .929 .648 .486 r
F
.38604 .57314 m .38707 .57837 L .38583 .57788 L .849 .569 .514 r
F
.38721 .57361 m .38729 .57364 L .38708 .57838 L F
.38721 .57361 m .38708 .57838 L .38708 .57838 L F
.38921 .5761 m .38566 .57776 L .38583 .57788 L .598 .766 .96 r
F
.38674 .57824 m .38583 .57788 L .38657 .57839 L F
.38921 .5761 m .38583 .57788 L .38674 .57824 L F
.38708 .57838 m .38708 .57838 L .38708 .57843 L .849 .569 .514 r
F
.38583 .57788 m .38708 .57843 L .38583 .57793 L F
.38674 .57824 m .38667 .57831 L .38708 .57838 L .598 .766 .96 r
F
.38707 .57837 m .38708 .57843 L .38583 .57788 L .849 .569 .514 r
F
.38921 .5761 m .38674 .57824 L .38802 .57854 L .598 .766 .96 r
F
.38674 .57824 m .38708 .57838 L .38802 .57854 L F
.38429 .57581 m .38379 .57578 L .38441 .57648 L F
.38479 .58448 m .38133 .58747 L .38501 .5857 L .598 .767 .96 r
F
.38479 .58448 m .37807 .58603 L .38133 .58747 L F
.38453 .58303 m .37807 .58603 L .38479 .58448 L F
.37857 .58107 m .37452 .58887 L .38183 .58251 L .598 .766 .96 r
F
.36864 .58101 m .36789 .59015 L .37509 .58387 L .599 .766 .959 r
F
.36864 .58101 m .35824 .58589 L .36789 .59015 L F
.37857 .58107 m .36802 .586 L .37452 .58887 L .598 .766 .96 r
F
.38193 .58424 m .37553 .58425 L .37807 .58603 L .598 .767 .96 r
F
.38583 .57793 m .3857 .58266 L .38562 .58263 L .849 .569 .514 r
F
.38496 .5773 m .38562 .58263 L .3848 .58208 L .929 .648 .486 r
F
.38443 .5766 m .38425 .5814 L .38443 .5766 L .989 .724 .411 r
F
.38526 .58269 m .38298 .58246 L .38193 .58424 L .598 .767 .96 r
F
.38475 .58204 m .38298 .58246 L .38526 .58269 L F
.38475 .58203 m .38474 .58203 L .38475 .58204 L F
.38474 .58203 m .38298 .58246 L .38475 .58204 L F
.38591 .58351 m .38453 .58303 L .38479 .58448 L F
.38872 .58107 m .38526 .58269 L .38591 .58351 L F
.38526 .58269 m .38453 .58303 L .38591 .58351 L F
.38443 .5766 m .38496 .5773 L .38475 .58204 L .989 .724 .411 r
F
.38443 .5766 m .38475 .58204 L .38425 .5814 L F
.38496 .5773 m .3848 .58208 L .38475 .58204 L .929 .648 .486 r
F
.37604 .57928 m .36802 .586 L .37857 .58107 L .598 .766 .96 r
F
.37606 .58412 m .37388 .58225 L .37553 .58425 L .598 .767 .96 r
F
.38872 .58107 m .38355 .58148 L .38298 .58246 L F
.38425 .5814 m .38425 .5814 L .38443 .5766 L .989 .724 .411 r
F
.38429 .57583 m .38422 .58136 L .38409 .58064 L .875 .7 .179 r
F
.3843 .5757 m .3843 .57585 L .38429 .57583 L F
.3843 .57585 m .38422 .58136 L .38429 .57583 L F
.38361 .57261 m .37754 .57409 L .38249 .57451 L .599 .766 .959 r
F
.37754 .57409 m .37661 .57431 L .37682 .57446 L F
.37497 .57231 m .36359 .57747 L .37661 .57431 L F
.38429 .57581 m .37416 .57314 L .37375 .57518 L .598 .766 .96 r
F
.38486 .57461 m .38429 .57583 L .38485 .57489 L 0 0 .269 r
F
.3845 .57108 m .38446 .57451 L .3843 .5757 L .875 .7 .179 r
F
.38059 .57059 m .37474 .56819 L .37433 .57022 L .599 .766 .959 r
F
.3897 .57113 m .38376 .56997 L .38059 .57059 L F
.38376 .56997 m .37474 .56819 L .38059 .57059 L F
.3897 .57113 m .3869 .57357 L .38838 .57382 L F
.38954 .49677 m .38513 .5701 L .38636 .56945 L .339 .143 .462 r
F
.38954 .49677 m .38825 .49762 L .38506 .57014 L F
.38954 .49677 m .38506 .57014 L .38513 .5701 L F
.39214 .4963 m .39084 .4964 L .38769 .56919 L .652 .396 .519 r
F
.3897 .57113 m .38437 .56925 L .3805 .56933 L .599 .766 .959 r
F
.39084 .4964 m .38643 .56944 L .38769 .56919 L .545 .308 .506 r
F
.39084 .4964 m .38636 .56945 L .38643 .56944 L F
.38113 .56811 m .37854 .56484 L .37618 .56636 L .599 .766 .959 r
F
.3897 .57113 m .38629 .56921 L .38437 .56925 L F
.3897 .57113 m .38838 .57382 L .38983 .57407 L F
.3897 .57113 m .38167 .56376 L .37854 .56484 L F
.39214 .4963 m .38776 .56919 L .38902 .56916 L .652 .396 .519 r
F
.39214 .4963 m .38769 .56919 L .38776 .56919 L F
.3897 .57113 m .38536 .56318 L .38167 .56376 L .599 .766 .959 r
F
.39346 .49644 m .39214 .4963 L .38902 .56916 L .735 .467 .523 r
F
.39346 .49644 m .38902 .56916 L .38909 .56917 L F
.39346 .49644 m .38909 .56917 L .39037 .56934 L F
.3897 .57113 m .38934 .56314 L .38536 .56318 L .599 .766 .959 r
F
.38902 .56916 m .3875 .57341 L .38884 .57332 L .652 .396 .519 r
F
.38776 .56919 m .3875 .57341 L .38902 .56916 L F
.38437 .56925 m .38532 .56867 L .38113 .56811 L .599 .766 .959 r
F
.38629 .56921 m .38532 .56867 L .38437 .56925 L F
.38532 .56867 m .37854 .56484 L .38113 .56811 L F
.38909 .56917 m .38902 .56916 L .38884 .57332 L .735 .467 .523 r
F
.38776 .56919 m .38769 .56919 L .3875 .57341 L .652 .396 .519 r
F
.3805 .56933 m .38113 .56811 L .37474 .56819 L .599 .766 .959 r
F
.38437 .56925 m .38113 .56811 L .3805 .56933 L F
.38113 .56811 m .37618 .56636 L .37541 .56734 L F
.38113 .56811 m .37541 .56734 L .37474 .56819 L F
.38961 .56924 m .39335 .56365 L .38934 .56314 L F
.3897 .57113 m .39056 .56937 L .38961 .56924 L F
.39056 .56937 m .39335 .56365 L .38961 .56924 L F
.3897 .57113 m .39711 .56467 L .39335 .56365 L F
.3897 .57113 m .40447 .56995 L .40286 .56794 L F
.3897 .57113 m .40506 .57205 L .40447 .56995 L F
.39037 .56934 m .38884 .57332 L .39019 .57346 L .735 .467 .523 r
F
.38909 .56917 m .38884 .57332 L .39037 .56934 L F
.38769 .56919 m .38617 .57377 L .3875 .57341 L .545 .308 .506 r
F
.38643 .56944 m .38617 .57377 L .38769 .56919 L F
.38506 .57014 m .3843 .5757 L .38486 .57461 L 0 0 .269 r
F
.38453 .57103 m .3843 .5757 L .38506 .57014 L F
.38453 .57103 m .3845 .57108 L .3843 .5757 L F
.38921 .5761 m .38416 .57511 L .38429 .57581 L .598 .766 .96 r
F
.38416 .57511 m .37416 .57314 L .38429 .57581 L F
.38443 .5766 m .38425 .5814 L .38422 .58136 L .989 .724 .411 r
F
.36359 .57747 m .35824 .58589 L .36864 .58101 L .599 .766 .959 r
F
.37604 .57928 m .36294 .58245 L .36802 .586 L .598 .766 .96 r
F
.38068 .58171 m .37324 .58016 L .37388 .58225 L .598 .767 .96 r
F
.38872 .58107 m .38259 .58071 L .38068 .58171 L F
.38259 .58071 m .37324 .58016 L .38068 .58171 L F
.38234 .65544 m .38149 .65629 L .38238 .6585 L .659 .811 .956 r
F
.38149 .65629 m .3797 .6581 L .38188 .65842 L F
.38149 .65629 m .38188 .65842 L .38238 .6585 L F
.38117 .65506 m .3797 .6581 L .38149 .65629 L F
.38127 .65509 m .38149 .65629 L .38234 .65544 L F
.38117 .65506 m .38149 .65629 L .38127 .65509 L F
.3843 .5757 m .38409 .58064 L .38408 .58059 L .875 .7 .179 r
F
.38921 .5761 m .38429 .57581 L .38441 .57648 L .598 .766 .96 r
F
.38443 .57656 m .38443 .5766 L .38443 .5766 L .989 .724 .411 r
F
.38443 .57656 m .38478 .57705 L .38443 .5766 L F
.38921 .5761 m .38441 .57648 L .38455 .57723 L .598 .766 .96 r
F
.38478 .57705 m .38496 .5773 L .38443 .5766 L .989 .724 .411 r
F
.37497 .57231 m .36029 .57348 L .36359 .57747 L .599 .766 .959 r
F
.37433 .57022 m .36029 .57348 L .37497 .57231 L F
.38435 .57514 m .3756 .5713 L .37416 .57314 L .598 .766 .96 r
F
.38921 .5761 m .38485 .57488 L .38466 .5752 L F
.38485 .57488 m .3846 .57971 L .38464 .57965 L 0 0 .269 r
F
.38486 .57461 m .38485 .57489 L .38485 .57488 L F
.38485 .57489 m .3846 .57971 L .38485 .57488 L F
.38921 .5761 m .38522 .57469 L .38485 .57488 L .598 .766 .96 r
F
.38466 .5752 m .38485 .57488 L .38435 .57514 L F
.38496 .57728 m .38496 .5773 L .38496 .57728 L .989 .724 .411 r
F
.38496 .57728 m .38496 .5773 L .38478 .57705 L F
.38921 .5761 m .38486 .57715 L .38566 .57776 L .598 .766 .96 r
F
.38486 .57715 m .38496 .57728 L .38566 .57776 L F
.38496 .57728 m .38583 .57793 L .38496 .5773 L .929 .648 .486 r
F
.38582 .57787 m .38583 .57793 L .38496 .57728 L F
.38617 .57377 m .38486 .57461 L .38485 .57488 L .339 .143 .462 r
F
.38921 .5761 m .38599 .57429 L .38522 .57469 L .598 .766 .96 r
F
.38617 .57377 m .38485 .57488 L .38605 .57426 L .339 .143 .462 r
F
.38617 .57377 m .38615 .5742 L .38615 .5742 L F
.38636 .56945 m .38486 .57461 L .38617 .57377 L F
.38513 .5701 m .38486 .57461 L .38636 .56945 L F
.38513 .5701 m .38506 .57014 L .38486 .57461 L F
.38599 .57429 m .38113 .5687 L .37798 .56979 L .598 .766 .96 r
F
.3875 .57341 m .38617 .57377 L .38615 .5742 L .545 .308 .506 r
F
.38921 .5761 m .38696 .57404 L .38599 .57429 L .598 .766 .96 r
F
.38696 .57404 m .38615 .5742 L .38599 .57429 L F
.37439 .57727 m .36294 .58245 L .37604 .57928 L F
.37834 .58046 m .37365 .57812 L .37324 .58016 L .598 .767 .96 r
F
.38485 .57489 m .38429 .57583 L .38408 .58059 L 0 0 .269 r
F
.38396 .58079 m .38195 .57975 L .37834 .58046 L .598 .767 .96 r
F
.38872 .58107 m .3843 .58021 L .38396 .58079 L F
.38485 .57489 m .38408 .58059 L .3846 .57971 L 0 0 .269 r
F
.3843 .58021 m .38195 .57975 L .38396 .58079 L .598 .767 .96 r
F
.38195 .57975 m .37365 .57812 L .37834 .58046 L F
.3875 .57341 m .38615 .5742 L .38747 .57394 L .545 .308 .506 r
F
.38643 .56944 m .38636 .56945 L .38617 .57377 L F
.38648 .5736 m .38484 .56812 L .38113 .5687 L .598 .766 .96 r
F
.38921 .5761 m .38802 .57393 L .38696 .57404 L F
.38884 .57332 m .38748 .57394 L .38881 .57391 L .652 .396 .519 r
F
.38802 .57393 m .38797 .57384 L .38748 .57394 L .598 .766 .96 r
F
.38802 .57393 m .38748 .57394 L .38696 .57404 L F
.38884 .57332 m .3875 .57341 L .38748 .57394 L .652 .396 .519 r
F
.38872 .58107 m .38475 .58203 L .38526 .58269 L .598 .767 .96 r
F
.38785 .58352 m .38857 .58381 L .38883 .58346 L F
.38751 .58354 m .38857 .58381 L .38785 .58352 L F
.38591 .58351 m .38479 .58448 L .3869 .58478 L F
.38479 .58448 m .38501 .5857 L .3869 .58478 L F
.38524 .65851 m .38537 .66136 L .38962 .66079 L .659 .811 .956 r
F
.38238 .6585 m .38537 .66136 L .38524 .65851 L F
.38524 .65851 m .38962 .66079 L .38808 .65813 L F
.38547 .65595 m .38524 .65851 L .38808 .65813 L F
.38511 .65564 m .38513 .65609 L .38547 .65595 L F
.38513 .65609 m .38524 .65851 L .38547 .65595 L F
.38808 .65813 m .38962 .66079 L .39356 .65968 L F
.38808 .65813 m .39356 .65968 L .39071 .65738 L F
.39009 .65563 m .39071 .65738 L .39295 .65633 L F
.39143 .58316 m .39775 .58804 L .3921 .58297 L .598 .767 .96 r
F
.38903 .57871 m .38895 .58346 L .38883 .58346 L .631 .379 .518 r
F
.38905 .57871 m .39076 .58336 L .38896 .58346 L F
.40552 .58568 m .41332 .59284 L .42265 .58971 L .599 .766 .959 r
F
.39721 .58343 m .40514 .59068 L .41141 .58857 L .598 .766 .96 r
F
.39464 .58315 m .39988 .58732 L .40227 .58583 L .598 .767 .96 r
F
.38872 .58107 m .39586 .58507 L .39464 .58315 L F
.39586 .58507 m .39988 .58732 L .39464 .58315 L F
.39328 .58183 m .39328 .58184 L .39347 .57712 L 0 0 .006 r
F
.39356 .57585 m .39354 .57635 L .39354 .57636 L .99 .735 .374 r
F
.39373 .57165 m .39374 .57161 L .39356 .57585 L 0 0 .006 r
F
.40314 .57589 m .41651 .58061 L .41947 .57699 L .599 .766 .959 r
F
.40314 .57589 m .41947 .57699 L .40461 .57407 L F
.3936 .57575 m .40467 .57701 L .40407 .57492 L .598 .766 .96 r
F
.39373 .57165 m .39356 .57585 L .39366 .57238 L 0 0 .006 r
F
.39374 .57161 m .39292 .57473 L .39356 .57585 L .99 .735 .374 r
F
.39356 .57585 m .39292 .57473 L .3929 .57534 L F
.38921 .5761 m .39354 .57635 L .39317 .57578 L .598 .766 .96 r
F
.41175 .58357 m .42265 .58971 L .42981 .58531 L .599 .766 .959 r
F
.40552 .58568 m .42265 .58971 L .41175 .58357 L F
.40035 .58236 m .41141 .58857 L .4162 .58561 L .598 .766 .96 r
F
.39721 .58343 m .41141 .58857 L .40035 .58236 L F
.39397 .5821 m .40227 .58583 L .40375 .58402 L .598 .767 .96 r
F
.393 .57774 m .39327 .58188 L .39283 .58246 L 0 0 .327 r
F
.39218 .57824 m .393 .57774 L .3928 .5825 L .286 .104 .449 r
F
.393 .57774 m .39283 .58246 L .3928 .5825 L 0 0 .327 r
F
.393 .57774 m .39283 .58246 L .393 .57774 L F
.38872 .58107 m .39464 .58315 L .39397 .5821 L .598 .767 .96 r
F
.39464 .58315 m .40227 .58583 L .39397 .5821 L F
.38921 .5761 m .39318 .5775 L .39347 .57712 L .598 .766 .96 r
F
.38921 .5761 m .39347 .57712 L .39349 .57694 L F
.39301 .57743 m .39303 .5777 L .393 .57774 L 0 0 .327 r
F
.39303 .5777 m .39327 .58188 L .393 .57774 L F
.39303 .5777 m .39347 .57712 L .39327 .58188 L F
.39219 .57803 m .393 .57774 L .39218 .57824 L .286 .104 .449 r
F
.39356 .57585 m .3929 .57534 L .39354 .57635 L .99 .735 .374 r
F
.38921 .5761 m .39356 .57575 L .39273 .57525 L .598 .766 .96 r
F
.39203 .58297 m .39245 .58272 L .3916 .59687 L .286 .104 .449 r
F
.39245 .58272 m .3928 .5825 L .3916 .59687 L F
.3916 .59687 m .3928 .5825 L .38984 .65385 L F
.39203 .58297 m .38984 .65385 L .38979 .65389 L F
.38872 .58107 m .39 .5834 L .3912 .58333 L .598 .767 .96 r
F
.39084 .58333 m .38893 .6545 L .39084 .58334 L .484 .259 .497 r
F
.38893 .6545 m .38893 .6545 L .39084 .58334 L F
.39076 .58336 m .38893 .6545 L .38774 .655 L F
.38872 .58107 m .39143 .58316 L .3921 .58297 L .598 .767 .96 r
F
.38883 .65532 m .38999 .6568 L .39009 .65563 L .659 .811 .956 r
F
.38809 .65514 m .38863 .65561 L .38883 .65532 L F
.38863 .65561 m .38999 .6568 L .38883 .65532 L F
.388 .65521 m .38999 .6568 L .38809 .65514 L F
.38715 .65584 m .38808 .65813 L .38991 .65761 L F
.38659 .65548 m .38689 .65602 L .38715 .65584 L F
.38689 .65602 m .38808 .65813 L .38715 .65584 L F
.38723 .65578 m .38991 .65761 L .38996 .65704 L F
.38659 .65548 m .38715 .65584 L .38723 .65578 L F
.38715 .65584 m .38991 .65761 L .38723 .65578 L F
.39203 .58297 m .38979 .65389 L .39198 .583 L .286 .104 .449 r
F
.39129 .58342 m .39153 .58417 L .39177 .58385 L .598 .767 .96 r
F
.39084 .58333 m .39198 .583 L .389 .65447 L .484 .259 .497 r
F
.38689 .65535 m .38829 .6561 L .38785 .65508 L .659 .811 .956 r
F
.38829 .6561 m .39071 .65738 L .38858 .65567 L F
.38829 .6561 m .38858 .65567 L .38785 .65508 L F
.40035 .58236 m .4162 .58561 L .40274 .58087 L .598 .766 .96 r
F
.39489 .58144 m .40375 .58402 L .4042 .58199 L .598 .767 .96 r
F
.39347 .57712 m .39328 .58184 L .39327 .58188 L 0 0 .006 r
F
.39347 .57712 m .39334 .58112 L .39328 .58183 L F
.38872 .58107 m .39693 .58268 L .39489 .58144 L .598 .767 .96 r
F
.39693 .58268 m .40375 .58402 L .39489 .58144 L F
.38921 .5761 m .3917 .57838 L .39218 .57824 L .598 .766 .96 r
F
.38921 .5761 m .39218 .57824 L .39259 .57799 L F
.39172 .56976 m .39019 .57346 L .39155 .57386 L .814 .537 .519 r
F
.39179 .5698 m .39172 .56976 L .39155 .57386 L .912 .629 .494 r
F
.39309 .5706 m .39155 .57386 L .39292 .57473 L F
.39179 .5698 m .39155 .57386 L .39309 .5706 L F
.39313 .57065 m .39309 .5706 L .39292 .57473 L .99 .735 .374 r
F
.39313 .57065 m .39292 .57473 L .39374 .57161 L F
.39155 .57386 m .39019 .57346 L .39017 .57409 L .814 .537 .519 r
F
.38921 .5761 m .39117 .5744 L .39019 .5741 L .598 .766 .96 r
F
.39084 .58333 m .389 .65447 L .38893 .6545 L .484 .259 .497 r
F
.38653 .65545 m .38659 .65548 L .38689 .65535 L .659 .811 .956 r
F
.38659 .65548 m .3882 .65623 L .38689 .65535 L F
.3882 .65623 m .39071 .65738 L .38829 .6561 L F
.3882 .65623 m .38829 .6561 L .38689 .65535 L F
.39283 .58246 m .3903 .65319 L .3928 .5825 L 0 0 .327 r
F
.39328 .58184 m .39039 .65239 L .39327 .58188 L 0 0 .006 r
F
.39015 .65504 m .39295 .65633 L .39305 .65625 L .659 .811 .956 r
F
.39015 .65508 m .39295 .65633 L .39015 .65504 L F
.41175 .58357 m .42981 .58531 L .41651 .58061 L .599 .766 .959 r
F
.40274 .58087 m .4162 .58561 L .41918 .58198 L .598 .766 .96 r
F
.40274 .58087 m .41918 .58198 L .40422 .57904 L F
.39548 .58054 m .4042 .58199 L .4036 .5799 L .598 .767 .96 r
F
.39354 .57635 m .3927 .58011 L .3933 .58105 L .99 .735 .374 r
F
.39354 .57635 m .3933 .58105 L .39354 .57636 L F
.3933 .58105 m .3933 .58106 L .39354 .57636 L F
.39354 .57636 m .3933 .58106 L .39334 .58112 L F
.38872 .58107 m .39489 .58144 L .39365 .58069 L .598 .767 .96 r
F
.38897 .65455 m .39015 .65504 L .39018 .65465 L .659 .811 .956 r
F
.38897 .65455 m .39015 .65508 L .39015 .65504 L F
.38785 .65508 m .39295 .65633 L .38897 .65455 L F
.38807 .65813 m .39095 .66045 L .3932 .65938 L F
.38789 .65819 m .39095 .66045 L .38807 .65813 L F
.38675 .65851 m .38718 .65871 L .38789 .65819 L F
.38718 .65871 m .39095 .66045 L .38789 .65819 L F
.38919 .65761 m .3932 .65938 L .3892 .6576 L F
.38807 .65813 m .38871 .65829 L .38919 .65761 L F
.38871 .65829 m .3932 .65938 L .38919 .65761 L F
.39071 .65738 m .39356 .65968 L .39692 .6581 L F
.3892 .6576 m .3932 .65938 L .39492 .65808 L F
.38999 .6568 m .39071 .65738 L .39009 .65563 L F
.3892 .6576 m .39006 .65767 L .39006 .65695 L F
.38996 .65704 m .38991 .65761 L .39071 .65738 L F
.39071 .65738 m .39692 .6581 L .39295 .65633 L F
.39006 .65767 m .39492 .65808 L .39012 .65696 L F
.39006 .65767 m .39012 .65696 L .39006 .65695 L F
.39295 .65633 m .39692 .6581 L .39948 .65615 L F
.39006 .65695 m .39597 .65662 L .39058 .65622 L F
.38897 .65455 m .39207 .65481 L .38982 .6539 L F
.39207 .65481 m .39466 .65503 L .39176 .65435 L F
.39207 .65481 m .39176 .65435 L .38982 .6539 L F
.3903 .65319 m .3903 .65319 L .3928 .5825 L 0 0 .327 r
F
.39283 .58246 m .39327 .58188 L .39032 .65315 L F
.39283 .58246 m .39032 .65315 L .3903 .65319 L F
.38979 .65389 m .38979 .65389 L .39198 .583 L .286 .104 .449 r
F
.39198 .583 m .38979 .65389 L .389 .65447 L F
.3928 .5825 m .3903 .65319 L .38984 .65385 L 0 0 .327 r
F
.3933 .58105 m .38977 .65142 L .3933 .58106 L .99 .735 .374 r
F
.39057 .65622 m .39006 .65695 L .39058 .65622 L .659 .811 .956 r
F
.38979 .65389 m .3897 .65686 L .389 .65447 L .286 .104 .449 r
F
.3897 .65686 m .38944 .65704 L .389 .65447 L F
.38984 .65385 m .39004 .65637 L .38971 .65684 L 0 0 .327 r
F
.389 .65447 m .38944 .65704 L .38887 .65746 L .286 .104 .449 r
F
.38511 .65564 m .38808 .65813 L .38653 .65545 L .659 .811 .956 r
F
.38558 .66443 m .38537 .6614 L .38964 .66083 L .662 .418 .541 r
F
.38532 .6587 m .38545 .66157 L .3883 .66119 L .659 .811 .956 r
F
.38675 .65851 m .3883 .66119 L .39095 .66045 L F
.38532 .6587 m .3883 .66119 L .38675 .65851 L F
.38885 .58392 m .38836 .58451 L .3889 .58488 L .598 .767 .96 r
F
.38883 .58346 m .38857 .58381 L .38885 .58392 L F
.38883 .58346 m .38763 .65502 L .38576 .65535 L .631 .379 .518 r
F
.38368 .65564 m .38524 .65851 L .38511 .65564 L .659 .811 .956 r
F
.38368 .65564 m .38238 .6585 L .38524 .65851 L F
.38238 .6585 m .38109 .66134 L .38537 .66136 L F
.38388 .65869 m .38545 .66157 L .38532 .6587 L F
.38128 .66442 m .38537 .6614 L .38558 .66443 L .732 .472 .535 r
F
.38128 .66442 m .38107 .66139 L .38537 .6614 L F
.38388 .65869 m .38257 .66156 L .38545 .66157 L .659 .811 .956 r
F
.38253 .65849 m .38257 .66156 L .38388 .65869 L F
.38688 .58313 m .38565 .65534 L .38375 .65525 L .753 .483 .524 r
F
.38511 .65563 m .38368 .65564 L .38511 .65564 L .659 .811 .956 r
F
.38498 .65277 m .38385 .65527 L .38511 .65563 L F
.38385 .65527 m .38368 .65564 L .38511 .65563 L F
.3857 .58266 m .38688 .58313 L .38375 .65525 L .849 .569 .514 r
F
.38403 .65835 m .38253 .65849 L .38388 .65869 L .659 .811 .956 r
F
.38369 .65523 m .38375 .65525 L .38362 .65824 L .849 .569 .514 r
F
.38369 .65523 m .38362 .65824 L .38361 .65823 L F
.3857 .58266 m .38375 .65525 L .38369 .65523 L F
.3837 .65559 m .38234 .65544 L .38368 .65564 L .659 .811 .956 r
F
.38273 .65504 m .38234 .65544 L .3837 .65559 L F
.38296 .65805 m .38253 .65849 L .38403 .65835 L F
.3797 .6581 m .38109 .66134 L .38238 .6585 L F
.38234 .65544 m .38238 .6585 L .38368 .65564 L F
.3797 .6581 m .37707 .66075 L .38109 .66134 L F
.38253 .65849 m .37988 .66116 L .38257 .66156 L F
.38135 .65811 m .37988 .66116 L .38253 .65849 L F
.38562 .58263 m .38369 .65523 L .38246 .65488 L .849 .569 .514 r
F
.38475 .58204 m .38242 .65485 L .38157 .65437 L .929 .648 .486 r
F
.38241 .65536 m .38117 .65506 L .38234 .65544 L .659 .811 .956 r
F
.3848 .58208 m .38242 .65486 L .38475 .58204 L .929 .648 .486 r
F
.38182 .65467 m .38117 .65506 L .38241 .65536 L .659 .811 .956 r
F
.38409 .58064 m .38422 .58136 L .38102 .65373 L .875 .7 .179 r
F
.38126 .655 m .38027 .65452 L .38117 .65506 L .659 .811 .956 r
F
.38118 .65461 m .38027 .65452 L .38126 .655 L F
.38154 .65434 m .38027 .65452 L .38182 .65467 L F
.38143 .65736 m .38143 .65736 L .38154 .65434 L .989 .724 .411 r
F
.38154 .65434 m .38154 .65434 L .38425 .5814 L F
.38143 .65736 m .38154 .65434 L .38154 .65434 L F
.38117 .65506 m .37903 .65634 L .3797 .6581 L .659 .811 .956 r
F
.37903 .65634 m .37737 .65734 L .37832 .65764 L F
.37903 .65634 m .37832 .65764 L .3797 .6581 L F
.38027 .65452 m .37974 .65503 L .38117 .65506 L F
.37974 .65503 m .37737 .65734 L .37903 .65634 L F
.37974 .65503 m .37903 .65634 L .38117 .65506 L F
.38409 .58064 m .38102 .65373 L .38102 .65369 L .875 .7 .179 r
F
.38425 .5814 m .38154 .65434 L .38425 .5814 L .989 .724 .411 r
F
.38154 .65434 m .38154 .65434 L .38425 .5814 L F
.38425 .5814 m .38156 .65436 L .38154 .65434 L F
.38409 .58064 m .38102 .65369 L .38408 .58059 L .875 .7 .179 r
F
.38102 .65369 m .38102 .65369 L .38408 .58059 L F
.38408 .58059 m .38102 .65369 L .38088 .65294 L F
.38182 .65467 m .38118 .65461 L .38126 .655 L .659 .811 .956 r
F
.38425 .5814 m .38475 .58204 L .38157 .65437 L .989 .724 .411 r
F
.38156 .65436 m .38157 .65437 L .38152 .65536 L F
.38425 .5814 m .38157 .65437 L .38156 .65436 L F
.38135 .65411 m .38032 .65396 L .38027 .65452 L .659 .811 .956 r
F
.38092 .65361 m .37968 .65386 L .38135 .65411 L F
.38102 .65373 m .38143 .65736 L .38089 .65672 L .989 .724 .411 r
F
.38422 .58136 m .38154 .65434 L .38102 .65373 L F
.38154 .65434 m .38143 .65736 L .38102 .65373 L F
.38092 .65361 m .37945 .65313 L .37968 .65386 L .659 .811 .956 r
F
.38242 .65486 m .38242 .65485 L .38475 .58204 L .929 .648 .486 r
F
.38183 .65782 m .38044 .65757 L .38135 .65811 L .659 .811 .956 r
F
.38425 .5814 m .38154 .65434 L .38422 .58136 L .989 .724 .411 r
F
.38154 .65434 m .38143 .65736 L .38154 .65434 L F
.38154 .65434 m .38154 .65434 L .38422 .58136 L F
.38046 .65306 m .37961 .65237 L .37945 .65313 L .659 .811 .956 r
F
.38143 .65736 m .38143 .65736 L .38154 .65434 L .989 .724 .411 r
F
.38154 .65434 m .38154 .65434 L .38422 .58136 L F
.38143 .65736 m .38154 .65434 L .38154 .65434 L F
.36359 .57747 m .35065 .58061 L .35824 .58589 L .599 .766 .959 r
F
.37439 .57727 m .35962 .57845 L .36294 .58245 L .598 .766 .96 r
F
.37375 .57518 m .35962 .57845 L .37439 .57727 L F
.37753 .57888 m .3751 .57629 L .37365 .57812 L .598 .767 .96 r
F
.38872 .58107 m .38387 .57937 L .38195 .57975 L F
.3846 .57971 m .38408 .58059 L .38088 .65294 L 0 0 .269 r
F
.3846 .57971 m .38088 .65294 L .3809 .65289 L F
.3846 .57971 m .3809 .65289 L .38464 .57965 L F
.3809 .65289 m .38091 .65289 L .38464 .57965 L F
.38464 .57965 m .38091 .65289 L .38145 .65189 L F
.38119 .65236 m .38054 .65174 L .37972 .6522 L .659 .811 .956 r
F
.3857 .58266 m .38369 .65523 L .38562 .58263 L .849 .569 .514 r
F
.38369 .65523 m .38369 .65523 L .38562 .58263 L F
.38385 .65527 m .38273 .65504 L .3837 .65559 L .659 .811 .956 r
F
.38279 .65498 m .38273 .65504 L .38385 .65527 L F
.38361 .65823 m .38361 .65823 L .38562 .58263 L .849 .569 .514 r
F
.3848 .58208 m .38562 .58263 L .38246 .65488 L .929 .648 .486 r
F
.3848 .58208 m .38246 .65488 L .38243 .65486 L F
.38273 .65504 m .38182 .65467 L .38241 .65536 L .659 .811 .956 r
F
.38195 .65459 m .38182 .65467 L .38273 .65504 L F
.3848 .58208 m .38233 .65787 L .38232 .65787 L .929 .648 .486 r
F
.38498 .65277 m .38135 .65411 L .38157 .65437 L .659 .811 .956 r
F
.38195 .65459 m .38157 .65437 L .38182 .65467 L F
.38498 .65277 m .38157 .65437 L .38195 .65459 L F
.38243 .65486 m .38246 .65488 L .38233 .65787 L .929 .648 .486 r
F
.38285 .65817 m .3821 .65814 L .38253 .65849 L .659 .811 .956 r
F
.38232 .65787 m .38233 .65787 L .38229 .65874 L .929 .648 .486 r
F
.38369 .65523 m .38361 .65823 L .38369 .65523 L .849 .569 .514 r
F
.38154 .65434 m .38143 .65736 L .38154 .65434 L .989 .724 .411 r
F
.38242 .65486 m .38232 .65787 L .38242 .65485 L .929 .648 .486 r
F
.38232 .65787 m .38232 .65787 L .38242 .65485 L F
.38296 .65805 m .38233 .65787 L .38285 .65817 L .659 .811 .956 r
F
.38233 .65787 m .38183 .65782 L .38285 .65817 L F
.3821 .65814 m .38235 .65844 L .38253 .65849 L F
.38233 .65787 m .38358 .65923 L .38229 .65874 L .849 .569 .514 r
F
.38246 .65488 m .3833 .65815 L .38233 .65787 L F
.3833 .65815 m .38358 .65923 L .38233 .65787 L F
.38203 .6577 m .38193 .65776 L .38233 .65787 L .659 .811 .956 r
F
.38193 .65776 m .38183 .65782 L .38233 .65787 L F
.38279 .65498 m .38246 .65488 L .38273 .65504 L F
.38369 .65523 m .38358 .65923 L .38246 .65488 L .849 .569 .514 r
F
.38203 .6577 m .38144 .65736 L .38183 .65782 L .659 .811 .956 r
F
.38183 .65782 m .38135 .65811 L .3821 .65814 L F
.3821 .65814 m .38135 .65811 L .38235 .65844 L F
.38144 .65736 m .38229 .65874 L .3814 .65813 L .929 .648 .486 r
F
.38157 .65437 m .38213 .65776 L .38144 .65736 L F
.38183 .65782 m .3821 .65814 L .38285 .65817 L .659 .811 .956 r
F
.38213 .65776 m .38229 .65874 L .38144 .65736 L .929 .648 .486 r
F
.38144 .65736 m .38044 .65757 L .38183 .65782 L .659 .811 .956 r
F
.38133 .65724 m .38127 .65727 L .38144 .65736 L F
.38127 .65727 m .38044 .65757 L .38144 .65736 L F
.38242 .65485 m .38229 .65874 L .38157 .65437 L .929 .648 .486 r
F
.38375 .65525 m .38416 .6562 L .3837 .65636 L .753 .483 .524 r
F
.38416 .6562 m .38507 .65831 L .3837 .65636 L F
.3837 .65636 m .38507 .65831 L .38362 .65824 L F
.3853 .65832 m .38388 .65869 L .38532 .6587 L .659 .811 .956 r
F
.3851 .65531 m .38511 .65564 L .38649 .65539 L F
.38565 .65534 m .3856 .65834 L .38375 .65525 L .753 .483 .524 r
F
.3856 .65834 m .38507 .65831 L .38375 .65525 L F
.38519 .65582 m .38407 .65826 L .3853 .65832 L .659 .811 .956 r
F
.38407 .65826 m .38388 .65869 L .3853 .65832 L F
.3856 .65834 m .38558 .6595 L .38507 .65831 L .753 .483 .524 r
F
.38151 .65537 m .38152 .65536 L .38144 .65736 L .989 .724 .411 r
F
.38143 .65736 m .38144 .65736 L .3814 .65813 L F
.38151 .65537 m .38144 .65736 L .38143 .65736 L F
.38498 .65277 m .38059 .65244 L .38046 .65306 L .659 .811 .956 r
F
.38059 .65244 m .37989 .65239 L .38017 .65272 L F
.38059 .65244 m .38017 .65272 L .38046 .65306 L F
.38498 .65277 m .38195 .65459 L .38246 .65488 L F
.38498 .65277 m .38142 .65194 L .38119 .65236 L F
.38059 .65244 m .37972 .6522 L .37989 .65239 L F
.38498 .65277 m .38079 .65232 L .38059 .65244 L F
.38079 .65232 m .37972 .6522 L .38059 .65244 L F
.38387 .57937 m .37747 .57477 L .3751 .57629 L .598 .767 .96 r
F
.38583 .57788 m .38583 .57793 L .38582 .57787 L .929 .648 .486 r
F
.38615 .5742 m .38464 .57965 L .38586 .57901 L .339 .143 .462 r
F
.38605 .57426 m .38464 .57965 L .38615 .5742 L F
.38605 .57426 m .38485 .57488 L .38464 .57965 L F
.38872 .58107 m .38521 .57911 L .38387 .57937 L .598 .767 .96 r
F
.38521 .57911 m .37747 .57477 L .38387 .57937 L F
.38708 .57838 m .38903 .57871 L .38708 .57843 L .753 .483 .524 r
F
.38903 .57871 m .38903 .57871 L .38708 .57838 L F
.38747 .57394 m .38719 .57872 L .38748 .57394 L .545 .308 .506 r
F
.38498 .65277 m .38046 .65306 L .38092 .65361 L .659 .811 .956 r
F
.38498 .65277 m .38092 .65361 L .38135 .65411 L F
.38649 .65539 m .38511 .65564 L .38653 .65545 L F
.38699 .58315 m .38566 .65534 L .38688 .58313 L .753 .483 .524 r
F
.38668 .65839 m .38532 .6587 L .38675 .65851 L .659 .811 .956 r
F
.38566 .65534 m .3856 .65834 L .38565 .65534 L .753 .483 .524 r
F
.3856 .65834 m .3856 .65834 L .38565 .65534 L F
.3853 .65832 m .38532 .6587 L .38668 .65839 L .659 .811 .956 r
F
.38563 .65834 m .38756 .65929 L .38558 .6595 L .631 .379 .518 r
F
.38576 .65535 m .38702 .65809 L .38563 .65834 L F
.38655 .65818 m .38563 .65834 L .38668 .65839 L .659 .811 .956 r
F
.38784 .65795 m .38675 .65851 L .38807 .65813 L F
.38566 .65534 m .38565 .65534 L .38688 .58313 L .753 .483 .524 r
F
.38872 .58107 m .38751 .58354 L .38883 .58346 L .598 .767 .96 r
F
.38699 .58315 m .38883 .58346 L .38558 .6595 L .753 .483 .524 r
F
.38774 .655 m .38649 .65539 L .38785 .65508 L .659 .811 .956 r
F
.38895 .58346 m .38764 .65501 L .38883 .58346 L .631 .379 .518 r
F
.38764 .65501 m .38763 .65502 L .38883 .58346 L F
.3864 .65523 m .38649 .65539 L .38774 .655 L .659 .811 .956 r
F
.38762 .65799 m .38675 .65851 L .38784 .65795 L F
.38655 .65818 m .38667 .65838 L .38762 .65799 L F
.38667 .65838 m .38675 .65851 L .38762 .65799 L F
.38762 .65799 m .38881 .65884 L .38756 .65929 L .484 .259 .497 r
F
.38655 .65549 m .38808 .65813 L .38659 .65548 L .659 .811 .956 r
F
.38774 .655 m .38848 .65763 L .38762 .65799 L .484 .259 .497 r
F
.38848 .65763 m .38881 .65884 L .38762 .65799 L F
.38649 .65539 m .38673 .6554 L .38785 .65508 L .659 .811 .956 r
F
.38774 .655 m .38785 .65508 L .3882 .65491 L F
.38896 .58346 m .39076 .58336 L .38762 .65799 L .631 .379 .518 r
F
.38759 .65799 m .38762 .65799 L .38756 .65929 L F
.38896 .58346 m .38762 .65799 L .38759 .65799 L F
.38764 .65501 m .38756 .65929 L .38763 .65502 L F
.38759 .65775 m .38758 .65799 L .3872 .65743 L F
.38759 .65775 m .3872 .65743 L .38576 .65535 L F
.38649 .65539 m .38653 .65545 L .38673 .6554 L .659 .811 .956 r
F
.38498 .65277 m .3851 .65531 L .38649 .65539 L F
.38653 .65545 m .38655 .65549 L .38659 .65548 L F
.38763 .65502 m .38759 .65775 L .38576 .65535 L .631 .379 .518 r
F
.38758 .65799 m .38702 .65809 L .38576 .65535 L F
.38895 .58346 m .38896 .58346 L .38756 .65929 L F
.38498 .65277 m .38774 .655 L .38775 .65499 L .659 .811 .956 r
F
.38889 .65452 m .38775 .65499 L .38897 .65455 L F
.38498 .65277 m .38775 .65499 L .38889 .65452 L F
.39084 .58334 m .38893 .6545 L .39076 .58336 L .484 .259 .497 r
F
.38888 .65746 m .38784 .65795 L .3892 .6576 L .659 .811 .956 r
F
.38784 .65795 m .38884 .65777 L .3892 .6576 L F
.38893 .6545 m .38893 .6545 L .39076 .58336 L .484 .259 .497 r
F
.38498 .65277 m .38897 .65455 L .38982 .6539 L .659 .811 .956 r
F
.38893 .6545 m .38885 .65747 L .38893 .6545 L .484 .259 .497 r
F
.38885 .65747 m .38885 .65747 L .38893 .6545 L F
.38893 .6545 m .38885 .65747 L .38893 .6545 L F
.38885 .65747 m .38885 .65747 L .38893 .6545 L F
.38893 .6545 m .389 .65447 L .38887 .65746 L F
.38893 .6545 m .38887 .65746 L .38885 .65747 L F
.38979 .65389 m .3897 .65686 L .38979 .65389 L .286 .104 .449 r
F
.3897 .65686 m .38966 .65825 L .3897 .65686 L F
.3897 .65686 m .3897 .65686 L .38979 .65389 L F
.38969 .65686 m .38888 .65746 L .39006 .65695 L .659 .811 .956 r
F
.3878 .65791 m .38784 .65795 L .38888 .65746 L F
.38784 .65795 m .38807 .65813 L .38884 .65777 L F
.38774 .655 m .3882 .65491 L .38897 .65455 L F
.38785 .65508 m .388 .65521 L .38809 .65514 L F
.38893 .6545 m .38881 .65884 L .38774 .655 L .484 .259 .497 r
F
.38519 .65582 m .38888 .65746 L .38969 .65686 L .659 .811 .956 r
F
.38888 .65746 m .38888 .65746 L .38969 .65686 L F
.38888 .65746 m .3892 .6576 L .39 .65699 L F
.38888 .65746 m .39 .65699 L .39006 .65695 L F
.38885 .65747 m .38881 .65884 L .38885 .65747 L .484 .259 .497 r
F
.38885 .65747 m .38881 .65884 L .38885 .65747 L F
.38519 .65582 m .3878 .65791 L .38888 .65746 L .659 .811 .956 r
F
.38498 .65277 m .3864 .65523 L .38774 .655 L F
.38519 .65582 m .38655 .65818 L .38784 .65795 L F
.38758 .65799 m .38756 .65929 L .38702 .65809 L .631 .379 .518 r
F
.38702 .65809 m .38756 .65929 L .38563 .65834 L F
.38519 .65582 m .3853 .65832 L .38563 .65834 L .659 .811 .956 r
F
.38519 .65582 m .38563 .65834 L .38655 .65818 L F
.3856 .65834 m .38558 .6595 L .3856 .65834 L .753 .483 .524 r
F
.38314 .57795 m .38063 .57369 L .37747 .57477 L .598 .767 .96 r
F
.38747 .57394 m .38615 .5742 L .38595 .57896 L .545 .308 .506 r
F
.38708 .57838 m .38708 .57843 L .38707 .57837 L .849 .569 .514 r
F
.38747 .57394 m .38595 .57896 L .38719 .57872 L .545 .308 .506 r
F
.38615 .5742 m .38586 .57901 L .38595 .57896 L .339 .143 .462 r
F
.38615 .5742 m .38586 .57901 L .38615 .5742 L F
.38872 .58107 m .38614 .57872 L .38458 .57875 L .598 .767 .96 r
F
.38498 .65277 m .38246 .65488 L .38279 .65498 L .659 .811 .956 r
F
.38498 .65277 m .38279 .65498 L .38385 .65527 L F
.38719 .57872 m .38719 .57872 L .38748 .57394 L .545 .308 .506 r
F
.38748 .57394 m .38719 .57872 L .38727 .5787 L F
.38802 .57393 m .38885 .56808 L .38484 .56812 L .598 .766 .96 r
F
.38921 .5761 m .38911 .57391 L .38802 .57393 L F
.38884 .57332 m .38881 .57391 L .38882 .57391 L .652 .396 .519 r
F
.39019 .57346 m .38884 .57332 L .38882 .57391 L .735 .467 .523 r
F
.38911 .57391 m .38885 .56808 L .38802 .57393 L .598 .766 .96 r
F
.38882 .57391 m .38852 .57868 L .38861 .57868 L .652 .396 .519 r
F
.38881 .57391 m .38852 .57868 L .38882 .57391 L F
.38881 .57391 m .38748 .57394 L .38727 .5787 L F
.38881 .57391 m .38727 .5787 L .38852 .57868 L F
.38522 .57469 m .37798 .56979 L .3756 .5713 L .598 .766 .96 r
F
.38599 .57429 m .37798 .56979 L .38522 .57469 L F
.38522 .57469 m .3756 .5713 L .38435 .57514 L F
.38872 .58107 m .38434 .57311 L .38063 .57369 L .598 .767 .96 r
F
.3875 .57341 m .38747 .57394 L .38748 .57394 L .545 .308 .506 r
F
.38696 .57404 m .38795 .5738 L .38648 .5736 L .598 .766 .96 r
F
.38797 .57384 m .38795 .5738 L .38696 .57404 L F
.38795 .5738 m .38484 .56812 L .38648 .5736 L F
.38696 .57404 m .38678 .57387 L .38615 .5742 L F
.38617 .57377 m .38605 .57426 L .38615 .5742 L .339 .143 .462 r
F
.38678 .57387 m .38113 .5687 L .38599 .57429 L .598 .766 .96 r
F
.38872 .58107 m .38836 .57307 L .38434 .57311 L .598 .767 .96 r
F
.38498 .65277 m .38982 .6539 L .39034 .65317 L .659 .811 .956 r
F
.39327 .58188 m .39039 .65239 L .39032 .65315 L 0 0 .006 r
F
.38498 .65277 m .39034 .65317 L .39049 .65248 L .659 .811 .956 r
F
.39045 .65242 m .39049 .65248 L .3905 .65241 L F
.38498 .65277 m .39049 .65248 L .39045 .65242 L F
.39017 .65619 m .38971 .65684 L .39057 .65622 L F
.39018 .65465 m .39305 .65625 L .39207 .65481 L F
.39015 .65504 m .39305 .65625 L .39018 .65465 L F
.38982 .6539 m .39466 .65503 L .3957 .65357 L F
.38982 .6539 m .3957 .65357 L .39034 .65317 L F
.39032 .65315 m .39025 .65559 L .3902 .65614 L 0 0 .006 r
F
.39328 .58183 m .39334 .58112 L .3904 .65235 L F
.39328 .58183 m .3904 .65235 L .39039 .65239 L F
.39039 .65239 m .39039 .65239 L .39327 .58188 L F
.39328 .58183 m .39039 .65239 L .39328 .58184 L F
.39039 .65239 m .39039 .65239 L .39328 .58184 L F
.39334 .58112 m .38977 .65142 L .3904 .65235 L .99 .735 .374 r
F
.38999 .65174 m .3905 .65241 L .39028 .65168 L .659 .811 .956 r
F
.38498 .65277 m .39045 .65242 L .38999 .65174 L F
.39045 .65242 m .3905 .65241 L .38999 .65174 L F
.3933 .58106 m .38977 .65142 L .39334 .58112 L .99 .735 .374 r
F
.39026 .65549 m .39065 .65589 L .39037 .65548 L .659 .811 .956 r
F
.3903 .65319 m .39019 .65615 L .3903 .65319 L 0 0 .327 r
F
.38971 .65684 m .39006 .65695 L .39057 .65622 L .659 .811 .956 r
F
.38969 .65686 m .3897 .65687 L .38971 .65684 L F
.3897 .65687 m .39006 .65695 L .38971 .65684 L F
.3903 .65319 m .39032 .65315 L .3902 .65614 L 0 0 .327 r
F
.39019 .65615 m .3902 .65614 L .39014 .65755 L F
.3903 .65319 m .3902 .65614 L .39019 .65615 L F
.39019 .65615 m .39014 .65755 L .39019 .65615 L F
.39019 .65615 m .39019 .65615 L .3903 .65319 L F
.39017 .65619 m .3902 .65619 L .3902 .65614 L .659 .811 .956 r
F
.39006 .65695 m .39492 .65808 L .39597 .65662 L F
.3903 .65319 m .39019 .65615 L .38984 .65385 L 0 0 .327 r
F
.39019 .65615 m .39014 .65755 L .39004 .65637 L F
.39019 .65615 m .39004 .65637 L .38984 .65385 L F
.39039 .65239 m .39027 .65535 L .39039 .65239 L 0 0 .006 r
F
.39027 .65535 m .39027 .65535 L .39039 .65239 L F
.38977 .65142 m .38977 .65142 L .39334 .58112 L .99 .735 .374 r
F
.38977 .65142 m .38977 .65142 L .3933 .58106 L F
.38498 .65277 m .39028 .65168 L .39022 .65161 L .659 .811 .956 r
F
.3929 .57534 m .39261 .58006 L .3927 .58011 L .912 .629 .494 r
F
.39289 .57534 m .39132 .57927 L .3926 .58005 L F
.39292 .57473 m .39274 .57525 L .39289 .57534 L F
.39274 .57525 m .39132 .57927 L .39289 .57534 L F
.39292 .57473 m .39155 .57386 L .39152 .57451 L F
.39292 .57473 m .39152 .57451 L .39274 .57525 L F
.392 .5748 m .40246 .5729 L .39993 .57109 L .598 .766 .96 r
F
.38921 .5761 m .39273 .57525 L .392 .5748 L F
.39292 .57473 m .39289 .57534 L .3929 .57534 L .912 .629 .494 r
F
.39273 .57525 m .40246 .5729 L .392 .5748 L .598 .766 .96 r
F
.39289 .57534 m .3926 .58005 L .3929 .57534 L .912 .629 .494 r
F
.3926 .58005 m .39261 .58006 L .3929 .57534 L F
.39354 .57635 m .3929 .57534 L .3927 .58011 L .99 .735 .374 r
F
.39354 .57635 m .40467 .57701 L .3936 .57575 L .598 .766 .96 r
F
.39187 .57961 m .40199 .57788 L .39946 .57608 L .598 .767 .96 r
F
.38872 .58107 m .39271 .58011 L .39187 .57961 L F
.39271 .58011 m .40199 .57788 L .39187 .57961 L F
.3933 .58105 m .38974 .65137 L .38977 .65142 L .99 .735 .374 r
F
.38498 .65277 m .39022 .65161 L .38932 .65116 L .659 .811 .956 r
F
.39348 .57993 m .4036 .5799 L .40199 .57788 L .598 .767 .96 r
F
.38872 .58107 m .39548 .58054 L .39348 .57993 L F
.39548 .58054 m .4036 .5799 L .39348 .57993 L F
.38872 .58107 m .39111 .58325 L .39143 .58316 L F
.38921 .5761 m .39218 .57471 L .39117 .5744 L .598 .766 .96 r
F
.39152 .57451 m .39123 .57924 L .39132 .57927 L .814 .537 .519 r
F
.39155 .57386 m .39151 .5745 L .39152 .57451 L F
.39151 .5745 m .39123 .57924 L .39152 .57451 L F
.39117 .5744 m .39993 .57109 L .39667 .56962 L .598 .766 .96 r
F
.39218 .57471 m .39993 .57109 L .39117 .5744 L F
.39151 .5745 m .38996 .57886 L .39123 .57924 L .814 .537 .519 r
F
.39274 .57525 m .39152 .57451 L .39132 .57927 L .912 .629 .494 r
F
.39273 .57525 m .40407 .57492 L .40246 .5729 L .598 .766 .96 r
F
.39356 .57575 m .40407 .57492 L .39273 .57525 L F
.39349 .57694 m .39347 .57712 L .39359 .57696 L F
.39111 .57901 m .39946 .57608 L .39619 .57461 L .598 .767 .96 r
F
.38872 .58107 m .3927 .57922 L .39111 .57901 L F
.3927 .57922 m .39946 .57608 L .39111 .57901 L F
.38872 .58107 m .38883 .58346 L .39 .5834 L F
.39017 .57409 m .38987 .57884 L .38996 .57886 L .735 .467 .523 r
F
.39019 .57346 m .39015 .57409 L .39017 .57409 L F
.39015 .57409 m .38987 .57884 L .39017 .57409 L F
.39019 .57346 m .38882 .57391 L .39015 .57409 L F
.39044 .56936 m .39037 .56934 L .39019 .57346 L .814 .537 .519 r
F
.39044 .56936 m .39019 .57346 L .39172 .56976 L F
.38911 .57395 m .39288 .56859 L .38885 .56808 L .598 .766 .96 r
F
.38921 .5761 m .39019 .57409 L .38911 .57395 L F
.39019 .57409 m .39288 .56859 L .38911 .57395 L F
.39015 .57409 m .38861 .57868 L .38987 .57884 L .735 .467 .523 r
F
.39151 .5745 m .39017 .57409 L .38996 .57886 L .814 .537 .519 r
F
.39317 .57578 m .39354 .57635 L .3936 .57575 L .598 .766 .96 r
F
.39354 .57635 m .39354 .57635 L .39317 .57578 L F
.38872 .58107 m .39619 .57461 L .3924 .57359 L .598 .767 .96 r
F
.38996 .57886 m .38561 .65039 L .38693 .6504 L .735 .467 .523 r
F
.38498 .65277 m .38606 .65039 L .38554 .65038 L .659 .811 .956 r
F
.38861 .57868 m .38423 .65057 L .38554 .65038 L .652 .396 .519 r
F
.38487 .65048 m .38554 .65038 L .38487 .65037 L .659 .811 .956 r
F
.38498 .65277 m .38554 .65038 L .38487 .65048 L F
.38719 .57872 m .38286 .65099 L .38719 .57872 L .545 .308 .506 r
F
.38586 .57901 m .38151 .65185 L .38595 .57896 L .339 .143 .462 r
F
.38151 .65185 m .38151 .65185 L .38595 .57896 L F
.38595 .57896 m .38151 .65185 L .3828 .65101 L F
.38586 .57901 m .38464 .57965 L .38145 .65189 L F
.38586 .57901 m .38145 .65189 L .38151 .65185 L F
.38138 .65193 m .38177 .65134 L .38054 .65174 L .659 .811 .956 r
F
.38498 .65277 m .38208 .65148 L .38138 .65193 L F
.38208 .65148 m .38177 .65134 L .38138 .65193 L F
.38043 .65546 m .3803 .65468 L .37978 .65541 L F
.38088 .65294 m .38086 .65658 L .38075 .65594 L .875 .7 .179 r
F
.3809 .65289 m .38088 .65294 L .38075 .65594 L 0 0 .269 r
F
.38026 .65683 m .37963 .65617 L .37985 .65691 L .659 .811 .956 r
F
.38102 .65369 m .38102 .65373 L .38089 .65672 L .875 .7 .179 r
F
.38087 .6567 m .37985 .65691 L .38097 .65716 L .659 .811 .956 r
F
.38089 .65672 m .38097 .65716 L .38133 .65724 L F
.38087 .6567 m .38097 .65716 L .38089 .65672 L F
.38102 .65369 m .38089 .65672 L .38102 .65369 L .875 .7 .179 r
F
.38089 .65672 m .38086 .65741 L .38089 .65672 L F
.38089 .65672 m .38089 .65672 L .38102 .65369 L F
.38089 .65672 m .38089 .65672 L .38086 .65741 L F
.38102 .65369 m .38089 .65672 L .38089 .65672 L F
.38089 .6567 m .38065 .65611 L .38026 .65683 L .659 .811 .956 r
F
.38097 .65716 m .37985 .65691 L .38101 .65736 L F
.38102 .65369 m .38086 .65741 L .38088 .65294 L .875 .7 .179 r
F
.38519 .65582 m .38078 .6561 L .38089 .6567 L .659 .811 .956 r
F
.38078 .6561 m .38065 .65611 L .38089 .6567 L F
.38065 .65611 m .37963 .65617 L .38026 .65683 L F
.3809 .65289 m .38075 .65594 L .38075 .65593 L 0 0 .269 r
F
.38065 .65611 m .37978 .65541 L .37963 .65617 L .659 .811 .956 r
F
.38519 .65582 m .38098 .6555 L .38065 .65611 L F
.3809 .65289 m .38075 .65593 L .38091 .65289 L 0 0 .269 r
F
.38075 .65593 m .38075 .65593 L .38091 .65289 L F
.38154 .65434 m .38152 .65536 L .38151 .65537 L .989 .724 .411 r
F
.38519 .65582 m .3813 .65491 L .38105 .65537 L .659 .811 .956 r
F
.38145 .65189 m .38085 .65575 L .38132 .65488 L 0 0 .269 r
F
.38151 .65185 m .38145 .65189 L .38132 .65488 L .339 .143 .462 r
F
.38151 .65185 m .38132 .65488 L .38133 .65488 L F
.38091 .65289 m .38072 .65656 L .38145 .65189 L 0 0 .269 r
F
.38128 .65491 m .38116 .65402 L .3803 .65468 L .659 .811 .956 r
F
.38519 .65582 m .38204 .65442 L .38128 .65491 L F
.38133 .65488 m .38133 .65488 L .38151 .65185 L .339 .143 .462 r
F
.38519 .65582 m .38105 .65537 L .38098 .6555 L .659 .811 .956 r
F
.38177 .65134 m .3821 .65045 L .38097 .65098 L F
.38498 .65277 m .3828 .65101 L .38177 .65134 L F
.3828 .65101 m .3821 .65045 L .38177 .65134 L F
.38719 .57872 m .38286 .65099 L .38727 .5787 L .545 .308 .506 r
F
.38286 .65099 m .38286 .65099 L .38727 .5787 L F
.38286 .65099 m .38286 .65099 L .38719 .57872 L F
.38727 .5787 m .38286 .65099 L .38416 .65058 L F
.38719 .57872 m .38595 .57896 L .3828 .65101 L F
.38519 .65582 m .38286 .65395 L .38177 .6543 L .659 .811 .956 r
F
.38267 .65401 m .38129 .6555 L .38264 .65468 L .339 .143 .462 r
F
.3828 .65101 m .38155 .65474 L .38267 .65401 L F
.38155 .65474 m .38129 .6555 L .38267 .65401 L F
.38151 .65185 m .38133 .65488 L .38151 .65185 L F
.38156 .65436 m .38152 .65536 L .38154 .65434 L .989 .724 .411 r
F
.38151 .65185 m .38129 .6555 L .3828 .65101 L .339 .143 .462 r
F
.38177 .6543 m .38229 .65349 L .38116 .65402 L .659 .811 .956 r
F
.38286 .65099 m .38268 .65401 L .38286 .65099 L .545 .308 .506 r
F
.38268 .65401 m .38264 .65468 L .38268 .65401 L F
.38268 .65401 m .38268 .65401 L .38286 .65099 L F
.38286 .65099 m .3828 .65101 L .38267 .65401 L F
.38286 .65099 m .38267 .65401 L .38268 .65401 L F
.38286 .65099 m .38264 .65468 L .38286 .65099 L F
.38519 .65582 m .38391 .65361 L .38286 .65395 L .659 .811 .956 r
F
.38498 .65277 m .38378 .6507 L .3828 .65101 L F
.38852 .57868 m .38727 .5787 L .38416 .65058 L .652 .396 .519 r
F
.38852 .57868 m .38416 .65058 L .38423 .65057 L F
.38852 .57868 m .38423 .65057 L .38861 .57868 L F
.38423 .65057 m .38423 .65057 L .38861 .57868 L F
.38498 .65277 m .38485 .64989 L .38342 .65008 L .659 .811 .956 r
F
.38403 .65357 m .38264 .65468 L .384 .65433 L .545 .308 .506 r
F
.38416 .65058 m .38292 .65393 L .38403 .65357 L F
.38292 .65393 m .38264 .65468 L .38403 .65357 L F
.38423 .65057 m .38416 .65058 L .38403 .65357 L .652 .396 .519 r
F
.38405 .65357 m .38403 .65357 L .384 .65433 L F
.38423 .65057 m .38403 .65357 L .38405 .65357 L F
.38423 .65057 m .38405 .65357 L .38423 .65057 L F
.38405 .65357 m .384 .65433 L .38405 .65357 L F
.38405 .65357 m .38405 .65357 L .38423 .65057 L F
.38519 .65582 m .38508 .65343 L .38391 .65361 L .659 .811 .956 r
F
.38508 .65343 m .38403 .65357 L .38391 .65361 L F
.38987 .57884 m .3856 .65039 L .38996 .57886 L .735 .467 .523 r
F
.38498 .65277 m .38726 .65047 L .38606 .65039 L .659 .811 .956 r
F
.39132 .57927 m .387 .65042 L .38832 .65067 L .814 .537 .519 r
F
.38726 .65047 m .38693 .6504 L .38606 .65039 L .659 .811 .956 r
F
.39123 .57924 m .38699 .65042 L .39132 .57927 L .814 .537 .519 r
F
.3926 .58005 m .38839 .6507 L .39261 .58006 L .912 .629 .494 r
F
.38839 .6507 m .38839 .6507 L .39261 .58006 L F
.3927 .58011 m .3884 .65071 L .38974 .65137 L F
.38842 .65041 m .3888 .65048 L .38842 .65036 L .659 .811 .956 r
F
.39123 .57924 m .38996 .57886 L .38693 .6504 L .814 .537 .519 r
F
.38498 .65277 m .38841 .65071 L .38832 .65067 L .659 .811 .956 r
F
.38498 .65277 m .38832 .65067 L .38766 .65054 L F
.38498 .65277 m .38781 .65042 L .38732 .65041 L F
.39261 .58006 m .38839 .6507 L .3927 .58011 L .912 .629 .494 r
F
.38498 .65277 m .38932 .65116 L .38841 .65071 L .659 .811 .956 r
F
.38839 .6507 m .38822 .65368 L .3884 .65071 L .912 .629 .494 r
F
.38822 .65368 m .38822 .65368 L .3884 .65071 L F
.38519 .65582 m .38851 .65382 L .3882 .65367 L .659 .811 .956 r
F
.38519 .65582 m .3882 .65367 L .38746 .65353 L F
.38839 .6507 m .38822 .65368 L .38839 .6507 L .912 .629 .494 r
F
.38519 .65582 m .38939 .65426 L .38851 .65382 L .659 .811 .956 r
F
.38822 .65368 m .38815 .65477 L .38822 .65368 L .912 .629 .494 r
F
.38822 .65368 m .38822 .65368 L .38839 .6507 L F
.38979 .65389 m .38984 .65385 L .38966 .65825 L .286 .104 .449 r
F
.38519 .65582 m .39026 .65549 L .38993 .65484 L .659 .811 .956 r
F
.39026 .65549 m .39037 .65548 L .39027 .65534 L F
.39026 .65549 m .39027 .65534 L .38993 .65484 L F
.39039 .65239 m .39027 .65535 L .39039 .65239 L 0 0 .006 r
F
.39022 .65589 m .39065 .65589 L .39026 .65549 L .659 .811 .956 r
F
.39027 .65535 m .39022 .6567 L .39027 .65535 L 0 0 .006 r
F
.39027 .65535 m .39027 .65535 L .39039 .65239 L F
.38519 .65582 m .39022 .65589 L .39026 .65549 L .659 .811 .956 r
F
.39039 .65239 m .3904 .65235 L .39027 .65534 L 0 0 .006 r
F
.39039 .65239 m .39027 .65534 L .39027 .65535 L F
.39027 .65535 m .39025 .65559 L .39032 .65315 L F
.38977 .65142 m .38962 .65438 L .3904 .65235 L .99 .735 .374 r
F
.38519 .65582 m .38993 .65484 L .38939 .65426 L .659 .811 .956 r
F
.38993 .65484 m .38962 .65438 L .38939 .65426 L F
.38962 .65438 m .38956 .65562 L .38981 .65465 L .99 .735 .374 r
F
.38962 .65438 m .38981 .65465 L .3904 .65235 L F
.39039 .65239 m .39027 .65535 L .39032 .65315 L 0 0 .006 r
F
.3904 .65235 m .38985 .6545 L .3903 .65474 L .99 .735 .374 r
F
.3903 .65477 m .38993 .65484 L .39027 .65534 L F
.38993 .65484 m .39033 .65476 L .38962 .65438 L .659 .811 .956 r
F
.39033 .65476 m .39038 .65475 L .39033 .65472 L F
.38977 .65142 m .38962 .65438 L .38977 .65142 L .99 .735 .374 r
F
.38962 .65438 m .38956 .65562 L .38962 .65438 L F
.38962 .65438 m .38962 .65438 L .38977 .65142 L F
.39033 .65476 m .39033 .65472 L .38961 .65437 L .659 .811 .956 r
F
.38962 .65438 m .38961 .65437 L .38939 .65426 L F
.39033 .65476 m .38961 .65437 L .38962 .65438 L F
.39027 .65535 m .39022 .6567 L .39025 .65559 L 0 0 .006 r
F
.38961 .65437 m .38815 .65477 L .38956 .65562 L .912 .629 .494 r
F
.38974 .65137 m .38858 .65385 L .38961 .65437 L F
.38858 .65385 m .38815 .65477 L .38961 .65437 L F
.38977 .65142 m .38974 .65137 L .38961 .65437 L .99 .735 .374 r
F
.38962 .65438 m .38961 .65437 L .38956 .65562 L F
.38977 .65142 m .38961 .65437 L .38962 .65438 L F
.38951 .65422 m .39052 .65472 L .38994 .65406 L .659 .811 .956 r
F
.38939 .65426 m .38959 .65434 L .38951 .65422 L F
.38959 .65434 m .39052 .65472 L .38951 .65422 L F
.39038 .65475 m .39052 .65472 L .38939 .65426 L F
.38977 .65142 m .38962 .65438 L .38977 .65142 L .99 .735 .374 r
F
.38962 .65438 m .38962 .65438 L .38977 .65142 L F
.38851 .65382 m .38994 .65406 L .38903 .65352 L .659 .811 .956 r
F
.38939 .65426 m .38994 .65406 L .38851 .65382 L F
.3882 .65367 m .38676 .65437 L .38815 .65477 L .814 .537 .519 r
F
.38832 .65067 m .38714 .65347 L .3882 .65367 L F
.38699 .65042 m .38693 .6504 L .3868 .6534 L F
.38699 .65042 m .3868 .6534 L .38682 .6534 L F
.38699 .65042 m .38682 .6534 L .387 .65042 L F
.38682 .6534 m .38682 .6534 L .387 .65042 L F
.38519 .65582 m .38746 .65353 L .3868 .6534 L .659 .811 .956 r
F
.38693 .6504 m .38572 .65339 L .3868 .6534 L .735 .467 .523 r
F
.38629 .65339 m .3868 .6534 L .38632 .65331 L .659 .811 .956 r
F
.38519 .65582 m .3868 .6534 L .38629 .65339 L F
.38519 .65582 m .38629 .65339 L .38507 .65338 L F
.3856 .65039 m .38554 .65038 L .38537 .65424 L .735 .467 .523 r
F
.3856 .65039 m .38537 .65424 L .38561 .65039 L F
.38554 .65038 m .38431 .65354 L .38541 .65338 L .652 .396 .519 r
F
.38561 .65039 m .38537 .65424 L .38693 .6504 L .735 .467 .523 r
F
.38542 .65327 m .3865 .65293 L .38543 .65292 L .659 .811 .956 r
F
.38542 .65327 m .38543 .65292 L .38505 .65292 L F
.38507 .65338 m .38542 .65327 L .38505 .65292 L F
.38629 .65339 m .3865 .65293 L .38507 .65338 L F
.3868 .6534 m .38537 .65424 L .38676 .65437 L .735 .467 .523 r
F
.38572 .65339 m .38537 .65424 L .3868 .6534 L F
.387 .65042 m .38676 .65437 L .38832 .65067 L .814 .537 .519 r
F
.38632 .65331 m .38785 .65313 L .3865 .65293 L .659 .811 .956 r
F
.38746 .65353 m .38785 .65313 L .38632 .65331 L F
.38682 .6534 m .38676 .65437 L .38682 .6534 L .814 .537 .519 r
F
.38714 .65347 m .38676 .65437 L .3882 .65367 L F
.3884 .65071 m .38815 .65477 L .38974 .65137 L .912 .629 .494 r
F
.3926 .58005 m .39132 .57927 L .38815 .65477 L F
.3882 .65367 m .38903 .65352 L .38761 .65338 L .659 .811 .956 r
F
.38851 .65382 m .38864 .65375 L .3882 .65367 L F
.38864 .65375 m .38903 .65352 L .3882 .65367 L F
.38746 .65353 m .3882 .65367 L .38761 .65338 L F
.38682 .6534 m .3868 .6534 L .38676 .65437 L .814 .537 .519 r
F
.38761 .65338 m .38903 .65352 L .38785 .65313 L .659 .811 .956 r
F
.38822 .65368 m .38815 .65477 L .38822 .65368 L .912 .629 .494 r
F
.38839 .6507 m .3884 .65071 L .3927 .58011 L F
.38841 .65071 m .3897 .65102 L .3888 .65048 L .659 .811 .956 r
F
.38932 .65116 m .3897 .65102 L .38841 .65071 L F
.39123 .57924 m .38693 .6504 L .38699 .65042 L .814 .537 .519 r
F
.38766 .65054 m .38832 .65067 L .38781 .65042 L .659 .811 .956 r
F
.38732 .65041 m .38781 .65042 L .38748 .65025 L F
.39015 .57409 m .38882 .57391 L .38861 .57868 L .735 .467 .523 r
F
.39155 .57386 m .39017 .57409 L .39151 .5745 L .814 .537 .519 r
F
.39019 .5741 m .39124 .57433 L .39034 .57379 L .598 .766 .96 r
F
.39117 .5744 m .39124 .57433 L .39019 .5741 L F
.39034 .57379 m .39667 .56962 L .39288 .56859 L F
.39124 .57433 m .39667 .56962 L .39034 .57379 L F
.38872 .58107 m .3924 .57359 L .38836 .57307 L .598 .767 .96 r
F
.38987 .57884 m .38861 .57868 L .38554 .65038 L .735 .467 .523 r
F
.38987 .57884 m .38554 .65038 L .3856 .65039 L F
.38842 .65041 m .38842 .65036 L .38763 .6501 L .659 .811 .956 r
F
.38748 .65025 m .38842 .65041 L .38763 .6501 L F
.38841 .65071 m .3888 .65048 L .38748 .65025 L F
.38699 .65042 m .387 .65042 L .39132 .57927 L .814 .537 .519 r
F
.38612 .65025 m .38763 .6501 L .38628 .64989 L .659 .811 .956 r
F
.38606 .65039 m .38646 .65032 L .38612 .65025 L F
.38646 .65032 m .38763 .6501 L .38612 .65025 L F
.38726 .65047 m .38732 .65041 L .38693 .6504 L F
.3856 .65039 m .38561 .65039 L .38996 .57886 L .735 .467 .523 r
F
.38732 .65041 m .38763 .6501 L .38606 .65039 L .659 .811 .956 r
F
.38541 .65338 m .384 .65433 L .38537 .65424 L .652 .396 .519 r
F
.38431 .65354 m .384 .65433 L .38541 .65338 L F
.38423 .65057 m .384 .65433 L .38554 .65038 L F
.38507 .65324 m .38505 .65292 L .38396 .65358 L .659 .811 .956 r
F
.38403 .65357 m .38396 .65358 L .38391 .65361 L F
.38507 .65324 m .38396 .65358 L .38403 .65357 L F
.38508 .65343 m .38507 .65324 L .38403 .65357 L F
.3839 .65359 m .38505 .65292 L .38362 .65311 L F
.38391 .65361 m .38396 .65358 L .3839 .65359 L F
.38396 .65358 m .38505 .65292 L .3839 .65359 L F
.38286 .65099 m .38264 .65468 L .38416 .65058 L .545 .308 .506 r
F
.38286 .65395 m .38362 .65311 L .38229 .65349 L .659 .811 .956 r
F
.38391 .65361 m .38362 .65311 L .38286 .65395 L F
.38286 .65395 m .38229 .65349 L .38177 .6543 L F
.38268 .65401 m .38267 .65401 L .38264 .65468 L .545 .308 .506 r
F
.38719 .57872 m .3828 .65101 L .38286 .65099 L F
.3828 .65101 m .38374 .65063 L .38253 .6508 L .659 .811 .956 r
F
.38378 .6507 m .38374 .65063 L .3828 .65101 L F
.38253 .6508 m .38342 .65008 L .3821 .65045 L F
.38374 .65063 m .38342 .65008 L .38253 .6508 L F
.38204 .65442 m .38116 .65402 L .38128 .65491 L F
.38133 .65488 m .38129 .6555 L .38133 .65488 L .339 .143 .462 r
F
.38132 .65488 m .38072 .65656 L .38129 .6555 L 0 0 .269 r
F
.38085 .65575 m .38072 .65656 L .38132 .65488 L F
.38098 .6555 m .38064 .65533 L .38066 .65548 L .659 .811 .956 r
F
.38105 .65537 m .38064 .65533 L .38098 .6555 L F
.38098 .6555 m .37978 .65541 L .38065 .65611 L F
.38075 .65594 m .38075 .65597 L .38072 .65656 L .875 .7 .179 r
F
.38075 .65597 m .38086 .65741 L .38072 .65656 L F
.38075 .65593 m .38072 .65656 L .38075 .65593 L 0 0 .269 r
F
.38075 .65593 m .38075 .65594 L .38072 .65656 L F
.38105 .65537 m .38128 .65491 L .38064 .65533 L .659 .811 .956 r
F
.3813 .65491 m .38128 .65491 L .38105 .65537 L F
.38066 .65548 m .38064 .65533 L .38043 .65546 L F
.38128 .65491 m .3803 .65468 L .38043 .65546 L F
.38133 .65488 m .38132 .65488 L .38129 .6555 L .339 .143 .462 r
F
.38054 .65174 m .38104 .65101 L .38012 .65164 L .659 .811 .956 r
F
.38177 .65134 m .38104 .65101 L .38054 .65174 L F
.38104 .65101 m .38097 .65098 L .38092 .65103 L F
.38104 .65101 m .38092 .65103 L .38012 .65164 L F
.38487 .65037 m .38628 .64989 L .38485 .64989 L F
.38606 .65039 m .38628 .64989 L .38487 .65037 L F
.3933 .58105 m .3927 .58011 L .38974 .65137 L .99 .735 .374 r
F
.38932 .65116 m .39022 .65161 L .3897 .65102 L .659 .811 .956 r
F
.38962 .65438 m .38956 .65562 L .38962 .65438 L .99 .735 .374 r
F
.38993 .65484 m .39067 .65546 L .39052 .65472 L .659 .811 .956 r
F
.39037 .65548 m .39067 .65546 L .38993 .65484 L F
.39067 .65546 m .39074 .65546 L .39072 .65539 L F
.39067 .65546 m .39072 .65539 L .39052 .65472 L F
.38519 .65582 m .39017 .65619 L .39022 .65589 L F
.39017 .65619 m .3902 .65614 L .39022 .65589 L F
.39027 .65535 m .39022 .6567 L .39027 .65535 L 0 0 .006 r
F
.39027 .65535 m .39027 .65534 L .39022 .6567 L F
.39022 .65589 m .39058 .65622 L .39065 .65589 L .659 .811 .956 r
F
.3902 .65619 m .39058 .65622 L .39022 .65589 L F
.39037 .65548 m .39065 .65589 L .39074 .65546 L F
.39025 .65559 m .39022 .6567 L .3902 .65614 L 0 0 .006 r
F
.39027 .65534 m .38956 .65562 L .39022 .6567 L .99 .735 .374 r
F
.38981 .65465 m .38956 .65562 L .39027 .65534 L F
.38458 .57875 m .38566 .57828 L .38314 .57795 L .598 .767 .96 r
F
.38614 .57872 m .38566 .57828 L .38458 .57875 L F
.38566 .57828 m .38063 .57369 L .38314 .57795 L F
.38086 .65658 m .38086 .65741 L .38075 .65594 L .875 .7 .179 r
F
.38101 .65736 m .37985 .65691 L .38044 .65757 L .659 .811 .956 r
F
.38133 .65724 m .38097 .65716 L .38101 .65736 L F
.38519 .65582 m .38087 .6567 L .38133 .65724 L F
.38519 .65582 m .38133 .65724 L .38144 .65736 L F
.38519 .65582 m .38144 .65736 L .38203 .6577 L F
.38361 .65823 m .38358 .65923 L .38361 .65823 L .849 .569 .514 r
F
.38519 .65582 m .38203 .6577 L .38233 .65787 L .659 .811 .956 r
F
.38519 .65582 m .38233 .65787 L .38296 .65805 L F
.38142 .65194 m .38054 .65174 L .38119 .65236 L F
.38054 .65174 m .38012 .65164 L .37991 .65194 L F
.38054 .65174 m .37991 .65194 L .37972 .6522 L F
.38195 .57975 m .38224 .5788 L .37753 .57888 L .598 .767 .96 r
F
.38387 .57937 m .38224 .5788 L .38195 .57975 L F
.38224 .5788 m .3751 .57629 L .37753 .57888 L F
.37989 .65239 m .37972 .6522 L .37961 .65237 L .659 .811 .956 r
F
.37989 .65239 m .37961 .65237 L .38046 .65306 L F
.38143 .65736 m .3814 .65813 L .38143 .65736 L .989 .724 .411 r
F
.38046 .65306 m .37945 .65313 L .38092 .65361 L .659 .811 .956 r
F
.38089 .65672 m .3814 .65813 L .38086 .65741 L .989 .724 .411 r
F
.38143 .65736 m .3814 .65813 L .38089 .65672 L F
.38032 .65396 m .37968 .65386 L .38011 .65435 L .659 .811 .956 r
F
.38032 .65396 m .38011 .65435 L .38027 .65452 L F
.38143 .65736 m .3814 .65813 L .38143 .65736 L .989 .724 .411 r
F
.38232 .65787 m .38229 .65874 L .38232 .65787 L .929 .648 .486 r
F
.38362 .65824 m .38558 .6595 L .38358 .65923 L .753 .483 .524 r
F
.38407 .65826 m .38362 .65824 L .38403 .65835 L .659 .811 .956 r
F
.38507 .65831 m .38558 .6595 L .38362 .65824 L .753 .483 .524 r
F
.38519 .65582 m .38296 .65805 L .38362 .65824 L .659 .811 .956 r
F
.38519 .65582 m .38362 .65824 L .38407 .65826 L F
.38361 .65823 m .38362 .65824 L .38358 .65923 L .849 .569 .514 r
F
.38885 .65747 m .38887 .65746 L .38881 .65884 L .484 .259 .497 r
F
.38519 .65582 m .38969 .65686 L .38971 .65684 L .659 .811 .956 r
F
.38519 .65582 m .38971 .65684 L .39017 .65619 L F
.3897 .65686 m .38966 .65825 L .38944 .65704 L .286 .104 .449 r
F
.3902 .65614 m .39022 .6567 L .39014 .65755 L 0 0 .006 r
F
.38971 .65684 m .39014 .65755 L .38966 .65825 L 0 0 .327 r
F
.39004 .65637 m .39014 .65755 L .38971 .65684 L F
.38887 .65746 m .38966 .65825 L .38881 .65884 L .286 .104 .449 r
F
.38944 .65704 m .38966 .65825 L .38887 .65746 L F
.39365 .58069 m .39927 .5817 L .39548 .58054 L .598 .767 .96 r
F
.39489 .58144 m .39927 .5817 L .39365 .58069 L F
.39927 .5817 m .4042 .58199 L .39548 .58054 L F
.39207 .65481 m .39305 .65625 L .39466 .65503 L .659 .811 .956 r
F
.38298 .58246 m .38068 .58171 L .37606 .58412 L .598 .767 .96 r
F
.38355 .58148 m .38068 .58171 L .38298 .58246 L F
.38068 .58171 m .37388 .58225 L .37606 .58412 L F
.38298 .58246 m .37553 .58425 L .38193 .58424 L F
.39586 .58507 m .39775 .58804 L .39988 .58732 L F
.65994 .32372 m .68479 .30981 L .65752 .31941 L .657 .779 .938 r
F
.65994 .32372 m .68951 .3185 L .68479 .30981 L F
.37216 .47254 m .35224 .46756 L .34811 .4737 L .662 .803 .95 r
F
.37561 .46981 m .35224 .46756 L .37216 .47254 L F
.39472 .34986 m .37117 .34525 L .37126 .35214 L .664 .425 .549 r
F
0 g
.34965 .35789 m
.37126 .35214 L
s
.39472 .34986 m .39459 .34297 L .37117 .34525 L .664 .425 .549 r
F
0 g
.3496 .35102 m
.37117 .34525 L
s
.22629 .73473 m .22672 .73733 L .2308 .73679 L .66 .811 .956 r
F
.22351 .73474 m .22672 .73733 L .22629 .73473 L F
.22351 .73474 m .22255 .73734 L .22672 .73733 L F
.60248 .33163 m .57088 .33689 L .601 .33632 L .657 .779 .939 r
F
.69183 .34148 m .72116 .32691 L .69119 .33217 L .656 .78 .94 r
F
.66177 .34205 m .69183 .34148 L .69119 .33217 L F
.22902 .73437 m .2308 .73679 L .23451 .73575 L .66 .811 .956 r
F
.22629 .73473 m .2308 .73679 L .22902 .73437 L F
0 g
.22672 .73733 m
.2308 .73679 L
s
.34854 .48515 m .32628 .48327 L .32475 .49282 L .66 .804 .952 r
F
0 g
.32475 .49282 m
.32784 .50197 L
s
.41166 .47597 m .42389 .46403 L .408 .47365 L .661 .803 .951 r
F
.41166 .47597 m .43118 .46872 L .42389 .46403 L F
.725 .6119 m .71541 .60592 L .71004 .60878 L .601 .765 .958 r
F
.72835 .61089 m .71541 .60592 L .725 .6119 L F
.21506 .7358 m .21851 .73385 L .21857 .73682 L .852 .58 .527 r
F
.21506 .7358 m .215 .73283 L .21851 .73385 L F
.21845 .73074 m .21851 .73385 L .22079 .73142 L .66 .81 .955 r
F
.21845 .73074 m .215 .73283 L .21851 .73385 L F
0 g
.21851 .73385 m
.22248 .73438 L
s
.74621 .61316 m .7523 .60566 L .74336 .61178 L .601 .765 .958 r
F
.74621 .61316 m .75801 .60845 L .7523 .60566 L F
.72215 .62309 m .70608 .622 L .72028 .62481 L .599 .766 .959 r
F
.7222 .61819 m .70985 .61363 L .70615 .6171 L .6 .765 .958 r
F
.72491 .61677 m .70985 .61363 L .7222 .61819 L F
.22085 .73439 m .22255 .73734 L .22351 .73474 L .66 .811 .956 r
F
.22085 .73439 m .21857 .73682 L .22255 .73734 L F
0 g
.22255 .73734 m
.22672 .73733 L
s
.74942 .62654 m .76224 .62165 L .7483 .62464 L .599 .766 .959 r
F
.74942 .62654 m .76443 .62547 L .76224 .62165 L F
.74832 .61974 m .75813 .61331 L .74626 .61803 L .6 .765 .958 r
F
.74832 .61974 m .76224 .61674 L .75813 .61331 L F
.70985 .61363 m .69193 .61428 L .70615 .6171 L F
.21218 .73138 m .21494 .72987 L .215 .73283 L .916 .637 .498 r
F
.21218 .73138 m .21213 .72842 L .21494 .72987 L F
0 g
.21494 .72987 m
.21827 .73084 L
s
.21656 .72679 m .21499 .72984 L .21842 .72775 L .66 .81 .955 r
F
.21656 .72679 m .21219 .72839 L .21499 .72984 L F
.4075 .46798 m .41382 .455 L .40278 .46631 L .662 .803 .95 r
F
.4075 .46798 m .42329 .45839 L .41382 .455 L F
.71004 .60878 m .6977 .60421 L .69222 .60943 L .601 .765 .958 r
F
.23754 .73133 m .23975 .72658 L .23983 .72954 L .304 .15 .501 r
F
.23762 .73429 m .23754 .73133 L .23983 .72954 L F
.23451 .73575 m .23754 .73133 L .23762 .73429 L .477 .281 .535 r
F
.2335 .72973 m .23754 .73133 L .23983 .72954 L .66 .81 .955 r
F
.23143 .73071 m .23754 .73133 L .2335 .72973 L F
0 g
.23444 .73279 m
.23754 .73133 L
s
.69743 .60905 m .69201 .60938 L .69193 .61428 L .14 .018 .441 r
F
.69743 .60905 m .69751 .60414 L .69201 .60938 L F
0 g
.68945 .61516 m
.69201 .60938 L
s
.2315 .73368 m .23451 .73575 L .23762 .73429 L .66 .811 .956 r
F
.22902 .73437 m .23451 .73575 L .2315 .73368 L F
0 g
.2308 .73679 m
.23451 .73575 L
s
.76442 .62056 m .77624 .61372 L .76224 .61674 L .6 .765 .958 r
F
.76442 .62056 m .77946 .61947 L .77624 .61372 L F
.41827 .35124 m .39459 .34297 L .39472 .34986 L .735 .483 .547 r
F
0 g
.37117 .34525 m
.39459 .34297 L
s
.39459 .34297 m
.4181 .34436 L
s
.41827 .35124 m
.44016 .35616 L
s
.57367 .32747 m .54073 .33746 L .57088 .33689 L .657 .779 .939 r
F
.60248 .33163 m .57367 .32747 L .57088 .33689 L F
.66177 .34205 m .69119 .33217 L .66136 .33741 L .656 .78 .94 r
F
.35224 .46756 m .32603 .47181 L .34811 .4737 L .662 .803 .95 r
F
.77946 .61947 m .77944 .61457 L .77621 .60881 L .984 .732 .341 r
F
0 g
.77944 .61457 m
.77957 .62051 L
s
.23983 .72954 m .23975 .72658 L .24105 .72458 L 0 0 .401 r
F
0 g
.23747 .72837 m
.23975 .72658 L
s
.23489 .72557 m .23968 .72656 L .24097 .72457 L .66 .81 .955 r
F
.23338 .72676 m .23968 .72656 L .23489 .72557 L F
.37278 .48397 m .34854 .48515 L .37067 .48702 L .66 .804 .952 r
F
0 g
.39472 .34986 m
.41827 .35124 L
s
.60552 .32037 m .57349 .32064 L .6021 .3248 L .657 .779 .938 r
F
.21851 .7337 m .21857 .73682 L .22085 .73439 L .66 .811 .956 r
F
.21851 .7337 m .21506 .7358 L .21857 .73682 L F
0 g
.21857 .73682 m
.22255 .73734 L
s
.72835 .61089 m .72212 .60387 L .71541 .60592 L .601 .765 .958 r
F
.73212 .61035 m .72212 .60387 L .72835 .61089 L F
.43621 .48008 m .45133 .46717 L .43163 .47446 L .66 .804 .952 r
F
.43621 .48008 m .45809 .47567 L .45133 .46717 L F
.4576 .46994 m .45036 .45569 L .45084 .46142 L .981 .689 .339 r
F
.45809 .47567 m .4576 .46994 L .45084 .46142 L F
0 g
.4576 .46994 m
.45982 .47926 L
s
.74336 .61178 m .74535 .60371 L .7399 .61081 L .601 .765 .958 r
F
.74336 .61178 m .7523 .60566 L .74535 .60371 L F
.21224 .73435 m .215 .73283 L .21506 .7358 L .916 .637 .498 r
F
.21224 .73435 m .21218 .73138 L .215 .73283 L F
.21657 .72977 m .215 .73283 L .21845 .73074 L .66 .81 .955 r
F
.21657 .72977 m .21218 .73138 L .215 .73283 L F
0 g
.215 .73283 m
.21834 .7338 L
s
.71384 .2108 m .692 .18883 L .69194 .19731 L .886 .596 .491 r
F
0 g
.71384 .2108 m
.72949 .22747 L
s
.57367 .32747 m .54466 .32328 L .54073 .33746 L .657 .779 .939 r
F
.54508 .33019 m .54073 .33746 L .54114 .34434 L 0 0 .291 r
F
0 g
.54158 .34273 m
.54184 .34432 L
s
.54508 .33019 m .54466 .32328 L .54073 .33746 L 0 0 .291 r
F
.23762 .73429 m .23983 .72954 L .2399 .7325 L .304 .15 .501 r
F
.23357 .7327 m .23762 .73429 L .2399 .7325 L .66 .811 .956 r
F
.2315 .73368 m .23762 .73429 L .23357 .7327 L F
0 g
.23451 .73575 m
.23762 .73429 L
s
.37242 .47823 m .35237 .47325 L .34821 .47941 L .661 .803 .951 r
F
.3759 .4755 m .35237 .47325 L .37242 .47823 L F
0 g
.39612 .49775 m
.39655 .48745 L
s
.37561 .46981 m .35913 .46206 L .35224 .46756 L .662 .803 .95 r
F
.3802 .4676 m .35913 .46206 L .37561 .46981 L F
.72491 .61677 m .71526 .61077 L .70985 .61363 L .6 .765 .958 r
F
.72828 .61575 m .71526 .61077 L .72491 .61677 L F
0 g
.38825 .49762 m
.38868 .48788 L
s
.74626 .61803 m .75238 .61052 L .74339 .61665 L .6 .765 .958 r
F
.74626 .61803 m .75813 .61331 L .75238 .61052 L F
.23983 .72954 m .24105 .72458 L .24113 .72754 L 0 0 .401 r
F
.2399 .7325 m .23983 .72954 L .24113 .72754 L F
.23502 .72854 m .23983 .72954 L .24113 .72754 L .66 .81 .955 r
F
.2335 .72973 m .23983 .72954 L .23502 .72854 L F
0 g
.23754 .73133 m
.23983 .72954 L
s
.73212 .61035 m .72971 .60278 L .72212 .60387 L .601 .765 .958 r
F
.73606 .61032 m .72971 .60278 L .73212 .61035 L F
.72215 .62309 m .70979 .61854 L .70608 .622 L .599 .766 .959 r
F
.72486 .62167 m .70979 .61854 L .72215 .62309 L F
.22092 .72518 m .21656 .72679 L .21842 .72775 L .66 .81 .955 r
F
.7399 .61081 m .73764 .60272 L .73606 .61032 L .601 .765 .958 r
F
.7399 .61081 m .74535 .60371 L .73764 .60272 L F
.41208 .48169 m .42433 .46978 L .40841 .47938 L .66 .804 .952 r
F
.41208 .48169 m .43163 .47446 L .42433 .46978 L F
.21026 .7296 m .21213 .72842 L .21218 .73138 L .976 .697 .432 r
F
.21026 .7296 m .2102 .72663 L .21213 .72842 L F
0 g
.21213 .72842 m
.21494 .72987 L
s
.21528 .7256 m .21219 .72839 L .21656 .72679 L .66 .81 .955 r
F
.21528 .7256 m .21028 .72661 L .21219 .72839 L F
.66072 .33054 m .68576 .31658 L .65829 .32622 L .657 .779 .939 r
F
.66072 .33054 m .6905 .3253 L .68576 .31658 L F
.7483 .62464 m .75813 .61823 L .74624 .62294 L .599 .766 .959 r
F
.7483 .62464 m .76224 .62165 L .75813 .61823 L F
.70979 .61854 m .69184 .61919 L .70608 .622 L F
.71541 .60592 m .6977 .60421 L .71004 .60878 L .601 .765 .958 r
F
.70985 .61363 m .69743 .60905 L .69193 .61428 L .6 .765 .958 r
F
.69736 .61397 m .69193 .61428 L .69184 .61919 L .14 .018 .441 r
F
.69736 .61397 m .69743 .60905 L .69193 .61428 L F
0 g
.68936 .62004 m
.69193 .61428 L
s
.76443 .62547 m .77626 .61865 L .76224 .62165 L .599 .766 .959 r
F
.76443 .62547 m .77949 .62439 L .77626 .61865 L F
.73606 .61032 m .73764 .60272 L .72971 .60278 L .601 .765 .958 r
F
.76209 .61186 m .76991 .6037 L .75801 .60845 L F
.76209 .61186 m .776 .60885 L .76991 .6037 L F
.23489 .72557 m .24097 .72457 L .23576 .72424 L .66 .81 .955 r
F
0 g
.37126 .35214 m
.39472 .34986 L
s
.22586 .73212 m .22629 .73473 L .22902 .73437 L .66 .811 .956 r
F
.22447 .73212 m .22629 .73473 L .22586 .73212 L F
.22447 .73212 m .22351 .73474 L .22629 .73473 L F
.60301 .33851 m .57135 .34376 L .60153 .34319 L .656 .78 .94 r
F
.22723 .73194 m .22902 .73437 L .2315 .73368 L .66 .811 .956 r
F
.22586 .73212 m .22902 .73437 L .22723 .73194 L F
.40278 .46631 m .40279 .45314 L .39729 .4654 L .662 .803 .95 r
F
.40278 .46631 m .41382 .455 L .40279 .45314 L F
.77946 .61947 m .77621 .60881 L .77624 .61372 L .984 .732 .341 r
F
.77949 .62439 m .77946 .61947 L .77624 .61372 L F
0 g
.77946 .61947 m
.7796 .6254 L
s
.408 .47365 m .41436 .46063 L .40324 .47197 L .661 .803 .951 r
F
.408 .47365 m .42389 .46403 L .41436 .46063 L F
.68951 .3185 m .71235 .3001 L .68479 .30981 L .657 .779 .938 r
F
.68951 .3185 m .7192 .31326 L .71235 .3001 L F
.21663 .73274 m .21506 .7358 L .21851 .7337 L .66 .811 .956 r
F
.21663 .73274 m .21224 .73435 L .21506 .7358 L F
0 g
.21506 .7358 m
.21857 .73682 L
s
.60641 .1765 m .57875 .17448 L .57838 .1829 L .563 .321 .507 r
F
.60641 .1765 m .60671 .16807 L .57875 .17448 L F
0 g
.55462 .18561 m
.57875 .17448 L
s
.62931 .46292 m .62857 .45721 L .64622 .45494 L .667 .436 .561 r
F
.61193 .46266 m .62857 .45721 L .62931 .46292 L .735 .485 .55 r
F
.61193 .46266 m .61121 .45695 L .62857 .45721 L F
0 g
.39338 .56366 m
.39612 .49775 L
s
.24113 .72754 m .24105 .72458 L .24129 .7225 L 0 0 .124 r
F
0 g
.23975 .72658 m
.24105 .72458 L
s
.23576 .72424 m .24097 .72457 L .24121 .72251 L .66 .81 .955 r
F
.22314 .73195 m .22351 .73474 L .22447 .73212 L .66 .811 .956 r
F
.22314 .73195 m .22085 .73439 L .22351 .73474 L F
0 g
.38536 .56318 m
.38825 .49762 L
s
.63013 .44461 m .62859 .45702 L .64616 .45476 L .661 .804 .952 r
F
.61852 .44443 m .62859 .45702 L .63013 .44461 L F
.61852 .44443 m .61132 .45676 L .62859 .45702 L F
.692 .18883 m .69206 .18039 L .6656 .17114 L .809 .527 .512 r
F
0 g
.69206 .18039 m
.71384 .19392 L
s
.35237 .47325 m .32599 .47752 L .34821 .47941 L .661 .803 .951 r
F
.43053 .46307 m .43924 .4487 L .42329 .45839 L .662 .803 .95 r
F
.43053 .46307 m .45007 .4558 L .43924 .4487 L F
.22847 .73159 m .2315 .73368 L .23357 .7327 L .66 .811 .956 r
F
.22723 .73194 m .2315 .73368 L .22847 .73159 L F
.64699 .46065 m .64622 .45494 L .66305 .45028 L .593 .384 .567 r
F
.62931 .46292 m .64622 .45494 L .64699 .46065 L .667 .436 .561 r
F
0 g
.62857 .45721 m
.64622 .45494 L
s
.72828 .61575 m .72202 .60871 L .71526 .61077 L .6 .765 .958 r
F
.73207 .61521 m .72202 .60871 L .72828 .61575 L F
.74339 .61665 m .74539 .60855 L .7399 .61567 L F
.74339 .61665 m .75238 .61052 L .74539 .60855 L F
.2399 .7325 m .24113 .72754 L .24121 .73051 L 0 0 .401 r
F
.23509 .7315 m .2399 .7325 L .24121 .73051 L .66 .811 .956 r
F
.23357 .7327 m .2399 .7325 L .23509 .7315 L F
0 g
.23762 .73429 m
.2399 .7325 L
s
.22097 .72815 m .21657 .72977 L .21845 .73074 L .66 .81 .955 r
F
.22029 .72458 m .21656 .72679 L .22092 .72518 L F
.22029 .72458 m .21528 .7256 L .21656 .72679 L F
.21031 .73257 m .21218 .73138 L .21224 .73435 L .976 .697 .432 r
F
.21031 .73257 m .21026 .7296 L .21218 .73138 L F
.21529 .72857 m .21218 .73138 L .21657 .72977 L .66 .81 .955 r
F
.21529 .72857 m .21026 .7296 L .21218 .73138 L F
0 g
.21218 .73138 m
.215 .73283 L
s
.64193 .44309 m .64616 .45476 L .6629 .45013 L .661 .804 .952 r
F
.63013 .44461 m .64616 .45476 L .64193 .44309 L F
.65752 .31941 m .67628 .30234 L .65322 .31573 L .657 .779 .938 r
F
.65752 .31941 m .68479 .30981 L .67628 .30234 L F
.57415 .33436 m .54114 .34434 L .57135 .34376 L .656 .78 .94 r
F
.60301 .33851 m .57415 .33436 L .57135 .34376 L F
.22197 .73161 m .22085 .73439 L .22314 .73195 L .66 .811 .956 r
F
.22197 .73161 m .21851 .7337 L .22085 .73439 L F
.45809 .47567 m .45084 .46142 L .45133 .46717 L .981 .689 .339 r
F
0 g
.45809 .47567 m
.46031 .48496 L
s
.3802 .4676 m .36833 .45759 L .35913 .46206 L .662 .803 .95 r
F
.3856 .46607 m .36833 .45759 L .3802 .4676 L F
.23502 .72854 m .24113 .72754 L .23588 .7272 L .66 .81 .955 r
F
.2302 .72753 m .23502 .72854 L .23588 .7272 L F
.23576 .72424 m .24121 .72251 L .23591 .72286 L F
.23053 .7239 m .23576 .72424 L .23591 .72286 L F
.22951 .7311 m .23357 .7327 L .23509 .7315 L .66 .811 .956 r
F
.22847 .73159 m .23357 .7327 L .22951 .7311 L F
.72486 .62167 m .7152 .61569 L .70979 .61854 L .599 .766 .959 r
F
.72824 .62066 m .7152 .61569 L .72486 .62167 L F
.74624 .62294 m .75238 .61544 L .74337 .62156 L F
.74624 .62294 m .75813 .61823 L .75238 .61544 L F
.37278 .48397 m .3527 .47901 L .34854 .48515 L .66 .804 .952 r
F
.37627 .48124 m .3527 .47901 L .37278 .48397 L F
.60592 .32719 m .57367 .32747 L .60248 .33163 L .657 .779 .939 r
F
.24113 .72754 m .24129 .7225 L .24137 .72547 L 0 0 .124 r
F
.24121 .73051 m .24113 .72754 L .24137 .72547 L F
.23588 .7272 m .24113 .72754 L .24137 .72547 L .66 .81 .955 r
F
0 g
.23983 .72954 m
.24113 .72754 L
s
.73207 .61521 m .72965 .60762 L .72202 .60871 L .6 .765 .958 r
F
.73604 .61518 m .72965 .60762 L .73207 .61521 L F
.39729 .4654 m .39097 .45296 L .39143 .46531 L .662 .803 .95 r
F
.39729 .4654 m .40279 .45314 L .39097 .45296 L F
.7399 .61567 m .73763 .60756 L .73604 .61518 L .6 .765 .958 r
F
.7399 .61567 m .74539 .60855 L .73763 .60756 L F
.3759 .4755 m .35931 .46773 L .35237 .47325 L .661 .803 .951 r
F
.38052 .47328 m .35931 .46773 L .3759 .4755 L F
.20935 .72759 m .2102 .72663 L .21026 .7296 L .957 .714 .262 r
F
.20935 .72759 m .2093 .72463 L .2102 .72663 L F
0 g
.2102 .72663 m
.21213 .72842 L
s
.21469 .72427 m .21028 .72661 L .21528 .7256 L .66 .81 .955 r
F
.21469 .72427 m .20938 .72462 L .21028 .72661 L F
.71526 .61077 m .69743 .60905 L .70985 .61363 L .6 .765 .958 r
F
.70979 .61854 m .69736 .61397 L .69184 .61919 L .599 .766 .959 r
F
0 g
.68927 .62493 m
.69184 .61919 L
s
.73604 .61518 m .73763 .60756 L .72965 .60762 L .6 .765 .958 r
F
.57415 .33436 m .54508 .33019 L .54114 .34434 L .656 .78 .94 r
F
0 g
.54114 .34434 m
.54339 .35812 L
s
.76224 .61674 m .7701 .60855 L .75813 .61331 L .6 .765 .958 r
F
.76224 .61674 m .77624 .61372 L .7701 .60855 L F
.22103 .73112 m .21851 .7337 L .22197 .73161 L .66 .811 .956 r
F
.22103 .73112 m .21663 .73274 L .21851 .7337 L F
.22033 .72755 m .21657 .72977 L .22097 .72815 L .66 .81 .955 r
F
.22033 .72755 m .21529 .72857 L .21657 .72977 L F
.77949 .62439 m .77624 .61372 L .77626 .61865 L .984 .732 .341 r
F
0 g
.77949 .62439 m
.77963 .6303 L
s
.21535 .73155 m .21224 .73435 L .21663 .73274 L .66 .811 .956 r
F
.21535 .73155 m .21031 .73257 L .21224 .73435 L F
0 g
.21224 .73435 m
.21506 .7358 L
s
.3856 .46607 m .3792 .45448 L .36833 .45759 L .662 .803 .95 r
F
.39143 .46531 m .3792 .45448 L .3856 .46607 L F
.22 .72392 m .21528 .7256 L .22029 .72458 L .66 .81 .955 r
F
.22 .72392 m .21469 .72427 L .21528 .7256 L F
.23053 .7239 m .23591 .72286 L .23061 .72321 L F
.39143 .46531 m .39097 .45296 L .3792 .45448 L .662 .803 .95 r
F
.59595 .4599 m .61121 .45695 L .61193 .46266 L .803 .534 .531 r
F
.59595 .4599 m .59525 .45417 L .61121 .45695 L F
0 g
.61121 .45695 m
.62857 .45721 L
s
.40324 .47197 m .40325 .45877 L .39772 .47106 L .661 .803 .951 r
F
.40324 .47197 m .41436 .46063 L .40325 .45877 L F
.40841 .47938 m .41479 .46639 L .40365 .47771 L .66 .804 .952 r
F
.40841 .47938 m .42433 .46978 L .41479 .46639 L F
.23509 .7315 m .24121 .73051 L .23596 .73017 L .66 .811 .956 r
F
.23027 .7305 m .23509 .7315 L .23596 .73017 L F
.22951 .7311 m .23509 .7315 L .23027 .7305 L F
.35224 .46756 m .33212 .46254 L .32603 .47181 L .662 .803 .95 r
F
0 g
.22596 .72995 m
.22783 .72976 L
s
.22596 .72995 m
.22596 .72995 L
s
.22402 .72971 m
.22596 .72995 L
s
.63006 .46864 m .62931 .46292 L .64699 .46065 L .667 .436 .561 r
F
.61266 .4684 m .62931 .46292 L .63006 .46864 L .735 .485 .55 r
F
.61266 .4684 m .61193 .46266 L .62931 .46292 L F
.63087 .45048 m .62931 .46292 L .64699 .46065 L .66 .805 .952 r
F
.61919 .4503 m .62931 .46292 L .63087 .45048 L F
.61919 .4503 m .61193 .46266 L .62931 .46292 L F
.60787 .44254 m .61132 .45676 L .61852 .44443 L .661 .804 .952 r
F
.60787 .44254 m .59544 .454 L .61132 .45676 L F
.33212 .46822 m .3257 .47178 L .32599 .47752 L .025 0 .434 r
F
.33212 .46822 m .33182 .46246 L .3257 .47178 L F
0 g
.32417 .48137 m
.3257 .47178 L
s
.23591 .72286 m .24121 .72251 L .24036 .72051 L .66 .81 .955 r
F
.24137 .72547 m .24129 .7225 L .24043 .72049 L .947 .705 .241 r
F
0 g
.24105 .72458 m
.24111 .72409 L
s
.23588 .7272 m .24137 .72547 L .23604 .72582 L .66 .81 .955 r
F
.23063 .72687 m .23588 .7272 L .23604 .72582 L F
.2302 .72753 m .23588 .7272 L .23063 .72687 L F
.66136 .33741 m .68645 .32347 L .65892 .3331 L .656 .78 .94 r
F
.66136 .33741 m .69119 .33217 L .68645 .32347 L F
.60552 .32037 m .58022 .31172 L .57349 .32064 L .657 .779 .938 r
F
.61067 .31651 m .58022 .31172 L .60552 .32037 L F
.72824 .62066 m .72197 .61364 L .7152 .61569 L .599 .766 .959 r
F
.73204 .62012 m .72197 .61364 L .72824 .62066 L F
.74337 .62156 m .74537 .61348 L .73988 .62059 L F
.74337 .62156 m .75238 .61544 L .74537 .61348 L F
.3527 .47901 m .32628 .48327 L .34854 .48515 L .66 .804 .952 r
F
.23591 .72286 m .24036 .72051 L .23533 .72153 L .66 .81 .955 r
F
.23061 .72321 m .23591 .72286 L .23533 .72153 L F
.24121 .73051 m .24137 .72547 L .24145 .72843 L 0 0 .124 r
F
.23596 .73017 m .24121 .73051 L .24145 .72843 L .66 .811 .956 r
F
0 g
.2399 .7325 m
.24121 .73051 L
s
.43118 .46872 m .43995 .4543 L .42389 .46403 L .661 .803 .951 r
F
.43118 .46872 m .45084 .46142 L .43995 .4543 L F
.22544 .7295 m .22586 .73212 L .22723 .73194 L .66 .811 .956 r
F
.22544 .7295 m .22447 .73212 L .22586 .73212 L F
.22544 .7295 m .22723 .73194 L .22847 .73159 L F
0 g
.22783 .72976 m
.22899 .72935 L
s
.64699 .46065 m .66305 .45028 L .66385 .45599 L .593 .384 .567 r
F
.64777 .46637 m .64699 .46065 L .66385 .45599 L F
.63006 .46864 m .64699 .46065 L .64777 .46637 L .667 .436 .561 r
F
.64275 .44895 m .64699 .46065 L .66385 .45599 L .66 .805 .952 r
F
.63087 .45048 m .64699 .46065 L .64275 .44895 L F
0 g
.62931 .46292 m
.64699 .46065 L
s
.20941 .73057 m .21026 .7296 L .21031 .73257 L .957 .714 .262 r
F
.20941 .73057 m .20935 .72759 L .21026 .7296 L F
.21469 .72724 m .21026 .7296 L .21529 .72857 L .66 .81 .955 r
F
.21469 .72724 m .20935 .72759 L .21026 .7296 L F
0 g
.21026 .7296 m
.21218 .73138 L
s
.23061 .72321 m .23533 .72153 L .23032 .72254 L .66 .81 .955 r
F
.22544 .7295 m .22314 .73195 L .22447 .73212 L .66 .811 .956 r
F
0 g
.22274 .72926 m
.22402 .72971 L
s
.22899 .72935 m
.22973 .72881 L
s
.6905 .3253 m .71351 .30684 L .68576 .31658 L .657 .779 .939 r
F
.6905 .3253 m .72041 .32003 L .71351 .30684 L F
.22544 .7295 m .22847 .73159 L .22951 .7311 L .66 .811 .956 r
F
0 g
.22184 .7287 m
.22274 .72926 L
s
.71541 .60592 m .70575 .59989 L .6977 .60421 L .601 .765 .958 r
F
.72212 .60387 m .70575 .59989 L .71541 .60592 L F
.22039 .73052 m .21663 .73274 L .22103 .73112 L .66 .811 .956 r
F
.22039 .73052 m .21535 .73155 L .21663 .73274 L F
.22544 .7295 m .22197 .73161 L .22314 .73195 L F
.75801 .60845 m .76133 .59949 L .7523 .60566 L .601 .765 .958 r
F
.75801 .60845 m .76991 .6037 L .76133 .59949 L F
.38052 .47328 m .36857 .46324 L .35931 .46773 L .661 .803 .951 r
F
.38595 .47174 m .36857 .46324 L .38052 .47328 L F
.22003 .72688 m .21529 .72857 L .22033 .72755 L .66 .81 .955 r
F
.22003 .72688 m .21469 .72724 L .21529 .72857 L F
.23063 .72687 m .23604 .72582 L .2307 .72617 L F
.22006 .72323 m .21469 .72427 L .22 .72392 L F
.73204 .62012 m .72961 .61255 L .72197 .61364 L .599 .766 .959 r
F
.73601 .6201 m .72961 .61255 L .73204 .62012 L F
.22544 .7295 m .22951 .7311 L .23027 .7305 L .66 .811 .956 r
F
.73988 .62059 m .7376 .6125 L .73601 .6201 L .599 .766 .959 r
F
.73988 .62059 m .74537 .61348 L .7376 .6125 L F
0 g
.22973 .72881 m
.23013 .72817 L
s
.72041 .32003 m .71965 .31318 L .71277 .29995 L .951 .662 .217 r
F
0 g
.71994 .31879 m
.71995 .31916 L
s
.22125 .72804 m
.22184 .7287 L
s
.7152 .61569 m .69736 .61397 L .70979 .61854 L .599 .766 .959 r
F
.24137 .72547 m .24043 .72049 L .24051 .72346 L .947 .705 .241 r
F
.23604 .72582 m .24137 .72547 L .24051 .72346 L .66 .81 .955 r
F
.24145 .72843 m .24137 .72547 L .24051 .72346 L .947 .705 .241 r
F
0 g
.24113 .72754 m
.24119 .72705 L
s
.23032 .72254 m .23408 .72033 L .22969 .72195 L .66 .81 .955 r
F
0 g
.22953 .72478 m
.22976 .72226 L
s
.23032 .72254 m .23533 .72153 L .23408 .72033 L .66 .81 .955 r
F
0 g
.22979 .72191 m
.23592 .65263 L
s
.23596 .73017 m .24145 .72843 L .23611 .72879 L .66 .811 .956 r
F
.2307 .72984 m .23596 .73017 L .23611 .72879 L F
.23027 .7305 m .23596 .73017 L .2307 .72984 L F
.21482 .72289 m .20938 .72462 L .21469 .72427 L .66 .81 .955 r
F
.22006 .72323 m .21482 .72289 L .21469 .72427 L F
.66385 .45599 m .66305 .45028 L .67798 .44352 L .505 .323 .567 r
F
0 g
.65413 .45275 m
.66305 .45028 L
s
.73601 .6201 m .7376 .6125 L .72961 .61255 L .599 .766 .959 r
F
.65829 .32622 m .67719 .30909 L .65397 .32253 L .657 .779 .939 r
F
.65829 .32622 m .68576 .31658 L .67719 .30909 L F
.58022 .31172 m .54468 .31646 L .57349 .32064 L .657 .779 .938 r
F
.37627 .48124 m .35966 .4735 L .3527 .47901 L .66 .804 .952 r
F
.38089 .47902 m .35966 .4735 L .37627 .48124 L F
.22544 .7295 m .22103 .73112 L .22197 .73161 L .66 .811 .956 r
F
.76224 .62165 m .77012 .61349 L .75813 .61823 L .599 .766 .959 r
F
.76224 .62165 m .77626 .61865 L .77012 .61349 L F
.39772 .47106 m .39136 .45859 L .39182 .47098 L .661 .803 .951 r
F
.39772 .47106 m .40325 .45877 L .39136 .45859 L F
.65318 .43996 m .6629 .45013 L .67777 .4434 L .661 .804 .952 r
F
.64193 .44309 m .6629 .45013 L .65318 .43996 L F
.70554 .60472 m .69751 .60414 L .69743 .60905 L .361 .188 .507 r
F
.70554 .60472 m .70561 .5998 L .69751 .60414 L F
0 g
.69201 .60938 m
.69751 .60414 L
s
.23604 .72582 m .24051 .72346 L .23546 .72448 L .66 .81 .955 r
F
.2307 .72617 m .23604 .72582 L .23546 .72448 L F
.21482 .72289 m .20957 .72255 L .20938 .72462 L F
.20954 .72552 m .2093 .72463 L .20935 .72759 L 0 0 .095 r
F
.20954 .72552 m .20949 .72254 L .2093 .72463 L F
0 g
.20954 .72515 m
.2102 .72663 L
s
.35913 .46206 m .33212 .46254 L .35224 .46756 L .662 .803 .95 r
F
.22544 .7295 m .23027 .7305 L .2307 .72984 L .66 .811 .956 r
F
.21475 .73021 m .21031 .73257 L .21535 .73155 L F
.21475 .73021 m .20941 .73057 L .21031 .73257 L F
0 g
.21031 .73257 m
.21224 .73435 L
s
.22049 .72256 m .21482 .72289 L .22006 .72323 L .66 .81 .955 r
F
.2307 .72617 m .23546 .72448 L .23041 .72551 L F
.77624 .61372 m .77621 .60881 L .77009 .60362 L .955 .681 .479 r
F
0 g
.77621 .60881 m
.77944 .61457 L
s
.23012 .7274 m
.23013 .72817 L
s
.23533 .72153 m .23847 .71871 L .23408 .72033 L .66 .81 .955 r
F
.23533 .72153 m .24036 .72051 L .23847 .71871 L F
.60611 .18499 m .57838 .1829 L .578 .19137 L .563 .321 .507 r
F
0 g
.55375 .20245 m
.578 .19137 L
s
.60611 .18499 m .60641 .1765 L .57838 .1829 L .563 .321 .507 r
F
0 g
.55418 .19401 m
.57838 .1829 L
s
.22103 .72727 m
.22125 .72804 L
s
.60646 .33408 m .57415 .33436 L .60301 .33851 L .656 .78 .94 r
F
.38595 .47174 m .37951 .46012 L .36857 .46324 L .661 .803 .951 r
F
.39182 .47098 m .37951 .46012 L .38595 .47174 L F
.22969 .72195 m .23222 .71935 L .22875 .72146 L .66 .81 .955 r
F
.22969 .72195 m .23408 .72033 L .23222 .71935 L F
.22544 .7295 m .22039 .73052 L .22103 .73112 L .66 .811 .956 r
F
.65322 .31573 m .66451 .29666 L .64735 .31294 L .657 .779 .938 r
F
.65322 .31573 m .67628 .30234 L .66451 .29666 L F
.692 .18883 m .6656 .17114 L .66547 .17958 L .809 .527 .512 r
F
.69194 .19731 m .692 .18883 L .66547 .17958 L F
0 g
.692 .18883 m
.71384 .20234 L
s
.59665 .46564 m .61193 .46266 L .61266 .4684 L .803 .534 .531 r
F
.59665 .46564 m .59595 .4599 L .61193 .46266 L F
.60847 .44841 m .61193 .46266 L .61919 .4503 L .66 .805 .952 r
F
.60847 .44841 m .59595 .4599 L .61193 .46266 L F
0 g
.61193 .46266 m
.62931 .46292 L
s
.39182 .47098 m .39136 .45859 L .37951 .46012 L .661 .803 .951 r
F
.40365 .47771 m .40367 .46454 L .39812 .47681 L .66 .804 .952 r
F
.40365 .47771 m .41479 .46639 L .40367 .46454 L F
.22009 .72986 m .21535 .73155 L .22039 .73052 L .66 .811 .956 r
F
.22009 .72986 m .21475 .73021 L .21535 .73155 L F
.63162 .45623 m .63006 .46864 L .64777 .46637 L .659 .805 .953 r
F
.61993 .45606 m .63006 .46864 L .63162 .45623 L F
.61993 .45606 m .61266 .4684 L .63006 .46864 L F
.2307 .72984 m .23611 .72879 L .23077 .72915 L .66 .811 .956 r
F
.22544 .7295 m .2307 .72984 L .23077 .72915 L F
.2201 .72619 m .21469 .72724 L .22003 .72688 L .66 .81 .955 r
F
.24051 .72346 m .24043 .72049 L .23854 .71869 L .977 .696 .422 r
F
0 g
.24043 .72049 m
.24129 .7225 L
s
.35237 .47325 m .33212 .46822 L .32599 .47752 L .661 .803 .951 r
F
.33243 .474 m .32599 .47752 L .32628 .48327 L .025 0 .434 r
F
.33243 .474 m .33212 .46822 L .32599 .47752 L F
0 g
.32446 .48709 m
.32599 .47752 L
s
.22049 .72256 m .21567 .72155 L .21482 .72289 L .66 .81 .955 r
F
.22124 .72196 m .21567 .72155 L .22049 .72256 L F
.24145 .72843 m .24051 .72346 L .24059 .72643 L .947 .705 .241 r
F
.23611 .72879 m .24145 .72843 L .24059 .72643 L .66 .811 .956 r
F
0 g
.24121 .73051 m
.24145 .72843 L
s
.23041 .72551 m .23419 .72328 L .22978 .72491 L .66 .81 .955 r
F
.23041 .72551 m .23546 .72448 L .23419 .72328 L F
.21483 .72585 m .20935 .72759 L .21469 .72724 L F
.2201 .72619 m .21483 .72585 L .21469 .72724 L F
.43163 .47446 m .44042 .46007 L .42433 .46978 L .66 .804 .952 r
F
.43163 .47446 m .45133 .46717 L .44042 .46007 L F
.22875 .72146 m .22988 .71866 L .22759 .72112 L .66 .81 .955 r
F
.22875 .72146 m .23222 .71935 L .22988 .71866 L F
0 g
.22103 .72727 m
.22148 .7263 L
s
.21567 .72155 m .20957 .72255 L .21482 .72289 L .66 .81 .955 r
F
.23611 .72879 m .24059 .72643 L .23554 .72745 L .66 .811 .956 r
F
.23077 .72915 m .23611 .72879 L .23554 .72745 L F
.22544 .7295 m .22009 .72986 L .22039 .73052 L F
.64777 .46637 m .66385 .45599 L .66465 .46172 L .593 .384 .567 r
F
.64352 .4547 m .64777 .46637 L .66465 .46172 L .659 .805 .953 r
F
.63162 .45623 m .64777 .46637 L .64352 .4547 L F
0 g
.63006 .46864 m
.64777 .46637 L
s
.2096 .72849 m .20935 .72759 L .20941 .73057 L 0 0 .095 r
F
.21483 .72585 m .20954 .72552 L .20935 .72759 L .66 .81 .955 r
F
.2096 .72849 m .20954 .72552 L .20935 .72759 L 0 0 .095 r
F
0 g
.20959 .72812 m
.21026 .7296 L
s
.71526 .61077 m .70554 .60472 L .69743 .60905 L .6 .765 .958 r
F
.72202 .60871 m .70554 .60472 L .71526 .61077 L F
.75813 .61331 m .76147 .60432 L .75238 .61052 L F
.75813 .61331 m .7701 .60855 L .76147 .60432 L F
.22124 .72196 m .21717 .72035 L .21567 .72155 L .66 .81 .955 r
F
.22227 .72147 m .21717 .72035 L .22124 .72196 L F
.60592 .32719 m .58045 .31852 L .57367 .32747 L .657 .779 .939 r
F
.61111 .32332 m .58045 .31852 L .60592 .32719 L F
.23077 .72915 m .23554 .72745 L .23048 .72848 L .66 .811 .956 r
F
.22544 .7295 m .23077 .72915 L .23048 .72848 L F
.22053 .72552 m .21483 .72585 L .2201 .72619 L .66 .81 .955 r
F
.23546 .72448 m .23862 .72166 L .23419 .72328 L F
.23546 .72448 m .24051 .72346 L .23862 .72166 L F
.22759 .72112 m .22723 .71831 L .22626 .72094 L F
.22759 .72112 m .22988 .71866 L .22723 .71831 L F
.23408 .72033 m .23569 .71724 L .23222 .71935 L F
.23408 .72033 m .23847 .71871 L .23569 .71724 L F
.38089 .47902 m .36893 .46902 L .35966 .4735 L .66 .804 .952 r
F
.38633 .47749 m .36893 .46902 L .38089 .47902 L F
.22978 .72491 m .23232 .7223 L .22884 .72442 L .66 .81 .955 r
F
.22978 .72491 m .23419 .72328 L .23232 .7223 L F
.22544 .7295 m .22016 .72917 L .22009 .72986 L .66 .811 .956 r
F
.22544 .7295 m .22059 .7285 L .22016 .72917 L F
.22544 .7295 m .22135 .7279 L .22059 .7285 L F
.22544 .7295 m .22239 .7274 L .22135 .7279 L F
.22544 .7295 m .22364 .72705 L .22239 .7274 L F
.22544 .7295 m .22501 .72687 L .22364 .72705 L F
.22544 .7295 m .2264 .72687 L .22501 .72687 L F
.22544 .7295 m .22774 .72705 L .2264 .72687 L F
.22544 .7295 m .22891 .72739 L .22774 .72705 L F
.22544 .7295 m .22985 .72788 L .22891 .72739 L F
0 g
.22939 .72641 m
.23012 .7274 L
s
.22544 .7295 m .23048 .72848 L .22985 .72788 L .66 .811 .956 r
F
.22227 .72147 m .21924 .71937 L .21717 .72035 L .66 .81 .955 r
F
.22351 .72112 m .21924 .71937 L .22227 .72147 L F
.61067 .31651 m .5905 .3039 L .58022 .31172 L .657 .779 .938 r
F
.61721 .31349 m .5905 .3039 L .61067 .31651 L F
.70547 .60965 m .69743 .60905 L .69736 .61397 L .361 .188 .507 r
F
.70547 .60965 m .70554 .60472 L .69743 .60905 L F
0 g
.69193 .61428 m
.69743 .60905 L
s
.72212 .60387 m .71584 .59679 L .70575 .59989 L .601 .765 .958 r
F
.72971 .60278 m .71584 .59679 L .72212 .60387 L F
.22626 .72094 m .22445 .71831 L .22487 .72094 L .66 .81 .955 r
F
.22626 .72094 m .22723 .71831 L .22445 .71831 L F
.22016 .72917 m .21475 .73021 L .22009 .72986 L .66 .811 .956 r
F
.24051 .72346 m .23854 .71869 L .23862 .72166 L .977 .696 .422 r
F
.24059 .72643 m .24051 .72346 L .23862 .72166 L F
0 g
.24051 .72346 m
.24137 .72547 L
s
.69119 .33217 m .71426 .31375 L .68645 .32347 L .656 .78 .94 r
F
.69119 .33217 m .72116 .32691 L .71426 .31375 L F
0 g
.22796 .72563 m
.22939 .72641 L
s
.22939 .72641 m
.22939 .72641 L
s
.45084 .46142 m .45036 .45569 L .43948 .44855 L .939 .646 .459 r
F
0 g
.45036 .45569 m
.45711 .46424 L
s
.7523 .60566 m .75086 .59653 L .74535 .60371 L .601 .765 .958 r
F
.7523 .60566 m .76133 .59949 L .75086 .59653 L F
.66385 .45599 m .67798 .44352 L .67881 .44924 L .505 .323 .567 r
F
.66465 .46172 m .66385 .45599 L .67881 .44924 L F
.65407 .44581 m .66385 .45599 L .67881 .44924 L .66 .805 .952 r
F
.64275 .44895 m .66385 .45599 L .65407 .44581 L F
0 g
.65487 .45847 m
.66385 .45599 L
s
.42329 .45839 m .42501 .44353 L .41382 .455 L .662 .803 .95 r
F
.42329 .45839 m .43924 .4487 L .42501 .44353 L F
.22351 .72112 m .22172 .71867 L .21924 .71937 L .66 .81 .955 r
F
.22487 .72094 m .22172 .71867 L .22351 .72112 L F
0 g
.22148 .7263 m
.22148 .7263 L
s
.22148 .7263 m
.22268 .72556 L
s
.22487 .72094 m .22445 .71831 L .22172 .71867 L .66 .81 .955 r
F
.22053 .72552 m .21568 .72451 L .21483 .72585 L F
.22129 .72492 m .21568 .72451 L .22053 .72552 L F
.39812 .47681 m .39175 .46437 L .39221 .47673 L .66 .804 .952 r
F
.39812 .47681 m .40367 .46454 L .39175 .46437 L F
.77624 .61372 m .77009 .60362 L .7701 .60855 L .955 .681 .479 r
F
.77626 .61865 m .77624 .61372 L .7701 .60855 L F
0 g
.77624 .61372 m
.77946 .61947 L
s
.21567 .72155 m .21083 .72054 L .20957 .72255 L .66 .81 .955 r
F
.21082 .7235 m .20949 .72254 L .20954 .72552 L 0 0 .386 r
F
.21082 .7235 m .21076 .72053 L .20949 .72254 L F
0 g
.2093 .72463 m
.20949 .72254 L
s
.23048 .72848 m .23427 .72626 L .22985 .72788 L .66 .811 .956 r
F
.23048 .72848 m .23554 .72745 L .23427 .72626 L F
.21488 .72883 m .20941 .73057 L .21475 .73021 L F
.22016 .72917 m .21488 .72883 L .21475 .73021 L F
.22884 .72442 m .22997 .72161 L .22767 .72407 L .66 .81 .955 r
F
.22884 .72442 m .23232 .7223 L .22997 .72161 L F
.35931 .46773 m .33212 .46822 L .35237 .47325 L .661 .803 .951 r
F
.6362 .17536 m .60671 .16807 L .60641 .1765 L .654 .396 .517 r
F
.6362 .17536 m .63641 .16692 L .60671 .16807 L F
0 g
.57875 .17448 m
.60671 .16807 L
s
.21568 .72451 m .20954 .72552 L .21483 .72585 L .66 .81 .955 r
F
.21488 .72883 m .2096 .72849 L .20941 .73057 L .66 .811 .956 r
F
0 g
.20941 .73057 m
.21031 .73257 L
s
.66547 .17958 m .6656 .17114 L .63641 .16692 L .733 .462 .518 r
F
0 g
.6656 .17114 m
.69206 .18039 L
s
.21717 .72035 m .21083 .72054 L .21567 .72155 L .66 .81 .955 r
F
.72041 .32003 m .71277 .29995 L .71351 .30684 L .951 .662 .217 r
F
.72116 .32691 m .72041 .32003 L .71351 .30684 L F
0 g
.72069 .32567 m
.72071 .32604 L
s
.22129 .72492 m .21719 .72331 L .21568 .72451 L .66 .81 .955 r
F
.22232 .72443 m .21719 .72331 L .22129 .72492 L F
.65892 .3331 m .67787 .31601 L .6546 .32941 L .656 .78 .94 r
F
.65892 .3331 m .68645 .32347 L .67787 .31601 L F
.38633 .47749 m .37989 .4659 L .36893 .46902 L .66 .804 .952 r
F
.39221 .47673 m .37989 .4659 L .38633 .47749 L F
.22059 .7285 m .21488 .72883 L .22016 .72917 L .66 .811 .956 r
F
.23554 .72745 m .2387 .72463 L .23427 .72626 L F
.23554 .72745 m .24059 .72643 L .2387 .72463 L F
0 g
.22659 .72528 m
.22796 .72563 L
s
.58045 .31852 m .54466 .32328 L .57367 .32747 L .657 .779 .939 r
F
.6092 .45418 m .61266 .4684 L .61993 .45606 L .659 .805 .953 r
F
.6092 .45418 m .59665 .46564 L .61266 .4684 L F
0 g
.61266 .4684 m
.63006 .46864 L
s
.22268 .72556 m
.22395 .72524 L
s
.22767 .72407 m .22731 .72125 L .22634 .7239 L .66 .81 .955 r
F
.22767 .72407 m .22997 .72161 L .22731 .72125 L F
.39221 .47673 m .39175 .46437 L .37989 .4659 L .66 .804 .952 r
F
.5824 .45476 m .59525 .45417 L .59595 .4599 L .875 .587 .497 r
F
.5824 .45476 m .58172 .44902 L .59525 .45417 L F
0 g
.59525 .45417 m
.60109 .45518 L
s
.23862 .72166 m .23854 .71869 L .23574 .71721 L .918 .636 .492 r
F
0 g
.23854 .71869 m
.24043 .72049 L
s
.23419 .72328 m .23581 .72018 L .23232 .7223 L .66 .81 .955 r
F
.23419 .72328 m .23862 .72166 L .23581 .72018 L F
.23222 .71935 m .23218 .7162 L .22988 .71866 L F
.23222 .71935 m .23569 .71724 L .23218 .7162 L F
.22985 .72788 m .2324 .72528 L .22891 .72739 L .66 .811 .956 r
F
.22985 .72788 m .23427 .72626 L .2324 .72528 L F
.3527 .47901 m .33243 .474 L .32628 .48327 L .66 .804 .952 r
F
0 g
.32475 .49282 m
.32628 .48327 L
s
.59888 .43908 m .59544 .454 L .60787 .44254 L .661 .804 .952 r
F
.59888 .43908 m .58197 .44887 L .59544 .454 L F
.22232 .72443 m .21927 .72232 L .21719 .72331 L .66 .81 .955 r
F
.22357 .72408 m .21927 .72232 L .22232 .72443 L F
0 g
.22526 .72515 m
.22659 .72528 L
s
.22395 .72524 m
.22526 .72515 L
s
.22634 .7239 m .22451 .72126 L .22494 .7239 L .66 .81 .955 r
F
.22634 .7239 m .22731 .72125 L .22451 .72126 L F
.24059 .72643 m .23862 .72166 L .2387 .72463 L .977 .696 .422 r
F
0 g
.24059 .72643 m
.24145 .72843 L
s
.7152 .61569 m .70547 .60965 L .69736 .61397 L .599 .766 .959 r
F
0 g
.69184 .61919 m
.69736 .61397 L
s
.72197 .61364 m .70547 .60965 L .7152 .61569 L .599 .766 .959 r
F
.22357 .72408 m .22176 .72162 L .21927 .72232 L .66 .81 .955 r
F
.22494 .7239 m .22176 .72162 L .22357 .72408 L F
.22494 .7239 m .22451 .72126 L .22176 .72162 L F
.75813 .61823 m .76147 .60927 L .75238 .61544 L .599 .766 .959 r
F
.75813 .61823 m .77012 .61349 L .76147 .60927 L F
.22059 .7285 m .21574 .72749 L .21488 .72883 L .66 .811 .956 r
F
.22135 .7279 m .21574 .72749 L .22059 .7285 L F
.64735 .31294 m .6503 .29318 L .6403 .31124 L .657 .779 .938 r
F
.64735 .31294 m .66451 .29666 L .6503 .29318 L F
.21087 .72648 m .20954 .72552 L .2096 .72849 L 0 0 .386 r
F
.21568 .72451 m .21082 .7235 L .20954 .72552 L .66 .81 .955 r
F
.21087 .72648 m .21082 .7235 L .20954 .72552 L 0 0 .386 r
F
0 g
.20935 .72759 m
.20954 .72552 L
s
.65397 .32253 m .66534 .3034 L .64805 .31973 L .657 .779 .939 r
F
.65397 .32253 m .67719 .30909 L .66534 .3034 L F
.22891 .72739 m .23005 .72459 L .22774 .72705 L .66 .811 .956 r
F
.22891 .72739 m .2324 .72528 L .23005 .72459 L F
.72971 .60278 m .72727 .59513 L .71584 .59679 L .601 .765 .958 r
F
.73764 .60272 m .72727 .59513 L .72971 .60278 L F
.21717 .72035 m .21309 .71874 L .21083 .72054 L .66 .81 .955 r
F
.21924 .71937 m .21309 .71874 L .21717 .72035 L F
.74535 .60371 m .73923 .59504 L .73764 .60272 L .601 .765 .958 r
F
.74535 .60371 m .75086 .59653 L .73923 .59504 L F
.21574 .72749 m .2096 .72849 L .21488 .72883 L .66 .811 .956 r
F
.21719 .72331 m .21082 .7235 L .21568 .72451 L .66 .81 .955 r
F
.22135 .7279 m .21725 .72628 L .21574 .72749 L .66 .811 .956 r
F
.22239 .7274 m .21725 .72628 L .22135 .7279 L F
.22988 .71866 m .2282 .71566 L .22723 .71831 L .66 .81 .955 r
F
.22988 .71866 m .23218 .7162 L .2282 .71566 L F
.72202 .60871 m .71569 .60161 L .70554 .60472 L .6 .765 .958 r
F
.72965 .60762 m .71569 .60161 L .72202 .60871 L F
.75238 .61052 m .75093 .60136 L .74539 .60855 L F
.75238 .61052 m .76147 .60432 L .75093 .60136 L F
.22774 .72705 m .22738 .72423 L .2264 .72687 L .66 .811 .956 r
F
.22774 .72705 m .23005 .72459 L .22738 .72423 L F
.23862 .72166 m .23574 .71721 L .23581 .72018 L .918 .636 .492 r
F
.2387 .72463 m .23862 .72166 L .23581 .72018 L F
0 g
.23862 .72166 m
.24051 .72346 L
s
.77626 .61865 m .7701 .60855 L .77012 .61349 L .955 .681 .479 r
F
0 g
.77626 .61865 m
.77949 .62439 L
s
.23427 .72626 m .23589 .72316 L .2324 .72528 L .66 .811 .956 r
F
.23427 .72626 m .2387 .72463 L .23589 .72316 L F
.23232 .7223 m .23229 .71914 L .22997 .72161 L .66 .81 .955 r
F
.23232 .7223 m .23581 .72018 L .23229 .71914 L F
.21309 .72169 m .21076 .72053 L .21082 .7235 L .293 .139 .494 r
F
.21309 .72169 m .21303 .71871 L .21076 .72053 L F
0 g
.20949 .72254 m
.21076 .72053 L
s
.73764 .60272 m .73923 .59504 L .72727 .59513 L .601 .765 .958 r
F
.45084 .46142 m .43948 .44855 L .43995 .4543 L .939 .646 .459 r
F
.45133 .46717 m .45084 .46142 L .43995 .4543 L F
0 g
.45084 .46142 m
.4576 .46994 L
s
.66465 .46172 m .67881 .44924 L .67964 .45498 L .505 .323 .567 r
F
.65486 .45156 m .66465 .46172 L .67964 .45498 L .659 .805 .953 r
F
.64352 .4547 m .66465 .46172 L .65486 .45156 L F
0 g
.64777 .46637 m
.66465 .46172 L
s
.22239 .7274 m .21933 .7253 L .21725 .72628 L .66 .811 .956 r
F
.22364 .72705 m .21933 .7253 L .22239 .7274 L F
.61721 .31349 m .60364 .29775 L .5905 .3039 L .657 .779 .938 r
F
.62468 .31153 m .60364 .29775 L .61721 .31349 L F
.60646 .33408 m .58094 .32543 L .57415 .33436 L .656 .78 .94 r
F
.61166 .33022 m .58094 .32543 L .60646 .33408 L F
.42389 .46403 m .42563 .44912 L .41436 .46063 L .661 .803 .951 r
F
.42389 .46403 m .43995 .4543 L .42563 .44912 L F
.2264 .72687 m .22457 .72423 L .22501 .72687 L .66 .811 .956 r
F
.2264 .72687 m .22738 .72423 L .22457 .72423 L F
.21924 .71937 m .21619 .71726 L .21309 .71874 L .66 .81 .955 r
F
.22172 .71867 m .21619 .71726 L .21924 .71937 L F
.68479 .30981 m .69968 .28875 L .67628 .30234 L .657 .779 .938 r
F
.68479 .30981 m .71235 .3001 L .69968 .28875 L F
.22364 .72705 m .22183 .7246 L .21933 .7253 L .66 .811 .956 r
F
.22501 .72687 m .22183 .7246 L .22364 .72705 L F
.66547 .17958 m .63641 .16692 L .6362 .17536 L .733 .462 .518 r
F
0 g
.63641 .16692 m
.6656 .17114 L
s
.60671 .16807 m
.63641 .16692 L
s
.22501 .72687 m .22457 .72423 L .22183 .7246 L .66 .811 .956 r
F
.22723 .71831 m .22401 .71567 L .22445 .71831 L .66 .81 .955 r
F
.22723 .71831 m .2282 .71566 L .22401 .71567 L F
.35966 .4735 m .33243 .474 L .3527 .47901 L .66 .804 .952 r
F
.21574 .72749 m .21087 .72648 L .2096 .72849 L .66 .811 .956 r
F
0 g
.20941 .73057 m
.2096 .72849 L
s
.69194 .19731 m .66547 .17958 L .66533 .18808 L .809 .527 .512 r
F
0 g
.69194 .19731 m
.71384 .2108 L
s
.23581 .72018 m .23574 .71721 L .23222 .71616 L .854 .58 .523 r
F
0 g
.23574 .71721 m
.23854 .71869 L
s
.61111 .32332 m .5908 .31067 L .58045 .31852 L .657 .779 .939 r
F
.6177 .32029 m .5908 .31067 L .61111 .32332 L F
.22172 .71867 m .21992 .71621 L .21619 .71726 L .66 .81 .955 r
F
.22445 .71831 m .21992 .71621 L .22172 .71867 L F
.21719 .72331 m .21309 .72169 L .21082 .7235 L F
.21927 .72232 m .21309 .72169 L .21719 .72331 L F
.22445 .71831 m .22401 .71567 L .21992 .71621 L F
.63169 .43199 m .63013 .44461 L .63296 .44425 L .661 .804 .952 r
F
.63507 .43566 m .63296 .44425 L .64193 .44309 L F
.63169 .43199 m .63296 .44425 L .63507 .43566 L F
.63764 .43123 m .64193 .44309 L .64897 .44113 L F
.64681 .43638 m .64897 .44113 L .65318 .43996 L F
.63764 .43123 m .64897 .44113 L .64681 .43638 L F
.63611 .43142 m .64193 .44309 L .63764 .43123 L F
.63169 .43199 m .63507 .43566 L .63611 .43142 L F
.63507 .43566 m .64193 .44309 L .63611 .43142 L F
.63691 .36755 m .63711 .36659 L .63908 .41934 L 0 0 .209 r
F
.63764 .43123 m .64681 .43638 L .6433 .42964 L .661 .804 .952 r
F
.64681 .43638 m .65318 .43996 L .64415 .43053 L F
.64681 .43638 m .64415 .43053 L .6433 .42964 L F
.63691 .36755 m .63908 .41934 L .63902 .41958 L 0 0 .209 r
F
.63691 .36755 m .63902 .41958 L .63887 .42018 L F
.63844 .43705 m .64275 .44895 L .65407 .44581 L .66 .805 .952 r
F
.63244 .43783 m .64275 .44895 L .63844 .43705 L F
.63844 .43705 m .65407 .44581 L .64414 .43546 L F
.63677 .42281 m .63764 .43123 L .6433 .42964 L .661 .804 .952 r
F
.63804 .42175 m .6433 .42964 L .6483 .42734 L F
.63224 .36976 m .63552 .42219 L .63412 .42243 L .629 .374 .513 r
F
.63755 .42184 m .6433 .42964 L .63804 .42175 L .661 .804 .952 r
F
.63679 .42197 m .63713 .42237 L .63755 .42184 L F
.63713 .42237 m .6433 .42964 L .63755 .42184 L F
.63634 .36835 m .63691 .36755 L .63887 .42018 L .067 0 .41 r
F
.6363 .42231 m .6433 .42964 L .63679 .42197 L .661 .804 .952 r
F
.63528 .42469 m .63764 .43123 L .63677 .42281 L F
.63818 .42926 m .63844 .43705 L .64414 .43546 L .66 .805 .952 r
F
.63863 .42744 m .64413 .43546 L .64109 .42878 L F
.63853 .42786 m .64413 .43546 L .63863 .42744 L F
.64413 .43546 m .64414 .43546 L .64413 .43546 L F
.64413 .43546 m .64413 .43546 L .63863 .42744 L F
.63544 .36901 m .63802 .4211 L .63737 .42156 L .328 .148 .478 r
F
.63417 .36953 m .637 .42171 L .63608 .42209 L .492 .27 .504 r
F
.63224 .36976 m .63417 .36953 L .63608 .42209 L .629 .374 .513 r
F
.63224 .36976 m .63608 .42209 L .63552 .42219 L F
.63658 .42261 m .63528 .42469 L .63677 .42281 L .661 .804 .952 r
F
.63036 .36946 m .63224 .36976 L .63412 .42243 L .755 .473 .507 r
F
.63036 .36946 m .63412 .42243 L .63357 .42239 L F
.63244 .43783 m .63087 .45048 L .64275 .44895 L .66 .805 .952 r
F
.63321 .44361 m .63162 .45623 L .64352 .4547 L .659 .805 .953 r
F
.62992 .43196 m .63013 .44461 L .63169 .43199 L .661 .804 .952 r
F
.62584 .43189 m .62999 .44422 L .62992 .43196 L F
.62999 .44422 m .63013 .44461 L .62992 .43196 L F
.63011 .43779 m .63087 .45048 L .63244 .43783 L .66 .805 .952 r
F
.62584 .43189 m .61852 .44443 L .63013 .44461 L .661 .804 .952 r
F
.62656 .43773 m .63017 .44842 L .63011 .43779 L .66 .805 .952 r
F
.63017 .44842 m .63087 .45048 L .63011 .43779 L F
.63254 .42508 m .62584 .43189 L .63169 .43199 L .661 .804 .952 r
F
.63115 .4228 m .62988 .42498 L .63254 .42508 L F
.62988 .42498 m .62584 .43189 L .62989 .42778 L F
.62988 .42498 m .62989 .42778 L .63254 .42508 L F
.62802 .36739 m .62844 .36821 L .63026 .42134 L .972 .694 .284 r
F
.63115 .4228 m .62454 .42784 L .62584 .43189 L .661 .804 .952 r
F
.62454 .42784 m .62049 .43093 L .62228 .43126 L F
.62454 .42784 m .62228 .43126 L .62584 .43189 L F
.62802 .36739 m .63026 .42134 L .63015 .42115 L .972 .694 .284 r
F
.62802 .36739 m .63015 .42115 L .62985 .42066 L F
.62844 .36821 m .6292 .3689 L .63103 .42189 L .948 .643 .425 r
F
.63149 .42222 m .63049 .42172 L .63115 .4228 L .661 .804 .952 r
F
.63103 .42189 m .63049 .42172 L .63149 .42222 L F
.63062 .4216 m .6305 .42171 L .63103 .42189 L F
.6305 .42171 m .63049 .42172 L .63103 .42189 L F
.63049 .42172 m .62563 .4262 L .63115 .4228 L F
.62563 .4262 m .62049 .43093 L .62454 .42784 L F
.62563 .4262 m .62454 .42784 L .63115 .4228 L F
.6292 .3689 m .63188 .42218 L .63103 .42189 L .862 .563 .481 r
F
.62844 .36821 m .63103 .42189 L .63082 .42174 L .948 .643 .425 r
F
.63036 .36946 m .63357 .42239 L .63221 .4223 L .755 .473 .507 r
F
.63286 .42252 m .63115 .4228 L .63254 .42508 L .661 .804 .952 r
F
.6292 .3689 m .63036 .36946 L .63221 .4223 L .862 .563 .481 r
F
.6292 .3689 m .63221 .4223 L .63188 .42218 L F
.63328 .41916 m .63157 .42208 L .63286 .42252 L .661 .804 .952 r
F
.63157 .42208 m .63115 .4228 L .63286 .42252 L F
.62656 .43773 m .61919 .4503 L .63087 .45048 L .66 .805 .952 r
F
.62731 .44352 m .63162 .45623 L .63321 .44361 L .659 .805 .953 r
F
.63456 .42272 m .63169 .43199 L .63764 .43123 L .661 .804 .952 r
F
.63328 .41916 m .63274 .42347 L .63456 .42272 L F
.63274 .42347 m .63169 .43199 L .63456 .42272 L F
.63417 .36953 m .63544 .36901 L .63737 .42156 L .492 .27 .504 r
F
.63417 .36953 m .63737 .42156 L .637 .42171 L F
.63328 .41916 m .63608 .42209 L .63804 .42175 L .661 .804 .952 r
F
.637 .42171 m .63737 .42156 L .63757 .42702 L .492 .27 .504 r
F
.637 .42171 m .63757 .42702 L .6373 .42713 L F
.63357 .42239 m .63412 .42243 L .63431 .42789 L .755 .473 .507 r
F
.63321 .44361 m .64352 .4547 L .63921 .44284 L .659 .805 .953 r
F
.63357 .42239 m .63431 .42789 L .63391 .42786 L .755 .473 .507 r
F
.63188 .42218 m .63215 .42767 L .63103 .42189 L .862 .563 .481 r
F
.63544 .42879 m .63244 .43783 L .63844 .43705 L .66 .805 .952 r
F
.63495 .42862 m .63244 .43783 L .63544 .42879 L F
.63431 .42789 m .63244 .43783 L .63513 .42795 L F
.63369 .42785 m .63367 .428 L .63431 .42789 L F
.63367 .428 m .63244 .43783 L .63431 .42789 L F
.6363 .43483 m .63321 .44361 L .63921 .44284 L .659 .805 .953 r
F
.6358 .43346 m .63505 .43639 L .6363 .43483 L F
.63505 .43639 m .63321 .44361 L .6363 .43483 L F
.63842 .4346 m .63921 .44284 L .64454 .44135 L F
.63761 .43158 m .63844 .43705 L .63818 .42926 L .66 .805 .952 r
F
.63579 .42975 m .63844 .43705 L .63709 .42812 L F
.637 .43304 m .63784 .43692 L .63842 .4346 L .659 .805 .953 r
F
.63784 .43692 m .63921 .44284 L .63842 .4346 L F
.63844 .43452 m .64454 .44135 L .64411 .44041 L F
.63842 .43458 m .64454 .44135 L .63844 .43452 L F
.63739 .43347 m .63842 .4346 L .63741 .43345 L F
.63842 .4346 m .64454 .44135 L .63842 .43458 L F
.63842 .4346 m .63842 .43458 L .63741 .43345 L F
.63786 .42716 m .63849 .42799 L .63794 .42707 L .66 .805 .952 r
F
.63849 .42799 m .64414 .43546 L .63853 .42786 L F
.63849 .42799 m .63853 .42786 L .63794 .42707 L F
.63634 .36835 m .6387 .42039 L .63828 .42092 L .067 0 .41 r
F
.63865 .42066 m .63804 .42175 L .64081 .42127 L .661 .804 .952 r
F
.63544 .36901 m .63634 .36835 L .63828 .42092 L .328 .148 .478 r
F
.63544 .36901 m .63828 .42092 L .63802 .4211 L F
.63328 .41916 m .63751 .42146 L .63865 .42066 L .661 .804 .952 r
F
.63751 .42146 m .63804 .42175 L .63865 .42066 L F
.63648 .43303 m .63592 .43379 L .63692 .43295 L .659 .805 .953 r
F
.63592 .43379 m .63921 .44284 L .63695 .43307 L F
.63592 .43379 m .63695 .43307 L .63692 .43295 L F
.63648 .43303 m .63817 .44329 L .63687 .44379 L .492 .27 .504 r
F
.63705 .42808 m .63579 .42975 L .63709 .42812 L .66 .805 .952 r
F
.63412 .42243 m .63481 .4278 L .63431 .42789 L .629 .374 .513 r
F
.63328 .41916 m .63447 .42246 L .63658 .42261 L .661 .804 .952 r
F
.63447 .42246 m .63528 .42469 L .63658 .42261 L F
.63552 .42219 m .63586 .42762 L .63412 .42243 L .629 .374 .513 r
F
.63519 .42774 m .63513 .42795 L .63528 .42796 L .66 .805 .952 r
F
.63506 .42776 m .63513 .42795 L .63519 .42774 L F
.63646 .42747 m .63528 .42796 L .63705 .42808 L F
.63586 .42762 m .63481 .4278 L .63412 .42243 L .629 .374 .513 r
F
.63608 .42209 m .63661 .42741 L .63628 .42755 L .492 .27 .504 r
F
.63552 .42219 m .63608 .42209 L .63628 .42755 L .629 .374 .513 r
F
.63552 .42219 m .63628 .42755 L .63586 .42762 L F
.63405 .42496 m .63519 .42774 L .63646 .42747 L .66 .805 .952 r
F
.63519 .42774 m .63528 .42796 L .63628 .42755 L F
.63519 .42774 m .63628 .42755 L .63646 .42747 L F
.63569 .43316 m .63575 .43333 L .63648 .43303 L .659 .805 .953 r
F
.63575 .43333 m .63592 .43379 L .63648 .43303 L F
.63569 .43316 m .63563 .43345 L .6358 .43346 L F
.63563 .43345 m .63321 .44361 L .6358 .43346 L F
.6345 .43337 m .63321 .44361 L .63563 .43345 L F
.63451 .43337 m .63563 .43345 L .63569 .43316 L F
.6345 .43337 m .63563 .43345 L .63451 .43337 L F
.63221 .4223 m .63289 .42779 L .6324 .42776 L .755 .473 .507 r
F
.63082 .42174 m .63103 .42189 L .63122 .42735 L .948 .643 .425 r
F
.63325 .43138 m .62656 .43773 L .63244 .43783 L .66 .805 .952 r
F
.63354 .42901 m .63255 .43025 L .63325 .43138 L F
.63255 .43025 m .62656 .43773 L .63325 .43138 L F
.63062 .4216 m .61598 .42917 L .62049 .43093 L .661 .804 .952 r
F
.62844 .36821 m .63082 .42174 L .63026 .42134 L .948 .643 .425 r
F
.63328 .41916 m .62992 .4211 L .63062 .4216 L .661 .804 .952 r
F
.62992 .4211 m .61598 .42917 L .63062 .4216 L F
.63321 .42877 m .63235 .42992 L .63354 .42901 L .66 .805 .952 r
F
.63235 .42992 m .62656 .43773 L .63255 .43025 L F
.63235 .42992 m .63255 .43025 L .63354 .42901 L F
.62801 .36643 m .62985 .42043 L .62984 .41983 L 0 0 .044 r
F
.62801 .36643 m .62802 .36739 L .62985 .42066 L F
.62801 .36643 m .62985 .42066 L .62985 .42043 L F
.63328 .41916 m .62509 .42216 L .61598 .42917 L .661 .804 .952 r
F
.62509 .42216 m .61264 .42672 L .61501 .42846 L F
.62509 .42216 m .61501 .42846 L .61598 .42917 L F
.63013 .3643 m .62872 .36522 L .63057 .41873 L .369 .177 .485 r
F
.63173 .4289 m .62656 .43773 L .63235 .42992 L .66 .805 .952 r
F
.62985 .42066 m .63014 .4263 L .63004 .42612 L .972 .694 .284 r
F
.62985 .42043 m .62985 .42066 L .63004 .42612 L 0 0 .044 r
F
.63222 .42807 m .63006 .42977 L .63007 .43174 L .66 .805 .952 r
F
.62049 .43093 m .61852 .44443 L .62584 .43189 L .661 .804 .952 r
F
.63134 .42744 m .62434 .43386 L .63222 .42807 L .66 .805 .952 r
F
.62434 .43386 m .62117 .43677 L .62377 .43472 L F
.62434 .43386 m .62377 .43472 L .63222 .42807 L F
.63082 .42174 m .63106 .42724 L .63026 .42134 L .948 .643 .425 r
F
.63106 .42724 m .63065 .42695 L .63026 .42134 L F
.63026 .42134 m .63065 .42695 L .63045 .4268 L F
.63015 .42115 m .63037 .42666 L .62985 .42066 L .972 .694 .284 r
F
.63037 .42666 m .63014 .4263 L .62985 .42066 L F
.63015 .42115 m .63026 .42134 L .63045 .4268 L F
.63015 .42115 m .63045 .4268 L .63037 .42666 L F
.62509 .42216 m .61069 .42375 L .61264 .42672 L .661 .804 .952 r
F
.63328 .41916 m .62826 .42018 L .62509 .42216 L F
.62826 .42018 m .61069 .42375 L .62509 .42216 L F
.63188 .42218 m .63221 .4223 L .6324 .42776 L .862 .563 .481 r
F
.63188 .42218 m .6324 .42776 L .63223 .4277 L F
.63215 .42767 m .63152 .42746 L .63103 .42189 L F
.63241 .42776 m .63134 .42744 L .63222 .42807 L .66 .805 .952 r
F
.63188 .42218 m .63223 .4277 L .63215 .42767 L .862 .563 .481 r
F
.63357 .42239 m .63391 .42786 L .63221 .4223 L .755 .473 .507 r
F
.63222 .42807 m .63173 .4289 L .63321 .42877 L .66 .805 .952 r
F
.63173 .4289 m .63235 .42992 L .63321 .42877 L F
.63241 .42776 m .63222 .42807 L .63365 .42818 L F
.63222 .42807 m .63321 .42877 L .63365 .42818 L F
.63365 .42818 m .63321 .42877 L .63354 .42901 L F
.63391 .42786 m .63289 .42779 L .63221 .4223 L .755 .473 .507 r
F
.63405 .42496 m .63241 .42776 L .63365 .42818 L .66 .805 .952 r
F
.63395 .43769 m .63027 .43934 L .63321 .44361 L .659 .805 .953 r
F
.63279 .43579 m .63027 .43934 L .63395 .43769 L F
.63027 .43934 m .63029 .44357 L .63321 .44361 L F
.63334 .43329 m .63296 .43394 L .6345 .43337 L F
.63082 .42174 m .63122 .42735 L .63106 .42724 L .948 .643 .425 r
F
.62049 .43093 m .60787 .44254 L .61852 .44443 L .661 .804 .952 r
F
.62434 .43386 m .61664 .435 L .62117 .43677 L .66 .805 .952 r
F
.63138 .42741 m .6279 .42851 L .62434 .43386 L F
.63039 .42707 m .6279 .42851 L .63138 .42741 L F
.63232 .43502 m .62731 .44352 L .63279 .43579 L .659 .805 .953 r
F
.61598 .42917 m .60787 .44254 L .62049 .43093 L .661 .804 .952 r
F
.61598 .42917 m .59888 .43908 L .60787 .44254 L F
.6279 .42851 m .61328 .43255 L .61664 .435 L .66 .805 .952 r
F
.63103 .42189 m .63152 .42746 L .63122 .42735 L .862 .563 .481 r
F
.63405 .42496 m .62904 .42679 L .6279 .42851 L .66 .805 .952 r
F
.62904 .42679 m .61328 .43255 L .6279 .42851 L F
.62872 .36522 m .63004 .41953 L .63057 .41873 L 0 0 .377 r
F
.62872 .36522 m .62801 .36643 L .62984 .41983 L F
.62872 .36522 m .62984 .41983 L .63004 .41953 L F
.61817 .42223 m .61027 .42045 L .61069 .42375 L .661 .804 .952 r
F
.63328 .41916 m .62667 .41953 L .61817 .42223 L F
.62667 .41953 m .61027 .42045 L .61817 .42223 L F
.6315 .3639 m .63013 .3643 L .63201 .41783 L .547 .31 .508 r
F
.63296 .43394 m .63208 .43463 L .63232 .43502 L .659 .805 .953 r
F
.63279 .43382 m .63198 .43447 L .63296 .43394 L F
.62117 .43677 m .61919 .4503 L .62656 .43773 L .66 .805 .952 r
F
.63198 .43447 m .62192 .44256 L .63208 .43463 L .659 .805 .953 r
F
.63198 .43447 m .63208 .43463 L .63296 .43394 L F
.63405 .42496 m .63039 .42707 L .63138 .42741 L .66 .805 .952 r
F
.63037 .42666 m .63045 .4268 L .63064 .43229 L .972 .694 .284 r
F
.63232 .43502 m .62278 .44194 L .62731 .44352 L .659 .805 .953 r
F
.63208 .43463 m .62192 .44256 L .63232 .43502 L F
.63225 .43312 m .63206 .4333 L .63324 .43345 L F
.62985 .42043 m .63004 .42612 L .63004 .42595 L 0 0 .044 r
F
.62984 .41983 m .63004 .42595 L .63003 .4253 L F
.62985 .42043 m .63004 .42595 L .62984 .41983 L F
.63405 .42496 m .62967 .42585 L .62904 .42679 L .66 .805 .952 r
F
.63027 .42864 m .63044 .43196 L .6303 .42989 L .972 .694 .284 r
F
.63027 .42864 m .6303 .42989 L .63004 .42612 L F
.63014 .4263 m .63027 .42864 L .63004 .42612 L F
.63044 .43196 m .63037 .43185 L .63004 .42612 L F
.63004 .41953 m .62984 .41983 L .63003 .4253 L 0 0 .377 r
F
.63004 .41953 m .63003 .4253 L .63013 .42514 L F
.61264 .42672 m .59888 .43908 L .61598 .42917 L .661 .804 .952 r
F
.61264 .42672 m .59216 .43424 L .59888 .43908 L F
.61069 .42375 m .59216 .43424 L .61264 .42672 L F
.62737 .42631 m .61089 .42626 L .61132 .42957 L .66 .805 .952 r
F
.63405 .42496 m .6291 .42524 L .62737 .42631 L F
.6291 .42524 m .61089 .42626 L .62737 .42631 L F
.63206 .4333 m .63024 .43496 L .63279 .43382 L .659 .805 .953 r
F
.63024 .43496 m .63025 .43586 L .63279 .43382 L F
.63206 .4333 m .63279 .43382 L .63324 .43345 L F
.63122 .42735 m .63182 .43297 L .63141 .43283 L .862 .563 .481 r
F
.63007 .43174 m .62117 .43677 L .62656 .43773 L .66 .805 .952 r
F
.63106 .42724 m .63122 .42735 L .63141 .43283 L .948 .643 .425 r
F
.62117 .43677 m .60847 .44841 L .61919 .4503 L .66 .805 .952 r
F
.63206 .4333 m .61738 .4408 L .62192 .44256 L .659 .805 .953 r
F
.632 .43325 m .63024 .43416 L .63206 .4333 L F
.63024 .43416 m .61738 .4408 L .63024 .43423 L F
.63024 .43416 m .63024 .43423 L .63206 .4333 L F
.6313 .4328 m .62736 .43506 L .63225 .43312 L F
.62736 .43506 m .61738 .4408 L .62677 .43595 L F
.62736 .43506 m .62677 .43595 L .63225 .43312 L F
.63037 .42666 m .63064 .43229 L .63058 .4322 L .972 .694 .284 r
F
.63037 .42666 m .63058 .4322 L .63014 .4263 L F
.63058 .4322 m .63044 .43196 L .63014 .4263 L F
.63004 .41953 m .63013 .42514 L .63018 .42507 L 0 0 .377 r
F
.6291 .42524 m .61205 .42285 L .61089 .42626 L .66 .805 .952 r
F
.62667 .41953 m .61142 .41705 L .61027 .42045 L .661 .804 .952 r
F
.63328 .41916 m .6291 .41876 L .62667 .41953 L F
.6291 .41876 m .61142 .41705 L .62667 .41953 L F
.63013 .3643 m .63057 .41873 L .63097 .41848 L .369 .177 .485 r
F
.63328 .41916 m .61407 .41378 L .61142 .41705 L .661 .804 .952 r
F
.63004 .41953 m .63018 .42507 L .63057 .41873 L 0 0 .377 r
F
.63011 .42518 m .63014 .42458 L .6291 .42524 L .66 .805 .952 r
F
.63405 .42496 m .63048 .42462 L .63011 .42518 L F
.63018 .42507 m .63057 .42449 L .63057 .41873 L 0 0 .377 r
F
.63048 .42462 m .63014 .42458 L .63011 .42518 L .66 .805 .952 r
F
.63106 .42724 m .63141 .43283 L .63131 .43276 L .948 .643 .425 r
F
.63152 .42746 m .63202 .43304 L .63122 .42735 L .862 .563 .481 r
F
.63202 .43304 m .63182 .43297 L .63122 .42735 L F
.63391 .42786 m .63424 .43335 L .63289 .42779 L .755 .473 .507 r
F
.63424 .43335 m .63357 .4333 L .63289 .42779 L F
.63215 .42767 m .63259 .43323 L .63243 .43318 L .862 .563 .481 r
F
.63223 .4277 m .63259 .43323 L .63215 .42767 L F
.63223 .4277 m .6324 .42776 L .63259 .43323 L F
.63241 .42776 m .6324 .42776 L .63241 .42776 L .66 .805 .952 r
F
.63289 .42779 m .63357 .4333 L .6324 .42776 L .755 .473 .507 r
F
.63357 .4333 m .63325 .43328 L .6324 .42776 L F
.6355 .4332 m .63517 .43325 L .63431 .42789 L .629 .374 .513 r
F
.6324 .42776 m .63325 .43328 L .63259 .43323 L .755 .473 .507 r
F
.63431 .42789 m .63517 .43325 L .63451 .43337 L .629 .374 .513 r
F
.63225 .43312 m .632 .43325 L .63206 .4333 L .659 .805 .953 r
F
.63296 .43394 m .63232 .43502 L .63371 .43447 L F
.63232 .43502 m .63279 .43579 L .63371 .43447 L F
.63138 .42741 m .63134 .42744 L .63241 .42776 L .66 .805 .952 r
F
.63215 .42767 m .63243 .43318 L .63152 .42746 L .862 .563 .481 r
F
.63243 .43318 m .63296 .44373 L .63202 .43304 L F
.63243 .43318 m .63202 .43304 L .63152 .42746 L F
.63006 .42977 m .62117 .43677 L .63007 .43174 L .66 .805 .952 r
F
.63106 .42724 m .63131 .43276 L .63065 .42695 L .948 .643 .425 r
F
.63328 .41916 m .63062 .4216 L .63149 .42222 L .661 .804 .952 r
F
.63013 .3643 m .63097 .41848 L .63201 .41783 L .369 .177 .485 r
F
.63328 .41916 m .61805 .41087 L .61407 .41378 L .661 .804 .952 r
F
.63014 .42458 m .61472 .41957 L .61205 .42285 L .66 .805 .952 r
F
.63405 .42496 m .63094 .42409 L .63014 .42458 L F
.63097 .41848 m .63057 .41873 L .63076 .4242 L .369 .177 .485 r
F
.63097 .41848 m .63076 .4242 L .63096 .42408 L F
.63057 .41873 m .63057 .42449 L .63076 .4242 L 0 0 .377 r
F
.63094 .42409 m .61472 .41957 L .63014 .42458 L .66 .805 .952 r
F
.63094 .42409 m .61873 .41665 L .61472 .41957 L F
.63405 .42496 m .63164 .42365 L .63094 .42409 L F
.63097 .41848 m .63096 .42408 L .63105 .42402 L .369 .177 .485 r
F
.63328 .41916 m .62309 .40851 L .61805 .41087 L .661 .804 .952 r
F
.63097 .41848 m .63105 .42402 L .63201 .41783 L .369 .177 .485 r
F
.63105 .42402 m .63182 .42354 L .63201 .41783 L F
.63164 .42365 m .61873 .41665 L .63094 .42409 L .66 .805 .952 r
F
.63105 .42402 m .63095 .42969 L .63114 .42957 L .369 .177 .485 r
F
.63096 .42408 m .63095 .42969 L .63105 .42402 L F
.63096 .42408 m .63076 .4242 L .63095 .42969 L F
.61664 .435 m .60847 .44841 L .62117 .43677 L .66 .805 .952 r
F
.6313 .4328 m .62019 .43637 L .61738 .4408 L .659 .805 .953 r
F
.63065 .42695 m .63104 .43257 L .63045 .4268 L .948 .643 .425 r
F
.63104 .43257 m .63091 .43248 L .63045 .4268 L F
.63045 .4268 m .63091 .43248 L .63064 .43229 L F
.63131 .43276 m .63104 .43257 L .63065 .42695 L F
.63391 .42786 m .63431 .42789 L .63451 .43337 L .755 .473 .507 r
F
.63296 .43394 m .63371 .43447 L .6345 .43337 L .659 .805 .953 r
F
.6345 .43337 m .63279 .43579 L .63395 .43769 L F
.63424 .43335 m .63451 .43337 L .63489 .44403 L .755 .473 .507 r
F
.63391 .42786 m .63451 .43337 L .63424 .43335 L F
.63482 .43077 m .63225 .43312 L .63259 .43323 L .659 .805 .953 r
F
.63334 .43329 m .63259 .43323 L .63324 .43345 L F
.63482 .43077 m .63259 .43323 L .63334 .43329 L F
.63482 .43077 m .63025 .43244 L .6313 .4328 L F
.63025 .43244 m .62875 .43299 L .6313 .4328 L F
.61664 .435 m .59943 .44494 L .60847 .44841 L .66 .805 .952 r
F
.62875 .43299 m .61402 .43836 L .62821 .43379 L .659 .805 .953 r
F
.62875 .43299 m .62821 .43379 L .6313 .4328 L F
.63057 .42449 m .63057 .43026 L .63076 .4242 L 0 0 .377 r
F
.61328 .43255 m .59943 .44494 L .61664 .435 L .66 .805 .952 r
F
.62122 .43573 m .61205 .43539 L .61402 .43836 L .659 .805 .953 r
F
.63004 .42612 m .63037 .43185 L .63022 .43161 L .972 .694 .284 r
F
.6279 .42851 m .61664 .435 L .62434 .43386 L .66 .805 .952 r
F
.63065 .4323 m .62648 .43246 L .62122 .43573 L .659 .805 .953 r
F
.63482 .43077 m .63028 .43169 L .63065 .4323 L F
.63028 .43169 m .62648 .43246 L .63065 .4323 L F
.62648 .43246 m .61205 .43539 L .62122 .43573 L F
.63144 .42354 m .6238 .41428 L .61873 .41665 L .66 .805 .952 r
F
.63405 .42496 m .6324 .42324 L .63144 .42354 L F
.63201 .41783 m .63182 .42354 L .6322 .4233 L .369 .177 .485 r
F
.6315 .3639 m .63239 .41771 L .63339 .41739 L .547 .31 .508 r
F
.6315 .3639 m .63201 .41783 L .63239 .41771 L F
.63328 .41916 m .62884 .40688 L .62309 .40851 L .661 .804 .952 r
F
.63239 .41771 m .63201 .41783 L .6322 .4233 L .547 .31 .508 r
F
.63239 .41771 m .6322 .4233 L .63248 .42321 L F
.6324 .42324 m .6238 .41428 L .63144 .42354 L .66 .805 .952 r
F
.63482 .43077 m .6313 .4328 L .63225 .43312 L .659 .805 .953 r
F
.63482 .43077 m .63334 .43329 L .6345 .43337 L F
.63424 .43335 m .63489 .44403 L .63357 .4333 L .755 .473 .507 r
F
.63357 .4333 m .63489 .44403 L .63325 .43328 L F
.63259 .43323 m .63489 .44403 L .63296 .44373 L F
.63324 .43345 m .63279 .43382 L .63296 .43394 L .659 .805 .953 r
F
.63325 .43328 m .63489 .44403 L .63259 .43323 L .755 .473 .507 r
F
.63243 .43318 m .63259 .43323 L .63296 .44373 L .862 .563 .481 r
F
.63003 .4253 m .63022 .43107 L .63022 .43078 L 0 0 .044 r
F
.63004 .42595 m .63022 .4315 L .63003 .4253 L F
.63022 .4315 m .63022 .43107 L .63003 .4253 L F
.62951 .43185 m .62864 .43112 L .62648 .43246 L .659 .805 .953 r
F
.63004 .42595 m .63004 .42612 L .63022 .43161 L 0 0 .044 r
F
.63004 .42595 m .63022 .43161 L .63022 .4315 L F
.63482 .43077 m .63004 .43104 L .62951 .43185 L .659 .805 .953 r
F
.63004 .43104 m .62864 .43112 L .62951 .43185 L F
.6309 .44019 m .63091 .44017 L .63099 .44249 L .972 .694 .284 r
F
.63058 .4322 m .63091 .44017 L .6309 .44019 L F
.63058 .4322 m .63064 .43229 L .63091 .44017 L F
.63106 .43289 m .63177 .44318 L .63115 .43547 L .948 .643 .425 r
F
.63106 .43289 m .63115 .43547 L .63091 .43248 L F
.63104 .43257 m .63106 .43289 L .63091 .43248 L F
.63058 .4322 m .63099 .44249 L .63044 .43196 L .972 .694 .284 r
F
.63064 .43229 m .63177 .44318 L .63099 .44249 L .948 .643 .425 r
F
.63091 .43248 m .63177 .44318 L .63064 .43229 L F
.63044 .43196 m .63099 .44249 L .63037 .43185 L .972 .694 .284 r
F
.63022 .43161 m .63099 .44249 L .63057 .44169 L F
.63037 .43185 m .63099 .44249 L .63022 .43161 L F
.62904 .42679 m .61438 .42895 L .61328 .43255 L .66 .805 .952 r
F
.61438 .42895 m .61132 .42957 L .61151 .42986 L F
.61438 .42895 m .61151 .42986 L .61328 .43255 L F
.59216 .43424 m .58197 .44887 L .59888 .43908 L .661 .804 .952 r
F
.61132 .42957 m .59266 .44009 L .61328 .43255 L .66 .805 .952 r
F
.62422 .43137 m .6128 .42868 L .61163 .43209 L .659 .805 .953 r
F
.63018 .42507 m .63032 .43064 L .63057 .42449 L 0 0 .377 r
F
.63032 .43064 m .63057 .43026 L .63057 .42449 L F
.63405 .42496 m .63138 .42741 L .6324 .42776 L .66 .805 .952 r
F
.63182 .42354 m .63163 .42926 L .6322 .4233 L .369 .177 .485 r
F
.63018 .42507 m .63022 .43078 L .63032 .43064 L 0 0 .377 r
F
.63013 .42514 m .63022 .43078 L .63018 .42507 L F
.63013 .42514 m .63003 .4253 L .63022 .43078 L F
.63482 .43077 m .62994 .43031 L .62864 .43112 L .659 .805 .953 r
F
.63131 .43276 m .63141 .43283 L .63177 .44318 L .948 .643 .425 r
F
.63141 .43283 m .63296 .44373 L .63177 .44318 L .862 .563 .481 r
F
.63182 .43297 m .63296 .44373 L .63141 .43283 L F
.63131 .43276 m .63177 .44318 L .63104 .43257 L .948 .643 .425 r
F
.63076 .4242 m .63069 .43008 L .63095 .42969 L 0 0 .377 r
F
.63057 .43026 m .63069 .43008 L .63076 .4242 L F
.62967 .42585 m .61438 .42895 L .62904 .42679 L .66 .805 .952 r
F
.62813 .43014 m .61547 .42541 L .6128 .42868 L .659 .805 .953 r
F
.63482 .43077 m .63019 .42949 L .62813 .43014 L F
.63019 .42949 m .61547 .42541 L .62813 .43014 L F
.6324 .42324 m .62959 .41265 L .6238 .41428 L .66 .805 .952 r
F
.63405 .42496 m .63332 .42295 L .6324 .42324 L F
.63414 .36395 m .63283 .3638 L .63475 .41721 L .735 .457 .508 r
F
.63414 .36395 m .63475 .41721 L .63511 .41722 L F
.63283 .3638 m .6315 .3639 L .63339 .41739 L .65 .39 .512 r
F
.63405 .42496 m .6324 .42776 L .63241 .42776 L .66 .805 .952 r
F
.63405 .42496 m .63369 .42785 L .63513 .42795 L F
.63634 .36835 m .63887 .42018 L .6387 .42039 L .067 0 .41 r
F
.64125 .41993 m .65229 .42448 L .655 .42125 L .661 .804 .952 r
F
.63328 .41916 m .64567 .42263 L .64125 .41993 L F
.64567 .42263 m .65229 .42448 L .64125 .41993 L F
.63804 .42175 m .6483 .42734 L .64081 .42127 L F
.63794 .42707 m .63853 .42786 L .63863 .42744 L .66 .805 .952 r
F
.6387 .42039 m .63895 .4258 L .63828 .42092 L .067 0 .41 r
F
.63709 .42812 m .64414 .43546 L .63786 .42716 L .66 .805 .952 r
F
.63608 .42209 m .6363 .42231 L .63679 .42197 L .661 .804 .952 r
F
.637 .42171 m .6373 .42713 L .63608 .42209 L .492 .27 .504 r
F
.6373 .42713 m .63661 .42741 L .63608 .42209 L F
.63802 .4211 m .63828 .42092 L .63849 .42638 L .328 .148 .478 r
F
.63769 .42693 m .64109 .42878 L .63868 .42625 L .66 .805 .952 r
F
.6433 .42964 m .65318 .43996 L .66313 .43542 L .661 .804 .952 r
F
.6433 .42964 m .66313 .43542 L .6483 .42734 L F
.64109 .42878 m .64916 .43316 L .64048 .42743 L .66 .805 .952 r
F
.64109 .42878 m .64048 .42743 L .63868 .42625 L F
.63711 .36659 m .63874 .4186 L .63908 .41934 L .944 .685 .22 r
F
.63943 .41881 m .655 .42125 L .65625 .41786 L .661 .804 .952 r
F
.63328 .41916 m .64125 .41993 L .63943 .41881 L F
.64125 .41993 m .655 .42125 L .63943 .41881 L F
.63664 .36536 m .63541 .36439 L .63737 .41755 L .931 .625 .44 r
F
.63802 .4211 m .63849 .42638 L .63836 .42647 L .328 .148 .478 r
F
.63829 .42652 m .63869 .43186 L .63856 .43195 L F
.63802 .4211 m .63836 .42647 L .63829 .42652 L F
.63836 .42647 m .63869 .43186 L .63829 .42652 L F
.64081 .42127 m .6483 .42734 L .65229 .42448 L .661 .804 .952 r
F
.6483 .42734 m .66313 .43542 L .67112 .42976 L F
.6483 .42734 m .67112 .42976 L .65229 .42448 L F
.63974 .4255 m .65318 .43029 L .65591 .42705 L .66 .805 .952 r
F
.63895 .4258 m .63863 .42619 L .63828 .42092 L .067 0 .41 r
F
.6387 .42039 m .63887 .42018 L .63907 .42565 L F
.63923 .42545 m .63868 .42625 L .63974 .4255 L .66 .805 .952 r
F
.63828 .42092 m .63863 .42619 L .63849 .42638 L .067 0 .41 r
F
.63737 .42156 m .6378 .42686 L .63757 .42702 L .328 .148 .478 r
F
.63887 .42018 m .63913 .42543 L .63907 .42565 L 0 0 .209 r
F
.6387 .42039 m .63907 .42565 L .63895 .4258 L .067 0 .41 r
F
.63709 .42812 m .63786 .42716 L .63771 .42696 L .66 .805 .952 r
F
.63741 .43345 m .63842 .43458 L .63844 .43452 L .659 .805 .953 r
F
.63769 .42693 m .63786 .42716 L .63794 .42707 L .66 .805 .952 r
F
.63709 .42812 m .63761 .43158 L .63818 .42926 L F
.65229 .42448 m .67112 .42976 L .6766 .42333 L .661 .804 .952 r
F
.65229 .42448 m .6766 .42333 L .655 .42125 L F
.64109 .42456 m .65591 .42705 L .65717 .42365 L .66 .805 .952 r
F
.63802 .4211 m .63829 .42652 L .63737 .42156 L .328 .148 .478 r
F
.63829 .42652 m .63796 .42674 L .63737 .42156 L F
.63856 .43195 m .63824 .43217 L .6378 .42686 L F
.63796 .42674 m .6378 .42686 L .63737 .42156 L F
.63856 .43195 m .6378 .42686 L .63796 .42674 L F
.655 .42125 m .6766 .42333 L .67919 .41657 L .661 .804 .952 r
F
.655 .42125 m .67919 .41657 L .65625 .41786 L F
.64316 .42311 m .65717 .42365 L .65685 .42033 L .66 .805 .952 r
F
.63664 .36536 m .63772 .41776 L .63861 .41831 L .931 .625 .44 r
F
.63711 .36659 m .63664 .36536 L .63861 .41831 L .944 .685 .22 r
F
.63711 .36659 m .63861 .41831 L .63874 .4186 L F
.63916 .41796 m .65625 .41786 L .65593 .41455 L .661 .804 .952 r
F
.63328 .41916 m .64217 .41866 L .63916 .41796 L F
.64217 .41866 m .65625 .41786 L .63916 .41796 L F
.63874 .4186 m .63881 .42377 L .63891 .42399 L .944 .685 .22 r
F
.63902 .41958 m .63924 .42498 L .63887 .42018 L 0 0 .209 r
F
.63924 .42498 m .63913 .42543 L .63887 .42018 L F
.63874 .4186 m .63891 .42399 L .63908 .41934 L .944 .685 .22 r
F
.63891 .42399 m .63916 .42454 L .63908 .41934 L F
.63902 .41958 m .63908 .41934 L .63928 .4248 L 0 0 .209 r
F
.63902 .41958 m .63928 .4248 L .63924 .42498 L F
.63908 .41934 m .63916 .42454 L .63928 .4248 L .944 .685 .22 r
F
.63405 .42496 m .64018 .42461 L .63908 .42394 L .66 .805 .952 r
F
.63405 .42496 m .63974 .4255 L .64063 .42488 L F
.64018 .42461 m .64063 .42488 L .64109 .42456 L F
.63405 .42496 m .64063 .42488 L .64018 .42461 L F
.63829 .42652 m .63856 .43195 L .63796 .42674 L .328 .148 .478 r
F
.63868 .42625 m .65318 .43029 L .63974 .4255 L .66 .805 .952 r
F
.63868 .42625 m .64916 .43316 L .65318 .43029 L F
.63924 .42498 m .63946 .4304 L .63913 .42543 L 0 0 .209 r
F
.65318 .43996 m .67777 .4434 L .66313 .43542 L .661 .804 .952 r
F
.64414 .43546 m .65407 .44581 L .66408 .44125 L .66 .805 .952 r
F
.64131 .43427 m .64492 .44125 L .64996 .43895 L .659 .805 .953 r
F
.63883 .43294 m .64379 .43971 L .64131 .43427 L F
.64379 .43971 m .64492 .44125 L .64131 .43427 L F
.63405 .42496 m .63861 .42623 L .63923 .42545 L .66 .805 .952 r
F
.63916 .42454 m .63924 .42976 L .63928 .4248 L .944 .685 .22 r
F
.63873 .43333 m .64492 .44125 L .63883 .43294 L .659 .805 .953 r
F
.63806 .43265 m .64393 .44 L .63813 .43256 L F
.64393 .44 m .64492 .44125 L .6439 .43994 L F
.64393 .44 m .6439 .43994 L .63813 .43256 L F
.63861 .42623 m .63868 .42625 L .63923 .42545 L .66 .805 .952 r
F
.63895 .4258 m .63907 .42565 L .63928 .43113 L .067 0 .41 r
F
.63741 .43345 m .64492 .44125 L .63806 .43265 L .659 .805 .953 r
F
.63861 .41831 m .63849 .42358 L .63881 .42377 L .931 .625 .44 r
F
.63874 .4186 m .63861 .41831 L .63881 .42377 L .944 .685 .22 r
F
.63867 .42327 m .65685 .42033 L .65497 .41731 L .66 .805 .952 r
F
.63664 .36536 m .63737 .41755 L .63772 .41776 L .931 .625 .44 r
F
.63755 .41759 m .65593 .41455 L .65406 .41154 L .661 .804 .952 r
F
.63328 .41916 m .63916 .41796 L .63755 .41759 L F
.63916 .41796 m .65593 .41455 L .63755 .41759 L F
.63541 .36439 m .63414 .36395 L .63607 .41725 L .822 .528 .492 r
F
.63405 .42496 m .63908 .42394 L .63824 .42342 L .66 .805 .952 r
F
.63856 .43217 m .64131 .43427 L .64071 .43298 L .659 .805 .953 r
F
.63665 .42766 m .63709 .42812 L .63771 .42696 L .66 .805 .952 r
F
.63513 .42795 m .63579 .42975 L .63705 .42808 L F
.63646 .42747 m .6365 .42751 L .63722 .42716 L F
.6365 .42751 m .63665 .42766 L .63699 .42743 L F
.6365 .42751 m .63699 .42743 L .63769 .42693 L F
.6373 .42713 m .63759 .43257 L .63661 .42741 L .492 .27 .504 r
F
.63759 .43257 m .63713 .43276 L .63661 .42741 L F
.63513 .42795 m .63495 .42862 L .63544 .42879 L .66 .805 .952 r
F
.63586 .42762 m .6362 .43308 L .63481 .4278 L .629 .374 .513 r
F
.6362 .43308 m .63687 .44379 L .6355 .4332 L F
.6362 .43308 m .6355 .4332 L .63481 .4278 L F
.64109 .42878 m .64414 .43546 L .64916 .43316 L .66 .805 .952 r
F
.64413 .43546 m .64414 .43546 L .64109 .42878 L F
.64414 .43546 m .66408 .44125 L .64916 .43316 L F
.64047 .43234 m .65227 .4373 L .64713 .43419 L .659 .805 .953 r
F
.63836 .42647 m .63849 .42638 L .63869 .43186 L .328 .148 .478 r
F
.63628 .42755 m .63713 .43276 L .63648 .43303 L .492 .27 .504 r
F
.63661 .42741 m .63713 .43276 L .63628 .42755 L F
.63757 .42702 m .63808 .43228 L .63777 .4325 L .328 .148 .478 r
F
.63481 .4278 m .6355 .4332 L .63431 .42789 L .629 .374 .513 r
F
.63849 .42638 m .63889 .43161 L .63869 .43186 L .067 0 .41 r
F
.63665 .42766 m .63771 .42696 L .63757 .42702 L .66 .805 .952 r
F
.6373 .42713 m .63757 .42702 L .63777 .4325 L .492 .27 .504 r
F
.63741 .43345 m .63806 .43265 L .63788 .43242 L .659 .805 .953 r
F
.63759 .43257 m .63777 .4325 L .63817 .44329 L .492 .27 .504 r
F
.6373 .42713 m .63777 .4325 L .63759 .43257 L F
.63909 .43196 m .63947 .43251 L .64047 .43234 L .659 .805 .953 r
F
.63586 .42762 m .63628 .42755 L .63648 .43303 L .629 .374 .513 r
F
.6362 .43308 m .63648 .43303 L .63687 .44379 L F
.63586 .42762 m .63648 .43303 L .6362 .43308 L F
.63482 .43077 m .63692 .43295 L .63788 .43242 L .659 .805 .953 r
F
.63692 .43295 m .637 .43303 L .63719 .4329 L F
.63692 .43295 m .63719 .4329 L .63788 .43242 L F
.63757 .42702 m .63771 .42696 L .63769 .42693 L .66 .805 .952 r
F
.6378 .42686 m .63824 .43217 L .63757 .42702 L .328 .148 .478 r
F
.63791 .43244 m .64131 .43427 L .63856 .43217 L .659 .805 .953 r
F
.63813 .43256 m .63873 .43333 L .63883 .43294 L F
.63824 .43217 m .63909 .44263 L .63808 .43228 L .328 .148 .478 r
F
.63824 .43217 m .63808 .43228 L .63757 .42702 L F
.6387 .43185 m .63856 .43217 L .63909 .43196 L .659 .805 .953 r
F
.63482 .43077 m .63835 .43209 L .6387 .43185 L F
.63835 .43209 m .63856 .43217 L .6387 .43185 L F
.63856 .43217 m .63947 .43251 L .63909 .43196 L F
.63947 .43251 m .65227 .4373 L .64047 .43234 L F
.63482 .43077 m .63791 .43244 L .63856 .43217 L F
.637 .43303 m .63741 .43345 L .63788 .43242 L F
.63692 .43295 m .63739 .43347 L .63741 .43345 L F
.63695 .43307 m .63784 .43692 L .637 .43304 L F
.63759 .43257 m .63817 .44329 L .63713 .43276 L .492 .27 .504 r
F
.63405 .42496 m .63769 .42693 L .63868 .42625 L .66 .805 .952 r
F
.63541 .36439 m .63607 .41725 L .63643 .41733 L .822 .528 .492 r
F
.63541 .36439 m .63643 .41733 L .63737 .41755 L F
.63414 .36395 m .63511 .41722 L .63607 .41725 L .735 .457 .508 r
F
.63537 .41723 m .65076 .40903 L .64625 .40721 L .661 .804 .952 r
F
.63328 .41916 m .63654 .41727 L .63537 .41723 L F
.63654 .41727 m .65076 .40903 L .63537 .41723 L F
.63692 .43295 m .63695 .43307 L .637 .43304 L .659 .805 .953 r
F
.63713 .43276 m .63817 .44329 L .63648 .43303 L .492 .27 .504 r
F
.63482 .43077 m .63569 .43316 L .63692 .43295 L .659 .805 .953 r
F
.6355 .4332 m .63687 .44379 L .63517 .43325 L .629 .374 .513 r
F
.63482 .43077 m .6345 .43337 L .63569 .43316 L .659 .805 .953 r
F
.63451 .43337 m .63687 .44379 L .63489 .44403 L .629 .374 .513 r
F
.63517 .43325 m .63687 .44379 L .63451 .43337 L F
.63405 .42496 m .63646 .42747 L .63769 .42693 L .66 .805 .952 r
F
.66313 .43542 m .67777 .4434 L .68977 .43498 L .661 .804 .952 r
F
.66313 .43542 m .68977 .43498 L .67112 .42976 L F
.64916 .43316 m .66408 .44125 L .67213 .43557 L .66 .805 .952 r
F
.64916 .43316 m .67213 .43557 L .65318 .43029 L F
.64275 .43152 m .65398 .43608 L .65672 .43285 L .659 .805 .953 r
F
.63895 .4258 m .63928 .43113 L .63919 .43123 L .067 0 .41 r
F
.63895 .4258 m .63919 .43123 L .63863 .42619 L F
.63919 .43123 m .63899 .43149 L .63863 .42619 L F
.63863 .42619 m .63899 .43149 L .63849 .42638 L F
.63899 .43149 m .63889 .43161 L .63849 .42638 L F
.63482 .43077 m .64713 .43419 L .64275 .43152 L .659 .805 .953 r
F
.64713 .43419 m .65398 .43608 L .64275 .43152 L F
.63772 .41776 m .63783 .42317 L .63861 .41831 L .931 .625 .44 r
F
.63783 .42317 m .63849 .42358 L .63861 .41831 L F
.63784 .42277 m .65497 .41731 L .65165 .4148 L .66 .805 .952 r
F
.63721 .41688 m .65406 .41154 L .65076 .40903 L .661 .804 .952 r
F
.63328 .41916 m .64081 .41639 L .63721 .41688 L F
.64081 .41639 m .65406 .41154 L .63721 .41688 L F
.63737 .41755 m .63723 .42294 L .63757 .42302 L .822 .528 .492 r
F
.63772 .41776 m .63757 .42302 L .63783 .42317 L .931 .625 .44 r
F
.63745 .42299 m .63987 .42283 L .63784 .42277 L .66 .805 .952 r
F
.63405 .42496 m .63867 .42327 L .63745 .42299 L F
.63867 .42327 m .63987 .42283 L .63745 .42299 L F
.63405 .42496 m .63506 .42776 L .63519 .42774 L F
.63283 .3638 m .63377 .41734 L .63475 .41721 L .65 .39 .512 r
F
.63328 .41916 m .64625 .40721 L .64083 .40621 L .661 .804 .952 r
F
.63849 .42358 m .63837 .42887 L .63881 .42377 L .931 .625 .44 r
F
.63482 .43077 m .64275 .43152 L .64273 .43151 L .659 .805 .953 r
F
.63946 .4304 m .63938 .4307 L .63913 .42543 L 0 0 .209 r
F
.64094 .43043 m .65673 .43282 L .64516 .43019 L .659 .805 .953 r
F
.63913 .42543 m .63938 .4307 L .63907 .42565 L 0 0 .209 r
F
.63938 .4307 m .63935 .43084 L .63907 .42565 L F
.63907 .42565 m .63935 .43084 L .63928 .43113 L F
.63482 .43077 m .64273 .43151 L .64094 .43043 L .659 .805 .953 r
F
.64273 .43151 m .65673 .43282 L .64094 .43043 L F
.63783 .42317 m .63757 .42302 L .63777 .4285 L .931 .625 .44 r
F
.63788 .43242 m .63806 .43265 L .63813 .43256 L .659 .805 .953 r
F
.63777 .4325 m .63909 .44263 L .63817 .44329 L .328 .148 .478 r
F
.63808 .43228 m .63909 .44263 L .63777 .4325 L F
.63924 .42498 m .63948 .43029 L .63946 .4304 L 0 0 .209 r
F
.63482 .43077 m .64516 .43019 L .64427 .42998 L .659 .805 .953 r
F
.67112 .42976 m .68977 .43498 L .69808 .4254 L .661 .804 .952 r
F
.67112 .42976 m .69808 .4254 L .6766 .42333 L F
.65318 .43029 m .67765 .42913 L .65591 .42705 L .66 .805 .952 r
F
.64166 .42939 m .65792 .42884 L .64608 .42849 L .659 .805 .953 r
F
.63924 .42976 m .63932 .42993 L .63928 .4248 L .944 .685 .22 r
F
.63924 .42498 m .63928 .4248 L .63948 .43029 L 0 0 .209 r
F
.63928 .4248 m .63932 .42993 L .63948 .43029 L .944 .685 .22 r
F
.63482 .43077 m .64427 .42998 L .64166 .42939 L .659 .805 .953 r
F
.64427 .42998 m .65792 .42884 L .64166 .42939 L F
.63646 .42747 m .63722 .42716 L .63769 .42693 L .66 .805 .952 r
F
.63643 .41733 m .63654 .42278 L .63737 .41755 L .822 .528 .492 r
F
.63405 .42496 m .63745 .42299 L .63644 .42276 L .66 .805 .952 r
F
.63654 .42278 m .63664 .42825 L .63723 .42294 L .822 .528 .492 r
F
.63664 .42825 m .63709 .42835 L .63723 .42294 L F
.63654 .42278 m .63723 .42294 L .63737 .41755 L F
.63643 .41733 m .63627 .42272 L .63654 .42278 L F
.63772 .41776 m .63737 .41755 L .63757 .42302 L .931 .625 .44 r
F
.63644 .42276 m .63892 .42214 L .6368 .42243 L .66 .805 .952 r
F
.63745 .42299 m .63892 .42214 L .63644 .42276 L F
.6368 .42243 m .65165 .4148 L .64711 .41298 L F
.63892 .42214 m .65165 .4148 L .6368 .42243 L F
.63723 .42294 m .63709 .42835 L .63757 .42302 L .822 .528 .492 r
F
.63709 .42835 m .63731 .4284 L .63757 .42302 L F
.63757 .42302 m .63731 .4284 L .63777 .4285 L F
.63607 .41725 m .63592 .42271 L .63627 .42272 L .735 .457 .508 r
F
.63511 .41722 m .63521 .42269 L .63607 .41725 L F
.63405 .42496 m .63648 .42273 L .63538 .42269 L .66 .805 .952 r
F
.63521 .42269 m .63592 .42271 L .63607 .41725 L .735 .457 .508 r
F
.63386 .42282 m .63459 .42273 L .63475 .41721 L .65 .39 .512 r
F
.63475 .41721 m .63459 .42273 L .63494 .42268 L F
.63643 .41733 m .63607 .41725 L .63627 .42272 L .822 .528 .492 r
F
.63511 .41722 m .63475 .41721 L .63494 .42268 L .735 .457 .508 r
F
.63511 .41722 m .63494 .42268 L .63521 .42269 L F
.63283 .3638 m .63339 .41739 L .63377 .41734 L .65 .39 .512 r
F
.63328 .41916 m .64083 .40621 L .63489 .4061 L .661 .804 .952 r
F
.63433 .42266 m .64166 .41197 L .63568 .41186 L .66 .805 .952 r
F
.63405 .42496 m .63538 .42269 L .63433 .42266 L F
.63538 .42269 m .64166 .41197 L .63433 .42266 L F
.63482 .43077 m .63634 .4282 L .63515 .42817 L .659 .805 .953 r
F
.63521 .42269 m .63494 .42268 L .63514 .42817 L .735 .457 .508 r
F
.63377 .41734 m .63386 .42282 L .63475 .41721 L .65 .39 .512 r
F
.63377 .41734 m .63339 .41739 L .63359 .42286 L F
.63377 .41734 m .63359 .42286 L .63386 .42282 L F
.63267 .41749 m .63352 .41717 L .63255 .41714 L .661 .804 .952 r
F
.63328 .41916 m .6335 .41738 L .63267 .41749 L F
.6335 .41738 m .63352 .41717 L .63267 .41749 L F
.63255 .41714 m .63489 .4061 L .62884 .40688 L F
.63352 .41717 m .63489 .4061 L .63255 .41714 L F
.63244 .42051 m .63248 .42321 L .63276 .42141 L .547 .31 .508 r
F
.63244 .42051 m .63276 .42141 L .63339 .41739 L F
.63239 .41771 m .63244 .42051 L .63339 .41739 L F
.63248 .42321 m .63298 .42305 L .63339 .41739 L F
.63257 .42873 m .63305 .42858 L .63339 .41739 L F
.63339 .41739 m .63322 .42298 L .63359 .42286 L F
.6333 .4229 m .63568 .41186 L .62959 .41265 L .66 .805 .952 r
F
.63405 .42496 m .63432 .42276 L .6333 .4229 L F
.63432 .42276 m .63568 .41186 L .6333 .4229 L F
.63482 .43077 m .63514 .42817 L .63394 .42833 L .659 .805 .953 r
F
.63386 .42282 m .63378 .42835 L .63396 .42833 L .65 .39 .512 r
F
.63386 .42282 m .63396 .42833 L .63459 .42273 L F
.63396 .42833 m .63442 .42826 L .63459 .42273 L F
.63521 .42269 m .63514 .42817 L .63532 .42817 L .735 .457 .508 r
F
.63521 .42269 m .63522 .42271 L .63522 .42269 L F
.63522 .42271 m .63532 .42817 L .63522 .42269 L F
.63522 .42269 m .63532 .42817 L .63592 .42271 L F
.63538 .42269 m .6368 .42243 L .63542 .42261 L .66 .805 .952 r
F
.63648 .42273 m .6368 .42243 L .63538 .42269 L F
.63542 .42261 m .64711 .41298 L .64166 .41197 L F
.6368 .42243 m .64711 .41298 L .63542 .42261 L F
.63482 .43077 m .63515 .42817 L .63514 .42817 L .659 .805 .953 r
F
.63627 .42272 m .636 .42819 L .63647 .42821 L .735 .457 .508 r
F
.63783 .42317 m .63777 .4285 L .63794 .4286 L .931 .625 .44 r
F
.63837 .42887 m .63858 .42899 L .63881 .42377 L F
.63654 .42278 m .63627 .42272 L .63647 .42821 L .822 .528 .492 r
F
.63654 .42278 m .63647 .42821 L .63664 .42825 L F
.63987 .42283 m .65497 .41731 L .63784 .42277 L .66 .805 .952 r
F
.63783 .42317 m .63794 .4286 L .63849 .42358 L .931 .625 .44 r
F
.63794 .4286 m .63837 .42887 L .63849 .42358 L F
.63824 .42342 m .6404 .42367 L .63867 .42327 L .66 .805 .952 r
F
.63908 .42394 m .6404 .42367 L .63824 .42342 L F
.6404 .42367 m .65685 .42033 L .63867 .42327 L F
.63891 .42399 m .63881 .42377 L .63901 .42926 L .944 .685 .22 r
F
.63891 .42399 m .63901 .42926 L .63908 .4294 L F
.63881 .42377 m .63858 .42899 L .63901 .42926 L .931 .625 .44 r
F
.63891 .42399 m .63908 .4294 L .63916 .42454 L .944 .685 .22 r
F
.63908 .4294 m .63924 .42976 L .63916 .42454 L F
.63908 .42394 m .64109 .42456 L .64316 .42311 L .66 .805 .952 r
F
.64018 .42461 m .64109 .42456 L .63908 .42394 L F
.63634 .4282 m .64791 .41881 L .64246 .41782 L .659 .805 .953 r
F
.63482 .43077 m .6376 .42824 L .63634 .4282 L F
.64109 .42456 m .65717 .42365 L .64316 .42311 L .66 .805 .952 r
F
.63974 .4255 m .65591 .42705 L .64109 .42456 L F
.6376 .42824 m .64791 .41881 L .63634 .4282 L .659 .805 .953 r
F
.6376 .42824 m .65246 .42063 L .64791 .41881 L F
.63482 .43077 m .63915 .42829 L .6376 .42824 L F
.63915 .42829 m .65246 .42063 L .6376 .42824 L F
.63592 .42271 m .63577 .42819 L .63627 .42272 L .735 .457 .508 r
F
.63482 .43077 m .65578 .42313 L .65246 .42063 L .659 .805 .953 r
F
.6766 .42333 m .69808 .4254 L .70209 .41528 L .661 .804 .952 r
F
.6766 .42333 m .70209 .41528 L .67919 .41657 L F
.65591 .42705 m .68026 .42235 L .65717 .42365 L .66 .805 .952 r
F
.63482 .43077 m .65766 .42614 L .65578 .42313 L .659 .805 .953 r
F
.63577 .42819 m .6355 .43815 L .636 .42819 L .735 .457 .508 r
F
.63577 .42819 m .636 .42819 L .63627 .42272 L F
.63514 .42817 m .63413 .43826 L .6355 .43815 L .65 .39 .512 r
F
.63494 .42268 m .63465 .42823 L .63514 .42817 L F
.63163 .42926 m .63188 .42911 L .6322 .4233 L .369 .177 .485 r
F
.63105 .42402 m .63114 .42957 L .63182 .42354 L F
.63114 .42957 m .63163 .42926 L .63182 .42354 L F
.63482 .43077 m .63102 .42872 L .6286 .42905 L .659 .805 .953 r
F
.63014 .42458 m .61205 .42285 L .6291 .42524 L .66 .805 .952 r
F
.63102 .42872 m .62457 .42013 L .61949 .42249 L .659 .805 .953 r
F
.63248 .42321 m .63257 .42873 L .63298 .42305 L .547 .31 .508 r
F
.63248 .42321 m .6322 .4233 L .63239 .42879 L F
.63248 .42321 m .63239 .42879 L .63257 .42873 L F
.6322 .4233 m .63188 .42911 L .63239 .42879 L .369 .177 .485 r
F
.63482 .43077 m .63264 .4285 L .63102 .42872 L .659 .805 .953 r
F
.63264 .4285 m .62457 .42013 L .63102 .42872 L F
.63459 .42273 m .63442 .42826 L .63494 .42268 L .65 .39 .512 r
F
.63386 .42282 m .63359 .42286 L .63378 .42835 L F
.63322 .42298 m .63305 .42858 L .63359 .42286 L .547 .31 .508 r
F
.63305 .42858 m .63328 .42851 L .63359 .42286 L F
.63359 .42286 m .63328 .42851 L .63378 .42835 L F
.63482 .43077 m .63036 .4185 L .62457 .42013 L .659 .805 .953 r
F
.63442 .42826 m .63413 .43826 L .63465 .42823 L .65 .39 .512 r
F
.63442 .42826 m .63465 .42823 L .63494 .42268 L F
.63465 .42823 m .63413 .43826 L .63514 .42817 L F
.6286 .42905 m .61949 .42249 L .61547 .42541 L .659 .805 .953 r
F
.63102 .42872 m .61949 .42249 L .6286 .42905 L F
.63514 .42817 m .63647 .41771 L .63386 .42813 L F
.63515 .42817 m .63515 .42817 L .63514 .42817 L F
.63515 .42817 m .63647 .41771 L .63514 .42817 L F
.63396 .42833 m .63378 .42835 L .63413 .43826 L .65 .39 .512 r
F
.63396 .42833 m .63413 .43826 L .63442 .42826 L F
.63394 .42833 m .63514 .42817 L .63386 .42813 L .659 .805 .953 r
F
.63332 .42295 m .62959 .41265 L .6324 .42324 L .66 .805 .952 r
F
.63386 .42813 m .63647 .41771 L .63036 .4185 L .659 .805 .953 r
F
.63532 .42817 m .63514 .42817 L .6355 .43815 L .735 .457 .508 r
F
.63532 .42817 m .63577 .42819 L .63592 .42271 L F
.63515 .42817 m .63635 .42818 L .63518 .42791 L .659 .805 .953 r
F
.63634 .4282 m .63635 .42818 L .63515 .42817 L F
.63532 .42817 m .6355 .43815 L .63577 .42819 L .735 .457 .508 r
F
.63518 .42791 m .64246 .41782 L .63647 .41771 L .659 .805 .953 r
F
.63635 .42818 m .64246 .41782 L .63518 .42791 L F
.63664 .42825 m .63684 .4383 L .63709 .42835 L .822 .528 .492 r
F
.63709 .42835 m .63684 .4383 L .63731 .4284 L F
.63777 .4285 m .63684 .4383 L .63815 .43874 L F
.63731 .4284 m .63684 .4383 L .63777 .4285 L F
.64427 .42998 m .65798 .42946 L .65792 .42884 L .659 .805 .953 r
F
.64516 .43019 m .65798 .42946 L .64427 .42998 L F
.65591 .42705 m .67765 .42913 L .68026 .42235 L .66 .805 .952 r
F
.64608 .42849 m .65792 .42884 L .65766 .42614 L .659 .805 .953 r
F
.63647 .42821 m .6355 .43815 L .63684 .4383 L .735 .457 .508 r
F
.636 .42819 m .6355 .43815 L .63647 .42821 L F
.63794 .4286 m .63777 .4285 L .63815 .43874 L .931 .625 .44 r
F
.6383 .43213 m .63828 .43273 L .63824 .43217 L .328 .148 .478 r
F
.63856 .43195 m .63828 .43273 L .6383 .43213 L F
.63856 .43195 m .63909 .44263 L .63828 .43273 L F
.63837 .42887 m .63815 .43874 L .63858 .42899 L .931 .625 .44 r
F
.64273 .43151 m .65672 .43285 L .65673 .43282 L .659 .805 .953 r
F
.64275 .43152 m .65672 .43285 L .64273 .43151 L F
.65318 .43029 m .67213 .43557 L .67765 .42913 L .66 .805 .952 r
F
.64516 .43019 m .65673 .43282 L .65798 .42946 L .659 .805 .953 r
F
.63664 .42825 m .63647 .42821 L .63684 .4383 L .822 .528 .492 r
F
.63794 .4286 m .63815 .43874 L .63837 .42887 L .931 .625 .44 r
F
.63919 .43123 m .63968 .44184 L .63899 .43149 L .067 0 .41 r
F
.63899 .43149 m .63968 .44184 L .63889 .43161 L F
.63869 .43186 m .63968 .44184 L .63909 .44263 L F
.63889 .43161 m .63968 .44184 L .63869 .43186 L F
.63908 .4294 m .63901 .42926 L .6394 .43969 L .944 .685 .22 r
F
.64071 .43298 m .64996 .43895 L .65227 .4373 L .659 .805 .953 r
F
.64131 .43427 m .64996 .43895 L .64071 .43298 L F
.64713 .43419 m .65227 .4373 L .65398 .43608 L F
.63856 .43195 m .63869 .43186 L .63909 .44263 L .328 .148 .478 r
F
.63901 .42926 m .63815 .43874 L .6394 .43969 L .931 .625 .44 r
F
.63858 .42899 m .63815 .43874 L .63901 .42926 L F
.63919 .43123 m .63928 .43113 L .63968 .44184 L .067 0 .41 r
F
.63908 .4294 m .6394 .43969 L .63924 .42976 L .944 .685 .22 r
F
.63928 .43113 m .63988 .4409 L .63968 .44184 L 0 0 .209 r
F
.63935 .43084 m .63988 .4409 L .63928 .43113 L F
.63924 .42976 m .6394 .43969 L .63932 .42993 L .944 .685 .22 r
F
.63946 .4304 m .63988 .4409 L .63938 .4307 L 0 0 .209 r
F
.63257 .42873 m .63239 .42879 L .63274 .43865 L .547 .31 .508 r
F
.63163 .42926 m .63129 .43956 L .63188 .42911 L .369 .177 .485 r
F
.62864 .43112 m .62813 .43014 L .62422 .43137 L .659 .805 .953 r
F
.62994 .43031 m .62813 .43014 L .62864 .43112 L F
.62813 .43014 m .6128 .42868 L .62422 .43137 L F
.63257 .42873 m .63274 .43865 L .63305 .42858 L .547 .31 .508 r
F
.63095 .42969 m .63056 .44075 L .63129 .43956 L 0 0 .377 r
F
.63069 .43008 m .63056 .44075 L .63095 .42969 L F
.63202 .43304 m .63296 .44373 L .63182 .43297 L .862 .563 .481 r
F
.63239 .42879 m .63129 .43956 L .63274 .43865 L .369 .177 .485 r
F
.63188 .42911 m .63129 .43956 L .63239 .42879 L F
.62648 .43246 m .62422 .43137 L .61205 .43539 L .659 .805 .953 r
F
.62864 .43112 m .62422 .43137 L .62648 .43246 L F
.61328 .43255 m .59266 .44009 L .59943 .44494 L .66 .805 .952 r
F
.62422 .43137 m .61163 .43209 L .61203 .43523 L .659 .805 .953 r
F
.62422 .43137 m .61203 .43523 L .61205 .43539 L F
.63305 .42858 m .63274 .43865 L .63328 .42851 L .547 .31 .508 r
F
.63378 .42835 m .63274 .43865 L .63413 .43826 L F
.63328 .42851 m .63274 .43865 L .63378 .42835 L F
.63114 .42957 m .63129 .43956 L .63163 .42926 L .369 .177 .485 r
F
.63057 .43026 m .63056 .44075 L .63069 .43008 L 0 0 .377 r
F
.63114 .42957 m .63095 .42969 L .63129 .43956 L .369 .177 .485 r
F
.62019 .43637 m .61402 .43836 L .61539 .43935 L .659 .805 .953 r
F
.62019 .43637 m .61539 .43935 L .61738 .4408 L F
.63032 .43064 m .63056 .44075 L .63057 .43026 L 0 0 .377 r
F
.63022 .43078 m .63057 .44169 L .63056 .44075 L 0 0 .044 r
F
.63022 .43107 m .63057 .44169 L .63022 .43078 L F
.63022 .4315 m .63057 .44169 L .63022 .43107 L F
.63024 .43496 m .62192 .44256 L .63025 .43586 L .659 .805 .953 r
F
.63032 .43064 m .63022 .43078 L .63056 .44075 L 0 0 .377 r
F
.62278 .44194 m .62192 .44256 L .62232 .44263 L .659 .805 .953 r
F
.62278 .44194 m .62232 .44263 L .62731 .44352 L F
.63022 .4315 m .63022 .43161 L .63057 .44169 L 0 0 .044 r
F
.63027 .43934 m .62731 .44352 L .63029 .44357 L .659 .805 .953 r
F
.63938 .4307 m .63988 .4409 L .63935 .43084 L 0 0 .209 r
F
.63946 .4304 m .63948 .43029 L .63988 .4409 L F
.63948 .43029 m .6394 .43969 L .63988 .4409 L .944 .685 .22 r
F
.63932 .42993 m .6394 .43969 L .63948 .43029 L F
.64411 .44041 m .64454 .44135 L .64492 .44125 L .659 .805 .953 r
F
.35913 .46206 m .34244 .4542 L .33212 .46254 L .662 .803 .95 r
F
.36833 .45759 m .34244 .4542 L .35913 .46206 L F
.21725 .72628 m .21087 .72648 L .21574 .72749 L .66 .811 .956 r
F
.58022 .31172 m .55461 .30296 L .54468 .31646 L .657 .779 .938 r
F
.58308 .46053 m .59595 .4599 L .59665 .46564 L .875 .587 .497 r
F
.58308 .46053 m .5824 .45476 L .59595 .4599 L F
.59943 .44494 m .59595 .4599 L .60847 .44841 L .66 .805 .952 r
F
.59943 .44494 m .5824 .45476 L .59595 .4599 L F
0 g
.59595 .4599 m
.60183 .46091 L
s
.55466 .30974 m .54424 .3164 L .54466 .32328 L .097 .008 .455 r
F
.55466 .30974 m .55422 .30282 L .54424 .3164 L F
0 g
.54032 .3306 m
.54424 .3164 L
s
.67881 .44924 m .67798 .44352 L .69005 .43506 L .385 .24 .559 r
F
0 g
.66851 .44781 m
.67798 .44352 L
s
.22997 .72161 m .22828 .7186 L .22731 .72125 L .66 .81 .955 r
F
.22997 .72161 m .23229 .71914 L .22828 .7186 L F
.71569 .60161 m .70561 .5998 L .70554 .60472 L .495 .293 .535 r
F
.71569 .60161 m .71575 .59668 L .70561 .5998 L F
0 g
.69751 .60414 m
.70561 .5998 L
s
.6403 .31124 m .63466 .29219 L .63256 .31076 L .657 .779 .938 r
F
.6403 .31124 m .6503 .29318 L .63466 .29219 L F
.2387 .72463 m .23581 .72018 L .23589 .72316 L .918 .636 .492 r
F
0 g
.2387 .72463 m
.24059 .72643 L
s
.2324 .72528 m .23236 .72212 L .23005 .72459 L .66 .811 .956 r
F
.2324 .72528 m .23589 .72316 L .23236 .72212 L F
.72116 .32691 m .71351 .30684 L .71426 .31375 L .951 .662 .217 r
F
0 g
.72116 .32691 m
.72186 .34091 L
s
.7701 .60855 m .77009 .60362 L .76147 .59939 L .877 .609 .528 r
F
0 g
.77009 .60362 m
.77621 .60881 L
s
.21314 .72467 m .21082 .7235 L .21087 .72648 L .293 .139 .494 r
F
.21314 .72467 m .21309 .72169 L .21082 .7235 L F
0 g
.20954 .72552 m
.21082 .7235 L
s
.72965 .60762 m .7272 .59995 L .71569 .60161 L .6 .765 .958 r
F
.73763 .60756 m .7272 .59995 L .72965 .60762 L F
.58094 .32543 m .54508 .33019 L .57415 .33436 L .656 .78 .94 r
F
.21927 .72232 m .2162 .7202 L .21309 .72169 L .66 .81 .955 r
F
.22176 .72162 m .2162 .7202 L .21927 .72232 L F
.74539 .60855 m .73923 .59986 L .73763 .60756 L .6 .765 .958 r
F
.74539 .60855 m .75093 .60136 L .73923 .59986 L F
.40204 .59953 m .40251 .59462 L .41343 .59295 L .581 .355 .538 r
F
0 g
.39937 .59464 m
.40251 .59462 L
s
.62468 .31153 m .61872 .29375 L .60364 .29775 L .657 .779 .938 r
F
.63256 .31076 m .61872 .29375 L .62468 .31153 L F
.2162 .7202 m .21303 .71871 L .21309 .72169 L .472 .275 .531 r
F
.2162 .7202 m .21614 .71723 L .21303 .71871 L F
0 g
.21076 .72053 m
.21303 .71871 L
s
.22731 .72125 m .22407 .7186 L .22451 .72126 L .66 .81 .955 r
F
.22731 .72125 m .22828 .7186 L .22407 .7186 L F
.72197 .61364 m .71564 .60655 L .70547 .60965 L .599 .766 .959 r
F
.72961 .61255 m .71564 .60655 L .72197 .61364 L F
.75238 .61544 m .75092 .6063 L .74537 .61348 L F
.75238 .61544 m .76147 .60927 L .75092 .6063 L F
.23581 .72018 m .23222 .71616 L .23229 .71914 L .854 .58 .523 r
F
.23589 .72316 m .23581 .72018 L .23229 .71914 L F
0 g
.23581 .72018 m
.23862 .72166 L
s
.63256 .31076 m .63466 .29219 L .61872 .29375 L .657 .779 .938 r
F
.21725 .72628 m .21314 .72467 L .21087 .72648 L .66 .811 .956 r
F
0 g
.2096 .72849 m
.21087 .72648 L
s
.21933 .7253 m .21314 .72467 L .21725 .72628 L .66 .811 .956 r
F
.22176 .72162 m .21995 .71915 L .2162 .7202 L .66 .81 .955 r
F
.22451 .72126 m .21995 .71915 L .22176 .72162 L F
.22451 .72126 m .22407 .7186 L .21995 .71915 L F
.73763 .60756 m .73923 .59986 L .7272 .59995 L .6 .765 .958 r
F
.23229 .71914 m .23222 .71616 L .22821 .71562 L .792 .528 .538 r
F
0 g
.23222 .71616 m
.23574 .71721 L
s
.64805 .31973 m .65103 .29992 L .64095 .31803 L .657 .779 .939 r
F
.64805 .31973 m .66534 .3034 L .65103 .29992 L F
.6546 .32941 m .666 .31033 L .64867 .32663 L .656 .78 .94 r
F
.6546 .32941 m .67787 .31601 L .666 .31033 L F
.23005 .72459 m .22835 .72158 L .22738 .72423 L .66 .811 .956 r
F
.23005 .72459 m .23236 .72212 L .22835 .72158 L F
.41382 .455 m .40837 .44068 L .40279 .45314 L .662 .803 .95 r
F
.41382 .455 m .42501 .44353 L .40837 .44068 L F
.63598 .18385 m .60641 .1765 L .60611 .18499 L .654 .396 .517 r
F
0 g
.578 .19137 m
.60611 .18499 L
s
.63598 .18385 m .6362 .17536 L .60641 .1765 L .654 .396 .517 r
F
0 g
.57838 .1829 m
.60641 .1765 L
s
.45133 .46717 m .43995 .4543 L .44042 .46007 L .939 .646 .459 r
F
0 g
.45133 .46717 m
.45809 .47567 L
s
.66533 .18808 m .66547 .17958 L .6362 .17536 L .733 .462 .518 r
F
0 g
.66547 .17958 m
.692 .18883 L
s
.42433 .46978 m .42608 .4549 L .41479 .46639 L .66 .804 .952 r
F
.42433 .46978 m .44042 .46007 L .42608 .4549 L F
.21933 .7253 m .21626 .72319 L .21314 .72467 L .66 .811 .956 r
F
.22183 .7246 m .21626 .72319 L .21933 .7253 L F
.21995 .71915 m .21614 .71723 L .2162 .7202 L .584 .361 .544 r
F
.21995 .71915 m .21989 .71617 L .21614 .71723 L F
0 g
.21303 .71871 m
.21614 .71723 L
s
.21626 .72319 m .21309 .72169 L .21314 .72467 L .472 .275 .531 r
F
0 g
.21087 .72648 m
.21314 .72467 L
s
.21626 .72319 m .2162 .7202 L .21309 .72169 L .472 .275 .531 r
F
0 g
.21082 .7235 m
.21309 .72169 L
s
.22738 .72423 m .22414 .72159 L .22457 .72423 L .66 .811 .956 r
F
.22738 .72423 m .22835 .72158 L .22414 .72159 L F
.71564 .60655 m .70554 .60472 L .70547 .60965 L .495 .293 .535 r
F
0 g
.69736 .61397 m
.70547 .60965 L
s
.71564 .60655 m .71569 .60161 L .70554 .60472 L .495 .293 .535 r
F
0 g
.69743 .60905 m
.70554 .60472 L
s
.23589 .72316 m .23229 .71914 L .23236 .72212 L .854 .58 .523 r
F
0 g
.23589 .72316 m
.2387 .72463 L
s
.6177 .32029 m .60404 .30451 L .5908 .31067 L .657 .779 .939 r
F
.62522 .31832 m .60404 .30451 L .6177 .32029 L F
.35931 .46773 m .3425 .45986 L .33212 .46822 L .661 .803 .951 r
F
.36857 .46324 m .3425 .45986 L .35931 .46773 L F
.22828 .7186 m .22821 .71562 L .22401 .71563 L .731 .478 .546 r
F
.23229 .71914 m .22821 .71562 L .22828 .7186 L .792 .528 .538 r
F
0 g
.22821 .71562 m
.23222 .71616 L
s
.7701 .60855 m .76147 .59939 L .76147 .60432 L .877 .609 .528 r
F
.77012 .61349 m .7701 .60855 L .76147 .60432 L F
0 g
.7701 .60855 m
.77624 .61372 L
s
.3425 .45986 m .33182 .46246 L .33212 .46822 L .313 .168 .518 r
F
.3425 .45986 m .34218 .45409 L .33182 .46246 L F
0 g
.3257 .47178 m
.33182 .46246 L
s
.22183 .7246 m .22001 .72213 L .21626 .72319 L .66 .811 .956 r
F
.22457 .72423 m .22001 .72213 L .22183 .7246 L F
.60014 .45072 m .59665 .46564 L .6092 .45418 L .659 .805 .953 r
F
.60014 .45072 m .58308 .46053 L .59665 .46564 L F
0 g
.59665 .46564 m
.61266 .4684 L
s
.68576 .31658 m .70076 .29546 L .67719 .30909 L .657 .779 .939 r
F
.68576 .31658 m .71351 .30684 L .70076 .29546 L F
.22457 .72423 m .22414 .72159 L .22001 .72213 L .66 .811 .956 r
F
.67881 .44924 m .69005 .43506 L .69089 .4408 L .385 .24 .559 r
F
.67964 .45498 m .67881 .44924 L .69089 .4408 L F
.66408 .44125 m .67881 .44924 L .69089 .4408 L .66 .805 .952 r
F
.65407 .44581 m .67881 .44924 L .66408 .44125 L F
0 g
.66926 .45355 m
.67881 .44924 L
s
.63574 .3412 m
.63664 .36536 L
s
.23236 .72212 m .23229 .71914 L .22828 .7186 L .792 .528 .538 r
F
0 g
.23229 .71914 m
.23581 .72018 L
s
.72961 .61255 m .72715 .60489 L .71564 .60655 L .599 .766 .959 r
F
.7376 .6125 m .72715 .60489 L .72961 .61255 L F
.36677 .60009 m .37842 .59813 L .37793 .60305 L .798 .548 .561 r
F
.36677 .60009 m .36728 .59516 L .37842 .59813 L F
.37452 .58887 m .36728 .59516 L .37842 .59813 L .598 .766 .96 r
F
0 g
.37842 .59813 m
.38024 .59836 L
s
.6279 .34134 m
.62872 .36522 L
s
.74537 .61348 m .7392 .60481 L .7376 .6125 L .599 .766 .959 r
F
.74537 .61348 m .75092 .6063 L .7392 .60481 L F
.61166 .33022 m .59132 .3176 L .58094 .32543 L .656 .78 .94 r
F
.61826 .32719 m .59132 .3176 L .61166 .33022 L F
.40204 .59953 m .41343 .59295 L .41298 .59787 L .581 .355 .538 r
F
.40158 .60446 m .40204 .59953 L .41298 .59787 L F
.39781 .5918 m .40204 .59953 L .41298 .59787 L .598 .766 .96 r
F
0 g
.39888 .59955 m
.40204 .59953 L
s
.22407 .7186 m .21989 .71617 L .21995 .71915 L .664 .425 .548 r
F
.22407 .7186 m .22401 .71563 L .21989 .71617 L F
0 g
.21614 .71723 m
.21989 .71617 L
s
.5905 .3039 m .55461 .30296 L .58022 .31172 L .657 .779 .938 r
F
.22828 .7186 m .22401 .71563 L .22407 .7186 L .731 .478 .546 r
F
0 g
.21989 .71617 m
.22401 .71563 L
s
.22401 .71563 m
.22821 .71562 L
s
.58045 .31852 m .55466 .30974 L .54466 .32328 L .657 .779 .939 r
F
.5551 .31668 m .54466 .32328 L .54508 .33019 L .097 .008 .455 r
F
.5551 .31668 m .55466 .30974 L .54466 .32328 L F
0 g
.54073 .33746 m
.54466 .32328 L
s
.35756 .59089 m .36779 .59024 L .36728 .59516 L .861 .609 .557 r
F
.35756 .59089 m .35808 .58597 L .36779 .59024 L F
0 g
.36779 .59024 m
.37172 .59129 L
s
.7376 .6125 m .7392 .60481 L .72715 .60489 L .599 .766 .959 r
F
.64095 .31803 m .63528 .29892 L .63316 .31755 L .657 .779 .939 r
F
.64095 .31803 m .65103 .29992 L .63528 .29892 L F
.41298 .59787 m .41343 .59295 L .42281 .58981 L .469 .26 .513 r
F
0 g
.4042 .59436 m
.41343 .59295 L
s
.22001 .72213 m .2162 .7202 L .21626 .72319 L .584 .361 .544 r
F
.22001 .72213 m .21995 .71915 L .2162 .7202 L F
0 g
.21309 .72169 m
.2162 .7202 L
s
.21314 .72467 m
.21626 .72319 L
s
.63664 .36536 m
.63815 .40616 L
s
.36833 .45759 m .35628 .44742 L .34244 .4542 L .662 .803 .95 r
F
.3792 .45448 m .35628 .44742 L .36833 .45759 L F
.22835 .72158 m .22828 .7186 L .22407 .7186 L .731 .478 .546 r
F
.23236 .72212 m .22828 .7186 L .22835 .72158 L .792 .528 .538 r
F
0 g
.22828 .7186 m
.23229 .71914 L
s
.23236 .72212 m
.23589 .72316 L
s
.62872 .36522 m
.63016 .40671 L
s
.66533 .18808 m .6362 .17536 L .63598 .18385 L .733 .462 .518 r
F
0 g
.6362 .17536 m
.66547 .17958 L
s
.66533 .18808 m
.69194 .19731 L
s
.60641 .1765 m
.6362 .17536 L
s
.62522 .31832 m .61923 .30049 L .60404 .30451 L .657 .779 .939 r
F
.63316 .31755 m .61923 .30049 L .62522 .31832 L F
.41436 .46063 m .40888 .44627 L .40325 .45877 L .661 .803 .951 r
F
.41436 .46063 m .42563 .44912 L .40888 .44627 L F
.22414 .72159 m .21995 .71915 L .22001 .72213 L .664 .425 .548 r
F
.22414 .72159 m .22407 .7186 L .21995 .71915 L F
0 g
.2162 .7202 m
.21995 .71915 L
s
.63316 .31755 m .63528 .29892 L .61923 .30049 L .657 .779 .939 r
F
.22835 .72158 m .22407 .7186 L .22414 .72159 L .731 .478 .546 r
F
0 g
.21995 .71915 m
.22407 .7186 L
s
.22407 .7186 m
.22828 .7186 L
s
.22835 .72158 m
.23236 .72212 L
s
.64867 .32663 m .65167 .30686 L .64156 .32493 L .656 .78 .94 r
F
.64867 .32663 m .666 .31033 L .65167 .30686 L F
.7272 .59995 m .71575 .59668 L .71569 .60161 L .589 .368 .548 r
F
.7272 .59995 m .72724 .59501 L .71575 .59668 L F
0 g
.70561 .5998 m
.71575 .59668 L
s
.77012 .61349 m .76147 .60432 L .76147 .60927 L .877 .609 .528 r
F
0 g
.77012 .61349 m
.77626 .61865 L
s
.76147 .60432 m .76147 .59939 L .75094 .59642 L .803 .544 .547 r
F
0 g
.76147 .59939 m
.77009 .60362 L
s
.40279 .45314 m .39049 .4404 L .39097 .45296 L .662 .803 .95 r
F
.40279 .45314 m .40837 .44068 L .39049 .4404 L F
0 g
.21626 .72319 m
.22001 .72213 L
s
.37401 .59381 m .37793 .60305 L .38149 .59581 L .598 .767 .96 r
F
.37401 .59381 m .36677 .60009 L .37793 .60305 L F
0 g
.37793 .60305 m
.38306 .6037 L
s
.57219 .44757 m .58172 .44902 L .5824 .45476 L .947 .643 .429 r
F
.57219 .44757 m .57152 .4418 L .58172 .44902 L F
0 g
.58172 .44902 m
.58813 .45146 L
s
.35966 .4735 m .34283 .46565 L .33243 .474 L .66 .804 .952 r
F
.36893 .46902 m .34283 .46565 L .35966 .4735 L F
.34283 .46565 m .33212 .46822 L .33243 .474 L .313 .168 .518 r
F
0 g
.32628 .48327 m
.33243 .474 L
s
.34283 .46565 m .3425 .45986 L .33212 .46822 L .313 .168 .518 r
F
0 g
.32599 .47752 m
.33212 .46822 L
s
.40158 .60446 m .41298 .59787 L .41253 .6028 L .581 .355 .538 r
F
.39734 .59675 m .40158 .60446 L .41253 .6028 L .598 .767 .96 r
F
0 g
.39238 .60452 m
.40158 .60446 L
s
.59216 .43424 m .57183 .44169 L .58197 .44887 L .661 .804 .952 r
F
.67964 .45498 m .69089 .4408 L .69174 .44655 L .385 .24 .559 r
F
.66489 .44702 m .67964 .45498 L .69174 .44655 L .659 .805 .953 r
F
.65486 .45156 m .67964 .45498 L .66489 .44702 L F
0 g
.66465 .46172 m
.67964 .45498 L
s
.22414 .72159 m
.22835 .72158 L
s
.35704 .59582 m .36728 .59516 L .36677 .60009 L .861 .609 .557 r
F
.35704 .59582 m .35756 .59089 L .36728 .59516 L F
.36802 .586 m .36728 .59516 L .37452 .58887 L .598 .766 .96 r
F
.36802 .586 m .35756 .59089 L .36728 .59516 L F
0 g
.36728 .59516 m
.37124 .59621 L
s
.61826 .32719 m .60458 .31145 L .59132 .3176 L .656 .78 .94 r
F
.6258 .32522 m .60458 .31145 L .61826 .32719 L F
0 g
.22001 .72213 m
.22414 .72159 L
s
.41298 .59787 m .42281 .58981 L .42237 .59473 L .469 .26 .513 r
F
.41253 .6028 m .41298 .59787 L .42237 .59473 L F
.40514 .59068 m .41298 .59787 L .42237 .59473 L .598 .766 .96 r
F
.39781 .5918 m .41298 .59787 L .40514 .59068 L F
0 g
.4037 .59928 m
.41298 .59787 L
s
.68645 .32347 m .70149 .3024 L .67787 .31601 L .656 .78 .94 r
F
.68645 .32347 m .71426 .31375 L .70149 .3024 L F
.43995 .4543 m .43948 .44855 L .42518 .44335 L .869 .589 .51 r
F
0 g
.43948 .44855 m
.45036 .45569 L
s
.3792 .45448 m .3727 .4427 L .35628 .44742 L .662 .803 .95 r
F
.39097 .45296 m .3727 .4427 L .3792 .45448 L F
0 g
.60611 .18499 m
.63598 .18385 L
s
.5908 .31067 m .55466 .30974 L .58045 .31852 L .657 .779 .939 r
F
0 g
.63598 .18385 m
.66533 .18808 L
s
.39097 .45296 m .39049 .4404 L .3727 .4427 L .662 .803 .95 r
F
.58094 .32543 m .5551 .31668 L .54508 .33019 L .656 .78 .94 r
F
0 g
.54114 .34434 m
.54508 .33019 L
s
.36857 .46324 m .35645 .45305 L .3425 .45986 L .661 .803 .951 r
F
.37951 .46012 m .35645 .45305 L .36857 .46324 L F
.64156 .32493 m .63589 .30587 L .63375 .32445 L .656 .78 .94 r
F
.64156 .32493 m .65167 .30686 L .63589 .30587 L F
.41479 .46639 m .4093 .45207 L .40367 .46454 L .66 .804 .952 r
F
.41479 .46639 m .42608 .4549 L .4093 .45207 L F
.72715 .60489 m .71569 .60161 L .71564 .60655 L .589 .368 .548 r
F
0 g
.70547 .60965 m
.71564 .60655 L
s
.72715 .60489 m .7272 .59995 L .71569 .60161 L .589 .368 .548 r
F
0 g
.70554 .60472 m
.71569 .60161 L
s
.76147 .60432 m .75094 .59642 L .75093 .60136 L .803 .544 .547 r
F
.76147 .60927 m .76147 .60432 L .75093 .60136 L F
0 g
.76147 .60432 m
.7701 .60855 L
s
.6258 .32522 m .6198 .30744 L .60458 .31145 L .656 .78 .94 r
F
.63375 .32445 m .6198 .30744 L .6258 .32522 L F
.67628 .30234 m .682 .28007 L .66451 .29666 L .657 .779 .938 r
F
.67628 .30234 m .69968 .28875 L .682 .28007 L F
.73923 .59986 m .72724 .59501 L .7272 .59995 L .666 .43 .554 r
F
.73923 .59986 m .73925 .59492 L .72724 .59501 L F
0 g
.71575 .59668 m
.72724 .59501 L
s
.57287 .45336 m .5824 .45476 L .58308 .46053 L .947 .643 .429 r
F
.57287 .45336 m .57219 .44757 L .5824 .45476 L F
.59266 .44009 m .5824 .45476 L .59943 .44494 L .66 .805 .952 r
F
.59266 .44009 m .57219 .44757 L .5824 .45476 L F
0 g
.5824 .45476 m
.58886 .45721 L
s
.75093 .60136 m .75094 .59642 L .73925 .59492 L .734 .486 .554 r
F
0 g
.75094 .59642 m
.76147 .59939 L
s
.40325 .45877 m .39088 .44599 L .39136 .45859 L .661 .803 .951 r
F
.40325 .45877 m .40888 .44627 L .39088 .44599 L F
.63375 .32445 m .63589 .30587 L .6198 .30744 L .656 .78 .94 r
F
.36751 .59095 m .36677 .60009 L .37401 .59381 L .598 .767 .96 r
F
.36751 .59095 m .35704 .59582 L .36677 .60009 L F
0 g
.36677 .60009 m
.37793 .60305 L
s
.34992 .5856 m .35808 .58597 L .35756 .59089 L .927 .677 .541 r
F
.34992 .5856 m .35045 .58066 L .35808 .58597 L F
0 g
.35808 .58597 m
.36323 .58824 L
s
.71351 .30684 m .71277 .29995 L .70004 .28854 L .958 .649 .402 r
F
0 g
.71277 .29995 m
.71965 .31318 L
s
.41253 .6028 m .42237 .59473 L .42193 .59968 L .469 .26 .513 r
F
.40467 .59563 m .41253 .6028 L .42193 .59968 L .598 .767 .96 r
F
.39734 .59675 m .41253 .6028 L .40467 .59563 L F
0 g
.40158 .60446 m
.41253 .6028 L
s
.42237 .59473 m .42281 .58981 L .43001 .58538 L .293 .115 .461 r
F
0 g
.41399 .59276 m
.42281 .58981 L
s
.69089 .4408 m .69005 .43506 L .6984 .42544 L .2 .114 .528 r
F
0 g
.68164 .44095 m
.69005 .43506 L
s
.43995 .4543 m .42518 .44335 L .42563 .44912 L .869 .589 .51 r
F
.44042 .46007 m .43995 .4543 L .42563 .44912 L F
0 g
.43995 .4543 m
.45084 .46142 L
s
.75093 .60136 m .73925 .59492 L .73923 .59986 L .734 .486 .554 r
F
0 g
.73925 .59492 m
.75094 .59642 L
s
.72724 .59501 m
.73925 .59492 L
s
.37951 .46012 m .37297 .44831 L .35645 .45305 L .661 .803 .951 r
F
.39136 .45859 m .37297 .44831 L .37951 .46012 L F
.36893 .46902 m .35679 .45886 L .34283 .46565 L .66 .804 .952 r
F
.37989 .4659 m .35679 .45886 L .36893 .46902 L F
.76147 .60927 m .75093 .60136 L .75092 .6063 L .803 .544 .547 r
F
0 g
.76147 .60927 m
.77012 .61349 L
s
.39136 .45859 m .39088 .44599 L .37297 .44831 L .661 .803 .951 r
F
.62731 .44352 m .61993 .45606 L .63162 .45623 L .659 .805 .953 r
F
.59132 .3176 m .5551 .31668 L .58094 .32543 L .656 .78 .94 r
F
.7392 .60481 m .7272 .59995 L .72715 .60489 L .666 .43 .554 r
F
0 g
.71564 .60655 m
.72715 .60489 L
s
.7392 .60481 m .73923 .59986 L .7272 .59995 L .666 .43 .554 r
F
0 g
.71569 .60161 m
.7272 .59995 L
s
.63921 .44284 m .64352 .4547 L .65486 .45156 L .659 .805 .953 r
F
.75092 .6063 m .75093 .60136 L .73923 .59986 L .734 .486 .554 r
F
0 g
.75093 .60136 m
.76147 .60432 L
s
.34938 .59054 m .35756 .59089 L .35704 .59582 L .927 .677 .541 r
F
.34938 .59054 m .34992 .5856 L .35756 .59089 L F
.36294 .58245 m .35756 .59089 L .36802 .586 L .598 .766 .96 r
F
.36294 .58245 m .34992 .5856 L .35756 .59089 L F
0 g
.35756 .59089 m
.36275 .59317 L
s
.59337 .44589 m .58308 .46053 L .60014 .45072 L .659 .805 .953 r
F
.59337 .44589 m .57287 .45336 L .58308 .46053 L F
0 g
.58308 .46053 m
.59665 .46564 L
s
.40367 .46454 m .39128 .4518 L .39175 .46437 L .66 .804 .952 r
F
.40367 .46454 m .4093 .45207 L .39128 .4518 L F
.42237 .59473 m .43001 .58538 L .42958 .59032 L .293 .115 .461 r
F
.42193 .59968 m .42237 .59473 L .42958 .59032 L F
.41141 .58857 m .42237 .59473 L .42958 .59032 L .598 .766 .96 r
F
.40514 .59068 m .42237 .59473 L .41141 .58857 L F
0 g
.4135 .5977 m
.42237 .59473 L
s
.5905 .3039 m .56998 .29107 L .55461 .30296 L .657 .779 .938 r
F
.60364 .29775 m .56998 .29107 L .5905 .3039 L F
.75092 .6063 m .73923 .59986 L .7392 .60481 L .734 .486 .554 r
F
0 g
.73923 .59986 m
.75093 .60136 L
s
.75092 .6063 m
.76147 .60927 L
s
.7272 .59995 m
.73923 .59986 L
s
.67719 .30909 m .68296 .28675 L .66534 .3034 L .657 .779 .939 r
F
.67719 .30909 m .70076 .29546 L .68296 .28675 L F
.35645 .45305 m .34218 .45409 L .3425 .45986 L .476 .289 .547 r
F
.35645 .45305 m .3561 .44727 L .34218 .45409 L F
0 g
.33182 .46246 m
.34218 .45409 L
s
.62192 .44256 m .61993 .45606 L .62731 .44352 L .659 .805 .953 r
F
.62192 .44256 m .6092 .45418 L .61993 .45606 L F
.69089 .4408 m .6984 .42544 L .69927 .43119 L .2 .114 .528 r
F
.69174 .44655 m .69089 .4408 L .69927 .43119 L F
.67213 .43557 m .69089 .4408 L .69927 .43119 L .66 .805 .952 r
F
.66408 .44125 m .69089 .4408 L .67213 .43557 L F
0 g
.68243 .44671 m
.69089 .4408 L
s
.44042 .46007 m .42563 .44912 L .42608 .4549 L .869 .589 .51 r
F
0 g
.44042 .46007 m
.45133 .46717 L
s
.71351 .30684 m .70004 .28854 L .70076 .29546 L .958 .649 .402 r
F
.71426 .31375 m .71351 .30684 L .70076 .29546 L F
0 g
.71351 .30684 m
.72041 .32003 L
s
.37989 .4659 m .37334 .45412 L .35679 .45886 L .66 .804 .952 r
F
.39175 .46437 m .37334 .45412 L .37989 .4659 L F
.39175 .46437 m .39128 .4518 L .37334 .45412 L F
0 g
.72715 .60489 m
.7392 .60481 L
s
.7392 .60481 m
.75092 .6063 L
s
.64492 .44125 m .65486 .45156 L .66489 .44702 L .659 .805 .953 r
F
.63921 .44284 m .65486 .45156 L .64492 .44125 L F
.72948 .70884 m .73267 .7064 L .73316 .70939 L .799 .52 .515 r
F
.72948 .70884 m .729 .70585 L .73267 .7064 L F
0 g
.73267 .7064 m
.73513 .7064 L
s
.73215 .70331 m .7327 .70636 L .73459 .70368 L .656 .814 .96 r
F
.73215 .70331 m .72904 .70581 L .7327 .70636 L F
.36242 .5874 m .35704 .59582 L .36751 .59095 L .598 .767 .96 r
F
.36242 .5874 m .34938 .59054 L .35704 .59582 L F
0 g
.35704 .59582 m
.36677 .60009 L
s
.42193 .59968 m .42958 .59032 L .42915 .59527 L .293 .115 .461 r
F
.41095 .59352 m .42193 .59968 L .42915 .59527 L .598 .767 .96 r
F
.40467 .59563 m .42193 .59968 L .41095 .59352 L F
0 g
.41253 .6028 m
.42193 .59968 L
s
.73772 .71238 m .73723 .70939 L .7414 .70884 L .666 .428 .551 r
F
.73365 .71238 m .73723 .70939 L .73772 .71238 L .731 .473 .537 r
F
.73365 .71238 m .73316 .70939 L .73723 .70939 L F
.73778 .70669 m .73723 .70939 L .7414 .70884 L .655 .815 .96 r
F
.73506 .70669 m .73723 .70939 L .73778 .70669 L F
.73506 .70669 m .73316 .70939 L .73723 .70939 L F
.7419 .71183 m .7414 .70884 L .74541 .70777 L .595 .38 .559 r
F
.73772 .71238 m .7414 .70884 L .7419 .71183 L .666 .428 .551 r
F
.74057 .70633 m .7414 .70884 L .74541 .70777 L .655 .815 .96 r
F
.73778 .70669 m .7414 .70884 L .74057 .70633 L F
0 g
.73723 .70939 m
.7414 .70884 L
s
.72643 .70778 m .729 .70585 L .72948 .70884 L .873 .571 .474 r
F
.72643 .70778 m .72595 .70479 L .729 .70585 L F
0 g
.729 .70585 m
.73267 .7064 L
s
.73012 .7026 m .72904 .70581 L .73215 .70331 L .656 .814 .96 r
F
.73012 .7026 m .72601 .70475 L .72904 .70581 L F
.35679 .45886 m .3425 .45986 L .34283 .46565 L .476 .289 .547 r
F
0 g
.33243 .474 m
.34283 .46565 L
s
.35679 .45886 m .35645 .45305 L .3425 .45986 L .476 .289 .547 r
F
0 g
.33212 .46822 m
.3425 .45986 L
s
.57015 .29781 m .55422 .30282 L .55466 .30974 L .332 .177 .515 r
F
.57015 .29781 m .56967 .29087 L .55422 .30282 L F
0 g
.54424 .3164 m
.55422 .30282 L
s
.72996 .71183 m .73316 .70939 L .73365 .71238 L .799 .52 .515 r
F
.72996 .71183 m .72948 .70884 L .73316 .70939 L F
.7326 .70633 m .73316 .70939 L .73506 .70669 L .655 .815 .96 r
F
.7326 .70633 m .72948 .70884 L .73316 .70939 L F
0 g
.73316 .70939 m
.73723 .70939 L
s
.42563 .44912 m .42518 .44335 L .40845 .44049 L .801 .535 .536 r
F
0 g
.42518 .44335 m
.43948 .44855 L
s
.69174 .44655 m .69927 .43119 L .70014 .43697 L .2 .114 .528 r
F
.67296 .44134 m .69174 .44655 L .70014 .43697 L .659 .805 .953 r
F
.66489 .44702 m .69174 .44655 L .67296 .44134 L F
0 g
.67964 .45498 m
.69174 .44655 L
s
.34489 .57962 m .35045 .58066 L .34992 .5856 L .986 .751 .493 r
F
.34489 .57962 m .34543 .57467 L .35045 .58066 L F
0 g
.35045 .58066 m
.35558 .58423 L
s
.74898 .70627 m .74848 .70328 L .75137 .70143 L .401 .249 .558 r
F
.74541 .70777 m .74848 .70328 L .74898 .70627 L .512 .324 .562 r
F
0 g
.74617 .70425 m
.74848 .70328 L
s
.36029 .57348 m .35065 .58061 L .36359 .57747 L .599 .766 .959 r
F
.36029 .57348 m .34565 .57465 L .35065 .58061 L F
.74591 .71076 m .74541 .70777 L .74898 .70627 L .512 .324 .562 r
F
.7419 .71183 m .74541 .70777 L .74591 .71076 L .595 .38 .559 r
F
.74324 .70561 m .74541 .70777 L .74898 .70627 L .655 .815 .96 r
F
.74057 .70633 m .74541 .70777 L .74324 .70561 L F
0 g
.7414 .70884 m
.74541 .70777 L
s
.5908 .31067 m .57015 .29781 L .55466 .30974 L .657 .779 .939 r
F
.60404 .30451 m .57015 .29781 L .5908 .31067 L F
.66451 .29666 m .66052 .27473 L .6503 .29318 L .657 .779 .938 r
F
.66451 .29666 m .682 .28007 L .66052 .27473 L F
.42958 .59032 m .43001 .58538 L .43452 .57995 L 0 0 .34 r
F
0 g
.423 .58969 m
.43001 .58538 L
s
.67787 .31601 m .68366 .29372 L .666 .31033 L .656 .78 .94 r
F
.67787 .31601 m .70149 .3024 L .68366 .29372 L F
.41651 .58061 m .42981 .58531 L .4343 .57991 L .599 .766 .959 r
F
.38133 .58747 m .37401 .59381 L .38149 .59581 L .598 .767 .96 r
F
.39306 .58895 m .39734 .59675 L .40467 .59563 L F
.73827 .70969 m .73772 .71238 L .7419 .71183 L .655 .815 .96 r
F
.73555 .70969 m .73772 .71238 L .73827 .70969 L F
.73555 .70969 m .73365 .71238 L .73772 .71238 L F
.61738 .4408 m .6092 .45418 L .62192 .44256 L .659 .805 .953 r
F
.61738 .4408 m .60014 .45072 L .6092 .45418 L F
.71426 .31375 m .70076 .29546 L .70149 .3024 L .958 .649 .402 r
F
0 g
.71426 .31375 m
.72116 .32691 L
s
.74106 .70932 m .7419 .71183 L .74591 .71076 L .655 .815 .96 r
F
.73827 .70969 m .7419 .71183 L .74106 .70932 L F
0 g
.73772 .71238 m
.7419 .71183 L
s
.56606 .43876 m .57152 .4418 L .57219 .44757 L .969 .671 .273 r
F
.56606 .43876 m .5654 .43297 L .57152 .4418 L F
0 g
.57152 .4418 m
.57713 .44577 L
s
.58818 .42833 m .57183 .44169 L .59216 .43424 L .661 .804 .952 r
F
.58818 .42833 m .56573 .4329 L .57183 .44169 L F
.72691 .71077 m .72948 .70884 L .72996 .71183 L .873 .571 .474 r
F
.72691 .71077 m .72643 .70778 L .72948 .70884 L F
.73057 .70561 m .72948 .70884 L .7326 .70633 L .655 .815 .96 r
F
.73057 .70561 m .72643 .70778 L .72948 .70884 L F
0 g
.72948 .70884 m
.73316 .70939 L
s
.73309 .70932 m .73365 .71238 L .73555 .70969 L .655 .815 .96 r
F
.73309 .70932 m .72996 .71183 L .73365 .71238 L F
0 g
.73365 .71238 m
.73772 .71238 L
s
.72422 .70627 m .72595 .70479 L .72643 .70778 L .946 .625 .39 r
F
.72422 .70627 m .72374 .70328 L .72595 .70479 L F
0 g
.72595 .70479 m
.729 .70585 L
s
.72866 .7016 m .72601 .70475 L .73012 .7026 L .656 .814 .96 r
F
.72866 .7016 m .72381 .70325 L .72601 .70475 L F
.74898 .70627 m .75137 .70143 L .75187 .70442 L .401 .249 .558 r
F
.74948 .70926 m .74898 .70627 L .75187 .70442 L F
.74591 .71076 m .74898 .70627 L .74948 .70926 L .512 .324 .562 r
F
.74562 .70461 m .74898 .70627 L .75187 .70442 L .655 .815 .96 r
F
.74324 .70561 m .74898 .70627 L .74562 .70461 L F
0 g
.74541 .70777 m
.74898 .70627 L
s
.74374 .70861 m .74591 .71076 L .74948 .70926 L .655 .815 .96 r
F
.74106 .70932 m .74591 .71076 L .74374 .70861 L F
0 g
.7419 .71183 m
.74591 .71076 L
s
.75187 .70442 m .75137 .70143 L .75338 .69936 L .229 .134 .535 r
F
0 g
.74848 .70328 m
.75137 .70143 L
s
.74701 .70037 m .7513 .70141 L .7533 .69936 L .656 .814 .96 r
F
.74509 .7016 m .7513 .70141 L .74701 .70037 L F
.34434 .58458 m .34992 .5856 L .34938 .59054 L .986 .751 .493 r
F
.34434 .58458 m .34489 .57962 L .34992 .5856 L F
.35962 .57845 m .34992 .5856 L .36294 .58245 L .598 .766 .96 r
F
.35962 .57845 m .34489 .57962 L .34992 .5856 L F
0 g
.34992 .5856 m
.35508 .58917 L
s
.73425 .70044 m .73012 .7026 L .73215 .70331 L .656 .814 .96 r
F
.60364 .29775 m .58979 .28169 L .56998 .29107 L .657 .779 .938 r
F
.61872 .29375 m .58979 .28169 L .60364 .29775 L F
.37807 .58603 m .37401 .59381 L .38133 .58747 L .598 .767 .96 r
F
.37807 .58603 m .36751 .59095 L .37401 .59381 L F
.42563 .44912 m .40845 .44049 L .40888 .44627 L .801 .535 .536 r
F
.42608 .4549 m .42563 .44912 L .40888 .44627 L F
0 g
.42563 .44912 m
.43995 .4543 L
s
.73106 .70861 m .72996 .71183 L .73309 .70932 L .655 .815 .96 r
F
.73106 .70861 m .72691 .71077 L .72996 .71183 L F
0 g
.72996 .71183 m
.73365 .71238 L
s
.64996 .43895 m .66489 .44702 L .67296 .44134 L .659 .805 .953 r
F
.64492 .44125 m .66489 .44702 L .64996 .43895 L F
.39674 .58839 m .40467 .59563 L .41095 .59352 L .598 .767 .96 r
F
.39306 .58895 m .40467 .59563 L .39674 .58839 L F
.42958 .59032 m .43452 .57995 L .4341 .58491 L 0 0 .34 r
F
.42915 .59527 m .42958 .59032 L .4341 .58491 L F
.4162 .58561 m .42958 .59032 L .4341 .58491 L .598 .766 .96 r
F
.41141 .58857 m .42958 .59032 L .4162 .58561 L F
0 g
.42253 .59464 m
.42958 .59032 L
s
.7247 .70927 m .72643 .70778 L .72691 .71077 L .946 .625 .39 r
F
.7247 .70927 m .72422 .70627 L .72643 .70778 L F
.7291 .70461 m .72643 .70778 L .73057 .70561 L .655 .815 .96 r
F
.7291 .70461 m .72422 .70627 L .72643 .70778 L F
0 g
.72643 .70778 m
.72948 .70884 L
s
.73574 .7038 m .7326 .70633 L .73506 .70669 L .655 .815 .96 r
F
.74948 .70926 m .75187 .70442 L .75238 .70741 L .401 .249 .558 r
F
.74612 .7076 m .74948 .70926 L .75238 .70741 L .655 .815 .96 r
F
.74374 .70861 m .74948 .70926 L .74612 .7076 L F
0 g
.74591 .71076 m
.74948 .70926 L
s
.57062 .30477 m .55466 .30974 L .5551 .31668 L .332 .177 .515 r
F
.57062 .30477 m .57015 .29781 L .55466 .30974 L F
0 g
.54466 .32328 m
.55466 .30974 L
s
.37297 .44831 m .3561 .44727 L .35645 .45305 L .584 .369 .556 r
F
.37297 .44831 m .3726 .44252 L .3561 .44727 L F
0 g
.34218 .45409 m
.3561 .44727 L
s
.56673 .44457 m .57219 .44757 L .57287 .45336 L .969 .671 .273 r
F
.56673 .44457 m .56606 .43876 L .57219 .44757 L F
.58865 .43417 m .57219 .44757 L .59266 .44009 L .66 .805 .952 r
F
.58865 .43417 m .56606 .43876 L .57219 .44757 L F
0 g
.57219 .44757 m
.57784 .45155 L
s
.75187 .70442 m .75338 .69936 L .75388 .70235 L .229 .134 .535 r
F
.75238 .70741 m .75187 .70442 L .75388 .70235 L F
.74755 .70337 m .75187 .70442 L .75388 .70235 L .655 .815 .96 r
F
.74562 .70461 m .75187 .70442 L .74755 .70337 L F
0 g
.74898 .70627 m
.75187 .70442 L
s
.59132 .3176 m .57062 .30477 L .5551 .31668 L .656 .78 .94 r
F
0 g
.54508 .33019 m
.5551 .31668 L
s
.60458 .31145 m .57062 .30477 L .59132 .3176 L .656 .78 .94 r
F
.73352 .69994 m .73012 .7026 L .73425 .70044 L .656 .814 .96 r
F
.73352 .69994 m .72866 .7016 L .73012 .7026 L F
.723 .70442 m .72374 .70328 L .72422 .70627 L .944 .632 .19 r
F
.723 .70442 m .72252 .70142 L .72374 .70328 L F
0 g
.72374 .70328 m
.72595 .70479 L
s
.72786 .70036 m .72381 .70325 L .72866 .7016 L .656 .814 .96 r
F
.72786 .70036 m .7226 .70141 L .72381 .70325 L F
.66534 .3034 m .66133 .28141 L .65103 .29992 L .657 .779 .939 r
F
.66534 .3034 m .68296 .28675 L .66133 .28141 L F
.73472 .70345 m .7326 .70633 L .73574 .7038 L .655 .815 .96 r
F
.73472 .70345 m .73057 .70561 L .7326 .70633 L F
.74701 .70037 m .7533 .69936 L .74834 .699 L .656 .814 .96 r
F
.73882 .70699 m .73827 .70969 L .74106 .70932 L .655 .815 .96 r
F
.73746 .70699 m .73827 .70969 L .73882 .70699 L F
.73746 .70699 m .73555 .70969 L .73827 .70969 L F
.74022 .7068 m .74106 .70932 L .74374 .70861 L F
.73882 .70699 m .74106 .70932 L .74022 .7068 L F
.72958 .7076 m .72691 .71077 L .73106 .70861 L F
.72958 .7076 m .7247 .70927 L .72691 .71077 L F
0 g
.72691 .71077 m
.72996 .71183 L
s
.75388 .70235 m .75338 .69936 L .75437 .69721 L 0 0 .454 r
F
0 g
.75137 .70143 m
.75338 .69936 L
s
.74834 .699 m .7533 .69936 L .75429 .69722 L .656 .814 .96 r
F
.73623 .7068 m .73555 .70969 L .73746 .70699 L .655 .815 .96 r
F
.73623 .7068 m .73309 .70932 L .73555 .70969 L F
.35909 .58341 m .34938 .59054 L .36242 .5874 L .598 .767 .96 r
F
.35909 .58341 m .34434 .58458 L .34938 .59054 L F
0 g
.34938 .59054 m
.35704 .59582 L
s
.74156 .70645 m .74374 .70861 L .74612 .7076 L .655 .815 .96 r
F
.74022 .7068 m .74374 .70861 L .74156 .70645 L F
.6503 .29318 m .63681 .27319 L .63466 .29219 L .657 .779 .938 r
F
.6503 .29318 m .66052 .27473 L .63681 .27319 L F
.42915 .59527 m .4341 .58491 L .43367 .58987 L 0 0 .34 r
F
.41575 .59057 m .42915 .59527 L .43367 .58987 L .598 .767 .96 r
F
.41095 .59352 m .42915 .59527 L .41575 .59057 L F
0 g
.42193 .59968 m
.42915 .59527 L
s
.69927 .43119 m .6984 .42544 L .70244 .41526 L 0 0 .432 r
F
0 g
.69245 .43229 m
.6984 .42544 L
s
.75238 .70741 m .75388 .70235 L .75439 .70535 L .229 .134 .535 r
F
.74805 .70637 m .75238 .70741 L .75439 .70535 L .655 .815 .96 r
F
.74612 .7076 m .75238 .70741 L .74805 .70637 L F
0 g
.74948 .70926 m
.75238 .70741 L
s
.73398 .70294 m .73057 .70561 L .73472 .70345 L .655 .815 .96 r
F
.73398 .70294 m .7291 .70461 L .73057 .70561 L F
.73312 .69932 m .72866 .7016 L .73352 .69994 L .656 .814 .96 r
F
.73312 .69932 m .72786 .70036 L .72866 .7016 L F
.72348 .70742 m .72422 .70627 L .7247 .70927 L .944 .632 .19 r
F
.72348 .70742 m .723 .70442 L .72422 .70627 L F
.72829 .70337 m .72422 .70627 L .7291 .70461 L .655 .815 .96 r
F
.72829 .70337 m .723 .70442 L .72422 .70627 L F
0 g
.72422 .70627 m
.72643 .70778 L
s
.42608 .4549 m .40888 .44627 L .4093 .45207 L .801 .535 .536 r
F
0 g
.42608 .4549 m
.44042 .46007 L
s
.40888 .44627 m .40845 .44049 L .39049 .44021 L .735 .484 .549 r
F
0 g
.40845 .44049 m
.42518 .44335 L
s
.73521 .70645 m .73309 .70932 L .73623 .7068 L .655 .815 .96 r
F
.73521 .70645 m .73106 .70861 L .73309 .70932 L F
.41651 .58061 m .4343 .57991 L .41947 .57699 L .599 .766 .959 r
F
.74755 .70337 m .75388 .70235 L .74889 .70199 L .655 .815 .96 r
F
.37553 .58425 m .36751 .59095 L .37807 .58603 L .598 .767 .96 r
F
.37553 .58425 m .36242 .5874 L .36751 .59095 L F
.74834 .699 m .75429 .69722 L .74899 .69757 L .656 .814 .96 r
F
.74275 .70594 m .74612 .7076 L .74805 .70637 L .655 .815 .96 r
F
.74156 .70645 m .74612 .7076 L .74275 .70594 L F
.67213 .43557 m .69927 .43119 L .67765 .42913 L .66 .805 .952 r
F
.39988 .58732 m .41095 .59352 L .41575 .59057 L .598 .767 .96 r
F
.39674 .58839 m .41095 .59352 L .39988 .58732 L F
.61872 .29375 m .61263 .27557 L .58979 .28169 L .657 .779 .938 r
F
.63466 .29219 m .61263 .27557 L .61872 .29375 L F
.75388 .70235 m .75437 .69721 L .75488 .70021 L 0 0 .454 r
F
.75439 .70535 m .75388 .70235 L .75488 .70021 L F
.74889 .70199 m .75388 .70235 L .75488 .70021 L .655 .815 .96 r
F
0 g
.75187 .70442 m
.75388 .70235 L
s
.61402 .43836 m .60014 .45072 L .61738 .4408 L .659 .805 .953 r
F
.61402 .43836 m .59337 .44589 L .60014 .45072 L F
.60404 .30451 m .5901 .2884 L .57015 .29781 L .657 .779 .939 r
F
.61923 .30049 m .5901 .2884 L .60404 .30451 L F
.37334 .45412 m .35645 .45305 L .35679 .45886 L .584 .369 .556 r
F
0 g
.34283 .46565 m
.35679 .45886 L
s
.37334 .45412 m .37297 .44831 L .35645 .45305 L .584 .369 .556 r
F
0 g
.3425 .45986 m
.35645 .45305 L
s
.58936 .43998 m .57287 .45336 L .59337 .44589 L .659 .805 .953 r
F
.58936 .43998 m .56673 .44457 L .57287 .45336 L F
0 g
.57287 .45336 m
.58308 .46053 L
s
.72286 .70235 m .72252 .70142 L .723 .70442 L 0 0 .178 r
F
.72777 .69899 m .7226 .70141 L .72786 .70036 L .656 .814 .96 r
F
.72777 .69899 m .72246 .69934 L .7226 .70141 L F
.72286 .70235 m .72238 .69935 L .72252 .70142 L 0 0 .178 r
F
0 g
.72278 .70181 m
.72374 .70328 L
s
.73448 .70594 m .73106 .70861 L .73521 .70645 L .655 .815 .96 r
F
.73448 .70594 m .72958 .7076 L .73106 .70861 L F
.73358 .70232 m .7291 .70461 L .73398 .70294 L F
.73358 .70232 m .72829 .70337 L .7291 .70461 L F
.72878 .70637 m .7247 .70927 L .72958 .7076 L F
.72878 .70637 m .72348 .70742 L .7247 .70927 L F
0 g
.7247 .70927 m
.72691 .71077 L
s
.63466 .29219 m .63681 .27319 L .61263 .27557 L .657 .779 .938 r
F
.73308 .69863 m .72786 .70036 L .73312 .69932 L .656 .814 .96 r
F
.73308 .69863 m .72777 .69899 L .72786 .70036 L F
.70076 .29546 m .70004 .28854 L .68227 .27981 L .886 .59 .48 r
F
0 g
.70004 .28854 m
.71277 .29995 L
s
.74805 .70637 m .75439 .70535 L .74939 .70499 L .655 .815 .96 r
F
.74372 .70532 m .74805 .70637 L .74939 .70499 L F
.74275 .70594 m .74805 .70637 L .74372 .70532 L F
0 g
.73878 .70479 m
.73878 .70479 L
s
.73689 .70454 m
.73878 .70479 L
s
.73878 .70479 m
.74075 .70459 L
s
.75488 .70021 m .75437 .69721 L .75428 .69513 L 0 0 .206 r
F
0 g
.75338 .69936 m
.75437 .69721 L
s
.74899 .69757 m .75429 .69722 L .7542 .69515 L .656 .814 .96 r
F
.74889 .70199 m .75488 .70021 L .74955 .70056 L .655 .815 .96 r
F
.74389 .70163 m .74889 .70199 L .74955 .70056 L F
.39088 .44599 m .3726 .44252 L .37297 .44831 L .665 .431 .556 r
F
.39088 .44599 m .39049 .44021 L .3726 .44252 L F
0 g
.3561 .44727 m
.3726 .44252 L
s
.666 .31033 m .66199 .28839 L .65167 .30686 L .656 .78 .94 r
F
.666 .31033 m .68366 .29372 L .66199 .28839 L F
.34283 .57335 m .34543 .57467 L .34489 .57962 L .968 .786 .353 r
F
.34283 .57335 m .34338 .56839 L .34543 .57467 L F
0 g
.34543 .57467 m
.34928 .57927 L
s
.35897 .56931 m .34565 .57465 L .36029 .57348 L .599 .766 .959 r
F
.35897 .56931 m .34361 .5684 L .34565 .57465 L F
.74899 .69757 m .7542 .69515 L .74893 .69619 L .656 .814 .96 r
F
.74369 .69793 m .74899 .69757 L .74893 .69619 L F
.61069 .42375 m .58818 .42833 L .59216 .43424 L .661 .804 .952 r
F
.75439 .70535 m .75488 .70021 L .75539 .7032 L 0 0 .454 r
F
.74939 .70499 m .75439 .70535 L .75539 .7032 L .655 .815 .96 r
F
0 g
.75238 .70741 m
.75439 .70535 L
s
.73938 .70428 m .73882 .70699 L .74022 .7068 L .655 .815 .96 r
F
.73938 .70428 m .73746 .70699 L .73882 .70699 L F
.73938 .70428 m .74022 .7068 L .74156 .70645 L F
0 g
.74075 .70459 m
.74207 .70417 L
s
.4341 .58491 m .43452 .57995 L .43602 .57388 L 0 0 .057 r
F
0 g
.43028 .58506 m
.43452 .57995 L
s
.4162 .58561 m .4341 .58491 L .41918 .58198 L .598 .766 .96 r
F
.41947 .57699 m .4343 .57991 L .43579 .57387 L .599 .766 .959 r
F
.72334 .70535 m .723 .70442 L .72348 .70742 L 0 0 .178 r
F
.7282 .70199 m .723 .70442 L .72829 .70337 L .655 .815 .96 r
F
.7282 .70199 m .72286 .70235 L .723 .70442 L F
.72334 .70535 m .72286 .70235 L .723 .70442 L 0 0 .178 r
F
0 g
.72326 .70481 m
.72422 .70627 L
s
.74369 .69793 m .74893 .69619 L .74365 .69724 L .656 .814 .96 r
F
.73938 .70428 m .73623 .7068 L .73746 .70699 L .655 .815 .96 r
F
0 g
.73575 .70407 m
.73689 .70454 L
s
.69927 .43119 m .70244 .41526 L .70332 .42104 L 0 0 .432 r
F
.70014 .43697 m .69927 .43119 L .70332 .42104 L F
.67765 .42913 m .69927 .43119 L .70332 .42104 L .66 .805 .952 r
F
0 g
.69327 .43807 m
.69927 .43119 L
s
.40888 .44627 m .39049 .44021 L .39088 .44599 L .735 .484 .549 r
F
0 g
.3726 .44252 m
.39049 .44021 L
s
.39049 .44021 m
.40845 .44049 L
s
.74207 .70417 m
.74301 .70361 L
s
.73938 .70428 m .74156 .70645 L .74275 .70594 L .655 .815 .96 r
F
0 g
.73502 .7035 m
.73575 .70407 L
s
.4093 .45207 m .40888 .44627 L .39088 .44599 L .735 .484 .549 r
F
0 g
.40888 .44627 m
.42563 .44912 L
s
.73407 .70532 m .72958 .7076 L .73448 .70594 L .655 .815 .96 r
F
.73407 .70532 m .72878 .70637 L .72958 .7076 L F
.73938 .70428 m .73521 .70645 L .73623 .7068 L F
.73354 .70163 m .72829 .70337 L .73358 .70232 L F
.73354 .70163 m .7282 .70199 L .72829 .70337 L F
.74389 .70163 m .74955 .70056 L .74422 .70092 L F
.7334 .69792 m .72777 .69899 L .73308 .69863 L .656 .814 .96 r
F
.73938 .70428 m .74275 .70594 L .74372 .70532 L .655 .815 .96 r
F
.65103 .29992 m .63745 .27987 L .63528 .29892 L .657 .779 .939 r
F
.65103 .29992 m .66133 .28141 L .63745 .27987 L F
0 g
.74301 .70361 m
.74363 .70295 L
s
.67296 .44134 m .70014 .43697 L .67849 .43491 L .659 .805 .953 r
F
.65398 .43608 m .67296 .44134 L .67849 .43491 L F
.64996 .43895 m .67296 .44134 L .65398 .43608 L F
0 g
.73465 .70282 m
.73502 .7035 L
s
.75488 .70021 m .75428 .69513 L .75479 .69813 L 0 0 .206 r
F
.75539 .7032 m .75488 .70021 L .75479 .69813 L F
.74955 .70056 m .75488 .70021 L .75479 .69813 L .655 .815 .96 r
F
0 g
.75388 .70235 m
.75488 .70021 L
s
.74365 .69724 m .74814 .69495 L .74326 .69662 L .656 .814 .96 r
F
0 g
.74321 .69695 m
.74337 .69932 L
s
.74365 .69724 m .74893 .69619 L .74814 .69495 L .656 .814 .96 r
F
.74939 .70499 m .75539 .7032 L .75005 .70356 L .655 .815 .96 r
F
.74439 .70463 m .74939 .70499 L .75005 .70356 L F
.74372 .70532 m .74939 .70499 L .74439 .70463 L F
.72841 .69756 m .72246 .69934 L .72777 .69899 L .656 .814 .96 r
F
.7334 .69792 m .72841 .69756 L .72777 .69899 L F
.73938 .70428 m .73448 .70594 L .73521 .70645 L .655 .815 .96 r
F
.74955 .70056 m .75479 .69813 L .74948 .69918 L F
.74422 .70092 m .74955 .70056 L .74948 .69918 L F
.72841 .69756 m .72341 .6972 L .72246 .69934 L .656 .814 .96 r
F
.72382 .70019 m .72238 .69935 L .72286 .70235 L 0 0 .44 r
F
.72382 .70019 m .72333 .69719 L .72238 .69935 L F
0 g
.72238 .69935 m
.72252 .70142 L
s
.73938 .70428 m .74372 .70532 L .74439 .70463 L .655 .815 .96 r
F
.72869 .70499 m .72348 .70742 L .72878 .70637 L F
.72869 .70499 m .72334 .70535 L .72348 .70742 L F
0 g
.72348 .70742 m
.7247 .70927 L
s
.73406 .69723 m .72841 .69756 L .7334 .69792 L .656 .814 .96 r
F
.74422 .70092 m .74948 .69918 L .74418 .70023 L .655 .815 .96 r
F
0 g
.74363 .70295 m
.74389 .70215 L
s
.74893 .69619 m .75303 .69328 L .74814 .69495 L .656 .814 .96 r
F
.74893 .69619 m .7542 .69515 L .75303 .69328 L F
0 g
.73465 .70282 m
.73469 .70202 L
s
.74326 .69662 m .74669 .69394 L .74253 .69611 L .656 .814 .96 r
F
.74326 .69662 m .74814 .69495 L .74669 .69394 L F
.73938 .70428 m .73407 .70532 L .73448 .70594 L .655 .815 .96 r
F
.60458 .31145 m .59062 .29538 L .57062 .30477 L .656 .78 .94 r
F
.6198 .30744 m .59062 .29538 L .60458 .31145 L F
.61923 .30049 m .6131 .28226 L .5901 .2884 L .657 .779 .939 r
F
.63528 .29892 m .6131 .28226 L .61923 .30049 L F
.34228 .57832 m .34489 .57962 L .34434 .58458 L .968 .786 .353 r
F
.34228 .57832 m .34283 .57335 L .34489 .57962 L F
.35829 .57426 m .34489 .57962 L .35962 .57845 L .598 .766 .96 r
F
.35829 .57426 m .34283 .57335 L .34489 .57962 L F
0 g
.34489 .57962 m
.34877 .58423 L
s
.73403 .70463 m .72878 .70637 L .73407 .70532 L .655 .815 .96 r
F
.73403 .70463 m .72869 .70499 L .72878 .70637 L F
.37388 .58225 m .36242 .5874 L .37553 .58425 L .598 .767 .96 r
F
.37388 .58225 m .35909 .58341 L .36242 .5874 L F
.74439 .70463 m .75005 .70356 L .74472 .70392 L .655 .815 .96 r
F
.73938 .70428 m .74439 .70463 L .74472 .70392 L F
.73386 .70092 m .7282 .70199 L .73354 .70163 L F
.75479 .69813 m .75428 .69513 L .7531 .69326 L .935 .622 .167 r
F
0 g
.75436 .69688 m
.75437 .69721 L
s
.39128 .4518 m .37297 .44831 L .37334 .45412 L .665 .431 .556 r
F
0 g
.35679 .45886 m
.37334 .45412 L
s
.39128 .4518 m .39088 .44599 L .37297 .44831 L .665 .431 .556 r
F
0 g
.35645 .45305 m
.37297 .44831 L
s
.4341 .58491 m .43602 .57388 L .4356 .57885 L 0 0 .057 r
F
.43367 .58987 m .4341 .58491 L .4356 .57885 L F
.41918 .58198 m .4341 .58491 L .4356 .57885 L .598 .766 .96 r
F
0 g
.42982 .59002 m
.4341 .58491 L
s
.37433 .57022 m .35897 .56931 L .36029 .57348 L .599 .766 .959 r
F
.73406 .69723 m .72973 .69618 L .72841 .69756 L .656 .814 .96 r
F
.73502 .69661 m .72973 .69618 L .73406 .69723 L F
.41575 .59057 m .43367 .58987 L .41873 .58695 L .598 .767 .96 r
F
.40227 .58583 m .41575 .59057 L .41873 .58695 L F
.39988 .58732 m .41575 .59057 L .40227 .58583 L F
.75539 .7032 m .75479 .69813 L .7553 .70113 L 0 0 .206 r
F
.75005 .70356 m .75539 .7032 L .7553 .70113 L .655 .815 .96 r
F
0 g
.75439 .70535 m
.75539 .7032 L
s
.61132 .42957 m .58865 .43417 L .59266 .44009 L .66 .805 .952 r
F
.74418 .70023 m .74869 .69793 L .74378 .69961 L .655 .815 .96 r
F
.74418 .70023 m .74948 .69918 L .74869 .69793 L F
.72884 .70056 m .72286 .70235 L .7282 .70199 L F
.73386 .70092 m .72884 .70056 L .7282 .70199 L F
.41947 .57699 m .43579 .57387 L .42043 .57296 L .599 .766 .959 r
F
.40461 .57407 m .41947 .57699 L .42043 .57296 L F
.74253 .69611 m .74466 .69322 L .74152 .69575 L .656 .814 .96 r
F
.74253 .69611 m .74669 .69394 L .74466 .69322 L F
0 g
.73469 .70202 m
.73548 .70102 L
s
.72973 .69618 m .72341 .6972 L .72841 .69756 L .656 .814 .96 r
F
.63528 .29892 m .63745 .27987 L .6131 .28226 L .657 .779 .939 r
F
.75005 .70356 m .7553 .70113 L .74999 .70218 L .655 .815 .96 r
F
.74472 .70392 m .75005 .70356 L .74999 .70218 L F
.73938 .70428 m .73403 .70463 L .73407 .70532 L F
.70076 .29546 m .68227 .27981 L .68296 .28675 L .886 .59 .48 r
F
.70149 .3024 m .70076 .29546 L .68296 .28675 L F
0 g
.70076 .29546 m
.71351 .30684 L
s
.7243 .7032 m .72286 .70235 L .72334 .70535 L 0 0 .44 r
F
.72884 .70056 m .72382 .70019 L .72286 .70235 L .655 .815 .96 r
F
.7243 .7032 m .72382 .70019 L .72286 .70235 L 0 0 .44 r
F
0 g
.72286 .70235 m
.723 .70442 L
s
.70014 .43697 m .70332 .42104 L .7042 .42684 L 0 0 .432 r
F
.67849 .43491 m .70014 .43697 L .7042 .42684 L .659 .805 .953 r
F
0 g
.69174 .44655 m
.70014 .43697 L
s
.4093 .45207 m .39088 .44599 L .39128 .4518 L .735 .484 .549 r
F
0 g
.37297 .44831 m
.39088 .44599 L
s
.39088 .44599 m
.40888 .44627 L
s
.4093 .45207 m
.42608 .4549 L
s
.73502 .69661 m .73164 .69494 L .72973 .69618 L .656 .814 .96 r
F
.7362 .69611 m .73164 .69494 L .73502 .69661 L F
.74472 .70392 m .74999 .70218 L .74468 .70323 L .655 .815 .96 r
F
.73938 .70428 m .74472 .70392 L .74468 .70323 L F
0 g
.39128 .4518 m
.4093 .45207 L
s
.73453 .70022 m .72884 .70056 L .73386 .70092 L .655 .815 .96 r
F
.74948 .69918 m .75361 .69626 L .74869 .69793 L F
.74948 .69918 m .75479 .69813 L .75361 .69626 L F
.74152 .69575 m .74221 .69284 L .74029 .69557 L .656 .814 .96 r
F
.74152 .69575 m .74466 .69322 L .74221 .69284 L F
.74814 .69495 m .75085 .69176 L .74669 .69394 L F
.74814 .69495 m .75303 .69328 L .75085 .69176 L F
.74378 .69961 m .74723 .69691 L .74305 .6991 L .655 .815 .96 r
F
.74378 .69961 m .74869 .69793 L .74723 .69691 L F
.73938 .70428 m .73436 .70392 L .73403 .70463 L F
.73938 .70428 m .73502 .70323 L .73436 .70392 L F
.73938 .70428 m .73599 .70261 L .73502 .70323 L F
.73938 .70428 m .73718 .7021 L .73599 .70261 L F
.73938 .70428 m .73853 .70174 L .73718 .7021 L F
.73938 .70428 m .73993 .70155 L .73853 .70174 L F
.73938 .70428 m .7413 .70155 L .73993 .70155 L F
.73938 .70428 m .74253 .70174 L .7413 .70155 L F
.73938 .70428 m .74355 .7021 L .74253 .70174 L F
.73938 .70428 m .74428 .70261 L .74355 .7021 L F
0 g
.74349 .70113 m
.74389 .70215 L
s
.73938 .70428 m .74468 .70323 L .74428 .70261 L .655 .815 .96 r
F
.7362 .69611 m .73402 .69393 L .73164 .69494 L .656 .814 .96 r
F
.73754 .69575 m .73402 .69393 L .7362 .69611 L F
.74029 .69557 m .73949 .69284 L .73894 .69557 L F
.74029 .69557 m .74221 .69284 L .73949 .69284 L F
.73436 .70392 m .72869 .70499 L .73403 .70463 L .655 .815 .96 r
F
.75479 .69813 m .7531 .69326 L .75361 .69626 L .935 .622 .167 r
F
.7553 .70113 m .75479 .69813 L .75361 .69626 L F
0 g
.75487 .69988 m
.75488 .70021 L
s
.7423 .70033 m
.74349 .70113 L
s
.74349 .70113 m
.74349 .70113 L
s
.73754 .69575 m .73669 .69321 L .73402 .69393 L .656 .814 .96 r
F
.73894 .69557 m .73669 .69321 L .73754 .69575 L F
0 g
.73548 .70102 m
.73548 .70102 L
s
.73548 .70102 m
.73696 .70025 L
s
.73894 .69557 m .73949 .69284 L .73669 .69321 L .656 .814 .96 r
F
.73453 .70022 m .73017 .69917 L .72884 .70056 L .655 .815 .96 r
F
.73549 .6996 m .73017 .69917 L .73453 .70022 L F
.72973 .69618 m .72538 .69512 L .72341 .6972 L .656 .814 .96 r
F
.7258 .69811 m .72333 .69719 L .72382 .70019 L .216 .123 .529 r
F
.7258 .69811 m .72532 .69511 L .72333 .69719 L F
0 g
.72238 .69935 m
.72333 .69719 L
s
.74468 .70323 m .7492 .70093 L .74428 .70261 L .655 .815 .96 r
F
.74468 .70323 m .74999 .70218 L .7492 .70093 L F
.72933 .70356 m .72334 .70535 L .72869 .70499 L F
.73436 .70392 m .72933 .70356 L .72869 .70499 L F
.74305 .6991 m .7452 .69619 L .74203 .69874 L F
.74305 .6991 m .74723 .69691 L .7452 .69619 L F
.5901 .2884 m .56967 .29087 L .57015 .29781 L .477 .283 .538 r
F
.5901 .2884 m .58958 .28145 L .56967 .29087 L F
0 g
.55422 .30282 m
.56967 .29087 L
s
.65167 .30686 m .63807 .28686 L .63589 .30587 L .656 .78 .94 r
F
.65167 .30686 m .66199 .28839 L .63807 .28686 L F
.73017 .69917 m .72382 .70019 L .72884 .70056 L .655 .815 .96 r
F
.72933 .70356 m .7243 .7032 L .72334 .70535 L F
0 g
.72334 .70535 m
.72348 .70742 L
s
.73164 .69494 m .72538 .69512 L .72973 .69618 L .656 .814 .96 r
F
.35776 .57924 m .34434 .58458 L .35909 .58341 L .598 .767 .96 r
F
.35776 .57924 m .34228 .57832 L .34434 .58458 L F
0 g
.34434 .58458 m
.34938 .59054 L
s
.73549 .6996 m .7321 .69792 L .73017 .69917 L .655 .815 .96 r
F
.73669 .69909 m .7321 .69792 L .73549 .6996 L F
.73502 .70323 m .72933 .70356 L .73436 .70392 L F
.74999 .70218 m .75412 .69926 L .7492 .70093 L F
.74999 .70218 m .7553 .70113 L .75412 .69926 L F
.56449 .42889 m .5654 .43297 L .56606 .43876 L .743 .534 0 r
F
.56449 .42889 m .56382 .42307 L .5654 .43297 L F
0 g
.5654 .43297 m
.569 .43816 L
s
.74103 .69996 m
.7423 .70033 L
s
.58724 .42175 m .56573 .4329 L .58818 .42833 L .661 .804 .952 r
F
.58724 .42175 m .56417 .42305 L .56573 .4329 L F
.37375 .57518 m .35829 .57426 L .35962 .57845 L .598 .766 .96 r
F
0 g
.73696 .70025 m
.73836 .69992 L
s
.43367 .58987 m .4356 .57885 L .43517 .58383 L 0 0 .057 r
F
.41873 .58695 m .43367 .58987 L .43517 .58383 L .598 .767 .96 r
F
0 g
.42915 .59527 m
.43367 .58987 L
s
.74203 .69874 m .74273 .69582 L .7408 .69855 L .655 .815 .96 r
F
.74203 .69874 m .7452 .69619 L .74273 .69582 L F
.75361 .69626 m .7531 .69326 L .75092 .69172 L .948 .623 .379 r
F
0 g
.7531 .69326 m
.75428 .69513 L
s
.74869 .69793 m .75142 .69473 L .74723 .69691 L .655 .815 .96 r
F
.74869 .69793 m .75361 .69626 L .75142 .69473 L F
.74669 .69394 m .74782 .69067 L .74466 .69322 L .656 .814 .96 r
F
.74669 .69394 m .75085 .69176 L .74782 .69067 L F
.74428 .70261 m .74774 .69992 L .74355 .7021 L .655 .815 .96 r
F
.74428 .70261 m .7492 .70093 L .74774 .69992 L F
.41918 .58198 m .4356 .57885 L .42013 .57793 L .598 .766 .96 r
F
.40422 .57904 m .41918 .58198 L .42013 .57793 L F
0 g
.37334 .45412 m
.39128 .4518 L
s
.73669 .69909 m .73449 .69691 L .7321 .69792 L .655 .815 .96 r
F
.73803 .69874 m .73449 .69691 L .73669 .69909 L F
0 g
.73972 .69983 m
.74103 .69996 L
s
.73836 .69992 m
.73972 .69983 L
s
.7408 .69855 m .73999 .69581 L .73943 .69855 L .655 .815 .96 r
F
.7408 .69855 m .74273 .69582 L .73999 .69581 L F
.40461 .57407 m .42043 .57296 L .40506 .57205 L .599 .766 .959 r
F
.7553 .70113 m .75361 .69626 L .75412 .69926 L .935 .622 .167 r
F
0 g
.7553 .70113 m
.75539 .7032 L
s
.61205 .43539 m .59337 .44589 L .61402 .43836 L .659 .805 .953 r
F
.61205 .43539 m .58936 .43998 L .59337 .44589 L F
.67765 .42913 m .70332 .42104 L .68026 .42235 L .66 .805 .952 r
F
.73803 .69874 m .73718 .69619 L .73449 .69691 L .655 .815 .96 r
F
.73943 .69855 m .73718 .69619 L .73803 .69874 L F
.73943 .69855 m .73999 .69581 L .73718 .69619 L F
.73502 .70323 m .73066 .70217 L .72933 .70356 L F
.73599 .70261 m .73066 .70217 L .73502 .70323 L F
.6198 .30744 m .61367 .28925 L .59062 .29538 L .656 .78 .94 r
F
.63589 .30587 m .61367 .28925 L .6198 .30744 L F
.72629 .70112 m .72382 .70019 L .7243 .7032 L .216 .123 .529 r
F
.73017 .69917 m .7258 .69811 L .72382 .70019 L .655 .815 .96 r
F
.72629 .70112 m .7258 .69811 L .72382 .70019 L .216 .123 .529 r
F
0 g
.72286 .70235 m
.72382 .70019 L
s
.74355 .7021 m .7457 .6992 L .74253 .70174 L .655 .815 .96 r
F
.74355 .7021 m .74774 .69992 L .7457 .6992 L F
.73164 .69494 m .72825 .69326 L .72538 .69512 L .656 .814 .96 r
F
.73402 .69393 m .72825 .69326 L .73164 .69494 L F
.73066 .70217 m .7243 .7032 L .72933 .70356 L .655 .815 .96 r
F
.7321 .69792 m .7258 .69811 L .73017 .69917 L F
.73599 .70261 m .73259 .70093 L .73066 .70217 L F
.73718 .7021 m .73259 .70093 L .73599 .70261 L F
.74466 .69322 m .74413 .69011 L .74221 .69284 L .656 .814 .96 r
F
.74466 .69322 m .74782 .69067 L .74413 .69011 L F
.74253 .70174 m .74323 .69882 L .7413 .70155 L .655 .815 .96 r
F
.74253 .70174 m .7457 .6992 L .74323 .69882 L F
.63589 .30587 m .63807 .28686 L .61367 .28925 L .656 .78 .94 r
F
.70149 .3024 m .68296 .28675 L .68366 .29372 L .886 .59 .48 r
F
0 g
.70149 .3024 m
.71426 .31375 L
s
.75361 .69626 m .75092 .69172 L .75142 .69473 L .948 .623 .379 r
F
.75412 .69926 m .75361 .69626 L .75142 .69473 L F
0 g
.75361 .69626 m
.75479 .69813 L
s
.7492 .70093 m .75193 .69773 L .74774 .69992 L .655 .815 .96 r
F
.7492 .70093 m .75412 .69926 L .75193 .69773 L F
.74723 .69691 m .74837 .69364 L .7452 .69619 L F
.74723 .69691 m .75142 .69473 L .74837 .69364 L F
.72869 .69624 m .72532 .69511 L .7258 .69811 L .394 .242 .554 r
F
.72869 .69624 m .7282 .69324 L .72532 .69511 L F
0 g
.72333 .69719 m
.72532 .69511 L
s
.73718 .7021 m .73498 .69991 L .73259 .70093 L .655 .815 .96 r
F
.73853 .70174 m .73498 .69991 L .73718 .7021 L F
.7413 .70155 m .74049 .69882 L .73993 .70155 L F
.7413 .70155 m .74323 .69882 L .74049 .69882 L F
.73402 .69393 m .73182 .69174 L .72825 .69326 L .656 .814 .96 r
F
.73669 .69321 m .73182 .69174 L .73402 .69393 L F
0 g
.38558 .6595 m
.38563 .65834 L
s
.73853 .70174 m .73768 .69919 L .73498 .69991 L .655 .815 .96 r
F
.73993 .70155 m .73768 .69919 L .73853 .70174 L F
.73993 .70155 m .74049 .69882 L .73768 .69919 L F
.74221 .69284 m .74004 .6901 L .73949 .69284 L .656 .814 .96 r
F
.74221 .69284 m .74413 .69011 L .74004 .6901 L F
.73066 .70217 m .72629 .70112 L .7243 .7032 L .655 .815 .96 r
F
0 g
.72334 .70535 m
.7243 .7032 L
s
.37324 .58016 m .35909 .58341 L .37388 .58225 L .598 .767 .96 r
F
.37324 .58016 m .35776 .57924 L .35909 .58341 L F
.75142 .69473 m .75092 .69172 L .74786 .69064 L .875 .57 .468 r
F
0 g
.75092 .69172 m
.7531 .69326 L
s
.73669 .69321 m .73584 .69066 L .73182 .69174 L .656 .814 .96 r
F
.73949 .69284 m .73584 .69066 L .73669 .69321 L F
.7321 .69792 m .72869 .69624 L .7258 .69811 L .655 .815 .96 r
F
.73449 .69691 m .72869 .69624 L .7321 .69792 L F
.73949 .69284 m .74004 .6901 L .73584 .69066 L .656 .814 .96 r
F
.41873 .58695 m .43517 .58383 L .41969 .58291 L .598 .767 .96 r
F
.40375 .58402 m .41873 .58695 L .41969 .58291 L F
.40227 .58583 m .41873 .58695 L .40375 .58402 L F
.56516 .43472 m .56606 .43876 L .56673 .44457 L .743 .534 0 r
F
.56516 .43472 m .56449 .42889 L .56606 .43876 L F
.58771 .42757 m .56606 .43876 L .58865 .43417 L .66 .805 .952 r
F
.58771 .42757 m .56449 .42889 L .56606 .43876 L F
0 g
.56606 .43876 m
.56969 .44397 L
s
.73259 .70093 m .72629 .70112 L .73066 .70217 L .655 .815 .96 r
F
.61027 .42045 m .58818 .42833 L .61069 .42375 L .661 .804 .952 r
F
.61027 .42045 m .58724 .42175 L .58818 .42833 L F
.40422 .57904 m .42013 .57793 L .40467 .57701 L .598 .766 .96 r
F
.35975 .56524 m .34361 .5684 L .35897 .56931 L .599 .766 .959 r
F
.35975 .56524 m .34471 .56228 L .34361 .5684 L F
.34393 .56721 m .34338 .56839 L .34283 .57335 L 0 0 0 r
F
0 g
.3436 .56907 m
.34504 .57348 L
s
.34393 .56721 m .34448 .56224 L .34338 .56839 L 0 0 0 r
F
.7452 .69619 m .74466 .69307 L .74273 .69582 L .655 .815 .96 r
F
.7452 .69619 m .74837 .69364 L .74466 .69307 L F
.37474 .56819 m .35897 .56931 L .37433 .57022 L .599 .766 .959 r
F
.37474 .56819 m .35975 .56524 L .35897 .56931 L F
.59062 .29538 m .57015 .29781 L .57062 .30477 L .477 .283 .538 r
F
0 g
.5551 .31668 m
.57062 .30477 L
s
.59062 .29538 m .5901 .2884 L .57015 .29781 L .477 .283 .538 r
F
0 g
.55466 .30974 m
.57015 .29781 L
s
.40506 .57205 m .41928 .56877 L .40447 .56995 L .599 .766 .959 r
F
.40506 .57205 m .42043 .57296 L .41928 .56877 L F
.75412 .69926 m .75142 .69473 L .75193 .69773 L .948 .623 .379 r
F
0 g
.75412 .69926 m
.7553 .70113 L
s
.42043 .57296 m .43414 .56758 L .41928 .56877 L .599 .766 .959 r
F
.42043 .57296 m .43579 .57387 L .43414 .56758 L F
.74774 .69992 m .74888 .69665 L .7457 .6992 L .655 .815 .96 r
F
.74774 .69992 m .75193 .69773 L .74888 .69665 L F
.72918 .69925 m .7258 .69811 L .72629 .70112 L .394 .242 .554 r
F
.72918 .69925 m .72869 .69624 L .7258 .69811 L F
0 g
.72382 .70019 m
.7258 .69811 L
s
.4356 .57885 m .43602 .57388 L .43436 .56757 L .941 .763 .294 r
F
0 g
.43481 .5788 m
.43535 .5766 L
s
.67849 .43491 m .7042 .42684 L .6811 .42815 L .659 .805 .953 r
F
.65672 .43285 m .67849 .43491 L .6811 .42815 L F
.65398 .43608 m .67849 .43491 L .65672 .43285 L F
.73449 .69691 m .73228 .69471 L .72869 .69624 L .655 .815 .96 r
F
.73718 .69619 m .73228 .69471 L .73449 .69691 L F
.73228 .69471 m .7282 .69324 L .72869 .69624 L .508 .319 .56 r
F
.73228 .69471 m .73179 .6917 L .7282 .69324 L F
0 g
.72532 .69511 m
.7282 .69324 L
s
.74273 .69582 m .74055 .69307 L .73999 .69581 L .655 .815 .96 r
F
.74273 .69582 m .74466 .69307 L .74055 .69307 L F
.75142 .69473 m .74786 .69064 L .74837 .69364 L .875 .57 .468 r
F
.75193 .69773 m .75142 .69473 L .74837 .69364 L F
0 g
.75142 .69473 m
.75361 .69626 L
s
.73259 .70093 m .72918 .69925 L .72629 .70112 L .655 .815 .96 r
F
0 g
.7243 .7032 m
.72629 .70112 L
s
.73498 .69991 m .72918 .69925 L .73259 .70093 L .655 .815 .96 r
F
.73718 .69619 m .73633 .69363 L .73228 .69471 L F
.73999 .69581 m .73633 .69363 L .73718 .69619 L F
.73999 .69581 m .74055 .69307 L .73633 .69363 L F
.74837 .69364 m .74786 .69064 L .74416 .69007 L .8 .518 .511 r
F
0 g
.74786 .69064 m
.75092 .69172 L
s
.7457 .6992 m .74516 .69608 L .74323 .69882 L .655 .815 .96 r
F
.7457 .6992 m .74888 .69665 L .74516 .69608 L F
.70332 .42104 m .70244 .41526 L .70179 .40522 L 0 0 .173 r
F
0 g
.70007 .42123 m
.70244 .41526 L
s
.67919 .41657 m .70209 .41528 L .70145 .40529 L .661 .804 .952 r
F
.73498 .69991 m .73277 .69772 L .72918 .69925 L .655 .815 .96 r
F
.73768 .69919 m .73277 .69772 L .73498 .69991 L F
.68296 .28675 m .68227 .27981 L .66068 .27445 L .809 .53 .516 r
F
0 g
.68227 .27981 m
.70004 .28854 L
s
.73633 .69363 m .73179 .6917 L .73228 .69471 L .593 .377 .557 r
F
.73633 .69363 m .73583 .69062 L .73179 .6917 L F
0 g
.7282 .69324 m
.73179 .6917 L
s
.40375 .58402 m .41969 .58291 L .4042 .58199 L .598 .767 .96 r
F
.73277 .69772 m .72869 .69624 L .72918 .69925 L .508 .319 .56 r
F
0 g
.72629 .70112 m
.72918 .69925 L
s
.73277 .69772 m .73228 .69471 L .72869 .69624 L .508 .319 .56 r
F
0 g
.7258 .69811 m
.72869 .69624 L
s
.35907 .57018 m .34283 .57335 L .35829 .57426 L .598 .766 .96 r
F
.35907 .57018 m .34393 .56721 L .34283 .57335 L F
.34338 .5722 m .34283 .57335 L .34228 .57832 L 0 0 0 r
F
0 g
.34306 .57403 m
.34451 .57845 L
s
.34338 .5722 m .34393 .56721 L .34283 .57335 L 0 0 0 r
F
.74323 .69882 m .74105 .69608 L .74049 .69882 L .655 .815 .96 r
F
.74323 .69882 m .74516 .69608 L .74105 .69608 L F
.37416 .57314 m .35829 .57426 L .37375 .57518 L .598 .766 .96 r
F
.37416 .57314 m .35907 .57018 L .35829 .57426 L F
.75193 .69773 m .74837 .69364 L .74888 .69665 L .875 .57 .468 r
F
0 g
.75193 .69773 m
.75412 .69926 L
s
.58841 .4334 m .56673 .44457 L .58936 .43998 L .659 .805 .953 r
F
.58841 .4334 m .56516 .43472 L .56673 .44457 L F
0 g
.56673 .44457 m
.57287 .45336 L
s
.61089 .42626 m .58865 .43417 L .61132 .42957 L .66 .805 .952 r
F
.61089 .42626 m .58771 .42757 L .58865 .43417 L F
.40467 .57701 m .41898 .57373 L .40407 .57492 L .598 .766 .96 r
F
.40467 .57701 m .42013 .57793 L .41898 .57373 L F
.74466 .69307 m .74416 .69007 L .74005 .69006 L .732 .471 .534 r
F
.74837 .69364 m .74416 .69007 L .74466 .69307 L .8 .518 .511 r
F
0 g
.74416 .69007 m
.74786 .69064 L
s
.42013 .57793 m .43393 .57255 L .41898 .57373 L .598 .766 .96 r
F
.42013 .57793 m .4356 .57885 L .43393 .57255 L F
.73768 .69919 m .73682 .69664 L .73277 .69772 L .655 .815 .96 r
F
.74049 .69882 m .73682 .69664 L .73768 .69919 L F
.4356 .57885 m .43436 .56757 L .43393 .57255 L .941 .763 .294 r
F
.43517 .58383 m .4356 .57885 L .43393 .57255 L F
0 g
.43438 .58378 m
.43492 .58157 L
s
.37618 .56636 m .35975 .56524 L .37474 .56819 L .599 .766 .959 r
F
.74049 .69882 m .74105 .69608 L .73682 .69664 L .655 .815 .96 r
F
.40447 .56995 m .4161 .56472 L .40286 .56794 L .599 .766 .959 r
F
.40447 .56995 m .41928 .56877 L .4161 .56472 L F
.74888 .69665 m .74837 .69364 L .74466 .69307 L .8 .518 .511 r
F
0 g
.74837 .69364 m
.75142 .69473 L
s
.67919 .41657 m .70145 .40529 L .67865 .40993 L .661 .804 .952 r
F
.65625 .41786 m .67919 .41657 L .67865 .40993 L F
.74055 .69307 m .73583 .69062 L .73633 .69363 L .665 .426 .548 r
F
.74055 .69307 m .74005 .69006 L .73583 .69062 L F
0 g
.73179 .6917 m
.73583 .69062 L
s
.74466 .69307 m .74005 .69006 L .74055 .69307 L .732 .471 .534 r
F
0 g
.73583 .69062 m
.74005 .69006 L
s
.74005 .69006 m
.74416 .69007 L
s
.38956 .65562 m
.38961 .65437 L
s
.38129 .6555 m
.38132 .65488 L
s
.38136 .65393 m
.38145 .65189 L
s
.3815 .65073 m
.38464 .57965 L
s
.73682 .69664 m .73228 .69471 L .73277 .69772 L .593 .377 .557 r
F
.73682 .69664 m .73633 .69363 L .73228 .69471 L F
0 g
.72869 .69624 m
.73228 .69471 L
s
.72918 .69925 m
.73277 .69772 L
s
.74516 .69608 m .74466 .69307 L .74055 .69307 L .732 .471 .534 r
F
.74888 .69665 m .74466 .69307 L .74516 .69608 L .8 .518 .511 r
F
0 g
.74466 .69307 m
.74837 .69364 L
s
.74888 .69665 m
.75193 .69773 L
s
.65625 .41786 m .67865 .40993 L .65593 .41455 L .661 .804 .952 r
F
.70332 .42104 m .70179 .40522 L .70267 .41102 L 0 0 .173 r
F
.7042 .42684 m .70332 .42104 L .70267 .41102 L F
.68026 .42235 m .70332 .42104 L .70267 .41102 L .66 .805 .952 r
F
0 g
.70093 .42703 m
.70332 .42104 L
s
.74105 .69608 m .73633 .69363 L .73682 .69664 L .665 .426 .548 r
F
.74105 .69608 m .74055 .69307 L .73633 .69363 L F
0 g
.73228 .69471 m
.73633 .69363 L
s
.35854 .57517 m .34228 .57832 L .35776 .57924 L .598 .767 .96 r
F
.35854 .57517 m .34338 .5722 L .34228 .57832 L F
0 g
.34228 .57832 m
.34434 .58458 L
s
.74516 .69608 m .74055 .69307 L .74105 .69608 L .732 .471 .534 r
F
0 g
.73633 .69363 m
.74055 .69307 L
s
.74055 .69307 m
.74466 .69307 L
s
.74516 .69608 m
.74888 .69665 L
s
.37365 .57812 m .35776 .57924 L .37324 .58016 L .598 .767 .96 r
F
.37365 .57812 m .35854 .57517 L .35776 .57924 L F
.4042 .58199 m .41853 .57872 L .4036 .5799 L F
.4042 .58199 m .41969 .58291 L .41853 .57872 L F
.41969 .58291 m .4335 .57754 L .41853 .57872 L F
.41969 .58291 m .43517 .58383 L .4335 .57754 L F
.43517 .58383 m .43393 .57255 L .4335 .57754 L .941 .763 .294 r
F
0 g
.43367 .58987 m
.43517 .58383 L
s
.3756 .5713 m .35907 .57018 L .37416 .57314 L .598 .766 .96 r
F
.37618 .56636 m .36258 .56155 L .35975 .56524 L .599 .766 .959 r
F
.37854 .56484 m .36258 .56155 L .37618 .56636 L F
.40407 .57492 m .41578 .56968 L .40246 .5729 L .598 .766 .96 r
F
.40407 .57492 m .41898 .57373 L .41578 .56968 L F
.40286 .56794 m .41109 .5611 L .40035 .56614 L .599 .766 .959 r
F
.40286 .56794 m .4161 .56472 L .41109 .5611 L F
.36258 .56155 m .34471 .56228 L .35975 .56524 L F
0 g
.73277 .69772 m
.73682 .69664 L
s
.61163 .43209 m .58936 .43998 L .61205 .43539 L .659 .805 .953 r
F
.61163 .43209 m .58841 .4334 L .58936 .43998 L F
.41928 .56877 m .42942 .56149 L .4161 .56472 L .599 .766 .959 r
F
.41928 .56877 m .43414 .56758 L .42942 .56149 L F
0 g
.74105 .69608 m
.74516 .69608 L
s
.68026 .42235 m .70267 .41102 L .67973 .41568 L .66 .805 .952 r
F
.65717 .42365 m .68026 .42235 L .67973 .41568 L F
.6131 .28226 m .58958 .28145 L .5901 .2884 L .579 .358 .544 r
F
.6131 .28226 m .61254 .2753 L .58958 .28145 L F
0 g
.56967 .29087 m
.58958 .28145 L
s
.65672 .43285 m .6811 .42815 L .65798 .42946 L .659 .805 .953 r
F
.68296 .28675 m .66068 .27445 L .66133 .28141 L .809 .53 .516 r
F
.68366 .29372 m .68296 .28675 L .66133 .28141 L F
0 g
.68296 .28675 m
.70076 .29546 L
s
.73682 .69664 m
.74105 .69608 L
s
.61142 .41705 m .58724 .42175 L .61027 .42045 L .661 .804 .952 r
F
.65717 .42365 m .67973 .41568 L .65685 .42033 L .66 .805 .952 r
F
.7042 .42684 m .70267 .41102 L .70356 .41685 L 0 0 .173 r
F
.6811 .42815 m .7042 .42684 L .70356 .41685 L .659 .805 .953 r
F
0 g
.70014 .43697 m
.7042 .42684 L
s
.37854 .56484 m .36729 .5585 L .36258 .56155 L .599 .766 .959 r
F
.38167 .56376 m .36729 .5585 L .37854 .56484 L F
.40035 .56614 m .40459 .55815 L .39711 .56467 L F
.40035 .56614 m .41109 .5611 L .40459 .55815 L F
.3751 .57629 m .35854 .57517 L .37365 .57812 L .598 .767 .96 r
F
.3756 .5713 m .36192 .56648 L .35907 .57018 L .598 .766 .96 r
F
.37798 .56979 m .36192 .56648 L .3756 .5713 L F
.4036 .5799 m .41533 .57467 L .40199 .57788 L .598 .767 .96 r
F
.4036 .5799 m .41853 .57872 L .41533 .57467 L F
.40246 .5729 m .41074 .56604 L .39993 .57109 L .598 .766 .96 r
F
.40246 .5729 m .41578 .56968 L .41074 .56604 L F
.36192 .56648 m .34393 .56721 L .35907 .57018 L F
.36258 .56155 m .34891 .55672 L .34471 .56228 L .599 .766 .959 r
F
.34816 .56163 m .34448 .56224 L .34393 .56721 L 0 0 .292 r
F
.34816 .56163 m .3487 .55665 L .34448 .56224 L F
0 g
.34338 .56839 m
.34448 .56224 L
s
.58944 .41493 m .56417 .42305 L .58724 .42175 L .661 .804 .952 r
F
.61142 .41705 m .58944 .41493 L .58724 .42175 L F
.41898 .57373 m .42918 .56644 L .41578 .56968 L .598 .766 .96 r
F
.41898 .57373 m .43393 .57255 L .42918 .56644 L F
.65593 .41455 m .675 .40386 L .65406 .41154 L .661 .804 .952 r
F
.65593 .41455 m .67865 .40993 L .675 .40386 L F
.43393 .57255 m .43436 .56757 L .42962 .56144 L .991 .751 .467 r
F
0 g
.43436 .56757 m
.43602 .57388 L
s
.6811 .42815 m .70356 .41685 L .68057 .4215 L .659 .805 .953 r
F
.65798 .42946 m .6811 .42815 L .68057 .4215 L F
.38167 .56376 m .37356 .55631 L .36729 .5585 L .599 .766 .959 r
F
.38536 .56318 m .37356 .55631 L .38167 .56376 L F
.39711 .56467 m .39705 .55608 L .39335 .56365 L F
.39711 .56467 m .40459 .55815 L .39705 .55608 L F
.58944 .41493 m .56734 .4128 L .56417 .42305 L .661 .804 .952 r
F
.56768 .41861 m .56382 .42307 L .56449 .42889 L 0 0 .36 r
F
0 g
.56466 .42834 m
.56474 .42887 L
s
.56768 .41861 m .567 .41277 L .56382 .42307 L 0 0 .36 r
F
.61367 .28925 m .5901 .2884 L .59062 .29538 L .579 .358 .544 r
F
0 g
.57062 .30477 m
.59062 .29538 L
s
.61367 .28925 m .6131 .28226 L .5901 .2884 L .579 .358 .544 r
F
0 g
.57015 .29781 m
.5901 .2884 L
s
.66133 .28141 m .66068 .27445 L .63684 .2729 L .736 .475 .534 r
F
0 g
.66068 .27445 m
.68227 .27981 L
s
.68366 .29372 m .66133 .28141 L .66199 .28839 L .809 .53 .516 r
F
0 g
.68366 .29372 m
.70149 .3024 L
s
.61205 .42285 m .58771 .42757 L .61089 .42626 L .66 .805 .952 r
F
.65798 .42946 m .68057 .4215 L .65766 .42614 L .659 .805 .953 r
F
.37798 .56979 m .36666 .56342 L .36192 .56648 L .598 .766 .96 r
F
.38113 .5687 m .36666 .56342 L .37798 .56979 L F
.39993 .57109 m .4042 .56308 L .39667 .56962 L F
.39993 .57109 m .41074 .56604 L .4042 .56308 L F
.38536 .56318 m .38097 .55513 L .37356 .55631 L .599 .766 .959 r
F
.38934 .56314 m .38097 .55513 L .38536 .56318 L F
.3751 .57629 m .36139 .57147 L .35854 .57517 L .598 .767 .96 r
F
.37747 .57477 m .36139 .57147 L .3751 .57629 L F
.39335 .56365 m .38898 .55505 L .38934 .56314 L .599 .766 .959 r
F
.39335 .56365 m .39705 .55608 L .38898 .55505 L F
.40199 .57788 m .41028 .57104 L .39946 .57608 L .598 .767 .96 r
F
.40199 .57788 m .41533 .57467 L .41028 .57104 L F
.36139 .57147 m .34338 .5722 L .35854 .57517 L F
.36729 .5585 m .34891 .55672 L .36258 .56155 L .599 .766 .959 r
F
.36192 .56648 m .34816 .56163 L .34393 .56721 L .598 .766 .96 r
F
.34761 .56663 m .34393 .56721 L .34338 .5722 L 0 0 .292 r
F
.34761 .56663 m .34816 .56163 L .34393 .56721 L F
0 g
.34283 .57335 m
.34393 .56721 L
s
.41853 .57872 m .42874 .57144 L .41533 .57467 L .598 .767 .96 r
F
.41853 .57872 m .4335 .57754 L .42874 .57144 L F
.38934 .56314 m .38898 .55505 L .38097 .55513 L .599 .766 .959 r
F
.4161 .56472 m .42192 .55602 L .41109 .5611 L F
.4161 .56472 m .42942 .56149 L .42192 .55602 L F
.61407 .41378 m .58944 .41493 L .61142 .41705 L .661 .804 .952 r
F
.43393 .57255 m .42962 .56144 L .42918 .56644 L .991 .751 .467 r
F
.4335 .57754 m .43393 .57255 L .42918 .56644 L F
0 g
.43393 .57255 m
.4356 .57885 L
s
.58993 .42074 m .56449 .42889 L .58771 .42757 L .66 .805 .952 r
F
.61205 .42285 m .58993 .42074 L .58771 .42757 L F
.65685 .42033 m .67605 .4096 L .65497 .41731 L F
.65685 .42033 m .67973 .41568 L .67605 .4096 L F
.67865 .40993 m .69609 .39612 L .675 .40386 L .661 .804 .952 r
F
.67865 .40993 m .70145 .40529 L .69609 .39612 L F
.63745 .27987 m .61254 .2753 L .6131 .28226 L .662 .419 .543 r
F
.63745 .27987 m .63684 .2729 L .61254 .2753 L F
0 g
.58958 .28145 m
.61254 .2753 L
s
.38113 .5687 m .37297 .56122 L .36666 .56342 L .598 .766 .96 r
F
.38484 .56812 m .37297 .56122 L .38113 .5687 L F
.39667 .56962 m .3966 .561 L .39288 .56859 L F
.39667 .56962 m .4042 .56308 L .3966 .561 L F
.58993 .42074 m .56768 .41861 L .56449 .42889 L .66 .805 .952 r
F
.56836 .42447 m .56449 .42889 L .56516 .43472 L 0 0 .36 r
F
0 g
.56533 .43417 m
.56542 .43471 L
s
.56836 .42447 m .56768 .41861 L .56449 .42889 L 0 0 .36 r
F
.65406 .41154 m .66844 .39879 L .65076 .40903 L .661 .804 .952 r
F
.65406 .41154 m .675 .40386 L .66844 .39879 L F
.37747 .57477 m .36614 .56842 L .36139 .57147 L .598 .767 .96 r
F
.38063 .57369 m .36614 .56842 L .37747 .57477 L F
.6128 .42868 m .58841 .4334 L .61163 .43209 L .659 .805 .953 r
F
.39946 .57608 m .40372 .56808 L .39619 .57461 L .598 .767 .96 r
F
.39946 .57608 m .41028 .57104 L .40372 .56808 L F
.66133 .28141 m .63684 .2729 L .63745 .27987 L .736 .475 .534 r
F
0 g
.61254 .2753 m
.63684 .2729 L
s
.63684 .2729 m
.66068 .27445 L
s
.38484 .56812 m .38042 .56004 L .37297 .56122 L .598 .766 .96 r
F
.38885 .56808 m .38042 .56004 L .38484 .56812 L F
.39288 .56859 m .38848 .55997 L .38885 .56808 L F
.39288 .56859 m .3966 .561 L .38848 .55997 L F
.36666 .56342 m .34816 .56163 L .36192 .56648 L F
.36139 .57147 m .34761 .56663 L .34338 .5722 L .598 .767 .96 r
F
0 g
.34228 .57832 m
.34338 .5722 L
s
.66199 .28839 m .66133 .28141 L .63745 .27987 L .736 .475 .534 r
F
0 g
.66133 .28141 m
.68296 .28675 L
s
.38885 .56808 m .38848 .55997 L .38042 .56004 L .598 .766 .96 r
F
.41578 .56968 m .42164 .56094 L .41074 .56604 L F
.41578 .56968 m .42918 .56644 L .42164 .56094 L F
.4335 .57754 m .42918 .56644 L .42874 .57144 L .991 .751 .467 r
F
0 g
.4335 .57754 m
.43517 .58383 L
s
.61472 .41957 m .58993 .42074 L .61205 .42285 L .66 .805 .952 r
F
.59064 .42658 m .56516 .43472 L .58841 .4334 L .659 .805 .953 r
F
.6128 .42868 m .59064 .42658 L .58841 .4334 L F
.65766 .42614 m .6769 .41543 L .65578 .42313 L F
.65766 .42614 m .68057 .4215 L .6769 .41543 L F
.38063 .57369 m .37245 .56623 L .36614 .56842 L .598 .767 .96 r
F
.38434 .57311 m .37245 .56623 L .38063 .57369 L F
.67973 .41568 m .69729 .40183 L .67605 .4096 L .66 .805 .952 r
F
.67973 .41568 m .70267 .41102 L .69729 .40183 L F
.39619 .57461 m .39612 .56601 L .3924 .57359 L .598 .767 .96 r
F
.39619 .57461 m .40372 .56808 L .39612 .56601 L F
.70267 .41102 m .70179 .40522 L .69641 .396 L .94 .636 .181 r
F
0 g
.70207 .40958 m
.7021 .41005 L
s
.63296 .44373 m .63489 .44403 L .6375 .51726 L .755 .473 .507 r
F
.63807 .51756 m .63742 .52271 L .63953 .51714 L .602 .764 .957 r
F
.63296 .44373 m .63738 .51724 L .63552 .51691 L .755 .473 .507 r
F
.63296 .44373 m .6375 .51726 L .63738 .51724 L F
.63489 .44403 m .63941 .51714 L .6375 .51726 L .629 .374 .513 r
F
.63099 .44249 m .63177 .44318 L .63431 .51637 L .948 .643 .425 r
F
.63722 .51872 m .63337 .52218 L .63786 .51923 L .602 .764 .957 r
F
.63649 .51733 m .63615 .51786 L .63802 .518 L F
.63615 .51786 m .63337 .52218 L .63722 .51872 L F
.63615 .51786 m .63722 .51872 L .63802 .518 L F
.63177 .44318 m .63296 .44373 L .63552 .51691 L .862 .563 .481 r
F
.63177 .44318 m .63552 .51691 L .63545 .51687 L F
.63057 .44169 m .63099 .44249 L .63351 .51573 L .972 .694 .284 r
F
.63542 .51899 m .62966 .52111 L .63337 .52218 L .602 .764 .957 r
F
.63495 .51818 m .6331 .5192 L .63542 .51899 L F
.6331 .5192 m .62966 .52111 L .63311 .51984 L F
.6331 .5192 m .63311 .51984 L .63542 .51899 L F
.63057 .44169 m .63351 .51573 L .63349 .51569 L .972 .694 .284 r
F
.63447 .51736 m .6331 .51842 L .63495 .51818 L .602 .764 .957 r
F
.6331 .51842 m .62966 .52111 L .6331 .5192 L F
.6331 .51842 m .6331 .5192 L .63495 .51818 L F
.63177 .44318 m .63545 .51687 L .63431 .51637 L .862 .563 .481 r
F
.63099 .44249 m .63426 .51633 L .63351 .51573 L .948 .643 .425 r
F
.63099 .44249 m .63431 .51637 L .63426 .51633 L F
.6385 .51421 m .63035 .51786 L .62966 .52111 L .602 .764 .957 r
F
.63035 .51786 m .62654 .51957 L .62841 .52049 L F
.63035 .51786 m .62841 .52049 L .62966 .52111 L F
.63057 .44169 m .63349 .51569 L .63308 .515 L .972 .694 .284 r
F
.63129 .43956 m .63056 .44075 L .63308 .51417 L 0 0 .377 r
F
.6385 .51421 m .63186 .51582 L .63035 .51786 L .602 .764 .957 r
F
.63056 .44075 m .63308 .51495 L .63308 .51417 L 0 0 .044 r
F
.63056 .44075 m .63057 .44169 L .63308 .515 L F
.63056 .44075 m .63308 .515 L .63308 .51495 L F
.62526 .51742 m .62289 .51551 L .62423 .51766 L .602 .764 .957 r
F
.6385 .51421 m .63032 .51489 L .62526 .51742 L F
.63032 .51489 m .62289 .51551 L .62526 .51742 L F
.6385 .51421 m .63522 .51677 L .63649 .51733 L F
.63522 .51677 m .63447 .51736 L .63649 .51733 L F
.63447 .51736 m .63495 .51818 L .63649 .51733 L F
.63786 .51923 m .63337 .52218 L .63742 .52271 L F
.63431 .51637 m .63568 .52172 L .63447 .52119 L .862 .563 .481 r
F
.63337 .52218 m .63635 .53112 L .63742 .52271 L .602 .764 .957 r
F
.63337 .52218 m .62829 .53007 L .63635 .53112 L F
.62966 .52111 m .62829 .53007 L .63337 .52218 L F
.62966 .52111 m .6209 .52795 L .62829 .53007 L F
.63536 .52158 m .6263 .52464 L .62944 .52619 L .601 .765 .958 r
F
.63649 .51733 m .63495 .51818 L .63542 .51899 L .602 .764 .957 r
F
.63545 .51687 m .63569 .52172 L .63431 .51637 L .862 .563 .481 r
F
.63569 .52172 m .63568 .52172 L .63431 .51637 L F
.63351 .51573 m .63446 .52118 L .63368 .52055 L .948 .643 .425 r
F
.63308 .515 m .63367 .52055 L .63325 .51978 L .972 .694 .284 r
F
.62654 .51957 m .6209 .52795 L .62966 .52111 L .602 .764 .957 r
F
.62654 .51957 m .61468 .52489 L .6209 .52795 L F
.63359 .52041 m .62398 .52272 L .63405 .52118 L .601 .765 .958 r
F
.63367 .52055 m .63353 .5203 L .63325 .51978 L .972 .694 .284 r
F
.63129 .43956 m .63312 .51411 L .63383 .51315 L 0 0 .377 r
F
.63129 .43956 m .63308 .51417 L .63312 .51411 L F
.6385 .51421 m .62908 .51365 L .62289 .51551 L .602 .764 .957 r
F
.62908 .51365 m .62261 .51327 L .62281 .5149 L F
.62908 .51365 m .62281 .5149 L .62289 .51551 L F
.63413 .43826 m .63274 .43865 L .63532 .51241 L .547 .31 .508 r
F
.62908 .51365 m .62341 .51108 L .62261 .51327 L .602 .764 .957 r
F
.6385 .51421 m .63251 .51297 L .62908 .51365 L F
.63251 .51297 m .62341 .51108 L .62908 .51365 L F
.63274 .43865 m .63392 .5131 L .63532 .51241 L .369 .177 .485 r
F
.63274 .43865 m .63129 .43956 L .63383 .51315 L F
.63274 .43865 m .63383 .51315 L .63392 .5131 L F
.63953 .51714 m .63936 .51759 L .63955 .51713 L .602 .764 .957 r
F
.63936 .51759 m .63938 .51759 L .63955 .51713 L F
.63812 .51722 m .63807 .51756 L .63953 .51714 L F
.63974 .51766 m .63742 .52271 L .64155 .52267 L F
.63955 .51713 m .63938 .51759 L .63974 .51766 L F
.63938 .51759 m .63742 .52271 L .63974 .51766 L F
.63489 .44403 m .63687 .44379 L .63953 .51714 L .629 .374 .513 r
F
.63941 .51714 m .63953 .51714 L .6397 .52184 L F
.63489 .44403 m .63953 .51714 L .63941 .51714 L F
.6418 .51792 m .64155 .52267 L .64547 .52205 L .602 .764 .957 r
F
.64104 .51706 m .64129 .51985 L .6418 .51792 L F
.64129 .51985 m .64155 .52267 L .6418 .51792 L F
.63687 .44379 m .64079 .51677 L .63953 .51714 L .492 .27 .504 r
F
.63968 .44184 m .63988 .4409 L .64264 .51471 L 0 0 .209 r
F
.64215 .51655 m .64547 .52205 L .64584 .52192 L .602 .764 .957 r
F
.64397 .51772 m .64584 .52192 L .64893 .5209 L F
.64215 .51655 m .64584 .52192 L .64397 .51772 L F
.64212 .51668 m .64547 .52205 L .64215 .51655 L F
.63909 .44263 m .63968 .44184 L .64242 .51554 L .067 0 .41 r
F
.64149 .51657 m .64547 .52205 L .64196 .51643 L .602 .764 .957 r
F
.64109 .517 m .64547 .52205 L .64149 .51657 L F
.64079 .51679 m .64547 .52205 L .64087 .51675 L F
.63817 .44329 m .64176 .51624 L .64087 .51675 L .328 .148 .478 r
F
.63687 .44379 m .63817 .44329 L .64087 .51675 L .492 .27 .504 r
F
.63687 .44379 m .64087 .51675 L .64079 .51677 L F
.63909 .44263 m .64239 .51557 L .64181 .51621 L .067 0 .41 r
F
.64257 .51578 m .64893 .5209 L .65168 .51929 L .602 .764 .957 r
F
.63817 .44329 m .63909 .44263 L .64181 .51621 L .328 .148 .478 r
F
.63817 .44329 m .64181 .51621 L .64176 .51624 L F
.6385 .51421 m .64171 .51627 L .64257 .51578 L .602 .764 .957 r
F
.63909 .44263 m .64242 .51554 L .64239 .51557 L .067 0 .41 r
F
.63968 .44184 m .64264 .51471 L .64262 .51476 L 0 0 .209 r
F
.63968 .44184 m .64262 .51476 L .64242 .51554 L F
.63988 .4409 m .6394 .43969 L .64215 .51362 L .944 .685 .22 r
F
.64171 .51627 m .64397 .51772 L .64257 .51578 L .602 .764 .957 r
F
.64487 .51553 m .65168 .51929 L .65355 .51733 L F
.6385 .51421 m .64844 .51804 L .64487 .51553 L F
.64844 .51804 m .65168 .51929 L .64487 .51553 L F
.6385 .51421 m .64078 .51677 L .64196 .51643 L F
.64176 .51624 m .64181 .51621 L .64198 .52071 L .328 .148 .478 r
F
.64087 .51675 m .64109 .517 L .64149 .51657 L .602 .764 .957 r
F
.64102 .51705 m .64103 .51708 L .64104 .51706 L F
.6385 .51421 m .63955 .51713 L .64102 .51705 L F
.63955 .51713 m .64155 .52267 L .64102 .51705 L F
.64176 .51624 m .64198 .52071 L .64087 .51675 L .328 .148 .478 r
F
.64196 .51643 m .64212 .51668 L .64215 .51655 L .602 .764 .957 r
F
.64181 .51621 m .64258 .51993 L .64198 .52071 L .067 0 .41 r
F
.64239 .51557 m .64258 .51993 L .64181 .51621 L F
.63988 .4409 m .64218 .51368 L .64264 .51471 L .944 .685 .22 r
F
.6434 .5145 m .65355 .51733 L .6544 .51515 L .602 .764 .957 r
F
.6385 .51421 m .64487 .51553 L .6434 .5145 L F
.64487 .51553 m .65355 .51733 L .6434 .5145 L F
.6394 .43969 m .63815 .43874 L .64087 .51272 L .931 .625 .44 r
F
.6394 .43969 m .64087 .51272 L .64094 .51277 L F
.6394 .43969 m .64094 .51277 L .64215 .51362 L F
.63988 .4409 m .64215 .51362 L .64218 .51368 L .944 .685 .22 r
F
.63815 .43874 m .6396 .5123 L .64087 .51272 L .822 .528 .492 r
F
.64054 .51261 m .65056 .5088 L .64743 .50724 L .602 .764 .957 r
F
.6385 .51421 m .64141 .5129 L .64054 .51261 L F
.64141 .5129 m .65056 .5088 L .64054 .51261 L F
.64078 .51677 m .64079 .51679 L .64087 .51675 L F
.64141 .5129 m .65285 .51074 L .65056 .5088 L F
.6385 .51421 m .64246 .51325 L .64141 .5129 L F
.64246 .51325 m .65285 .51074 L .64141 .5129 L F
.63815 .43874 m .63684 .4383 L .63953 .51228 L .822 .528 .492 r
F
.63815 .43874 m .63953 .51228 L .6396 .5123 L F
.63684 .4383 m .63823 .5121 L .63953 .51228 L .735 .457 .508 r
F
.6385 .51421 m .64369 .50614 L .63959 .5056 L .602 .764 .957 r
F
.6385 .51421 m .64743 .50724 L .64369 .50614 L F
.6385 .51421 m .65416 .5129 L .65285 .51074 L F
.6385 .51421 m .6544 .51515 L .65416 .5129 L F
.6396 .5123 m .63953 .51228 L .63968 .51646 L .822 .528 .492 r
F
.64087 .51272 m .63968 .51646 L .64102 .51689 L F
.6396 .5123 m .63968 .51646 L .64087 .51272 L F
.64094 .51277 m .64087 .51272 L .64102 .51689 L .931 .625 .44 r
F
.64215 .51362 m .64102 .51689 L .64231 .51782 L F
.64094 .51277 m .64102 .51689 L .64215 .51362 L F
.64218 .51368 m .64215 .51362 L .64231 .51782 L .944 .685 .22 r
F
.64397 .51772 m .64893 .5209 L .64341 .51645 L .602 .764 .957 r
F
.64397 .51772 m .64341 .51645 L .64257 .51578 L F
.64239 .51557 m .64242 .51554 L .64258 .51993 L .067 0 .41 r
F
.64103 .51708 m .64155 .52267 L .64104 .51706 L .602 .764 .957 r
F
.64087 .51675 m .64198 .52071 L .64104 .52135 L .328 .148 .478 r
F
.64262 .51476 m .64264 .51471 L .6428 .51901 L 0 0 .209 r
F
.64242 .51554 m .6428 .51901 L .64258 .51993 L F
.64262 .51476 m .6428 .51901 L .64242 .51554 L F
.64264 .51471 m .64231 .51782 L .6428 .51901 L .944 .685 .22 r
F
.64218 .51368 m .64231 .51782 L .64264 .51471 L F
.64079 .51677 m .64087 .51675 L .64104 .52135 L .492 .27 .504 r
F
.6355 .43815 m .63413 .43826 L .63675 .51212 L .65 .39 .512 r
F
.6385 .51421 m .63327 .5122 L .62922 .51229 L .602 .764 .957 r
F
.63413 .43826 m .6354 .51239 L .63675 .51212 L .547 .31 .508 r
F
.63413 .43826 m .63532 .51241 L .6354 .51239 L F
.6301 .51098 m .62799 .50747 L .62524 .5091 L .602 .764 .957 r
F
.6385 .51421 m .63529 .51215 L .63327 .5122 L F
.6385 .51421 m .63649 .51733 L .63802 .518 L F
.6385 .51421 m .63146 .50629 L .62799 .50747 L F
.6355 .43815 m .63683 .51212 L .63816 .51209 L .65 .39 .512 r
F
.6355 .43815 m .63675 .51212 L .63683 .51212 L F
.6385 .51421 m .63542 .50565 L .63146 .50629 L .602 .764 .957 r
F
.63684 .4383 m .6355 .43815 L .63816 .51209 L .735 .457 .508 r
F
.63684 .4383 m .63816 .51209 L .63823 .5121 L F
.6385 .51421 m .63959 .5056 L .63542 .50565 L .602 .764 .957 r
F
.63816 .51209 m .63691 .51641 L .63831 .51631 L .65 .39 .512 r
F
.63683 .51212 m .63691 .51641 L .63816 .51209 L F
.63327 .5122 m .63438 .51157 L .6301 .51098 L .602 .764 .957 r
F
.63529 .51215 m .63438 .51157 L .63327 .5122 L F
.63438 .51157 m .62799 .50747 L .6301 .51098 L F
.63823 .5121 m .63816 .51209 L .63831 .51631 L .735 .457 .508 r
F
.63683 .51212 m .63675 .51212 L .63691 .51641 L .65 .39 .512 r
F
.62922 .51229 m .6301 .51098 L .62341 .51108 L .602 .764 .957 r
F
.63327 .5122 m .6301 .51098 L .62922 .51229 L F
.6301 .51098 m .62524 .5091 L .62425 .51017 L F
.6301 .51098 m .62425 .51017 L .62341 .51108 L F
.6385 .51421 m .63812 .51722 L .63955 .51713 L F
.63953 .51228 m .63831 .51631 L .63968 .51646 L .735 .457 .508 r
F
.63823 .5121 m .63831 .51631 L .63953 .51228 L F
.63675 .51212 m .63547 .5168 L .63691 .51641 L .547 .31 .508 r
F
.6354 .51239 m .63547 .5168 L .63675 .51212 L F
.6354 .51239 m .63532 .51241 L .63547 .5168 L F
.63308 .51417 m .63325 .51978 L .63324 .51886 L 0 0 .044 r
F
.63308 .51495 m .63325 .51978 L .63308 .51417 L F
.62423 .51766 m .61468 .52489 L .62654 .51957 L .602 .764 .957 r
F
.63359 .52041 m .62263 .52057 L .62398 .52272 L .601 .765 .958 r
F
.63349 .51569 m .63368 .52055 L .63308 .515 L .972 .694 .284 r
F
.63368 .52055 m .63367 .52055 L .63308 .515 L F
.63308 .51495 m .63308 .515 L .63325 .51978 L 0 0 .044 r
F
.63349 .51569 m .63351 .51573 L .63368 .52055 L .972 .694 .284 r
F
.63368 .52055 m .63368 .52055 L .63368 .52057 L F
.63349 .51569 m .63368 .52055 L .63368 .52055 L F
.63035 .51786 m .62526 .51742 L .62654 .51957 L .602 .764 .957 r
F
.62526 .51742 m .62443 .51783 L .62654 .51957 L F
.62423 .51766 m .61005 .5211 L .61468 .52489 L F
.63317 .51969 m .62234 .51832 L .62263 .52057 L .601 .765 .958 r
F
.63426 .51633 m .63447 .52119 L .63351 .51573 L .948 .643 .425 r
F
.63425 .52109 m .6263 .52464 L .63536 .52158 L .601 .765 .958 r
F
.63447 .52119 m .63447 .52124 L .63446 .52118 L .948 .643 .425 r
F
.63447 .52119 m .63446 .52118 L .63351 .51573 L F
.63426 .51633 m .63431 .51637 L .63447 .52124 L F
.63545 .51687 m .63552 .51691 L .6357 .52178 L .862 .563 .481 r
F
.63664 .52189 m .63569 .52172 L .63652 .52208 L .601 .765 .958 r
F
.63552 .51691 m .63767 .52207 L .63569 .52172 L .755 .473 .507 r
F
.63742 .52271 m .63635 .53112 L .64456 .53103 L .602 .764 .957 r
F
.63742 .52271 m .64456 .53103 L .64155 .52267 L F
.63797 .52213 m .63317 .52726 L .63725 .52779 L .601 .765 .958 r
F
.63802 .518 m .63722 .51872 L .63786 .51923 L .602 .764 .957 r
F
.63738 .51724 m .63767 .52207 L .63552 .51691 L .755 .473 .507 r
F
.63936 .51759 m .63742 .52271 L .63938 .51759 L .602 .764 .957 r
F
.63738 .51724 m .6375 .51726 L .63767 .52207 L .755 .473 .507 r
F
.6375 .51726 m .6397 .52184 L .63769 .52207 L .629 .374 .513 r
F
.63798 .52206 m .63767 .52207 L .63797 .52213 L .601 .765 .958 r
F
.63767 .52207 m .63769 .52207 L .63767 .52207 L .629 .374 .513 r
F
.6375 .51726 m .63769 .52207 L .63767 .52207 L F
.63834 .51926 m .63664 .52189 L .63767 .52207 L .601 .765 .958 r
F
.63834 .51926 m .63767 .52207 L .63798 .52206 L F
.63767 .52207 m .63317 .52726 L .63797 .52213 L F
.63512 .54456 m .63528 .53956 L .64759 .53943 L .663 .422 .546 r
F
.63635 .53112 m .6353 .53943 L .64754 .5393 L .602 .764 .957 r
F
.63512 .54456 m .64759 .53943 L .64744 .54443 L .663 .422 .546 r
F
.63635 .53112 m .64754 .5393 L .64456 .53103 L .602 .764 .957 r
F
.63495 .54957 m .63512 .54456 L .64744 .54443 L .663 .422 .546 r
F
.63618 .53622 m .63512 .54456 L .64744 .54443 L .601 .765 .958 r
F
.63495 .54957 m .64744 .54443 L .64729 .54945 L .663 .422 .546 r
F
.63618 .53622 m .64744 .54443 L .64444 .53614 L .601 .765 .958 r
F
.63601 .54126 m .63495 .54957 L .64729 .54945 L .6 .765 .958 r
F
.63601 .54126 m .64729 .54945 L .64428 .54117 L F
.63725 .52779 m .63618 .53622 L .64444 .53614 L .601 .765 .958 r
F
.63725 .52779 m .64444 .53614 L .6414 .52775 L F
.63709 .53284 m .63601 .54126 L .64428 .54117 L .6 .765 .958 r
F
.63709 .53284 m .64428 .54117 L .64125 .5328 L F
.63769 .52207 m .6397 .52184 L .63971 .52195 L .629 .374 .513 r
F
.63935 .52206 m .63725 .52779 L .6414 .52775 L .601 .765 .958 r
F
.63834 .51926 m .63793 .52247 L .63935 .52206 L F
.63793 .52247 m .63725 .52779 L .63935 .52206 L F
.6397 .52184 m .63971 .52195 L .63971 .52195 L .492 .27 .504 r
F
.63953 .51714 m .64104 .52135 L .6397 .52184 L F
.63941 .51714 m .6397 .52184 L .6375 .51726 L .629 .374 .513 r
F
.64155 .52267 m .64456 .53103 L .65237 .52981 L .602 .764 .957 r
F
.64052 .52172 m .6414 .52775 L .64535 .52713 L .601 .765 .958 r
F
.6397 .52184 m .64105 .52156 L .63971 .52195 L .492 .27 .504 r
F
.63834 .51926 m .63935 .52206 L .64052 .52172 L .601 .765 .958 r
F
.63935 .52206 m .6414 .52775 L .64052 .52172 L F
.6397 .52184 m .64104 .52135 L .64105 .52156 L .492 .27 .504 r
F
.64744 .54443 m .64759 .53943 L .65931 .53761 L .581 .355 .538 r
F
.64456 .53103 m .64754 .5393 L .65921 .53749 L .602 .764 .957 r
F
.64744 .54443 m .65931 .53761 L .65918 .54262 L .581 .355 .538 r
F
.64444 .53614 m .64744 .54443 L .65918 .54262 L .601 .765 .958 r
F
.64444 .53614 m .65918 .54262 L .6523 .53491 L F
.64456 .53103 m .65921 .53749 L .65237 .52981 L .602 .764 .957 r
F
.6414 .52775 m .64444 .53614 L .6523 .53491 L .601 .765 .958 r
F
.64125 .5328 m .64428 .54117 L .65216 .53995 L .6 .765 .958 r
F
.64125 .5328 m .65216 .53995 L .6452 .53218 L F
.64079 .51677 m .64104 .52135 L .63953 .51714 L .492 .27 .504 r
F
.64155 .52267 m .65237 .52981 L .64547 .52205 L .602 .764 .957 r
F
.64152 .5213 m .64535 .52713 L .64883 .52597 L .601 .765 .958 r
F
.64104 .52135 m .64105 .52156 L .64105 .52156 L .328 .148 .478 r
F
.64061 .52181 m .64535 .52713 L .64152 .5213 L .601 .765 .958 r
F
.6414 .52775 m .6523 .53491 L .64535 .52713 L F
.64547 .52205 m .65237 .52981 L .65927 .52753 L .602 .764 .957 r
F
.64547 .52205 m .65927 .52753 L .64893 .5209 L F
.64237 .52081 m .64883 .52597 L .6516 .52436 L .601 .765 .958 r
F
.64104 .52135 m .64198 .52071 L .64199 .52102 L .328 .148 .478 r
F
.64199 .52102 m .64883 .52597 L .64237 .52081 L .601 .765 .958 r
F
.64152 .5213 m .64166 .52139 L .64199 .52102 L F
.64166 .52139 m .64883 .52597 L .64199 .52102 L F
.64198 .52071 m .64258 .51993 L .6426 .52035 L .067 0 .41 r
F
.64223 .52076 m .64199 .52102 L .64237 .52081 L .601 .765 .958 r
F
.64191 .5285 m .64125 .5328 L .6452 .53218 L .6 .765 .958 r
F
.64893 .5209 m .65927 .52753 L .66479 .52433 L .602 .764 .957 r
F
.64265 .52016 m .6516 .52436 L .65348 .52239 L .601 .765 .958 r
F
.64247 .52085 m .6516 .52436 L .64265 .52016 L F
.6426 .52035 m .643 .52437 L .64279 .52514 L 0 0 .209 r
F
.64258 .51993 m .64262 .52029 L .6426 .52035 L F
.64262 .52029 m .643 .52437 L .6426 .52035 L F
.65168 .51929 m .66479 .52433 L .66856 .52043 L .602 .764 .957 r
F
.64893 .5209 m .66479 .52433 L .65168 .51929 L F
.64282 .51953 m .65348 .52239 L .65433 .52021 L .601 .765 .958 r
F
.64258 .51993 m .64282 .51953 L .64262 .52029 L 0 0 .209 r
F
.64258 .51993 m .64279 .52514 L .64278 .52519 L F
.64282 .51953 m .65348 .52239 L .64282 .51953 L .601 .765 .958 r
F
.64265 .52016 m .64314 .52026 L .64282 .51953 L F
.64314 .52026 m .65348 .52239 L .64282 .51953 L F
.6428 .51901 m .64231 .51782 L .64233 .51844 L .944 .685 .22 r
F
.63834 .51926 m .64265 .52016 L .64282 .51953 L .601 .765 .958 r
F
.63834 .51926 m .64282 .51953 L .64281 .51953 L F
.64198 .52071 m .6426 .52035 L .642 .52102 L .067 0 .41 r
F
.63834 .51926 m .64247 .52085 L .64265 .52016 L .601 .765 .958 r
F
.64258 .51993 m .6428 .51901 L .64282 .51953 L 0 0 .209 r
F
.64262 .52029 m .64282 .51953 L .643 .52437 L F
.64231 .52697 m .6452 .53218 L .64868 .53103 L .6 .765 .958 r
F
.64218 .52745 m .6452 .53218 L .64231 .52697 L F
.64084 .52732 m .6452 .53218 L .64158 .52651 L F
.65237 .52981 m .65921 .53749 L .66953 .5341 L .602 .764 .957 r
F
.64535 .52713 m .6523 .53491 L .65924 .53262 L .601 .765 .958 r
F
.65237 .52981 m .66953 .5341 L .65927 .52753 L .602 .764 .957 r
F
.64535 .52713 m .65924 .53262 L .64883 .52597 L .601 .765 .958 r
F
.64397 .52655 m .64868 .53103 L .65146 .52942 L .6 .765 .958 r
F
.642 .52102 m .64221 .52581 L .64199 .52102 L .067 0 .41 r
F
.64217 .52586 m .64489 .52862 L .64397 .52655 L .6 .765 .958 r
F
.64158 .52651 m .64489 .52862 L .64217 .52586 L F
.64158 .52651 m .64218 .52745 L .64231 .52697 L F
.64221 .52581 m .64221 .52582 L .64199 .52102 L .067 0 .41 r
F
.65927 .52753 m .66953 .5341 L .67783 .52935 L .602 .764 .957 r
F
.64883 .52597 m .65924 .53262 L .6648 .52942 L .601 .765 .958 r
F
.64347 .52542 m .65146 .52942 L .65334 .52746 L .6 .765 .958 r
F
.64199 .52102 m .64221 .52582 L .64217 .52586 L .067 0 .41 r
F
.642 .52102 m .64278 .52519 L .64221 .52581 L F
.64109 .52154 m .64199 .52102 L .64217 .52586 L .328 .148 .478 r
F
.64104 .52135 m .64217 .52586 L .64128 .52636 L F
.64105 .52156 m .64128 .52636 L .64122 .5264 L F
.63971 .52195 m .64105 .52156 L .64122 .5264 L .492 .27 .504 r
F
.64135 .52636 m .64084 .52732 L .64158 .52651 L .6 .765 .958 r
F
.64131 .52637 m .64084 .52732 L .64135 .52636 L F
.64043 .52685 m .64084 .52732 L .64132 .52634 L F
.64084 .52732 m .64114 .53141 L .64191 .5285 L F
.64114 .53141 m .64125 .5328 L .64191 .5285 L F
.64043 .52685 m .64054 .52765 L .64084 .52732 L F
.64054 .52765 m .64125 .5328 L .64084 .52732 L F
.63971 .52195 m .64122 .5264 L .63997 .52676 L .492 .27 .504 r
F
.63769 .52207 m .63971 .52195 L .63988 .52678 L .629 .374 .513 r
F
.64034 .52676 m .63931 .52748 L .64043 .52685 L .6 .765 .958 r
F
.64016 .52677 m .63931 .52748 L .64034 .52676 L F
.63769 .52207 m .63988 .52678 L .63798 .5269 L .629 .374 .513 r
F
.63971 .52195 m .63996 .52676 L .63988 .52678 L .492 .27 .504 r
F
.63914 .527 m .63931 .52748 L .64027 .52667 L .6 .765 .958 r
F
.63971 .52195 m .63997 .52676 L .63971 .52195 L .492 .27 .504 r
F
.63931 .52748 m .64125 .5328 L .64043 .52685 L .6 .765 .958 r
F
.63664 .52189 m .63648 .52214 L .63767 .52207 L .601 .765 .958 r
F
.63648 .52214 m .63317 .52726 L .63767 .52207 L F
.63652 .52208 m .62944 .52619 L .63317 .52726 L F
.63536 .52158 m .62944 .52619 L .63652 .52208 L F
.6357 .52178 m .63767 .52207 L .63784 .5269 L .755 .473 .507 r
F
.63919 .52714 m .63709 .53284 L .64125 .5328 L .6 .765 .958 r
F
.63899 .52711 m .63709 .53284 L .63919 .52714 L F
.63784 .5269 m .63709 .53284 L .63908 .52683 L F
.62829 .53007 m .6353 .53943 L .63635 .53112 L .602 .764 .957 r
F
.63317 .52726 m .63618 .53622 L .63725 .52779 L .601 .765 .958 r
F
.62301 .54299 m .63528 .53956 L .63512 .54456 L .735 .483 .548 r
F
.62301 .54299 m .62319 .53798 L .63528 .53956 L F
.62829 .53007 m .62327 .53787 L .6353 .53943 L .602 .764 .957 r
F
.62806 .53517 m .63512 .54456 L .63618 .53622 L .601 .765 .958 r
F
.63317 .52726 m .62806 .53517 L .63618 .53622 L F
.633 .53231 m .63601 .54126 L .63709 .53284 L .6 .765 .958 r
F
.6357 .52178 m .63784 .5269 L .63598 .52657 L .755 .473 .507 r
F
.63767 .52207 m .63769 .52207 L .63798 .5269 L .629 .374 .513 r
F
.63767 .52207 m .63798 .5269 L .63797 .5269 L F
.63431 .52106 m .63368 .52055 L .63405 .52118 L .601 .765 .958 r
F
.63405 .52118 m .62398 .52272 L .6263 .52464 L F
.63368 .52057 m .63447 .52124 L .63464 .52602 L .948 .643 .425 r
F
.63765 .52843 m .633 .53231 L .63709 .53284 L .6 .765 .958 r
F
.63716 .52803 m .633 .53231 L .63765 .52843 L F
.63751 .52728 m .63697 .52788 L .63778 .52739 L F
.63697 .52788 m .633 .53231 L .63716 .52803 L F
.63697 .52788 m .63716 .52803 L .63778 .52739 L F
.63317 .51969 m .62263 .52057 L .63325 .52041 L .601 .765 .958 r
F
.63325 .51982 m .63325 .52041 L .63359 .52041 L F
.63317 .51969 m .63325 .52041 L .63325 .51982 L F
.63324 .51886 m .63325 .51978 L .63325 .51982 L 0 0 .044 r
F
.63325 .51978 m .63368 .52057 L .63384 .52538 L .972 .694 .284 r
F
.63325 .51978 m .63384 .52538 L .63344 .5247 L F
.63558 .52833 m .633 .53231 L .63597 .52899 L .6 .765 .958 r
F
.63324 .51886 m .63325 .51982 L .63324 .51899 L 0 0 .044 r
F
.63325 .51969 m .63272 .51893 L .63317 .51969 L .601 .765 .958 r
F
.63399 .51769 m .63324 .51886 L .63324 .51899 L 0 0 .377 r
F
.63834 .51926 m .63326 .51896 L .63325 .51969 L .601 .765 .958 r
F
.62283 .548 m .63512 .54456 L .63495 .54957 L .735 .483 .548 r
F
.62283 .548 m .62301 .54299 L .63512 .54456 L F
.62806 .53517 m .62301 .54299 L .63512 .54456 L .601 .765 .958 r
F
.62789 .5402 m .63495 .54957 L .63601 .54126 L .6 .765 .958 r
F
.62789 .5402 m .62283 .548 L .63495 .54957 L F
.633 .53231 m .62789 .5402 L .63601 .54126 L F
.62944 .52619 m .62806 .53517 L .63317 .52726 L .601 .765 .958 r
F
.63345 .53162 m .62926 .53124 L .633 .53231 L .6 .765 .958 r
F
.63447 .52124 m .6357 .52178 L .63586 .52655 L .862 .563 .481 r
F
.63447 .52124 m .63586 .52655 L .63471 .52605 L F
.6357 .52178 m .63598 .52657 L .63586 .52655 L .755 .473 .507 r
F
.63767 .52207 m .63797 .5269 L .63784 .5269 L .629 .374 .513 r
F
.63558 .52833 m .63343 .52801 L .63345 .53162 L .6 .765 .958 r
F
.63478 .52696 m .63343 .52801 L .63558 .52833 L F
.63834 .51926 m .63317 .51969 L .63359 .52041 L .601 .765 .958 r
F
.63324 .51899 m .63341 .52387 L .63324 .51899 L 0 0 .044 r
F
.63447 .52124 m .63471 .52605 L .63464 .52602 L .862 .563 .481 r
F
.63368 .52057 m .63464 .52602 L .63389 .52542 L .948 .643 .425 r
F
.63817 .52433 m .63342 .52645 L .63343 .52801 L .6 .765 .958 r
F
.6209 .52795 m .62327 .53787 L .62829 .53007 L .602 .764 .957 r
F
.6209 .52795 m .61224 .53471 L .62327 .53787 L F
.62944 .52619 m .62063 .53304 L .62806 .53517 L .601 .765 .958 r
F
.6263 .52464 m .62063 .53304 L .62944 .52619 L F
.61468 .52489 m .61224 .53471 L .6209 .52795 L .602 .764 .957 r
F
.6263 .52464 m .61437 .52997 L .62063 .53304 L .601 .765 .958 r
F
.63342 .52645 m .6238 .52778 L .62612 .52969 L .6 .765 .958 r
F
.63368 .52057 m .63389 .52542 L .63384 .52538 L .948 .643 .425 r
F
.63817 .52433 m .63342 .52547 L .63342 .52645 L .6 .765 .958 r
F
.63342 .52547 m .6238 .52778 L .63342 .52645 L F
.63324 .51899 m .63325 .51982 L .63341 .52465 L 0 0 .044 r
F
.63696 .60006 m .63595 .60097 L .63646 .60335 L .657 .813 .958 r
F
.63595 .60097 m .63381 .60291 L .63596 .60326 L F
.63595 .60097 m .63596 .60326 L .63646 .60335 L F
.62398 .52272 m .61437 .52997 L .6263 .52464 L .601 .765 .958 r
F
.62437 .52765 m .62244 .52563 L .6238 .52778 L .6 .765 .958 r
F
.63817 .52433 m .63269 .52478 L .63191 .52583 L F
.63829 .60028 m .63646 .60335 L .63936 .60337 L .657 .813 .958 r
F
.63696 .60006 m .63646 .60335 L .63829 .60028 L F
.63776 .60283 m .63679 .60246 L .63738 .60318 L F
.6379 .6027 m .63742 .60259 L .63776 .60283 L F
.63742 .60259 m .63679 .60246 L .63776 .60283 L F
.63679 .60246 m .63626 .60276 L .63721 .60311 L F
.63646 .60335 m .63897 .60643 L .63936 .60337 L F
.63646 .60335 m .63463 .6064 L .63897 .60643 L F
.63381 .60291 m .63463 .6064 L .63646 .60335 L F
.63381 .60291 m .63066 .60574 L .63463 .6064 L F
.63738 .60318 m .63421 .60603 L .63687 .60647 L F
.63626 .60276 m .63421 .60603 L .63738 .60318 L F
.63585 .59965 m .63381 .60291 L .63595 .60097 L F
.63594 .59968 m .63595 .60097 L .63696 .60006 L F
.63585 .59965 m .63595 .60097 L .63594 .59968 L F
.63325 .51978 m .63344 .5247 L .63341 .52465 L .972 .694 .284 r
F
.63326 .51896 m .63324 .51899 L .63325 .51969 L .601 .765 .958 r
F
.63324 .51899 m .63341 .52465 L .63341 .52387 L 0 0 .044 r
F
.61468 .52489 m .60292 .53016 L .61224 .53471 L .602 .764 .957 r
F
.61005 .5211 m .60292 .53016 L .61468 .52489 L F
.62398 .52272 m .60971 .52616 L .61437 .52997 L .601 .765 .958 r
F
.62965 .52504 m .62215 .52339 L .62244 .52563 L .6 .765 .958 r
F
.63817 .52433 m .63183 .52396 L .62965 .52504 L F
.63183 .52396 m .62215 .52339 L .62965 .52504 L F
.63832 .60024 m .63696 .60006 L .63829 .60028 L .657 .813 .958 r
F
.63743 .59963 m .63696 .60006 L .63832 .60024 L F
.63464 .52602 m .63837 .59984 L .63719 .59946 L .862 .563 .481 r
F
.63384 .52538 m .63715 .59944 L .63637 .59891 L .948 .643 .425 r
F
.63635 .59888 m .63635 .59888 L .63341 .52465 L .972 .694 .284 r
F
.6362 .59864 m .63594 .59873 L .63658 .59923 L .657 .813 .958 r
F
.63594 .59873 m .63502 .59907 L .63594 .59916 L F
.63594 .59873 m .63594 .59916 L .63658 .59923 L F
.63344 .5247 m .63635 .59888 L .63341 .52465 L .972 .694 .284 r
F
.63635 .59888 m .63635 .59888 L .63341 .52465 L F
.63658 .59923 m .63594 .59916 L .63594 .59959 L .657 .813 .958 r
F
.63705 .59998 m .63585 .59965 L .63696 .60006 L F
.63658 .59923 m .63585 .59965 L .63705 .59998 L F
.63679 .60246 m .63543 .60218 L .63626 .60276 L F
.6362 .59864 m .63518 .59846 L .63502 .59907 L F
.63518 .59846 m .63455 .59836 L .6349 .59888 L F
.63518 .59846 m .6349 .59888 L .63502 .59907 L F
.63585 .59809 m .63537 .59819 L .6362 .59864 L F
.63537 .59819 m .63455 .59836 L .63518 .59846 L F
.63537 .59819 m .63518 .59846 L .6362 .59864 L F
.63357 .52868 m .63635 .59888 L .63594 .59822 L .972 .694 .284 r
F
.63639 .60183 m .63543 .60218 L .63679 .60246 L .657 .813 .958 r
F
.63585 .59809 m .63445 .59757 L .63455 .59836 L F
.63544 .57569 m .63513 .56286 L .63637 .59891 L .972 .694 .284 r
F
.63544 .57569 m .63637 .59891 L .63635 .59888 L F
.63341 .52387 m .63341 .52387 L .63324 .51899 L 0 0 .044 r
F
.63834 .51926 m .63359 .52041 L .63368 .52055 L .601 .765 .958 r
F
.63834 .51926 m .63368 .52055 L .63431 .52106 L F
.63368 .52055 m .63368 .52057 L .63367 .52055 L .972 .694 .284 r
F
.63367 .52055 m .63368 .52057 L .63353 .5203 L F
.63368 .52055 m .63447 .52124 L .63368 .52057 L .948 .643 .425 r
F
.63431 .52106 m .63425 .52109 L .63447 .52119 L .601 .765 .958 r
F
.63446 .52118 m .63447 .52124 L .63368 .52055 L .948 .643 .425 r
F
.63186 .51582 m .62526 .51742 L .63035 .51786 L .602 .764 .957 r
F
.62526 .51742 m .62423 .51766 L .62443 .51783 L F
.62289 .51551 m .61005 .5211 L .62423 .51766 L F
.63213 .5189 m .62315 .51613 L .62234 .51832 L .601 .765 .958 r
F
.63399 .51769 m .63324 .51899 L .634 .51797 L 0 0 .377 r
F
.63324 .51886 m .63324 .51899 L .63324 .51899 L 0 0 .044 r
F
.63383 .51315 m .63324 .51886 L .63399 .51769 L 0 0 .377 r
F
.63312 .51411 m .63324 .51886 L .63383 .51315 L F
.63316 .51575 m .63312 .51534 L .63324 .51886 L F
.63834 .51926 m .63343 .51825 L .63213 .5189 L .601 .765 .958 r
F
.63343 .51825 m .62315 .51613 L .63213 .5189 L F
.63834 .51926 m .63536 .52158 L .63569 .52172 L F
.63834 .51926 m .63431 .52106 L .63536 .52158 L F
.63447 .52119 m .6357 .52178 L .63447 .52124 L .862 .563 .481 r
F
.63568 .52172 m .6357 .52178 L .63447 .52119 L F
.63374 .51831 m .62499 .51414 L .62315 .51613 L .601 .765 .958 r
F
.63547 .5168 m .63399 .51769 L .634 .51797 L .369 .177 .485 r
F
.63834 .51926 m .63442 .51776 L .63374 .51831 L .601 .765 .958 r
F
.63442 .51776 m .634 .51797 L .63374 .51831 L F
.63431 .52106 m .63447 .52119 L .63536 .52158 L F
.63547 .5168 m .634 .51797 L .63537 .51729 L .369 .177 .485 r
F
.63532 .51241 m .63399 .51769 L .63547 .5168 L F
.63392 .5131 m .63399 .51769 L .63532 .51241 L F
.63392 .5131 m .63383 .51315 L .63399 .51769 L F
.63442 .51776 m .62775 .5125 L .62499 .51414 L .601 .765 .958 r
F
.63834 .51926 m .6353 .51732 L .63442 .51776 L F
.6353 .51732 m .62775 .5125 L .63442 .51776 L F
.63547 .5168 m .63537 .51729 L .63548 .51723 L .369 .177 .485 r
F
.63547 .5168 m .63548 .51723 L .63549 .51723 L F
.63312 .51411 m .63312 .51534 L .63316 .51575 L 0 0 .377 r
F
.63312 .51411 m .63308 .51417 L .63312 .51534 L F
.63523 .51728 m .63125 .51132 L .62775 .5125 L .601 .765 .958 r
F
.63834 .51926 m .63636 .51705 L .63523 .51728 L F
.63691 .51641 m .63547 .5168 L .63549 .51723 L .547 .31 .508 r
F
.63691 .51641 m .63549 .51723 L .63692 .51695 L F
.63636 .51705 m .63125 .51132 L .63523 .51728 L .601 .765 .958 r
F
.62263 .52057 m .60971 .52616 L .62398 .52272 L F
.62743 .5237 m .62296 .5212 L .62215 .52339 L .6 .765 .958 r
F
.634 .51797 m .63324 .51899 L .63341 .52382 L 0 0 .377 r
F
.63325 .52404 m .63134 .52292 L .62743 .5237 L .6 .765 .958 r
F
.63817 .52433 m .63371 .52341 L .63325 .52404 L F
.634 .51797 m .63341 .52382 L .63412 .52287 L 0 0 .377 r
F
.63324 .51899 m .63341 .52387 L .63341 .52382 L 0 0 .044 r
F
.63371 .52341 m .63134 .52292 L .63325 .52404 L .6 .765 .958 r
F
.63134 .52292 m .62296 .5212 L .62743 .5237 L F
.63569 .52172 m .63767 .52207 L .6357 .52178 L .755 .473 .507 r
F
.63767 .52207 m .63767 .52207 L .63569 .52172 L F
.63834 .51926 m .63569 .52172 L .63664 .52189 L .601 .765 .958 r
F
.63569 .52172 m .6357 .52178 L .63568 .52172 L .862 .563 .481 r
F
.63636 .51705 m .63523 .51068 L .63125 .51132 L .601 .765 .958 r
F
.63831 .51631 m .63691 .51641 L .63693 .51694 L .65 .39 .512 r
F
.63834 .51926 m .63749 .51693 L .63636 .51705 L .601 .765 .958 r
F
.63749 .51693 m .63693 .51694 L .63636 .51705 L F
.63341 .52387 m .63593 .59818 L .63341 .52382 L 0 0 .044 r
F
.63593 .59818 m .63593 .59818 L .63341 .52382 L F
.63341 .52382 m .63593 .59818 L .63593 .59737 L F
.63341 .52387 m .63593 .59818 L .63341 .52387 L F
.63593 .59818 m .63593 .59818 L .63341 .52387 L F
.63341 .52387 m .63341 .52465 L .63593 .59822 L F
.63341 .52387 m .63593 .59822 L .63593 .59818 L F
.63593 .59807 m .63548 .5975 L .63585 .59809 L .657 .813 .958 r
F
.63471 .52605 m .63837 .59984 L .63464 .52602 L .862 .563 .481 r
F
.63829 .60028 m .63936 .60337 L .63974 .6003 L .657 .813 .958 r
F
.6394 .60957 m .63897 .60648 L .64341 .60589 L .66 .412 .534 r
F
.63936 .60337 m .63897 .60643 L .64339 .60584 L .657 .813 .958 r
F
.63871 .6034 m .63687 .60647 L .63979 .6065 L F
.63738 .60318 m .63687 .60647 L .63871 .6034 L F
.63974 .60028 m .63829 .60028 L .63974 .6003 L F
.63852 .59989 m .63829 .60028 L .63974 .60028 L F
.63936 .60337 m .64339 .60584 L .6423 .60298 L F
.63974 .6003 m .63936 .60337 L .6423 .60298 L F
.64017 .60341 m .63979 .6065 L .64276 .6061 L F
.63871 .6034 m .63979 .6065 L .64017 .60341 L F
.64023 .60301 m .63871 .6034 L .64017 .60341 L F
.63843 .59986 m .63999 .60299 L .63854 .60291 L .755 .473 .507 r
F
.63899 .60293 m .63871 .6034 L .64023 .60301 L .657 .813 .958 r
F
.63978 .59994 m .63852 .59989 L .63974 .60028 L F
.63853 .59987 m .63852 .59989 L .63978 .59994 L F
.63974 .6003 m .6423 .60298 L .64122 .6001 L F
.64017 .60341 m .64276 .6061 L .64166 .60321 L F
.63817 .52433 m .63478 .52696 L .63558 .52833 L .6 .765 .958 r
F
.63645 .52699 m .63558 .52833 L .63751 .52727 L F
.63558 .52833 m .63597 .52899 L .63751 .52727 L F
.63586 .52655 m .64034 .59997 L .63843 .59986 L .755 .473 .507 r
F
.64119 .60002 m .63974 .6003 L .64122 .6001 L .657 .813 .958 r
F
.63598 .52657 m .64035 .59997 L .63586 .52655 L .755 .473 .507 r
F
.64035 .59997 m .64034 .59997 L .63586 .52655 L F
.63978 .59994 m .63974 .6003 L .64119 .60002 L .657 .813 .958 r
F
.64385 .60898 m .64341 .60589 L .64762 .6047 L .581 .358 .541 r
F
.6423 .60298 m .64339 .60584 L .64759 .60467 L .657 .813 .958 r
F
.64166 .60321 m .64276 .6061 L .64557 .60531 L F
.6423 .60298 m .64759 .60467 L .64511 .60219 L F
.64166 .60321 m .64557 .60531 L .64307 .60281 L F
.64035 .59997 m .64053 .60302 L .64034 .59997 L .755 .473 .507 r
F
.64053 .60302 m .6406 .6042 L .64053 .60302 L F
.64053 .60302 m .64053 .60302 L .64034 .59997 L F
.64161 .60309 m .64017 .60341 L .64166 .60321 L .657 .813 .958 r
F
.64153 .60285 m .64104 .60305 L .64161 .60309 L F
.64104 .60305 m .64017 .60341 L .64161 .60309 L F
.64045 .59998 m .64201 .60277 L .64056 .60302 L .629 .374 .513 r
F
.64034 .59997 m .64053 .60302 L .63843 .59986 L .755 .473 .507 r
F
.64023 .60301 m .64022 .60309 L .64056 .60302 L .657 .813 .958 r
F
.64053 .60302 m .6406 .6042 L .63999 .60299 L .755 .473 .507 r
F
.64053 .60302 m .63999 .60299 L .63843 .59986 L F
.6368 .52697 m .63751 .52727 L .63784 .5269 L .6 .765 .958 r
F
.63645 .52699 m .63751 .52727 L .6368 .52697 L F
.63778 .52739 m .63716 .52803 L .63765 .52843 L F
.63784 .5269 m .63751 .52728 L .63778 .52739 L F
.63817 .52433 m .63645 .52699 L .63784 .5269 L F
.63598 .52657 m .63784 .5269 L .64045 .59998 L .755 .473 .507 r
F
.63598 .52657 m .64045 .59998 L .64037 .59998 L F
.63598 .52657 m .64056 .60302 L .64053 .60302 L F
.63784 .5269 m .64241 .59963 L .64045 .59998 L .629 .374 .513 r
F
.63797 .5269 m .64242 .59963 L .63784 .5269 L F
.64128 .52636 m .64481 .59843 L .64128 .52636 L .328 .148 .478 r
F
.64277 .60093 m .6423 .60298 L .64511 .60219 L .657 .813 .958 r
F
.64186 .60045 m .64209 .60176 L .64277 .60093 L F
.64209 .60176 m .6423 .60298 L .64277 .60093 L F
.64511 .60219 m .64759 .60467 L .65128 .60298 L F
.64511 .60219 m .65128 .60298 L .64757 .60106 L F
.64208 .6003 m .64511 .60219 L .64275 .59984 L F
.64127 .60013 m .64186 .60045 L .64159 .59999 L F
.64186 .60045 m .64511 .60219 L .64208 .6003 L F
.64186 .60045 m .64208 .6003 L .64159 .59999 L F
.64128 .52636 m .64481 .59843 L .64122 .5264 L .328 .148 .478 r
F
.63997 .52676 m .63996 .52676 L .63971 .52195 L .492 .27 .504 r
F
.64105 .52156 m .64128 .52636 L .64105 .52156 L .328 .148 .478 r
F
.64128 .52636 m .64128 .52636 L .64105 .52156 L F
.63817 .52433 m .64217 .52586 L .64308 .52534 L .6 .765 .958 r
F
.64217 .52586 m .64397 .52655 L .64308 .52534 L F
.66479 .52433 m .67783 .52935 L .68352 .52353 L .602 .764 .957 r
F
.65927 .52753 m .67783 .52935 L .66479 .52433 L F
.6516 .52436 m .6648 .52942 L .66858 .52551 L .601 .765 .958 r
F
.64883 .52597 m .6648 .52942 L .6516 .52436 L F
.64311 .52462 m .65334 .52746 L .65419 .52528 L .6 .765 .958 r
F
.642 .52102 m .6426 .52035 L .64278 .52519 L .067 0 .41 r
F
.63817 .52433 m .64347 .52542 L .64311 .52462 L .6 .765 .958 r
F
.64347 .52542 m .65334 .52746 L .64311 .52462 L F
.6428 .51901 m .64233 .51844 L .64281 .51953 L .944 .685 .22 r
F
.6428 .51901 m .64281 .51953 L .64282 .51953 L F
.65168 .51929 m .66856 .52043 L .65355 .51733 L .602 .764 .957 r
F
.64295 .51888 m .65433 .52021 L .65409 .51796 L .601 .765 .958 r
F
.63834 .51926 m .64398 .5196 L .64295 .51888 L F
.64398 .5196 m .65433 .52021 L .64295 .51888 L F
.64221 .52581 m .64545 .59768 L .64221 .52582 L .067 0 .41 r
F
.64545 .59768 m .64545 .59768 L .64221 .52582 L F
.6448 .6003 m .64511 .60219 L .64757 .60106 L .657 .813 .958 r
F
.64326 .60034 m .64511 .60219 L .64357 .59996 L F
.64221 .52582 m .64545 .59768 L .64217 .52586 L .067 0 .41 r
F
.64496 .59967 m .64757 .60106 L .64768 .60099 L .657 .813 .958 r
F
.64413 .59927 m .64495 .5997 L .64496 .59967 L F
.64495 .5997 m .64757 .60106 L .64496 .59967 L F
.64413 .59928 m .64495 .59971 L .64413 .59927 L F
.64495 .59971 m .64757 .60106 L .64495 .5997 L F
.64495 .59971 m .64495 .5997 L .64413 .59927 L F
.64279 .52514 m .64569 .59682 L .64278 .52519 L 0 0 .209 r
F
.64422 .59917 m .64768 .60099 L .64695 .59943 L .657 .813 .958 r
F
.64385 .59914 m .64413 .59927 L .64422 .59917 L F
.64413 .59927 m .64768 .60099 L .64422 .59917 L F
.64221 .52581 m .64278 .52519 L .64548 .59764 L .067 0 .41 r
F
.6436 .59926 m .64757 .60106 L .64385 .59914 L .657 .813 .958 r
F
.64262 .5997 m .64285 .59977 L .6436 .59926 L F
.64285 .59977 m .64757 .60106 L .6436 .59926 L F
.64132 .52634 m .64131 .52637 L .64135 .52636 L .6 .765 .958 r
F
.64128 .52636 m .64217 .52586 L .64486 .59839 L .328 .148 .478 r
F
.64484 .59844 m .64672 .59894 L .64652 .59853 L .657 .813 .958 r
F
.64644 .59836 m .65035 .59872 L .64945 .59819 L F
.64484 .59844 m .64652 .59853 L .64644 .59836 L F
.64652 .59853 m .65035 .59872 L .64644 .59836 L F
.64221 .52581 m .64548 .59764 L .64545 .59768 L .067 0 .41 r
F
.64569 .59682 m .64569 .59682 L .64278 .52519 L 0 0 .209 r
F
.64278 .52519 m .64569 .59682 L .64548 .59764 L F
.64545 .59768 m .64544 .59768 L .64217 .52586 L .067 0 .41 r
F
.6516 .52436 m .66858 .52551 L .65348 .52239 L .601 .765 .958 r
F
.6434 .5239 m .65419 .52528 L .65395 .52303 L .6 .765 .958 r
F
.64281 .51953 m .64296 .5243 L .64282 .51953 L .944 .685 .22 r
F
.64296 .5243 m .64297 .5243 L .64282 .51953 L F
.64282 .51953 m .64297 .5243 L .643 .52437 L F
.64281 .51953 m .64251 .52328 L .64296 .5243 L F
.63817 .52433 m .64456 .52471 L .6434 .5239 L .6 .765 .958 r
F
.64456 .52471 m .65419 .52528 L .6434 .5239 L F
.64128 .52636 m .64486 .59839 L .64481 .59843 L .328 .148 .478 r
F
.64481 .59843 m .6448 .59843 L .64122 .5264 L F
.64122 .5264 m .6448 .59843 L .64389 .59905 L F
.64217 .52586 m .64544 .59768 L .64486 .59839 L .067 0 .41 r
F
.64481 .59843 m .64481 .59843 L .64128 .52636 L .328 .148 .478 r
F
.64231 .51782 m .64232 .51844 L .64233 .51844 L .931 .625 .44 r
F
.65355 .51733 m .66856 .52043 L .67029 .51609 L .602 .764 .957 r
F
.65355 .51733 m .67029 .51609 L .6544 .51515 L F
.64218 .51834 m .65409 .51796 L .65278 .51578 L .601 .765 .958 r
F
.63834 .51926 m .64295 .51888 L .64218 .51834 L F
.64295 .51888 m .65409 .51796 L .64218 .51834 L F
.64231 .51782 m .64102 .51689 L .64105 .51755 L .931 .625 .44 r
F
.64198 .52071 m .642 .52102 L .64199 .52102 L .067 0 .41 r
F
.63834 .51926 m .64152 .5213 L .64199 .52102 L .601 .765 .958 r
F
.63834 .51926 m .64199 .52102 L .64223 .52076 L F
.64104 .52135 m .64199 .52102 L .64109 .52154 L .328 .148 .478 r
F
.64232 .51844 m .64122 .52239 L .64242 .52322 L .931 .625 .44 r
F
.64233 .51844 m .64241 .52244 L .64248 .52242 L F
.64241 .52244 m .64243 .52323 L .64248 .52242 L F
.64248 .52242 m .64243 .52323 L .64251 .52328 L F
.63817 .52433 m .64252 .52329 L .64174 .52274 L .6 .765 .958 r
F
.64385 .59914 m .64413 .59928 L .64413 .59927 L .657 .813 .958 r
F
.64357 .59996 m .64453 .60136 L .6448 .6003 L F
.64453 .60136 m .64511 .60219 L .6448 .6003 L F
.64279 .52514 m .64297 .52447 L .64366 .5464 L 0 0 .209 r
F
.64297 .52447 m .643 .52437 L .64366 .5464 L F
.64366 .5464 m .643 .52437 L .6457 .59678 L F
.64279 .52514 m .6457 .59678 L .64569 .59682 L F
.64232 .51844 m .64242 .52322 L .64233 .51844 L .931 .625 .44 r
F
.63817 .52433 m .6434 .5239 L .64252 .52329 L .6 .765 .958 r
F
.64385 .59914 m .64695 .59943 L .64517 .59853 L .657 .813 .958 r
F
.64385 .59914 m .64517 .59853 L .64408 .59898 L F
.64408 .59898 m .64517 .59853 L .64484 .59844 L F
.64432 .60225 m .64806 .60418 L .65003 .60278 L F
.6443 .60226 m .64806 .60418 L .64432 .60225 L F
.64307 .60281 m .6437 .60299 L .6443 .60226 L F
.6437 .60299 m .64806 .60418 L .6443 .60226 L F
.64432 .60225 m .64517 .60233 L .6453 .60155 L F
.64517 .60233 m .65003 .60278 L .64537 .60157 L F
.64517 .60233 m .64537 .60157 L .6453 .60155 L F
.64757 .60106 m .65128 .60298 L .65423 .6009 L F
.6453 .60155 m .65003 .60278 L .65137 .60122 L F
.64695 .59943 m .64768 .60099 L .64954 .59968 L F
.64757 .60106 m .65423 .6009 L .64954 .59968 L F
.6453 .60155 m .65137 .60122 L .64597 .60077 L F
.64484 .59844 m .65086 .59812 L .6455 .59766 L F
.64486 .59839 m .64539 .60092 L .64497 .60144 L .067 0 .41 r
F
.64595 .60076 m .6453 .60155 L .64597 .60077 L .657 .813 .958 r
F
.6448 .59843 m .64495 .60145 L .64389 .59905 L .328 .148 .478 r
F
.64495 .60145 m .64466 .60165 L .64389 .59905 L F
.64307 .60281 m .64557 .60531 L .64806 .60418 L .657 .813 .958 r
F
.63988 .52678 m .64382 .59909 L .64253 .59961 L .492 .27 .504 r
F
.64242 .59963 m .64241 .59963 L .63784 .5269 L .629 .374 .513 r
F
.63797 .5269 m .63798 .5269 L .64242 .59963 L F
.63797 .5269 m .64242 .59963 L .64242 .59963 L F
.64253 .59961 m .64262 .5997 L .64301 .59953 L .657 .813 .958 r
F
.64159 .59999 m .64208 .6003 L .64262 .5997 L F
.64208 .6003 m .64275 .59984 L .64262 .5997 L F
.64253 .59961 m .64119 .60002 L .64262 .5997 L F
.64113 .59986 m .64119 .60002 L .64253 .59961 L F
.64119 .60002 m .64143 .60004 L .64262 .5997 L F
.63908 .52683 m .63899 .52711 L .63919 .52714 L .6 .765 .958 r
F
.63817 .52433 m .63908 .52683 L .64027 .52667 L F
.63908 .52683 m .63914 .527 L .63988 .52678 L F
.63908 .52683 m .63988 .52678 L .64027 .52667 L F
.64287 .60261 m .64166 .60321 L .64307 .60281 L .657 .813 .958 r
F
.63798 .5269 m .63988 .52678 L .64264 .60266 L .629 .374 .513 r
F
.63798 .5269 m .64264 .60266 L .64261 .60266 L F
.64264 .60266 m .64166 .60321 L .64287 .60261 L .657 .813 .958 r
F
.64153 .60285 m .64161 .60307 L .64264 .60266 L F
.64161 .60307 m .64166 .60321 L .64264 .60266 L F
.64264 .60266 m .64406 .60349 L .64269 .60398 L .492 .27 .504 r
F
.64253 .59961 m .64358 .60227 L .64264 .60266 L F
.64358 .60227 m .64406 .60349 L .64264 .60266 L F
.64242 .59963 m .64242 .59963 L .64261 .60266 L .629 .374 .513 r
F
.64261 .60266 m .64261 .60266 L .64269 .60398 L F
.64242 .59963 m .64261 .60266 L .64261 .60266 L F
.64382 .59908 m .64389 .59905 L .64401 .6021 L .492 .27 .504 r
F
.64398 .60211 m .64401 .6021 L .64406 .60349 L F
.64382 .59908 m .64401 .6021 L .64398 .60211 L F
.64401 .6021 m .64502 .60287 L .64406 .60349 L .328 .148 .478 r
F
.64389 .59905 m .64466 .60165 L .64401 .6021 L F
.64402 .60209 m .644 .6021 L .64432 .60225 L .657 .813 .958 r
F
.64466 .60165 m .64502 .60287 L .64401 .6021 L .328 .148 .478 r
F
.644 .6021 m .64287 .60261 L .64348 .60246 L .657 .813 .958 r
F
.644 .6021 m .64348 .60246 L .64432 .60225 L F
.64283 .60258 m .64287 .60261 L .64402 .60209 L F
.64287 .60261 m .64307 .60281 L .64392 .60243 L F
.64287 .60261 m .64392 .60243 L .64432 .60225 L F
.64012 .59721 m .64253 .59961 L .64253 .59961 L F
.64378 .5991 m .64253 .59961 L .64385 .59914 L F
.64012 .59721 m .64253 .59961 L .64378 .5991 L F
.63996 .52676 m .64382 .59908 L .63988 .52678 L .492 .27 .504 r
F
.64382 .59908 m .64382 .59909 L .63988 .52678 L F
.64027 .52667 m .64043 .52685 L .64122 .5264 L .6 .765 .958 r
F
.64027 .52667 m .64016 .52677 L .64034 .52676 L F
.63997 .52676 m .64122 .5264 L .64389 .59905 L .492 .27 .504 r
F
.63997 .52676 m .64389 .59905 L .64382 .59908 L F
.63997 .52676 m .64382 .59908 L .63996 .52676 L F
.64382 .59908 m .64382 .59908 L .63996 .52676 L F
.64012 .59721 m .64385 .59914 L .64484 .59844 L .657 .813 .958 r
F
.64382 .59908 m .64398 .60211 L .64382 .59909 L .492 .27 .504 r
F
.64398 .60211 m .64398 .60211 L .64382 .59909 L F
.64253 .59961 m .64301 .59953 L .64385 .59914 L .657 .813 .958 r
F
.64262 .5997 m .64326 .60034 L .64357 .59996 L F
.64382 .59909 m .64398 .60211 L .64253 .59961 L .492 .27 .504 r
F
.64398 .60211 m .64406 .60349 L .64358 .60227 L F
.64398 .60211 m .64358 .60227 L .64253 .59961 L F
.64481 .59843 m .64486 .59839 L .64497 .60144 L .328 .148 .478 r
F
.64496 .60145 m .64497 .60144 L .64502 .60287 L F
.64481 .59843 m .64497 .60144 L .64496 .60145 L F
.64494 .60146 m .64402 .60209 L .6453 .60155 L .657 .813 .958 r
F
.64148 .60071 m .6423 .60298 L .64186 .60045 L F
.64123 .60014 m .6423 .60298 L .64127 .60013 L F
.64382 .59908 m .64406 .60349 L .64382 .59908 L .492 .27 .504 r
F
.64242 .59963 m .64269 .60398 L .64241 .59963 L .629 .374 .513 r
F
.64122 .6001 m .64127 .60013 L .64159 .59999 L .657 .813 .958 r
F
.64127 .60013 m .64148 .60071 L .64186 .60045 L F
.64122 .6001 m .64123 .60014 L .64127 .60013 L F
.64119 .60002 m .64122 .6001 L .64143 .60004 L F
.64113 .59986 m .64045 .59998 L .64119 .60002 L F
.64241 .59963 m .64269 .60398 L .64045 .59998 L .629 .374 .513 r
F
.64056 .60031 m .64401 .60209 L .64494 .60146 L .657 .813 .958 r
F
.64401 .60209 m .64402 .60209 L .64494 .60146 L F
.64402 .60209 m .64432 .60225 L .64523 .6016 L F
.64402 .60209 m .64523 .6016 L .6453 .60155 L F
.64398 .60211 m .64406 .60349 L .64398 .60211 L .492 .27 .504 r
F
.64056 .60031 m .64283 .60258 L .64402 .60209 L .657 .813 .958 r
F
.64056 .60031 m .64153 .60285 L .64287 .60261 L F
.64261 .60266 m .64264 .60266 L .64269 .60398 L .629 .374 .513 r
F
.64695 .59943 m .64672 .59894 L .64517 .59853 L .657 .813 .958 r
F
.64545 .59768 m .64548 .59764 L .64559 .60068 L .067 0 .41 r
F
.64494 .60146 m .6453 .60155 L .6454 .60143 L .657 .813 .958 r
F
.64549 .60108 m .6454 .60143 L .64595 .60076 L F
.64494 .60146 m .6454 .60143 L .64549 .60108 L F
.6455 .59766 m .65086 .59812 L .65146 .59649 L F
.6455 .59766 m .65146 .59649 L .64579 .59685 L F
.64012 .59721 m .6455 .59766 L .64579 .59685 L F
.643 .52437 m .64523 .59578 L .6457 .59678 L .944 .685 .22 r
F
.64012 .59721 m .64579 .59685 L .6457 .59606 L .657 .813 .958 r
F
.64569 .59682 m .64581 .59984 L .64569 .59682 L 0 0 .209 r
F
.64545 .59768 m .64559 .60068 L .64558 .6007 L .067 0 .41 r
F
.64548 .59764 m .64574 .60009 L .64559 .60068 L 0 0 .209 r
F
.64569 .59682 m .64581 .59984 L .64548 .59764 L F
.64581 .59984 m .64574 .60009 L .64548 .59764 L F
.64545 .59768 m .64558 .6007 L .64544 .59768 L .067 0 .41 r
F
.64558 .6007 m .64558 .6007 L .64544 .59768 L F
.64481 .59843 m .64496 .60145 L .6448 .59843 L .328 .148 .478 r
F
.64496 .60145 m .64502 .60287 L .64495 .60145 L F
.64496 .60145 m .64495 .60145 L .6448 .59843 L F
.64569 .59682 m .6457 .59678 L .64581 .59982 L 0 0 .209 r
F
.64577 .59998 m .64581 .60041 L .64588 .59997 L .657 .813 .958 r
F
.64569 .59682 m .64581 .59982 L .64581 .59984 L 0 0 .209 r
F
.64581 .59984 m .64581 .59984 L .64569 .59682 L F
.64545 .59768 m .64558 .6007 L .64545 .59768 L .067 0 .41 r
F
.64558 .6007 m .64565 .60211 L .64558 .6007 L F
.64558 .6007 m .64558 .6007 L .64545 .59768 L F
.64555 .60073 m .64558 .60073 L .64559 .60068 L .657 .813 .958 r
F
.64555 .60073 m .64497 .60144 L .64595 .60076 L F
.64544 .59768 m .64565 .60211 L .64486 .59839 L .067 0 .41 r
F
.64481 .59843 m .64502 .60287 L .64481 .59843 L .328 .148 .478 r
F
.64056 .60031 m .64555 .60073 L .64566 .60041 L .657 .813 .958 r
F
.64555 .60073 m .64559 .60068 L .64566 .60041 L F
.64056 .60031 m .64588 .59997 L .64556 .59928 L F
.64581 .59984 m .64581 .59982 L .64586 .60121 L 0 0 .209 r
F
.64056 .60031 m .64566 .60041 L .64577 .59998 L .657 .813 .958 r
F
.64566 .60041 m .64581 .60041 L .64577 .59998 L F
.64581 .59984 m .64586 .60121 L .64574 .60009 L 0 0 .209 r
F
.64558 .60073 m .64597 .60077 L .64566 .60041 L .657 .813 .958 r
F
.64581 .59984 m .64586 .60121 L .64581 .59984 L 0 0 .209 r
F
.64574 .60009 m .64586 .60121 L .64559 .60068 L F
.64581 .59982 m .64536 .60005 L .64586 .60121 L .944 .685 .22 r
F
.6457 .59678 m .64546 .59908 L .64581 .59982 L F
.64012 .59721 m .64484 .59844 L .6455 .59766 L .657 .813 .958 r
F
.64012 .59721 m .6457 .59606 L .64565 .59599 L F
.64296 .5243 m .64251 .52328 L .6452 .59573 L .944 .685 .22 r
F
.64296 .5243 m .6452 .59573 L .64523 .59578 L F
.64251 .52328 m .64396 .595 L .6452 .59573 L .931 .625 .44 r
F
.64297 .5243 m .64523 .59578 L .643 .52437 L .944 .685 .22 r
F
.64523 .59578 m .64523 .59578 L .643 .52437 L F
.64296 .5243 m .64523 .59578 L .64297 .5243 L F
.64523 .59578 m .64523 .59578 L .64297 .5243 L F
.64482 .5955 m .64565 .59599 L .64523 .59535 L .657 .813 .958 r
F
.64012 .59721 m .64565 .59599 L .64482 .5955 L F
.64012 .59721 m .64113 .59986 L .64253 .59961 L F
.64056 .60031 m .64512 .59866 L .6443 .59818 L F
.64523 .59578 m .64532 .59879 L .6457 .59678 L .944 .685 .22 r
F
.64056 .60031 m .64556 .59928 L .64512 .59866 L .657 .813 .958 r
F
.64556 .59928 m .64603 .59919 L .64532 .59877 L F
.64556 .59928 m .64532 .59877 L .64512 .59866 L F
.64523 .59578 m .64532 .59879 L .64523 .59578 L .944 .685 .22 r
F
.64532 .59879 m .64536 .60005 L .64532 .59879 L F
.64532 .59879 m .64532 .59879 L .64523 .59578 L F
.64532 .59879 m .64536 .60005 L .64546 .59908 L F
.64532 .59879 m .64546 .59908 L .6457 .59678 L F
.64524 .59861 m .64617 .59916 L .6457 .59844 L .657 .813 .958 r
F
.6452 .59573 m .64436 .59822 L .64532 .59877 L .931 .625 .44 r
F
.64512 .59866 m .6453 .59875 L .64524 .59861 L .657 .813 .958 r
F
.6453 .59875 m .64617 .59916 L .64524 .59861 L F
.64603 .59919 m .64617 .59916 L .64512 .59866 L F
.64532 .59877 m .64405 .59913 L .64536 .60005 L .931 .625 .44 r
F
.64436 .59822 m .64405 .59913 L .64532 .59877 L F
.6443 .59818 m .64524 .59861 L .64488 .59786 L .657 .813 .958 r
F
.64512 .59866 m .64524 .59861 L .6443 .59818 L F
.64398 .59501 m .64523 .59535 L .64441 .59477 L F
.64012 .59721 m .64482 .5955 L .64398 .59501 L F
.64482 .5955 m .64523 .59535 L .64398 .59501 L F
.64242 .52322 m .64396 .595 L .64243 .52323 L .931 .625 .44 r
F
.64396 .595 m .64402 .59802 L .64396 .595 L F
.64402 .59802 m .64402 .59802 L .64396 .595 L F
.64401 .59753 m .64401 .59753 L .64396 .595 L F
.64402 .59802 m .64401 .59753 L .64401 .59753 L F
.64402 .59802 m .64402 .59802 L .64401 .59753 L F
.64012 .59721 m .64045 .59998 L .64113 .59986 L .657 .813 .958 r
F
.64056 .60031 m .6443 .59818 L .64401 .59801 L F
.63817 .52433 m .64027 .52667 L .64132 .52634 L .6 .765 .958 r
F
.64027 .52667 m .64122 .5264 L .64132 .52634 L F
.63817 .52433 m .64158 .52651 L .64217 .52586 L F
.63834 .51926 m .64061 .52181 L .64152 .5213 L .601 .765 .958 r
F
.64102 .51689 m .64104 .51754 L .64105 .51755 L .822 .528 .492 r
F
.64231 .51782 m .64105 .51755 L .64232 .51844 L .931 .625 .44 r
F
.64069 .51743 m .65047 .51384 L .64733 .51227 L .601 .765 .958 r
F
.63834 .51926 m .6417 .51776 L .64069 .51743 L F
.6417 .51776 m .65047 .51384 L .64069 .51743 L F
.64102 .51689 m .63968 .51646 L .6397 .5171 L .822 .528 .492 r
F
.63834 .51926 m .64069 .51743 L .63973 .51711 L .601 .765 .958 r
F
.64056 .60031 m .64401 .59801 L .64328 .59786 L .657 .813 .958 r
F
.64102 .51689 m .6397 .5171 L .64104 .51754 L .822 .528 .492 r
F
.63834 .51926 m .63973 .51711 L .63863 .51695 L .601 .765 .958 r
F
.63817 .52433 m .63784 .5269 L .63908 .52683 L .6 .765 .958 r
F
.63968 .51646 m .63831 .51631 L .63833 .51691 L .735 .457 .508 r
F
.63834 .51926 m .63863 .51695 L .63833 .51691 L .601 .765 .958 r
F
.63831 .51631 m .63693 .51694 L .63832 .51691 L .65 .39 .512 r
F
.63749 .51693 m .63833 .51691 L .63744 .51679 L .601 .765 .958 r
F
.63834 .51926 m .63833 .51691 L .63749 .51693 L F
.64012 .59721 m .63978 .59994 L .64045 .59998 L .657 .813 .958 r
F
.64012 .59721 m .63853 .59987 L .63978 .59994 L F
.63471 .52605 m .63586 .52655 L .63843 .59986 L .862 .563 .481 r
F
.63471 .52605 m .63843 .59986 L .63837 .59984 L F
.63837 .59984 m .63837 .59984 L .63464 .52602 L F
.63677 .59918 m .63658 .59923 L .63661 .59928 L .657 .813 .958 r
F
.63389 .52542 m .63715 .59944 L .63384 .52538 L .948 .643 .425 r
F
.63715 .59944 m .63715 .59944 L .63384 .52538 L F
.63389 .52542 m .63464 .52602 L .63719 .59946 L F
.63715 .59944 m .63719 .59946 L .63729 .60251 L F
.63715 .59944 m .63729 .60251 L .63728 .6025 L F
.63715 .59944 m .63728 .6025 L .63715 .59944 L F
.63728 .6025 m .63732 .60339 L .63728 .6025 L F
.63728 .6025 m .63728 .6025 L .63715 .59944 L F
.64037 .59998 m .64045 .59998 L .64056 .60302 L .755 .473 .507 r
F
.63837 .59984 m .63843 .59986 L .63854 .60291 L .862 .563 .481 r
F
.63893 .60303 m .63738 .60318 L .63871 .6034 L .657 .813 .958 r
F
.63852 .6029 m .63854 .60291 L .63857 .60391 L .862 .563 .481 r
F
.63837 .59984 m .63854 .60291 L .63852 .6029 L F
.6379 .6027 m .63738 .60318 L .63893 .60303 L .657 .813 .958 r
F
.63837 .59984 m .63857 .60391 L .63837 .59984 L .862 .563 .481 r
F
.63719 .59946 m .63852 .6029 L .63729 .60251 L F
.63751 .59957 m .63719 .59946 L .63743 .59963 L .657 .813 .958 r
F
.63852 .59989 m .63743 .59963 L .63832 .60024 L F
.63751 .59957 m .63743 .59963 L .63852 .59989 L F
.63837 .59984 m .63852 .6029 L .63719 .59946 L .862 .563 .481 r
F
.64056 .60031 m .6379 .6027 L .63893 .60303 L .657 .813 .958 r
F
.63637 .59891 m .63728 .6025 L .63648 .60196 L .948 .643 .425 r
F
.63743 .59963 m .63661 .59928 L .63705 .59998 L .657 .813 .958 r
F
.63719 .59946 m .63661 .59928 L .63743 .59963 L F
.63672 .59915 m .63658 .59923 L .63677 .59918 L F
.63715 .59944 m .63728 .6025 L .63637 .59891 L .948 .643 .425 r
F
.64056 .60031 m .63702 .60233 L .6379 .6027 L .657 .813 .958 r
F
.63702 .60233 m .63691 .60239 L .63729 .60251 L F
.63702 .60233 m .63729 .60251 L .6379 .6027 L F
.63635 .59888 m .63637 .59891 L .63648 .60196 L .972 .694 .284 r
F
.63647 .60195 m .63648 .60196 L .6365 .60273 L F
.63635 .59888 m .63648 .60196 L .63647 .60195 L F
.63594 .59822 m .63647 .60195 L .63604 .60127 L F
.63593 .59818 m .63604 .60126 L .63593 .59818 L 0 0 .044 r
F
.63602 .60124 m .63495 .60146 L .63604 .60174 L .657 .813 .958 r
F
.63604 .60127 m .63604 .60174 L .63639 .60183 L F
.63602 .60124 m .63604 .60174 L .63604 .60127 L F
.63389 .52542 m .63719 .59946 L .63715 .59944 L .948 .643 .425 r
F
.64012 .59721 m .63585 .59809 L .6362 .59864 L .657 .813 .958 r
F
.63344 .5247 m .63513 .56286 L .63544 .57569 L .972 .694 .284 r
F
.63344 .5247 m .63384 .52538 L .63513 .56286 L F
.62688 .522 m .62481 .51922 L .62296 .5212 L .6 .765 .958 r
F
.634 .51797 m .63412 .52287 L .63417 .52281 L 0 0 .377 r
F
.634 .51797 m .63412 .52287 L .634 .51797 L F
.63817 .52433 m .63342 .52251 L .63134 .52292 L .6 .765 .958 r
F
.63412 .52287 m .63596 .59732 L .63417 .52281 L 0 0 .377 r
F
.63586 .59748 m .63474 .59676 L .63445 .59757 L .657 .813 .958 r
F
.64012 .59721 m .63626 .59688 L .63586 .59748 L F
.63596 .59732 m .63597 .59732 L .63417 .52281 L 0 0 .377 r
F
.63417 .52281 m .63597 .59732 L .6367 .59624 L F
.63585 .59965 m .63158 .60208 L .63381 .60291 L .657 .813 .958 r
F
.63538 .60138 m .63486 .60067 L .63495 .60146 L F
.63593 .59737 m .63604 .60111 L .63604 .60042 L 0 0 .044 r
F
.63604 .60124 m .63591 .60061 L .63538 .60138 L .657 .813 .958 r
F
.63635 .59888 m .63647 .60195 L .63594 .59822 L .972 .694 .284 r
F
.63642 .60053 m .63647 .60195 L .63642 .60053 L F
.63647 .60195 m .63647 .60195 L .63642 .60053 L F
.64056 .60031 m .63604 .6006 L .63604 .60124 L .657 .813 .958 r
F
.63604 .6006 m .63591 .60061 L .63604 .60124 L F
.63591 .60061 m .63486 .60067 L .63538 .60138 L F
.64012 .59721 m .63593 .59747 L .63593 .59807 L F
.63412 .52287 m .63341 .52382 L .63593 .59737 L 0 0 .377 r
F
.63412 .52287 m .63593 .59737 L .63596 .59733 L F
.63596 .59732 m .63604 .60042 L .63604 .60041 L F
.63412 .52287 m .63596 .59733 L .63596 .59732 L F
.63596 .59733 m .63604 .60042 L .63596 .59732 L F
.63666 .5963 m .63638 .59527 L .6354 .59597 L .657 .813 .958 r
F
.63272 .51893 m .62234 .51832 L .63317 .51969 L .601 .765 .958 r
F
.63342 .52251 m .62757 .51758 L .62481 .51922 L .6 .765 .958 r
F
.63548 .51723 m .63417 .52281 L .63556 .52212 L .369 .177 .485 r
F
.63537 .51729 m .63417 .52281 L .63548 .51723 L F
.63537 .51729 m .634 .51797 L .63417 .52281 L F
.63817 .52433 m .63486 .52222 L .63342 .52251 L .6 .765 .958 r
F
.63486 .52222 m .62757 .51758 L .63342 .52251 L F
.63692 .51695 m .637 .5218 L .63693 .51694 L .547 .31 .508 r
F
.64012 .59721 m .63741 .59581 L .63666 .5963 L .657 .813 .958 r
F
.63741 .59581 m .63671 .59624 L .63666 .5963 L F
.64012 .59721 m .63666 .5963 L .63626 .59688 L F
.64012 .59721 m .63672 .59915 L .63677 .59918 L F
.64012 .59721 m .63661 .59928 L .63751 .59957 L F
.64012 .59721 m .6362 .59864 L .63658 .59923 L F
.64012 .59721 m .63751 .59957 L .63852 .59989 L F
.63666 .58849 m .63699 .59606 L .6378 .59557 L .369 .177 .485 r
F
.63666 .58849 m .63677 .5962 L .63699 .59606 L F
.63692 .51695 m .63549 .51723 L .63566 .52207 L .547 .31 .508 r
F
.63692 .51695 m .63566 .52207 L .637 .5218 L F
.63399 .51769 m .634 .51797 L .634 .51797 L 0 0 .377 r
F
.63421 .51768 m .62499 .51414 L .63374 .51831 L .601 .765 .958 r
F
.63549 .51723 m .63556 .52212 L .63566 .52207 L .369 .177 .485 r
F
.63548 .51723 m .63556 .52212 L .63549 .51723 L F
.63326 .51896 m .63324 .51896 L .63324 .51899 L .601 .765 .958 r
F
.63324 .51896 m .63272 .51893 L .63325 .51969 L F
.63817 .52433 m .63107 .5164 L .62757 .51758 L .6 .765 .958 r
F
.63556 .52212 m .63677 .5962 L .63566 .52207 L .369 .177 .485 r
F
.63594 .59959 m .63502 .59907 L .63585 .59965 L .657 .813 .958 r
F
.63502 .59907 m .63158 .60208 L .63585 .59965 L F
.6358 .59991 m .63581 .59907 L .63515 .59986 L F
.63596 .59733 m .63593 .59737 L .63604 .60042 L 0 0 .377 r
F
.63604 .60126 m .63604 .60126 L .63593 .59818 L 0 0 .044 r
F
.63596 .59732 m .63604 .60041 L .63597 .59732 L 0 0 .377 r
F
.63604 .60041 m .63604 .60041 L .63597 .59732 L F
.63591 .60061 m .63515 .59986 L .63486 .60067 L .657 .813 .958 r
F
.63593 .59818 m .63604 .60126 L .63593 .59737 L 0 0 .044 r
F
.63639 .60183 m .63604 .60174 L .63604 .60195 L .657 .813 .958 r
F
.63604 .60127 m .6365 .60273 L .63606 .60196 L .972 .694 .284 r
F
.63604 .60126 m .63606 .60196 L .63604 .60111 L 0 0 .044 r
F
.63604 .60126 m .63604 .60111 L .63593 .59737 L F
.64056 .60031 m .63604 .60124 L .63639 .60183 L .657 .813 .958 r
F
.63604 .60124 m .63602 .60124 L .63604 .60127 L F
.63604 .60124 m .63604 .60127 L .63639 .60183 L F
.63642 .60053 m .63642 .60053 L .63635 .59888 L .972 .694 .284 r
F
.63593 .59818 m .63606 .60196 L .63593 .59818 L 0 0 .044 r
F
.63593 .59818 m .63593 .59822 L .63606 .60196 L F
.64056 .60031 m .63635 .59996 L .63591 .60061 L .657 .813 .958 r
F
.63635 .59888 m .63642 .60053 L .63635 .59888 L .972 .694 .284 r
F
.63642 .60053 m .63635 .59888 L .63635 .59888 L F
.6367 .59624 m .63617 .60023 L .63681 .59929 L 0 0 .377 r
F
.63671 .59624 m .6367 .59624 L .63666 .5963 L .657 .813 .958 r
F
.63597 .59732 m .63604 .60041 L .6367 .59624 L 0 0 .377 r
F
.63604 .60041 m .63606 .60106 L .63617 .60023 L F
.63604 .60041 m .63617 .60023 L .6367 .59624 L F
.63556 .52212 m .63417 .52281 L .63681 .59929 L .369 .177 .485 r
F
.64056 .60031 m .63679 .59932 L .63635 .59996 L .657 .813 .958 r
F
.63682 .59929 m .63681 .59929 L .63683 .59992 L .369 .177 .485 r
F
.63556 .52212 m .63681 .59929 L .63682 .59929 L F
.63676 .59932 m .6368 .59837 L .63581 .59907 L .657 .813 .958 r
F
.63679 .59932 m .63679 .59931 L .63676 .59932 L F
.63679 .59931 m .6368 .59837 L .63676 .59932 L F
.64056 .60031 m .63762 .59879 L .63679 .59932 L F
.63566 .52207 m .63666 .58849 L .6378 .59557 L .369 .177 .485 r
F
.63566 .52207 m .6378 .59557 L .63822 .59531 L F
.63741 .59581 m .63822 .59531 L .63713 .59566 L .657 .813 .958 r
F
.64012 .59721 m .63822 .59531 L .63741 .59581 L F
.63822 .59531 m .63822 .59531 L .63741 .59581 L F
.6378 .59557 m .63727 .59901 L .63825 .59841 L .369 .177 .485 r
F
.63762 .59879 m .63804 .5978 L .63741 .59809 L .657 .813 .958 r
F
.63699 .59606 m .63716 .59973 L .6378 .59557 L .369 .177 .485 r
F
.63762 .59879 m .63681 .59929 L .63679 .59932 L .657 .813 .958 r
F
.63713 .5991 m .63683 .59992 L .63716 .59973 L .369 .177 .485 r
F
.63699 .59606 m .63686 .59926 L .63713 .5991 L F
.63686 .59926 m .63683 .59992 L .63713 .5991 L F
.63727 .59861 m .6368 .59837 L .63679 .59931 L .657 .813 .958 r
F
.63681 .59929 m .63679 .59931 L .63679 .59932 L F
.63727 .59861 m .63679 .59931 L .63681 .59929 L F
.63762 .59879 m .63741 .59809 L .6368 .59837 L F
.637 .5218 m .63701 .5218 L .63693 .51694 L .547 .31 .508 r
F
.63693 .51694 m .63701 .5218 L .6371 .52178 L F
.63832 .51691 m .63693 .51694 L .6371 .52178 L .65 .39 .512 r
F
.63834 .51926 m .65278 .51578 L .65047 .51384 L .601 .765 .958 r
F
.63832 .51691 m .6371 .52178 L .63841 .52175 L .65 .39 .512 r
F
.63442 .51776 m .63421 .51768 L .634 .51797 L .601 .765 .958 r
F
.63817 .52433 m .63506 .51577 L .63107 .5164 L .6 .765 .958 r
F
.637 .5218 m .63829 .59529 L .63701 .5218 L .547 .31 .508 r
F
.63829 .59529 m .63829 .59529 L .63701 .5218 L F
.63701 .5218 m .63829 .59529 L .6371 .52178 L F
.63829 .59529 m .63829 .59529 L .6371 .52178 L F
.6371 .52178 m .63829 .59529 L .63969 .59485 L F
.637 .5218 m .63566 .52207 L .63822 .59531 L F
.64056 .60031 m .63854 .5983 L .63762 .59879 L .657 .813 .958 r
F
.63854 .5983 m .63833 .59836 L .63762 .59879 L F
.6385 .59826 m .63804 .5978 L .63772 .59855 L F
.63833 .59836 m .63772 .59855 L .63762 .59879 L F
.6385 .59826 m .63772 .59855 L .63833 .59836 L F
.63829 .59529 m .63822 .59531 L .63833 .59836 L .547 .31 .508 r
F
.63834 .59836 m .63833 .59836 L .63835 .59905 L F
.63829 .59529 m .63833 .59836 L .63834 .59836 L F
.637 .5218 m .63822 .59531 L .63829 .59529 L F
.63822 .59531 m .63925 .59491 L .638 .59508 L .657 .813 .958 r
F
.64012 .59721 m .63928 .59498 L .63822 .59531 L F
.63928 .59498 m .63925 .59491 L .63822 .59531 L F
.638 .59508 m .63902 .59431 L .63762 .59471 L F
.63925 .59491 m .63902 .59431 L .638 .59508 L F
.63833 .51691 m .63842 .52175 L .6385 .52175 L .65 .39 .512 r
F
.63831 .51631 m .63832 .51691 L .63833 .51691 L F
.63817 .52433 m .6385 .52175 L .63725 .52178 L .6 .765 .958 r
F
.63832 .51691 m .63841 .52175 L .63833 .51691 L .65 .39 .512 r
F
.63817 .52433 m .63974 .52192 L .6385 .52175 L .6 .765 .958 r
F
.63969 .5171 m .6385 .52175 L .63979 .52193 L .735 .457 .508 r
F
.6397 .5171 m .6398 .52193 L .63988 .52194 L F
.63969 .5171 m .63979 .52193 L .6397 .5171 L F
.63979 .52193 m .6398 .52193 L .6397 .5171 L F
.64104 .51754 m .6397 .5171 L .63988 .52194 L .822 .528 .492 r
F
.63817 .52433 m .64105 .5221 L .63974 .52192 L .6 .765 .958 r
F
.64104 .51754 m .63988 .52194 L .64113 .52235 L .822 .528 .492 r
F
.64105 .51755 m .64114 .52236 L .64122 .52239 L F
.63817 .52433 m .64199 .52264 L .64085 .52226 L .6 .765 .958 r
F
.64104 .51754 m .64113 .52235 L .64105 .51755 L .822 .528 .492 r
F
.64113 .52235 m .64259 .59469 L .64114 .52236 L F
.64259 .59469 m .64259 .59469 L .64114 .52236 L F
.64012 .59721 m .64285 .59475 L .64253 .59468 L .657 .813 .958 r
F
.64012 .59721 m .64253 .59468 L .64165 .59466 L F
.64396 .595 m .64396 .595 L .64243 .52323 L .931 .625 .44 r
F
.64396 .595 m .64396 .595 L .64243 .52323 L F
.64012 .59721 m .64398 .59501 L .64285 .59475 L .657 .813 .958 r
F
.64398 .59501 m .64401 .59499 L .64389 .59497 L F
.64398 .59501 m .64389 .59497 L .64285 .59475 L F
.64242 .52322 m .64122 .52239 L .64389 .59497 L .931 .625 .44 r
F
.64396 .595 m .64389 .59497 L .64405 .59913 L F
.64242 .52322 m .64389 .59497 L .64396 .595 L F
.64389 .59497 m .64265 .59773 L .64401 .59801 L .822 .528 .492 r
F
.64122 .52239 m .64259 .59469 L .64389 .59497 L F
.64259 .59469 m .64265 .59773 L .64389 .59497 L F
.64243 .52323 m .64396 .595 L .64251 .52328 L .931 .625 .44 r
F
.64285 .59475 m .64441 .59477 L .6433 .59435 L .657 .813 .958 r
F
.64401 .59499 m .64441 .59477 L .64285 .59475 L F
.64253 .59468 m .64154 .5977 L .64264 .59772 L .735 .457 .508 r
F
.64056 .60031 m .64212 .59771 L .64123 .5977 L .657 .813 .958 r
F
.6385 .52175 m .63976 .59484 L .64112 .59465 L .65 .39 .512 r
F
.63988 .52194 m .64119 .59465 L .64253 .59468 L .735 .457 .508 r
F
.63979 .52193 m .64119 .59465 L .6398 .52193 L F
.64119 .59465 m .64119 .59465 L .6398 .52193 L F
.6398 .52193 m .64119 .59465 L .63988 .52194 L F
.64119 .59465 m .64119 .59465 L .63988 .52194 L F
.64012 .59721 m .64165 .59466 L .64044 .59463 L .657 .813 .958 r
F
.63974 .52192 m .6385 .52175 L .6385 .52175 L .6 .765 .958 r
F
.63979 .52193 m .6385 .52175 L .64126 .59857 L .735 .457 .508 r
F
.64044 .59463 m .64197 .59412 L .64051 .59411 L .657 .813 .958 r
F
.64165 .59466 m .64197 .59412 L .64044 .59463 L F
.64119 .59465 m .64126 .59857 L .64119 .59465 L .735 .457 .508 r
F
.64112 .59465 m .63981 .5979 L .64123 .5977 L .65 .39 .512 r
F
.64012 .59721 m .64043 .59474 L .63925 .59491 L .657 .813 .958 r
F
.63976 .59484 m .63981 .5979 L .64112 .59465 L .65 .39 .512 r
F
.63841 .52175 m .63981 .5979 L .63842 .52175 L F
.63981 .5979 m .63981 .5979 L .63842 .52175 L F
.63842 .52175 m .63981 .5979 L .6385 .52175 L F
.63981 .5979 m .63981 .5979 L .6385 .52175 L F
.64056 .60031 m .64088 .59775 L .6398 .5979 L .657 .813 .958 r
F
.63969 .59485 m .6386 .59828 L .6398 .5979 L .547 .31 .508 r
F
.63966 .59794 m .6398 .5979 L .63966 .59792 L .657 .813 .958 r
F
.64056 .60031 m .6398 .5979 L .63966 .59794 L F
.63854 .5983 m .63966 .59792 L .63835 .5981 L F
.64056 .60031 m .63966 .59794 L .63854 .5983 L F
.63966 .59794 m .63966 .59792 L .63854 .5983 L F
.63829 .59529 m .63834 .59836 L .63969 .59485 L .547 .31 .508 r
F
.63834 .59836 m .63835 .59905 L .6386 .59828 L F
.63834 .59836 m .6386 .59828 L .63969 .59485 L F
.6398 .5979 m .63835 .59905 L .63982 .59867 L F
.6386 .59828 m .63835 .59905 L .6398 .5979 L F
.63975 .59484 m .63969 .59485 L .63982 .59867 L .65 .39 .512 r
F
.63966 .59792 m .64095 .5972 L .63946 .5974 L .657 .813 .958 r
F
.64088 .59775 m .64095 .5972 L .63966 .59792 L F
.63981 .5979 m .63982 .59867 L .63981 .5979 L .65 .39 .512 r
F
.63981 .5979 m .63982 .59867 L .63981 .5979 L F
.63829 .59529 m .63834 .59836 L .63829 .59529 L .547 .31 .508 r
F
.63834 .59836 m .63834 .59836 L .63829 .59529 L F
.63822 .59531 m .6378 .59557 L .63825 .59841 L .369 .177 .485 r
F
.63822 .59531 m .63825 .59841 L .63833 .59836 L F
.63829 .59529 m .63835 .59905 L .63829 .59529 L .547 .31 .508 r
F
.63835 .5981 m .63946 .5974 L .63804 .5978 L .657 .813 .958 r
F
.63966 .59792 m .63946 .5974 L .63835 .5981 L F
.63841 .52175 m .6371 .52178 L .63969 .59485 L .65 .39 .512 r
F
.63841 .52175 m .63969 .59485 L .63975 .59484 L F
.63925 .59491 m .64051 .59411 L .63902 .59431 L .657 .813 .958 r
F
.64043 .59474 m .64051 .59411 L .63925 .59491 L F
.64088 .59775 m .64123 .5977 L .64089 .59769 L F
.64056 .60031 m .64123 .5977 L .64088 .59775 L F
.64123 .5977 m .63982 .59867 L .64126 .59857 L .65 .39 .512 r
F
.63981 .5979 m .63982 .59867 L .64123 .5977 L F
.64119 .59465 m .64126 .59857 L .64253 .59468 L .735 .457 .508 r
F
.64119 .59465 m .64126 .59857 L .64119 .59465 L F
.64089 .59769 m .64242 .59721 L .64095 .5972 L .657 .813 .958 r
F
.64212 .59771 m .64242 .59721 L .64089 .59769 L F
.64259 .59469 m .64265 .59773 L .64259 .59469 L .822 .528 .492 r
F
.64114 .52236 m .64265 .59773 L .64122 .52239 L F
.64113 .52235 m .63988 .52194 L .64264 .59772 L F
.64113 .52235 m .64264 .59772 L .64265 .59773 L F
.64217 .59763 m .64376 .59744 L .64242 .59721 L .657 .813 .958 r
F
.64056 .60031 m .64328 .59786 L .64217 .59763 L F
.64328 .59786 m .64376 .59744 L .64217 .59763 L F
.64265 .59773 m .64264 .59772 L .64267 .59871 L .822 .528 .492 r
F
.64264 .59772 m .64126 .59857 L .64267 .59871 L .735 .457 .508 r
F
.64154 .5977 m .64126 .59857 L .64264 .59772 L F
.64253 .59468 m .6433 .59435 L .64174 .59451 L .657 .813 .958 r
F
.64285 .59475 m .64292 .59468 L .64253 .59468 L F
.64292 .59468 m .6433 .59435 L .64253 .59468 L F
.64165 .59466 m .64253 .59468 L .64174 .59451 L F
.64174 .59451 m .6433 .59435 L .64197 .59412 L F
.64113 .52235 m .64114 .52236 L .64105 .51755 L .822 .528 .492 r
F
.64242 .52322 m .64243 .52323 L .64233 .51844 L .931 .625 .44 r
F
.64232 .51844 m .64105 .51755 L .64122 .52239 L F
.64281 .51953 m .64233 .51844 L .64251 .52328 L .944 .685 .22 r
F
.64105 .5221 m .64717 .51736 L .63976 .5219 L .6 .765 .958 r
F
.63988 .52194 m .63976 .5219 L .63974 .52192 L F
.64105 .5221 m .63976 .5219 L .63988 .52194 L F
.64085 .52226 m .65032 .51893 L .64717 .51736 L F
.64199 .52264 m .65032 .51893 L .64085 .52226 L F
.64281 .51953 m .64282 .51953 L .64282 .51953 L .601 .765 .958 r
F
.63975 .5219 m .64717 .51736 L .6434 .51626 L .6 .765 .958 r
F
.63974 .52192 m .63976 .5219 L .63975 .5219 L F
.63976 .5219 m .64717 .51736 L .63975 .5219 L F
.63969 .5171 m .63833 .51691 L .6385 .52175 L .735 .457 .508 r
F
.63968 .51646 m .63833 .51691 L .63969 .5171 L F
.63863 .51695 m .64356 .51118 L .63943 .51063 L .601 .765 .958 r
F
.63968 .51646 m .63969 .5171 L .6397 .5171 L .735 .457 .508 r
F
.63973 .51711 m .64356 .51118 L .63863 .51695 L .601 .765 .958 r
F
.63973 .51711 m .64733 .51227 L .64356 .51118 L F
.64069 .51743 m .64733 .51227 L .63973 .51711 L F
.6385 .52175 m .6434 .51626 L .63927 .51572 L .6 .765 .958 r
F
.63974 .52192 m .63986 .52172 L .6385 .52175 L F
.63841 .52175 m .63842 .52175 L .63833 .51691 L .65 .39 .512 r
F
.63986 .52172 m .6434 .51626 L .6385 .52175 L .6 .765 .958 r
F
.63744 .51679 m .63943 .51063 L .63523 .51068 L .601 .765 .958 r
F
.63863 .51695 m .63943 .51063 L .63744 .51679 L F
.63749 .51693 m .63746 .51684 L .63693 .51694 L F
.63691 .51641 m .63692 .51695 L .63693 .51694 L .547 .31 .508 r
F
.63746 .51684 m .63523 .51068 L .63636 .51705 L .601 .765 .958 r
F
.63725 .52178 m .63927 .51572 L .63506 .51577 L .6 .765 .958 r
F
.6385 .52175 m .63927 .51572 L .63725 .52178 L F
.63834 .59836 m .63835 .59905 L .63834 .59836 L .547 .31 .508 r
F
.63854 .5983 m .6385 .59826 L .63833 .59836 L .657 .813 .958 r
F
.63833 .59836 m .63825 .59841 L .63835 .59905 L .369 .177 .485 r
F
.63825 .59841 m .63716 .59973 L .63835 .59905 L F
.63727 .59901 m .63716 .59973 L .63825 .59841 L F
.63762 .59879 m .63727 .59861 L .63681 .59929 L .657 .813 .958 r
F
.63635 .59996 m .63515 .59986 L .63591 .60061 L F
.63681 .59929 m .63606 .60106 L .63683 .59992 L 0 0 .377 r
F
.63617 .60023 m .63606 .60106 L .63681 .59929 L F
.63604 .60041 m .63606 .60106 L .63604 .60041 L F
.63635 .59996 m .63676 .59932 L .6358 .59991 L .657 .813 .958 r
F
.63679 .59932 m .63676 .59932 L .63635 .59996 L F
.63676 .59932 m .63581 .59907 L .6358 .59991 L F
.63677 .5962 m .63682 .59929 L .63677 .5962 L .369 .177 .485 r
F
.63682 .59929 m .63683 .59992 L .63682 .59929 L F
.63682 .59929 m .63682 .59929 L .63677 .5962 L F
.63677 .5962 m .63677 .5962 L .63566 .52207 L F
.63711 .59565 m .63638 .59527 L .63665 .59627 L .657 .813 .958 r
F
.6367 .59624 m .63665 .59627 L .63666 .5963 L F
.63711 .59565 m .63665 .59627 L .6367 .59624 L F
.63713 .59566 m .63762 .59471 L .63638 .59527 L F
.63822 .59531 m .63762 .59471 L .63713 .59566 L F
.63713 .59566 m .63709 .59567 L .6367 .59624 L F
.63713 .59566 m .6367 .59624 L .63671 .59624 L F
.63741 .59581 m .63713 .59566 L .63671 .59624 L F
.63677 .5962 m .63683 .59992 L .63699 .59606 L .369 .177 .485 r
F
.63713 .59566 m .63711 .59565 L .63709 .59567 L .657 .813 .958 r
F
.63626 .59688 m .6354 .59597 L .63474 .59676 L F
.63666 .5963 m .6354 .59597 L .63626 .59688 L F
.63604 .60041 m .63604 .60042 L .63606 .60106 L 0 0 .377 r
F
.63626 .59688 m .63474 .59676 L .63586 .59748 L .657 .813 .958 r
F
.63134 .52292 m .63181 .5219 L .62688 .522 L .6 .765 .958 r
F
.63342 .52251 m .63181 .5219 L .63134 .52292 L F
.63181 .5219 m .62481 .51922 L .62688 .522 L F
.63604 .60042 m .63606 .60196 L .63606 .60106 L 0 0 .044 r
F
.63604 .60111 m .63606 .60196 L .63604 .60042 L F
.63604 .60126 m .63606 .60196 L .63604 .60126 L F
.63604 .60195 m .63495 .60146 L .63543 .60218 L .657 .813 .958 r
F
.63604 .60174 m .63495 .60146 L .63604 .60195 L F
.64056 .60031 m .63639 .60183 L .63648 .60196 L F
.63702 .60233 m .63648 .60196 L .63679 .60246 L F
.64056 .60031 m .63648 .60196 L .63702 .60233 L F
.63728 .6025 m .63729 .60251 L .63732 .60339 L .948 .643 .425 r
F
.64328 .59786 m .64401 .59801 L .64346 .5977 L .657 .813 .958 r
F
.64401 .59801 m .64267 .59871 L .64405 .59913 L .822 .528 .492 r
F
.64265 .59773 m .64267 .59871 L .64401 .59801 L F
.64404 .59895 m .64396 .595 L .64396 .595 L .931 .625 .44 r
F
.64396 .595 m .64405 .59913 L .6452 .59573 L F
.64346 .5977 m .64488 .59786 L .64376 .59744 L .657 .813 .958 r
F
.6443 .59818 m .64488 .59786 L .64346 .5977 L F
.64402 .59802 m .64404 .59895 L .64402 .59802 L .931 .625 .44 r
F
.64404 .59895 m .64404 .59895 L .64402 .59802 L F
.64404 .59895 m .64402 .59802 L .64402 .59802 L F
.64523 .59578 m .64532 .59879 L .64523 .59578 L .944 .685 .22 r
F
.64546 .59908 m .64536 .60005 L .64581 .59982 L F
.64524 .59861 m .6457 .59844 L .64489 .59786 L .657 .813 .958 r
F
.64524 .59861 m .64489 .59786 L .64488 .59786 L F
.64556 .59928 m .64627 .59995 L .64617 .59916 L F
.64588 .59997 m .64627 .59995 L .64556 .59928 L F
.64532 .59879 m .64536 .60005 L .64532 .59879 L .944 .685 .22 r
F
.64532 .59879 m .64532 .59879 L .64523 .59578 L F
.64581 .60041 m .64609 .60042 L .64599 .6002 L .657 .813 .958 r
F
.64581 .60041 m .64599 .6002 L .64588 .59997 L F
.64558 .6007 m .64565 .60211 L .64558 .6007 L .067 0 .41 r
F
.64566 .60041 m .64597 .60077 L .64609 .60042 L .657 .813 .958 r
F
.64588 .59997 m .64609 .60042 L .64627 .59995 L F
.64523 .59578 m .6452 .59573 L .64532 .59877 L .944 .685 .22 r
F
.64532 .59879 m .64532 .59877 L .64536 .60005 L F
.64523 .59578 m .64532 .59877 L .64532 .59879 L F
.64558 .6007 m .64559 .60068 L .64565 .60211 L .067 0 .41 r
F
.64056 .60031 m .64494 .60146 L .64497 .60144 L .657 .813 .958 r
F
.64056 .60031 m .64497 .60144 L .64555 .60073 L F
.64495 .60145 m .64502 .60287 L .64466 .60165 L .328 .148 .478 r
F
.64559 .60068 m .64586 .60121 L .64565 .60211 L 0 0 .209 r
F
.64497 .60144 m .64565 .60211 L .64502 .60287 L .067 0 .41 r
F
.64539 .60092 m .64565 .60211 L .64497 .60144 L F
.64404 .59895 m .64405 .59913 L .64404 .59895 L .931 .625 .44 r
F
.66479 .52433 m .68352 .52353 L .66856 .52043 L .602 .764 .957 r
F
.65348 .52239 m .66858 .52551 L .67033 .52116 L .601 .765 .958 r
F
.65348 .52239 m .67033 .52116 L .65433 .52021 L F
.64252 .52329 m .65395 .52303 L .65263 .52086 L .6 .765 .958 r
F
.6434 .5239 m .65395 .52303 L .64252 .52329 L F
.64695 .59943 m .64954 .59968 L .64672 .59894 L .657 .813 .958 r
F
.64174 .52274 m .65263 .52086 L .65032 .51893 L .6 .765 .958 r
F
.64252 .52329 m .65263 .52086 L .64174 .52274 L F
.64652 .59853 m .64954 .59968 L .65035 .59872 L .657 .813 .958 r
F
.64672 .59894 m .64954 .59968 L .64652 .59853 L F
.64945 .59819 m .65035 .59872 L .65086 .59812 L F
.64053 .60302 m .64056 .60302 L .6406 .6042 L .755 .473 .507 r
F
.64022 .60309 m .64017 .60341 L .64104 .60305 L .657 .813 .958 r
F
.64056 .60302 m .64104 .60305 L .64153 .60285 L F
.64022 .60309 m .64104 .60305 L .64056 .60302 L F
.64056 .60031 m .64023 .60301 L .64153 .60285 L F
.64023 .60301 m .64056 .60302 L .64153 .60285 L F
.64056 .60302 m .64269 .60398 L .6406 .6042 L .629 .374 .513 r
F
.64201 .60277 m .64269 .60398 L .64056 .60302 L F
.64056 .60031 m .63899 .60293 L .64023 .60301 L .657 .813 .958 r
F
.63854 .60291 m .6406 .6042 L .63857 .60391 L .755 .473 .507 r
F
.63999 .60299 m .6406 .6042 L .63854 .60291 L F
.63593 .59747 m .63548 .5975 L .63593 .59807 L .657 .813 .958 r
F
.63548 .5975 m .63445 .59757 L .63585 .59809 L F
.63647 .60195 m .6365 .60273 L .63604 .60127 L .972 .694 .284 r
F
.63594 .59916 m .63502 .59907 L .63594 .59959 L .657 .813 .958 r
F
.63648 .60196 m .63732 .60339 L .6365 .60273 L .948 .643 .425 r
F
.63691 .60239 m .63679 .60246 L .6379 .6027 L .657 .813 .958 r
F
.63679 .60246 m .63721 .60311 L .63738 .60318 L F
.63728 .6025 m .63732 .60339 L .63648 .60196 L .948 .643 .425 r
F
.63729 .60251 m .63857 .60391 L .63732 .60339 L .862 .563 .481 r
F
.63852 .6029 m .63857 .60391 L .63729 .60251 L F
.63647 .60195 m .6365 .60273 L .63647 .60195 L .972 .694 .284 r
F
.63191 .52583 m .62965 .52504 L .62437 .52765 L .6 .765 .958 r
F
.63269 .52478 m .62965 .52504 L .63191 .52583 L F
.62965 .52504 m .62244 .52563 L .62437 .52765 L F
.63343 .52801 m .63049 .52775 L .62926 .53124 L F
.63342 .52645 m .63049 .52775 L .63343 .52801 L F
.63049 .52775 m .62612 .52969 L .62826 .53075 L F
.63049 .52775 m .62826 .53075 L .62926 .53124 L F
.63343 .52801 m .62926 .53124 L .63345 .53162 L F
.64308 .52534 m .64397 .52655 L .64347 .52542 L F
.64397 .52655 m .65146 .52942 L .64347 .52542 L F
.64489 .52862 m .64868 .53103 L .64397 .52655 L F
.61407 .41378 m .59468 .40835 L .58944 .41493 L .661 .804 .952 r
F
.61805 .41087 m .59468 .40835 L .61407 .41378 L F
.36729 .5585 m .35595 .55211 L .34891 .55672 L .599 .766 .959 r
F
.37356 .55631 m .35595 .55211 L .36729 .5585 L F
.63807 .28686 m .6131 .28226 L .61367 .28925 L .662 .419 .543 r
F
0 g
.59062 .29538 m
.61367 .28925 L
s
.63807 .28686 m .63745 .27987 L .6131 .28226 L .662 .419 .543 r
F
0 g
.5901 .2884 m
.6131 .28226 L
s
.41109 .5611 m .41215 .55155 L .40459 .55815 L .599 .766 .959 r
F
.41109 .5611 m .42192 .55602 L .41215 .55155 L F
.59064 .42658 m .56836 .42447 L .56516 .43472 L .659 .805 .953 r
F
0 g
.56516 .43472 m
.56673 .44457 L
s
.38434 .57311 m .37991 .56505 L .37245 .56623 L .598 .767 .96 r
F
.38836 .57307 m .37991 .56505 L .38434 .57311 L F
.3924 .57359 m .38799 .56498 L .38836 .57307 L F
.3924 .57359 m .39612 .56601 L .38799 .56498 L F
.65497 .41731 m .66946 .40452 L .65165 .4148 L .66 .805 .952 r
F
.65497 .41731 m .67605 .4096 L .66946 .40452 L F
.36614 .56842 m .34761 .56663 L .36139 .57147 L .598 .767 .96 r
F
.38836 .57307 m .38799 .56498 L .37991 .56505 L F
.41533 .57467 m .42119 .56596 L .41028 .57104 L F
.41533 .57467 m .42874 .57144 L .42119 .56596 L F
.35524 .55701 m .3487 .55665 L .34816 .56163 L .259 .08 .438 r
F
.35524 .55701 m .35578 .55201 L .3487 .55665 L F
0 g
.34448 .56224 m
.3487 .55665 L
s
.65076 .40903 m .65941 .3951 L .64625 .40721 L .661 .804 .952 r
F
.65076 .40903 m .66844 .39879 L .65941 .3951 L F
.42918 .56644 m .42962 .56144 L .42209 .55594 L .935 .679 .526 r
F
0 g
.42962 .56144 m
.43436 .56757 L
s
.66199 .28839 m .63745 .27987 L .63807 .28686 L .736 .475 .534 r
F
0 g
.6131 .28226 m
.63745 .27987 L
s
.63745 .27987 m
.66133 .28141 L
s
.66199 .28839 m
.68366 .29372 L
s
.59468 .40835 m .56734 .4128 L .58944 .41493 L .661 .804 .952 r
F
.61547 .42541 m .59064 .42658 L .6128 .42868 L .659 .805 .953 r
F
0 g
.63807 .28686 m
.66199 .28839 L
s
.68057 .4215 m .69818 .40768 L .6769 .41543 L .659 .805 .953 r
F
.68057 .4215 m .70356 .41685 L .69818 .40768 L F
.70267 .41102 m .69641 .396 L .69729 .40183 L .94 .636 .181 r
F
.70356 .41685 m .70267 .41102 L .69729 .40183 L F
0 g
.70295 .4154 m
.70298 .41587 L
s
.36666 .56342 m .35524 .55701 L .34816 .56163 L .598 .766 .96 r
F
.37297 .56122 m .35524 .55701 L .36666 .56342 L F
.61472 .41957 m .59521 .41413 L .58993 .42074 L .66 .805 .952 r
F
.61873 .41665 m .59521 .41413 L .61472 .41957 L F
.41074 .56604 m .4118 .55647 L .4042 .56308 L .598 .766 .96 r
F
.41074 .56604 m .42164 .56094 L .4118 .55647 L F
0 g
.63901 .42926 m
.6394 .43969 L
s
.61805 .41087 m .60263 .40246 L .59468 .40835 L .661 .804 .952 r
F
.62309 .40851 m .60263 .40246 L .61805 .41087 L F
0 g
.63095 .42969 m
.63129 .43956 L
s
.65578 .42313 m .6703 .41037 L .65246 .42063 L .659 .805 .953 r
F
.65578 .42313 m .6769 .41543 L .6703 .41037 L F
.35471 .56202 m .34816 .56163 L .34761 .56663 L .259 .08 .438 r
F
.35471 .56202 m .35524 .55701 L .34816 .56163 L F
0 g
.34393 .56721 m
.34816 .56163 L
s
.37356 .55631 m .36538 .54878 L .35595 .55211 L .599 .766 .959 r
F
.38097 .55513 m .36538 .54878 L .37356 .55631 L F
.40459 .55815 m .40078 .54843 L .39705 .55608 L F
.40459 .55815 m .41215 .55155 L .40078 .54843 L F
0 g
.61367 .28925 m
.63807 .28686 L
s
.42918 .56644 m .42209 .55594 L .42164 .56094 L .935 .679 .526 r
F
.42874 .57144 m .42918 .56644 L .42164 .56094 L F
0 g
.42918 .56644 m
.43393 .57255 L
s
.64625 .40721 m .64852 .39306 L .64083 .40621 L .661 .804 .952 r
F
.64625 .40721 m .65941 .3951 L .64852 .39306 L F
.65165 .4148 m .66036 .40082 L .64711 .41298 L .66 .805 .952 r
F
.65165 .4148 m .66946 .40452 L .66036 .40082 L F
0 g
.6394 .43969 m
.64186 .5059 L
s
.63129 .43956 m
.63358 .50595 L
s
.59521 .41413 m .56768 .41861 L .58993 .42074 L .66 .805 .952 r
F
.675 .40386 m .68632 .38844 L .66844 .39879 L .661 .804 .952 r
F
.675 .40386 m .69609 .39612 L .68632 .38844 L F
.36614 .56842 m .35471 .56202 L .34761 .56663 L .598 .767 .96 r
F
0 g
.34338 .5722 m
.34761 .56663 L
s
.37245 .56623 m .35471 .56202 L .36614 .56842 L .598 .767 .96 r
F
.70356 .41685 m .69729 .40183 L .69818 .40768 L .94 .636 .181 r
F
0 g
.70356 .41685 m
.7042 .42684 L
s
.62309 .40851 m .61274 .3977 L .60263 .40246 L .661 .804 .952 r
F
.62884 .40688 m .61274 .3977 L .62309 .40851 L F
.41028 .57104 m .41134 .56149 L .40372 .56808 L .598 .767 .96 r
F
.41028 .57104 m .42119 .56596 L .41134 .56149 L F
.61547 .42541 m .59593 .41999 L .59064 .42658 L .659 .805 .953 r
F
.61949 .42249 m .59593 .41999 L .61547 .42541 L F
.38097 .55513 m .37653 .54699 L .36538 .54878 L .599 .766 .959 r
F
.38898 .55505 m .37653 .54699 L .38097 .55513 L F
.39705 .55608 m .38862 .54687 L .38898 .55505 L F
.39705 .55608 m .40078 .54843 L .38862 .54687 L F
.64083 .40621 m .63653 .39281 L .63489 .4061 L .661 .804 .952 r
F
.64083 .40621 m .64852 .39306 L .63653 .39281 L F
.61873 .41665 m .60321 .40823 L .59521 .41413 L .66 .805 .952 r
F
.6238 .41428 m .60321 .40823 L .61873 .41665 L F
.37297 .56122 m .36473 .55368 L .35524 .55701 L .598 .766 .96 r
F
.38042 .56004 m .36473 .55368 L .37297 .56122 L F
.4042 .56308 m .40036 .55333 L .3966 .561 L F
.4042 .56308 m .4118 .55647 L .40036 .55333 L F
.42874 .57144 m .42164 .56094 L .42119 .56596 L .935 .679 .526 r
F
0 g
.42874 .57144 m
.4335 .57754 L
s
.38898 .55505 m .38862 .54687 L .37653 .54699 L .599 .766 .959 r
F
.62884 .40688 m .62432 .3944 L .61274 .3977 L .661 .804 .952 r
F
.63489 .4061 m .62432 .3944 L .62884 .40688 L F
.63489 .4061 m .63653 .39281 L .62432 .3944 L F
.64711 .41298 m .6494 .39878 L .64166 .41197 L .66 .805 .952 r
F
.64711 .41298 m .66036 .40082 L .6494 .39878 L F
.65246 .42063 m .66119 .40668 L .64791 .41881 L .659 .805 .953 r
F
.65246 .42063 m .6703 .41037 L .66119 .40668 L F
.59468 .40835 m .5751 .40286 L .56734 .4128 L .661 .804 .952 r
F
.5755 .40864 m .567 .41277 L .56768 .41861 L .135 .056 .495 r
F
.5755 .40864 m .57481 .40278 L .567 .41277 L F
0 g
.56382 .42307 m
.567 .41277 L
s
.59593 .41999 m .56836 .42447 L .59064 .42658 L .659 .805 .953 r
F
.67605 .4096 m .68746 .39413 L .66946 .40452 L .66 .805 .952 r
F
.67605 .4096 m .69729 .40183 L .68746 .39413 L F
.36473 .55368 m .35578 .55201 L .35524 .55701 L .453 .24 .499 r
F
.36473 .55368 m .36525 .54867 L .35578 .55201 L F
0 g
.3487 .55665 m
.35578 .55201 L
s
.42164 .56094 m .42209 .55594 L .41227 .55145 L .867 .609 .547 r
F
0 g
.42209 .55594 m
.42962 .56144 L
s
.6238 .41428 m .61339 .40344 L .60321 .40823 L .66 .805 .952 r
F
.62959 .41265 m .61339 .40344 L .6238 .41428 L F
.38042 .56004 m .37595 .55188 L .36473 .55368 L .598 .766 .96 r
F
.38848 .55997 m .37595 .55188 L .38042 .56004 L F
.3966 .561 m .38811 .55176 L .38848 .55997 L F
.3966 .561 m .40036 .55333 L .38811 .55176 L F
.37245 .56623 m .3642 .5587 L .35471 .56202 L .598 .767 .96 r
F
.37991 .56505 m .3642 .5587 L .37245 .56623 L F
.40372 .56808 m .39988 .55836 L .39612 .56601 L F
.40372 .56808 m .41134 .56149 L .39988 .55836 L F
.61949 .42249 m .60395 .41409 L .59593 .41999 L .659 .805 .953 r
F
.62457 .42013 m .60395 .41409 L .61949 .42249 L F
.64166 .41197 m .63734 .39854 L .63568 .41186 L .66 .805 .952 r
F
.64166 .41197 m .6494 .39878 L .63734 .39854 L F
.38848 .55997 m .38811 .55176 L .37595 .55188 L .598 .766 .96 r
F
.60263 .40246 m .5751 .40286 L .59468 .40835 L .661 .804 .952 r
F
.62959 .41265 m .62505 .40013 L .61339 .40344 L .66 .805 .952 r
F
.63568 .41186 m .62505 .40013 L .62959 .41265 L F
.63568 .41186 m .63734 .39854 L .62505 .40013 L F
.64791 .41881 m .65022 .40465 L .64246 .41782 L .659 .805 .953 r
F
.64791 .41881 m .66119 .40668 L .65022 .40465 L F
.59521 .41413 m .5755 .40864 L .56768 .41861 L .66 .805 .952 r
F
.57619 .41452 m .56768 .41861 L .56836 .42447 L .135 .056 .495 r
F
.57619 .41452 m .5755 .40864 L .56768 .41861 L F
0 g
.56449 .42889 m
.56768 .41861 L
s
.3642 .5587 m .35524 .55701 L .35471 .56202 L .453 .24 .499 r
F
0 g
.34761 .56663 m
.35471 .56202 L
s
.3642 .5587 m .36473 .55368 L .35524 .55701 L .453 .24 .499 r
F
0 g
.34816 .56163 m
.35524 .55701 L
s
.6769 .41543 m .68834 .4 L .6703 .41037 L .659 .805 .953 r
F
.6769 .41543 m .69818 .40768 L .68834 .4 L F
.42164 .56094 m .41227 .55145 L .4118 .55647 L .867 .609 .547 r
F
.42119 .56596 m .42164 .56094 L .4118 .55647 L F
0 g
.42164 .56094 m
.42918 .56644 L
s
.37991 .56505 m .37543 .55691 L .3642 .5587 L .598 .767 .96 r
F
.38799 .56498 m .37543 .55691 L .37991 .56505 L F
.39612 .56601 m .38762 .55679 L .38799 .56498 L F
.39612 .56601 m .39988 .55836 L .38762 .55679 L F
.62457 .42013 m .61415 .40932 L .60395 .41409 L .659 .805 .953 r
F
.63036 .4185 m .61415 .40932 L .62457 .42013 L F
.38799 .56498 m .38762 .55679 L .37543 .55691 L .598 .767 .96 r
F
.69729 .40183 m .69641 .396 L .68659 .38828 L .955 .636 .384 r
F
0 g
.69641 .396 m
.70179 .40522 L
s
.66844 .39879 m .67276 .38281 L .65941 .3951 L .661 .804 .952 r
F
.66844 .39879 m .68632 .38844 L .67276 .38281 L F
.64246 .41782 m .63814 .40442 L .63647 .41771 L .659 .805 .953 r
F
.64246 .41782 m .65022 .40465 L .63814 .40442 L F
.60321 .40823 m .5755 .40864 L .59521 .41413 L .66 .805 .952 r
F
.63036 .4185 m .62582 .40601 L .61415 .40932 L .659 .805 .953 r
F
.63647 .41771 m .62582 .40601 L .63036 .4185 L F
.63647 .41771 m .63814 .40442 L .62582 .40601 L F
.59593 .41999 m .57619 .41452 L .56836 .42447 L F
0 g
.56516 .43472 m
.56836 .42447 L
s
.37595 .55188 m .36525 .54867 L .36473 .55368 L .574 .343 .528 r
F
.37595 .55188 m .37646 .54687 L .36525 .54867 L F
0 g
.35578 .55201 m
.36525 .54867 L
s
.42119 .56596 m .4118 .55647 L .41134 .56149 L .867 .609 .547 r
F
0 g
.42119 .56596 m
.42874 .57144 L
s
.4118 .55647 m .41227 .55145 L .40084 .54831 L .801 .546 .553 r
F
0 g
.41227 .55145 m
.42209 .55594 L
s
.69729 .40183 m .68659 .38828 L .68746 .39413 L .955 .636 .384 r
F
.69818 .40768 m .69729 .40183 L .68746 .39413 L F
0 g
.69729 .40183 m
.70267 .41102 L
s
.66946 .40452 m .67381 .38849 L .66036 .40082 L .66 .805 .952 r
F
.66946 .40452 m .68746 .39413 L .67381 .38849 L F
.60395 .41409 m .57619 .41452 L .59593 .41999 L .659 .805 .953 r
F
.60263 .40246 m .587 .39395 L .5751 .40286 L .661 .804 .952 r
F
.61274 .3977 m .587 .39395 L .60263 .40246 L F
.37543 .55691 m .36473 .55368 L .3642 .5587 L .574 .343 .528 r
F
0 g
.35471 .56202 m
.3642 .5587 L
s
.37543 .55691 m .37595 .55188 L .36473 .55368 L .574 .343 .528 r
F
0 g
.35524 .55701 m
.36473 .55368 L
s
.4118 .55647 m .40084 .54831 L .40036 .55333 L .801 .546 .553 r
F
.41134 .56149 m .4118 .55647 L .40036 .55333 L F
0 g
.4118 .55647 m
.42164 .56094 L
s
.38811 .55176 m .37646 .54687 L .37595 .55188 L .662 .42 .544 r
F
.38811 .55176 m .38861 .54675 L .37646 .54687 L F
0 g
.36525 .54867 m
.37646 .54687 L
s
.61191 .53982 m .62319 .53798 L .62301 .54299 L .804 .544 .544 r
F
.61191 .53982 m .61211 .53481 L .62319 .53798 L F
0 g
.62319 .53798 m
.62601 .53835 L
s
.40036 .55333 m .40084 .54831 L .38861 .54675 L .735 .485 .551 r
F
0 g
.40084 .54831 m
.41227 .55145 L
s
.40036 .55333 m .38861 .54675 L .38811 .55176 L .735 .485 .551 r
F
0 g
.38861 .54675 m
.40084 .54831 L
s
.37646 .54687 m
.38861 .54675 L
s
.65941 .3951 m .65633 .37968 L .64852 .39306 L .661 .804 .952 r
F
.65941 .3951 m .67276 .38281 L .65633 .37968 L F
.69818 .40768 m .68746 .39413 L .68834 .4 L .955 .636 .384 r
F
0 g
.69818 .40768 m
.70356 .41685 L
s
.6703 .41037 m .67467 .39438 L .66119 .40668 L .659 .805 .953 r
F
.6703 .41037 m .68834 .4 L .67467 .39438 L F
.41134 .56149 m .40036 .55333 L .39988 .55836 L .801 .546 .553 r
F
0 g
.41134 .56149 m
.42119 .56596 L
s
.60321 .40823 m .58748 .39969 L .5755 .40864 L .66 .805 .952 r
F
.61339 .40344 m .58748 .39969 L .60321 .40823 L F
.58748 .39969 m .57481 .40278 L .5755 .40864 L .351 .206 .54 r
F
.58748 .39969 m .58676 .39382 L .57481 .40278 L F
0 g
.567 .41277 m
.57481 .40278 L
s
.38762 .55679 m .37595 .55188 L .37543 .55691 L .662 .42 .544 r
F
0 g
.3642 .5587 m
.37543 .55691 L
s
.38762 .55679 m .38811 .55176 L .37595 .55188 L .662 .42 .544 r
F
0 g
.36473 .55368 m
.37595 .55188 L
s
.61171 .54484 m .62301 .54299 L .62283 .548 L .804 .544 .544 r
F
.61171 .54484 m .61191 .53982 L .62301 .54299 L F
.62063 .53304 m .62301 .54299 L .62806 .53517 L .601 .765 .958 r
F
.62063 .53304 m .61191 .53982 L .62301 .54299 L F
0 g
.62301 .54299 m
.62584 .54335 L
s
.39988 .55836 m .40036 .55333 L .38811 .55176 L .735 .485 .551 r
F
0 g
.40036 .55333 m
.4118 .55647 L
s
.64729 .54945 m .64744 .54443 L .65918 .54262 L .581 .355 .538 r
F
0 g
.64547 .54445 m
.64744 .54443 L
s
.60253 .53526 m .61211 .53481 L .61191 .53982 L .876 .609 .531 r
F
.60253 .53526 m .60274 .53024 L .61211 .53481 L F
0 g
.61211 .53481 m
.61667 .53612 L
s
.65918 .54262 m .65931 .53761 L .66969 .5342 L .479 .273 .522 r
F
0 g
.65527 .53824 m
.65931 .53761 L
s
.39988 .55836 m .38811 .55176 L .38762 .55679 L .735 .485 .551 r
F
0 g
.38811 .55176 m
.40036 .55333 L
s
.39988 .55836 m
.41134 .56149 L
s
.37595 .55188 m
.38811 .55176 L
s
.61274 .3977 m .60223 .38671 L .587 .39395 L .661 .804 .952 r
F
.62432 .3944 m .60223 .38671 L .61274 .3977 L F
0 g
.63354 .54939 m
.63354 .54939 L
s
.63354 .54939 m
.63354 .54939 L
s
.63354 .54939 m
.63426 .54948 L
s
.66036 .40082 m .65727 .38536 L .6494 .39878 L .66 .805 .952 r
F
.66036 .40082 m .67381 .38849 L .65727 .38536 L F
.38985 .66386 m .38964 .66083 L .3936 .65971 L .581 .358 .542 r
F
.38558 .66443 m .38964 .66083 L .38985 .66386 L .662 .418 .541 r
F
0 g
.38953 .66085 m
.38964 .66083 L
s
.37543 .55691 m
.38762 .55679 L
s
.64852 .39306 m .63821 .37929 L .63653 .39281 L .661 .804 .952 r
F
.64852 .39306 m .65633 .37968 L .63821 .37929 L F
.62044 .53807 m .62283 .548 L .62789 .5402 L .6 .765 .958 r
F
.62044 .53807 m .61171 .54484 L .62283 .548 L F
0 g
.62283 .548 m
.63354 .54939 L
s
.38762 .55679 m
.39988 .55836 L
s
.60395 .41409 m .5882 .40559 L .57619 .41452 L .659 .805 .953 r
F
.61415 .40932 m .5882 .40559 L .60395 .41409 L F
.5882 .40559 m .5755 .40864 L .57619 .41452 L .351 .206 .54 r
F
0 g
.56836 .42447 m
.57619 .41452 L
s
.5882 .40559 m .58748 .39969 L .5755 .40864 L .351 .206 .54 r
F
0 g
.56768 .41861 m
.5755 .40864 L
s
.64729 .54945 m .65918 .54262 L .65904 .54764 L .581 .355 .538 r
F
.64428 .54117 m .64729 .54945 L .65904 .54764 L .6 .765 .958 r
F
0 g
.64393 .54948 m
.64729 .54945 L
s
.37723 .66382 m .38107 .66139 L .38128 .66442 L .797 .523 .522 r
F
.37723 .66382 m .37703 .66079 L .38107 .66139 L F
0 g
.38107 .66139 m
.38139 .66139 L
s
.39382 .66275 m .3936 .65971 L .39698 .65813 L .476 .28 .534 r
F
.38985 .66386 m .3936 .65971 L .39382 .66275 L .581 .358 .542 r
F
0 g
.38964 .66083 m
.3936 .65971 L
s
.60232 .54028 m .61191 .53982 L .61171 .54484 L .876 .609 .531 r
F
.60232 .54028 m .60253 .53526 L .61191 .53982 L F
.61437 .52997 m .61191 .53982 L .62063 .53304 L .601 .765 .958 r
F
.61437 .52997 m .60253 .53526 L .61191 .53982 L F
0 g
.61191 .53982 m
.6165 .54113 L
s
.65918 .54262 m .66969 .5342 L .66957 .53922 L .479 .273 .522 r
F
.65904 .54764 m .65918 .54262 L .66957 .53922 L F
.6523 .53491 m .65918 .54262 L .66957 .53922 L .601 .765 .958 r
F
0 g
.6506 .54394 m
.65918 .54262 L
s
.68746 .39413 m .68659 .38828 L .67296 .38262 L .884 .583 .472 r
F
0 g
.68659 .38828 m
.69641 .396 L
s
.38578 .66747 m .38558 .66443 L .38985 .66386 L .662 .418 .541 r
F
.38148 .66746 m .38558 .66443 L .38578 .66747 L .732 .472 .535 r
F
.38148 .66746 m .38128 .66442 L .38558 .66443 L F
.38545 .66157 m .38558 .66443 L .38985 .66386 L .659 .811 .956 r
F
.38257 .66156 m .38558 .66443 L .38545 .66157 L F
.38257 .66156 m .38128 .66442 L .38558 .66443 L F
.39006 .6669 m .38985 .66386 L .39382 .66275 L .581 .358 .542 r
F
.38578 .66747 m .38985 .66386 L .39006 .6669 L .662 .418 .541 r
F
.3883 .66119 m .38985 .66386 L .39382 .66275 L .659 .811 .956 r
F
.38545 .66157 m .38985 .66386 L .3883 .66119 L F
0 g
.38558 .66443 m
.38985 .66386 L
s
.62432 .3944 m .61972 .3817 L .60223 .38671 L .661 .804 .952 r
F
.63653 .39281 m .61972 .3817 L .62432 .3944 L F
.37372 .66268 m .37703 .66079 L .37723 .66382 L .864 .576 .5 r
F
.37372 .66268 m .37353 .65964 L .37703 .66079 L F
0 g
.37703 .66079 m
.38107 .66139 L
s
.37737 .65734 m .37707 .66075 L .3797 .6581 L .659 .811 .956 r
F
.37737 .65734 m .37358 .65961 L .37707 .66075 L F
.37743 .66687 m .38128 .66442 L .38148 .66746 L .797 .523 .522 r
F
.37743 .66687 m .37723 .66382 L .38128 .66442 L F
.37988 .66116 m .38128 .66442 L .38257 .66156 L .659 .811 .956 r
F
.37988 .66116 m .37723 .66382 L .38128 .66442 L F
0 g
.38128 .66442 m
.38558 .66443 L
s
.63653 .39281 m .63821 .37929 L .61972 .3817 L .661 .804 .952 r
F
.61339 .40344 m .60281 .39243 L .58748 .39969 L .66 .805 .952 r
F
.62505 .40013 m .60281 .39243 L .61339 .40344 L F
.66119 .40668 m .6581 .39126 L .65022 .40465 L .659 .805 .953 r
F
.66119 .40668 m .67467 .39438 L .6581 .39126 L F
.3972 .66116 m .39698 .65813 L .39955 .65617 L .32 .166 .51 r
F
.39382 .66275 m .39698 .65813 L .3972 .66116 L .476 .28 .534 r
F
0 g
.3936 .65971 m
.39698 .65813 L
s
.39403 .66579 m .39382 .66275 L .3972 .66116 L .476 .28 .534 r
F
.39006 .6669 m .39382 .66275 L .39403 .66579 L .581 .358 .542 r
F
.39095 .66045 m .39382 .66275 L .3972 .66116 L .659 .811 .956 r
F
.3883 .66119 m .39382 .66275 L .39095 .66045 L F
0 g
.38985 .66386 m
.39382 .66275 L
s
.38565 .66462 m .38578 .66747 L .39006 .6669 L .659 .812 .957 r
F
.38278 .66461 m .38578 .66747 L .38565 .66462 L F
.38278 .66461 m .38148 .66746 L .38578 .66747 L F
.38851 .66423 m .39006 .6669 L .39403 .66579 L F
.38565 .66462 m .39006 .6669 L .38851 .66423 L F
0 g
.38578 .66747 m
.39006 .6669 L
s
.6494 .39878 m .63903 .38498 L .63734 .39854 L .66 .805 .952 r
F
.6494 .39878 m .65727 .38536 L .63903 .38498 L F
.37392 .66573 m .37723 .66382 L .37743 .66687 L .864 .576 .5 r
F
.37392 .66573 m .37372 .66268 L .37723 .66382 L F
.37753 .6604 m .37723 .66382 L .37988 .66116 L .659 .811 .956 r
F
.37753 .6604 m .37372 .66268 L .37723 .66382 L F
0 g
.37723 .66382 m
.38128 .66442 L
s
.61417 .53501 m .61171 .54484 L .62044 .53807 L .6 .765 .958 r
F
.61417 .53501 m .60232 .54028 L .61171 .54484 L F
0 g
.61171 .54484 m
.62283 .548 L
s
.59552 .52958 m .60274 .53024 L .60253 .53526 L .949 .681 .496 r
F
.59552 .52958 m .59574 .52456 L .60274 .53024 L F
0 g
.60274 .53024 m
.60801 .53281 L
s
.38008 .66421 m .38148 .66746 L .38278 .66461 L .659 .812 .957 r
F
.38008 .66421 m .37743 .66687 L .38148 .66746 L F
0 g
.38148 .66746 m
.38578 .66747 L
s
.65904 .54764 m .66957 .53922 L .66945 .54426 L .479 .273 .522 r
F
.65216 .53995 m .65904 .54764 L .66945 .54426 L .6 .765 .958 r
F
.64428 .54117 m .65904 .54764 L .65216 .53995 L F
0 g
.64729 .54945 m
.65904 .54764 L
s
.61005 .5211 m .59595 .52451 L .60292 .53016 L .602 .764 .957 r
F
.37098 .66107 m .37353 .65964 L .37372 .66268 L .932 .634 .456 r
F
.37098 .66107 m .37079 .65803 L .37353 .65964 L F
0 g
.37353 .65964 m
.37694 .66076 L
s
.37556 .65626 m .37358 .65961 L .37737 .65734 L .659 .811 .956 r
F
.37556 .65626 m .37086 .658 L .37358 .65961 L F
.66957 .53922 m .66969 .5342 L .67802 .52943 L .334 .159 .489 r
F
0 g
.66095 .53707 m
.66969 .5342 L
s
.3972 .66116 m .39955 .65617 L .39977 .65921 L .32 .166 .51 r
F
.39741 .6642 m .3972 .66116 L .39977 .65921 L F
.39403 .66579 m .3972 .66116 L .39741 .6642 L .476 .28 .534 r
F
.3932 .65938 m .3972 .66116 L .39977 .65921 L .659 .811 .956 r
F
.39095 .66045 m .3972 .66116 L .3932 .65938 L F
0 g
.39382 .66275 m
.3972 .66116 L
s
.39116 .66349 m .39403 .66579 L .39741 .6642 L .659 .812 .957 r
F
.38851 .66423 m .39403 .66579 L .39116 .66349 L F
0 g
.39006 .6669 m
.39403 .66579 L
s
.68746 .39413 m .67296 .38262 L .67381 .38849 L .884 .583 .472 r
F
.68834 .4 m .68746 .39413 L .67381 .38849 L F
0 g
.68746 .39413 m
.69729 .40183 L
s
.39977 .65921 m .39955 .65617 L .40114 .65398 L .053 0 .441 r
F
0 g
.39698 .65813 m
.39955 .65617 L
s
.39466 .65503 m .39948 .65615 L .40105 .65397 L .659 .811 .956 r
F
.39295 .65633 m .39948 .65615 L .39466 .65503 L F
.62505 .40013 m .62043 .3874 L .60281 .39243 L .66 .805 .952 r
F
.63734 .39854 m .62043 .3874 L .62505 .40013 L F
.37773 .66344 m .37743 .66687 L .38008 .66421 L .659 .812 .957 r
F
.37773 .66344 m .37392 .66573 L .37743 .66687 L F
0 g
.37743 .66687 m
.38148 .66746 L
s
.61415 .40932 m .60356 .39833 L .5882 .40559 L .659 .805 .953 r
F
.62582 .40601 m .60356 .39833 L .61415 .40932 L F
.63734 .39854 m .63903 .38498 L .62043 .3874 L .66 .805 .952 r
F
.37118 .66412 m .37372 .66268 L .37392 .66573 L .932 .634 .456 r
F
.37118 .66412 m .37098 .66107 L .37372 .66268 L F
.37571 .65932 m .37372 .66268 L .37753 .6604 L .659 .811 .956 r
F
.37571 .65932 m .37098 .66107 L .37372 .66268 L F
0 g
.37372 .66268 m
.37715 .6638 L
s
.39741 .6642 m .39977 .65921 L .39999 .66225 L .32 .166 .51 r
F
.39342 .66243 m .39741 .6642 L .39999 .66225 L .659 .812 .957 r
F
.39116 .66349 m .39741 .6642 L .39342 .66243 L F
0 g
.39403 .66579 m
.39741 .6642 L
s
.39977 .65921 m .40114 .65398 L .40136 .65702 L .053 0 .441 r
F
.39999 .66225 m .39977 .65921 L .40136 .65702 L F
.39492 .65808 m .39977 .65921 L .40136 .65702 L .659 .811 .956 r
F
.3932 .65938 m .39977 .65921 L .39492 .65808 L F
0 g
.3972 .66116 m
.39977 .65921 L
s
.5953 .53462 m .60253 .53526 L .60232 .54028 L .949 .681 .496 r
F
.5953 .53462 m .59552 .52958 L .60253 .53526 L F
.60971 .52616 m .60253 .53526 L .61437 .52997 L .601 .765 .958 r
F
.60971 .52616 m .59552 .52958 L .60253 .53526 L F
0 g
.60253 .53526 m
.60783 .53783 L
s
.38027 .65452 m .37556 .65626 L .37737 .65734 L .659 .811 .956 r
F
.3692 .6591 m .37079 .65803 L .37098 .66107 L .98 .685 .357 r
F
.3692 .6591 m .36901 .65605 L .37079 .65803 L F
0 g
.37079 .65803 m
.37353 .65964 L
s
.37438 .65495 m .37086 .658 L .37556 .65626 L .659 .811 .956 r
F
.37438 .65495 m .36909 .65604 L .37086 .658 L F
.65022 .40465 m .63984 .39089 L .63814 .40442 L .659 .805 .953 r
F
.65022 .40465 m .6581 .39126 L .63984 .39089 L F
.66957 .53922 m .67802 .52943 L .67791 .53446 L .334 .159 .489 r
F
.66945 .54426 m .66957 .53922 L .67791 .53446 L F
.65924 .53262 m .66957 .53922 L .67791 .53446 L .601 .765 .958 r
F
.6523 .53491 m .66957 .53922 L .65924 .53262 L F
0 g
.66077 .5421 m
.66957 .53922 L
s
.38135 .65811 m .37753 .6604 L .37988 .66116 L .659 .811 .956 r
F
.39466 .65503 m .40105 .65397 L .3957 .65357 L F
.38552 .66175 m .38565 .66462 L .38851 .66423 L .659 .812 .957 r
F
.38408 .66174 m .38565 .66462 L .38552 .66175 L F
.38408 .66174 m .38278 .66461 L .38565 .66462 L F
.38696 .66156 m .38851 .66423 L .39116 .66349 L F
.38552 .66175 m .38851 .66423 L .38696 .66156 L F
.37591 .66237 m .37392 .66573 L .37773 .66344 L F
.37591 .66237 m .37118 .66412 L .37392 .66573 L F
0 g
.37392 .66573 m
.37743 .66687 L
s
.60281 .39243 m .58676 .39382 L .58748 .39969 L .486 .301 .554 r
F
.60281 .39243 m .60207 .38654 L .58676 .39382 L F
0 g
.57481 .40278 m
.58676 .39382 L
s
.40136 .65702 m .40114 .65398 L .40162 .6517 L 0 0 .246 r
F
0 g
.39955 .65617 m
.40114 .65398 L
s
.3957 .65357 m .40105 .65397 L .40154 .6517 L .659 .811 .956 r
F
.38273 .66154 m .38278 .66461 L .38408 .66174 L .659 .812 .957 r
F
.38273 .66154 m .38008 .66421 L .38278 .66461 L F
.68834 .4 m .67381 .38849 L .67467 .39438 L .884 .583 .472 r
F
0 g
.68834 .4 m
.69818 .40768 L
s
.38828 .66118 m .39116 .66349 L .39342 .66243 L .659 .812 .957 r
F
.38696 .66156 m .39116 .66349 L .38828 .66118 L F
.62582 .40601 m .6212 .3933 L .60356 .39833 L .659 .805 .953 r
F
.63814 .40442 m .6212 .3933 L .62582 .40601 L F
.39999 .66225 m .40136 .65702 L .40158 .66006 L .053 0 .441 r
F
.39513 .66112 m .39999 .66225 L .40158 .66006 L .659 .812 .957 r
F
.39342 .66243 m .39999 .66225 L .39513 .66112 L F
0 g
.39741 .6642 m
.39999 .66225 L
s
.38044 .65757 m .37753 .6604 L .38135 .65811 L .659 .811 .956 r
F
.38044 .65757 m .37571 .65932 L .37753 .6604 L F
.37968 .65386 m .37556 .65626 L .38027 .65452 L F
.37968 .65386 m .37438 .65495 L .37556 .65626 L F
.3694 .66215 m .37098 .66107 L .37118 .66412 L .98 .685 .357 r
F
.3694 .66215 m .3692 .6591 L .37098 .66107 L F
.37453 .658 m .37098 .66107 L .37571 .65932 L .659 .811 .956 r
F
.37453 .658 m .3692 .6591 L .37098 .66107 L F
0 g
.37098 .66107 m
.37372 .66268 L
s
.38156 .66116 m .38008 .66421 L .38273 .66154 L .659 .812 .957 r
F
.38156 .66116 m .37773 .66344 L .38008 .66421 L F
.63814 .40442 m .63984 .39089 L .6212 .3933 L .659 .805 .953 r
F
.39492 .65808 m .40136 .65702 L .39597 .65662 L .659 .811 .956 r
F
.3957 .65357 m .40154 .6517 L .39602 .65206 L F
.39034 .65317 m .3957 .65357 L .39602 .65206 L F
.38941 .66065 m .39342 .66243 L .39513 .66112 L .659 .812 .957 r
F
.38828 .66118 m .39342 .66243 L .38941 .66065 L F
.60951 .53121 m .60232 .54028 L .61417 .53501 L .6 .765 .958 r
F
.60951 .53121 m .5953 .53462 L .60232 .54028 L F
0 g
.60232 .54028 m
.61171 .54484 L
s
.40136 .65702 m .40162 .6517 L .40185 .65474 L 0 0 .246 r
F
.40158 .66006 m .40136 .65702 L .40185 .65474 L F
.39597 .65662 m .40136 .65702 L .40185 .65474 L .659 .811 .956 r
F
0 g
.39977 .65921 m
.40136 .65702 L
s
.66945 .54426 m .67791 .53446 L .6778 .5395 L .334 .159 .489 r
F
.65911 .53767 m .66945 .54426 L .6778 .5395 L .6 .765 .958 r
F
.65216 .53995 m .66945 .54426 L .65911 .53767 L F
0 g
.65904 .54764 m
.66945 .54426 L
s
.36851 .65689 m .36901 .65605 L .3692 .6591 L .884 .648 .126 r
F
.36851 .65689 m .36832 .65385 L .36901 .65605 L F
0 g
.36901 .65605 m
.37079 .65803 L
s
.37393 .65348 m .36909 .65604 L .37438 .65495 L .659 .811 .956 r
F
.37393 .65348 m .3684 .65384 L .36909 .65604 L F
.38065 .66062 m .37773 .66344 L .38156 .66116 L .659 .812 .957 r
F
.38065 .66062 m .37591 .66237 L .37773 .66344 L F
.37985 .65691 m .37571 .65932 L .38044 .65757 L .659 .811 .956 r
F
.37985 .65691 m .37453 .658 L .37571 .65932 L F
.37473 .66105 m .37118 .66412 L .37591 .66237 L .659 .812 .957 r
F
.37473 .66105 m .3694 .66215 L .37118 .66412 L F
0 g
.37118 .66412 m
.37392 .66573 L
s
.37945 .65313 m .37438 .65495 L .37968 .65386 L .659 .811 .956 r
F
.37945 .65313 m .37393 .65348 L .37438 .65495 L F
.39034 .65317 m .39602 .65206 L .3905 .65241 L F
.39513 .66112 m .40158 .66006 L .39619 .65966 L .659 .812 .957 r
F
.39027 .66 m .39513 .66112 L .39619 .65966 L F
.38941 .66065 m .39513 .66112 L .39027 .66 L F
0 g
.38558 .6595 m
.38756 .65929 L
s
.38558 .6595 m
.38558 .6595 L
s
.38358 .65923 m
.38558 .6595 L
s
.39602 .65206 m .40154 .6517 L .4009 .6495 L .659 .811 .956 r
F
.40185 .65474 m .40162 .6517 L .40098 .64948 L .865 .632 .099 r
F
0 g
.40114 .65398 m
.40147 .65244 L
s
.39597 .65662 m .40185 .65474 L .39629 .6551 L .659 .811 .956 r
F
.39058 .65622 m .39597 .65662 L .39629 .6551 L F
.60356 .39833 m .58748 .39969 L .5882 .40559 L .486 .301 .554 r
F
0 g
.57619 .41452 m
.5882 .40559 L
s
.60356 .39833 m .60281 .39243 L .58748 .39969 L .486 .301 .554 r
F
0 g
.5755 .40864 m
.58748 .39969 L
s
.67381 .38849 m .67296 .38262 L .65644 .37948 L .808 .528 .514 r
F
0 g
.67296 .38262 m
.68659 .38828 L
s
.39602 .65206 m .4009 .6495 L .39559 .65059 L .659 .811 .956 r
F
.3905 .65241 m .39602 .65206 L .39559 .65059 L F
.40158 .66006 m .40185 .65474 L .40207 .65779 L 0 0 .246 r
F
.39619 .65966 m .40158 .66006 L .40207 .65779 L .659 .812 .957 r
F
0 g
.39999 .66225 m
.40158 .66006 L
s
.59135 .52317 m .59574 .52456 L .59552 .52958 L .993 .745 .404 r
F
.59135 .52317 m .59158 .51813 L .59574 .52456 L F
0 g
.59574 .52456 m
.60046 .52839 L
s
.60733 .51681 m .59595 .52451 L .61005 .5211 L .602 .764 .957 r
F
.60733 .51681 m .59181 .51811 L .59595 .52451 L F
.38539 .65887 m .38552 .66175 L .38696 .66156 L .659 .812 .957 r
F
.38539 .65887 m .38408 .66174 L .38552 .66175 L F
.38539 .65887 m .38696 .66156 L .38828 .66118 L F
0 g
.38756 .65929 m
.38881 .65884 L
s
.3687 .65995 m .3692 .6591 L .3694 .66215 L .884 .648 .126 r
F
.3687 .65995 m .36851 .65689 L .3692 .6591 L F
.37407 .65653 m .3692 .6591 L .37453 .658 L .659 .811 .956 r
F
.37407 .65653 m .36851 .65689 L .3692 .6591 L F
0 g
.3692 .6591 m
.37098 .66107 L
s
.3905 .65241 m .39559 .65059 L .39028 .65168 L .659 .811 .956 r
F
.38539 .65887 m .38273 .66154 L .38408 .66174 L .659 .812 .957 r
F
0 g
.38229 .65874 m
.38358 .65923 L
s
.67791 .53446 m .67802 .52943 L .68374 .52358 L .099 0 .416 r
F
0 g
.67051 .53373 m
.67802 .52943 L
s
.38881 .65884 m
.38966 .65825 L
s
.38539 .65887 m .38828 .66118 L .38941 .66065 L .659 .812 .957 r
F
0 g
.3814 .65813 m
.38229 .65874 L
s
.62926 .53124 m .62789 .5402 L .633 .53231 L .6 .765 .958 r
F
.62926 .53124 m .62044 .53807 L .62789 .5402 L F
.38006 .65996 m .37591 .66237 L .38065 .66062 L .659 .812 .957 r
F
.38006 .65996 m .37473 .66105 L .37591 .66237 L F
.38539 .65887 m .38156 .66116 L .38273 .66154 L F
.37963 .65617 m .37453 .658 L .37985 .65691 L .659 .811 .956 r
F
.37963 .65617 m .37407 .65653 L .37453 .658 L F
.39058 .65622 m .39629 .6551 L .39074 .65546 L F
.37961 .65237 m .37393 .65348 L .37945 .65313 L F
.38539 .65887 m .38941 .66065 L .39027 .66 L .659 .812 .957 r
F
0 g
.38966 .65825 m
.39014 .65755 L
s
.38086 .65741 m
.3814 .65813 L
s
.40185 .65474 m .40098 .64948 L .4012 .65253 L .865 .632 .099 r
F
.39629 .6551 m .40185 .65474 L .4012 .65253 L .659 .811 .956 r
F
.40207 .65779 m .40185 .65474 L .4012 .65253 L .865 .632 .099 r
F
0 g
.40136 .65702 m
.40169 .65548 L
s
.39028 .65168 m .39443 .64927 L .3897 .65102 L .659 .811 .956 r
F
0 g
.38963 .65388 m
.38974 .65137 L
s
.39028 .65168 m .39559 .65059 L .39443 .64927 L .659 .811 .956 r
F
0 g
.38975 .651 m
.3927 .58011 L
s
.39619 .65966 m .40207 .65779 L .39651 .65815 L .659 .812 .957 r
F
.39079 .65926 m .39619 .65966 L .39651 .65815 L F
.39027 .66 m .39619 .65966 L .39079 .65926 L F
.37423 .65197 m .3684 .65384 L .37393 .65348 L .659 .811 .956 r
F
.37961 .65237 m .37423 .65197 L .37393 .65348 L F
.38539 .65887 m .38065 .66062 L .38156 .66116 L .659 .812 .957 r
F
.39629 .6551 m .4012 .65253 L .39586 .65362 L .659 .811 .956 r
F
.39074 .65546 m .39629 .6551 L .39586 .65362 L F
.37423 .65197 m .36884 .65157 L .3684 .65384 L F
.36895 .65461 m .36832 .65385 L .36851 .65689 L 0 0 .221 r
F
0 g
.3688 .65538 m
.36901 .65605 L
s
.36895 .65461 m .36876 .65156 L .36832 .65385 L 0 0 .221 r
F
.38539 .65887 m .39027 .66 L .39079 .65926 L .659 .812 .957 r
F
.37427 .65959 m .3694 .66215 L .37473 .66105 L F
.37427 .65959 m .3687 .65995 L .3694 .66215 L F
0 g
.3694 .66215 m
.37118 .66412 L
s
.38012 .65164 m .37423 .65197 L .37961 .65237 L .659 .811 .956 r
F
.39074 .65546 m .39586 .65362 L .39052 .65472 L F
0 g
.39014 .65755 m
.39022 .6567 L
s
.39559 .65059 m .39917 .64751 L .39443 .64927 L .659 .811 .956 r
F
.39559 .65059 m .4009 .6495 L .39917 .64751 L F
0 g
.38072 .65656 m
.38086 .65741 L
s
.3897 .65102 m .39262 .64818 L .3888 .65048 L .659 .811 .956 r
F
.3897 .65102 m .39443 .64927 L .39262 .64818 L F
.38539 .65887 m .38006 .65996 L .38065 .66062 L .659 .812 .957 r
F
.37983 .65923 m .37473 .66105 L .38006 .65996 L F
.37983 .65923 m .37427 .65959 L .37473 .66105 L F
.39079 .65926 m .39651 .65815 L .39095 .65851 L F
.38539 .65887 m .39079 .65926 L .39095 .65851 L F
.37978 .65541 m .37407 .65653 L .37963 .65617 L .659 .811 .956 r
F
.4012 .65253 m .40098 .64948 L .39924 .64749 L .979 .682 .343 r
F
0 g
.40098 .64948 m
.40162 .6517 L
s
.59113 .52822 m .59552 .52958 L .5953 .53462 L .993 .745 .404 r
F
.59113 .52822 m .59135 .52317 L .59552 .52958 L F
.60697 .52187 m .59552 .52958 L .60971 .52616 L .601 .765 .958 r
F
.60697 .52187 m .59135 .52317 L .59552 .52958 L F
0 g
.59552 .52958 m
.60027 .53343 L
s
.62612 .52969 m .62044 .53807 L .62926 .53124 L .6 .765 .958 r
F
.62612 .52969 m .61417 .53501 L .62044 .53807 L F
.67381 .38849 m .65644 .37948 L .65727 .38536 L .808 .528 .514 r
F
.67467 .39438 m .67381 .38849 L .65727 .38536 L F
0 g
.67381 .38849 m
.68746 .39413 L
s
.38012 .65164 m .37526 .6505 L .37423 .65197 L .659 .811 .956 r
F
.38097 .65098 m .37526 .6505 L .38012 .65164 L F
.6452 .53218 m .65216 .53995 L .65911 .53767 L .6 .765 .958 r
F
.40207 .65779 m .4012 .65253 L .40142 .65558 L .865 .632 .099 r
F
.39651 .65815 m .40207 .65779 L .40142 .65558 L .659 .812 .957 r
F
0 g
.40158 .66006 m
.40207 .65779 L
s
.39052 .65472 m .39469 .6523 L .38994 .65406 L .659 .811 .956 r
F
.39052 .65472 m .39586 .65362 L .39469 .6523 L F
.37437 .65501 m .36851 .65689 L .37407 .65653 L F
.37978 .65541 m .37437 .65501 L .37407 .65653 L F
.67791 .53446 m .68374 .52358 L .68364 .52862 L .099 0 .416 r
F
.6778 .5395 m .67791 .53446 L .68364 .52862 L F
.6648 .52942 m .67791 .53446 L .68364 .52862 L .601 .765 .958 r
F
.65924 .53262 m .67791 .53446 L .6648 .52942 L F
0 g
.67035 .53877 m
.67791 .53446 L
s
.3888 .65048 m .39029 .64741 L .38763 .6501 L .659 .811 .956 r
F
.3888 .65048 m .39262 .64818 L .39029 .64741 L F
0 g
.38072 .65656 m
.38129 .6555 L
s
.37526 .6505 m .36884 .65157 L .37423 .65197 L .659 .811 .956 r
F
.39651 .65815 m .40142 .65558 L .39607 .65667 L .659 .812 .957 r
F
.39095 .65851 m .39651 .65815 L .39607 .65667 L F
.38539 .65887 m .37983 .65923 L .38006 .65996 L F
.36914 .65766 m .36851 .65689 L .3687 .65995 L 0 0 .221 r
F
0 g
.36899 .65843 m
.3692 .6591 L
s
.37437 .65501 m .36895 .65461 L .36851 .65689 L .659 .811 .956 r
F
.36914 .65766 m .36895 .65461 L .36851 .65689 L 0 0 .221 r
F
.38097 .65098 m .37696 .64919 L .37526 .6505 L .659 .811 .956 r
F
.3821 .65045 m .37696 .64919 L .38097 .65098 L F
.39095 .65851 m .39607 .65667 L .39073 .65777 L .659 .812 .957 r
F
.38539 .65887 m .39095 .65851 L .39073 .65777 L F
.3803 .65468 m .37437 .65501 L .37978 .65541 L .659 .811 .956 r
F
.39586 .65362 m .39946 .65053 L .39469 .6523 L F
.39586 .65362 m .4012 .65253 L .39946 .65053 L F
.38763 .6501 m .38759 .647 L .38628 .64989 L F
.38763 .6501 m .39029 .64741 L .38759 .647 L F
.39443 .64927 m .39646 .64588 L .39262 .64818 L F
.39443 .64927 m .39917 .64751 L .39646 .64588 L F
.62043 .3874 m .60207 .38654 L .60281 .39243 L .584 .369 .556 r
F
.62043 .3874 m .61965 .3815 L .60207 .38654 L F
0 g
.58676 .39382 m
.60207 .38654 L
s
.38994 .65406 m .39288 .65121 L .38903 .65352 L .659 .811 .956 r
F
.38994 .65406 m .39469 .6523 L .39288 .65121 L F
.38539 .65887 m .37998 .65847 L .37983 .65923 L .659 .812 .957 r
F
.38539 .65887 m .38051 .65773 L .37998 .65847 L F
.38539 .65887 m .38136 .65708 L .38051 .65773 L F
.38539 .65887 m .38249 .65654 L .38136 .65708 L F
.38539 .65887 m .38382 .65617 L .38249 .65654 L F
.38539 .65887 m .38526 .65597 L .38382 .65617 L F
.38539 .65887 m .38671 .65598 L .38526 .65597 L F
.38539 .65887 m .38806 .65618 L .38671 .65598 L F
.38539 .65887 m .38924 .65657 L .38806 .65618 L F
.38539 .65887 m .39015 .65711 L .38924 .65657 L F
0 g
.38956 .65562 m
.39022 .6567 L
s
.38539 .65887 m .39073 .65777 L .39015 .65711 L .659 .812 .957 r
F
.3821 .65045 m .37921 .64812 L .37696 .64919 L .659 .811 .956 r
F
.38342 .65008 m .37921 .64812 L .3821 .65045 L F
.38628 .64989 m .38472 .64699 L .38485 .64989 L F
.38628 .64989 m .38759 .647 L .38472 .64699 L F
.37998 .65847 m .37427 .65959 L .37983 .65923 L .659 .812 .957 r
F
.4012 .65253 m .39924 .64749 L .39946 .65053 L .979 .682 .343 r
F
.40142 .65558 m .4012 .65253 L .39946 .65053 L F
0 g
.4012 .65253 m
.40185 .65474 L
s
.38815 .65477 m
.38956 .65562 L
s
.38956 .65562 m
.38956 .65562 L
s
.38342 .65008 m .38185 .64737 L .37921 .64812 L .659 .811 .956 r
F
.38485 .64989 m .38185 .64737 L .38342 .65008 L F
0 g
.38129 .6555 m
.38129 .6555 L
s
.38129 .6555 m
.38264 .65468 L
s
.38485 .64989 m .38472 .64699 L .38185 .64737 L .659 .811 .956 r
F
.3803 .65468 m .37541 .65354 L .37437 .65501 L F
.38116 .65402 m .37541 .65354 L .3803 .65468 L F
.37526 .6505 m .37038 .64937 L .36884 .65157 L F
.3705 .6524 m .36876 .65156 L .36895 .65461 L .032 0 .429 r
F
.3705 .6524 m .37031 .64935 L .36876 .65156 L F
0 g
.36832 .65385 m
.36876 .65156 L
s
.39073 .65777 m .39491 .65535 L .39015 .65711 L .659 .812 .957 r
F
.39073 .65777 m .39607 .65667 L .39491 .65535 L F
.37457 .65807 m .3687 .65995 L .37427 .65959 L F
.37998 .65847 m .37457 .65807 L .37427 .65959 L F
.38903 .65352 m .39053 .65043 L .38785 .65313 L .659 .811 .956 r
F
.38903 .65352 m .39288 .65121 L .39053 .65043 L F
.37541 .65354 m .36895 .65461 L .37437 .65501 L F
.37457 .65807 m .36914 .65766 L .3687 .65995 L .659 .812 .957 r
F
0 g
.3687 .65995 m
.3694 .66215 L
s
.37696 .64919 m .37038 .64937 L .37526 .6505 L .659 .811 .956 r
F
.38116 .65402 m .37712 .65223 L .37541 .65354 L F
.38229 .65349 m .37712 .65223 L .38116 .65402 L F
.60676 .52693 m .5953 .53462 L .60951 .53121 L .6 .765 .958 r
F
.60676 .52693 m .59113 .52822 L .5953 .53462 L F
0 g
.5953 .53462 m
.60232 .54028 L
s
.38051 .65773 m .37457 .65807 L .37998 .65847 L .659 .812 .957 r
F
.39607 .65667 m .39968 .65359 L .39491 .65535 L F
.39607 .65667 m .40142 .65558 L .39968 .65359 L F
0 g
.38676 .65437 m
.38815 .65477 L
s
.38264 .65468 m
.384 .65433 L
s
.38785 .65313 m .38782 .65002 L .3865 .65293 L .659 .811 .956 r
F
.38785 .65313 m .39053 .65043 L .38782 .65002 L F
.39946 .65053 m .39924 .64749 L .39652 .64585 L .934 .633 .448 r
F
0 g
.39924 .64749 m
.40098 .64948 L
s
.39469 .6523 m .39674 .6489 L .39288 .65121 L .659 .811 .956 r
F
.39469 .6523 m .39946 .65053 L .39674 .6489 L F
.39262 .64818 m .39296 .64472 L .39029 .64741 L F
.39262 .64818 m .39646 .64588 L .39296 .64472 L F
.39015 .65711 m .39309 .65426 L .38924 .65657 L .659 .812 .957 r
F
.39015 .65711 m .39491 .65535 L .39309 .65426 L F
.6778 .5395 m .68364 .52862 L .68354 .53368 L .099 0 .416 r
F
.66467 .53448 m .6778 .5395 L .68354 .53368 L .6 .765 .958 r
F
.65911 .53767 m .6778 .5395 L .66467 .53448 L F
0 g
.66945 .54426 m
.6778 .5395 L
s
.62289 .51551 m .60733 .51681 L .61005 .5211 L .602 .764 .957 r
F
.38229 .65349 m .37938 .65115 L .37712 .65223 L .659 .811 .956 r
F
.38362 .65311 m .37938 .65115 L .38229 .65349 L F
0 g
.38537 .65424 m
.38676 .65437 L
s
.67467 .39438 m .65727 .38536 L .6581 .39126 L .808 .528 .514 r
F
0 g
.67467 .39438 m
.68834 .4 L
s
.384 .65433 m
.38537 .65424 L
s
.65727 .38536 m .65644 .37948 L .63823 .37909 L .736 .477 .537 r
F
0 g
.65644 .37948 m
.67296 .38262 L
s
.3865 .65293 m .38492 .65001 L .38505 .65292 L .659 .811 .956 r
F
.3865 .65293 m .38782 .65002 L .38492 .65001 L F
.40142 .65558 m .39946 .65053 L .39968 .65359 L .979 .682 .343 r
F
0 g
.40142 .65558 m
.40207 .65779 L
s
.38362 .65311 m .38204 .6504 L .37938 .65115 L .659 .811 .956 r
F
.38505 .65292 m .38204 .6504 L .38362 .65311 L F
.38505 .65292 m .38492 .65001 L .38204 .6504 L F
.38051 .65773 m .37561 .6566 L .37457 .65807 L .659 .812 .957 r
F
.38136 .65708 m .37561 .6566 L .38051 .65773 L F
.3707 .65546 m .36895 .65461 L .36914 .65766 L .032 0 .429 r
F
.37541 .65354 m .3705 .6524 L .36895 .65461 L .659 .811 .956 r
F
.3707 .65546 m .3705 .6524 L .36895 .65461 L .032 0 .429 r
F
0 g
.36851 .65689 m
.36895 .65461 L
s
.6238 .52778 m .61417 .53501 L .62612 .52969 L .6 .765 .958 r
F
.6238 .52778 m .60951 .53121 L .61417 .53501 L F
.38924 .65657 m .39074 .65349 L .38806 .65618 L .659 .812 .957 r
F
.38924 .65657 m .39309 .65426 L .39074 .65349 L F
.64868 .53103 m .65911 .53767 L .66467 .53448 L .6 .765 .958 r
F
.6452 .53218 m .65911 .53767 L .64868 .53103 L F
.37696 .64919 m .37293 .6474 L .37038 .64937 L .659 .811 .956 r
F
.37921 .64812 m .37293 .6474 L .37696 .64919 L F
.37561 .6566 m .36914 .65766 L .37457 .65807 L .659 .812 .957 r
F
.37712 .65223 m .3705 .6524 L .37541 .65354 L .659 .811 .956 r
F
.38136 .65708 m .37732 .65528 L .37561 .6566 L .659 .812 .957 r
F
.38249 .65654 m .37732 .65528 L .38136 .65708 L F
.39029 .64741 m .38891 .6441 L .38759 .647 L .659 .811 .956 r
F
.39029 .64741 m .39296 .64472 L .38891 .6441 L F
.6212 .3933 m .60281 .39243 L .60356 .39833 L .584 .369 .556 r
F
0 g
.5882 .40559 m
.60356 .39833 L
s
.6212 .3933 m .62043 .3874 L .60281 .39243 L .584 .369 .556 r
F
0 g
.58748 .39969 m
.60281 .39243 L
s
.38806 .65618 m .38803 .65308 L .38671 .65598 L .659 .812 .957 r
F
.38806 .65618 m .39074 .65349 L .38803 .65308 L F
.39946 .65053 m .39652 .64585 L .39674 .6489 L .934 .633 .448 r
F
.39968 .65359 m .39946 .65053 L .39674 .6489 L F
0 g
.39946 .65053 m
.4012 .65253 L
s
.39491 .65535 m .39695 .65195 L .39309 .65426 L .659 .812 .957 r
F
.39491 .65535 m .39968 .65359 L .39695 .65195 L F
.39288 .65121 m .39322 .64773 L .39053 .65043 L .659 .811 .956 r
F
.39288 .65121 m .39674 .6489 L .39322 .64773 L F
.37306 .65042 m .37031 .64935 L .3705 .6524 L .309 .156 .504 r
F
.37306 .65042 m .37287 .64737 L .37031 .64935 L F
0 g
.36876 .65156 m
.37031 .64935 L
s
.38249 .65654 m .37958 .65421 L .37732 .65528 L .659 .812 .957 r
F
.38382 .65617 m .37958 .65421 L .38249 .65654 L F
.38671 .65598 m .38513 .65307 L .38526 .65597 L F
.38671 .65598 m .38803 .65308 L .38513 .65307 L F
.37921 .64812 m .37631 .64579 L .37293 .6474 L .659 .811 .956 r
F
.38185 .64737 m .37631 .64579 L .37921 .64812 L F
.38382 .65617 m .38225 .65345 L .37958 .65421 L .659 .812 .957 r
F
.38526 .65597 m .38225 .65345 L .38382 .65617 L F
.38526 .65597 m .38513 .65307 L .38225 .65345 L F
.38759 .647 m .38458 .64408 L .38472 .64699 L .659 .811 .956 r
F
.38759 .647 m .38891 .6441 L .38458 .64408 L F
.37561 .6566 m .3707 .65546 L .36914 .65766 L .659 .812 .957 r
F
0 g
.3687 .65995 m
.36914 .65766 L
s
.63903 .38498 m .61965 .3815 L .62043 .3874 L .663 .425 .55 r
F
.63903 .38498 m .63823 .37909 L .61965 .3815 L F
0 g
.60207 .38654 m
.61965 .3815 L
s
.39674 .6489 m .39652 .64585 L .393 .64468 L .865 .575 .495 r
F
0 g
.39652 .64585 m
.39924 .64749 L
s
.59035 .51643 m .59158 .51813 L .59135 .52317 L .862 .698 .17 r
F
.59035 .51643 m .59058 .51138 L .59158 .51813 L F
0 g
.59158 .51813 m
.59466 .52289 L
s
.60671 .51233 m .59181 .51811 L .60733 .51681 L .602 .764 .957 r
F
.60671 .51233 m .59082 .51139 L .59181 .51811 L F
.38185 .64737 m .38028 .64466 L .37631 .64579 L .659 .811 .956 r
F
.38472 .64699 m .38028 .64466 L .38185 .64737 L F
.37712 .65223 m .37306 .65042 L .3705 .6524 L F
.37938 .65115 m .37306 .65042 L .37712 .65223 L F
.38472 .64699 m .38458 .64408 L .38028 .64466 L F
.62263 .52057 m .60697 .52187 L .60971 .52616 L .601 .765 .958 r
F
.37732 .65528 m .3707 .65546 L .37561 .6566 L .659 .812 .957 r
F
.68364 .52862 m .68374 .52358 L .68643 .51704 L 0 0 .239 r
F
0 g
.6786 .52884 m
.68374 .52358 L
s
.6648 .52942 m .68364 .52862 L .66858 .52551 L .601 .765 .958 r
F
.66856 .52043 m .68352 .52353 L .68619 .51703 L .602 .764 .957 r
F
.39053 .65043 m .38914 .64711 L .38782 .65002 L .659 .811 .956 r
F
.39053 .65043 m .39322 .64773 L .38914 .64711 L F
.65727 .38536 m .63823 .37909 L .63903 .38498 L .736 .477 .537 r
F
0 g
.61965 .3815 m
.63823 .37909 L
s
.63823 .37909 m
.65644 .37948 L
s
.39968 .65359 m .39674 .6489 L .39695 .65195 L .934 .633 .448 r
F
0 g
.39968 .65359 m
.40142 .65558 L
s
.39309 .65426 m .39343 .65079 L .39074 .65349 L .659 .812 .957 r
F
.39309 .65426 m .39695 .65195 L .39343 .65079 L F
.6581 .39126 m .65727 .38536 L .63903 .38498 L .736 .477 .537 r
F
0 g
.65727 .38536 m
.67381 .38849 L
s
.37326 .65348 m .3705 .6524 L .3707 .65546 L .309 .156 .504 r
F
.37326 .65348 m .37306 .65042 L .3705 .6524 L F
0 g
.36895 .65461 m
.3705 .6524 L
s
.37938 .65115 m .37646 .64881 L .37306 .65042 L .659 .811 .956 r
F
.38204 .6504 m .37646 .64881 L .37938 .65115 L F
.37646 .64881 m .37287 .64737 L .37306 .65042 L .471 .274 .53 r
F
.37646 .64881 m .37626 .64575 L .37287 .64737 L F
0 g
.37031 .64935 m
.37287 .64737 L
s
.38782 .65002 m .38479 .64709 L .38492 .65001 L .659 .811 .956 r
F
.38782 .65002 m .38914 .64711 L .38479 .64709 L F
.39674 .6489 m .393 .64468 L .39322 .64773 L .865 .575 .495 r
F
.39695 .65195 m .39674 .6489 L .39322 .64773 L F
0 g
.39674 .6489 m
.39946 .65053 L
s
.37732 .65528 m .37326 .65348 L .3707 .65546 L .659 .812 .957 r
F
0 g
.36914 .65766 m
.3707 .65546 L
s
.37958 .65421 m .37326 .65348 L .37732 .65528 L .659 .812 .957 r
F
.38204 .6504 m .38046 .64767 L .37646 .64881 L .659 .811 .956 r
F
.38492 .65001 m .38046 .64767 L .38204 .6504 L F
.38492 .65001 m .38479 .64709 L .38046 .64767 L F
.39322 .64773 m .393 .64468 L .38893 .64406 L .798 .521 .519 r
F
0 g
.393 .64468 m
.39652 .64585 L
s
.39074 .65349 m .38935 .65017 L .38803 .65308 L .659 .812 .957 r
F
.39074 .65349 m .39343 .65079 L .38935 .65017 L F
.59012 .52149 m .59135 .52317 L .59113 .52822 L .862 .698 .17 r
F
.59012 .52149 m .59035 .51643 L .59135 .52317 L F
.60635 .51737 m .59135 .52317 L .60697 .52187 L .601 .765 .958 r
F
.60635 .51737 m .59035 .51643 L .59135 .52317 L F
0 g
.59135 .52317 m
.59445 .52794 L
s
.37958 .65421 m .37666 .65187 L .37326 .65348 L .659 .812 .957 r
F
.38225 .65345 m .37666 .65187 L .37958 .65421 L F
.62244 .52563 m .60951 .53121 L .6238 .52778 L .6 .765 .958 r
F
.62244 .52563 m .60676 .52693 L .60951 .53121 L F
.63984 .39089 m .62043 .3874 L .6212 .3933 L .663 .425 .55 r
F
0 g
.60356 .39833 m
.6212 .3933 L
s
.63984 .39089 m .63903 .38498 L .62043 .3874 L .663 .425 .55 r
F
0 g
.60281 .39243 m
.62043 .3874 L
s
.38046 .64767 m .37626 .64575 L .37646 .64881 L .579 .354 .538 r
F
.38046 .64767 m .38026 .64462 L .37626 .64575 L F
0 g
.37287 .64737 m
.37626 .64575 L
s
.68364 .52862 m .68643 .51704 L .68633 .5221 L 0 0 .239 r
F
.68354 .53368 m .68364 .52862 L .68633 .5221 L F
.66858 .52551 m .68364 .52862 L .68633 .5221 L .601 .765 .958 r
F
0 g
.67846 .5339 m
.68364 .52862 L
s
.62261 .51327 m .60733 .51681 L .62289 .51551 L .602 .764 .957 r
F
.62261 .51327 m .60671 .51233 L .60733 .51681 L F
.37666 .65187 m .37306 .65042 L .37326 .65348 L .471 .274 .53 r
F
0 g
.3707 .65546 m
.37326 .65348 L
s
.37666 .65187 m .37646 .64881 L .37306 .65042 L .471 .274 .53 r
F
0 g
.3705 .6524 m
.37306 .65042 L
s
.66467 .53448 m .68354 .53368 L .66846 .53058 L .6 .765 .958 r
F
.65146 .52942 m .66467 .53448 L .66846 .53058 L F
.64868 .53103 m .66467 .53448 L .65146 .52942 L F
.38803 .65308 m .385 .65015 L .38513 .65307 L .659 .812 .957 r
F
.38803 .65308 m .38935 .65017 L .385 .65015 L F
.39695 .65195 m .39322 .64773 L .39343 .65079 L .865 .575 .495 r
F
0 g
.39695 .65195 m
.39968 .65359 L
s
.66856 .52043 m .68619 .51703 L .67029 .51609 L .602 .764 .957 r
F
.38914 .64711 m .38893 .64406 L .38458 .64404 L .732 .47 .532 r
F
.39322 .64773 m .38893 .64406 L .38914 .64711 L .798 .521 .519 r
F
0 g
.38893 .64406 m
.393 .64468 L
s
.38225 .65345 m .38067 .65073 L .37666 .65187 L .659 .812 .957 r
F
.38513 .65307 m .38067 .65073 L .38225 .65345 L F
.38513 .65307 m .385 .65015 L .38067 .65073 L F
.6581 .39126 m .63903 .38498 L .63984 .39089 L .736 .477 .537 r
F
0 g
.62043 .3874 m
.63903 .38498 L
s
.63903 .38498 m
.65727 .38536 L
s
.6581 .39126 m
.67467 .39438 L
s
.39343 .65079 m .39322 .64773 L .38914 .64711 L .798 .521 .519 r
F
0 g
.39322 .64773 m
.39674 .6489 L
s
.63984 .39089 m
.6581 .39126 L
s
.38479 .64709 m .38026 .64462 L .38046 .64767 L .661 .416 .538 r
F
.38479 .64709 m .38458 .64404 L .38026 .64462 L F
0 g
.37626 .64575 m
.38026 .64462 L
s
.38914 .64711 m .38458 .64404 L .38479 .64709 L .732 .47 .532 r
F
0 g
.38026 .64462 m
.38458 .64404 L
s
.38458 .64404 m
.38893 .64406 L
s
.38067 .65073 m .37646 .64881 L .37666 .65187 L .579 .354 .538 r
F
.38067 .65073 m .38046 .64767 L .37646 .64881 L F
0 g
.37306 .65042 m
.37646 .64881 L
s
.37326 .65348 m
.37666 .65187 L
s
.38935 .65017 m .38914 .64711 L .38479 .64709 L .732 .47 .532 r
F
.39343 .65079 m .38914 .64711 L .38935 .65017 L .798 .521 .519 r
F
0 g
.38914 .64711 m
.39322 .64773 L
s
.39343 .65079 m
.39695 .65195 L
s
.60614 .52244 m .59113 .52822 L .60676 .52693 L .6 .765 .958 r
F
.60614 .52244 m .59012 .52149 L .59113 .52822 L F
0 g
.59113 .52822 m
.5953 .53462 L
s
.385 .65015 m .38046 .64767 L .38067 .65073 L .661 .416 .538 r
F
.385 .65015 m .38479 .64709 L .38046 .64767 L F
0 g
.37646 .64881 m
.38046 .64767 L
s
.62234 .51832 m .60697 .52187 L .62263 .52057 L .601 .765 .958 r
F
.62234 .51832 m .60635 .51737 L .60697 .52187 L F
.68354 .53368 m .68633 .5221 L .68623 .52718 L 0 0 .239 r
F
.66846 .53058 m .68354 .53368 L .68623 .52718 L .6 .765 .958 r
F
0 g
.6778 .5395 m
.68354 .53368 L
s
.38935 .65017 m .38479 .64709 L .385 .65015 L .732 .47 .532 r
F
0 g
.38046 .64767 m
.38479 .64709 L
s
.38479 .64709 m
.38914 .64711 L
s
.38935 .65017 m
.39343 .65079 L
s
.66858 .52551 m .68633 .5221 L .67033 .52116 L .601 .765 .958 r
F
0 g
.6212 .3933 m
.63984 .39089 L
s
.37666 .65187 m
.38067 .65073 L
s
.385 .65015 m
.38935 .65017 L
s
.38067 .65073 m
.385 .65015 L
s
.64056 .60302 m
.6406 .6042 L
s
.62215 .52339 m .60676 .52693 L .62244 .52563 L .6 .765 .958 r
F
.62215 .52339 m .60614 .52244 L .60676 .52693 L F
.66846 .53058 m .68623 .52718 L .67021 .52623 L F
.65334 .52746 m .66846 .53058 L .67021 .52623 L F
.65146 .52942 m .66846 .53058 L .65334 .52746 L F
.60827 .50795 m .59082 .51139 L .60671 .51233 L .602 .764 .957 r
F
.60827 .50795 m .59308 .5048 L .59082 .51139 L F
.59263 .50982 m .59058 .51138 L .59035 .51643 L 0 0 .171 r
F
0 g
.59103 .51444 m
.59134 .51648 L
s
.59263 .50982 m .59285 .50475 L .59058 .51138 L 0 0 .171 r
F
.62341 .51108 m .60671 .51233 L .62261 .51327 L .602 .764 .957 r
F
.62341 .51108 m .60827 .50795 L .60671 .51233 L F
.6544 .51515 m .66987 .51159 L .65416 .5129 L F
.6544 .51515 m .67029 .51609 L .66987 .51159 L F
.67029 .51609 m .68562 .51027 L .66987 .51159 L F
.67029 .51609 m .68619 .51703 L .68562 .51027 L F
.68633 .5221 m .68643 .51704 L .68586 .51025 L .797 .645 .09 r
F
0 g
.6844 .52199 m
.68616 .51771 L
s
.65334 .52746 m .67021 .52623 L .65419 .52528 L .6 .765 .958 r
F
.60791 .51298 m .59035 .51643 L .60635 .51737 L .601 .765 .958 r
F
.60791 .51298 m .59263 .50982 L .59035 .51643 L F
.5924 .5149 m .59035 .51643 L .59012 .52149 L 0 0 .171 r
F
0 g
.59081 .5195 m
.59111 .52155 L
s
.5924 .5149 m .59263 .50982 L .59035 .51643 L 0 0 .171 r
F
.62315 .51613 m .60635 .51737 L .62234 .51832 L .601 .765 .958 r
F
.62315 .51613 m .60791 .51298 L .60635 .51737 L F
.65433 .52021 m .6699 .51664 L .65409 .51796 L F
.65433 .52021 m .67033 .52116 L .6699 .51664 L F
.67033 .52116 m .68576 .51533 L .6699 .51664 L F
.67033 .52116 m .68633 .5221 L .68576 .51533 L F
.68633 .5221 m .68586 .51025 L .68576 .51533 L .797 .645 .09 r
F
.68623 .52718 m .68633 .5221 L .68576 .51533 L F
0 g
.68429 .52706 m
.68606 .52277 L
s
.62524 .5091 m .60827 .50795 L .62341 .51108 L .602 .764 .957 r
F
.65416 .5129 m .66729 .50724 L .65285 .51074 L F
.65416 .5129 m .66987 .51159 L .66729 .50724 L F
0 g
.64532 .59877 m
.64536 .60005 L
s
.64251 .52328 m
.64519 .59532 L
s
.63681 .59929 m
.63683 .59992 L
s
.6367 .59624 m
.63678 .59838 L
s
.63417 .52281 m
.63666 .59514 L
s
.6077 .51805 m .59012 .52149 L .60614 .52244 L .6 .765 .958 r
F
.6077 .51805 m .5924 .5149 L .59012 .52149 L F
0 g
.59012 .52149 m
.59113 .52822 L
s
.62296 .5212 m .60614 .52244 L .62215 .52339 L .6 .765 .958 r
F
.62296 .5212 m .6077 .51805 L .60614 .52244 L F
.65419 .52528 m .66978 .52172 L .65395 .52303 L F
.65419 .52528 m .67021 .52623 L .66978 .52172 L F
.67021 .52623 m .68566 .52041 L .66978 .52172 L F
.67021 .52623 m .68623 .52718 L .68566 .52041 L F
.68623 .52718 m .68576 .51533 L .68566 .52041 L .797 .645 .09 r
F
0 g
.68354 .53368 m
.68623 .52718 L
s
.62499 .51414 m .60791 .51298 L .62315 .51613 L .601 .765 .958 r
F
.62524 .5091 m .6119 .50397 L .60827 .50795 L .602 .764 .957 r
F
.62799 .50747 m .6119 .50397 L .62524 .5091 L F
.65409 .51796 m .66731 .51228 L .65278 .51578 L .601 .765 .958 r
F
.65409 .51796 m .6699 .51664 L .66731 .51228 L F
.65285 .51074 m .66272 .50335 L .65056 .5088 L .602 .764 .957 r
F
.65285 .51074 m .66729 .50724 L .66272 .50335 L F
.6119 .50397 m .59308 .5048 L .60827 .50795 L F
.66987 .51159 m .68181 .50373 L .66729 .50724 L F
.66987 .51159 m .68562 .51027 L .68181 .50373 L F
.62799 .50747 m .61738 .50067 L .6119 .50397 L F
.63146 .50629 m .61738 .50067 L .62799 .50747 L F
.65056 .5088 m .65646 .50019 L .64743 .50724 L F
.65056 .5088 m .66272 .50335 L .65646 .50019 L F
.62481 .51922 m .6077 .51805 L .62296 .5212 L .6 .765 .958 r
F
.62499 .51414 m .61157 .50899 L .60791 .51298 L .601 .765 .958 r
F
.62775 .5125 m .61157 .50899 L .62499 .51414 L F
.65395 .52303 m .66718 .51737 L .65263 .52086 L .6 .765 .958 r
F
.65395 .52303 m .66978 .52172 L .66718 .51737 L F
.65278 .51578 m .66271 .50838 L .65047 .51384 L .601 .765 .958 r
F
.65278 .51578 m .66731 .51228 L .66271 .50838 L F
.61157 .50899 m .59263 .50982 L .60791 .51298 L F
.6119 .50397 m .59849 .4988 L .59308 .5048 L .602 .764 .957 r
F
.59806 .5038 m .59285 .50475 L .59263 .50982 L .043 0 .381 r
F
.59806 .5038 m .59828 .49872 L .59285 .50475 L F
0 g
.59058 .51138 m
.59285 .50475 L
s
.6699 .51664 m .68192 .50876 L .66731 .51228 L .601 .765 .958 r
F
.6699 .51664 m .68576 .51533 L .68192 .50876 L F
.68576 .51533 m .68586 .51025 L .68203 .50367 L .988 .737 .36 r
F
0 g
.68586 .51025 m
.68643 .51704 L
s
.63146 .50629 m .62434 .49829 L .61738 .50067 L .602 .764 .957 r
F
.63542 .50565 m .62434 .49829 L .63146 .50629 L F
.64743 .50724 m .64894 .49799 L .64369 .50614 L F
.64743 .50724 m .65646 .50019 L .64894 .49799 L F
.62775 .5125 m .61708 .50568 L .61157 .50899 L .601 .765 .958 r
F
.63125 .51132 m .61708 .50568 L .62775 .5125 L F
.65047 .51384 m .65641 .50521 L .64733 .51227 L F
.65047 .51384 m .66271 .50838 L .65641 .50521 L F
.63542 .50565 m .6323 .497 L .62434 .49829 L .602 .764 .957 r
F
.63959 .5056 m .6323 .497 L .63542 .50565 L F
.62481 .51922 m .61136 .51407 L .6077 .51805 L .6 .765 .958 r
F
.62757 .51758 m .61136 .51407 L .62481 .51922 L F
.64369 .50614 m .6407 .4969 L .63959 .5056 L .602 .764 .957 r
F
.64369 .50614 m .64894 .49799 L .6407 .4969 L F
.65263 .52086 m .66257 .51347 L .65032 .51893 L .6 .765 .958 r
F
.65263 .52086 m .66718 .51737 L .66257 .51347 L F
.61136 .51407 m .5924 .5149 L .6077 .51805 L F
.61738 .50067 m .59849 .4988 L .6119 .50397 L .602 .764 .957 r
F
.61157 .50899 m .59806 .5038 L .59263 .50982 L .601 .765 .958 r
F
.59784 .50889 m .59263 .50982 L .5924 .5149 L .043 0 .381 r
F
.59784 .50889 m .59806 .5038 L .59263 .50982 L F
0 g
.59035 .51643 m
.59263 .50982 L
s
.66978 .52172 m .68182 .51386 L .66718 .51737 L .6 .765 .958 r
F
.66978 .52172 m .68566 .52041 L .68182 .51386 L F
.63959 .5056 m .6407 .4969 L .6323 .497 L .602 .764 .957 r
F
.66729 .50724 m .67498 .49785 L .66272 .50335 L F
.66729 .50724 m .68181 .50373 L .67498 .49785 L F
.68576 .51533 m .68203 .50367 L .68192 .50876 L .988 .737 .36 r
F
.68566 .52041 m .68576 .51533 L .68192 .50876 L F
0 g
.68576 .51533 m
.68633 .5221 L
s
.63125 .51132 m .62409 .5033 L .61708 .50568 L .601 .765 .958 r
F
.63523 .51068 m .62409 .5033 L .63125 .51132 L F
.64733 .51227 m .64885 .50299 L .64356 .51118 L F
.64733 .51227 m .65641 .50521 L .64885 .50299 L F
.62757 .51758 m .61689 .51077 L .61136 .51407 L .6 .765 .958 r
F
.63107 .5164 m .61689 .51077 L .62757 .51758 L F
.65032 .51893 m .65627 .51031 L .64717 .51736 L F
.65032 .51893 m .66257 .51347 L .65627 .51031 L F
.63523 .51068 m .63209 .502 L .62409 .5033 L .601 .765 .958 r
F
.63943 .51063 m .63209 .502 L .63523 .51068 L F
.64356 .51118 m .64055 .5019 L .63943 .51063 L F
.64356 .51118 m .64885 .50299 L .64055 .5019 L F
.61708 .50568 m .59806 .5038 L .61157 .50899 L F
.61136 .51407 m .59784 .50889 L .5924 .5149 L .6 .765 .958 r
F
0 g
.59012 .52149 m
.5924 .5149 L
s
.63943 .51063 m .64055 .5019 L .63209 .502 L .601 .765 .958 r
F
.66731 .51228 m .67505 .50287 L .66271 .50838 L F
.66731 .51228 m .68192 .50876 L .67505 .50287 L F
.68566 .52041 m .68192 .50876 L .68182 .51386 L .988 .737 .36 r
F
0 g
.68566 .52041 m
.68623 .52718 L
s
.63107 .5164 m .6239 .50839 L .61689 .51077 L .6 .765 .958 r
F
.63506 .51577 m .6239 .50839 L .63107 .5164 L F
.64717 .51736 m .64869 .5081 L .6434 .51626 L F
.64717 .51736 m .65627 .51031 L .64869 .5081 L F
.61738 .50067 m .60669 .49382 L .59849 .4988 L .602 .764 .957 r
F
.62434 .49829 m .60669 .49382 L .61738 .50067 L F
.66272 .50335 m .66558 .49307 L .65646 .50019 L F
.66272 .50335 m .67498 .49785 L .66558 .49307 L F
.63506 .51577 m .63192 .50711 L .6239 .50839 L .6 .765 .958 r
F
.63927 .51572 m .63192 .50711 L .63506 .51577 L F
.6434 .51626 m .64038 .50701 L .63927 .51572 L F
.6434 .51626 m .64869 .5081 L .64038 .50701 L F
.61689 .51077 m .59784 .50889 L .61136 .51407 L F
.63927 .51572 m .64038 .50701 L .63192 .50711 L F
.66718 .51737 m .67493 .50798 L .66257 .51347 L F
.66718 .51737 m .68182 .51386 L .67493 .50798 L F
.60632 .4988 m .59828 .49872 L .59806 .5038 L .306 .129 .47 r
F
.60632 .4988 m .60653 .49371 L .59828 .49872 L F
0 g
.59285 .50475 m
.59828 .49872 L
s
.68192 .50876 m .68203 .50367 L .67516 .49777 L .956 .681 .474 r
F
0 g
.68203 .50367 m
.68586 .51025 L
s
.61708 .50568 m .60632 .4988 L .59806 .5038 L .601 .765 .958 r
F
.62409 .5033 m .60632 .4988 L .61708 .50568 L F
.66271 .50838 m .66559 .49807 L .65641 .50521 L F
.66271 .50838 m .67505 .50287 L .66559 .49807 L F
.60611 .50391 m .59806 .5038 L .59784 .50889 L .306 .129 .47 r
F
.60611 .50391 m .60632 .4988 L .59806 .5038 L F
0 g
.59263 .50982 m
.59806 .5038 L
s
.62434 .49829 m .61716 .49021 L .60669 .49382 L .602 .764 .957 r
F
.6323 .497 m .61716 .49021 L .62434 .49829 L F
.65646 .50019 m .65426 .48974 L .64894 .49799 L F
.65646 .50019 m .66558 .49307 L .65426 .48974 L F
.68192 .50876 m .67516 .49777 L .67505 .50287 L .956 .681 .474 r
F
.68182 .51386 m .68192 .50876 L .67505 .50287 L F
0 g
.68192 .50876 m
.68576 .51533 L
s
.61689 .51077 m .60611 .50391 L .59784 .50889 L .6 .765 .958 r
F
0 g
.5924 .5149 m
.59784 .50889 L
s
.6239 .50839 m .60611 .50391 L .61689 .51077 L .6 .765 .958 r
F
.66257 .51347 m .66546 .50319 L .65627 .51031 L F
.66257 .51347 m .67493 .50798 L .66546 .50319 L F
.6323 .497 m .62915 .48825 L .61716 .49021 L .602 .764 .957 r
F
.6407 .4969 m .62915 .48825 L .6323 .497 L F
.64894 .49799 m .64182 .48809 L .6407 .4969 L F
.64894 .49799 m .65426 .48974 L .64182 .48809 L F
.62409 .5033 m .61685 .49519 L .60632 .4988 L .601 .765 .958 r
F
.63209 .502 m .61685 .49519 L .62409 .5033 L F
.65641 .50521 m .65419 .49472 L .64885 .50299 L F
.65641 .50521 m .66559 .49807 L .65419 .49472 L F
.68182 .51386 m .67505 .50287 L .67493 .50798 L .956 .681 .474 r
F
0 g
.68182 .51386 m
.68566 .52041 L
s
.6407 .4969 m .64182 .48809 L .62915 .48825 L .602 .764 .957 r
F
.61685 .49519 m .60653 .49371 L .60632 .4988 L .464 .255 .509 r
F
.61685 .49519 m .61705 .49009 L .60653 .49371 L F
0 g
.59828 .49872 m
.60653 .49371 L
s
.67505 .50287 m .67516 .49777 L .66571 .49296 L .882 .608 .518 r
F
0 g
.67516 .49777 m
.68203 .50367 L
s
.63209 .502 m .62892 .49323 L .61685 .49519 L .601 .765 .958 r
F
.64055 .5019 m .62892 .49323 L .63209 .502 L F
.64885 .50299 m .64167 .49306 L .64055 .5019 L F
.64885 .50299 m .65419 .49472 L .64167 .49306 L F
.6239 .50839 m .61666 .5003 L .60611 .50391 L .6 .765 .958 r
F
.63192 .50711 m .61666 .5003 L .6239 .50839 L F
.65627 .51031 m .65405 .49984 L .64869 .5081 L F
.65627 .51031 m .66546 .50319 L .65405 .49984 L F
.64055 .5019 m .64167 .49306 L .62892 .49323 L .601 .765 .958 r
F
.61666 .5003 m .60632 .4988 L .60611 .50391 L .464 .255 .509 r
F
0 g
.59784 .50889 m
.60611 .50391 L
s
.61666 .5003 m .61685 .49519 L .60632 .4988 L .464 .255 .509 r
F
0 g
.59806 .5038 m
.60632 .4988 L
s
.67505 .50287 m .66571 .49296 L .66559 .49807 L .882 .608 .518 r
F
.67493 .50798 m .67505 .50287 L .66559 .49807 L F
0 g
.67505 .50287 m
.68192 .50876 L
s
.63192 .50711 m .62874 .49835 L .61666 .5003 L .6 .765 .958 r
F
.64038 .50701 m .62874 .49835 L .63192 .50711 L F
.64869 .5081 m .64151 .49819 L .64038 .50701 L F
.64869 .5081 m .65405 .49984 L .64151 .49819 L F
.64038 .50701 m .64151 .49819 L .62874 .49835 L F
.62892 .49323 m .61705 .49009 L .61685 .49519 L .574 .343 .528 r
F
.62892 .49323 m .6291 .48812 L .61705 .49009 L F
0 g
.60653 .49371 m
.61705 .49009 L
s
.67493 .50798 m .66559 .49807 L .66546 .50319 L .882 .608 .518 r
F
0 g
.67493 .50798 m
.68182 .51386 L
s
.66559 .49807 m .66571 .49296 L .65434 .48961 L .808 .541 .534 r
F
0 g
.66571 .49296 m
.67516 .49777 L
s
.62874 .49835 m .61685 .49519 L .61666 .5003 L .574 .343 .528 r
F
0 g
.60611 .50391 m
.61666 .5003 L
s
.62874 .49835 m .62892 .49323 L .61685 .49519 L .574 .343 .528 r
F
0 g
.60632 .4988 m
.61685 .49519 L
s
.66559 .49807 m .65434 .48961 L .65419 .49472 L .808 .541 .534 r
F
.66546 .50319 m .66559 .49807 L .65419 .49472 L F
0 g
.66559 .49807 m
.67505 .50287 L
s
.64167 .49306 m .6291 .48812 L .62892 .49323 L .66 .414 .537 r
F
.64167 .49306 m .64183 .48796 L .6291 .48812 L F
0 g
.61705 .49009 m
.6291 .48812 L
s
.65419 .49472 m .65434 .48961 L .64183 .48796 L .735 .478 .539 r
F
0 g
.65434 .48961 m
.66571 .49296 L
s
.65419 .49472 m .64183 .48796 L .64167 .49306 L .735 .478 .539 r
F
0 g
.64183 .48796 m
.65434 .48961 L
s
.6291 .48812 m
.64183 .48796 L
s
.66546 .50319 m .65419 .49472 L .65405 .49984 L .808 .541 .534 r
F
0 g
.66546 .50319 m
.67493 .50798 L
s
.64151 .49819 m .62892 .49323 L .62874 .49835 L .66 .414 .537 r
F
0 g
.61666 .5003 m
.62874 .49835 L
s
.64151 .49819 m .64167 .49306 L .62892 .49323 L .66 .414 .537 r
F
0 g
.61685 .49519 m
.62892 .49323 L
s
.65405 .49984 m .65419 .49472 L .64167 .49306 L .735 .478 .539 r
F
0 g
.65419 .49472 m
.66559 .49807 L
s
.65405 .49984 m .64167 .49306 L .64151 .49819 L .735 .478 .539 r
F
0 g
.64167 .49306 m
.65419 .49472 L
s
.65405 .49984 m
.66546 .50319 L
s
.62892 .49323 m
.64167 .49306 L
s
.63504 .60954 m .63897 .60648 L .6394 .60957 L .732 .463 .521 r
F
.63504 .60954 m .63461 .60644 L .63897 .60648 L F
.6394 .60957 m .64341 .60589 L .64385 .60898 L .66 .412 .534 r
F
0 g
.62874 .49835 m
.64151 .49819 L
s
.64151 .49819 m
.65405 .49984 L
s
.63105 .60888 m .63461 .60644 L .63504 .60954 L .803 .514 .5 r
F
.63105 .60888 m .63062 .60578 L .63461 .60644 L F
0 g
.63461 .60644 m
.6368 .60646 L
s
.64385 .60898 m .64762 .6047 L .64807 .60779 L .581 .358 .541 r
F
.64807 .60779 m .64762 .6047 L .65134 .60301 L .486 .292 .542 r
F
0 g
.64576 .60523 m
.64762 .6047 L
s
.63984 .61267 m .6394 .60957 L .64385 .60898 L .66 .412 .534 r
F
.63547 .61263 m .6394 .60957 L .63984 .61267 L .732 .463 .521 r
F
.63547 .61263 m .63504 .60954 L .6394 .60957 L F
.63979 .6065 m .6394 .60957 L .64385 .60898 L .657 .813 .958 r
F
.63687 .60647 m .6394 .60957 L .63979 .6065 L F
.63687 .60647 m .63504 .60954 L .6394 .60957 L F
.64429 .61207 m .64385 .60898 L .64807 .60779 L .581 .358 .541 r
F
.63984 .61267 m .64385 .60898 L .64429 .61207 L .66 .412 .534 r
F
.64276 .6061 m .64385 .60898 L .64807 .60779 L .657 .813 .958 r
F
.63979 .6065 m .64385 .60898 L .64276 .6061 L F
0 g
.6394 .60957 m
.64385 .60898 L
s
.62769 .60764 m .63062 .60578 L .63105 .60888 L .877 .569 .461 r
F
.62769 .60764 m .62726 .60454 L .63062 .60578 L F
0 g
.63062 .60578 m
.63461 .60644 L
s
.63158 .60208 m .63066 .60574 L .63381 .60291 L .657 .813 .958 r
F
.63158 .60208 m .62733 .6045 L .63066 .60574 L F
.63148 .61198 m .63504 .60954 L .63547 .61263 L .803 .514 .5 r
F
.63148 .61198 m .63105 .60888 L .63504 .60954 L F
.63421 .60603 m .63504 .60954 L .63687 .60647 L .657 .813 .958 r
F
.63421 .60603 m .63105 .60888 L .63504 .60954 L F
0 g
.63504 .60954 m
.6394 .60957 L
s
.65179 .6061 m .65134 .60301 L .6543 .60092 L .357 .204 .532 r
F
.64807 .60779 m .65134 .60301 L .65179 .6061 L .486 .292 .542 r
F
0 g
.64762 .6047 m
.65134 .60301 L
s
.64851 .61089 m .64807 .60779 L .65179 .6061 L .486 .292 .542 r
F
.64429 .61207 m .64807 .60779 L .64851 .61089 L .581 .358 .541 r
F
.64557 .60531 m .64807 .60779 L .65179 .6061 L .657 .813 .958 r
F
.64276 .6061 m .64807 .60779 L .64557 .60531 L F
0 g
.64385 .60898 m
.64807 .60779 L
s
.64023 .6096 m .63984 .61267 L .64429 .61207 L .657 .813 .959 r
F
.63731 .60957 m .63984 .61267 L .64023 .6096 L F
.63731 .60957 m .63547 .61263 L .63984 .61267 L F
.6432 .6092 m .64429 .61207 L .64851 .61089 L F
.64023 .6096 m .64429 .61207 L .6432 .6092 L F
0 g
.63984 .61267 m
.64429 .61207 L
s
.62812 .61074 m .63105 .60888 L .63148 .61198 L .877 .569 .461 r
F
.62812 .61074 m .62769 .60764 L .63105 .60888 L F
.63197 .6052 m .63105 .60888 L .63421 .60603 L .657 .813 .958 r
F
.63197 .6052 m .62769 .60764 L .63105 .60888 L F
0 g
.63105 .60888 m
.63504 .60954 L
s
.63464 .60913 m .63547 .61263 L .63731 .60957 L .657 .813 .959 r
F
.63464 .60913 m .63148 .61198 L .63547 .61263 L F
0 g
.63547 .61263 m
.63984 .61267 L
s
.6252 .60589 m .62726 .60454 L .62769 .60764 L .947 .624 .384 r
F
.6252 .60589 m .62477 .6028 L .62726 .60454 L F
0 g
.62726 .60454 m
.63062 .60578 L
s
.62993 .60092 m .62733 .6045 L .63158 .60208 L .657 .813 .958 r
F
.62993 .60092 m .62485 .60277 L .62733 .6045 L F
.65179 .6061 m .6543 .60092 L .65475 .60402 L .357 .204 .532 r
F
.65223 .6092 m .65179 .6061 L .65475 .60402 L F
.64851 .61089 m .65179 .6061 L .65223 .6092 L .486 .292 .542 r
F
.64806 .60418 m .65179 .6061 L .65475 .60402 L .657 .813 .958 r
F
.64557 .60531 m .65179 .6061 L .64806 .60418 L F
0 g
.64807 .60779 m
.65179 .6061 L
s
.64602 .60841 m .64851 .61089 L .65223 .6092 L .657 .813 .959 r
F
.6432 .6092 m .64851 .61089 L .64602 .60841 L F
0 g
.64429 .61207 m
.64851 .61089 L
s
.65475 .60402 m .6543 .60092 L .6563 .59858 L .156 .069 .498 r
F
0 g
.65134 .60301 m
.6543 .60092 L
s
.64954 .59968 m .65423 .6009 L .65622 .59857 L .657 .813 .958 r
F
.6324 .6083 m .63148 .61198 L .63464 .60913 L .657 .813 .959 r
F
.6324 .6083 m .62812 .61074 L .63148 .61198 L F
0 g
.63148 .61198 m
.63547 .61263 L
s
.62563 .609 m .62769 .60764 L .62812 .61074 L .947 .624 .384 r
F
.62563 .609 m .6252 .60589 L .62769 .60764 L F
.63031 .60404 m .62769 .60764 L .63197 .6052 L .657 .813 .958 r
F
.63031 .60404 m .6252 .60589 L .62769 .60764 L F
0 g
.62769 .60764 m
.63105 .60888 L
s
.65223 .6092 m .65475 .60402 L .6552 .60712 L .357 .204 .532 r
F
.6485 .60728 m .65223 .6092 L .6552 .60712 L .657 .813 .959 r
F
.64602 .60841 m .65223 .6092 L .6485 .60728 L F
0 g
.64851 .61089 m
.65223 .6092 L
s
.65475 .60402 m .6563 .59858 L .65676 .60167 L .156 .069 .498 r
F
.6552 .60712 m .65475 .60402 L .65676 .60167 L F
.65003 .60278 m .65475 .60402 L .65676 .60167 L .657 .813 .958 r
F
.64806 .60418 m .65475 .60402 L .65003 .60278 L F
0 g
.65179 .6061 m
.65475 .60402 L
s
.63502 .59907 m .62993 .60092 L .63158 .60208 L .657 .813 .958 r
F
.62375 .60377 m .62477 .6028 L .6252 .60589 L .953 .642 .214 r
F
.62375 .60377 m .62332 .60066 L .62477 .6028 L F
0 g
.62477 .6028 m
.62726 .60454 L
s
.62898 .5995 m .62485 .60277 L .62993 .60092 L .657 .813 .958 r
F
.62898 .5995 m .62341 .60065 L .62485 .60277 L F
.63626 .60276 m .63197 .6052 L .63421 .60603 L F
.64954 .59968 m .65622 .59857 L .65086 .59812 L F
.64061 .60651 m .64023 .6096 L .6432 .6092 L .657 .813 .959 r
F
.63915 .6065 m .64023 .6096 L .64061 .60651 L F
.63915 .6065 m .63731 .60957 L .64023 .6096 L F
.6421 .60631 m .6432 .6092 L .64602 .60841 L F
.64061 .60651 m .6432 .6092 L .6421 .60631 L F
.63074 .60714 m .62812 .61074 L .6324 .6083 L F
.63074 .60714 m .62563 .609 L .62812 .61074 L F
0 g
.62812 .61074 m
.63148 .61198 L
s
.65676 .60167 m .6563 .59858 L .65721 .59613 L 0 0 .392 r
F
0 g
.6543 .60092 m
.6563 .59858 L
s
.65086 .59812 m .65622 .59857 L .65712 .59613 L .657 .813 .958 r
F
.63782 .60628 m .63731 .60957 L .63915 .6065 L .657 .813 .959 r
F
.63782 .60628 m .63464 .60913 L .63731 .60957 L F
.64352 .60592 m .64602 .60841 L .6485 .60728 L F
.6421 .60631 m .64602 .60841 L .64352 .60592 L F
.6552 .60712 m .65676 .60167 L .65721 .60477 L .156 .069 .498 r
F
.65048 .60589 m .6552 .60712 L .65721 .60477 L .657 .813 .959 r
F
.6485 .60728 m .6552 .60712 L .65048 .60589 L F
0 g
.65223 .6092 m
.6552 .60712 L
s
.63543 .60218 m .63197 .6052 L .63626 .60276 L .657 .813 .958 r
F
.63543 .60218 m .63031 .60404 L .63197 .6052 L F
.63455 .59836 m .62993 .60092 L .63502 .59907 L F
.63455 .59836 m .62898 .5995 L .62993 .60092 L F
.62417 .60687 m .6252 .60589 L .62563 .609 L .953 .642 .214 r
F
.62417 .60687 m .62375 .60377 L .6252 .60589 L F
.62935 .60262 m .6252 .60589 L .63031 .60404 L .657 .813 .958 r
F
.62935 .60262 m .62375 .60377 L .6252 .60589 L F
0 g
.6252 .60589 m
.62769 .60764 L
s
.6367 .60586 m .63464 .60913 L .63782 .60628 L .657 .813 .959 r
F
.6367 .60586 m .6324 .6083 L .63464 .60913 L F
.65003 .60278 m .65676 .60167 L .65137 .60122 L .657 .813 .958 r
F
.65086 .59812 m .65712 .59613 L .65146 .59649 L F
.64476 .60535 m .6485 .60728 L .65048 .60589 L .657 .813 .959 r
F
.64352 .60592 m .6485 .60728 L .64476 .60535 L F
.65676 .60167 m .65721 .59613 L .65767 .59923 L 0 0 .392 r
F
.65721 .60477 m .65676 .60167 L .65767 .59923 L F
.65137 .60122 m .65676 .60167 L .65767 .59923 L .657 .813 .958 r
F
0 g
.65475 .60402 m
.65676 .60167 L
s
.62344 .6014 m .62332 .60066 L .62375 .60377 L 0 0 .1 r
F
.62344 .6014 m .62302 .59829 L .62332 .60066 L F
0 g
.62334 .60069 m
.62477 .6028 L
s
.62878 .59793 m .62341 .60065 L .62898 .5995 L .657 .813 .958 r
F
.62878 .59793 m .6231 .59829 L .62341 .60065 L F
.63587 .60528 m .6324 .6083 L .6367 .60586 L .657 .813 .959 r
F
.63587 .60528 m .63074 .60714 L .6324 .6083 L F
.63495 .60146 m .63031 .60404 L .63543 .60218 L .657 .813 .958 r
F
.63495 .60146 m .62935 .60262 L .63031 .60404 L F
.62978 .60572 m .62563 .609 L .63074 .60714 L .657 .813 .959 r
F
.62978 .60572 m .62417 .60687 L .62563 .609 L F
0 g
.62563 .609 m
.62812 .61074 L
s
.63445 .59757 m .62898 .5995 L .63455 .59836 L .657 .813 .958 r
F
.63445 .59757 m .62878 .59793 L .62898 .5995 L F
.65048 .60589 m .65721 .60477 L .65181 .60432 L .657 .813 .959 r
F
.64575 .60465 m .65048 .60589 L .65181 .60432 L F
.64476 .60535 m .65048 .60589 L .64575 .60465 L F
0 g
.6406 .6042 m
.64269 .60398 L
s
.6406 .6042 m
.6406 .6042 L
s
.63857 .60391 m
.6406 .6042 L
s
.65767 .59923 m .65721 .59613 L .65696 .59375 L 0 0 .13 r
F
0 g
.6563 .59858 m
.65721 .59613 L
s
.65146 .59649 m .65712 .59613 L .65687 .59376 L .657 .813 .958 r
F
.65137 .60122 m .65767 .59923 L .65197 .59959 L F
.64597 .60077 m .65137 .60122 L .65197 .59959 L F
.65146 .59649 m .65687 .59376 L .65128 .59491 L F
.64579 .59685 m .65146 .59649 L .65128 .59491 L F
.65721 .60477 m .65767 .59923 L .65812 .60233 L 0 0 .392 r
F
.65181 .60432 m .65721 .60477 L .65812 .60233 L .657 .813 .959 r
F
0 g
.6552 .60712 m
.65721 .60477 L
s
.641 .60342 m .64061 .60651 L .6421 .60631 L .657 .813 .959 r
F
.641 .60342 m .63915 .6065 L .64061 .60651 L F
.641 .60342 m .6421 .60631 L .64352 .60592 L F
0 g
.64269 .60398 m
.64406 .60349 L
s
.62387 .60451 m .62375 .60377 L .62417 .60687 L 0 0 .1 r
F
.62915 .60103 m .62344 .6014 L .62375 .60377 L .657 .813 .958 r
F
.62387 .60451 m .62344 .6014 L .62375 .60377 L 0 0 .1 r
F
0 g
.62377 .60379 m
.6252 .60589 L
s
.62915 .60103 m .62375 .60377 L .62935 .60262 L .657 .813 .958 r
F
.64579 .59685 m .65128 .59491 L .6457 .59606 L F
.641 .60342 m .63782 .60628 L .63915 .6065 L .657 .813 .959 r
F
0 g
.63732 .60339 m
.63857 .60391 L
s
.641 .60342 m .64352 .60592 L .64476 .60535 L .657 .813 .959 r
F
0 g
.6365 .60273 m
.63732 .60339 L
s
.63539 .60457 m .63074 .60714 L .63587 .60528 L .657 .813 .959 r
F
.63539 .60457 m .62978 .60572 L .63074 .60714 L F
.641 .60342 m .6367 .60586 L .63782 .60628 L F
.63486 .60067 m .62935 .60262 L .63495 .60146 L .657 .813 .958 r
F
.63486 .60067 m .62915 .60103 L .62935 .60262 L F
.64597 .60077 m .65197 .59959 L .64627 .59995 L F
.63474 .59676 m .62878 .59793 L .63445 .59757 L F
.641 .60342 m .64476 .60535 L .64575 .60465 L .657 .813 .959 r
F
0 g
.64406 .60349 m
.64502 .60287 L
s
.64502 .60287 m
.64565 .60211 L
s
.63606 .60196 m
.6365 .60273 L
s
.65767 .59923 m .65696 .59375 L .65741 .59685 L 0 0 .13 r
F
.65812 .60233 m .65767 .59923 L .65741 .59685 L F
.65197 .59959 m .65767 .59923 L .65741 .59685 L .657 .813 .958 r
F
0 g
.65676 .60167 m
.65767 .59923 L
s
.6457 .59606 m .65035 .59349 L .64523 .59535 L .657 .813 .958 r
F
0 g
.6452 .59573 m
.64529 .59815 L
s
.6457 .59606 m .65128 .59491 L .65035 .59349 L .657 .813 .958 r
F
.65181 .60432 m .65812 .60233 L .65242 .60269 L .657 .813 .959 r
F
.64641 .60387 m .65181 .60432 L .65242 .60269 L F
.64575 .60465 m .65181 .60432 L .64641 .60387 L F
.62935 .5963 m .6231 .59829 L .62878 .59793 L .657 .813 .958 r
F
.63474 .59676 m .62935 .5963 L .62878 .59793 L F
.641 .60342 m .63587 .60528 L .6367 .60586 L .657 .813 .959 r
F
.65197 .59959 m .65741 .59685 L .65179 .598 L .657 .813 .958 r
F
.64627 .59995 m .65197 .59959 L .65179 .598 L F
.62935 .5963 m .62396 .59584 L .6231 .59829 L F
.6243 .59894 m .62302 .59829 L .62344 .6014 L 0 0 .375 r
F
.6243 .59894 m .62387 .59584 L .62302 .59829 L F
0 g
.62302 .59829 m
.62332 .60066 L
s
.641 .60342 m .64575 .60465 L .64641 .60387 L .657 .813 .959 r
F
.62958 .60414 m .62417 .60687 L .62978 .60572 L F
.62958 .60414 m .62387 .60451 L .62417 .60687 L F
0 g
.62417 .60687 m
.62563 .609 L
s
.6354 .59597 m .62935 .5963 L .63474 .59676 L .657 .813 .958 r
F
.64627 .59995 m .65179 .598 L .64617 .59916 L F
0 g
.64565 .60211 m
.64586 .60121 L
s
.65128 .59491 m .65547 .59162 L .65035 .59349 L .657 .813 .958 r
F
.65128 .59491 m .65687 .59376 L .65547 .59162 L F
0 g
.63606 .60106 m
.63606 .60196 L
s
.64523 .59535 m .64871 .59231 L .64441 .59477 L .657 .813 .958 r
F
.64523 .59535 m .65035 .59349 L .64871 .59231 L F
.641 .60342 m .63539 .60457 L .63587 .60528 L .657 .813 .959 r
F
.63529 .60378 m .62978 .60572 L .63539 .60457 L F
.63529 .60378 m .62958 .60414 L .62978 .60572 L F
.64641 .60387 m .65242 .60269 L .64671 .60306 L F
.641 .60342 m .64641 .60387 L .64671 .60306 L F
.63515 .59986 m .62915 .60103 L .63486 .60067 L .657 .813 .958 r
F
.65741 .59685 m .65696 .59375 L .65555 .59159 L .945 .633 .191 r
F
.6354 .59597 m .63066 .59473 L .62935 .5963 L .657 .813 .958 r
F
.63638 .59527 m .63066 .59473 L .6354 .59597 L F
.65812 .60233 m .65741 .59685 L .65787 .59996 L 0 0 .13 r
F
.65242 .60269 m .65812 .60233 L .65787 .59996 L .657 .813 .959 r
F
0 g
.65721 .60477 m
.65812 .60233 L
s
.64617 .59916 m .65085 .59657 L .6457 .59844 L .657 .813 .958 r
F
.64617 .59916 m .65179 .598 L .65085 .59657 L F
.62973 .5994 m .62344 .6014 L .62915 .60103 L F
.63515 .59986 m .62973 .5994 L .62915 .60103 L F
.64441 .59477 m .64648 .59147 L .6433 .59435 L F
.64441 .59477 m .64871 .59231 L .64648 .59147 L F
0 g
.63606 .60106 m
.63683 .59992 L
s
.63066 .59473 m .62396 .59584 L .62935 .5963 L .657 .813 .958 r
F
.65242 .60269 m .65787 .59996 L .65224 .60111 L .657 .813 .959 r
F
.64671 .60306 m .65242 .60269 L .65224 .60111 L F
.641 .60342 m .63529 .60378 L .63539 .60457 L F
.62473 .60206 m .62344 .6014 L .62387 .60451 L 0 0 .375 r
F
.62973 .5994 m .6243 .59894 L .62344 .6014 L .657 .813 .958 r
F
.62473 .60206 m .6243 .59894 L .62344 .6014 L 0 0 .375 r
F
0 g
.62344 .6014 m
.62375 .60377 L
s
.63638 .59527 m .63262 .59333 L .63066 .59473 L .657 .813 .958 r
F
.63762 .59471 m .63262 .59333 L .63638 .59527 L F
.64671 .60306 m .65224 .60111 L .64662 .60227 L .657 .813 .959 r
F
.641 .60342 m .64671 .60306 L .64662 .60227 L F
.63581 .59907 m .62973 .5994 L .63515 .59986 L .657 .813 .958 r
F
.65179 .598 m .656 .5947 L .65085 .59657 L F
.65179 .598 m .65741 .59685 L .656 .5947 L F
.6433 .59435 m .64382 .59102 L .64197 .59412 L F
.6433 .59435 m .64648 .59147 L .64382 .59102 L F
.65035 .59349 m .65302 .58986 L .64871 .59231 L F
.65035 .59349 m .65547 .59162 L .65302 .58986 L F
.6457 .59844 m .6492 .5954 L .64488 .59786 L F
.6457 .59844 m .65085 .59657 L .6492 .5954 L F
.641 .60342 m .63559 .60297 L .63529 .60378 L .657 .813 .959 r
F
.641 .60342 m .63625 .60218 L .63559 .60297 L F
.641 .60342 m .63724 .60148 L .63625 .60218 L F
.641 .60342 m .63848 .60091 L .63724 .60148 L F
.641 .60342 m .6399 .60051 L .63848 .60091 L F
.641 .60342 m .64139 .60031 L .6399 .60051 L F
.641 .60342 m .64286 .60032 L .64139 .60031 L F
.641 .60342 m .6442 .60055 L .64286 .60032 L F
.641 .60342 m .64532 .60097 L .6442 .60055 L F
.641 .60342 m .64615 .60155 L .64532 .60097 L F
0 g
.64536 .60005 m
.64586 .60121 L
s
.641 .60342 m .64662 .60227 L .64615 .60155 L .657 .813 .959 r
F
.63762 .59471 m .6351 .59219 L .63262 .59333 L .657 .813 .958 r
F
.63902 .59431 m .6351 .59219 L .63762 .59471 L F
.64197 .59412 m .6409 .591 L .64051 .59411 L F
.64197 .59412 m .64382 .59102 L .6409 .591 L F
.63559 .60297 m .62958 .60414 L .63529 .60378 L .657 .813 .959 r
F
.65741 .59685 m .65555 .59159 L .656 .5947 L .945 .633 .191 r
F
.65787 .59996 m .65741 .59685 L .656 .5947 L F
0 g
.64405 .59913 m
.64536 .60005 L
s
.64536 .60005 m
.64536 .60005 L
s
.63902 .59431 m .63792 .5914 L .6351 .59219 L .657 .813 .958 r
F
.64051 .59411 m .63792 .5914 L .63902 .59431 L F
0 g
.63683 .59992 m
.63683 .59992 L
s
.63683 .59992 m
.63835 .59905 L
s
.64051 .59411 m .6409 .591 L .63792 .5914 L .657 .813 .958 r
F
.63581 .59907 m .63105 .59783 L .62973 .5994 L F
.6368 .59837 m .63105 .59783 L .63581 .59907 L F
.63066 .59473 m .62592 .59349 L .62396 .59584 L F
.62627 .59658 m .62387 .59584 L .6243 .59894 L .14 .055 .489 r
F
.62627 .59658 m .62585 .59347 L .62387 .59584 L F
0 g
.62302 .59829 m
.62387 .59584 L
s
.64662 .60227 m .6513 .59968 L .64615 .60155 L .657 .813 .959 r
F
.64662 .60227 m .65224 .60111 L .6513 .59968 L F
.63016 .60251 m .62387 .60451 L .62958 .60414 L F
.63559 .60297 m .63016 .60251 L .62958 .60414 L F
.64488 .59786 m .64696 .59455 L .64376 .59744 L .657 .813 .958 r
F
.64488 .59786 m .6492 .5954 L .64696 .59455 L F
.63105 .59783 m .6243 .59894 L .62973 .5994 L F
.63016 .60251 m .62473 .60206 L .62387 .60451 L .657 .813 .959 r
F
0 g
.62387 .60451 m
.62417 .60687 L
s
.63262 .59333 m .62592 .59349 L .63066 .59473 L .657 .813 .958 r
F
.6368 .59837 m .63302 .59642 L .63105 .59783 L F
.63804 .5978 m .63302 .59642 L .6368 .59837 L F
.63625 .60218 m .63016 .60251 L .63559 .60297 L .657 .813 .959 r
F
.65224 .60111 m .65646 .59781 L .6513 .59968 L F
.65224 .60111 m .65787 .59996 L .65646 .59781 L F
0 g
.64267 .59871 m
.64405 .59913 L
s
.63835 .59905 m
.63982 .59867 L
s
.64376 .59744 m .64428 .5941 L .64242 .59721 L .657 .813 .958 r
F
.64376 .59744 m .64696 .59455 L .64428 .5941 L F
.656 .5947 m .65555 .59159 L .65308 .58982 L .949 .621 .372 r
F
0 g
.65555 .59159 m
.65696 .59375 L
s
.65085 .59657 m .65354 .59293 L .6492 .5954 L .657 .813 .958 r
F
.65085 .59657 m .656 .5947 L .65354 .59293 L F
.64871 .59231 m .64968 .58859 L .64648 .59147 L F
.64871 .59231 m .65302 .58986 L .64968 .58859 L F
.64615 .60155 m .64965 .59851 L .64532 .60097 L .657 .813 .959 r
F
.64615 .60155 m .6513 .59968 L .64965 .59851 L F
.63804 .5978 m .63551 .59528 L .63302 .59642 L .657 .813 .958 r
F
.63946 .5974 m .63551 .59528 L .63804 .5978 L F
0 g
.64126 .59857 m
.64267 .59871 L
s
.63982 .59867 m
.64126 .59857 L
s
.64242 .59721 m .64134 .59408 L .64095 .5972 L .657 .813 .958 r
F
.64242 .59721 m .64428 .5941 L .64134 .59408 L F
.65787 .59996 m .656 .5947 L .65646 .59781 L .945 .633 .191 r
F
0 g
.65787 .59996 m
.65812 .60233 L
s
.63946 .5974 m .63835 .59448 L .63551 .59528 L .657 .813 .958 r
F
.64095 .5972 m .63835 .59448 L .63946 .5974 L F
.64095 .5972 m .64134 .59408 L .63835 .59448 L F
.63625 .60218 m .63148 .60094 L .63016 .60251 L .657 .813 .959 r
F
.63724 .60148 m .63148 .60094 L .63625 .60218 L F
.6267 .59969 m .6243 .59894 L .62473 .60206 L .14 .055 .489 r
F
.63105 .59783 m .62627 .59658 L .6243 .59894 L .657 .813 .958 r
F
.6267 .59969 m .62627 .59658 L .6243 .59894 L .14 .055 .489 r
F
0 g
.62344 .6014 m
.6243 .59894 L
s
.64532 .60097 m .64741 .59766 L .6442 .60055 L .657 .813 .959 r
F
.64532 .60097 m .64965 .59851 L .64741 .59766 L F
.63262 .59333 m .62886 .59138 L .62592 .59349 L .657 .813 .958 r
F
.6351 .59219 m .62886 .59138 L .63262 .59333 L F
.63148 .60094 m .62473 .60206 L .63016 .60251 L .657 .813 .959 r
F
.63302 .59642 m .62627 .59658 L .63105 .59783 L .657 .813 .958 r
F
.63724 .60148 m .63346 .59953 L .63148 .60094 L .657 .813 .959 r
F
.63848 .60091 m .63346 .59953 L .63724 .60148 L F
.64648 .59147 m .64567 .58791 L .64382 .59102 L .657 .813 .958 r
F
.64648 .59147 m .64968 .58859 L .64567 .58791 L F
.6442 .60055 m .64473 .59722 L .64286 .60032 L .657 .813 .959 r
F
.6442 .60055 m .64741 .59766 L .64473 .59722 L F
.656 .5947 m .65308 .58982 L .65354 .59293 L .949 .621 .372 r
F
.65646 .59781 m .656 .5947 L .65354 .59293 L F
0 g
.656 .5947 m
.65741 .59685 L
s
.6513 .59968 m .65399 .59604 L .64965 .59851 L .657 .813 .959 r
F
.6513 .59968 m .65646 .59781 L .65399 .59604 L F
.6492 .5954 m .65018 .59166 L .64696 .59455 L .657 .813 .958 r
F
.6492 .5954 m .65354 .59293 L .65018 .59166 L F
.62923 .59446 m .62585 .59347 L .62627 .59658 L .348 .195 .527 r
F
.62923 .59446 m .6288 .59135 L .62585 .59347 L F
0 g
.62387 .59584 m
.62585 .59347 L
s
.63848 .60091 m .63595 .59839 L .63346 .59953 L .657 .813 .959 r
F
.6399 .60051 m .63595 .59839 L .63848 .60091 L F
.64286 .60032 m .64179 .59719 L .64139 .60031 L F
.64286 .60032 m .64473 .59722 L .64179 .59719 L F
.6351 .59219 m .63258 .58967 L .62886 .59138 L .657 .813 .958 r
F
.63792 .5914 m .63258 .58967 L .6351 .59219 L F
.6399 .60051 m .63879 .59759 L .63595 .59839 L .657 .813 .959 r
F
.64139 .60031 m .63879 .59759 L .6399 .60051 L F
.64139 .60031 m .64179 .59719 L .63879 .59759 L F
.64382 .59102 m .64128 .58787 L .6409 .591 L .657 .813 .958 r
F
.64382 .59102 m .64567 .58791 L .64128 .58787 L F
.63148 .60094 m .6267 .59969 L .62473 .60206 L .657 .813 .959 r
F
0 g
.62387 .60451 m
.62473 .60206 L
s
.65354 .59293 m .65308 .58982 L .64973 .58855 L .879 .567 .454 r
F
0 g
.65308 .58982 m
.65555 .59159 L
s
.63792 .5914 m .63682 .58847 L .63258 .58967 L .657 .813 .958 r
F
.6409 .591 m .63682 .58847 L .63792 .5914 L F
.63302 .59642 m .62923 .59446 L .62627 .59658 L F
.63551 .59528 m .62923 .59446 L .63302 .59642 L F
.6409 .591 m .64128 .58787 L .63682 .58847 L F
.63346 .59953 m .6267 .59969 L .63148 .60094 L .657 .813 .959 r
F
.64696 .59455 m .64615 .59098 L .64428 .5941 L .657 .813 .958 r
F
.64696 .59455 m .65018 .59166 L .64615 .59098 L F
.65646 .59781 m .65354 .59293 L .65399 .59604 L .949 .621 .372 r
F
0 g
.65646 .59781 m
.65787 .59996 L
s
.64965 .59851 m .65063 .59477 L .64741 .59766 L .657 .813 .959 r
F
.64965 .59851 m .65399 .59604 L .65063 .59477 L F
.62966 .59758 m .62627 .59658 L .6267 .59969 L .348 .195 .527 r
F
.62966 .59758 m .62923 .59446 L .62627 .59658 L F
0 g
.6243 .59894 m
.62627 .59658 L
s
.63551 .59528 m .63297 .59274 L .62923 .59446 L .657 .813 .958 r
F
.63835 .59448 m .63297 .59274 L .63551 .59528 L F
.63297 .59274 m .6288 .59135 L .62923 .59446 L .481 .286 .538 r
F
.63297 .59274 m .63254 .58963 L .6288 .59135 L F
0 g
.62585 .59347 m
.6288 .59135 L
s
.64428 .5941 m .64173 .59094 L .64134 .59408 L .657 .813 .958 r
F
.64428 .5941 m .64615 .59098 L .64173 .59094 L F
.65354 .59293 m .64973 .58855 L .65018 .59166 L .879 .567 .454 r
F
.65399 .59604 m .65354 .59293 L .65018 .59166 L F
0 g
.65354 .59293 m
.656 .5947 L
s
.63346 .59953 m .62966 .59758 L .6267 .59969 L .657 .813 .959 r
F
0 g
.62473 .60206 m
.6267 .59969 L
s
.63595 .59839 m .62966 .59758 L .63346 .59953 L .657 .813 .959 r
F
.63835 .59448 m .63724 .59154 L .63297 .59274 L .657 .813 .958 r
F
.64134 .59408 m .63724 .59154 L .63835 .59448 L F
.64134 .59408 m .64173 .59094 L .63724 .59154 L F
.65018 .59166 m .64973 .58855 L .6457 .58787 L .804 .512 .495 r
F
0 g
.64973 .58855 m
.65308 .58982 L
s
.64741 .59766 m .6466 .5941 L .64473 .59722 L .657 .813 .959 r
F
.64741 .59766 m .65063 .59477 L .6466 .5941 L F
.63595 .59839 m .63341 .59586 L .62966 .59758 L F
.63879 .59759 m .63341 .59586 L .63595 .59839 L F
.63724 .59154 m .63254 .58963 L .63297 .59274 L .579 .354 .538 r
F
.63724 .59154 m .6368 .58843 L .63254 .58963 L F
0 g
.6288 .59135 m
.63254 .58963 L
s
.63341 .59586 m .62923 .59446 L .62966 .59758 L .481 .286 .538 r
F
0 g
.6267 .59969 m
.62966 .59758 L
s
.63341 .59586 m .63297 .59274 L .62923 .59446 L .481 .286 .538 r
F
0 g
.62627 .59658 m
.62923 .59446 L
s
.64473 .59722 m .64218 .59406 L .64179 .59719 L .657 .813 .959 r
F
.64473 .59722 m .6466 .5941 L .64218 .59406 L F
.65399 .59604 m .65018 .59166 L .65063 .59477 L .879 .567 .454 r
F
0 g
.65399 .59604 m
.65646 .59781 L
s
.64615 .59098 m .6457 .58787 L .64129 .58783 L .732 .461 .518 r
F
.65018 .59166 m .6457 .58787 L .64615 .59098 L .804 .512 .495 r
F
0 g
.6457 .58787 m
.64973 .58855 L
s
.63879 .59759 m .63768 .59466 L .63341 .59586 L .657 .813 .959 r
F
.64179 .59719 m .63768 .59466 L .63879 .59759 L F
.64179 .59719 m .64218 .59406 L .63768 .59466 L F
.65063 .59477 m .65018 .59166 L .64615 .59098 L .804 .512 .495 r
F
0 g
.65018 .59166 m
.65354 .59293 L
s
.64173 .59094 m .6368 .58843 L .63724 .59154 L .659 .409 .531 r
F
.64173 .59094 m .64129 .58783 L .6368 .58843 L F
0 g
.63254 .58963 m
.6368 .58843 L
s
.64615 .59098 m .64129 .58783 L .64173 .59094 L .732 .461 .518 r
F
0 g
.6368 .58843 m
.64129 .58783 L
s
.64129 .58783 m
.6457 .58787 L
s
.63768 .59466 m .63297 .59274 L .63341 .59586 L .579 .354 .538 r
F
.63768 .59466 m .63724 .59154 L .63297 .59274 L F
0 g
.62923 .59446 m
.63297 .59274 L
s
.62966 .59758 m
.63341 .59586 L
s
.6466 .5941 m .64615 .59098 L .64173 .59094 L .732 .461 .518 r
F
.65063 .59477 m .64615 .59098 L .6466 .5941 L .804 .512 .495 r
F
0 g
.64615 .59098 m
.65018 .59166 L
s
.65063 .59477 m
.65399 .59604 L
s
.64218 .59406 m .63724 .59154 L .63768 .59466 L .659 .409 .531 r
F
.64218 .59406 m .64173 .59094 L .63724 .59154 L F
0 g
.63297 .59274 m
.63724 .59154 L
s
.6466 .5941 m .64173 .59094 L .64218 .59406 L .732 .461 .518 r
F
0 g
.63724 .59154 m
.64173 .59094 L
s
.64173 .59094 m
.64615 .59098 L
s
.6466 .5941 m
.65063 .59477 L
s
.63341 .59586 m
.63768 .59466 L
s
.64218 .59406 m
.6466 .5941 L
s
.63768 .59466 m
.64218 .59406 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{476.062, 475.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007L0001fb000`400?l00000o`00003oo`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM
0?ooo`00o`3ooooM0?ooo`00o`3ooolX0?ooo`D00000/03oool00?l0oooo:03oool00`000000YV>3
0=:7O@0200000;00oooo003o0?ooobP0oooo00@000000:ISP`3BQgd00000/@3oool00?l0oooo7`3o
oolE00000:T0oooo003o0?oooaX0oooo1@000002091BP@h0YfF41@2kMX@700000:80oooo003o0?oo
oaD0oooo1@000007091BP@h0YfF4302kMX@5000009d0oooo003o0?oooa80oooo0`00000<091BP@h0
YfF43P2kMX@30<n6P`<00000VP3oool00?l0oooo403oool200000003074iO02@DX40T5:100X0T5:1
5@0000090;]fQ0H0chJ30`00002G0?ooo`00o`3oool>0?ooo`8000000`1a>G`7091BP@D000000P2@
DX4>0:MUQ0D0^gJ41`0000020;]fQ0T0chJ30`00002D0?ooo`00o`3oool=0?ooo`030000001a>G`0
LCUl00<0LCUl0P2@DX45000000L0T5:13P2WIH@<0;]fQ0D000002@3?QX<200000980oooo003o0?oo
o`/0oooo0P000005074iO0<00000302@DX4>0:MUQ0h0^gJ40`3?QX<3000000H0chJ30P3RV7d00`00
0000oooo0?ooo`2?0?ooo`00o`3oool90?ooo`8000001@1a>G`200000003074iO02@DX40T5:100T0
T5:15P0000090;]fQ0H0chJ30`0000030<n6P`<0hYQm0P00002?0?ooo`00o`3oool70?ooo`800000
1@1a>G`2000000<0LCUl1P2@DX45000001H0Y;cZ1`0000020;]fQ0T0chJ30`0000050>:HO@800000
S@3oool00?l0oooo1P3oool00`000000AAI`074iO004074iO0030000001a>G`0LCUl00<0LCUl0P2@
DX4400000280Y;cZ1@0000090<n6P`8000001@3RV7d00`000000oooo0?ooo`2:0?ooo`00o`3oool5
0?ooo`03000000155W00AAI`00<0LCUl0P000005074iO0<00000:`2T_>X3000000H0chJ30P3RV7d0
0`000000hYQm0>:HO@030>:HO@800000RP3oool00?l0oooo0`3oool2000000<0AAI`00<0LCUl0000
000000001@1a>G`200000340Y;cZ0`0000030<n6P`<0hYQm0P0000050>:HO@030000003oool0oooo
08L0oooo003o0?ooo`80oooo00<0000004DFL0155W000P155W02000000D0LCUl0P00000f0:BljP<0
00001@3RV7d2000000@0hYQm00<000000?ooo`3oool0QP3oool00?l0oooo0@3oool00`000000AAI`
04DFL00204DFL003000000155W00LCUl00@0LCUl00<000000:BljP2T_>X0>@2T_>X2000000D0hYQm
00H000000>:HO@3RV7d0hYQm0?F[L00000270?ooo`00o`3oool00`000000AAI`04DFL00204DFL003
000000155W00AAI`00<0LCUl0P00000n0:BljP030000003RV7d0hYQm00<0hYQm0P000000103RV7d0
mJ]`0?F[L00000260?ooo`00oP3oool010000000AAI`04DFL0155W02000000<0AAI`00<0LCUl0000
00000000@@2T_>X2000000D0hYQm00D000000?F[L03eZg00mJ]`000000250?ooo`00oP3oool01000
0000AAI`04DFL000000404DFL0800000A@2T_>X2000000@0hYQm00D000000?F[L03eZg00mJ]`0000
00240?ooo`00o@3oool010000000AAI`04DFL000000404DFL0030000002T_>X0Y;cZ04L0Y;cZ00H0
00000>:HO@3RV7d0hYQm0?F[L00000030?F[L0030000003oool0oooo0840oooo003l0?ooo`040000
000005H0AAI`000000@0AAI`00<000000:BljP2T_>X0B@2T_>X2000000040>:HO@3eZg00mJ]`0000
00<0mJ]`00<000000?ooo`3oool0P03oool00?`0oooo00<000000000EP0000000`155W02000004h0
Y;cZ00D000000?F[L03eZg00mJ]`000000030?F[L0030000003oool0oooo07l0oooo003k0?ooo`04
0000000005H0001F00000080AAI`00<000000:BljP2T_>X0C`2T_>X01@000000mJ]`0?F[L03eZg00
00000080mJ]`00<000000?ooo`3oool0O`3oool00?/0oooo00<000000000EP0000000P155W000`00
0000Y;cZ0:BljP1A0:BljP080000003eZg00mJ]`0?F[L0000000mJ]`0?ZgC`0000200?ooo`00nP3o
ool01P000000001F0000000005H0AAI`000005D0Y;cZ00L000000?F[L03eZg00mJ]`0000003j]dl0
00000800oooo003i0?ooo`030000000005H000000080001F00<000000:BljP2T_>X0E@2T_>X01`00
0000mJ]`0?F[L03eZg0000000?ZgC`000000O`3oool00?T0oooo00<000000000EP0000000P0005H0
0`000000Y;cZ0:BljP1F0:BljP060000003eZg00mJ]`0000003j]dl00000O`3oool00;h0oooo1000
000f0?ooo`030000000005H000000080001F00<000000:BljP2T_>X0F02T_>X00`000000mJ]`0?Zg
C`02000007l0oooo002m0?ooo`80000000<0_7N50=29Q0000000=P3oool200000080001F00<00000
0:BljP2T_>X0FP2T_>X01@000000n[M?0000003j]dl0000007h0oooo002m0?ooo`050000A0000000
_7N50=29Q0000000=P3oool010000000001F0000EP00001N0:BljP040000003j]dl00000000007h0
oooo002m0?ooo`050000A0000000_7N50=29Q0000000=@3oool200000080001F00<000000:BljP2T
_>X0G02T_>X01@000000n[M?0000003j]dl0000007d0oooo002m0?ooo`050000A0000000_7N50=29
Q0000000=@3oool2000000030000EP000000Y;cZ05l0Y;cZ0P0000000`3j]dl000000?ooo`1l0?oo
o`00[P3ooolD000003D0oooo00<000000000EP000000H@2T_>X010000000n[M?00000000001m0?oo
o`00Z@3oool500000080T5:13@2XIhH50;]hR0L00000;@3oool3000006<0Y;cZ0`00001m0?ooo`00
Y@3oool4000000L0T5:13@2XIhH<0;]hR0D00000:03oool3000006<0Y;cZ00<000000?ZgC`000000
O@3oool00:80oooo0`00000;091BP@d0Z6N63P2kN8P30<f8R0<000009@3oool00`0001X000000000
001S0:BljP030000003j]dl0000007d0oooo002P0?ooo`80000000<0KSEi091BP@2@DX40202@DX4H
000000H0^gR81P3=R8P300000280oooo00<0000J0000002T_>X0I02T_>X2000007d0oooo002N0?oo
o`8000000`1^=GT6091BP@@000000P2@DX4>0:QWQPP0^gR8200000070<f8R0<000007`3oool20000
06D0Y;cZ0P00001m0?ooo`00W03oool2000000D0KSEi0P2@DX44000000H0T5:13P2XIhH>0;]hR080
cHR80`0000070<f8R0<00000703oool2000006H0Y;cZ00<000000?ooo`3oool0N`3oool009X0oooo
0P00000606heN@<000002P2@DX4>0:QWQPh0^gR81@3=R8P2000000H0cHR80P3NVHH2000001X0oooo
00<0000J0000002T_>X0I@2T_>X00`000000oooo0?ooo`1k0?ooo`00V03oool2000000H0KSEi0P00
00000`1^=GT0T5:1091BP@08091BPAP000001P2kN8P70<f8R0800000103=R8P40=jIQP030000003o
ool0oooo01L0oooo0P00001V0:BljP030000003oool0oooo07/0oooo002G0?ooo`030000000g26H0
KSEi00<0KSEi0`00000306heN@D0T5:11@00000H0:Blj`L00000203=R8P3000000030<f8R03NVHH0
gYV600<0gYV60P00000G0?ooo`030000002T_>X0Y;cZ02T0Y;cZ00<0Z[oX0:BljP2T_>X0>@2T_>X0
0`000000oooo0?ooo`1k0?ooo`00UP3oool00`000000=`QV03L8IP0206heN@8000001P1^=GT00`2@
DX40000000000002000002@0Y;c[0`0000080<f8R08000001P3NVHH2000001D0oooo00<000000:Bl
jP2T_>X0:`2T_>X00`2Z_nP0Y;cZ0:BljP0g0:BljP030000003oool0oooo07/0oooo002E0?ooo`04
0000000g26H0=`QV03L8IP8000001P1^=GT3000002/0Y;c[0`0000050<f8R080gYV60P0000060=jI
QP030000003oool0oooo0180oooo00<000000:BljP2T_>X09`2T_>X00`2Z_nP0Y;cZ0:BljP030:Bl
jP030:Zoj02T_>X0Y;cZ03D0Y;cZ00<000000?ooo`3oool0N`3oool009@0oooo00<0000003L8IP0g
26H00P00000606heN@800000<@2T_>/2000000<0cHR8103NVHH2000000D0gYV60P00000B0?ooo`03
0000002T_>X0Y;cZ02l0Y;cZ00D0000008a?PP2lM880kYm`0000000a0:BljP030000003oool0oooo
07/0oooo002C0?ooo`050000000g26H0=`QV0000000g26H01@1^=GT2000003D0Y;c[0`0000060=jI
QP030000003NVHH0gYV60080gYV60P3`Zh000`000000oooo0?ooo`0?0?ooo`030000002T_>X0Y;cZ
02l0Y;cZ00D0000008a?PP2lM880kYm`0000000a0:BljP030000003oool0oooo07/0oooo002B0?oo
o`040000000g26H0=`QV00000080=`QV0`1^=GT2000003X0Y;c[0P0000050=jIQP8000000P3NVHH3
0?2[P0030000003oool0oooo00h0oooo00<000000:BljP2T_>X0;`2T_>X01P000000S4n20;adPP3^
Wg0000000:Zoj300Y;cZ00<000000?ooo`3oool0N`3oool00940oooo00@0000003L8IP0g26H00000
0`0g26H00`1^=GT000000000000n0:Blj`8000001@3NVHH2000000@0l:^000<000000?ooo`3oool0
3P3oool00`000000Y;cZ0:BljP0^0:BljP050000002<Ch80_7B20>jOL0000000<@2T_>X00`000000
oooo0?ooo`1k0?ooo`00T@3oool00`000000=`QV0000000303L8IP800000@P2T_>/2000000D0gYV6
0P0000030?2[P0030000003oool0oooo00d0oooo00<000000:BljP2T_>X0;P2T_>X01@000000S4n2
0;adPP3^Wg0000000340Y;cZ00<000000?ooo`3oool0N`3oool00900oooo00<0000003L8IP000000
0`0g26H00`000000Y;c[0:Blj`140:Blj`030000003NVHH0gYV60080gYV60P3`Zh001@000000l:^0
0?2[P03`Zh00000000h0oooo00<000000:BljP2T_>X0;P2T_>X01@000000S4n20;adPP3^Wg000000
0300Y;cZ00<000000?ooo`3oool0O03oool00900oooo0P00000303L8IP030000002T_>/0Y;c[04H0
Y;c[0P0000020=jIQP<0l:^000D000000?2[P03`Zh00l:^00000000=0?ooo`030000002T_>X0Y;cZ
02h0Y;cZ00D0000008a?PP2lM880kYm`0000000`0:BljP030000003oool0oooo07`0oooo002?0?oo
o`040000000003/0000003L8IP800000B`2T_>/2000000@0l:^000D000000?2[P03`Zh00l:^00000
000<0?ooo`030000002T_>X0Y;cZ02h0Y;cZ3@00000X0:BljP030000003oool0oooo07`0oooo002>
0?ooo`050000000003/0000003L8IP000000C`2T_>/2000000<0l:^000@000000?2[P03`Zh000000
303oool00`000000Y;cZ0:BljP0V0:BljPP000001P2YJh/70;aiR0P000007`2T_>X00`000000oooo
0?ooo`1m0?ooo`00SP3oool2000000030000>`000000Y;c[0540Y;c[00P000000?2[P03`Zh00l:^0
0000003`Zh00oKe^000000`0oooo00<000000:BljP2T_>X08P2T_>X300000080U5^;302YJh/;0;ai
R0@0chN41@00000J0:BljP030000003oool0oooo07d0oooo002=0?ooo`040000000003/000000000
05@0Y;c[00D000000?2[P03`Zh00l:^0000000020?fmKP030000003oool0oooo00X0oooo00<00000
0:BljP2T_>X07P2T_>X3000000H0U5^;1P2YJh/<000000D0_7V8203?Qh@4000001H0Y;cZ00<00000
0?ooo`3oool0O@3oool008d0oooo00@0000k0000000003/00000E@2T_>/01`000000l:^00?2[P03`
Zh0000000?fmKP000000303oool00`000000Y;cZ0:BljP0K0:BljP<000001`2DFh/8000000D0ZF^;
1`2lNHP8000000L0chN40P3RUgX2000001<0Y;cZ00<000000?ooo`3oool0OP3oool008d0oooo00<0
000k000000000000E`2T_>/010000000l:^00?2[P00000020?fmKP030000003oool0oooo00X0oooo
00<000000:BljP2T_>X0602T_>X20000000307Y8R@2DFh/0U5^;00<0U5^;1000000209AKR`/0ZF^;
302lNHP30<n7Q0<00000103?Qh@40>:GNP8000004@2T_>X00`000000oooo0?ooo`1n0?ooo`00S@3o
ool00`000000000k0000001H0:Blj`060000003`Zh00oKe^0000003m_Fh00000303oool00`000000
Y;cZ0:BljP0F0:BljP8000000`1jB8T209AKR`<000001P2DFh/<0:U[R`/0_7V81P3?Qh@300000003
0<n7Q03RUgX0hYMj00@0hYMj0P00000?0:BljP800000O`3oool008`0oooo00<000000000>`000000
FP2T_>/01P000000oKe^0?fmKP000000oKe^000000`0oooo00<000000:BljP2T_>X04`2T_>X20000
00@0NTR90`00000909AKR`H0ZF^;500000060<n7Q0<000001P3RUgX00`000000Y;cZ0:BljP0;0:Bl
jP030000002kNHP0^gV800L00000N03oool008`0oooo0P0003/00`000000Y;c[0:Blj`1I0:Blj`03
0000003m_Fh000000080oKe^00<000000?ooo`3oool02P3oool200000140Y;cZ0P00000407Y8R@80
000000<0NTR909AKR`2DFh/01`2DFh/8000001@0YlO`0`0000040<n7Q080hYMj0P0000040>:GNP03
0?FVIP000000Y;cZ00X0Y;cZ00<000000;]iR02kNHP0202kNHP5000007<0oooo002<0?ooo`030000
>`000000Y;c[05/0Y;c[00H000000?fmKP3m_Fh000000?fmKP00000>0?ooo`030000002T_>X0Y;cZ
00`0Y;cZ0P00000407Y8R@8000000`1jB8T509AKR`@000007`2Wao03000000030<n7Q03RUgX0hYMj
0080hYMj0P0000020>:GNP80mJIV00<000000:BljP2T_>X01`2T_>X00`000000^gV80;]iR00;0;]i
R0<0cXR60`00001`0?ooo`00S03oool00`0003/000000:Blj`1L0:Blj`050000003m_Fh000000?fm
KP0000003`3oool00`000000Y;cZ0:BljP0:0:BljP030000001D;H<0NTR90080NTR90P00000507Y8
R@80U5^;0`00000V0:O7l0<00000103RUgX2000000<0mJIV00<000000:BljP2T_>X01P2T_>X50000
00T0^gV81P3>R8H3000006d0oooo002<0?ooo`030000002T_>/0Y;c[05d0Y;c[00D000000?fmKP00
0000j[`n0000000?0?ooo`030000002T_>X0Y;cZ00L0Y;cZ0P00000205@]P`0307Y8R@0000000000
00H0NTR90`00000/0:O7l0800000103RUgX200000080mJIV00<000000:BljP2T_>X0102T_>X00`00
0000ZFV90;]iR0030;]iR0L000000P2kNHP90<j8QP<00000JP3oool008`0oooo00<000000:Blj`2T
_>/0G@2T_>/00`000000oKe^0?fmKP0200000100oooo00<000000:BljP2T_>X01@2T_>X010000000
E2f305@]P`1D;H<2000000H0NTR90P00000a0:O7l0<0000000@0hYMj0?FVIP3eYVH000000P3eYVH0
0`000000Y;cZ0:BljP020:BljP030000002YJHT0ZFV900/0^gV81@0000090<j8QP800000J03oool0
07`0oooo0P00000=0?ooo`030:BljP000000Y;c[05l0Y;c[00@000000?fmKP00000000004@3oool0
0`000000Y;cZ0:BljP030:BljP060000001D;H<0E2f305@]P`000000E2f3101jB8T3000003H0YlO`
0P0000020?FVIP050000003eYVH0mJIV0000002T_>X00P0000030:UYR@d0^gV80`3>R8H3000000H0
cXR60P3QVH42000006H0oooo001k0?ooo`80000000<0cX^90000000000002`3oool00`2T_>X00000
0:Blj`1O0:Blj`040000003m_Fh0000000000180oooo00D000000:BljP2T_>X0Y;cZ0000000305@]
P`050000001D;H<0E2f305@]P`1jB8T00P00000k0:O7l080000000<0mJIV0000003eYVH030000008
0;]iR0H0cXR60`0000030<j8QP@0hIV100<000000?ooo`3oool0H`3oool007/0oooo00<000000:MX
Q`3>RhT00P00000;0?ooo`030:BljP000000Y;c[0600Y;c[0`00000C0?ooo`80000000D0Y;cZ0000
001D;H<0E2f30000000305@]P`800000?`2Wao001@000000mJIV0000003cZCL0000000X0Y;cZ1`00
00020;]iR0P0cXR60`0000050>6IP@800000H`3oool007/0oooo00@000000:MXQ`0000000000303o
ool00`000000Y;c[0:Blj`1Q0:Blj`030000003Z_3h0000001@0oooo00@0000005@]P`1D;H<00000
0`1D;H<00`000000YlO`0:O7l0100:O7l0040000003eYVH0000000000140Y;cZ100000090<j8QP80
00001@3QVH4200000640oooo001k0?ooo`040000002WJ8L00000000000`0oooo00<000000:Blj`2T
_>/0H@2T_>/3000001<0oooo00@0000001P2M01D;H<000000`1D;H<00`000000YlO`0:O7l0120:O7
l080000000<0ljTg0000002T_>X04`2T_>X3000000H0cXR60P3QVH42000000D0hIV100<000000?oo
o`3oool0GP3oool007/0oooo00@000000:MXQ`0000000000303oool00`000000Y;c[0:Blj`1Q0:Bl
j`8000004`3oool010000000609d01P2M000000205@]P`800000AP2Wao03000001L0Y;cZ0`000003
0<j8QP@0hIV10P0000040>6IP@030000003oool0oooo05d0oooo001k0?ooo`040000002WJ8L0cX^9
000000`0oooo00<000000:Blj`2T_>/0H@2T_>/2000001<0oooo00H0000001P2M00H0W@0000005@]
P`0000190:O7l0<000006@2T_>X3000000H0hIV10P0000020>6IP@030000003oool0oooo05d0oooo
001`0?ooo`X0000000D0oooo0000003>RhT0cX^90000000<0?ooo`030000002T_>/0Y;c[0640Y;c[
0P00000B0?ooo`060000000H0W@0609d0000001D;H<00000BP2Wao02000001d0Y;cZ0P0000060>6I
P@80000000<0mJ]b0000003oool0G@3oool006H0oooo2P0000060:UYR0@0^gZ<1`00000:0?ooo`03
0000002T_>/0Y;c[02h0Y;c[00<000000:Blj`2T_>/0<@2T_>/00`000000oooo0?ooo`0?0?ooo`06
0000000H0W@0609d0000000H0W@00000C02Wao02000001h0Y;cZ0P0000060>6IP@030000003eZg80
000005d0oooo001Q0?ooo`D000000`2AE8<=0:UYR0/0^gZ<1@0000050?ooo`030000002T_>/0Y;c[
02@0Y;c[0`2T_>X00`2Z_nP0Y;c[0:Blj`040:Blj`040000002lMhD0d8V400000300Y;c[00<00000
0?ooo`3oool03`3oool00`000000609d0000000201P2M0030000002Wao00YlO`04X0YlO`00<00000
0?>Y=`0000007`2T_>X2000000@0hIV100@000000?F[LP3eZg800000G03oool005d0oooo10000008
095DP`d0ZFV83@2kNX`30<^:S@<000000`3oool00`000000Y;c[0:Blj`0Y0:Blj`080:Zoj02T_>/0
Y;c[0000A0000000_7N50=29Q00000060:Blj`80Y;cZ:02T_>/00`000000oooo0?ooo`0>0?ooo`03
0000000H0W@000000080609d00<000000:O7l02Wao00C02Wao000`000000Y;cZ0:BljP0P0:BljP80
00000P3QVH401@3eZg8000000?F[LP3eZg80000005/0oooo001K0?ooo`80000000<0KSIi095DP`2A
E8<02@2AE8<70:UYR0X000002@2kNX`60<^:S@@00000;P2T_>/01@0004@000000;agQ@3@RH@00000
00<0Y;c[0P2T_>X[0:Blj`030000003oool0oooo00h0oooo0P00000201P2M0030000002Wao00YlO`
04d0YlO`00<000000:BljP2T_>X08P2T_>X200000080mJ]b00@000000?F[LP3eZg800000FP3oool0
05T0oooo0P00000306hfN@P0TEB32P0000060:UYR0@0^gZ<1`0000020;]jS0T0bhZ=00<000000:Bl
j`2T_>/0:02T_>/02@2T_>X0Y;c[0:Blj`2T_>X000140000002lMhD0d8V4000000080:Blj`030:Bl
jP2T_>/0Y;c[02D0Y;c[00<000000?ooo`3oool03P3oool20000000301P2M0000000YlO`04l0YlO`
0P00000U0:BljP040000003eZg80mJ]b00000080mJ]b00<000000?ooo`3oool0E`3oool005L0oooo
0P00000506hfN@80TEB31P000003095DP`d0ZFV82`2kNX`5000000H0bhZ=00<000000:Blj`2T_>/0
9@2T_>/01@2T_>X0Y;c[0:Blj`2T_>/0Y;cZ0080Y;c[00D000140000002lMhD0d8V40000000`0:Bl
j`030000003oool0oooo00d0oooo00@000000000BP0000000000DP2Wao000`000000Y;cZ0:BljP0T
0:BljP030000003eZg8000000080mJ]b00<000000?ooo`3oool0E`3oool005D0oooo0P00000506hf
N@@000002@2AE8<=0:UYR0d0^gZ<0`3;RXd3000000@0bhZ=00<000000:Blj`2T_>/09P2T_>/00`2T
_>X0Y;c[0:Blj`020:Blj`050000A0000000_7N50=29Q0000000<02T_>/00`000000oooo0?ooo`0=
0?ooo`<00000D`2Wao000`000000Y;cZ0:BljP0U0:BljP060000003eZg8000000?F[LP3h]DT00000
F03oool005<0oooo0P00000506hfN@80000000<0KSIi095DP`2AE8<01`2AE8<C000000X0^gZ<1P3;
RXd3000000030<^:S@000000Y;c[02`0Y;c[00D000140000002lMhD0d8V40000000_0:Blj`030000
003oool0oooo00h0oooo00<0001:000000000000D`2Wao000`000000Y;cZ0:BljP0V0:BljP050000
003eZg8000000?ReB@000000F03oool00580oooo00<000000342HP1^=WT00`1^=WT2000000<0KSIi
1@2AE8<4000001<0Y;g[1`0000030;]jS0T0bhZ=0`00000/0:Blj`050000A0000000_7N50=29Q000
0000;`2T_>/00`000000oooo0?ooo`0>0?ooo`030000BP000000000005<0YlO`00<000000:BljP2T
_>X09`2T_>X01@000000mJ]b0000003h]DT0000005L0oooo001A0?ooo`030000000a0V80<@9R00<0
KSIi00<0000006hfN@1^=WT00`1^=WT2095DP`<000007P2T_N/5000000X0bhZ=0P00000U0:Blj``0
0000;@2T_>/00`000000oooo0?ooo`0>0?ooo`030000000004X0000002T0YlO`00<0dXMm0:O7l02W
ao009`2Wao000`000000Y;cZ0:BljP0X0:BljP8000000P3h]DT00`000000oooo0?ooo`1D0?ooo`00
D03oool01@000000<@9R0342HP0a0V80KSIi008000001@1^=WT3000002H0Y;g[0`0000070<^:S@80
fiV<0P00000K0:Blj`P000001@2YK8`70;akS0P000009@2T_>/00`000000oooo0?ooo`0:0?ooo`80
00000P3oool2000005@0YlO`00<000000:BljP2T_>X0:@2T_>X2000000030?ReB@000000oooo05D0
oooo001?0?ooo`040000000a0V80<@9R0342HP800000101^=WT3000002`0Y;g[0`0000040<^:S@@0
fiV<0`00000E0:Blj`<000000P2DFh/;0:U/S0/0_7^<103=RHT5000001l0Y;c[00<000000?ooo`3o
ool02@3oool2000000060;]jR@00000000000?ooo`0004X00000;02Wao000`000000YlO`0:O7l00U
0:O7l0030000002T_>X0Y;cZ02X0Y;cZ00@000000?ReB@3h]DT00000E@3oool004h0oooo00H00000
0342HP0a0V80<@9R0000000a0V8306hfN@800000<P2T_N/3000000030<^:S@3KVH`0fiV<00D0fiV<
0P00000@0:Blj`<000001@2DFh/60:U/S0`00000102lNh`90<f9R@<000006P2T_>/00`000000Y;c[
0000000;0?ooo`080000002AEhP0^gZ90>VQO`000000oooo0:S7l000000X0:O7l0050000002VHh<0
dXMm0>jOL00000009`2Wao000`000000Y;cZ0:BljP0Z0:BljP80000000<0n;E90?ooo`3oool0E03o
ool004d0oooo00D000000342HP0a0V80<@9R000000020342HP<00000=`2T_N/3000000L0fiV<0P00
000;0:Blj`<000001P2DFh/8000000D0ZFb<1`2lNh`8000000H0cHV90P3NV8@2000001X0Y;c[00<0
00000?ooo`3oool02@3oool020000000TEN80;]jR@3YXGl000000?ooo`2Xao0000009`2Wao001P00
060000000:ISP`3BQgd0kYm`000002L0YlO`00<000000:BljP2T_>X0:`2T_>X2000005H0oooo001=
0?ooo`040000000a0V80<@9R00000080<@9R00<000000:Bmj`2T_N/0>`2T_N/2000000L0fiV<0P00
00070:Blj`80000000<0MdF709AKR`2DFh/00`2DFh/300000080U5^;2`2YK8`;0;akS0@0cHV91@00
00020<f9R@<0gYR40`00000F0:Blj`030000003oool0oooo00X0oooo00D00000095GR02kNXT0jJ5o
000000020?ooo`030000002Wao00YlO`02D0YlO`00H0001P0000002VHh<0dXMm0>jOL000000V0:O7
l0030000002T_>X0Y;cZ02`0Y;cZ0P00001F0?ooo`00C03oool010000000<@9R0342HP0000020342
HP030000002T_N/0Y;g[03h0Y;g[0`0000040=^IS080k:^900@000000:Blj`2T_>/0Y;c[0`000003
07M5Q`80U5^;0`00000509AKR`/0ZFb<2`2lNh`90<f9R@@00000103NV8@2000001<0Y;c[00<00000
0?ooo`3oool02`3oool01@000000TEN80;]jR@3YXGl000000080oooo00<000000:O7l02Wao009@2W
ao001P00060000000:ISP`3BQgd0kYm`000002H0YlO`00<000000:BljP2T_>X0;02T_>X00`000000
n;E90000001E0?ooo`00C03oool00`000000<@9R000000020342HP030000002T_N/0Y;g[0480Y;g[
0P0000020=^IS0<0k:^90`00000507M5Q`<00000202DFh/60:U/S1<00000203=RHT20=jHQ0800000
103NV8@200000100Y;c[00<000000?ooo`3oool0303oool01@000000TEN80;]jR@3YXGl000000080
oooo00<000000:O7l02Wao009@2Wao001P00060000000:ISP`3BQgd0kYm`000000@0YlO`00<0Z<O`
0:O7l02Wao007`2Wao000`000000Y;cZ0:BljP0]0:BljP030000003oool0oooo05@0oooo001;0?oo
o`030000000002P000000080<@9R00<000000:Bmj`2T_N/0A@2T_N/200000080k:^90P00000507M5
Q`80000000<0MdF709AKR`2DFh/01P2DFh/8000001<0YlO`100000040<f9R@@0gYR40P0000020=jH
Q080l:Mi00<000000:Blj`2T_>/03@2T_>/00`000000oooo0?ooo`0<0?ooo`050000002AEhP0^gZ9
0>VQO`0000000P3oool2000002H0YlO`00H0001P0000002<Ch80_7B20>jOL000000U0:O7l0030000
002T_>X0Y;cZ02h0Y;cZ00<000000?ooo`3oool0E03oool004/0oooo00D000000000:0000000<@9R
0000001:0:Bmj`80000000@0BR9m07M5Q`1gAHL0MdF70`00000307M5Q`<0U5^;1@00000O0:O7l0<0
000000<0cHV90=jHQ03NV8@0103NV8@2000000<0l:Mi0P00000<0:Blj`030000003oool0oooo00/0
oooo2@0000000`3=VP/000000:O7l00U0:O7l00600002`000000S4n20;adPP3^Wg0000009@2Wao00
0`000000Y;cZ0:BljP0^0:BljP030000003oool0oooo05@0oooo001;0?ooo`80000000<0<@9R0000
002T_N/0BP2T_N/010000000BR9m04XRO@1gAHL2000000D0MdF71000000W0:O7l0<000001P3NV8@2
000000<0l:Mi00<000000:Blj`2T_>/01`2T_>/2000000@0oooo2P0000060:U/R`@0^g^<00<00000
0:O7l02Wao009@2Wao001@000000S4n20;adPP3^Wg00000002D0YlO`00<000000:BljP2T_>X0;`2T
_>X00`000000oooo0?ooo`1C0?ooo`00BP3oool010000000000X00000000001;0:Bmj`050000001:
8Wd0BR9m04XRO@0000001@1gAHL2000002h0YlO`0`0000030=jHQ080l:Mi00D000000?2WN@3`YgT0
l:Mi000000070:Blj`L000000`2EFXP=0:U/R`@0^g^<00<000000:O7l02Wao009@2Wao001@000000
S4n20;adPP3^Wg00000002@0YlO`00<000000:BljP2T_>X0<02T_>X00`000000oooo0?ooo`1C0?oo
o`00BP3oool00`0002P000000000001;0:Bmj`050000001:8Wd0BR9m04XRO@000000101gAHL20000
03<0YlO`0`0000030?2WN@8000000P3`YgT00`000000Y;c[0:Blj`030:Blj`8000002@2EFXP=0:U/
R`@0^g^<00<000000:O7l02Wao009@2Wao001@000000S4n20;adPP3^Wg00000002<0YlO`00<00000
0:BljP2T_>X0<@2T_>X00`000000oooo0?ooo`1C0?ooo`00BP3oool00`000000000X0000001:0:Bm
j`060000001:8Wd0BR9m04XRO@000000BR9m0`1gAHL00`000000YlO`0:O7l00f0:O7l08000000`3`
YgT00`000000l:Mi000000030:Blj`8000002`2EFXP70:U/R`X0000000<0^g^<0000002Wao009@2W
ao001@000000S4n20;adPP3^Wg0000000280YlO`00<000000:BljP2T_>X0<P2T_>X00`000000oooo
0?ooo`1C0?ooo`00BP3oool2000004/0Y;g[00@0000004XRO@1:8Wd000000P1:8Wd00`1gAHL00000
0000000k0:O7l00:0000003`YgT0l:Mi0?2WN@000000o;EM0000002T_>/0000007U3P`T0UEZ82P00
00060:U/R`@0^g^<0`00000U0:O7l0050000002<Ch80_7B20>jOL00000008@2Wao000`000000Y;cZ
0:BljP0c0:BljP030000003oool0oooo05<0oooo00190?ooo`030000000002P0000004X0Y;g[00@0
000004XRO@1:8Wd000000P1:8Wd2000003h0YlO`0P0000020?2WN@030000003l]Ed000000080ND>3
0`2EFXP6000000<0UEZ83@2YK8/70;]kS0030000002Wao00YlO`0280YlO`00D0000008a?PP2lM880
kYm`0000000O0:O7l08000000`2T_>X010000000Y;cZ0=68P@00000_0:BljP030000003oool0oooo
05<0oooo00190?ooo`030000:0000000Y;g[04T0Y;g[00@000000000HP1:8Wd000000P1:8Wd00`00
0000YlO`0:O7l0100:O7l0060000003`YgT000000?beG@000000ND>31000000909EJR0d0ZFb;202k
Nh`300000240YlO`00D0000008a?PP2lM880kYm`0000000N0:O7l0030000002T_>X0Y;cZ00<0Y;cZ
00@000000:BljP3AR8400000;`2T_>X00`000000oooo0?ooo`1C0?ooo`00B@3oool00`000000Y;g[
0:Bmj`190:Bmj`0300000000068000000080BR9m00<000000:O7l02Wao00@P2Wao001P000000o;EM
0000003l]Ed0000007U3P`X0UEZ84`0000060;]kS0030000002Wao00YlO`01l0YlO`00D0000008a?
PP2lM880kYm`0000000L0:O7l08000001P2T_>X010000000Y;cZ0=68P@00000_0:BljP030000003o
ool0oooo05<0oooo00190?ooo`030000002T_N/0Y;g[04P0Y;g[00H000000000HP000680000004XR
O@0000160:O7l0050000003l]Ed000000?beG@0000001P2EFXP4000001<0Y;c[1P0000000`2kNh`0
00000:O7l00O0:O7l0050000002<Ch80_7B20>jOL00000006P2Wao02000000P0Y;cZ00@000000:=T
R03AR8400000;`2T_>X00`000000oooo0?ooo`1C0?ooo`00B03oool00`000000Y;g[0:Bmj`180:Bm
j`06000000000680001R0000001:8Wd00000A`2Wao001@000000o;EM0000003l]Ed000000080UEZ8
1000000M0:Blj`<000007`2Wao001@000000S4n20;adPP3^Wg00000001T0YlO`00<000000:BljP2T
_>X0202T_>X010000000XfB80=68P@00000_0:BljP030000003oool0oooo05<0oooo00180?ooo`03
0000002T_N/0Y;g[04P0Y;g[00D000000000HP000000001R000000190:O7l0030000003l]Ed00000
00<00000902T_>/01@000000YlO`0:O7l02Wao00000001X0YlO`00<0000008a?PP2lM8801`00000B
0:O7l08000002`2T_>X010000000XfB80=68P@00000^0:BljP030000003oool0oooo05@0oooo0018
0?ooo`030000002T_N/0Y;g[04P0Y;g[00D000000000HP000000001R0000001:0:O7l0030000003l
]Ed0000002L0Y;c[0P00000J0:O7l0D000000P2YK8`50;ajR@P00000202Wao02000000d0Y;cZ00@0
00000:=TR03AR8400000;P2T_>X00`000000oooo0?ooo`1D0?ooo`00B03oool00`000000Y;g[0:Bm
j`0Y0:Bmj`030:Zoj02T_N/0Y;g[01`0Y;g[0P0000000`00068000000:O7l01:0:O7l0040000003l
]Ed00000000002P0Y;c[0P00000D0:O7l0@000001`2YK8`80;ajR@D0cXN32000000?0:BljP040000
002SI8P0dHR1000002h0Y;cZ00<000000?ooo`3oool0E03oool004P0oooo00<000000:Bmj`2T_N/0
A`2T_N/2000000030000HP000000YlO`04`0YlO`0`00000Z0:Blj`8000001@2Wao000`000000YlO`
0:O7l0060:O7l0@000000P2EGXh50:U/S1000000103>Qh<20>:EN0<000003`2T_>X010000000XfB8
0=68P@00000]0:BljP030000003oool0oooo05D0oooo00180?ooo`030000002T_N/0Y;g[02d0Y;g[
00<0Y;c[0:Bmj`2T_N/05`2T_N/2000000030000HP000000YlO`04d0YlO`0P00000/0:Blj`800000
2@2Wao03000000D0UEj>1P0000040:U/S0T0_7Z90`3>Qh<4000000030<j7P`3RUGP0hYEh0080hYEh
0P00000=0:BljP0501<0L0000000Q4j70>bZ;P000000;02T_>X00`000000oooo0?ooo`1E0?ooo`00
B03oool00`000000Y;g[0:Bmj`170:Bmj`<00000C`2Wao02000002h0Y;c[100000020:O7l0<00000
00<0O4f=09ENSP2EGXh00P2EGXh30000000309ENSP2YK8`0ZFb<00L0ZFb<2@2lNXT70<j7P`<00000
103RUGP00`000000Y;cZ0:BljP0:0:BljP030=^@OP000000Q4j701800000702T_>X00`000000oooo
0?ooo`1E0?ooo`00B03oool00`000000Y;g[0:Bmj`170:Bmj`800000D@2Wao000`000000Y;c[0:Bl
j`0_0:Blj`<00000101lCHd0102EGXh0000000000000000509ENSP@0ZFb<400000050<j7P`80hYEh
0P0000020>:EN0030?BRHP000000Y;cZ00@0Y;cZ2@0000050:Y_S`X0_7^<0`3>R8L3000001P0Y;cZ
00<000000?ooo`3oool0EP3oool004P0oooo00<000000:Bmj`2T_N/0;02T_N/00`1D8W@0Y;g[0:Bm
j`0H0:Bmj`800000D@2Wao000`000000Y;c[0:Blj`0^0:Blj`030000001lCHd0O4f=00@0O4f=0P00
000709ENSPD00000402Xc_<4000000030<j7P`3RUGP0hYEh0080hYEh0P0000020?BRHPD000000`2H
HHl;0:Y_S`X0_7^<1P3>R8L3000001@0Y;cZ00<000000?ooo`3oool0E`3oool004T0oooo00<00000
0:Bmj`2T_N/09P2T_N/20:Zoj0<0Y;g[00H000000:Bmj`2T_N/000000:Bmj`2T_>/E0:Bmj`800000
D@2Wao000`000000Y;c[0:Blj`0]0:Blj`030000001lCHd0O4f=0080O4f=0`0000000`1lCHd0UEj>
09ENSP0309ENSP<000006@2Xc_<4000000<0hYEh0P0000000`3dXV80000009QQS`0509QQS`H0ZVn?
300000040;akS0P0cXR70`00000@0:BljP030000003oool0oooo05P0oooo00190?ooo`030000002T
_N/0Y;g[02/0Y;g[00@000000:MXQ`3>RhT000005`2T_N/200000580YlO`00<000000:Blj`2T_>/0
:`2T_>/010000000FCB:05TdRP1lCHd2000000@0O4f=0P2EGXh300000200Z<kc0`0000020?BRHP<0
00000`2HHHl8000000D0ZVn?1`2lNh`7000000H0cXR70P3QUgh3000000`0Y;cZ00<000000?ooo`3o
ool0F@3oool004T0oooo00<000000:Bmj`2T_N/0:`2T_N/010000000YfR70<j;R@0000080:Bmj`03
0:Blj`2T_N/0Y;g[00`0Y;g[00<000000:O7l02Wao00D@2Wao000`000000Y;c[0:Blj`0Z0:Blj`03
0000001I=8X0FCB:008000001@1lCHd3000002H0Z<kc0P0000020?BRHP@000000P2HHHl;0:Y_S`/0
_7^<0`3>R8L5000000030<j8Q`3QUgh0hIMn00<0hIMn0P0000090:BljP030000003oool0oooo05X0
oooo001:0?ooo`030000002T_N/0Y;g[02X0Y;g[00@000000<1mRP3>RhT000005`2T_N/00`000000
YlO`0:O7l00U0:O7l0060000002VIH@0d8V40:O7l0000000Z<O`9P2Wao000`000000Y;c[0:Blj`0Y
0:Blj`050000001I=8X0FCB:0000001I=8X00`1lCHd3000002/0Z<kc00@000000?BRHP3dXV800000
102HHHl60:Y_S``00000102lNh`80<j8Q`<000001@3QUgh2000000H0Y;cZ00<000000?ooo`3oool0
F`3oool004X0oooo00<000000:Bmj`2T_N/0:P2T_N/010000000`7f:0<j;R@00000G0:Bmj`030000
002Wao00YlO`02D0YlO`00D000000:IUQ03@RH@0jJ5n0000000W0:O7l0030000002T_>/0Y;c[02P0
Y;c[00@0000005TdRP1I=8X000000P1I=8X00`1lCHd000000000000_0:S>l`050000003dXV800000
0000002HHHl02000000<0:O8l@L000001P3>R8L20>6GOP<000000P3QUgh20?BVJ0030000002T_>X0
Y;cZ0080Y;cZ00<000000?ooo`3oool0G03oool004X0oooo00<000000:Bmj`2T_N/0:@2T_N/01@00
0000E29d0<1mRP3>RhT0000001L0Y;g[00<000000:O7l02Wao00802Wao002P2Xao00YlO`0:O7l02W
ao00Z<O`0000002VIH@0d8V40>VQOP00000V0:O7l0030000002T_>/0Y;c[02P0Y;c[00@0000005Td
RP1I=8X000000P1I=8X200000380Z<kc00@000000?2R;P00000000006`2Wb?45000000030<j8Q`3Q
Ugh0hIMn00<0hIMn0`0000020?BVJ0040000002T_>X00000000005l0oooo001;0?ooo`050000002T
_N/0Y;g[0:Bmj`0000009P2T_N/01@000000S5230;]iR@3UXHH0000001P0Y;g[00<000000:O7l02W
ao006P2Wao000`2Xao00YlO`0:O7l0030:O7l0090:S7l02Wao00YlO`0:O7l0000000YVF40=29Q03Y
XGh0000002H0YlO`00<000000:Blj`2T_>/09`2T_>/0100000008Pin05TdRP00000205TdRP030000
002Xc_<0Z<kc03<0Z<kc0P00000Q0:O8l@<000001P3QUgh010000000m:IX0?BVJ000001Q0?ooo`00
B`3oool00`000000Y;g[0:Bmj`0X0:Bmj`050000002<D8<0^gV90>FQQP000000602T_N/00`000000
YlO`0:O7l00T0:O7l0050000002VIH@0d8V40>VQOP0000009P2Wao000`000000Y;c[0:Blj`0V0:Bl
j`050000000R3Wh08Pin0000001I=8X00P00000f0:S>l`<000008`2Wb?42000000@0hIMn00D0m:IX
0000003dYVP0m:IX0000001P0?ooo`00C03oool00`000000Y;g[0:Bmj`0W0:Bmj`050000002<D8<0
^gV90>FQQP000000602T_N/00`000000YlO`0:O7l00T0:O7l0050000002VIH@0d8V40>VQOP000000
9@2Wao000`000000Y;c[0:Blj`0V0:Blj`060000000R3Wh08Pin0000001I=8X00000>@2Xc_<20000
02D0YlSa0P0000020>6GOP80m:IX00@000000?BVJ03dYVP00000G`3oool004d0oooo00<000000:Bm
j`2T_N/09P2T_N/010000000S5230;]iR@00000J0:Bmj`030000002Wao00YlO`0280YlO`00D00000
05HTMP2lMhD0d8V40000000V0:O7l0030000002T_>/0Y;c[02H0Y;c[00D00000028>OP0000008Pin
0000000k0:S>l`030000002Wb?40YlSa02D0YlSa0P0000030?BVJ0030000003dYVP0000005l0oooo
001>0?ooo`030000002T_N/0Y;g[01`0Y;g[3@00000J0:Bmj`030000002Wao00YlO`0280YlO`00D0
000008]>P@2lMhD0d8V40000000V0:O7l0030000002T_>/0Y;c[02D0Y;c[00<00000028>OP000000
0P0R3Wh00`000000Z<kc0:S>l`0i0:S>l`800000:02Wb?4200000080m:IX00<000000?2V<0000000
GP3oool004l0oooo00<000000:Bmj`2T_N/0502T_N/7000000D0ZVn>1`2kOHl8000001<0Y;g[00<0
00000:O7l02Wao008P2Wao001@000000Rdj10;agQ@3@RH@0000000<0YlO`00<0Z<O`0:O7l02Wao00
7`2Wao000`000000Y;c[0:Blj`0F0:Blj`030:BljP2T_>/0Y;c[00d0Y;c[0P000002028>OP030000
002Xc_<0Z<kc03/0Z<kc00<000000:O8l@2Wb?40:02Wb?401P000000m:IX0?BVJ0000000l:H`0000
05d0oooo001@0?ooo`030000002T_N/0Y;g[0100Y;g[0`00000209EMS0X0ZVn>2`2kOHl40<^;SPD0
00003`2T_N/00`000000YlO`0:O7l00Q0:O7l0050000002;CX40_7N50=29Q0000000902Wao000`00
0000Y;c[0:Blj`0G0:Blj`030:BljP2T_>/0Y;c[00d0Y;c[0P0000000`0R3Wh000000:S>l`0m0:S>
l`030000002Wb?40YlSa02T0YlSa0`0000000`3`YS0000000?ooo`1L0?ooo`00D@3oool2000000d0
Y;g[0`00000509EMS0X0ZVn>2`2kOHl90<^;SP<000003@2T_N/00`000000YlO`0:O7l00P0:O7l005
0000002;CX40_7N50=29Q00000008`2Wao000`000000Y;c[0:Blj`0H0:Blj`030:BljP2T_>/0Y;c[
00`0Y;c[00D000000000G00000008Pin0000000n0:S>l`030000002Wb?40YlSa02/0YlSa0P000000
0`3`YS0000000?ooo`1K0?ooo`00D`3oool00`000000Y;g[0:Bmj`070:Bmj`<00000202EGH`50:Y_
SQ@000001P3;Rhh20=^HR`800000302T_N/00`000000YlO`0:O7l00O0:O7l0050000002;CX40_7N5
0=29Q00000008@2Wao02000001/0Y;c[00<0Y;cZ0:Blj`2T_>/0302T_>/0100005`000000000G000
000o0:S>l`030000002Wb?40YlSa02`0YlSa00<000000?2V<03oool0G03oool005@0oooo00<00000
0:Bmj`2T_N/0102T_N/20000000307M5Q`2EGH`0UEf<00H0UEf<1`0000050:Y_SP/0^gf?103;Rhh5
000000030<^;SP3KV8/0fiR;0080fiR;0`00000:0:Bmj`030000002Wao00YlO`01h0YlO`00D00000
08]>P@2lMhD0d8V40000000P0:O7l0030000002T_>/0Y;c[02X0Y;c[00@0_XP00000000005`00000
?`2Xc_<00`000000YlSa0:O8l@0/0:O8l@<00000G03oool005D0oooo0P0000020:Bmj`8000000`1g
AHL309EMS0D000000P2EGH`:0:Y_SP/0^gf?2@3;Rhh3000000D0fiR;0P0000090:Bmj`8000007P2W
ao001@000000Rdj10;agQ@3@RH@0000001h0YlO`0P00000J0:Blj`030:Zoj02T_>/0Y;c[0140Y;c[
0P00000Q0:S>l`030000002Xc_<0Z<kc01`0Z<kc00<000000:O8l@2Wb?40;@2Wb?42000005`0oooo
001G0?ooo`800000101gAHL4000000L0UEf<1@2ZKhhC000000L0bh^>0P3KV8/2000000D0fiR;0P00
00090:Bmj`030000002Wao00YlO`01/0YlO`00D0000008]>P@2lMhD0d8V40000000M0:O7l0030000
002T_>/0Y;c[02h0Y;c[00<0001L0000002Xc_<0702Xc_<01@000000S4n20;adPP3^Wg00000001d0
Z<kc00<000000:O8l@2Wb?40;P2Wb?42000005`0oooo001F0?ooo`030000001gAHL0MdF70080MdF7
0P0000000`1gAHL0UEf<09EMS00609EMS0L000004`2Wao03000000@0bh^>103KV8/300000080fiR;
0P3/Yh<2000000P0Y;g[0P00000K0:O7l0050000002;CX40_7N50=29Q0000000702Wao000`000000
Y;c[0:Blj`0J0:Blj`080:Zoj02T_>/0Y;c[0000002AEhP0^gZ90:Blj`0000070:Blj`030:BljP2T
_>/0Y;c[00<0Y;c[00<0001L0000002Xc_<0702Xc_<01@000000S4n20;adPP3^Wg00000001d0Z<kc
00<000000:O8l@2Wb?40;P2Wb?46000005P0oooo001E0?ooo`040000001gAHL0MdF707M5Q`800000
0`1gAHL309EMS0D000007@2Wao03000000030<^;SP3KV8/0fiR;00D0fiR;0P0000040>bWP`030000
002T_N/0Y;g[00L0Y;g[00<000000:O7l02Wao000P2Wao000`000000YlO`0:O7l00C0:O7l0050000
002;CX40_7N50=29Q00000006P2Wao0200000200Y;c[00D00000095GR02kNXT0jJ5o0000000=0:Bl
j`030000002Xc_<0Z<kc01`0Z<kc00D0000008a?PP2lM880dXMm0000000M0:S>l`030000002Wb?40
YlSa02l0YlSa00<000000;]lSP3<RH/00P3<RH/4000005@0oooo001D0?ooo`03000000157GX0MdF7
00800000101gAHL4000002D0YlO`100000060=^HR`8000000`3/Yh<2000000P0Y;g[0P00000H0:O7
l0050000002;CX40_7N50=29Q0000000602Wao02000001/0Y;c[00<0Y;cZ0:Blj`2T_>/00`2T_>/0
1P2Z_nP00000095GR02kNXT0jJ5o000000d0Y;c[00<000000:S>l`2Xc_<0702Xc_<01@000000S4n2
0;adPP3BQgd0000001`0Z<kc00<000000:O8l@2Wb?40<02Wb?400`000000^gb>0<b9R`060<b9R`<0
0000D@3oool005<0oooo00@0000004DMNP157GX00000101gAHL2000002d0YlO`0`0000030=^HR`80
k:N30P0000030>bWP`030000002T_N/0Y;g[00D0Y;g[1000000F0:O7l0050000002;CX40_7N50=29
Q00000005P2Wao0200000200Y;c[00T0Y;cZ0:Blj`2T_>/0Y;c[0000002AEhP0^gZ90>VQO`000000
3@2T_>/00`000000Z<kc0:S>l`0L0:S>l`050000002<Ch80_7B20=:7O@0000006@2Xc_<010000000
Z<kc0:S>l`0000080:O8l@030:O7l02Wb?40YlSa02L0YlSa00<000000;]lSP3<RH/02@3<RH/30000
04h0oooo001B0?ooo`04000000157GX0AAej000000<0MdF70P00000b0:O7l0<00000103/Yh<01000
0000k:N30>bWP`0000060:Bmj`050000002ZKXd0ZVj=0:Y^S@2kOHl00`00000?0:O7l18000002`2W
ao02000001l0Y;c[00<0Y;cZ0:Blj`2T_>/0102T_>/01@000000TEN80;]jR@3YXGl0000000d0Y;c[
00<0_XP00000002Xc_<0702Xc_<01@000000S4n20;adPP3BQgd0000001/0Z<kc00<000000:O8l@2W
b?40<@2Wb?45000000P0c8V;0P3OVHH2000004`0oooo001A0?ooo`06000000157GX0AAej00000015
7GX0MdF70P00000g0:O7l08000000`3/Yh<2000000030?^hL@000000Y;g[0080Y;g[0P0000040:Y^
S@@0^gf?0P0000070:O7l0H00000102ZKXh90;akS0D0cHR91@0000030:O7l0<00000:02T_>/01@00
0000TEN80;]jR@3YXGl0000000h0Y;c[00<000000:S>l`2Xc_<06`2Xc_<01@000000S4n20;adPP3B
Qgd0000001X0Z<kc00<000000:O8l@2Wb?40<P2Wb?400`000000^gb>0<b9R`020<b9R`@00000103<
RH/40=nIQP800000BP3oool00540oooo00@0000004DMNP000000AAej0P00000k0:O7l0030000003/
Yh<0k:N30080k:N300D000000?^hL@000000Y;g[000000040:Y^S@030:Blj`2ZKXd0^gf?00D0^gf?
1`00000209ENSP@0ZVj>400000040<f8R@<0gYJ20`00000[0:Blj`050000002AEhP0^gZ90>VQO`00
00003P2T_>/00`000000Z<kc0:S>l`0K0:S>l`050000002<Ch80_7B20=:7O@0000006@2Xc_<00`00
0000YlSa0:O8l@0:0:O8l@03091GQ`2Wb?40YlSa02H0YlSa00<000000;]lSP3<RH/01P3<RH/30000
00030<b9R`3OVHH0giV600@0giV600<000000?ooo`3oool0A`3oool00500oooo00D0000004DMNP00
0000AAej0000000n0:O7l08000000P3/Yh<00`000000nkQa0?^hL@0A000000D0UEj>1@0000040:Y^
SPT0_7^<0`3=R8T4000000030<f8R@3NUX80gYJ200<0gYJ20`00000X0:Blj`050000002AEhP0^gZ9
0>VQO`0000003P2T_>/00`000000Z<kc0:S>l`0K0:S>l`050000002<Ch80_7B20=:7O@0000005`2X
c_<2000003H0YlSa00<000000;]lSP3<RH/02@3<RH/3000000D0giV60P0000170?ooo`00C`3oool0
1@000000001E000000157GX000000440YlO`00@000000>bWP`3k^74000000P3k^7400`000000Y;g[
0:Bmj`070:Bmj`<0000000<0NDV<09ENSP2EGXh00P2EGXh30000000309ENSP2ZKXh0ZVj>00H0ZVj>
2@2lNh`70<f8R@@000000`3NUX820?2UM@030000002T_>/0Y;c[02D0Y;c[00D00000095GR02kNXT0
jJ5o0000000?0:Blj`030000002Xc_<0Z<kc01X0Z<kc00D0000008a?PP2lM880dXMm0000000F0:S>
l`030000002Wb?40YlSa00H0YlSa0`2Wao030:O8l@050000002@EhL0_7N60>fPLP0000009@2Wb?45
000000P0c8V;0P3OVHH2000000D0giV600<000000?ooo`3oool0A03oool004l0oooo00@000000000
E@0000000000@`2Wao0010000000nkQa0?^hL@0000020?^hL@030000002T_N/0Y;g[00@0Y;g[0P00
000407U9S00409ENSP0000000000000000@0UEj>102ZKXh@000000D0cHR90`3NUX83000000040=jF
PP3`YGD0l:Ee000002H0Y;c[00H00000095GR02kNXT0jJ5o0000002T_>X?0:Blj`030000002Xc_<0
Z<kc01T0Z<kc00D0000008a?PP2lM880dXMm0000000D0:S>l`8000003`2Wb?401@000000T5N70;ag
QP3]X780000002D0YlSa00<000000:Blj`2T_>/00P2T_>/4000000@0c8V;103OVHH2000000<0giV6
00<0lj]g0000003oool0A03oool004h0oooo00@000000000E@0000000000A@2Wao001P000000nkQa
0?^hL@000000nkQa000000@0Y;g[0P00000507U9S08000001@2EGXh600000100Z<gc100000000`3=
R8T0gYJ20=jFPP040=jFPP<0000000<0l:Ee0000002T_>/0902T_>/01@000000TEN80;]jR@3YXGl0
00000080Y;c[00<0Y;cZ0:Blj`2T_>/0302T_>/2000001T0Z<kc00D0000008a?PP2lM880dXMm0000
000C0:S>l`030000002Wb?40YlSa00h0YlSa00H0YlO`0000002@EhL0_7N60>fPLP00000T0:O8l@03
0000002T_>/0Y;c[00L0Y;c[0`0000000`3<RH/0giV60=nIQP040=nIQP030000003OVHH0giV60080
lj]g00<000000?ooo`3oool0@P3oool004h0oooo0`0000170:O7l0030000003k^740nkQa00800000
0`2T_N/00`000000D2^407U9S00207U9S0<0000000<0NDV<09ENSP2EGXh01000000J0:S=l`@00000
103NUX820?2UM@030000003`YGD000000280Y;c[4`0000070:Blj`8000005`2Xc_<01@000000S4n2
0;adPP3BQgd000000140Z<kc0P00000B0:O8l@050000002@EhL0_7N60>fPLP000000902Wb?400`00
0000Y;c[0:Blj`0:0:Blj`<000001@3OVHH2000000<0lj]g00<000000?ooo`3oool0@@3oool004h0
oooo00<000000000E@000000B02Wao000`000000nkQa0?^hL@02000000050:Bmj`000000D2^4050[
Q01iBH`00P00000307U9S0<000008P2XcO<3000000070=jFPP3`YGD0l:Ee0?2UM@000000nk1F0000
000J0:Blj`L000001@2[L90:0;]mS`@0c8Z<1@0000040:Blj`030000002Xc_<0Z<kc01@0Z<kc00D0
000008a?PP2lM880dXMm0000000>0:S>l`<00000502Wb?401P000000T5N70;agQP3]X78000000:O7
l2<0YlSa00<000000:Blj`2T_>/03@2T_>/2000000D0giV600D000000?>[M`3cZgL0lj]g00000012
0?ooo`00C@3oool00`000000001E0000001:0:O7l0030000003k^7400000008000000P1@:h@20000
00<0NDV<0P00000X0:S=l`<000000P3`YGD00`000000nk1F0000000D0:Blj`D000000P2HHY0:0:]`
T0X0^gf?2@3<RX`300000080Y;c[0P00000D0:S>l`050000002<Ch80YV>30=:7O@000000302Xc_<2
00000140YlSa00<0YlO`0:O8l@2Wb?400`2Wb?401@000000T5N70:QXR03]X780000002<0YlSa00<0
00000:Blj`2T_>/0402T_>/2000000<0giV600<0lj]g0000003cZgL00P3cZgL00`000000oooo0?oo
o`0o0?ooo`00C@3oool00`000000001E0000001;0:O7l0<000000P1@:h@00`000000D2^407U9S002
07U9S0030000002XcO<0Z<gc02/0Z<gc0P000000103`YGD000000?^`EP00000?0:Blj`@000001`2H
HY050:]`T0`00000102kOHl90<b:S080gIR60P0000020:Blj`8000004P2Xc_<01@000000S4n20:IS
P`3BQgd0000000T0Z<kc0`00000I0:O8l@0601<0L0000000Z6R80;agQP3/ZRh000007P2Wb?401000
0000YlSa0:O8l@00000E0:Blj`030000003OVHH0giV60080lj]g00D000000?>[M`3cZgL0lj]g0000
00100?ooo`00C@3oool2000004d0YlO`0P0000001@1@:h@00000050[Q01@:h@0NDV<00800000<02X
cO<200000080nk1F00<000000:Blj`2T_>/02P2T_>/200000003081?SP2HHY00V6:@00H0V6:@1`00
00050:]`T0L0^gf?1`0000060<b:S0@0gIR60P0000020:Blj`800000402Xc_<01@000000S4n20:IS
P`3BQgd0000000D0Z<kc1000000L0:O8l@060?:TKP000000Z6R80;agQP3]X7800000802Wb?400`00
0000Y;c[0:Blj`0E0:Blj`8000000`3cZgL010000000lj]g0?>[M`0000100?ooo`00C@3oool20000
04d0YlO`00<00000050[Q00000000P1@:h@2000003<0Z<gc0P0000000`3k/5H000000:Blj`090:Bl
j`8000000`20Chh309QRT0D000000P2HHY0:0:]`T0/0^gf?0`3<RX`5000000030<b:S03MV8H0gIR6
00@0gIR60P0000020:Blj`D000002`2Xc_<010000000S4n20:ISP`3BQgd600000200YlSa00H0mjm2
0000002XJ8P0_7N60>fPLP00000O0:O8l@030000002T_>/0Y;c[01P0Y;c[00P000000?>[M`3cZgL0
lj]g0000003cZgL0nKI;000003l0oooo001=0?ooo`030000002Wao00YlO`04/0YlO`00<0000000H0
K`0000000P1@:h@00`000000Z<gc0:S=l`0c0:S=l`040000003k/5H00000000000P0Y;c[0P000004
081?SP@000001`2HHY050:]`T0`00000102kOHl80<b:S0<000001P3MV8H2000000D0Y;c[30000000
0`2<Ch80YV>30=:7O@02000002D0YlSa00D000000:QXR02lMhH0kJ1b0000000N0:O8l@030000002T
_>/0Y;c[01X0Y;c[00L000000?>[M`3cZgL0lj]g0000003i]T/0000003l0oooo001=0?ooo`030000
002Wao00YlO`04/0YlO`00D0000000H0K`000000D2^40000000g0:S=l`030000003k/5H000000080
0000102T_>/2000000@0P4n>0P0000000`20Chh0V6:@09QRT00609QRT0L00000302Wb?47000000H0
c8Z<0P3MV8H3000000<0gIR60P3`YgT00`000000Y;c[0:Blj`030:Blj`800000202kOHl01`000000
S4n20:ISP`3BQgd000000<^:SP000000902Wb?401@000000Z6R80;agQP3]X780000001d0YlSa00<0
00000:Blj`2T_>/0702T_>/01`000000lj]g0?>[M`3cZgL000000?VfB`000000?P3oool004d0oooo
00<000000:O7l02Wao00BP2Wao001@0000001P1_0000001@:h@0000003T0Z<gc0`0000001P3oool0
00000000002T_>/0000005`dR0<0P4n>0P000003081?SPD0V6:@0`00000J0:O8l@D0000000<0c8Z<
0=fHQP3MV8H00`3MV8H3000000<0l:Mi0P0000020:Blj`P000000`2kOHl01`000000S4n20:ISP`3B
Qgd000000<^:SP000000902Wb?401@000000Z6R80;agQP3]X780000001/0YlSa0P00000P0:Blj`06
0000003cZgL0lj]g0000003i]T/00000?P3oool004d0oooo00<000000:O7l02Wao00BP2Wao020000
000300H0K`000000Z<gc03X0Z<gc0P0000020?ooo`8000000P1L=8P00`20Chh0000000000005081?
SP80V6:@0`00000R0:O8l@<000001P3MV8H2000000<0l:Mi0P0000000`2[Khl0^gf?0;]mS`050;]m
S`<0000000L0001P0000002VHh<0dXMm0>jOL0000000bhZ>008000008P2Wb?401@000000Z6R80;ag
QP3]X780000001T0YlSa0P00000S0:Blj`030000003cZgL0nKI;00800000?P3oool004d0oooo00<0
00000:O7l02Wao00902Wao0010000000^gV90>FQQP00000R0:O7l0040000000606l01P1_000003/0
Z<gc0P0000000`3oool0000005`dR00205`dR08000001P20Chh3000002P0YlSa0`0000030=fHQP80
l:Mi00H000000?2WN@3`YgT0l:Mi0000002[Khl:0;]mS`050000H0000000S4n20;adPP3BQgd01@00
000Q0:O8l@050000002XJ8P0_7N60>fPLP000000602Wb?400`000000Y;c[0:Blj`0T0:Blj`050000
003i]T/000000?VfB`000000?@3oool004d0oooo00<000000:O7l02Wao008`2Wao001@0003000000
0;]iR@3UXHH000000280YlO`00<0000000H0K`000000?02XcO<3000000<0G3B800<0000005`dR020
Chh00`20Chh3000002h0YlSa0`0000030?2WN@80000000<0l:Mi000000000000100000060;]mS`06
0?:TK0000000S4n20;adPP3BQgd000000`3;RXh200000200YlSa00D000000:QXR02lMhH0kJ1b0000
000F0:O8l@800000:02T_>/00`000000nKI;0000000n0?ooo`00C@3oool00`000000YlO`0:O7l00O
0:O7l0090:S7l02Wao00YlO`0:O7l000030000000;]iR@3UXHH000000280YlO`00<0000000H0K`00
0000?@2XcO<00`000000G3B805`dR00200000080G3B800@0P4n>0000000000000000=02Wb?420000
00<0l:Mi00<000000?^cEP000000102T_>/6000000060;]mS`000000S4n20;adPP3BQgd000001@3;
RXh00`000000YlSa0:O8l@0M0:O8l@050000002XJ8P0_7N60>fPLP000000502Wb?42000002X0Y;c[
00<000000?VfB`000000?P3oool004h0oooo00<000000:O7l02Wao006@2Wao000`2Xao00YlO`0:O7
l0030:O7l0080:S7l02Wao00YlO`0000<0000000^gV90>FQQP00000R0:O7l0800000?P2XcO<00`00
0000G3B80000000305`dR0800000>@2Wb?401`000000l:Mi0?2WN@3`YgT000000?^cEP0000002@2T
_>/20000000408a?PP2lM880dXMm000000H0bhZ>00<000000:O8l@2Wb?40702Wb?401@000000Z6R8
0;agQP3]X78000000180YlSa0P00000]0:Blj`800000?P3oool004h0oooo00<000000:O7l02Wao00
8P2Wao001@00030000000;]iR@3UXHH000000280YlO`0P00000J0:S=l`030:W=l`2XcO<0Z<gc0240
Z<gc0P00000305`dR0030000002Wb?40YlSa03X0YlSa0P000000103`YgT000000?^cEP00000:0:Bl
j`040000002<Ch80_7B20=:7O@@00000103;RXh2000001`0YlSa00D00000091GQ`2XJ8P0kJ1b0000
000?0:O8l@@00000;P2T_>/00`000000nKI;0000000m0?ooo`00CP3oool00`000000YlO`0:O7l00R
0:O7l0050000<0000000^gV90>FQQP0000008P2Wao02000001`0Z<gc00D000000:S=l`2lMhD0jJ5n
0000000M0:S=l`030000001L=8P0G3B800800000?`2Wb?401@000000nk=F0000003k/eH0000000D0
Y;c[3`0000000`3;RXh0g9V;0=bIR`03000001T0YlSa00D00000091GQ`2XJ8P0dHR10000000=0:O8
l@800000<`2T_>/00`000000oooo0?ooo`0l0?ooo`00C`3oool00`000000YlO`0:O7l00Q0:O7l004
0000002kNHT0cX^9000002<0YlO`00<000000:S=l`2XcO<06`2XcO<01@000000YVF40;agQ@3YXGh0
000001d0Z<gc00<0000005`dR0000000@P2Wb?401@000000nk=F000000000000Y;c[00@000000P2B
EhL60:QYR@@0_7Z91P0000030=bIR`<000005P2Wb?400`000000T5N70000000?000003D0Y;c[00<0
00000?ooo`3oool0?03oool004l0oooo00<000000:O7l02Wao00802Wao001@00030000000;]iR@3U
XHH0000002<0YlO`00<000000:S=l`2XcO<06`2XcO<020000000YVF40;agQ@3YXGh000000:W=l`2X
cO<0ZLgc6@2XcO<00`000000G3B8000000130:O8l@030000003k/eH000000080000000<0MT62099G
Q`2BEhL00`2BEhL60:QYR@H0_7Z90`3>RXP3000000@0g9V;0`00000@0:O8l@D00000102[L9080;al
S@<0cHR70`00000c0:Blj`800000?@3oool00500oooo00<000000:O7l02Wao007`2Wao001@000300
00000;]iR@3UXHH0000002<0YlO`00<000000:S=l`2XcO<06`2XcO<01@000000YVF40;agQ@3YXGh0
00000080Z<gc00@0ZLgc0:S=l`2XcO<0ZLgc5P2XcO<2000004@0YlSa0P00000407I1PP<0TUN74@00
00030<j:R08000000`3LVH/00`3_Zh80000000000004000000P0YlSa0`0000000`2HI980Zg2@0:]`
T0070:]`T0P0_7b=1@3=R8L400000300Y;c[00<000000?ooo`3oool0>`3oool00540oooo00<00000
0:O7l02Wao007P2Wao001@00030000000;]iR@3UXHH0000002<0YlO`00<000000:S=l`2XcO<06`2X
cO<01@000000YVF40=29Q03YXGh0000001T0Z<gc00<000000:S=l`2XcO<00P0000120:O8l@800000
00@0CR5h07I1PP1f@H80MT621@000002099GQ`H0Z6V91P2lNXT30<j:R0<000000P3QVh@200000004
0=bIR`3_Zh80000000000080Y;c[00<0kj^20:BljP0000001`00000409QTTPD0Zg2@4@000000103=
R8L0hIEl0>6EO03QUG`3000002d0Y;c[00<000000?ooo`3oool0>`3oool00580oooo00<000000:O7
l02Wao007@2Wao001@00030000000;]iR@3UXHH000000240YlO`0`00000M0:S=l`050000002VIH@0
d8V40>VQOP0000006`2XcO<200000480YlSa00<0000004hQN01>8GP01000000207I1PP80TUN73@00
00020;ajR@H0cXZ80P0000020>6KQ08000000P3_Zh800`000000Y;c[0:Blj`040:Blj`8000001@2H
I987000000@0Zg2@202lO8d50<f8Q`@000000`3QUG`2000002/0Y;c[00<000000?ooo`3oool0>`3o
ool005<0oooo00<000000:O7l02Wao000P2Wao000`000000YlO`0:O7l00G0:O7l0050000<0000000
^gV90>FQQP000000802Wao001@000000Y;c[0:Bmj`2T_N/0000001`0Z<gc00L000000:IUQ03@RH@0
jJ5n0000002XcO<0ZLgc01P0Z<gc0P0000120:O8l@050000001>8GP0CR5h0000001>8GP00`1f@H84
000000d0VL?e1P0000020<j:R080hI^40P0000020?B^N@040000003_Zh80kj^200000080Y;c[0`00
00000`23E980V6BB09QTTP0400000080V6BB2@2[L9080;alS@L0cHR70P3QUG`2000000030>6EO03d
Xf@0m:=T00800000:@2T_>/00`000000oooo0?ooo`0k0?ooo`00E03oool2000001`0YlO`00D0000`
0000002kNHT0iJ660000000O0:O7l0030000002T_N/0Y;g[0080Y;g[00<000000:S=l`2XcO<06P2X
cO<01@000000YVF40=29Q03YXGh0000001X0Z<gc00<000000:O8l@2Wb?40@02Wb?40100000002`1Q
04hQN000000204hQN0<000005`2I`oD400000080hI^400@000000?B^N@3d[WT000000P3_Zh820000
00<0PeBB0`00000709QTTP@0Zg2@4@0000020<f8Q`@0hIEl0P0000030?BSI0030000002T_>/0Y;c[
02H0Y;c[00<000000?ooo`3oool0>`3oool005H0oooo0P00000J0:O7l0050000<0000000^gV90>FQ
QP0000007P2Wao000`000000Y;g[0:Bmj`040:Bmj`030000002XcO<0Z<gc01T0Z<gc00D000000:IU
Q03@RH@0jJ5n0000000H0:S=l`800000@P2Wb?401@0000002`1Q00/0H@000000CR5h008000007P2I
`oD010000000hI^40?B^N@0000020?B^N@8000000P23E9830000000308=DTP2HI980V6BB00D0V6BB
1P00000A0:S>m0D000000`3QUG`200000080m:=T00<000000:Blj`2T_>/09@2T_>/00`000000oooo
0?ooo`0k0?ooo`00F03oool2000001P0YlO`00D0000`0000002kNHT0iJ660000000M0:O7l0030000
002T_N/0Y;g[00H0Y;g[00<000000:S=l`2XcO<0602XcO<01@000000YVF40=29Q03YXGh0000001H0
Z<gc100000120:O8l@050000000;0640000004hQN00000008@2I`oD01`000000m:ii0?B^N@000000
m:ii00000023E9800P00000508=DTP80V6BB1000000L0:S>m0<000000P3dXf@00`000000m:=T0000
000W0:Blj`030000003oool0oooo03/0oooo001J0?ooo`8000005P2Wao001@00030000000;]iR@3U
XHH0000001/0YlO`0P0000040:Bmj`80Y;c[102T_N/00`000000Z<gc0:S=l`0G0:S=l`050000002V
IH@0d8V40>VQOP0000005@2XcO<00`000000ZVn?0<b<S`0200000440YlSa00D0000000/0H@000000
2`1Q0000000S09W3m@060000003d[WT0m:ii0000003l_5`000001P23E983000002<0Z<kd00H00000
0?BSI03dXf@000000>fO9`00000V0:Blj`030000003oool0oooo03/0oooo001L0?ooo`800000502W
ao001@1D8W@000000;]iR@3UXHH0000001P0YlO`0`00000=0:Bmj`8000005`2XcO<01@000000YVF4
0=29Q03YXGh0000001<0Z<gc0`000000102ZKhl0c8b?0000@00000110:O8l@80000000<02`1Q0000
002I`oD0902I`oD01@000000m:ii0000003l_5`0000000<0PeBB0`00000W0:S>m0030000003dXf@0
m:=T008000009P2T_>/00`000000oooo0?ooo`0k0?ooo`00GP3oool3000000H0YlO`00<000000:O7
l02Wao00202Wao0010000000YfR70;]iR@00000@0:O7l0030000002Wao00YlO`00<0YlO`0`00000B
0:Bmj`8000005@2XcO<01@000000YVF40=29Q03YXGh000000100Z<gc0`0000001P2T_N/000000000
002ZKhl0c8b?000002D0YlSa00@000000:O8l@3YXGl000006@2Wb?400`0002/000000000000W09W3
m@050000003l_5`0000000000023E9800P00000[0:S>m0050000003dXf@000000>fO9`000000902T
_>/00`000000oooo0?ooo`0l0?ooo`00H@3oool3000000h0YlO`00@000000;]iR@3>RhT00000502W
ao02000001H0Y;g[0P00000D0:S=l`050000002VIH@0d8V40>VQOP0000003P2XcO<2000000@0Y;g[
0P0000000`2ZKhl0c8b?0000000T0:O8l@050000H0000000^gZ90>VQO`0000006@2Wb?42000002T0
VL?e00@000000?blG00000000000;P2Xc_@00`000000kIlW0000000T0:Blj`030000003oool0oooo
03d0oooo001T0?ooo`@000002@2Wao001@00030000000;]iR@3UXHH000000140YlO`0`00000H0:Bm
j`030000002kO8d00000008000004@2XcO<010000000YVF40=29Q000000<0:S=l`<000001@2T_N/0
1P000000oooo0000002ZKhl0c8b?000002@0YlSa00H0001P0000002kNXT0jJ5o0000002Wao0H0:O8
l@800000:@2I`oD010000000o;aL00000000000_0:S>m0<000008`2T_>/00`000000oooo0?ooo`0m
0?ooo`00J03ooolD000000P0YlO`0`00000K0:Bmj`050000002kO8d0cH^=0000002T_N/00`00000=
0:S=l`0505HTMP000000_7N50=29Q00000002@2XcO<3000000P0Y;g[00H000000?ooo`000000ZVn?
0<b<S`00000T0:O8l@050000H0000000^gZ90>VQO`0000000P2Wb?400`2Wao00YlSa0:O8l@0D0:O8
l@030000002I`oD0VL?e02T0VL?e00<000000<bU5`000000<02Xc_@200000280Y;c[00<000000?oo
o`3oool0?P3oool006D0oooo1P0000040:]`T0P0^gf?1@3;RXd8000001d0Y;g[00D00000095HR@2k
O8d0cH^=000000040:Bmj`H000001`2XcO<01@1F97H000000;agQ@3@RH@0000000<0Z<gc1P00000;
0:Bmj`060000003oool000000:Y_S`3<S8l00000902Wb?401@00060000000;]jR@3YXGl0000001T0
YlSa00<0000009W3m@2I`oD04P2I`oD00`2<Ch80VL?e09W3m@0E09W3m@800000<@2Xc_@00`000000
Y;c[0:Blj`0L0:Blj`040000002T_>/0Y;c[00000440oooo001R0?ooo`<000000P2FH8l40:]`T0l0
00001@3;RXd30=^GR@<00000702T_N/010000000^gb=0<f;S@0000040:Bmj`030:Blj`2T_N/0Y;g[
00@0Y;g[1`000000101F97H000000;agQ@3@RH@4000000l0Y;g[00L000000:Bmj`000000oooo0000
002ZKhl0c8b?008000008`2Wb?401@00060000000;]jR@3YXGl0000001T0YlSa00<0000009W3m@2I
`oD04P2I`oD01@000000YV>30=:7O@3^Wg00000001<0VL?e00<000000:S>m02Xc_@0<02Xc_@20000
01l0Y;c[00<000000?ooo`3oool0@03oool005l0oooo0`00000309IPS`H00000102[L9080;]mS`<0
bhZ=100000000`3;RXd0fiN90=^GR@040=^GR@<000006@2T_N/010000000^gb=0<f;S@00000B0:Bm
j`0505HTMP000000_7N50=29Q0000000502T_N/7000002<0YlSa00D0001P0000002kNXT0jJ5o0000
000I0:O8l@030000002I`oD0VL?e0140VL?e00H0001P0000002VHh<0dXMm0>jOL000000D09W3m@03
0000002Xc_@0Z<kd0300Z<kd00<000000:Blj`2T_>/0702T_>/00`000000oooo0?ooo`110?ooo`00
G@3oool20000000307Y:S02FH8l0UV2?00<000000P2FH8l80:]`T0T0^gf?1P3;RXd4000000@0fiN9
0P3/YH02000001L0Y;g[00@000000;]lS@3=Rhd000004P2T_N/01@1F97H000000;agQ@3@RH@00000
01<0Y;g[00@000000:]aT@2[LI40Zg6A0`2kOY800`000000YlSa0:O8l@0Q0:O8l@050000H0000000
^gZ90>VQO`0000006@2Wb?400`000000VL?e09W3m@0A09W3m@060000H0000000YV>30=:7O@3^Wg00
0000502I`oD00`000000Z<kd0:S>m00`0:S>m0/000004`2T_>/00`000000oooo0?ooo`120?ooo`00
F`3oool200000080NTZ<0`00000509IPS`@0Zg2@4P0000020<^:S@<0fiN90`0000000`3KUhT0k:F0
0>bUP0020>bUP0030000002T_N/0Y;g[00h0Y;g[4P00000:0:Bmj`0505HTMP000000_7N50=29Q000
00004P2T_N/00`000000Zg6A0:]aT@020:]aT@<0^gjB00<000000:O8l@2Wb?408@2Wb?401@000600
00000;]jR@3YXGl0000001T0YlSa00<0000009W3m@2I`oD04@2I`oD01P00060000000:ISP`3BQgd0
kYm`000001@0VL?e00<000000:S>m02Xc_@0<02Xc_@00`000000^gjA0;]nT@050;]nT@<0c8Z<1000
000>0:Blj`030000003oool0oooo04<0oooo001I0?ooo`8000000P1jBX`20000000307Y:S02FH8l0
UV2?00<0UV2?1P00000B0:W=l`D000000`3KUhT3000000<0k:F000<000000:Bmj`2T_N/01P2T_N/7
000000D0[7:B2P2kOi830<Z;T0D000001@2T_N/01@000000Rdj10;agQ@3@RH@000000140Y;g[00<0
00000:]aT@2T_>/00`2[LI440;]nTP030000002Wb?40YlSa0200YlSa00D0001P0000002kNXT0jJ5o
0000000J0:O8l@030000002I`oD0VL?e0100VL?e00H0001P0000002VHh<0dXMm0>jOL000000C09W3
m@030000002Xc_@0Z<kd0340Z<kd00<000000;]nT@2kOY401@2kOY470<b:S0<000002P2T_>/00`00
0000oooo0?ooo`140?ooo`00E`3oool20000000404/VPP1jBX`00000000000<0NTZ<0P2FH8l30000
01d0ZLgc0`0000000`3KUhT0k:F00>bUP002000000030>bUP03k]6`000000080Y;g[1@00000209US
T@X0[7:B2P2kOi880<Z;T0<000000P2T_N/01@000000Rdj10;agQ@3@RH@000000100Y;g[2`000000
0`2kOY8000000:O8l@0P0:O8l@050000H0000000^gZ90>VQO`0000006`2Wb?4200000100VL?e00H0
001P0000002VHh<0dXMm0>jOL000000B09W3m@030000002Xc_@0Z<kd0100Z<kd00<04`1`0:S>m02X
c_@07@2Xc_@00`000000Z<kd0000000:000000D0c8Z<0P3OV8<3000000D0Y;c[0P0000170?ooo`00
EP3oool00`000000BbJ204/VPP02000000@0NTZ<0`00000S0:W=l`<000000P3/YH000`000000nkA/
0?^dK002000000L0VF>A1@2/LY8B000000H0bX^@0P3JV8d3000000040:IUQ03@RH@0jJ5n000000/0
Y;g[00<000000:Bmj`2T_N/00P0000070:]aT@@0^gjB0`00000P0:O8l@050000H0000000^gZ90>VQ
O`0000006`2Wb?43000000l0VL?e00H0001P0000002VHh<0dXMm0>jOL000000A09W3m@030000002X
c_@0Z<kd0180Z<kd00D000000:QXR03AR840Z<kd0000000K0:S>m0030000002kOY40^gjA00H0^gjA
0`3<RX`5000000030<b:S03OV8<0giR30080giR30P0000020:Blj`030000003oool0oooo04L0oooo
001E0?ooo`050000001;9X80BbJ20000001;9X800`1jBX`2000002T0ZLgc0P0000001@3/YH000000
0000003k]6`0000000D0VF>A1`0000050:abTPX0^gnB0`3:Ri05000000030<Z;T03JV8d0fYR=0080
fYR=00D000000:IUQ03@RH@0jJ5n0000000=0:Bmj`030000002[LI40Zg6A00L0Zg6A1`2kOY820000
01h0YlSa00D0001P0000002kNXT0jJ5o0000000J0:O8l@050000002T_>/0Y;c[0:Blj`0000003P2I
`oD01P00060000000:ISP`3BQgd0kYm`00000100VL?e00<000000:S>m02Xc_@04`2Xc_@01@000000
Z6R80=68P@3]X780000001X0Z<kd00<000000;]nT@2kOY401`2kOY480<b:S0<00000103OV8<20000
04X0oooo001E0?ooo`030000001;9X8000000080BbJ200<0NTZ<000000000000;@2YcO<200000003
0?^dK0000000nkA/00D000000P2IHi4:0:abTPX0^gnB203:Ri0300000080fYR=00@000000:IUQ03@
RH@0jJ5n0P00000;0:Bmj`030000002[LI40Zg6A00P0Zg6A2@2kOY800`000000YlSa0:O8l@0K0:O8
l@050000H0000000^gZ90>VQO`000000602Wb?42000000@0Y;c[0`00000<09W3m@060000H0000000
YV>30=:7O@3^Wg0000003P2I`oD2000001H0Z<kd00D00000091GQ`2lMhH0kJ1b0000000J0:S>m0L0
00000`2kOY490<b:S080giR30`000000103OV8<0ljM^0?>WKP0000190?ooo`00E03oool00`000000
BbJ20000000204/VPP800000<@2YcO<010000000nkA/00000000000609UST@D0[7:B4P0000060<Z;
T080fYR=0`0000001@2VIH@0d8V40>VQOP000000jjN5008000001@2T_N/F000000<0^gjB0P00000K
0:O8l@050000H0000000^gZ90>VQO`0000004P2Wb?4010000000YlSa0:O8l@2Wb?42000000H0Y;c[
00<000000;]lS@3WXH400P00000:09W3m@060000H0000000YV>30;adPP3^Wg0000003@2I`oD00`00
0000Z<kd0:S>m00F0:S>m0050000002@EhL0_7N60>fPLP0000006@2Xc_@00`000000YlSa0:O8l@05
0:O8l@T000000`3<RX`50=nHP`8000000P3cYfh00`000000oooo0?ooo`160?ooo`00E03oool20000
0080BbJ200<000000:W=l`2YcO<0<@2YcO<010000000nkA/0?^dK000000409UST@L000004P2Wb?45
000000030<Z;T03JV8d0fYR=0080fYR=00D000000:IUQ03@RH@0jJ5n000000030>^WQ@D000005P2T
_N/6000001X0YlSa00D0001P0000002kNXT0jJ5o0000000D0:O8l@800000202T_>/01@000000^gb=
0>NQP@000000Y;c[00800000202I`oD01P3h/DP000000:ISP`2lM880kYm`000000<0VL?e00<00000
09W3m@2I`oD01@2I`oD2000001T0Z<kd00D00000091GQ`2lMhH0kJ1b0000000I0:S>m0030000002W
b?40YlSa00h0YlSa1@0000050=nHP`80000000<0ljM^0000003oool0AP3oool005<0oooo00D00000
0000I0000000BbJ20000000e0:W=l`030000003k]6`0000000@00000702Wb?4=000000<0jjN50P00
000N0:Bmj`800000602Wb?401@00060000000;]jR@3YXGl000000180YlSa0P00000:0:Blj`040000
002kO8d0ij61000000<0Y;c[0`00000509W3m@060?RaB0000000YV>30;adPP3^Wg000000202I`oD3
000001/0Z<kd00D00000091GQ`2lMhH0kJ1b0000000H0:S>m0030000002Wb?40YlSa01@0YlSa0`00
00020=nHP`80ljM^00<000000?>WKP000000AP3oool005<0oooo0P0000000`1;9X8000000:W=l`0f
0:W=l`<000006`2Wb?4400000080TUN71P2YJh/40;alS@L000007`2T_N/3000001D0YlSa00D0001P
0000002kNXT0jJ5o0000000@0:O8l@800000302T_>/010000000^gb=0>NQP@0000060:Blj`L00000
00<0YV>30;adPP3^Wg002@0000000`2T_>/000000:S>m00K0:S>m0050000002@EhL0_7N60>fPLP00
00005`2Xc_@00`000000YlSa0:O8l@0H0:O8l@8000000`3cYfh2000004H0oooo001C0?ooo`<00000
>@2YcO<2000001T0YlSa0P0000000`1c?Gl0TUN7099GQ`03099GQ`H0ZF^;1P2lO8d40<f;S@<00000
802T_N/300000180YlSa00D0001P0000002kNXT0jJ5o0000000=0:O8l@<000003P2T_>/010000000
^gb=0>NQP@00000;0:Blj`060?RaB0000000YV>30;adPP3^Wg0000002@2T_>/00`000000Z<kd0:S>
m00J0:S>m0050000002@EhL0_7N60>fPLP0000005@2Xc_@2000001d0YlSa0P0000020?>WKP800000
A@3oool005<0oooo00<000000000I0000000>@2YcO<2000001L0YlSa0P00000207<mOa@000000`3=
Rhd20=fKS08000008@2T_N/6000000`0YlSa00D0001P0000002kNXT0jJ5o000000080:O8l@D00000
4@2T_>/010000000ZVj>0<j;R`00000<0:Blj`050000002VHh<0_7B20>jOL00000002P2T_>/00`00
0000Z<kd0:S>m00I0:S>m0050000002@EhL0_7N60>fPLP0000004`2Xc_@200000240YlSa00@00000
0?>WKP3cYfh00000A@3oool005<0oooo0P00000k0:W=l`030000002Wb?40YlSa01<0YlSa0P000000
1@1257000000000000000000Lceo00D0TUN71P2YJh/60;alS@80cH^=0`0000040=fKS0030000002T
_N/0Y;g[02<0Y;g[2P0000020:O8l@l000005@2T_>/010000000ZVj>0<j;R`00000<0:Blj`050000
002VHh<0_7B20>jOL00000002P2T_>/00`000000Z<kd0:S>m00I0:S>m0050000002@EhL0_7N60>fP
LP0000004@2Xc_@2000002@0YlSa00<000000?>WKP000000A@3oool005<0oooo0P00000k0:W=l`03
0000002Wb?40YlSa0180YlSa00@00000048DL00000000000101c?Gl3099GQ``000000P2lO8d50<f;
S@8000000`3MVh`2000002D0Y;g[00@000000=VIT03IVI00jZZ;1P0000040:]bTPP0^gf@0`3<RH`3
00000180Y;c[00@000000:Y^SP3>Rh/00000302T_>/01@000000YV>30;adPP3^Wg00000000/0Y;c[
0P00000I0:S>m0050000002@EhL0_7N60>fPLP0000002`2Xc_@010000000Z<kd0:S>m02Xc_@20000
02L0YlSa00<000000?6W<P000000A03oool005<0oooo00<000000:W=l`2YcO<0>`2YcO<00`000000
YlSa0:O8l@0@0:O8l@040000001257000000048DL0<0Lceo1@00000<09W4m@D000000P3=Rhd20=fK
S0<000000P3_[HH2000002<0Y;g[1000000209UTTPP0Zg:B202kOI060<b9S0@000003P2T_>/01000
0000ZVj>0<j;R`00000<0:Blj`050000002<Ch80YV>30>jOL00000003@2T_>/2000001L0Z<kd00D0
0000091GQ`2lMhH0dHR10000000<0:S>m0<00000:P2Wb?42000004@0oooo001C0?ooo`030000002Y
cO<0ZLgc01d0ZLgc00<000000:W=l`2YcO<06`2YcO<00`000000YlSa0:O8l@0?0:O8l@0300000000
04X000000080@QA`0`00000F09W4m@@000000`3MVh`200000080kjf600<000000:Bmj`2T_N/07@2T
_N/3000000H0VFBB102[LY8A00000080c8V<0`3MUh@3000000X0Y;c[4@0000001P1N;G`000000:IS
P`3BQgd0kYm`000000h0Y;c[00<000000:S>m02Xc_@0502Xc_@01@000000T5N70;agQP3AR8400000
00@0Z<kd00<000000:S>m02Xc_@00`2Xc_@2000002d0YlSa0P0000140?ooo`00D`3oool00`000000
ZLgc0:W=l`0J0:W=l`040000002WJ8L0cX^9000001d0ZLgc00<000000:O8l@2Wb?403`2Wb?401@00
0000001:000000125700000001d0VLCe0`0000020>n]QP030000003_[HH0000001d0Y;g[0P000000
0`22Di80VFBB09UTTP0409UTTPH00000102[LY880;]mT0D0c8V<1@0000030=fGQ080000000<0Y;c[
0000000000001@0000050:acU0X0^gnB0P3;Rhl01P00060000000:ISP`3BQgd0kYm`000000l0Y;c[
0`00000C0:S>m00601<0L0000000T5N70;agQP2Xc_@000001P2Xc_@300000300YlSa0P0000130?oo
o`00D`3oool00`000000ZLgc0:W=l`0J0:W=l`040000002WJ8L0cX^9000001`0ZLgc00<000000:O8
l@2Wb?40402Wb?4200000003048DL0000000VLCe0200VLCe00H000000>n]QP3_[HH000000?g0M`00
000J0:Bmj`8000000`22Di8209UTTP@000000P2II9880:]bTPP0^gf@1`3<RH`30=fGQ0<000000P3`
YGD00`000000VfND09]WU00:0:acU0X0^gnB0P3;Rhl01@00060000000:ISP`3BQgd0kYm`00@00000
202T_>/010000000Y;c[0:Blj`2T_>/2000000040?ooo`000000000000000100Z<kd00H0fi1n0000
002@EhL0_7N60>fPLP0000020:S>m0@00000<`2Wb?42000004<0oooo001C0?ooo`030000002YcO<0
ZLgc01X0ZLgc00@000000:MXQ`3>RhT00000702YcO<00`000000YlSa0:O8l@0@0:O8l@0300000000
04X0000002<0VLCe00H000000>n]QP3m`7L000000?g0M`00000G0:Bmj`8000001022Di83000000H0
VFBB102[LY8A00000080c8V<1P3MUh@2000000030?2UM@000000VfND00D0[7>D4@0000001`000600
00000:ISP`3BQgd0kYm`0000003;Rhl00P3LV8T3000000P0Y;c[00<000000?ooo`3oool0103oool5
000000`0Z<kd00@00000091GQ`2lMhH0kJ1b0`00000g0:O8l@800000@`3oool005<0oooo00<00000
0:W=l`2YcO<06@2YcO<01@000000S5230;]iR@3UXHH0000001X0ZLgc00<000000:W=l`0000004P2W
b?42000002D0VLCe00<000000?g0M`3m`7L00P00000F0:Bmj`030000001P>hd0PU>B0080PU>B0P00
00000`22Di80VFBB09UTTP0409UTTPH000004@2Xc_@5000000<0gIN40P3`YGD8000000D0[7>D2P2k
Oi820<^;S`070000H0000000YV>30=:7O@3^Wg0000000<^;S`050=bHR@800000102T_>/2000000`0
oooo3@000000102@EhL0_7N60>fPLP00000j0:O8l@030000003oool0oooo0440oooo001C0?ooo`03
0000002YcO<0ZLgc01T0ZLgc00D0000008a@P`2kNHT0iJ660000000K0:W=l`030000002Wb?40YlSa
0100YlSa0P00000W09W4m@030000003m`7L0oL1g00800000502T_N/010000000H3^=060kS@22Di82
000000@0PU>B0P2II983000001`0Z<kd0`000000103MUh@0l:Ee0?2UM@3`YGD2000000T0[7>D2P2k
Oi820<^;S`050000H0000000YV>30=:7O@3^Wg00100000050=bHR@80000000<0Y;c[0000003oool0
3@3oool200000003040VR@000000YlSa00L0YlSa00D00000091GQ`2lMhH0kJ1b0000000j0:O8l@03
0000003oool0oooo0440oooo001D0?ooo`030000002YcO<0ZLgc01P0ZLgc00D0000008a@P`2kNHT0
iJ660000000J0:W=l`030000002Wb?40YlSa00/0YlSa00<0YlO`0:O8l@2Wb?400`2Wb?42000002L0
VLCe00<000000?g0M`3m`7L00P00000C0:Bmj`030000001P>hd0H3^=008000001@22Di8300000280
Z<kd0`0000020?2UM@800000102/Li@@000000070000H0000000YV>30=:7O@3^Wg0000000<^;S`02
0=bHR@<000000P3LV8T20>nXN`030000003oool0oooo00d0oooo0`0000090:O8l@050000002@EhL0
_7N60>fPLP000000>P2Wb?400`000000oooo0?ooo`110?ooo`00E03oool2000001T0ZLgc00D00000
08a@P`2kNHT0iJ660000000H0:W=l`8000003`2Wb?400`2Wao00YlSa0:O8l@020:O8l@030000002I
a?D0VLCe02L0VLCe00<000000?g0M`0000004`2T_N/01@000000H3^=000000000000H3^=00<0PU>B
0`00000X0:S>m0040000003`YGD000000?Z^CP@00000402Wb?401`00060000000:ISP`3BQgd0kYm`
0000003;Rhl01@3LV8T2000000<0kjQk00<000000?ooo`3oool0303oool3000000T0YlSa00D00000
091GQ`2lMhH0kJ1b0000000j0:O8l@030000003oool0oooo0440oooo001F0?ooo`030000002YcO<0
ZLgc01H0ZLgc00D0000008a@P`2kNHT0iJ660000000G0:W=l`030000002Wb?40YlSa0100YlSa00D0
YlO`0:O8l@2Wb?40YlSa0000000Z09W4m@8000004`2T_N/2000000<0H3^=00<0PU>B000000000000
;02Xc_@010000000nZi>00000000000C0:O8l@050000H0000000YV>30=:7O@3^Wg00100000050=bH
R@8000000P3_Z7/00`000000oooo0?ooo`0;0?ooo`8000002P2Wb?401@000000T5N70;agQP3]X780
000003X0YlSa00<000000?ooo`3oool0@@3oool005L0oooo00<000000:W=l`2YcO<05@2YcO<01@00
0000S5230;]iR@3UXHH0000001H0ZLgc00<000000:O8l@2Wb?404P2Wb?40102Wao00YlSa0:O8l@00
000C09W4m@050000002VIH@0_7N509W4m@0000004P2Ia?D00`000000000>0:Bmj`0A0:Bmj`800000
0`1P>hd2000002l0Z<kd0`00000C0:O8l@0600002`000000YV>30;adPP3^Wg0000000`2Wb?430000
0080g9R90P3_Z7/010000000kjQk0>nXN`00000<0?ooo`8000002P2Wb?401@000000T5N70;agQP3]
X780000001<0YlSa00@000000:O8l@2Wb?4000008`2Wb?400`000000oooo0?ooo`110?ooo`00F03o
ool2000001D0ZLgc00D000000:MXQ`2kNHT0iJ660000000D0:W=l`8000005P2Wb?4010000000YlSa
0:O8l@00000B09W4m@050000002VIH@0_7N50>VQOP0000004`2Ia?D00`000000Y;g[0:Bmj`0?0:Bm
j`040000000U4H000000060kS@800000<P2Xc_@300000180YlSa00H0n;580000002VHh<0_7B20>jO
L00000060:O8l@8000000`3_Z7/00`000000kjQk0000000<0?ooo`8000002P2Wb?401@000000T5N7
0;agQP3AR840000001<0YlSa00@000000:U]S@2kNh/000008`2Wb?400`000000oooo0?ooo`110?oo
o`00FP3oool2000001<0ZLgc00@000000:MXQ`2kNHT000004`2YcO<2000001L0YlSa00D0001:0000
002kO8d0i:680000000B09W4m@050000002VIH@0_7N50>VQOP0000004`2Ia?D00`000000Y;g[0:Bm
j`040:Bmj`030000002T_N/0Y;g[00L0Y;g[00D0000002DAP0000000H3^=0000000e0:S>m0800000
4P2Wb?401P3h/DP000000:ISP`2lM880kYm`000000P0YlSa0P0000020>nXN`030000003k/e@00000
00/0oooo00<000000:O8l@2Wb?402@2Wb?401@000000T5N70;agQP3AR840000001<0YlSa00@00000
0:U]S@2kNh/000008P2Wb?400`000000oooo0?ooo`120?ooo`00G03oool200000140ZLgc00@00000
0;]iR@3>RhT000004@2YcO<2000001L0YlSa00L0YlO`0:O8l@0004X000000;]lS@3TXHP000000180
VLCe00D000000:IUQ02lMhD0jJ5n0000000C09W4m@030000002T_N/0Y;g[00h0Y;g[0P0000000`0U
4H0000000:S>m00f0:S>m0030000002Wb?40YlSa0100YlSa00H0n;580000002VHh<0_7B20>jOL000
000:0:O8l@060000003_Z7/0kjQk0000003k/e@000002P3oool00`000000YlSa0:O8l@090:O8l@05
0000002@EhL0_7N60=68P@0000004`2Wb?4010000000ZFf=0;]kR`00000Q0:O8l@030000003oool0
oooo04<0oooo001N0?ooo`<000001P2YcO<00`000000ZLgc0:W=l`040:W=l`0505@RM0000000^gV9
0>FQQP0000003P2YcO<3000001P0YlSa00L0YlO`0:O8l@2Wb?40001:0000002kO8d0i:6800800000
4@2Ia?D01@000000YVF40;agQ@3YXGh0000001<0VLCe00<000000:Bmj`2T_N/03@2T_N/200000080
9A6000<000000:S>m02Xc_@0=@2Xc_@00`000000YlSa0:O8l@0@0:O8l@T00000202Wb?4300000080
nk=D00<000000?ooo`3oool01`3oool00`000000YlSa0:O8l@090:O8l@050000002@EhL0_7N60=68
P@0000004`2Wb?4010000000ZFf=0;]kR`00000Q0:O8l@030000003oool0oooo04<0oooo001Q0?oo
o`<000002P2YcO<01@000000S5230;]iR@3UXHH0000000/0ZLgc0`00000N0:O8l@060000BP000000
^gb=0>BQR0000000YlSa0P00000?09W4m@050000002VIH@0_7N50>VQOP0000004P2Ia?D2000000l0
Y;g[0P0000000`0U4H0000000:S>m00g0:S>m0030000002Wb?40YlSa00d0YlSa3P0000080:O8l@80
000000<0nk=D0?ooo`3oool02@3oool00`000000YlSa0:O8l@080:O8l@050000002@EhL0_7N60=68
P@0000004`2Wb?4010000000ZFf=0;]kR`00000O0:O8l@800000AP3oool006@0oooo1@0000050:W=
l`050000002<D8<0^gV90>FQQP0000001@2YcO<600000240YlSa00D0001:0000002kO8d0i:680000
00030:O8l@8000003@2Ia?D01@000000YVF40;agQ@3YXGh000000140VLCe00<000000:Zoj02Z_nP0
0P2T_N/010000000ZVn?0<b<S`0000090:Bmj`030000D`000000000003T0Z<kd00<000000:O8l@2W
b?40302Wb?401@000000NdV9000000000000U5Z90080Z6R70P2kMX@20<f3OP80hI5d00<000000?6R
<0000000202Wb?42000000/0oooo00<000000:O8l@2Wb?40202Wb?401@000000T5N70;agQP3AR840
000001<0YlSa00D0:0ml0000002YKHd0>ab10000000M0:O8l@030000003oool0oooo04H0oooo001Y
0?ooo`H0000000<0S5230;]iR@3UXHH01P0000050?ooo`040000002Wb?40YlSa000001h0YlSa00@0
0000095HR@2kO8d000001P2Wb?42000000/0VLCe00D000000:IUQ02lMhD0jJ5n0000000?09W4m@80
00001@2T_N/010000000ZVn?0<b<S`0000090:Bmj`800000>P2Xc_@00`000000YlSa0:O8l@0;0:O8
l@040000001I<HH0000007]9R@X0000000<0lYiO0000002Wb?40202Wb?4010000000nk=D00000000
00090?ooo`030000002Wb?40YlSa00H0YlSa3000000?0:O8l@040000002YKHd0chZ7000001`0YlSa
00<000000?ooo`3oool0A`3oool006h0oooo00D0000008a@P`2kNHT0iJ660000000;0?ooo`030000
002Wb?40YlSa01h0YlSa00@000000:U/S03=Rhd00000202Wb?4300000080VLCe00<0000009W4m@2I
a?D00`2Ia?D01@000000YVF40;agQ@3YXGh0000000h0VLCe00<000000:Bmj`2T_N/01@2T_N/01000
0000ZVn?0<b<S`0000090:Bmj`8000006`2Xc_@010000000Z<kd0:S>m000000K0:S>m0030000002W
b?40YlSa00/0YlSa1000000:0:S@m@<000002@2Wb?400`000000oooo0?ooo`0:0?ooo`030000002W
b?40YlSa00D000000P2FGX`60:Y^S@@0^gb=1@00000:0:O8l@040000002YKHd0chZ7000001/0YlSa
00<000000?ooo`3oool0B03oool006h0oooo00D0000008a@P`2kNHT0iJ660000000<0?ooo`030000
002Wb?40YlSa01d0YlSa00@000000:U/S03=Rhd000002`2Wb?42000000H0VLCe00D000000:IUQ03@
RH@0jJ5n0000000<09W4m@800000202T_N/010000000ZVn?0<b<S`0000090:Bmj`030000D`000000
Z<kd01X0Z<kd00@000000;]jR@3YXGl000006`2Xc_@00`000000YlSa0:O8l@0:0:O8l@<000003P2X
d?D00`000000YlSa0:O8l@080:O8l@030000003oool0oooo00P0oooo1000000207i;R080UUj<3@00
00000`2kO8d0cH^<0<f;S0020<f;S0<000001`2Wb?4010000000ZFf=0<n:Q`00000I0:O8l@800000
B`3oool006h0oooo00D000000:MXQ`2kNHT0iJ660000000=0?ooo`030000002Wb?40YlSa01`0YlSa
00@000000:U/S03=Rhd000003@2Wb?43000000<0VLCe00D000000:IUQ03@RH@0jJ5n0000000909W4
m@<000002P2T_N/010000000ZVn?0<b<S`0000090:Bmj`030000002Xc_@0Z<kd01T0Z<kd00D0001P
0000002kNXT0jJ5o0000000J0:S>m0030000002Wb?40YlSa00`0YlSa00<000000:S@m@2Xd?D03@2X
d?D00`000000YlSa0:O8l@090:O8l@030000003oool0oooo00D0oooo0P000000101L<840OT^807i;
R01nBhP4000000<0UUj<1P2ZKXd40;]lS@D0000000<0cH^<0>2KQ`3PVhL00P0000050:O8l@040000
002YKHd0chZ7000001L0YlSa0P00001=0?ooo`00KP3oool01@000000YfR70;]iR@3UXHH0000000h0
oooo00<000000:O8l@2Wb?406`2Wb?4010000000ZFb<0<f;S@00000@0:O8l@@0000000@0YVF40=29
Q03YXGh000001P2Ia?D3000000d0Y;g[00@000000:Y_S`3<S8l000002@2T_N/00`000000Z<kd0:S>
m00I0:S>m0050000H0000000^gZ90>VQO`0000006P2Xc_@00`000000YlSa0:O8l@0<0:O8l@030000
002Xd?D0Z=3e00d0Z=3e00<000000:O8l@2Wb?402@2Wb?400`000000oooo0?ooo`040?ooo`050000
001L<840G32105``P@1nBhP00P0000000`1nBhP0UUj<09INS00409INS0H0ZVj=1@2kO8d40<f;S0<0
00000P3PVhL00`000000YlSa0:O8l@020:O8l@040000002YKHd0chZ7000001H0YlSa00<000000?oo
o`3oool0C@3oool006h0oooo00@000000:MXQ`2kNHT00000403oool2000001/0YlSa00@000000:U/
S03=Rhd000004P2Wb?401@0004@000000:IUQ03@RH@0jJ5n00L00000402T_N/010000000ZVn?0<b<
S`0000090:Bmj`030000002Xc_@0Z<kd01T0Z<kd00D0001P0000002kNXT0jJ5o0000000I0:S>m003
0000002Wb?40YlSa00d0YlSa00<000000:S@m@2Xd?D03@2Xd?D00`000000YlSa0:O8l@090:O8l@03
0000003oool0oooo00<0oooo00@0000005``P@1L<840G3210P00000307i;R0<0UUj<400000030<f;
S080h9^70P0000000`3d[WX000000:O8l@020:O8l@040000002YKHd0chZ7000001@0YlSa0P00001@
0?ooo`00KP3oool010000000YfR70;]iR@00000B0?ooo`8000006@2Wb?4010000000ZFb<0<f;S@00
000B0:O8l@060000A0000000YVF40=29Q03YXGh000000P2Wb?400`000000Y;g[0:Bmj`0A0:Bmj`04
0000002ZKhl0c8b?000000X0Y;g[00<000000:S>m02Xc_@0602Xc_@01@00060000000;]jR@3YXGl0
000001P0Z<kd00<000000:O8l@2Wb?403P2Wb?400`000000Z=3e0:S@m@0;0:S@m@800000302Wb?40
0`000000oooo0?ooo`020?ooo`030000000S1700G3210080000000<0G32107i;R01nBhP01@00000@
09W4m@<00000103PVhL00`000000m:ij000000020:O8l@040000002YKHd0chZ700000180YlSa0P00
001B0?ooo`00KP3oool010000000^gV90<j;R@00000D0?ooo`8000005`2Wb?4010000000ZFb<0<f;
S@00000B0:O8l@050000A0000000YVF40=29Q03YXGh00`00000D0:Bmj`040000002ZKhl0c8b?0000
00X0Y;g[00<000000:S>m02Xc_@0602Xc_@01@00060000000;]jR@3YXGl0000001L0Z<kd00<00000
0:O8l@2Wb?40402Wb?400`000000Z=3e0:S@m@090:S@m@030000002Wb?40YlSa00`0YlSa00H00000
0?ooo`3oool0oooo0000000S170200000080G3210`00000H09W4m@8000000P3PVhL02@3d[WX00000
0?B^NP000000YlSa0000002YKHd0chZ70000000?0:O8l@<00000E03oool006d0oooo00D0E29d0000
002kNHT0iJ660000000F0?ooo`8000005@2Wb?4010000000ZFb<0<f;S@00000B0:O8l@060000A000
0000YVF40=29Q03YXGh000005P2T_N/010000000^gf@0>>QR@00000:0:Bmj`030000002Xc_@0Z<kd
01P0Z<kd00D0001P0000002kNXT0jJ5o0000000E0:S>m0800000202Wb?4010000000YlSa0:O8l@00
00080:O8l@/000003`2Wb?4010000000oooo0?ooo`3oool20000000402<4L01L<8400000000001d0
VLCe0P0000020?B^NP070000003k^eL000000000002YKHd0chZ70000000<0:O8l@<00000E`3oool0
06d0oooo00D0E29d0000002kNHT0iJ660000000H0?ooo`<000004P2Wb?4010000000ZFb<0<f;S@00
000B0:O8l@060000A0000000YVF40=29Q03YXGh000005P2T_N/010000000^gf@0>>QR@00000;0:Bm
j`030000002Xc_@0Z<kd01L0Z<kd00D0001P0000002kNXT0jJ5o0000000C0:S>m08000002P2Wb?40
10000000^gb=0>NQP@00000R0:O8l@030000003oool0oooo008000000P0S17000`000000VLCe09W4
m@0O09W4m@80000000L0m:ij0000003k^eL000000:U]S@3?RXL0000000T0YlSa0`00001J0?ooo`00
K@3oool01@1D8W@000000;]iR@3UXHH0000001/0oooo0`00000?0:O8l@040000002YK8`0cH^=0000
0100YlSa0P0000001P0004@000000:IUQ03@RH@0jJ5n000001H0Y;g[00@000000;]mT03SXHT00000
302T_N/00`000000Z<kd0:S>m00F0:S>m0050000H0000000^gZ90>VQO`0000004P2Xc_@00`000000
YlSa0:O8l@090:O8l@050140K`000000^gb=0>NQP@0000008@2Wb?4010000000oooo0?ooo`3oool2
0000000302<4L0000000VLCe02<0VLCe0P0000001P3k^eL000000000002kNh/0jjT[000000<0YlSa
1@00001M0?ooo`00K@3oool01@1D8W@000000;]iR@3UXHH0000001h0oooo0`00000<0:O8l@040000
002YK8`0cH^=000000/0YlSa1@0000020:Bmj`050000002VIH@0_7N50=29Q00000005`2T_N/01000
0000^gf@0>>QR@00000=0:Bmj`8000005P2Xc_@01@00060000000;]jR@3YXGl000000100Z<kd0P00
000<0:O8l@050140K`000000^gb=0>NQP@0000008@2Wb?401`000000oooo0?ooo`3oool0000002<4
L00000009P2Ia?D4000000030:U]S@3?RXL0000000<00000HP3oool006d0oooo00D0E29d0000002k
NHT0iJ660000000Q0?ooo`D000001`2Wb?4010000000^gb=0>BQR00000050:O8l@H000001@3oool0
1`000000Y;g[0000002VIH@0_7N50>VQOP0000004`2T_N/;000000`0Y;g[0P00000D0:S>m0050000
H0000000^gZ90>VQO`0000003P2Xc_@2000000h0YlSa00D04@1_0000002kO8d0ij610000000Q0:O8
l@040000003oool0oooo0?ooo`8000009`2Ia?D01`000000nk]G000000000000ZFf=0<n:Q`000000
I@3oool006D0oooo4000000S0?ooo`H0000000@0001:0000002kO8d0i:681P00000<0?ooo`800000
00@0YVF40;agQ@3YXGh00000302T_N/7000000D0[7FE1P2kPI@9000000D0Y;g[00<000000:S>m02X
c_@04@2Xc_@01@00060000000;]jR@3YXGl0000000`0Z<kd0P00000@0:O8l@050140K`000000^gb=
0>NQP@000000802Wb?400`000000oooo0?ooo`020?ooo`030000A0000000VLCe02L0VLCe0`000000
0`2YKHd0chZ70000001U0?ooo`00H03oool500000080U5Z81P2ZKHd50;]nT0<0bhbA0`00000V0?oo
o`050000BP000000^gb=0>BQR00000004P3oool01@000000YVF40;agQ@3YXGh0000000L0Y;g[1@00
000209aXU0X0[7FE2@2kPI@60<V<T`D0000000<0Y;g[0000000000000P00000?0:S>m0050000H000
0000^gZ90>VQO`000000202Xc_@400000180YlSa00D04@1_0000002ZKXh0cX^;0000000O0:O8l@03
0000003oool0oooo00<0oooo00<0000009W4m@2Ia?D05@2Ia?D00`2I`oD0VLCe09W4m@0@09W4m@80
000000<0ZFf=0000000000003P00001G0?ooo`00G@3oool300000080M3eo0`2DFXP;00000080^gj@
1P3;S94200000200oooo4000000;0?ooo`050000002VIH@0_7N50>VQOP000000102T_N/3000000L0
W6RD1@2/MID;000000<0^h6D2@39S9<20=VHS`<000000P2T_N/7000000P0Z<kd00@0001P0000002k
NXT0jJ5o2@00000G0:O8l@040000002ZKXh0cX^;000001h0YlSa00<000000?ooo`3oool0103oool0
0`000000VLCe09W4m@0@09W4m@0501<0L0000000Z6R80=68P@0000004`2Ia?D3000000@0[7BD1`2k
OY450<b9S0@00000D`3oool005`0oooo00@0000003d?K01d?Gl0M3eo1@00000209AJR0D0ZVf=102k
OY0600000080bhbA0P3JVi42000001P0oooo1P0000040:acT`L0^gnB1@3:Ri05000000H0oooo00@0
00000:IUQ02lMhD0jJ5n1@0000000`25EY80W6RD09aXU00509aXU0L000001@2/MID60;^1U0T00000
0`39S9<50=VHS`<000001P2T_N/8000000050000H0000000^gZ90>VQO`0000007`2Wb?4010000000
ZVj>0<j;R`00000M0:O8l@030000003oool0oooo00D0oooo00<0000009W4m@2Ia?D0402Ia?D01@0C
070000000:QXR03AR840000001<0VLCe00<000000:adU02/M9@0102/M9@80;]nT@H0c8V<0P3NUX83
00000500oooo001K0?ooo`030000000m3f`00000008000000P1d?Gl309AJR0/000000P2kOY040<^<
T@<000000`3JVi42000001<0oooo0`00000209YUT`@0[7>C400000020<Z;T0<0fIN<0`0000030?oo
o`040000002VIH@0_7N50>VQOP8000001025EY8209aXU0D000000P2LJ9@:0:aeU@T0^h6D1P39S9<5
000000D0fIR?0P0000030:Bmj`800000203oool01@00060000000;]jR@3YXGl0000001l0YlSa00@0
00000:Y^SP3>Rh/000006`2Wb?42000000P0oooo00<0000009W4m@2Ia?D0402Ia?D01`0C07000000
0:QXR03AR840000009W4m@2I`oD04@2Ia?D010000000[7BD0:adU02/M9@?00000080c8V<1@3NUX82
000004h0oooo001K0?ooo`80000000@0?@m/07@mO`1d?Gl0M3eo1000000;09S4mPH0000000<0bhbA
0=ZKT@3JVi400`0000020>Z/SP8000003P3oool3000000<0VVFC1P0000040:acT`L0^gnB1@3:Ri06
00000080fIN<10000000102VIH@0_7N50>VQOP00000408EFTP<000001`2LJ9@50:aeU@/000000`2k
PI@90<V<T`80fIR?0`0000020=VHS`80jjN60`00000:0?ooo`040000H0000000^gZ90>VQO`<00000
00<0YlSa0000002Wb?406P2Wb?4010000000ZVj>0<j;R`00000I0:O8l@8000002P3oool00`000000
VLCe09W4m@0@09W4m@0701<0L0000000Z6R80=68P@000000VLCe09W3m@0A09W4m@@000000`2/M9@8
0;]nT@@0c8V<1P000000103NUX80lZAZ0?:TJP00001=0?ooo`00FP3oool200000080?@m/00<0M3eo
0000000000005@2Ha?H3000000<0fY^A0P0000020>Z/SP030000003oool0oooo00P0oooo0`000000
0`21Di40VVFC09YUT`0300000080VVFC202/Li<80;]oTPL0bX^@0`3IUh`300000080jjF200H00000
0:IUQ03@RH@0jJ5n00000025EY830000000308EFTP2LJ9@0W6RD00D0W6RD1`00000;0:O8l@T00000
0`39S9<50=VHS`800000103[YhH2000000T0oooo00D0001P0000002kNXT0jJ5o000000020?ooo`03
0000002Wb?40YlSa01X0YlSa00@000000:Y^SP3>Rh/00000602Wb?400`000000oooo0?ooo`0;0?oo
o`030000002Ia?D0VLCe00l0VLCe00D04`1`0000002XJ8P0dHR10000000B09W4m@030000002/M9@0
[7BD0080[7BD400000000`3<RH`0gYJ20=jFPP020=jFPP<0000000<0lZAZ0000003oool0B`3oool0
05X0oooo00<0000j0000000m3f`00P00000J09S4mP<000000P3Z[8h3000000L0oooo0`000003085C
T@<000001@2JII<40:acTa4000000P3:Ri060=VGS0<0000000<0YVF40=29Q03YXGh00P00000408EF
TP80W6RD1@00000K0:O8l@D000001@3IV8l2000000@0jjN600<000000?ooo`3oool01P3oool01@00
060000000;]jR@3YXGl0000000<0oooo00<000000:O8l@2Wb?406@2Wb?4010000000ZVj>0<j;R`00
000F0:O8l@8000003`3oool2000000l0VLCe00D04`1`0000002XJ8P0dHR10000000A09W4m@H00000
402WcoD4000000<0gYJ200@0lZAZ0000003bY6X00000B`3oool005T0oooo0P0000000`0m3f`00000
09S4mP0N09S4mP040000003Z[8h0jZb>0>Z/SP8000001@3oool00`000000FSF:085CT@02085CT@80
000000<0PE>A09YUT`2JII<00`2JII<600000140Z<kd1@0000030=VGS0070>^UPP0004@000000:IU
Q03@RH@0jJ5n0000000408EFTP<000009@2Wb?4300000080fIR?0P3[YhH200000080jjN600<00000
0?ooo`3oool01P3oool01@00060000000;]jR@3YXGl0000000@0oooo00<000000:O8l@2Wb?40602W
b?4010000000ZVj>0<j;R`00000D0:O8l@8000004`3oool00`000000VLCe09W4m@0<09W4m@0601<0
L0000000Z6R80=68P@3]X78000003`2Ia?D00`000000Yloe0:O?m@0H0:O?m@<000000P3bY6X20000
04/0oooo001I0?ooo`030000000003X000000240V<Cf00H000000>Z/SP3Z[8h000000?ZoQ@000003
0?ooo`040000001J=HX0FSF:085CT@8000000`21Di4209YUT`<00000702Xc_@3000000060>^UPP00
04@000000:IUQ03@RH@0jJ5n1@00000[0:O8l@800000103[YhH2000000030?bgK@000000oooo00H0
oooo00D0001P0000002kNXT0jJ5o000000050?ooo`800000602Wb?4010000000ZVj>0<j;R`00000A
0:O8l@<000005P3oool2000000`0VLCe00H04`1`0000002XJ8P0Q4j70>fPLP00000:09W4m@030000
002Ia?D0VLCe008000007P2WcoD2000000030?:TJP000000000004X0oooo001I0?ooo`030000>P00
0000V<Cf0280V<Cf00P000000>Z/SP3j_hD000000?c<I`000000oooo00000080FSF:0P000004085C
T@<000008P2Xc_@00`000000001400000004000000030?^cJ`000000YlSa02h0YlSa0P0000040>^W
QP030000003l]fd0000000H0oooo00D0001P0000002kNXT0chZ7000000070?ooo`<000005@2Wb?40
10000000ZVj>0<j;R`00000>0:O8l@<000006`3oool2000000L0VLCe0P0000001`2Ia?D04`1`0000
002@EhL0Z6R80>fPLP0000002`2Ia?D200000280Yloe0P0000000`3^X2T000000?ooo`180?ooo`00
F@3oool00`000000V<Cf09S4mP0S09S4mP80000000<0n[n50000003lc6L00P0000000`1J=HX00000
05XeRP02085CT@<00000902Xc_@3000000030:UZR@2kN8P0^gR80080c8F40`00000`0:O8l@800000
0P3[YhH00`000000o;M]000000060?ooo`050000H0000000^gZ90<n:Q`0000002P3oool2000001<0
YlSa00@000000:Y^SP3>Rh/000002`2Wb?4300000200oooo1000000609W4m@0600008@0C07000000
0;agQP3AR8400000202Ia?D3000002D0Yloe0`0000190?ooo`00F@3oool00`000000V<Cf09S4mP0U
09S4mP80000000@0o<aW0000001J=HX000000P1J=HX2000002D0Z<kd0P0000000`2DFXT000000000
0007000000030>nRLP000000YlSa0300YlSa0P000000103l]fd000000?bgK@0000050?ooo`050000
H0000000^gZ90<n:Q`000000303oool6000000d0YlSa00@000000:Y^SP3>Rh/000001P2Wb?450000
02L0oooo1@00000209W4m@0501<0L0000000Z6R80=68P@0000000`2Ia?D5000002T0Yloe0P000019
0?ooo`00F@3oool00`000000V<Cf09S4mP0V09S4mP80000000D0401d0000001J=HX0FSF:0000000V
0:S>m0060000001?9h4000000000002DFXT0ZFZ91@0000020=fCOP<00000<P2Wb?4010000000o;M]
0000000000050?ooo`050000H0000000^gZ90<n:Q`0000004P3oool>000000030:Y^SP3>Rh/00000
00H00000<@3oool4000000030:QXR03AR840000000@00000;@2WcoD2000004T0oooo001I0?ooo`03
0000002Ha?H0V<Cf0100V<Cf00D0000009S4mP2Ha?H0V<Cf0000000A09S4mP80000000@0401d0000
001J=HX000009`2Xc_@20000000407Q6Q`0000000000000000D0Z<od0`0000000`3j[UL000000:O8
l@0a0:O8l@040000003l]fd0o;M]000000D0oooo00D0001P0000002kNXT0chZ70000000O0?ooo`04
0000002ZKXh0cX^;000003P0oooo00D0000001<0L0000000Z6R80=68P@0200000340Yloe00<00000
0?ooo`3oool0A`3oool005T0oooo00<0000009S4mP2Ha?H0402Ha?H01@000000YfR70<j;R@3UXHH0
00000180V<Cf0P0000000`1J=HX000000:S>m00V0:S>m080000000<0CbN10000002Xco@02P2Xco@2
000003<0YlSa00@000000?bgK@0000000000103oool01@00060000000;]jR@3?RXL0000001l0oooo
00@000000:Y^SP3>Rh/00000=`3oool01`000000001j01<0L0000000Z6R80=68P@000000<`2WcoD0
0`000000oooo0?ooo`160?ooo`00FP3oool00`000000V<Cf09S4mP0?09S4mP050000002WJ8L0cX^9
0>FQQP0000004P2Ha?H00`000000401d0000000Y0:S>m08000003@2Xco@00`000000YlSa0:O8l@0b
0:O8l@<00000103oool01@00060000000;]jR@3?RXL0000001l0oooo3`00000/0?ooo`0700000000
07X04`1`0000002XJ8P0dHR10000000c0:O?m@030000003oool0oooo04H0oooo001K0?ooo`030000
002Ha?H0V<Cf00h0V<Cf00D000000:MXQ`3>RhT0iJ660000000B09S4mP030000000@07@0000002T0
Z<kd00<000000:S?m02Xco@03@2Xco@00`000000YlSa0:O8l@0b0:O8lA4000004`3oool6000000<0
[7FE202kOi<40<^;S`D000009P3oool020000000001j0000NP0C070000000:QXR03AR8400000<P2W
coD00`000000oooo0?ooo`170?ooo`00G03oool00`000000V<Cf09S4mP0=09S4mP050000002WJ8L0
cX^90>FQQP0000004P2Ha?H2000002X0Z<kd00<000000:S?m02Xco@0302Xco@00`000000YlSa0:O8
l@0`0:O8l@D000000P2GGhd50:]_S`H0^gj@0P3<S903000000d0oooo0`00000209aYUPP0[7FE1`2k
Oi<60<^;S`<0fiN70`00000S0?ooo`080000000007X0000001<0L0000000Z6R80=68P@00000b0:O?
m@030000003oool0oooo04L0oooo001M0?ooo`8000003@2Ha?H01@000000YfR70<j;R@3UXHH00000
0180V<Cf00<000000:S>m02Xc_@0:@2Xc_@00`000000Z<od0:S?m00;0:S?m0800000;P2Wb?440000
0080ODV80`2GGhd;00000080^gj@1@3<S902000000P0oooo0`00000509aYUP@0[7FE400000020<^;
S`D0fiN70P00000R0?ooo`080000000007X04`1`0000002XJ8P0dHR10>fPLP00000a0:O?m@030000
003oool0oooo04L0oooo001O0?ooo`030000002Ha?H0V<Cf00T0V<Cf00D0000008a@P`2WJ8L0cX^9
0000000B09S4mP8000007@2Xc_@00`000000Z<kd0:S>m00<0:S>m0030000002Xco@0Z<od00T0Z<od
00<000000:O8l@2Wb?40;@2Wb?400`000000ERUm07e9R00207e9R0D000000P2GGhd50:]_S`@0^gj@
1@0000020<b<T080g9^=0P0000040?ooo`80000000<0QeZF09aYUP2LJIH00`2LJIH6000000@0[7FE
1`2kOi<50<^;S`@000000`3KUhL20>nUN0030000003oool0oooo01l0oooo0P0000001P0C07000000
0:QXR024CXL0kJ1b000001<0Yloe00D0000009ENS@2kNh/0jj1h0000000H0:O?m@030000003oool0
oooo04P0oooo001P0?ooo`8000002@2Ha?H01@000000YfR70<j;R@2RHhL000000100V<Cf1000000I
0:S>m0050000002YK8`0^gb=0>BQR00000003`2Xc_@<000002h0YlSa00<0000005HYO@0000000`00
000207e9R080Uen=300000000`2kOY00c8b@0<b<T0020<b<T0<000000`3LVhd4000000<0QeZF0P2L
JIH300000080W6VF102/MID@00000080bh^?0P3KUhL3000000<0kjEh00<000000?ooo`3oool07P3o
ool20000000601<0L0000000Z6R808A>Q`3]X78000004`2WcoD01@000000UEj=0;]kR`3[X7P00000
01P0Yloe00<000000?ooo`3oool0B03oool00680oooo0`00000609S4mP050000002WJ8L0cX^90>FQ
QP0000003`2Ha?H010000000oooo0?ooo`00000J0:S>m0050000002YK8`0^gb=0>BQR00000006@2X
c_@00`000000YlSa0:O8l@0B0:O8l@040000002Wb?40YlSa000001H0YlSa00@0000005HYO@000000
ERUm0P1mBHP5000000`0V<Cf1@0000000`3<S900g9^=0=bKS@0300000080kjf600@0000008MJUP27
FYH0QeZF0`00000309aYUPH00000402Wco@500000080fiN70P0000020>nUN0030000003oool0oooo
01d0oooo00P000000:O?m@0C070000000:QXR024CXL0kJ1b000001<0Yloe00D0000009ENS@2YKHd0
>ab10000000G0:O?m@030000003oool0oooo04T0oooo001U0?ooo`800000102Ha?H01@000000YfR7
0<j;R@3UXHH0000000D0V<Cf00<0000009S4mP2Ha?H0102Ha?H3000000<0oooo00<000000:S>m02X
c_@0602Xc_@010000000ZFb<0;]lS@00000J0:S>m0030000002Wb?40YlSa0180YlSa00@000000:Y_
S`3<S8l000005@2Wb?40100000003`1T0000001F:Gd3000001H0V<Cf0`0000030=bKS@80000000D0
kjf6000000000000000008MJUP0209aYUP<000006`2Wco@3000000040>nUN00000000000000001l0
oooo00P000000:O?m@0C070000000:QXR024CXL0kJ1b000001<0Yloe00D0:0ml0000002YKHd0K42:
0000000F0:O?m@030000003oool0oooo04X0oooo001W0?ooo`D0000000@0YfR70<j;R@3UXHH00000
202Ha?H4000000H0oooo00<000000:S>m02Xc_@0602Xc_@010000000ZFb<0<f;S@00000I0:S>m003
0000002Wb?40YlSa01<0YlSa00@000000:Y_S`3<S8l000005@2Wb?420000000305HYO@000000V<Cf
01/0V<Cf0`0000020>n]QP040000003n_g40000008MJUP<000008@2Wco@2000000030>nUN0000000
000001h0oooo00P000000:O?m@0C070000000:QXR024CXL0kJ1b000001<0Yloe00D0:0ml0000002Y
KHd0chZ70000000E0:O?m@030000003oool0oooo04/0oooo001[0?ooo`040000002WJ8L0cX^90>FQ
QPT000002`3oool00`000000Z<kd0:S>m00G0:S>m0040000002YK8`0cH^=000001P0Z<kd00<00000
0:O8l@2Wb?40502Wb?4010000000ZVn?0<b<S`00000D0:O8l@80000000<03`1T0000002Ha?H07`2H
a?H2000000040>n]QP000000o[ma000002H0Ylod00@000000?V^C@00000000007@3oool020000000
Yloe01<0L0000000Z6R808A>Q`3]X78000004`2WcoD01@0X3g`000000:U]S@3?RXL0000001<0Yloe
0P00001>0?ooo`00J`3oool01@000000YfR70<j;R@3UXHH0000001<0oooo0P0000000`2Xc_@00000
0:S>m00E0:S>m0040000002YK8`0cH^=000001H0Z<kd0P00000G0:O8l@040000002ZKhl0c8b?0000
01@0YlSa0`00000S09S4mP80000000<0o[ma0000002Wco@09P2Wco@00`000000nJi=0000000N0?oo
o`070000000C070000000:QXR024CXL0kJ1b0000000C0:O?m@0502P?O0000000ZFf=0<n:Q`000000
4@2WcoD200000500oooo001[0?ooo`050000002WJ8L0cX^90>FQQP0000005@3oool00`000000Z<kd
0:S>m00E0:S>m0040000002YK8`0cH^=000001D0Z<kd00<000000:O8l@2Wb?405`2Wb?4010000000
ZVn?0<b<S`00000D0:O8l@8000009@2Ha?H3000002P0Ylod00<000000?V^C@0000007P3oool01P0C
07000000091GQ`2XJ8P0kJ1b000001<0Yloe00D0:0ml0000002YKHd0chZ70000000?0:O?m@800000
DP3oool006/0oooo00D000000:MXQ`3>RhT0iJ660000000F0?ooo`030000002Xc_@0Z<kd01@0Z<kd
00@000000:U/S03=Rhd00000502Xc_@00`000000YlSa0:O8l@0H0:O8l@040000002ZKhl0c8b?0000
01@0YlSa00<0000009S4mP2Ha?H0902Ha?H00`000000o[ma0000000X0:O?m0030000003i[Td00000
01h0oooo00H0000Q01<0L0000000Z6R80=68P@00000C0:O?m@0502P?O0000000ZFf=0<n:Q`000000
2@2WcoD010000000Yloe0:O?m@2WcoD2000005@0oooo001[0?ooo`050000002WJ8L0cX^90>FQQP00
00005`3oool2000001@0Z<kd00@000000:U/S03=Rhd000003P2Xc_@010000000Z<kd0:S>m02Xc_@2
000001/0YlSa00@000000:Y_S`3<S8l00000502Wb?400`000000V<Cf09S4mP0U09S4mP800000:@2W
co@2000001l0oooo00D04`1`0000002XJ8P0dHR10000000C0:O?m@0502P?O0000000ZFf=0<n:Q`00
00002`2WcoD2000005H0oooo001[0?ooo`050000002WJ8L0cX^90>FQQP0000006@3oool200000180
Z<kd00@000000:U/S03=Rhd000003`2Xc_@3000001d0YlSa00@000000:Y_S`3<S8l00000502Wb?40
0`000000V<Cf09S4mP0?09S4mP030000H02Ha?H0V<Cf01@0V<Cf00<000000:O?m02Wco@0:02Wco@0
0`000000oooo0?ooo`0M0?ooo`0601<0L0000000Z6R80=68P@3]X78000004P2WcoD01@0X3g`00000
09ENS@2kNh/0000000T0Yloe0P00001H0?ooo`00JP3oool01@000000S5230:MXQ`3>RhT0000001`0
oooo00<000000:S>m02Xc_@03`2Xc_@010000000ZFb<0<f;S@00000<0:S>m0<000000P3oool00`00
0000YlSa0:O8l@0K0:O8l@040000002ZKhl0c8b?000001@0YlSa00<0000009S4mP2Ha?H03`2Ha?H0
1`00060000000;]jR@3?RXL0000009S4mP2Ha?D0402Ha?H00`000000Ylod0:O?m00X0:O?m0030000
003oool0oooo01d0oooo00H04`1`0000002XJ8P0dHR10>fPLP00000C0:O?m@040000002EGXd0^g^;
000000D0Yloe1000001J0?ooo`00JP3oool01@000000YfR70<j;R@2RHhL0000001d0oooo1000000=
0:S>m0040000002YK8`0cH^=000000T0Z<kd0`0000060?ooo`8000006`2Wb?4010000000ZVn?0<b<
S`00000D0:O8l@030000002Ha?H0V<Cf00l0V<Cf00D0001P0000002kNXT0chZ70000000B09S4mP03
0000002Wco@0Ylod02P0Ylod00<000000?ooo`3oool07@3oool900000100Yloe00@0M4F;0000002k
Nh/0jj1h1@00001N0?ooo`00JP3oool01@000000YfR70<j;R@3UXHH000000240oooo1`0000050:S>
m0050000001R<Gh0ZFb<0<f;S@0000000`2Xc_@6000000/0oooo0P00000I0:O8l@040000002ZKhl0
c8b?000001@0YlSa00<0000009S4mP2Ha?H03`2Ha?H01@00060000000;]jR@3?RXL000000180V<Cf
00<000000:O?m02Wco@0:02Wco@00`000000oooo0?ooo`0K0?ooo`80000000<0Uf2>0:Y]S02ZKH`0
0P2kN8P20<b4PP030=nAM`000000000000l0000000D0:0ml0000002YKHd0chZ70000001R0?ooo`00
JP3oool01@000000YfR70<j;R@3UXHH0000002P0oooo1P0000000`2YK8`0cH^=0<f;S@04000001<0
oooo0P00000G0:O8l@040000002ZKhl0c8b?000001D0YlSa00<0000009S4mP2Ha?H03P2Ha?H01@00
060000000;]jR@3?RXL000000180V<Cf00<000000:O?m02Wco@02`2Wco@010000000Ylod0>NQP@00
000I0:O?m0030000003oool0oooo01X0oooo00<00000089AS`0000002P00000?0?ooo`0502P?O000
0000ZFf=0<n:Q`000000HP3oool006X0oooo00D000000:MXQ`3>RhT0iJ660000000]0?ooo`050000
002YK8`0cH^=0>BQR0000000603oool3000001@0YlSa00@000000:Y_S`3<S8l000004`2Wb?450000
000309S4mP000000V<Cf00/0V<Cf00D0001P0000002kNXT0chZ70000000A09S4mP030000002Wco@0
Ylod00`0Ylod00@000000;]lS@3WXH400000602Wco@00`000000oooo0?ooo`0J0?ooo`<000000P2G
H8h8000000030?:OH@000000oooo00d0oooo00D0:0ml0000002YKHd0chZ70000001R0?ooo`00JP3o
ool01@000000YfR70<j;R@3UXHH0000002d0oooo00D000000:U/S03=Rhd0i:680000000K0?ooo`<0
00004@2Wb?4010000000ZVn?0<b<S`00000@0:O8l@<000001@3oool00`000000V<Cf09S4mP0;09S4
mP050000H0000000^gZ90<n:Q`000000402Ha?H00`000000Ylod0:O?m00<0:O?m0050140K`000000
^gb=0>NQP@000000602Wco@00`000000oooo0?ooo`0I0?ooo`80000000@0I3f=089AS`0000000000
202Wd?D2000000h0oooo00D0:0ml0000002YKHd0chZ70000001R0?ooo`00JP3oool01@000000YfR7
0<j;R@3UXHH0000002d0oooo00D000000:U/S03=Rhd0i:680000000N0?ooo`@000003@2Wb?401000
0000ZVn?0<b<S`00000;0:O8l@D000002@3oool2000000T0V<Cf00L0V<Ce09S4mP00060000000;]j
R@3?RXL0000000/0V<Cf00<0000009S4mP2Ha?H00P00000?0:O?m0050140K`000000^gb=06HjQ`00
0000602Wco@00`000000oooo0?ooo`0I0?ooo`040000000g7hL00000000000/0Ym3e00<000000?oo
o`3oool0303oool01@0X3g`000000:U]S@3?RXL000000680oooo001Z0?ooo`050000002WJ8L0cX^9
0>FQQP000000;@3oool01@000000ZFb<0<f;S@3TXHP000000280oooo1@0000080:O8l@040000002Z
Khl0c8b?000000<0YlSa2000000@0?ooo`<000001P2Ha?H01`000000V<Cf0000H0000000^gZ90<n:
Q`000000302Ha?H200000140Ylod00D04@1_0000002kO8d0cX^;0000000G0:O?m0030000003oool0
oooo01X0oooo0P00000=0:O@m@030000003oool0oooo00`0oooo00D0:0ml0000002YKHd0chZ70000
001R0?ooo`00JP3oool01@000000YfR70<j;R@3UXHH0000002d0oooo00D000000:U/S03=Rhd0i:68
0000000W0?ooo`T0000000<0ZVn?0<b<S`0000000`00000K0?ooo`<000001@2Ha?H01@0006000000
0;]jR@3?RXL0000000T0V<Cf0`00000C0:O?m0050140K`000000^gb=0<j;R`0000005P2Wco@00`00
0000oooo0?ooo`0K0?ooo`030000002Wd?D0Ym3e00`0Ym3e00<000000?ooo`3oool0303oool01@0X
3g`000000:U]S@3?RXL000000680oooo001Z0?ooo`050000002WJ8L0cX^90>FQQP000000;@3oool0
1@000000ZFb<0<f;S@3TXHP0000002l0oooo00@000000:Y_S`3<S8l000008@3oool40000000609S4
mP00060000000;]jR@3?RXL000001@2Ha?H4000001H0Ylod00D04@1_0000002kO8d0cX^;0000000D
0:O?m08000007P3oool00`000000Ym3e0:O@m@0;0:O@m@030000003oool0oooo00d0oooo00D0:0ml
0000002YKHd0chZ70000001R0?ooo`00JP3oool01@000000YfR70<j;R@3UXHH0000002d0oooo00@0
00000:U/S03=Rhd00000<03oool010000000ZVn?0<b<S`00000U0?ooo`<0000000<0^gZ90<n:Q`00
00001@0000000`3oool000000:O?m00G0:O?m0050140K`000000^gb=0<j;R`0000004@2Wco@30000
0240oooo00<000000:O@m@2Wd?D02@2Wd?D00`000000oooo0?ooo`0>0?ooo`0502P?O0000000UEj=
0;]kR`000000HP3oool006T0oooo00D0000008a@P`2WJ8L0cX^90000000^0?ooo`040000002YK8`0
cH^=00000300oooo00@000000:Y_S`3<S8l000009P3oool01@00060000000;]jR@3?RXL0000000L0
oooo00<000000:O?m02Wco@05@2Wco@01@0A06l000000;]lS@3>Rh/0000000l0Ylod0P00000U0?oo
o`030000002Wd?D0Ym3e00D0Ym3e0P00000C0?ooo`040000002EGXd0^g^;00000680oooo001Y0?oo
o`050000002WJ8L0cX^90:9SQ`000000;P3oool010000000ZFb<0<f;S@00000_0?ooo`050000002E
GXh0ZVn?0<b<S`0000009P3oool01@00060000000;]jR@3?RXL0000000P0oooo0P00000E0:O?m005
0140K`000000^gb=0<j;R`0000003@2Wco@2000002P0oooo1`00000E0?ooo`040000002EGXd0^g^;
00000680oooo001Y0?ooo`D00000;P3oool010000000ZFb<0<f;S@00000]0?ooo`l000007P3oool0
1@00060000000;]jR@3?RXL0000000X0oooo0P0000030:O?m0030000002Wco@0Ylod00d0Ylod00D0
4@1_0000002kO8d0cX^;0000000;0:O?m0800000AP3oool010000000UEj=0;]kR`00001R0?ooo`00
IP3oool3000000030:U/S02kNX/0^gZ;0080bXN90`00000[0?ooo`040000002YK8`0cH^=000002H0
oooo1`0000030:efUPP0^h6E1039S986000001P0oooo00D0001P0000002kNXT0chZ70000000<0?oo
o`<000001P2Wco@00`000000Ylod0:O?m0070:O?m0050140K`000000^gb=0<j;R`000000202Wco@3
000004P0oooo00@0000009ENS@2kNh/00000HP3oool006D0oooo00<0000009ELR`00000020000000
0`3[XWd000000?ooo`0Y0?ooo`040000002YK8`0cH^=00000240oooo1@00000309aZU`@0[GJF3`00
00020<V<TP@0f9N=1000000D0?ooo`050000H0000000^gZ90<n:Q`0000003`3oool3000000d0Ylod
00D04@1_0000002kO8d0cX^;000000050:O?m0<00000B`3oool010000000UEj=0;]kR`00001R0?oo
o`00I03oool?000002T0oooo00@000000:U/S03=Rhd000007`3oool20000000308MJUP2LJYL0W6ZG
00@0W6ZG1@0000040:efUPL0^h6E1039S985000000<0f9N=0P3ZYH<200000180oooo00D0001P0000
002kNXT0chZ70000000B0?ooo`d0000000@04@1_0000002kO8d0cX^;1P00001>0?ooo`0507A5R`00
0000^g^;0>^PN0000000H@3oool006<0oooo0P0000000`1hAXL000000:S?m0080:S?m0030000003j
/V`0000002P0oooo00D00000068aOP2YK8`0cH^=0000000N0?ooo`0300000027FYH0QeZF0080QeZF
0P2LJYL30000000309aZU`2]MYH0[GJF00H0[GJF1`2kPID60<V<TP<0f9N=0`0000040>ZUP`030000
003oool0oooo00l0oooo00D0001P0000002kNXT0chZ70000000O0?ooo`050140K`000000^gb=0<j;
R`000000D@3oool<000005`0oooo001S0?ooo`030000001;8gh0000000/0Z<od0P00000N0?oooa80
00006@3oool2000000@0QeZF0`00000509aZU`@0[GJF3`0000020<V<TPD0f9N=0P0000020>ZUP`03
0?^cI`000000oooo00l0oooo00D0001P0000002kNXT0chZ70000000O0?ooo`050140K`000000^gb=
0<j;R`000000C03oool500000080VVBA1P2[LY840;]oT@@00000F03oool006<0oooo0P00000=0:S?
m0030000003oool0oooo01X0oooo0P0000000`1lB8L0V62>09QPSP0309QPSPD0Zg6A1@2kOi<20<Z=
T`<000005@3oool010000000IT6A08MJUP27FYH30000000308MJUP2LJYL0W6ZG0080W6ZG1`00000?
0:O?m0H0000000<0f9N=0>ZUP`3ZYH<00P0000020?^cI`030000003oool0oooo00d0oooo00D0001P
0000002kNXT0chZ70000000O0?ooo`050140K`000000^gb=0<j;R`000000B@3oool300000080QUB?
0`2JI94<000000040;]oT@3<S900c8b@0<b<T0<00000E@3oool006<0oooo00<000000:S?m02Xco@0
302Xco@00`000000oooo0?ooo`0H0?ooo`8000000`1lB8L309QPSP/0000000<0^gnC0<Z=T`3:SI<0
0`3:SI<400000100oooo00<0000006I1T@0000000P00000308MJUPD00000702Wco@300000080jZF3
00@000000?^cI`3k/fL000003P3oool01@00060000000;]jR@3?RXL0000001l0oooo00D04@1_0000
002kO8d0cX^;000000170?ooo`80000000<0J3f908IDS`26E8l01@00000209YTT@H0Zg:B102kOi44
000000030<b<T03NVh/0gY^;00800000D`3oool006<0oooo00<000000:S?m02Xco@02`2Xco@00`00
0000oooo0?ooo`0G0?ooo`80000000<0Cb9i07a8Q`1lB8L01@00000209QPSPD0Zg6A102kOi<50000
00030<Z=T`3IVi<0fI^C0080fI^C0`00000<0?ooo`040000001V@I40000006I1T@<0QeZF0P00000T
0:O?m0@0000000<0nk=W0000003oool03@3oool01@00060000000;]jR@3?RXL0000001l0oooo00D0
4@1_0000002kO8d0cX^;000000160?ooo`030000001X?HT0J3f900<000000P26E8l509YTT@H0Zg:B
1@2kOi430<b<T0<000000P3NVh/200000540oooo001T0?ooo`<000002@2Xco@00`000000oooo0?oo
o`0H0?ooo`030000001?8WT00000008000000P1lB8L309QPSP/0000000<0^gnC0<Z=T`3:SI<00P3:
SI<3000000<0fI^C0P3Y[8l00`000000oooo0?ooo`080?ooo`030000001V@I4000000080IT6A00<0
QeZF000000000000:@2Wco@2000000030=RN4`000000oooo00`0oooo00D0001P0000002kNXT0chZ7
0000000O0?ooo`050140K`000000^gb=0<j;R`000000A@3oool01@000000J3f9000000000000J3f9
0080QUB?5@0000000`3<S900gY^;0=jKR`0200000080lZin00<000000?ooo`3oool0CP3oool006H0
oooo0`0000030:S?m0@000006P3oool010000000Cb9i0000001?8WT207a8Q`D000002`2Ga?H50000
00030<Z=T`3IVi<0fI^C0080000000D0fI^C0>V/S`3Y[8l0jJb?000000080?ooo`030000000Y5880
00000080IT6A0P00000[0:O?m0040000003k/fL00000000000d0oooo00D0001P0000002kNXT0chZ7
0000000O0?ooo`050140K`000000^gb=0<j;R`000000A03oool00`000000>1Ql0000000206PmR@<0
00005@2Ha?D300000080gY^;0P0000000`3b[Wh000000?ooo`1>0?ooo`00J@3oool3000001h0oooo
0P000000101?8WT0000000000000000E09O4mP<000000P3IVi<200000080jJb?00<000000?ooo`3o
ool01@3oool00`000000:AB20000000206I1T@030000002Wco@0Ylod02`0Ylod0`00000=0?ooo`05
0000H0000000^gZ90<n:Q`0000007`3oool01P0A06l0000009EMS@2kO8d0oooo00000480oooo00@0
000003PHO0000000J3f90P00000K09S4m@8000000P3b[Wh2000004l0oooo00290?ooo`0400000000
05<00000000001/0UlCf0P0000020>V/S`80000000<0n[n40000003oool01@3oool20000000302TD
PP1V@I4000000300Ylod0P00000=0?ooo`050000H0000000^gZ90<n:Q`000000803oool01@000000
UEf=0;]lS@3WXH4000000440oooo00D000000000E`000000>1Ql0000000O09S4m@80000000<0lZin
000000000000CP3oool008T0oooo0`00000N09O4mP8000000P3Y[8l00`000000n[n4000000040?oo
o`8000000P0Y58800`000000Ylod0:O?m00_0:O?m08000003@3oool01@00060000000;]jR@3?RXL0
00000200oooo00D0000009EMS@2kO8d0ij61000000110?ooo`040000E`000000>1Ql00000280V<Ce
0P00001?0?ooo`00R@3oool200000240UlCf00<000000>V/S`3j_h@00P0000040?ooo`80000000<0
:AB20000002Wco@0<P2Wco@00`000000oooo0?ooo`0;0?ooo`050000H0000000^gZ90<n:Q`000000
803oool01@000000UEf=0;]lS@3WXH4000000440oooo00<000000000E`000000902Ha?D2000004h0
oooo00290?ooo`030000002Ga?H0UlCf0240UlCf0P0000000`3j_h@00000000000030?ooo`030000
000Y5880000003@0Ylod00<000000?ooo`3oool02`3oool01@00060000000;]jR@3?RXL000000200
oooo00D0000009EMS@2kO8d0ij61000000110?ooo`030000E`000000V<Ce02@0V<Ce0P00001>0?oo
o`00R@3oool00`000000UlCf09O4mP0S09O4mP800000103oool2000001/0Ylod00<000000:O?m02W
co@05`2Wco@00`000000oooo0?ooo`0;0?ooo`050000H0000000^gZ90<n:Q`000000803oool01@00
0000UEf=0;]lS@3WXH4000000440oooo00<0000009S4m@2Ha?D09@2Ha?D00`000000oooo0?ooo`1<
0?ooo`00R@3oool00`000000UlCf09O4mP0?09O4mP03068aOP2Ga?H0UlCf0180UlCf0P0000030?oo
o`030000B0000000Ylod01L0Ylod00D000000:Y_S`3<S8l000000:O>m00G0:O?m0030000003oool0
oooo00X0oooo2`00000L0?ooo`050000002EGHd0^gb=0>NQP@000000@@3oool00`000000V<Ce09S4
m@0@09S4m@050000002Ha?D0V<Ce0000002Ha?D00`2Ia?D=09S4m@030000003oool0oooo04`0oooo
00290?ooo`030000002Ga?H0UlCf00l0UlCf00H000000:U/S02Ga?H0000009O4mP2Ha?H?09O4mP03
0000003oool0oooo0080oooo00<000000:O?m02Wco@05`2Wco@010000000ZVn?0<b<S`0000030:O?
m0030:O>m02Wco@0Ylod0180Ylod00<000000?ooo`3oool02@3oool00`000000PE2>09QQS`080000
00030>nRLP000000oooo01X0oooo00D0000009EMS@2kO8d0ij61000000120?ooo`030000002Ha?D0
V<Ce00h0V<Ce00D0:0ml0000002kNh/0chZ70000000209W4m@l0V<Ce00<000000?ooo`3oool0C03o
ool008X0oooo00<0000009O4mP2Ga?H03P2Ga?H010000000ZFb<0<f;S@00000A09O4mP030000003o
ool0oooo0080oooo00<000000:O?m02Wco@05`2Wco@010000000ZVn?0<b<S`00000G0:O?m0030000
003oool0oooo00T0oooo100000000`2HHHl0ZVj>0000000300000080g9>10P00000C0?oooa@00000
>`3oool00`000000V<Ce09S4m@0>09S4m@0502P?O0000000^g^;0<n:Q`0000004@2Ha?D00`000000
oooo0?ooo`1<0?ooo`00RP3oool00`000000UlCf09O4mP0:09O4mP80V<Cf0P2Ga?H010000000ZFb<
0<f;S@00000A09O4mP030000003oool0oooo0080oooo00<000000:O?m02Wco@05`2Wco@010000000
ZVn?0<b<S`00000F0:O?m0030000003oool0oooo00T0oooo0P0000000`21D8h00000000000020000
00@0Ym3e1000000?0?ooo`@000000P24DHd409YTT@H0[7:B1@2kOi<30<Z=TP<00000>03oool00`00
0000V<Ce09S4m@0=09S4m@0609W4m@0X3g`000000;]kR`3?RXL000004@2Ha?D00`000000oooo0?oo
o`1<0?ooo`00R`3oool00`000000UlCf09O4mP0=09O4mP040000002YK8`0cH^=00000140UlCf00<0
00000?ooo`3oool00`3oool00`000000Ylod0:O?m00F0:O?m0040000002ZKhl0c8b?000001@0Ylod
0P00000<0?ooo`030000001O>8/0000000/0Ym3e0P00000=0?ooo`030000001R=XD0Q56=00@0Q56=
0P2JI94;00000080^gnC103:SI820=^KT0800000=`3oool2000000h0V<Ce00D0:0ml0000002kNh/0
chZ70000000?09S4m@800000C`3oool008`0oooo0P00000=09O4mP040000002YK8`0cH^=00000140
UlCf00<000000?ooo`3oool0103oool00`000000Ylod0:O?m00E0:O?m0040000002ZKhl0c8b?0000
0140Ylod00<000000:O?m00000003P3oool2000000d0Ym3e00<000000?ooo`3oool02P3oool00`00
0000HSJ5068fQ@0208AAS@D000000P2JI9450:abTP@0^gnC1@0000000`3:SI80fi^@0=^KT0020=^K
T0800000=`3oool00`000000V<Ce09S4m@0;09S4m@0502P?O0000000^g^;0<n:Q`0000003P2Ha?D0
0`000000oooo0?ooo`1?0?ooo`00SP3oool00`000000UlCf09O4mP0:09O4mP040000002YK8`0cH^=
00000100UlCf00<000000?ooo`3oool01P3oool00`000000Ylod0:O?m00D0:O?m0040000002ZKhl0
c8b?00000180Ylod00<000000?ooo`3oool03@3oool00`000000Ym3e0:O@m@0;0:O@m@030000003o
ool0oooo00X0oooo00<00000068fQ@1R=XD00`00000208AAS@<0VVBA2`0000000`2kOi<0bXfB0<Z=
TP020<Z=TP@0000000@0fi^@0>j]R03^[HP00000=`3oool2000000@0V<Ce00<0000009S4m@2Ha?D0
1@2Ha?D01@000000^g^;0;]kR`3[X7P0000000P0V<Ce00<0000009S4m@2Ha?D00P00001B0?ooo`00
S`3oool4000000<0UlCf00@0000009O4mP2Ga?H0UlCf0P0000000`2YK8`0cH^=0000000>09O4mP80
00002P3oool2000000030:O?m0000000Ylod0140Ylod00@000000:Y_S`3<S8l00000302Wco@01000
0000Ylod0:O?m02Wco@200000100oooo00<000000:O@m@2Wd?D02P2Wd?D2000000/0oooo00D00000
02H6LP0000000000068fQ@0208AAS@D000002`2Ha?H5000000040<Z=TP3KVi00fi^@0=^KT0<00000
00<0kZf80000003oool0=`3oool00`000000V<Ce09S4m@0909S4m@050000002YKHd0^g^;0>^PN000
00002@2Ha?D2000005@0oooo002C0?ooo`<000001@2Ga?H010000000ZFb<0<f;S@00000;09O4mP<0
00003P3oool200000180Ylod00@000000:Y_S`3<S8l000003@2Wco@3000001<0oooo00<000000:O@
m@2Wd?D0202Wd?D00`000000oooo0?ooo`0;0?ooo`8000000P1R=XD3000001D0V<Cf0`0000020=^K
T080kZf80P00000i0?ooo`@000001`2Ha?D01@000000ZFf=0;]kR`3[X7P0000000H0V<Ce0`00001F
0?ooo`00UP3oool2000000<0UlCf00@000000:U/S03=Rhd000002@2Ga?H2000001<0oooo00<00000
0:O?m02Wco@01P2Wco@00`000000Ylod0:O?m0060:O?m0040000002ZKhl0c8b?000000X0Ylod0`00
000G0?ooo`<000000`2Wd?D4000000d0oooo0P0000000`0V1W8000000000000K09S4mP8000000`3^
[HP2000003`0oooo2@0000000`2kNh/0chZ700000006000005T0oooo002H0?ooo`<0000000<0ZFb<
0;]lS@3=Rhd02P00000F0?ooo`@000003@2Wco@010000000ZVn?0<b<S`0000070:O?m0<000007@3o
ool300000140oooo00<0000h0000000000007`2Ha?H2000000030>j]R0000000000004<0oooo00D0
:0ml0000002kNh/0chZ70000001O0?ooo`00VP3oool01@000000ZFb<0<f;S@3TXHP0000002<0oooo
1P0000070:O?m0040000002ZKhl0c8b?00000080Ylod1@00000d0?ooo`8000008P2Ha?H010000000
o[m`0000000000120?ooo`0502P?O0000000^g^;0<n:Q`000000G`3oool009X0oooo00D000000:U/
S03=Rhd0i:680000000Y0?ooo`P0000000<0ZVn?0<b<S`0000000P00000i0?ooo`030000>0000000
V<Cf0280V<Cf0`0000120?ooo`0502P?O0000000^g^;0<n:Q`000000G`3oool009X0oooo00D00000
0:U/S03=Rhd0i:680000000`0?ooo`040000002ZKhl0c8b?000003/0oooo00<0000009S4mP2Ha?H0
8P2Ha?H300000480oooo00D0:0ml0000002kNh/0chZ70000001O0?ooo`00VP3oool01@000000ZFb<
0<f;S@3TXHP000000300oooo00@000000:Y_S`3<S8l00000>`3oool00`000000V<Cf09S4mP0?09S4
mP040000002Ha?H0V<Cf00000100V<Cf0P0000120?ooo`0502P?O0000000^g^;0<n:Q`000000G`3o
ool009X0oooo00D000000:U/S03=Rhd0i:680000000`0?ooo`040000002ZKhl0c8b?000003/0oooo
00<0000009S4mP2Ha?H03`2Ha?H010000000^gb=0>NQP@00000@09S4mP800000@P3oool01@0X3g`0
00000;]kR`3?RXL0000005l0oooo002J0?ooo`050000002YK8`0cH^=0>BQR0000000<03oool01000
0000ZVn?0<b<S`00000k0?ooo`030000002Ha?H0V<Cf00h0V<Cf00D04@1_0000002kO8d0ij610000
000A09S4mP030000003oool0oooo0400oooo00D0:0ml0000002kNh/0chZ70000001O0?ooo`00VP3o
ool01@000000ZFb<0<f;S@3TXHP000000300oooo00@000000:Y_S`3<S8l00000?03oool00`000000
V<Cf09S4mP0=09S4mP050140K`000000^gb=0>NQP@0000004@2Ha?H00`000000oooo0?ooo`100?oo
o`060000<P000000^g^;0;]kR`3[X7P00000GP3oool009X0oooo00@000000:U/S03=Rhd00000<@3o
ool010000000ZVn?0<b<S`00000m0?ooo`80000000<0V<Cf0000002Ha?H02P2Ha?H01@0A06l00000
0;]lS@3WXH40000000l0V<Cf0P0000140?ooo`050000002YKHd0^g^;0>^PN0000000GP3oool009X0
oooo00@000000:U/S03=Rhd00000<03oool01@000000KCj60:Y_S`3<S8l0000003l0oooo00<00000
09S4mP2Ha?H02P2Ha?H01@0A06l000000;]lS@3WXH40000000h0V<Cf00<000000?ooo`3oool0A03o
ool01@000000ZFf=0;]kR`3[X7P0000005h0oooo002J0?ooo`040000002YK8`0cH^=00000300oooo
00D0000006dnQP2ZKhl0c8b?000000100?ooo`8000002P2Ha?H01@0A06l000000;]lS@3WXH400000
00`0V<Cf0P0000170?ooo`050000002YKHd0^g^;0>^PN0000000GP3oool009X0oooo00@000000:U/
S03=Rhd00000<03oool01@000000ZVn?0<b<S`3<S8l000000480oooo0P00000609S4mP090000002H
a?H04@1_0000002kO8d0ij610000002Ha?H0000000T0V<Cf00<000000?ooo`3oool0A`3oool01@00
0000ZFf=0;]kR`3[X7P0000005h0oooo002J0?ooo`040000002YK8`0cH^=00000300oooo00D00000
0:Y_S`3<S8l0hj69000000140?ooo`<000001@2Ha?H01@0A06l000000;]lS@3WXH40000000P0V<Cf
0`00001:0?ooo`050000002YKHd0^g^;0>^PN0000000GP3oool009X0oooo00@000000:U/S03=Rhd0
0000<03oool01@000000ZVn?0<b<S`3SXHT0000004L0oooo1`0000000`2kO8d0ij61000000080000
04d0oooo00D000000:U]S@2kNh/0jj1h0000001N0?ooo`00V@3oool01@1R<Gh000000:U/S03=Rhd0
00000300oooo00D000000:Y_S`3<S8l0hj690000001<0?ooo`050140K`000000^gb=0>NQP@000000
E@3oool01@000000ZFf=0;]kR`3[X7P0000005h0oooo002I0?ooo`05068aOP000000ZFb<0<f;S@00
0000<03oool01@000000ZVn?0<b<S`3SXHT0000004`0oooo00D04@1_0000002kO8d0ij610000001E
0?ooo`0502P?O0000000ReJ=0<n:Q`000000GP3oool009T0oooo00D00000095HR@2YK8`0cH^=0000
000`0?ooo`050000002ZKhl0c8b?0>>QR@000000C03oool01@0A06l000000;]lS@3WXH40000005D0
oooo00D0:0ml0000002kNh/0chZ70000001N0?ooo`00V@3oool01@000000ZFb<0;moS@3TXHP00000
0300oooo00D000000:Y_S`3<S8l0hj690000001<0?ooo`050140K`000000^gb=0>NQP@000000E@3o
ool01@0X3g`000000;]kR`3?RXL0000005h0oooo002I0?ooo`050000002YK8`0cH^=0>BQR0000000
:03ooolA000004P0oooo00D04@1_0000002kO8d0ij610000001E0?ooo`060000<P000000^g^;0;]k
R`3[X7P00000G@3oool009T0oooo00D000000:U/S03=Rhd0i:680000000V0?ooo`80000000<0Pe6=
09]UT@2KII400P2KII450:adU0D0^h6E0P39SYH3000004D0oooo00D04@1_0000002kO8d0ij610000
001F0?ooo`030000002YKHd0000000<00000G03oool009P0oooo1`00000S0?ooo`8000000`23DHd2
09]UT@/0000000<0^h6E0<V>UP39SYH00`39SYH300000480oooo00D04@1_0000002kO8d0ij610000
001D0?ooo`@000000P2kNhd20<^6R0800000FP3oool009H0oooo0P0000020:]`T080^Wb?0P39R8d0
103IU8P0000000000000000N0?ooo`80000000<0GS:208=AS@23DHd01000000209]UT@D0[7BD102k
PID400000080bHjF0`3HVi@200000400oooo00H04@1_0000002EGHd0^gb=0>NQP@00001B0?ooo`03
00000028FI@0VfJC00X00000F03oool009@0oooo3P00000M0?ooo`030000001N<X80GS:200<00000
00@0Pe6=09]UT@2KII40VfFA2`000000102kPID0bHjF0<V>UP39SYH4000000040=RKU03Y[900jJb@
00000400oooo00D0000009EMS@2kO8d0ij610000001@0?ooo`l00000F03oool009@0oooo0P000000
0`20Chh0VF:@0000000600000080jZ=o0P00000K0?ooo`060000000D06L000000000001N<X80Pe6=
1@00000;09O4mP@0000000@0bHjF0=RKU03HVi@0f9^D0`0000000`3Y[90000000?ooo`0n0?ooo`05
0000002EGHd0^gb=0>NQP@000000D03oool200000080R5VD00<000000:OAmP2WdOH01P2WdOH20000
05P0oooo002C0?ooo`D000001`2Xco@4000001/0oooo0P000000101N<X80000000000000000D09O4
mP@0000000H0f9^D0>V/T03Y[90000000?^oPP00000n0?ooo`050000002EGHd0^gb=0>NQP@000000
D03oool4000000X0Ym7f00<000000?ooo`3oool0EP3oool009<0oooo0P00000<0:S?m08000006`3o
ool3000001/0UlCf0`000000103Y[90000000?^oPP00000m0?ooo`050000002EGHd0^gb=0>NQP@00
0000D03oool00`000000Ym7f0:OAmP0;0:OAmP030000003oool0oooo05H0oooo002C0?ooo`030000
<P000000Z<od00`0Z<od00<000000?ooo`3oool06@3oool2000001l0UlCf00@000000?^oPP000000
0000?@3oool01@000000UEf=0;]lS@3WXH4000000500oooo00<000000:OAmP2WdOH02`2WdOH00`00
0000oooo0?ooo`1F0?ooo`00U03oool00`000000Z<od0:S?m00:0:S?m08000006P3oool200000240
UlCf00@000000?^oPP0000000000?03oool01@000000UEf=0;]lS@3WXH4000000500oooo00<00000
0:OAmP2WdOH0202WdOH3000005T0oooo002D0?ooo`8000002@2Xco@2000001`0oooo00<0000D0000
002Ga?H08@2Ga?H3000003`0oooo00D0000009EMS@2kO8d0ij610000001A0?ooo`800000102WdOH4
000005`0oooo002F0?ooo`T000007P3oool00`000000UlCf09O4mP0R09O4mP800000?03oool01@00
0000UEf=0;]lS@3WXH40000005<0oooo1000001P0?ooo`00_@3oool00`000000UlCf09O4mP0>09O4
mP040000002ZKhl0c8b?00000100UlCf00<000000?ooo`3oool0>`3oool01@000000UEf=0;]lS@3W
XH4000000;L0oooo002n0?ooo`030000002Ga?H0UlCf00d0UlCf00@000000:Y_S`3<S8l000004@2G
a?H00`000000oooo0?ooo`0j0?ooo`050000002EGHd0^gb=0>NQP@000000]`3oool00;l0oooo00<0
000009O4mP2Ga?H0302Ga?H010000000ZVn?0<b<S`00000A09O4mP030000003oool0oooo03X0oooo
00D0000009EMS@2kO8d0ij610000002g0?ooo`00`03oool20000000309O4mP000000UlCf00T0UlCf
00@000000:Y_S`3<S8l00000402Ga?H00`000000oooo0?ooo`0k0?ooo`H00000]P3oool00<80oooo
00D0000009O4mP2Ga?H0UlCf0000000709O4mP040000002ZKhl0c8b?000000l0UlCf00<000000?oo
o`3oool0>P3oool3000000030:abT@2jO8l0^Wb?0080bXN;0P00002d0?ooo`00``3oool3000000<0
UlCf00<0000009O4mP2Ga?H00P2Ga?H010000000ZVn?0<b<S`00000=09O4mP800000>`3oool>0000
0;80oooo00360?ooo`@00000102Ga?H010000000ZVn?0<b<S`00000309O4mP030000002Ga?H0UlCf
00<0UlCf1000000l0?ooo`050000001Y@i00000008MGT`2KIY801`0000000`3^XWD000000000002b
0?ooo`00bP3oool5000000030:Y_S`3<S8l0000000D0UlCf100000100?ooo`D000001`2Wd?H30000
0;80oooo003>0?ooo`030000002ZKhl0c8b?00H00000A03oool2000000`0Ym3f00<000000?ooo`3o
ool0/03oool00<h0oooo00@000000;n1T03<S8l00000B@3oool00`0006P000000:O@mP0;0:O@mP03
0000003oool0oooo0;00oooo003>0?ooo`040000002oPI00c8b?000004T0oooo00<000000:O@mP2W
d?H02P2Wd?H200000;80oooo003>0?ooo`040000002oPI00c8b?000004T0oooo0P0000090:O@mP80
0000]03oool00<h0oooo00@000000;n1T03<S8l00000B`3oool900000;H0oooo003>0?ooo`040000
002oPI00c8b?00000?l0oooo2`3oool00<d0oooo00D0nkYe0000002oPI00c8b?0000003o0?ooo`/0
oooo003=0?ooo`050?^jM@000000_h6@0<b<S`000000o`3oool;0?ooo`00c@3oool01@000000KCj6
0:Y_S`3<S8l000000?l0oooo2`3oool00<d0oooo00D000000:Y_S`2kOI00c8b?0000003o0?ooo`/0
oooo003=0?ooo`050000002ZKhl0^gf@0>>QR@000000o`3oool;0?ooo`00c@3oool01@000000ZVn?
0;]mT03SXHT000000?l0oooo2`3oool00<d0oooo00D000000:Y_S`2kOI00hj690000003o0?ooo`/0
oooo003=0?ooo`050000002ZKhl0^gf@0>>QR@000000o`3oool;0?ooo`00c@3oool01@000000ZVn?
0;]mT03SXHT000000?l0oooo2`3oool00<d0oooo00D000000:Y_S`2kOI00hj690000003o0?ooo`/0
oooo003=0?ooo`050000002ZKhl0^gf@0>>QR@000000o`3oool;0?ooo`00c@3oool01@000000_h6@
0;]mT03SXHT000000?l0oooo2`3oool00<d0oooo00D000000;n1T02kOI00hj690000003o0?ooo`/0
oooo003=0?ooo`050000002oPI00^gf@0>>QR@000000o`3oool;0?ooo`00c@3oool500000?l0oooo
2`3oool00</0oooo0`000000102/Li<0^WjA0<R9S`38RHl400000?l0oooo1`3oool00<T0oooo3@00
003o0?ooo`L0oooo00380?ooo`030000001V?hh000000080VfNC2@00003o0?ooo`L0oooo00380?oo
o`D00000202Wd?D200000?l0oooo1P3oool00<P0oooo0P00000;0:O@m@800000o`3oool60?ooo`00
b03oool2000000/0Ym3e00<000000?ooo`3oool0o`3oool50?ooo`00b@3oool00`000000Ym3e0:O@
m@090:O@m@030000003oool0oooo0?l0oooo1@3oool00<T0oooo0`0000060:O@m@<00000o`3oool8
0?ooo`00c03oool600000?l0oooo2`3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3o
ool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3o
ool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3o
ool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3o
ool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3o
ool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3o
ool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3o
ool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00?l0oooog@3o
ool00?l0oooog@3oool00?l0oooog@3oool00001\
\>"],
  ImageRangeCache->{{{0, 475.062}, {474.125, 0}} -> {0.017387, -4.89129*^-5, \
0.00193255, 0.00193255}},
  CellTags->"Laser Radar Example"]
}, Open  ]],

Cell["\<\
Finally, we are ready to run a ray-trace of forest. We will first \
do a preliminary ray-trace with a smaller number of rays in order to get an \
overall picture of what is happening. In order to see more clearly the \
outgoing and incoming rays, we will use a separate light source position \
{-500,0,50000} and detector position{0,0,50000}. Later on, we will put these \
at the same point in space for our actual simulation.\
\>", "Text",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{

Cell["\<\
Timing[res = TurboPlot[
\t{MoveDirected3D[GaussianBeam[20, .05, NumberOfRays->10, \
MonteCarlo->Stratified, FullForm->True, SpatialScale->1/10], 
\t\t{-500,0,50000},{0,0,0},SideOfObject->After],
\tfocusedtreecomposite,
\tBoundary[{-1500,-1500,0},{1500,1500,50000}]}, 
\tCreateClones->treepositions, ShowClones->True, \
RunningCommentary->TurboTrace];]\
\>", "Input",
  CellTags->"Laser Radar Example"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 9.28762 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-4.50091 10.0051 -0.717472 10.0051 [
[ 0 0 0 0 ]
[ 1 9.28762 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 9.28762 L
0 9.28762 L
closepath
clip
newpath
.41685 .76976 m .41728 .76251 L .44153 .76174 L .668 .434 .557 r
F
0 g
.5 Mabswid
[ ] 0 setdash
.38393 .76961 m
.46407 .74054 L
s
.39275 .76646 m .41728 .76251 L .41685 .76976 L .732 .489 .561 r
F
.39275 .76646 m .39319 .75921 L .41728 .76251 L F
.41806 .74244 m .41729 .76221 L .44142 .76145 L .654 .726 .902 r
F
.40207 .74026 m .41729 .76221 L .41806 .74244 L F
.40207 .74026 m .39332 .75893 L .41729 .76221 L F
.37045 .75933 m .39319 .75921 L .39275 .76646 L .793 .543 .56 r
F
0 g
.37736 .76154 m
.38393 .76961 L
s
.37045 .75933 m .37089 .75208 L .39319 .75921 L .793 .543 .56 r
F
0 g
.35004 .72797 m
.37081 .75348 L
s
.39319 .75921 m
.41728 .76251 L
s
.4411 .76899 m .44153 .76174 L .46429 .75697 L .594 .371 .547 r
F
.41685 .76976 m .44153 .76174 L .4411 .76899 L .668 .434 .557 r
F
0 g
.41728 .76251 m
.44153 .76174 L
s
.38727 .73552 m .39332 .75893 L .40207 .74026 L .654 .726 .902 r
F
.38727 .73552 m .37113 .75184 L .39332 .75893 L F
.43416 .74194 m .44142 .76145 L .46407 .7567 L F
.41806 .74244 m .44142 .76145 L .43416 .74194 L F
.41641 .77701 m .41685 .76976 L .4411 .76899 L .668 .434 .557 r
F
.39231 .77371 m .41685 .76976 L .41641 .77701 L .732 .489 .561 r
F
.39231 .77371 m .39275 .76646 L .41685 .76976 L F
.41762 .74989 m .41685 .76976 L .4411 .76899 L .654 .726 .902 r
F
.40154 .7477 m .41685 .76976 L .41762 .74989 L F
.40154 .7477 m .39275 .76646 L .41685 .76976 L F
.37 .76659 m .39275 .76646 L .39231 .77371 L .793 .543 .56 r
F
0 g
.36293 9.01957 m
.38243 1.3573 L
s
.37 .76659 m .37045 .75933 L .39275 .76646 L .793 .543 .56 r
F
.38667 .74294 m .39275 .76646 L .40154 .7477 L .654 .726 .902 r
F
.38667 .74294 m .37045 .75933 L .39275 .76646 L F
0 g
.39275 .76646 m
.41685 .76976 L
s
.4411 .76899 m .46429 .75697 L .46386 .76422 L .594 .371 .547 r
F
.44066 .77625 m .4411 .76899 L .46386 .76422 L F
.41641 .77701 m .4411 .76899 L .44066 .77625 L .668 .434 .557 r
F
.4338 .74938 m .4411 .76899 L .46386 .76422 L .654 .726 .902 r
F
.41762 .74989 m .4411 .76899 L .4338 .74938 L F
0 g
.41685 .76976 m
.4411 .76899 L
s
.35145 .74885 m .37089 .75208 L .37045 .75933 L .856 .601 .552 r
F
.35145 .74885 m .35189 .7416 L .37089 .75208 L F
0 g
.37089 .75208 m
.376 .75372 L
s
.41718 .75715 m .41641 .77701 L .44066 .77625 L .654 .726 .902 r
F
.4011 .75495 m .41641 .77701 L .41718 .75715 L F
.4011 .75495 m .39231 .77371 L .41641 .77701 L F
.46386 .76422 m .46429 .75697 L .48403 .74851 L .496 .289 .529 r
F
0 g
.45368 .7592 m
.46429 .75697 L
s
.37466 .72856 m .37113 .75184 L .38727 .73552 L .654 .726 .902 r
F
.37466 .72856 m .35223 .7414 L .37113 .75184 L F
.44927 .73877 m .46407 .7567 L .48371 .74828 L F
.43416 .74194 m .46407 .7567 L .44927 .73877 L F
.38622 .75019 m .39231 .77371 L .4011 .75495 L F
.38622 .75019 m .37 .76659 L .39231 .77371 L F
0 g
.39231 .77371 m
.41641 .77701 L
s
.38385 .79947 m
.38392 .77103 L
s
.44066 .77625 m .46386 .76422 L .46343 .77148 L .594 .371 .547 r
F
.43336 .75664 m .44066 .77625 L .46343 .77148 L .654 .726 .902 r
F
.41718 .75715 m .44066 .77625 L .43336 .75664 L F
0 g
.41641 .77701 m
.44066 .77625 L
s
.351 .7561 m .37045 .75933 L .37 .76659 L .856 .601 .552 r
F
.351 .7561 m .35145 .74885 L .37045 .75933 L F
.374 .73594 m .37045 .75933 L .38667 .74294 L .654 .726 .902 r
F
.374 .73594 m .35145 .74885 L .37045 .75933 L F
0 g
.37045 .75933 m
.37556 .76097 L
s
.46386 .76422 m .48403 .74851 L .4836 .75576 L .496 .289 .529 r
F
.46343 .77148 m .46386 .76422 L .4836 .75576 L F
.44898 .7462 m .46386 .76422 L .4836 .75576 L .654 .726 .902 r
F
.4338 .74938 m .46386 .76422 L .44898 .7462 L F
0 g
.45324 .76645 m
.46386 .76422 L
s
.41878 .63439 m .42025 .69253 L .41868 .69273 L .642 .403 .542 r
F
.41878 .63439 m .42036 .63419 L .42025 .69253 L F
.41723 .63413 m .41878 .63439 L .41868 .69273 L .751 .492 .541 r
F
0 g
.41878 .63439 m
.41878 .63439 L
s
.42036 .63419 m .42127 .6921 L .42025 .69253 L .519 .305 .529 r
F
.42036 .63419 m .42137 .63375 L .42127 .6921 L F
0 g
.41878 .63439 m
.42036 .63419 L
s
.41723 .63413 m .41868 .69273 L .41712 .69248 L .751 .492 .541 r
F
.41625 .63366 m .41723 .63413 L .41712 .69248 L .844 .572 .527 r
F
0 g
.41723 .63413 m
.41878 .63439 L
s
.42137 .63375 m .42197 .69154 L .42127 .6921 L .359 .182 .499 r
F
.42137 .63375 m .42207 .63319 L .42197 .69154 L F
0 g
.42036 .63419 m
.42137 .63375 L
s
.41625 .63366 m .41712 .69248 L .41614 .69201 L .844 .572 .527 r
F
.41559 .63307 m .41625 .63366 L .41614 .69201 L .927 .648 .492 r
F
0 g
.41625 .63366 m
.41723 .63413 L
s
.42207 .63319 m .4224 .69086 L .42197 .69154 L .077 0 .416 r
F
.42207 .63319 m .4225 .63252 L .4224 .69086 L F
0 g
.42137 .63375 m
.42207 .63319 L
s
.41559 .63307 m .41614 .69201 L .41548 .69142 L .927 .648 .492 r
F
.41521 .63238 m .41559 .63307 L .41548 .69142 L .989 .721 .392 r
F
0 g
.41559 .63307 m
.41625 .63366 L
s
.4225 .63252 m .42251 .69006 L .4224 .69086 L 0 0 .138 r
F
.4225 .63252 m .42261 .63171 L .42251 .69006 L F
0 g
.42207 .63319 m
.4225 .63252 L
s
.41521 .63238 m .41548 .69142 L .4151 .69073 L .989 .721 .392 r
F
.41516 .63158 m .41521 .63238 L .4151 .69073 L .789 .63 .07 r
F
0 g
.41521 .63238 m
.41559 .63307 L
s
.37355 .7432 m .37 .76659 L .38622 .75019 L .654 .726 .902 r
F
.37355 .7432 m .351 .7561 L .37 .76659 L F
0 g
.37 .76659 m
.39231 .77371 L
s
.42261 .63171 m .42206 .68903 L .42251 .69006 L .985 .728 .345 r
F
.42261 .63171 m .42216 .63068 L .42206 .68903 L F
.46343 .77148 m .4836 .75576 L .48317 .76302 L .496 .289 .529 r
F
.44855 .75345 m .46343 .77148 L .48317 .76302 L .654 .726 .902 r
F
.43336 .75664 m .46343 .77148 L .44855 .75345 L F
0 g
.44066 .77625 m
.46343 .77148 L
s
.41516 .63158 m .4151 .69073 L .41505 .68992 L .789 .63 .07 r
F
.41568 .63056 m .41516 .63158 L .41505 .68992 L 0 0 .377 r
F
.42216 .63068 m .42101 .68821 L .42206 .68903 L .908 .63 .503 r
F
.42216 .63068 m .42111 .62986 L .42101 .68821 L F
0 g
.42216 .63068 m
.42261 .63171 L
s
.42216 .63068 m
.42216 .63068 L
s
.41679 .62978 m .41568 .63056 L .41558 .68891 L .403 .215 .509 r
F
.41568 .63056 m .41505 .68992 L .41558 .68891 L 0 0 .377 r
F
0 g
.41516 .63158 m
.41568 .63056 L
s
.41568 .63056 m
.41568 .63056 L
s
.33704 .73572 m .35189 .7416 L .35145 .74885 L .926 .669 .53 r
F
.33704 .73572 m .33749 .72846 L .35189 .7416 L F
0 g
.35189 .7416 m
.35812 .74503 L
s
.36511 .71984 m .35223 .7414 L .37466 .72856 L .654 .726 .902 r
F
.36511 .71984 m .3379 .72833 L .35223 .7414 L F
.4836 .75576 m .48403 .74851 L .49939 .73694 L .346 .168 .491 r
F
0 g
.47357 .75299 m
.48403 .74851 L
s
.46407 .74054 m
.47177 .73774 L
s
.42111 .62986 m .41994 .68784 L .42101 .68821 L .809 .541 .534 r
F
.42111 .62986 m .42005 .62949 L .41994 .68784 L F
0 g
.42111 .62986 m
.42216 .63068 L
s
.41679 .62978 m .41558 .68891 L .41669 .68813 L .403 .215 .509 r
F
.41789 .62945 m .41679 .62978 L .41669 .68813 L .57 .345 .536 r
F
0 g
.41568 .63056 m
.41679 .62978 L
s
.46236 .73315 m .48371 .74828 L .49899 .73677 L .654 .726 .902 r
F
.44927 .73877 m .48371 .74828 L .46236 .73315 L F
.42005 .62949 m .41887 .68771 L .41994 .68784 L .734 .478 .542 r
F
.42005 .62949 m .41897 .62936 L .41887 .68771 L F
0 g
.42005 .62949 m
.42111 .62986 L
s
.41789 .62945 m .41669 .68813 L .41778 .6878 L .57 .345 .536 r
F
.41897 .62936 m .41789 .62945 L .41778 .6878 L .661 .418 .542 r
F
0 g
.41679 .62978 m
.41789 .62945 L
s
.41897 .62936 m .41778 .6878 L .41887 .68771 L .661 .418 .542 r
F
0 g
.41897 .62936 m
.42005 .62949 L
s
.41789 .62945 m
.41897 .62936 L
s
.41883 .72265 m .41806 .74244 L .43416 .74194 L .654 .726 .902 r
F
.41083 .72156 m .41806 .74244 L .41883 .72265 L F
.41083 .72156 m .40207 .74026 L .41806 .74244 L F
.33659 .74297 m .35145 .74885 L .351 .7561 L .926 .669 .53 r
F
.33659 .74297 m .33704 .73572 L .35145 .74885 L F
.36439 .72718 m .35145 .74885 L .374 .73594 L .654 .726 .902 r
F
.36439 .72718 m .33704 .73572 L .35145 .74885 L F
0 g
.35145 .74885 m
.35767 .75228 L
s
.40342 .71919 m .40207 .74026 L .41083 .72156 L .654 .726 .902 r
F
.40342 .71919 m .38727 .73552 L .40207 .74026 L F
.42688 .7224 m .43416 .74194 L .44927 .73877 L F
.41883 .72265 m .43416 .74194 L .42688 .7224 L F
.4836 .75576 m .49939 .73694 L .49897 .74419 L .346 .168 .491 r
F
.48317 .76302 m .4836 .75576 L .49897 .74419 L F
.46214 .74055 m .4836 .75576 L .49897 .74419 L .654 .726 .902 r
F
.44898 .7462 m .4836 .75576 L .46214 .74055 L F
0 g
.47314 .76025 m
.4836 .75576 L
s
.41839 .73001 m .41762 .74989 L .4338 .74938 L .654 .726 .902 r
F
.41035 .7289 m .41762 .74989 L .41839 .73001 L F
.41035 .7289 m .40154 .7477 L .41762 .74989 L F
.4029 .72652 m .40154 .7477 L .41035 .7289 L F
.4029 .72652 m .38667 .74294 L .40154 .7477 L F
.42648 .72975 m .4338 .74938 L .44898 .7462 L F
.41839 .73001 m .4338 .74938 L .42648 .72975 L F
.39712 .7157 m .38727 .73552 L .40342 .71919 L F
.39712 .7157 m .37466 .72856 L .38727 .73552 L F
.36395 .73444 m .351 .7561 L .37355 .7432 L F
.36395 .73444 m .33659 .74297 L .351 .7561 L F
0 g
.351 .7561 m
.37 .76659 L
s
.43444 .72081 m .44927 .73877 L .46236 .73315 L .654 .726 .902 r
F
.42688 .7224 m .44927 .73877 L .43444 .72081 L F
.48317 .76302 m .49897 .74419 L .49854 .75145 L .346 .168 .491 r
F
.46171 .74781 m .48317 .76302 L .49854 .75145 L .654 .726 .902 r
F
.44855 .75345 m .48317 .76302 L .46171 .74781 L F
0 g
.46343 .77148 m
.48317 .76302 L
s
.41795 .73726 m .41718 .75715 L .43336 .75664 L .654 .726 .902 r
F
.40991 .73616 m .41718 .75715 L .41795 .73726 L F
.40991 .73616 m .4011 .75495 L .41718 .75715 L F
.39657 .72302 m .38667 .74294 L .4029 .72652 L F
.39657 .72302 m .374 .73594 L .38667 .74294 L F
.40246 .73378 m .4011 .75495 L .40991 .73616 L F
.40246 .73378 m .38622 .75019 L .4011 .75495 L F
.42605 .73701 m .43336 .75664 L .44855 .75345 L F
.41795 .73726 m .43336 .75664 L .42605 .73701 L F
.43408 .72815 m .44898 .7462 L .46214 .74055 L F
.42648 .72975 m .44898 .7462 L .43408 .72815 L F
.32821 .72083 m .33749 .72846 L .33704 .73572 L .989 .743 .465 r
F
0 g
.34429 .72091 m
.34782 .72524 L
s
.32821 .72083 m .32866 .71357 L .33749 .72846 L .989 .743 .465 r
F
0 g
.33749 .72846 m
.3433 .73376 L
s
.35927 .70996 m .3379 .72833 L .36511 .71984 L .654 .726 .902 r
F
.35927 .70996 m .32912 .71352 L .3379 .72833 L F
.49897 .74419 m .49939 .73694 L .50934 .72303 L .076 0 .398 r
F
0 g
.49083 .74339 m
.49939 .73694 L
s
.47971 .73486 m
.48895 .73151 L
s
.48895 .73151 m
.50829 .72449 L
s
.47255 .72546 m .49899 .73677 L .50889 .72293 L .654 .726 .902 r
F
.46236 .73315 m .49899 .73677 L .47255 .72546 L F
.39235 .71134 m .37466 .72856 L .39712 .7157 L F
.39235 .71134 m .36511 .71984 L .37466 .72856 L F
.44099 .718 m .46236 .73315 L .47255 .72546 L F
.43444 .72081 m .46236 .73315 L .44099 .718 L F
.39613 .73028 m .38622 .75019 L .40246 .73378 L F
.39613 .73028 m .37355 .7432 L .38622 .75019 L F
.43365 .73541 m .44855 .75345 L .46171 .74781 L F
.42605 .73701 m .44855 .75345 L .43365 .73541 L F
.32776 .72808 m .33704 .73572 L .33659 .74297 L .989 .743 .465 r
F
.32776 .72808 m .32821 .72083 L .33704 .73572 L F
.35852 .71725 m .33704 .73572 L .36439 .72718 L .654 .726 .902 r
F
.35852 .71725 m .32821 .72083 L .33704 .73572 L F
0 g
.33704 .73572 m
.34285 .74102 L
s
.49897 .74419 m .50934 .72303 L .50891 .73028 L .076 0 .398 r
F
.49854 .75145 m .49897 .74419 L .50891 .73028 L F
.47238 .73283 m .49897 .74419 L .50891 .73028 L .654 .726 .902 r
F
.46214 .74055 m .49897 .74419 L .47238 .73283 L F
0 g
.4904 .75064 m
.49897 .74419 L
s
.39177 .71864 m .374 .73594 L .39657 .72302 L .654 .726 .902 r
F
.39177 .71864 m .36439 .72718 L .374 .73594 L F
.44066 .72533 m .46214 .74055 L .47238 .73283 L F
.43408 .72815 m .46214 .74055 L .44066 .72533 L F
.35807 .72451 m .33659 .74297 L .36395 .73444 L F
.35807 .72451 m .32776 .72808 L .33659 .74297 L F
0 g
.33659 .74297 m
.351 .7561 L
s
.49854 .75145 m .50891 .73028 L .50849 .73754 L .076 0 .398 r
F
.47195 .74009 m .49854 .75145 L .50849 .73754 L .654 .726 .902 r
F
.46171 .74781 m .49854 .75145 L .47195 .74009 L F
0 g
.48317 .76302 m
.49854 .75145 L
s
.39133 .72589 m .37355 .7432 L .39613 .73028 L .654 .726 .902 r
F
.39133 .72589 m .36395 .73444 L .37355 .7432 L F
.44023 .73259 m .46171 .74781 L .47195 .74009 L F
.43365 .73541 m .46171 .74781 L .44023 .73259 L F
.38943 .70639 m .36511 .71984 L .39235 .71134 L F
.38943 .70639 m .35927 .70996 L .36511 .71984 L F
.42087 .70624 m .41883 .72265 L .4196 .72263 L F
.42171 .70849 m .4196 .72263 L .42688 .7224 L F
.42087 .70624 m .4196 .72263 L .42171 .70849 L F
.4182 .71986 m .41815 .71702 L .42301 .71663 L .666 .427 .548 r
F
.41978 .72222 m .41839 .73001 L .41954 .72997 L .654 .726 .902 r
F
.41831 .71286 m .41815 .71696 L .42299 .71657 L .675 .735 .895 r
F
.4182 .71986 m .42301 .71663 L .42307 .71947 L .666 .427 .548 r
F
.41836 .71574 m .4182 .71986 L .42307 .71947 L .675 .735 .895 r
F
.42009 .71258 m .41915 .72225 L .41978 .72222 L .654 .726 .902 r
F
.41915 .72225 m .41839 .73001 L .41978 .72222 L F
.41893 .72225 m .4182 .71986 L .42307 .71947 L .666 .427 .548 r
F
.41712 .69248 m .41868 .69273 L .41865 .70568 L .751 .492 .541 r
F
.41548 .69142 m .41614 .69201 L .41611 .7049 L .927 .648 .492 r
F
.41505 .68992 m .4151 .69073 L .41508 .70365 L .789 .63 .07 r
F
.41588 .7153 m .41083 .72156 L .41637 .72231 L .654 .726 .902 r
F
.41836 .70948 m .41577 .71364 L .41928 .71111 L F
.41577 .71364 m .41083 .72156 L .41588 .7153 L F
.41577 .71364 m .41588 .7153 L .41928 .71111 L F
.41895 .70741 m .41807 .70896 L .41941 .70782 L F
.41807 .70896 m .41083 .72156 L .41836 .70948 L F
.41807 .70896 m .41836 .70948 L .41941 .70782 L F
.41917 .7064 m .41873 .70721 L .41946 .70654 L F
.41873 .70721 m .41083 .72156 L .41895 .70741 L F
.41873 .70721 m .41895 .70741 L .41946 .70654 L F
.41938 .70582 m .41908 .70636 L .41948 .70584 L F
.41908 .70636 m .41083 .72156 L .41917 .7064 L F
.41908 .70636 m .41917 .7064 L .41948 .70584 L F
.41825 .70572 m .41083 .72156 L .41938 .70582 L F
.41865 .70568 m .41938 .70582 L .41949 .70561 L F
.41825 .70572 m .41938 .70582 L .41865 .70568 L F
.41588 .7153 m .41637 .72231 L .41883 .72265 L F
.41928 .71111 m .41588 .7153 L .41883 .72265 L F
.41825 .72227 m .4182 .71986 L .41893 .72225 L .666 .427 .548 r
F
.41869 .72233 m .41035 .7289 L .41839 .73001 L .654 .726 .902 r
F
.41443 .72175 m .4182 .71986 L .41825 .72227 L .731 .478 .546 r
F
.41888 .71744 m .41556 .72191 L .41869 .72233 L .654 .726 .902 r
F
.41556 .72191 m .41035 .7289 L .41869 .72233 L F
.41343 .72225 m .41443 .72175 L .41826 .7227 L .731 .478 .546 r
F
.41443 .72175 m .41825 .72227 L .41826 .7227 L F
.41337 .71941 m .41815 .71702 L .4182 .71986 L F
.41337 .71941 m .41332 .71657 L .41815 .71702 L F
.41514 .71544 m .41337 .71941 L .4182 .71986 L .675 .735 .895 r
F
.41807 .71602 m .41462 .72178 L .41888 .71744 L .654 .726 .902 r
F
.41462 .72178 m .41035 .7289 L .41556 .72191 L F
.41443 .72175 m .41337 .71941 L .4182 .71986 L .731 .478 .546 r
F
.41462 .72178 m .41556 .72191 L .41888 .71744 L .654 .726 .902 r
F
.41686 .70861 m .41831 .71286 L .41847 .70876 L .675 .735 .895 r
F
.4151 .71256 m .41815 .71696 L .41831 .71286 L F
.41691 .71146 m .41836 .71574 L .41852 .71161 L F
.41799 .71258 m .41789 .7128 L .41906 .71279 L .654 .726 .902 r
F
.40933 .71321 m .39712 .7157 L .40342 .71919 L F
.4196 .70283 m .41296 .70663 L .40933 .71321 L F
.41296 .70663 m .39712 .7157 L .40933 .71321 L F
.4151 .69073 m .41516 .70379 L .41508 .70365 L .989 .721 .392 r
F
.41505 .68992 m .41504 .70305 L .41503 .70288 L .789 .63 .07 r
F
.41505 .68992 m .41508 .70365 L .41504 .70305 L F
.4151 .69073 m .41548 .69142 L .41546 .70432 L .989 .721 .392 r
F
.41558 .68891 m .41505 .68992 L .41503 .70288 L 0 0 .377 r
F
.41765 .7133 m .41715 .71438 L .41841 .71398 L .654 .726 .902 r
F
.41712 .69248 m .41744 .70545 L .4171 .70538 L .751 .492 .541 r
F
.41614 .69201 m .41633 .70501 L .41611 .7049 L .844 .572 .527 r
F
.41614 .69201 m .41712 .69248 L .4171 .70538 L F
.41614 .69201 m .4171 .70538 L .41633 .70501 L F
.41514 .71544 m .4182 .71986 L .41836 .71574 L .675 .735 .895 r
F
.4186 .71414 m .41567 .71939 L .41899 .71449 L .654 .726 .902 r
F
.41567 .71939 m .41035 .7289 L .41571 .71996 L F
.41567 .71939 m .41571 .71996 L .41899 .71449 L F
.4151 .71256 m .41334 .71651 L .41815 .71696 L .675 .735 .895 r
F
.41691 .71146 m .41514 .71544 L .41836 .71574 L F
.41881 .71325 m .41565 .7191 L .41903 .71337 L .654 .726 .902 r
F
.41565 .7191 m .41035 .7289 L .41567 .71939 L F
.41565 .7191 m .41567 .71939 L .41903 .71337 L F
.4196 .70283 m .41411 .70454 L .41296 .70663 L F
.41512 .70595 m .41258 .70568 L .41316 .70667 L .675 .735 .895 r
F
.4196 .70283 m .40342 .71919 L .41083 .72156 L .654 .726 .902 r
F
.41633 .70501 m .41635 .70662 L .41611 .7049 L .844 .572 .527 r
F
.41751 .70715 m .41538 .70819 L .41686 .70861 L .675 .735 .895 r
F
.41538 .70819 m .41214 .71172 L .4151 .71256 L F
.41594 .70924 m .41319 .70952 L .41415 .71038 L F
.41538 .70819 m .4151 .71256 L .41686 .70861 L F
.4164 .70944 m .41632 .70941 L .41619 .70654 L .844 .572 .527 r
F
.41668 .70677 m .41538 .70819 L .41751 .70715 L .675 .735 .895 r
F
.41715 .71438 m .41556 .71778 L .41768 .71533 L .654 .726 .902 r
F
.41686 .70861 m .4151 .71256 L .41831 .71286 L .675 .735 .895 r
F
.41757 .70998 m .41542 .71104 L .41691 .71146 L F
.41853 .70717 m .41686 .70861 L .41847 .70876 L F
.41744 .70545 m .41865 .70568 L .41865 .70719 L .751 .492 .541 r
F
.41744 .70545 m .41865 .70719 L .41787 .70707 L F
.41862 .70465 m .41757 .70703 L .41853 .70717 L .675 .735 .895 r
F
.41757 .70703 m .41686 .70861 L .41853 .70717 L F
.41787 .70707 m .41865 .70719 L .41865 .71 L .751 .492 .541 r
F
.41755 .70983 m .41864 .71271 L .41761 .71251 L F
.41916 .71009 m .41694 .71234 L .41708 .71241 L .654 .726 .902 r
F
.41799 .71258 m .41708 .71241 L .41789 .7128 L F
.41916 .71009 m .41708 .71241 L .41799 .71258 L F
.41868 .70749 m .41691 .71146 L .41852 .71161 L .675 .735 .895 r
F
.41755 .70983 m .41865 .71 L .41864 .71271 L .751 .492 .541 r
F
.41715 .71438 m .41768 .71533 L .41841 .71398 L .654 .726 .902 r
F
.41789 .7128 m .41765 .7133 L .41881 .71325 L F
.41765 .7133 m .41841 .71398 L .41881 .71325 L F
.41831 .71286 m .42299 .71657 L .42153 .7126 L .675 .735 .895 r
F
.42023 .70554 m .41883 .72265 L .4206 .70551 L .654 .726 .902 r
F
.41949 .70561 m .41948 .70582 L .42023 .70554 L F
.41948 .70582 m .41883 .72265 L .42023 .70554 L F
.42051 .70675 m .41883 .72265 L .42087 .70624 L F
.41847 .70876 m .42153 .7126 L .42008 .70862 L .675 .735 .895 r
F
.42049 .70966 m .42014 .71148 L .42166 .71108 L F
.41948 .70584 m .41917 .7064 L .41946 .70654 L .654 .726 .902 r
F
.41949 .70561 m .41938 .70582 L .41948 .70584 L F
.42052 .70693 m .42008 .70862 L .42159 .70822 L .675 .735 .895 r
F
.419 .70565 m .42023 .70554 L .42023 .70697 L .642 .403 .542 r
F
.419 .70565 m .42023 .70697 L .41943 .70708 L F
.41862 .70465 m .41951 .70707 L .42052 .70693 L .675 .735 .895 r
F
.41951 .70707 m .42008 .70862 L .42052 .70693 L F
.41943 .70708 m .42023 .70697 L .42022 .70978 L .642 .403 .542 r
F
.41955 .70987 m .41961 .71004 L .42022 .70978 L .675 .735 .895 r
F
.41961 .71004 m .42014 .71148 L .42049 .70966 L F
.42022 .71374 m .42021 .71559 L .42161 .71547 L F
.41852 .71161 m .42021 .71559 L .42022 .71374 L F
.41852 .71161 m .41836 .71574 L .42021 .71559 L F
.41979 .72222 m .41954 .72997 L .4207 .7222 L .654 .726 .902 r
F
.41941 .70782 m .41836 .70948 L .41928 .71111 L F
.42058 .70565 m .41883 .72265 L .42063 .70561 L F
.41847 .70876 m .41831 .71286 L .42153 .7126 L .675 .735 .895 r
F
.41852 .71161 m .42161 .71547 L .42014 .71148 L F
.42009 .71258 m .42009 .71262 L .4201 .71261 L .654 .726 .902 r
F
.42009 .71262 m .41954 .72997 L .4201 .71261 L F
.41826 .7227 m .41893 .72225 L .42312 .7223 L .666 .427 .548 r
F
.42197 .69154 m .4224 .69086 L .42237 .70402 L .077 0 .416 r
F
.42125 .70516 m .42688 .7224 L .42146 .70508 L .654 .726 .902 r
F
.42056 .70542 m .42063 .70561 L .42125 .70516 L F
.42063 .70561 m .42688 .7224 L .42125 .70516 L F
.42127 .6921 m .42197 .69154 L .42195 .70465 L .359 .182 .499 r
F
.42156 .70521 m .42199 .70659 L .4221 .70586 L .654 .726 .902 r
F
.42146 .70508 m .42152 .70528 L .42156 .70521 L F
.42153 .7126 m .42299 .71657 L .4273 .71542 L .675 .735 .895 r
F
.4221 .70586 m .43067 .7216 L .42547 .70994 L .654 .726 .902 r
F
.42721 .71522 m .4273 .71542 L .42753 .71536 L .675 .735 .895 r
F
.4221 .70586 m .42688 .7224 L .43067 .7216 L .654 .726 .902 r
F
.42153 .7126 m .4273 .71542 L .42721 .71522 L .675 .735 .895 r
F
.42197 .69154 m .42237 .70402 L .42204 .70451 L .077 0 .416 r
F
.42014 .71148 m .42161 .71547 L .42465 .71467 L .675 .735 .895 r
F
.42199 .70659 m .42688 .7224 L .4221 .70586 L .654 .726 .902 r
F
.42152 .70528 m .42688 .7224 L .42156 .70521 L F
.42008 .70862 m .42153 .7126 L .42456 .71179 L .675 .735 .895 r
F
.42022 .71146 m .42465 .71467 L .42166 .71108 L F
.42014 .71148 m .42019 .71151 L .42022 .71146 L F
.42019 .71151 m .42465 .71467 L .42022 .71146 L F
.4196 .70283 m .43444 .72081 L .44099 .718 L .654 .726 .902 r
F
.42235 .70534 m .42392 .70673 L .42458 .70575 L .675 .735 .895 r
F
.42059 .71243 m .42172 .71392 L .42133 .7121 L F
.42063 .70561 m .42051 .70675 L .42087 .70624 L .654 .726 .902 r
F
.4206 .70551 m .42058 .70565 L .42063 .70561 L F
.42133 .7065 m .42159 .70822 L .4229 .70758 L .675 .735 .895 r
F
.42046 .70546 m .42124 .70653 L .42061 .70681 L .519 .305 .529 r
F
.41862 .70465 m .42047 .70687 L .42133 .7065 L .675 .735 .895 r
F
.42047 .70687 m .42159 .70822 L .42133 .7065 L F
.42046 .70546 m .42125 .70516 L .42124 .70653 L .519 .305 .529 r
F
.42008 .70862 m .42456 .71179 L .42159 .70822 L .675 .735 .895 r
F
.42195 .70596 m .42392 .70673 L .42235 .70534 L F
.42204 .70451 m .42207 .70858 L .42195 .70465 L .077 0 .416 r
F
.42152 .70943 m .42166 .71108 L .42298 .71043 L .675 .735 .895 r
F
.42022 .71257 m .4206 .71363 L .42087 .71306 L .654 .726 .902 r
F
.42022 .71257 m .42087 .71306 L .42052 .71254 L F
.42009 .71258 m .4201 .71261 L .42022 .71257 L F
.41906 .71267 m .41839 .73001 L .42009 .71258 L F
.41918 .71266 m .42022 .71257 L .42022 .71259 L .642 .403 .542 r
F
.4196 .71267 m .4202 .71432 L .42042 .71256 L .675 .735 .895 r
F
.42133 .7121 m .42172 .71392 L .42304 .71327 L F
.42307 .71947 m .42758 .71542 L .42763 .71826 L .593 .369 .546 r
F
.42307 .71947 m .42301 .71663 L .42758 .71542 L F
.42161 .71547 m .42307 .71947 L .42763 .71826 L .675 .735 .895 r
F
.4234 .72206 m .42307 .71947 L .42763 .71826 L .593 .369 .546 r
F
.4207 .7222 m .41954 .72997 L .42364 .7221 L .654 .726 .902 r
F
.42312 .7223 m .42312 .72212 L .4234 .72206 L .593 .369 .546 r
F
.42312 .72212 m .42307 .71947 L .4234 .72206 L F
.42182 .71468 m .42406 .72192 L .42256 .71555 L .654 .726 .902 r
F
.42406 .72192 m .42648 .72975 L .4243 .72187 L F
.42406 .72192 m .4243 .72187 L .42256 .71555 L F
.42182 .71468 m .42256 .71555 L .42185 .7145 L F
.4217 .71429 m .42182 .71468 L .42185 .7145 L F
.4202 .71432 m .42471 .71751 L .42172 .71392 L .675 .735 .895 r
F
.42185 .7145 m .42256 .71555 L .42199 .71352 L .654 .726 .902 r
F
.42166 .71831 m .42312 .7223 L .42652 .7214 L .675 .735 .895 r
F
.42652 .7214 m .42763 .71826 L .42769 .72109 L .593 .369 .546 r
F
.4243 .72187 m .42648 .72975 L .42821 .72105 L .654 .726 .902 r
F
.42312 .7223 m .4234 .72206 L .42652 .7214 L .593 .369 .546 r
F
.4234 .72206 m .42763 .71826 L .42652 .7214 L F
.42821 .72105 m .42648 .72975 L .43408 .72815 L .654 .726 .902 r
F
.42568 .72017 m .42652 .7214 L .42769 .72109 L .675 .735 .895 r
F
.424 .71769 m .42769 .72109 L .42471 .71751 L F
.42256 .71555 m .4243 .72187 L .42652 .7214 L .654 .726 .902 r
F
.42026 .71216 m .42149 .71398 L .42172 .71392 L .675 .735 .895 r
F
.42301 .70301 m .44937 .70953 L .45064 .70445 L .654 .726 .902 r
F
.42197 .69154 m .42204 .70451 L .42195 .70465 L .077 0 .416 r
F
.42409 .70384 m .44608 .71415 L .44937 .70953 L .654 .726 .902 r
F
.4196 .70283 m .42671 .70587 L .42409 .70384 L F
.42671 .70587 m .44608 .71415 L .42409 .70384 L F
.42206 .68903 m .42101 .68821 L .42099 .70144 L .908 .63 .503 r
F
.42127 .6921 m .42195 .70465 L .4214 .70505 L .359 .182 .499 r
F
.4196 .70283 m .4226 .70351 L .42236 .70297 L .654 .726 .902 r
F
.42127 .6921 m .4214 .70505 L .42125 .70516 L .359 .182 .499 r
F
.41862 .70465 m .42256 .70398 L .42257 .7039 L .675 .735 .895 r
F
.42239 .70303 m .42204 .7035 L .42238 .70426 L .985 .728 .345 r
F
.4224 .69086 m .42249 .70326 L .4224 .70385 L 0 0 .138 r
F
.42239 .70303 m .42238 .70426 L .42249 .70326 L .985 .728 .345 r
F
.4196 .70283 m .44099 .718 L .44608 .71415 L .654 .726 .902 r
F
.4224 .70385 m .42249 .70451 L .42241 .70501 L 0 0 .138 r
F
.42159 .70822 m .42719 .7105 L .4229 .70758 L .675 .735 .895 r
F
.42061 .70681 m .42124 .70934 L .42092 .70948 L .519 .305 .529 r
F
.42159 .70822 m .42456 .71179 L .42719 .7105 L .675 .735 .895 r
F
.42195 .70877 m .42298 .71043 L .42401 .70958 L F
.42046 .70546 m .42123 .71219 L .42057 .71244 L .519 .305 .529 r
F
.42023 .70554 m .42043 .70969 L .42022 .70978 L F
.41868 .70749 m .42131 .70929 L .42195 .70877 L .675 .735 .895 r
F
.42131 .70929 m .42298 .71043 L .42195 .70877 L F
.4224 .70385 m .4224 .70511 L .42237 .70402 L 0 0 .138 r
F
.42194 .70597 m .4229 .70758 L .42196 .70596 L .675 .735 .895 r
F
.4213 .70648 m .42152 .70663 L .42194 .70597 L F
.42152 .70663 m .4229 .70758 L .42194 .70597 L F
.42205 .70581 m .42237 .70811 L .42207 .70858 L .077 0 .416 r
F
.42204 .70451 m .42215 .70566 L .42205 .70581 L F
.42196 .70596 m .42221 .7064 L .42226 .70608 L .675 .735 .895 r
F
.42215 .70566 m .42237 .70811 L .42205 .70581 L .077 0 .416 r
F
.42226 .70608 m .4229 .70758 L .42392 .70673 L .675 .735 .895 r
F
.4229 .70758 m .42923 .70881 L .42392 .70673 L F
.42255 .70683 m .42492 .70752 L .42475 .70646 L F
.4224 .70787 m .42239 .70795 L .42238 .70525 L 0 0 .138 r
F
.42158 .70626 m .42194 .70597 L .42194 .70878 L .359 .182 .499 r
F
.42207 .70858 m .42198 .70872 L .42195 .70465 L .077 0 .416 r
F
.42061 .70681 m .42124 .70653 L .42124 .70934 L .519 .305 .529 r
F
.41868 .70749 m .42245 .70751 L .42255 .70683 L .675 .735 .895 r
F
.42245 .70751 m .42492 .70752 L .42255 .70683 L F
.4224 .70511 m .4224 .70787 L .42238 .70525 L 0 0 .138 r
F
.42225 .70889 m .42401 .70958 L .42236 .70817 L .675 .735 .895 r
F
.4224 .70787 m .4224 .71079 L .42239 .70795 L 0 0 .138 r
F
.4224 .70511 m .42238 .70525 L .42237 .70402 L F
.42221 .7064 m .4229 .70758 L .42226 .70608 L .675 .735 .895 r
F
.41862 .70465 m .4213 .70648 L .42196 .70596 L F
.4214 .70505 m .42195 .70465 L .42194 .70597 L .359 .182 .499 r
F
.4214 .70505 m .42194 .70597 L .42158 .70626 L F
.42172 .70896 m .42194 .70878 L .42193 .71168 L F
.4214 .70505 m .42194 .70878 L .42172 .70896 L F
.42236 .70817 m .42401 .70958 L .42467 .70859 L .675 .735 .895 r
F
.42266 .70888 m .42481 .70929 L .42422 .7083 L F
.4224 .70787 m .42247 .71015 L .4224 .71064 L 0 0 .138 r
F
.4224 .70385 m .42249 .70326 L .42249 .70451 L F
.42025 .69253 m .42125 .70516 L .42046 .70546 L .519 .305 .529 r
F
.41862 .70465 m .42257 .7039 L .42194 .70342 L .675 .735 .895 r
F
.42204 .70451 m .42237 .7053 L .42215 .70566 L .077 0 .416 r
F
.41868 .69273 m .42023 .70554 L .419 .70565 L .642 .403 .542 r
F
.4196 .70283 m .41825 .70572 L .41949 .70561 L .654 .726 .902 r
F
.41862 .70465 m .42458 .70575 L .42484 .70469 L .675 .735 .895 r
F
.42178 .7033 m .42098 .70551 L .42138 .70581 L .908 .63 .503 r
F
.42204 .70226 m .42172 .70607 L .42203 .7063 L F
.42204 .70451 m .42237 .70402 L .42237 .7053 L .077 0 .416 r
F
.4196 .70283 m .42056 .70542 L .42146 .70508 L .654 .726 .902 r
F
.4196 .70283 m .41949 .70561 L .4206 .70551 L F
.41862 .70465 m .42484 .70469 L .42472 .70395 L .675 .735 .895 r
F
.42409 .70384 m .44937 .70953 L .42301 .70301 L .654 .726 .902 r
F
.42406 .70373 m .42472 .70395 L .42467 .70362 L .675 .735 .895 r
F
.42238 .70426 m .42247 .70448 L .42249 .70326 L .985 .728 .345 r
F
.41862 .70465 m .42472 .70395 L .42406 .70373 L .675 .735 .895 r
F
.42018 .72126 m .41795 .73726 L .41949 .73721 L .654 .726 .902 r
F
.42139 .72451 m .41949 .73721 L .42605 .73701 L F
.42018 .72126 m .41949 .73721 L .42139 .72451 L F
.42547 .70994 m .43067 .7216 L .43444 .72081 L F
.42769 .72109 m .42763 .71826 L .43159 .71631 L .499 .296 .536 r
F
.42763 .71826 m .42758 .71542 L .43153 .71347 L F
.42763 .71826 m .43153 .71347 L .43159 .71631 L F
.42465 .71467 m .42763 .71826 L .43159 .71631 L .675 .735 .895 r
F
.42769 .72109 m .43159 .71631 L .43164 .71915 L .499 .296 .536 r
F
.42471 .71751 m .42769 .72109 L .43164 .71915 L .675 .735 .895 r
F
.42471 .71751 m .43164 .71915 L .42734 .71621 L F
.42388 .71343 m .43408 .72815 L .44066 .72533 L .654 .726 .902 r
F
.42207 .70858 m .42237 .70811 L .42236 .71105 L .077 0 .416 r
F
.4201 .71261 m .42052 .71375 L .42022 .71257 L .654 .726 .902 r
F
.41836 .71574 m .42307 .71947 L .42161 .71547 L .675 .735 .895 r
F
.42052 .71375 m .42648 .72975 L .4206 .71363 L .654 .726 .902 r
F
.42052 .71375 m .4206 .71363 L .42022 .71257 L F
.42364 .7221 m .41954 .72997 L .42648 .72975 L F
.41893 .72225 m .42307 .71947 L .42312 .72212 L .666 .427 .548 r
F
.42155 .7165 m .4207 .7222 L .42364 .7221 L .654 .726 .902 r
F
.42184 .72148 m .42605 .73701 L .43081 .73601 L F
.41893 .72225 m .42312 .72212 L .42312 .7223 L .666 .427 .548 r
F
.41826 .7227 m .41825 .72227 L .41893 .72225 L F
.4201 .71261 m .41979 .72222 L .42155 .7165 L .654 .726 .902 r
F
.41842 .71858 m .41826 .7227 L .42312 .7223 L .675 .735 .895 r
F
.42099 .72008 m .4217 .72246 L .42184 .72148 L .654 .726 .902 r
F
.4217 .72246 m .42605 .73701 L .42184 .72148 L F
.42172 .71392 m .42734 .71621 L .42304 .71327 L .675 .735 .895 r
F
.42128 .71265 m .42618 .71859 L .42176 .71193 L .654 .726 .902 r
F
.4224 .71079 m .4224 .71773 L .42238 .71093 L 0 0 .138 r
F
.42189 .72118 m .43081 .73601 L .42689 .72724 L .654 .726 .902 r
F
.41979 .72222 m .4207 .7222 L .42155 .7165 L F
.41842 .71858 m .42312 .7223 L .42166 .71831 L .675 .735 .895 r
F
.42099 .72008 m .42184 .72148 L .42189 .72118 L .654 .726 .902 r
F
.42184 .72148 m .43081 .73601 L .42189 .72118 L F
.42208 .71146 m .42236 .71105 L .42235 .71808 L .077 0 .416 r
F
.42421 .72124 m .43365 .73541 L .44023 .73259 L .654 .726 .902 r
F
.42158 .7163 m .42648 .72975 L .42182 .71468 L F
.42151 .71932 m .42604 .72533 L .42421 .72124 L F
.42604 .72533 m .43365 .73541 L .42421 .72124 L F
.42153 .7126 m .42753 .71536 L .42456 .71179 L .675 .735 .895 r
F
.42166 .71108 m .42465 .71467 L .42729 .71337 L F
.42166 .71108 m .42729 .71337 L .42298 .71043 L F
.42291 .71109 m .42407 .71242 L .42473 .71143 L F
.41874 .71033 m .42304 .71327 L .42365 .71277 L F
.42337 .71215 m .42365 .71277 L .42407 .71242 L F
.41874 .71033 m .42365 .71277 L .42337 .71215 L F
.42049 .70966 m .42166 .71108 L .42133 .7093 L F
.42092 .70948 m .42124 .70934 L .42123 .71219 L .519 .305 .529 r
F
.41955 .70987 m .41852 .71161 L .42014 .71148 L .675 .735 .895 r
F
.41865 .70719 m .4188 .70998 L .41865 .71 L .642 .403 .542 r
F
.41865 .70568 m .4187 .70718 L .41865 .70719 L F
.41946 .70654 m .41895 .70741 L .41941 .70782 L .654 .726 .902 r
F
.41852 .70721 m .41847 .70876 L .41951 .70707 L .675 .735 .895 r
F
.4187 .70718 m .4188 .70998 L .41865 .70719 L .642 .403 .542 r
F
.41951 .70707 m .41847 .70876 L .42008 .70862 L .675 .735 .895 r
F
.41858 .71001 m .41852 .71161 L .41955 .70987 L F
.41863 .71974 m .41795 .73726 L .41958 .71966 L .654 .726 .902 r
F
.41906 .71279 m .41881 .71325 L .41903 .71337 L F
.419 .70565 m .41918 .71266 L .41865 .70568 L .642 .403 .542 r
F
.41932 .72253 m .41795 .73726 L .42018 .72126 L .654 .726 .902 r
F
.42618 .71859 m .43408 .72815 L .42388 .71343 L F
.42166 .71831 m .42652 .7214 L .42568 .72017 L .675 .735 .895 r
F
.42335 .71932 m .44023 .73259 L .44535 .72872 L .654 .726 .902 r
F
.42122 .71922 m .42187 .75003 L .42117 .75059 L .359 .182 .499 r
F
.4206 .71363 m .42158 .7163 L .42122 .71273 L .654 .726 .902 r
F
.42193 .71158 m .42337 .71215 L .42261 .71104 L .675 .735 .895 r
F
.43164 .71915 m .43159 .71631 L .43466 .71377 L .36 .19 .511 r
F
.42456 .71179 m .42753 .71536 L .43147 .71343 L .675 .735 .895 r
F
.42465 .71467 m .43159 .71631 L .42729 .71337 L F
.43164 .71915 m .43466 .71377 L .43472 .7166 L .36 .19 .511 r
F
.42734 .71621 m .43164 .71915 L .43472 .7166 L .675 .735 .895 r
F
.42734 .71621 m .43472 .7166 L .42939 .71451 L F
.42304 .71327 m .42734 .71621 L .42939 .71451 L F
.42304 .71327 m .42939 .71451 L .42407 .71242 L F
.42229 .71142 m .44066 .72533 L .44578 .72146 L .654 .726 .902 r
F
.41906 .71039 m .42193 .71158 L .42261 .71104 L .675 .735 .895 r
F
.41918 .71266 m .41889 .71269 L .41865 .70568 L .642 .403 .542 r
F
.41874 .71033 m .41912 .71048 L .41906 .71039 L .675 .735 .895 r
F
.41939 .71058 m .42022 .71091 L .42022 .71257 L .642 .403 .542 r
F
.41911 .70993 m .42022 .71091 L .41939 .71058 L F
.41911 .70993 m .42022 .70978 L .42022 .71091 L F
.41912 .71048 m .42193 .71158 L .41906 .71039 L .675 .735 .895 r
F
.42193 .71159 m .42193 .71168 L .42147 .71195 L .359 .182 .499 r
F
.42043 .70969 m .42057 .71244 L .42022 .70978 L .519 .305 .529 r
F
.41916 .71009 m .42168 .71187 L .42229 .71142 L .654 .726 .902 r
F
.42168 .71187 m .44066 .72533 L .42229 .71142 L F
.4202 .71432 m .42166 .71831 L .42471 .71751 L .675 .735 .895 r
F
.42123 .71219 m .42144 .71906 L .42122 .71922 L .359 .182 .499 r
F
.42125 .70516 m .42134 .71211 L .42123 .71219 L F
.42134 .71211 m .42144 .71906 L .42123 .71219 L F
.42144 .71906 m .42187 .75003 L .42122 .71922 L F
.42192 .71871 m .42172 .71947 L .42335 .71932 L .654 .726 .902 r
F
.42057 .71244 m .42068 .71943 L .42022 .71257 L .519 .305 .529 r
F
.42068 .71943 m .42117 .75059 L .42039 .71953 L F
.41899 .71449 m .41807 .71602 L .41888 .71744 L .654 .726 .902 r
F
.41858 .71445 m .41842 .71858 L .42166 .71831 L .675 .735 .895 r
F
.42068 .71943 m .42039 .71953 L .42022 .71257 L .519 .305 .529 r
F
.42132 .71919 m .42099 .72008 L .42151 .71932 L .654 .726 .902 r
F
.41858 .71445 m .42166 .71831 L .4202 .71432 L .675 .735 .895 r
F
.41918 .71273 m .42022 .71259 L .42021 .7196 L .642 .403 .542 r
F
.41872 .71735 m .4205 .71949 L .42132 .71919 L .654 .726 .902 r
F
.4205 .71949 m .42099 .72008 L .42132 .71919 L F
.41872 .71735 m .4213 .71917 L .42192 .71871 L F
.4213 .71917 m .42172 .71947 L .42192 .71871 L F
.42099 .72008 m .42689 .72724 L .42151 .71932 L F
.42689 .72724 m .43365 .73541 L .42604 .72533 L F
.42689 .72724 m .42604 .72533 L .42151 .71932 L F
.42161 .71547 m .42763 .71826 L .42465 .71467 L .675 .735 .895 r
F
.4224 .71079 m .42246 .71732 L .4224 .71773 L 0 0 .138 r
F
.42208 .71146 m .422 .71158 L .42198 .70872 L .077 0 .416 r
F
.41874 .71033 m .42232 .71099 L .42272 .71035 L .675 .735 .895 r
F
.4224 .71064 m .42248 .71029 L .4224 .71079 L 0 0 .138 r
F
.42247 .71015 m .42248 .71029 L .4224 .71064 L F
.42241 .70997 m .42233 .71701 L .42248 .71012 L .985 .728 .345 r
F
.42166 .71831 m .42568 .72017 L .424 .71769 L .675 .735 .895 r
F
.42568 .72017 m .42769 .72109 L .424 .71769 L F
.42256 .71555 m .42652 .7214 L .42821 .72105 L .654 .726 .902 r
F
.4223 .71815 m .44535 .72872 L .44866 .72408 L F
.42042 .71256 m .4202 .71432 L .42149 .71398 L .675 .735 .895 r
F
.42052 .71254 m .42087 .71306 L .42114 .71249 L .654 .726 .902 r
F
.4206 .71363 m .42122 .71273 L .42114 .71249 L F
.42057 .71244 m .42123 .71219 L .42122 .71922 L .519 .305 .529 r
F
.42068 .71943 m .42122 .71922 L .42117 .75059 L F
.42057 .71244 m .42122 .71922 L .42068 .71943 L F
.42235 .71094 m .42236 .71105 L .42208 .71136 L .077 0 .416 r
F
.43159 .71631 m .43153 .71347 L .43461 .71093 L .36 .19 .511 r
F
.43159 .71631 m .43461 .71093 L .43466 .71377 L F
.42729 .71337 m .43159 .71631 L .43466 .71377 L .675 .735 .895 r
F
.42456 .71179 m .43147 .71343 L .42719 .7105 L F
.42729 .71337 m .43466 .71377 L .42934 .71167 L F
.42298 .71043 m .42729 .71337 L .42934 .71167 L F
.42939 .71451 m .43472 .7166 L .43671 .71363 L F
.43472 .7166 m .43466 .71377 L .43665 .71079 L .12 .011 .445 r
F
.43472 .7166 m .43665 .71079 L .43671 .71363 L F
.42939 .71451 m .43671 .71363 L .43072 .71253 L .675 .735 .895 r
F
.42407 .71242 m .42939 .71451 L .43072 .71253 L F
.42407 .71242 m .43072 .71253 L .42473 .71143 L F
.42251 .71084 m .44578 .72146 L .44909 .71682 L .654 .726 .902 r
F
.42208 .71136 m .42236 .71105 L .42208 .71146 L .077 0 .416 r
F
.41916 .71009 m .42215 .71136 L .42251 .71084 L .654 .726 .902 r
F
.42261 .71104 m .42337 .71215 L .42291 .71109 L .675 .735 .895 r
F
.42337 .71215 m .42407 .71242 L .42291 .71109 L F
.42215 .71136 m .44578 .72146 L .42251 .71084 L .654 .726 .902 r
F
.42533 .71769 m .44866 .72408 L .44992 .71898 L F
.41874 .71033 m .42254 .70968 L .42256 .70951 L .675 .735 .895 r
F
.42139 .70963 m .42166 .71108 L .42152 .70943 L F
.4214 .70505 m .42193 .71159 L .42147 .71195 L .359 .182 .499 r
F
.42195 .70465 m .422 .71158 L .42193 .71168 L .077 0 .416 r
F
.42207 .70858 m .42208 .71146 L .42198 .70872 L F
.42133 .7093 m .42139 .70963 L .42152 .70943 L .675 .735 .895 r
F
.41874 .71033 m .42256 .70951 L .42203 .70911 L F
.42167 .70884 m .42098 .70832 L .42097 .7155 L .908 .63 .503 r
F
.41872 .71735 m .42192 .71871 L .4223 .71815 L .654 .726 .902 r
F
.42206 .71852 m .422 .71859 L .42193 .71168 L .077 0 .416 r
F
.42208 .71146 m .42235 .71808 L .42212 .71842 L F
.42236 .71105 m .42237 .71794 L .42235 .71808 L 0 0 .138 r
F
.4224 .71773 m .42239 .71784 L .42238 .71093 L F
.42193 .71168 m .422 .71859 L .42192 .71871 L .077 0 .416 r
F
.42172 .71392 m .42471 .71751 L .42734 .71621 L .675 .735 .895 r
F
.42176 .71193 m .42618 .71859 L .42388 .71343 L .654 .726 .902 r
F
.42114 .71249 m .4217 .71429 L .42199 .71352 L F
.4217 .71429 m .42185 .7145 L .42199 .71352 L F
.42147 .71202 m .42193 .71168 L .42192 .71871 L .359 .182 .499 r
F
.42155 .71898 m .42192 .71871 L .42187 .75003 L F
.42158 .7163 m .42182 .71468 L .42122 .71273 L .654 .726 .902 r
F
.42147 .71202 m .42192 .71871 L .42155 .71898 L .359 .182 .499 r
F
.42302 .71791 m .42342 .7184 L .42429 .71808 L .654 .726 .902 r
F
.42155 .71898 m .42144 .71906 L .42134 .71211 L .359 .182 .499 r
F
.4214 .71207 m .42134 .71211 L .42125 .70516 L F
.42155 .71898 m .42134 .71211 L .4214 .71207 L F
.42719 .7105 m .43147 .71343 L .43453 .7109 L .675 .735 .895 r
F
.42934 .71167 m .43466 .71377 L .43665 .71079 L F
.42298 .71043 m .42934 .71167 L .42401 .70958 L F
.43466 .71377 m .43461 .71093 L .43659 .70795 L .12 .011 .445 r
F
.43671 .71363 m .43665 .71079 L .43741 .70759 L 0 0 .254 r
F
.43671 .71363 m .43741 .70759 L .43747 .71043 L F
.43072 .71253 m .43671 .71363 L .43747 .71043 L .675 .735 .895 r
F
.43466 .71377 m .43659 .70795 L .43665 .71079 L .12 .011 .445 r
F
.42719 .7105 m .43453 .7109 L .42923 .70881 L .675 .735 .895 r
F
.42934 .71167 m .43665 .71079 L .43066 .70969 L F
.43072 .71253 m .43747 .71043 L .43123 .7104 L F
.42401 .70958 m .42934 .71167 L .43066 .70969 L F
.42473 .71143 m .43072 .71253 L .43123 .7104 L F
.42473 .71143 m .43123 .7104 L .42498 .71036 L F
.42378 .71033 m .44909 .71682 L .45036 .71172 L .654 .726 .902 r
F
.42155 .71898 m .42187 .75003 L .42144 .71906 L .359 .182 .499 r
F
.422 .71158 m .42206 .71852 L .42193 .71168 L .077 0 .416 r
F
.42018 .72126 m .42139 .72451 L .42099 .72008 L .654 .726 .902 r
F
.42139 .72451 m .42605 .73701 L .4217 .72246 L F
.42139 .72451 m .4217 .72246 L .42099 .72008 L F
.42238 .71093 m .42239 .71784 L .42236 .71105 L 0 0 .138 r
F
.42192 .71871 m .44535 .72872 L .4223 .71815 L .654 .726 .902 r
F
.42239 .71784 m .42241 .74856 L .42237 .71794 L 0 0 .138 r
F
.42239 .71784 m .42237 .71794 L .42236 .71105 L F
.43054 .70684 m .4365 .70794 L .43726 .70475 L .675 .735 .895 r
F
.43105 .70472 m .43726 .70475 L .43675 .70156 L F
.43741 .70759 m .43736 .70475 L .43684 .70155 L .858 .66 .125 r
F
.4224 .69086 m .4224 .70385 L .42237 .70402 L 0 0 .138 r
F
.4235 .70237 m .45064 .70445 L .44978 .69926 L .654 .726 .902 r
F
.4196 .70283 m .42561 .70314 L .4235 .70237 L F
.42561 .70314 m .45064 .70445 L .4235 .70237 L F
.42101 .68821 m .41994 .68784 L .41992 .70105 L .809 .541 .534 r
F
.4229 .70758 m .42719 .7105 L .42923 .70881 L .675 .735 .895 r
F
.42392 .70673 m .42923 .70881 L .43054 .70684 L F
.42467 .70859 m .43066 .70969 L .43117 .70756 L F
.42467 .70859 m .43117 .70756 L .42492 .70752 L F
.42481 .70929 m .42971 .70626 L .42422 .7083 L F
.42252 .70904 m .42506 .70939 L .4278 .70739 L .654 .726 .902 r
F
.42147 .71202 m .4214 .71207 L .42125 .70516 L .359 .182 .499 r
F
.4224 .71079 m .42238 .71093 L .42237 .70402 L 0 0 .138 r
F
.42237 .70402 m .42238 .71093 L .42236 .71105 L F
.42207 .70858 m .42235 .71094 L .42208 .71136 L .077 0 .416 r
F
.41874 .71033 m .42498 .71036 L .42486 .70961 L .675 .735 .895 r
F
.42401 .70958 m .43066 .70969 L .42467 .70859 L F
.42422 .7094 m .42486 .70961 L .42481 .70929 L F
.41874 .71033 m .42486 .70961 L .42422 .7094 L F
.42208 .70234 m .42204 .7035 L .42239 .70303 L .985 .728 .345 r
F
.42208 .70234 m .42204 .70226 L .42204 .7035 L F
.4224 .69086 m .42251 .69006 L .42249 .70326 L 0 0 .138 r
F
.42251 .69006 m .42239 .70303 L .42249 .70326 L .985 .728 .345 r
F
.42358 .70159 m .44978 .69926 L .44687 .69432 L .654 .726 .902 r
F
.4196 .70283 m .42651 .70201 L .42358 .70159 L F
.42651 .70201 m .44978 .69926 L .42358 .70159 L F
.41872 .71735 m .42429 .71808 L .42368 .71761 L F
.41936 .71968 m .42015 .75103 L .41912 .7197 L .642 .403 .542 r
F
.41958 .71966 m .41932 .72253 L .42018 .72126 L .654 .726 .902 r
F
.41918 .71273 m .42021 .7196 L .41936 .71968 L .642 .403 .542 r
F
.41864 .71271 m .42015 .75103 L .41857 .75123 L F
.42251 .69006 m .42208 .70234 L .42239 .70303 L .985 .728 .345 r
F
.42206 .68903 m .4218 .70207 L .42204 .70226 L .908 .63 .503 r
F
.42251 .69006 m .42204 .70226 L .42208 .70234 L .985 .728 .345 r
F
.4196 .70283 m .43579 .68645 L .42838 .68408 L .654 .726 .902 r
F
.4196 .70283 m .4421 .68995 L .43579 .68645 L F
.4196 .70283 m .44687 .69432 L .4421 .68995 L F
.4224 .70385 m .42244 .70757 L .4224 .70787 L 0 0 .138 r
F
.42235 .70702 m .4224 .70713 L .42247 .70448 L .985 .728 .345 r
F
.42201 .70625 m .42475 .70646 L .42417 .70546 L .675 .735 .895 r
F
.4214 .70505 m .42147 .71202 L .42125 .70516 L .359 .182 .499 r
F
.42046 .70546 m .42057 .71244 L .42023 .70554 L .519 .305 .529 r
F
.41868 .70749 m .42225 .70889 L .42236 .70817 L .675 .735 .895 r
F
.42257 .70751 m .42467 .70859 L .42492 .70752 L F
.41868 .70749 m .4229 .70827 L .42257 .70751 L F
.4229 .70827 m .42467 .70859 L .42257 .70751 L F
.42233 .70978 m .42241 .70997 L .42244 .70722 L .985 .728 .345 r
F
.42241 .70501 m .42249 .70451 L .42248 .70732 L 0 0 .138 r
F
.42244 .70757 m .42248 .70732 L .42248 .71029 L F
.42241 .70501 m .42248 .70732 L .42244 .70757 L F
.42238 .70426 m .42235 .70702 L .42247 .70448 L .985 .728 .345 r
F
.42171 .70556 m .42417 .70546 L .42321 .7046 L .675 .735 .895 r
F
.41868 .70749 m .42201 .70625 L .42181 .70579 L F
.42061 .7082 m .42084 .70827 L .42091 .70549 L .809 .541 .534 r
F
.4208 .70545 m .42091 .70549 L .42099 .70271 L F
.42061 .7082 m .42091 .70549 L .4208 .70545 L F
.42178 .7033 m .42138 .70581 L .42172 .70607 L .908 .63 .503 r
F
.41862 .70465 m .42195 .70596 L .42235 .70534 L .675 .735 .895 r
F
.4215 .70569 m .42181 .70579 L .42171 .70556 L F
.41868 .70749 m .42181 .70579 L .4215 .70569 L F
.42215 .70566 m .42237 .7053 L .42237 .70811 L .077 0 .416 r
F
.42238 .70426 m .42203 .7063 L .42221 .7067 L .985 .728 .345 r
F
.42201 .70625 m .42417 .70546 L .42171 .70556 L .675 .735 .895 r
F
.42238 .70426 m .42204 .7035 L .42203 .7063 L .985 .728 .345 r
F
.42221 .7067 m .42203 .7063 L .42203 .70911 L F
.42238 .70426 m .42203 .70929 L .42221 .7097 L F
.42132 .70751 m .42326 .70744 L .422 .70677 L .675 .735 .895 r
F
.41868 .70749 m .42049 .70966 L .42133 .7093 L F
.41874 .71033 m .42173 .70842 L .42132 .70751 L F
.42172 .70607 m .42098 .70832 L .42167 .70884 L .908 .63 .503 r
F
.42238 .70426 m .42222 .70954 L .42232 .70977 L .985 .728 .345 r
F
.42244 .70757 m .42248 .71029 L .4224 .70787 L 0 0 .138 r
F
.42249 .70326 m .42241 .70997 L .42248 .71012 L .985 .728 .345 r
F
.42173 .70842 m .42326 .70744 L .42132 .70751 L .675 .735 .895 r
F
.42204 .70913 m .42203 .70911 L .42203 .70929 L .985 .728 .345 r
F
.42221 .7067 m .42203 .70911 L .42204 .70913 L F
.42208 .71146 m .42212 .71842 L .422 .71158 L .077 0 .416 r
F
.42221 .7097 m .42203 .70929 L .42202 .71632 L .985 .728 .345 r
F
.42246 .71026 m .42357 .71048 L .42335 .71031 L .654 .726 .902 r
F
.41916 .71009 m .42252 .71039 L .42246 .71026 L F
.42272 .71035 m .42473 .71143 L .42498 .71036 L .675 .735 .895 r
F
.42252 .71039 m .42357 .71048 L .42246 .71026 L .654 .726 .902 r
F
.42229 .70688 m .42255 .70683 L .42201 .70625 L .675 .735 .895 r
F
.42255 .70683 m .42475 .70646 L .42263 .7063 L F
.42255 .70683 m .42263 .7063 L .42201 .70625 L F
.4224 .70713 m .42244 .70722 L .42247 .70448 L .985 .728 .345 r
F
.42233 .70978 m .42244 .70722 L .4224 .70713 L F
.41868 .70749 m .42229 .70688 L .42203 .7063 L .675 .735 .895 r
F
.42138 .70581 m .42098 .70832 L .42172 .70607 L .908 .63 .503 r
F
.42199 .70627 m .42203 .7063 L .42201 .70625 L .675 .735 .895 r
F
.41868 .70749 m .42203 .7063 L .42199 .70627 L F
.42235 .70702 m .42232 .70994 L .4224 .70713 L .985 .728 .345 r
F
.41862 .70465 m .41852 .70721 L .41951 .70707 L .675 .735 .895 r
F
.41868 .70749 m .42135 .70579 L .42098 .70551 L F
.42067 .70541 m .4208 .70545 L .42099 .70271 L .809 .541 .534 r
F
.42061 .70539 m .42098 .70551 L .42069 .70529 L .675 .735 .895 r
F
.41868 .70749 m .42098 .70551 L .42061 .70539 L F
.42067 .70541 m .41994 .70797 L .42061 .7082 L .809 .541 .534 r
F
.42138 .70581 m .42098 .70551 L .42098 .70832 L .908 .63 .503 r
F
.4198 .70793 m .422 .70677 L .42051 .70635 L .675 .735 .895 r
F
.419 .70565 m .42022 .70978 L .41911 .70993 L .642 .403 .542 r
F
.41868 .70749 m .41955 .70987 L .42049 .70966 L .675 .735 .895 r
F
.41874 .71033 m .42067 .70822 L .4198 .70793 L F
.42067 .70822 m .422 .70677 L .4198 .70793 L F
.42061 .7082 m .41991 .70808 L .42061 .70834 L .809 .541 .534 r
F
.41994 .70797 m .41991 .70808 L .42061 .7082 L F
.41862 .70465 m .42194 .70342 L .4213 .70294 L .675 .735 .895 r
F
.42075 .70135 m .42026 .70527 L .42067 .70541 L .809 .541 .534 r
F
.42026 .70527 m .41991 .70808 L .42067 .70541 L F
.41868 .70749 m .41858 .71001 L .41955 .70987 L .675 .735 .895 r
F
.41874 .71033 m .41979 .70795 L .41883 .70785 L F
.41868 .70749 m .41991 .70516 L .41973 .70514 L F
.41916 .71009 m .42009 .70811 L .41924 .70798 L .654 .726 .902 r
F
.41918 .71266 m .41918 .71273 L .41889 .71269 L .642 .403 .542 r
F
.41864 .7128 m .41858 .71445 L .4196 .71267 L .675 .735 .895 r
F
.41918 .71273 m .41936 .71968 L .41889 .71277 L .642 .403 .542 r
F
.41865 .71 m .41889 .71269 L .41864 .71271 L F
.41916 .71009 m .41799 .71258 L .41906 .71279 L .654 .726 .902 r
F
.41918 .71273 m .41889 .71277 L .41889 .71269 L .642 .403 .542 r
F
.41903 .71337 m .4186 .71414 L .41899 .71449 L .654 .726 .902 r
F
.4196 .71267 m .41858 .71445 L .4202 .71432 L .675 .735 .895 r
F
.4188 .70998 m .41889 .71269 L .41865 .71 L .642 .403 .542 r
F
.41918 .71266 m .42022 .71259 L .41918 .71273 L F
.41874 .71033 m .41864 .7128 L .4196 .71267 L .675 .735 .895 r
F
.41936 .71968 m .41912 .7197 L .41889 .71269 L .642 .403 .542 r
F
.41889 .71269 m .41912 .7197 L .41864 .71271 L F
.41912 .7197 m .42015 .75103 L .41892 .71971 L F
.41912 .7197 m .41892 .71971 L .41864 .71271 L F
.41868 .69273 m .42025 .69253 L .42023 .70554 L F
.41548 .69142 m .4156 .70445 L .41546 .70432 L .927 .648 .492 r
F
.4151 .69073 m .41546 .70432 L .41516 .70379 L .989 .721 .392 r
F
.41548 .69142 m .41611 .7049 L .4156 .70445 L .927 .648 .492 r
F
.41712 .69248 m .41865 .70568 L .41744 .70545 L .751 .492 .541 r
F
.40876 .70621 m .38943 .70639 L .39235 .71134 L .654 .726 .902 r
F
.4196 .70283 m .41285 .70363 L .40876 .70621 L F
.41285 .70363 m .38943 .70639 L .40876 .70621 L F
.41709 .70976 m .41542 .71104 L .41757 .70998 L .675 .735 .895 r
F
.41674 .7096 m .41666 .7097 L .41709 .70976 L F
.41666 .7097 m .41542 .71104 L .41709 .70976 L F
.41709 .70976 m .41732 .71246 L .41708 .71241 L .751 .492 .541 r
F
.4171 .70538 m .41724 .70978 L .41709 .70976 L F
.41724 .70978 m .41732 .71246 L .41709 .70976 L F
.41633 .70501 m .41708 .71241 L .41644 .71209 L .844 .572 .527 r
F
.41542 .71104 m .41514 .71544 L .41691 .71146 L .675 .735 .895 r
F
.41916 .71009 m .41384 .71313 L .41637 .71291 L .654 .726 .902 r
F
.41342 .72161 m .41337 .71941 L .41443 .72175 L .731 .478 .546 r
F
.41576 .70648 m .41316 .70667 L .41412 .70753 L .675 .735 .895 r
F
.41633 .70501 m .4171 .70538 L .41709 .70695 L .844 .572 .527 r
F
.41661 .70673 m .41709 .70695 L .41709 .70976 L F
.41633 .70501 m .41709 .70695 L .41661 .70673 L F
.41862 .70465 m .4154 .70584 L .41566 .7063 L .675 .735 .895 r
F
.41588 .7064 m .41566 .7063 L .41576 .70648 L F
.41635 .70662 m .41619 .70654 L .41611 .7049 L .844 .572 .527 r
F
.41862 .70465 m .41566 .7063 L .41588 .7064 L .675 .735 .895 r
F
.4154 .70584 m .41316 .70667 L .41576 .70648 L F
.41516 .70379 m .41546 .70432 L .41545 .70593 L .989 .721 .392 r
F
.4156 .70445 m .41562 .70608 L .41546 .70432 L .927 .648 .492 r
F
.41656 .7069 m .41518 .70685 L .41538 .70819 L .675 .735 .895 r
F
.41316 .70667 m .40962 .71041 L .41412 .70753 L F
.41477 .70816 m .41243 .70746 L .41261 .70852 L F
.41564 .70891 m .41559 .70886 L .41551 .70598 L .927 .648 .492 r
F
.41518 .70685 m .41412 .70753 L .41527 .70813 L .675 .735 .895 r
F
.41518 .70685 m .41527 .70813 L .41538 .70819 L F
.41595 .70636 m .41518 .70685 L .41656 .7069 L F
.41523 .70553 m .41545 .70593 L .41545 .70874 L .989 .721 .392 r
F
.41534 .70855 m .41545 .70874 L .41544 .71135 L F
.41523 .70553 m .41545 .70874 L .41534 .70855 L F
.41412 .70753 m .41214 .71172 L .41538 .70819 L .675 .735 .895 r
F
.41509 .7081 m .41398 .70746 L .41477 .70816 L F
.41635 .70662 m .4164 .70944 L .41619 .70654 L .844 .572 .527 r
F
.41506 .70883 m .41319 .70952 L .41594 .70924 L .675 .735 .895 r
F
.41502 .70727 m .41502 .71002 L .41501 .7099 L .789 .63 .07 r
F
.41508 .70525 m .41258 .70568 L .41512 .70595 L .675 .735 .895 r
F
.41503 .70288 m .41502 .70735 L .41502 .70727 L .789 .63 .07 r
F
.41512 .70881 m .41261 .70852 L .41319 .70952 L .675 .735 .895 r
F
.41674 .7096 m .41415 .71038 L .41542 .71104 L F
.41868 .70749 m .41594 .70924 L .41674 .7096 L F
.41594 .70924 m .41415 .71038 L .41652 .70967 L F
.41567 .71154 m .41555 .71144 L .41551 .7088 L .927 .648 .492 r
F
.41559 .70886 m .41551 .7088 L .41546 .70432 L F
.41567 .71154 m .41551 .7088 L .41559 .70886 L F
.41611 .70931 m .41652 .70967 L .41674 .7096 L .675 .735 .895 r
F
.41594 .70924 m .41652 .70967 L .41611 .70931 L F
.41644 .71209 m .41625 .712 L .4162 .70935 L .844 .572 .527 r
F
.41632 .70941 m .4162 .70935 L .41611 .7049 L F
.41644 .71209 m .4162 .70935 L .41632 .70941 L F
.41518 .70827 m .41544 .71135 L .4152 .7109 L .989 .721 .392 r
F
.41516 .70379 m .41534 .70855 L .41518 .70827 L F
.41542 .7087 m .41507 .7081 L .41512 .70881 L .675 .735 .895 r
F
.41509 .7081 m .41507 .7081 L .41542 .7087 L F
.41534 .70855 m .41544 .71135 L .41518 .70827 L .989 .721 .392 r
F
.41633 .70501 m .41709 .70976 L .4168 .70963 L .844 .572 .527 r
F
.41868 .70749 m .41509 .7081 L .41542 .7087 L .675 .735 .895 r
F
.41507 .7081 m .41261 .70852 L .41512 .70881 L F
.41503 .70751 m .41507 .71068 L .41503 .71017 L .789 .63 .07 r
F
.41504 .70466 m .41505 .70778 L .41503 .70751 L F
.41505 .70778 m .41507 .71068 L .41503 .70751 L F
.41502 .70735 m .41502 .71002 L .41502 .70727 L F
.41868 .70749 m .41503 .70747 L .41509 .7081 L .675 .735 .895 r
F
.41503 .70747 m .41474 .70747 L .41507 .70807 L F
.41505 .70478 m .41508 .70526 L .41507 .70807 L .789 .63 .07 r
F
.41506 .70784 m .41507 .70807 L .41507 .71068 L F
.41505 .70478 m .41507 .70807 L .41506 .70784 L F
.41503 .70747 m .41269 .70639 L .41243 .70746 L .675 .735 .895 r
F
.41562 .70608 m .41564 .70891 L .41551 .70598 L .927 .648 .492 r
F
.41868 .70749 m .41499 .70681 L .41503 .70747 L .675 .735 .895 r
F
.41499 .70681 m .41269 .70639 L .41503 .70747 L F
.41503 .70747 m .41507 .70807 L .41509 .7081 L F
.41474 .70747 m .41398 .70746 L .41509 .7081 L F
.41398 .70746 m .41243 .70746 L .41477 .70816 L F
.41564 .70891 m .41567 .71154 L .41559 .70886 L .927 .648 .492 r
F
.41562 .70608 m .41551 .70598 L .41546 .70432 L F
.41862 .70465 m .41595 .70636 L .41656 .7069 L .675 .735 .895 r
F
.41504 .70305 m .41505 .70478 L .41504 .70466 L .789 .63 .07 r
F
.41499 .70681 m .41335 .7054 L .41269 .70639 L .675 .735 .895 r
F
.41506 .70784 m .41505 .70778 L .41504 .70466 L .789 .63 .07 r
F
.41546 .70432 m .41555 .71144 L .41544 .71135 L .927 .648 .492 r
F
.41554 .70627 m .41546 .7091 L .41554 .70895 L 0 0 .377 r
F
.41516 .70379 m .41545 .70593 L .41523 .70553 L .989 .721 .392 r
F
.41862 .70465 m .41241 .70462 L .41258 .70568 L .675 .735 .895 r
F
.41555 .70192 m .41549 .70636 L .41554 .70627 L 0 0 .377 r
F
.41549 .70636 m .41546 .7091 L .41554 .70627 L F
.41505 .70478 m .41506 .70784 L .41504 .70466 L .789 .63 .07 r
F
.41506 .70784 m .41507 .71068 L .41505 .70778 L F
.41372 .72171 m .40886 .72107 L .41035 .7289 L .654 .726 .902 r
F
.41014 .72057 m .41337 .71941 L .41342 .72161 L .793 .53 .539 r
F
.41216 .7146 m .41337 .71941 L .41514 .71544 L .675 .735 .895 r
F
.41715 .71438 m .40967 .72042 L .41372 .72171 L .654 .726 .902 r
F
.40967 .72042 m .40886 .72107 L .41372 .72171 L F
.40896 .72099 m .41014 .72057 L .41343 .72225 L .793 .53 .539 r
F
.41014 .72057 m .41342 .72161 L .41343 .72225 L F
.41682 .71379 m .40886 .72107 L .41715 .71438 L .654 .726 .902 r
F
.41504 .70305 m .41508 .70365 L .41508 .70526 L .789 .63 .07 r
F
.41504 .70305 m .41508 .70526 L .41505 .70478 L F
.41503 .70463 m .41266 .70356 L .41241 .70462 L .675 .735 .895 r
F
.41504 .70466 m .41503 .70455 L .41503 .70288 L .789 .63 .07 r
F
.41862 .70465 m .41499 .70398 L .41503 .70463 L .675 .735 .895 r
F
.41499 .70398 m .41266 .70356 L .41503 .70463 L F
.41504 .70305 m .41504 .70466 L .41503 .70288 L .789 .63 .07 r
F
.41504 .70466 m .41503 .70751 L .41503 .70455 L F
.41503 .70751 m .41503 .71017 L .41503 .70744 L F
.41503 .70751 m .41503 .70744 L .41503 .70288 L F
.41493 .70602 m .41438 .70455 L .41335 .7054 L .675 .735 .895 r
F
.40261 .70484 m .38856 .70121 L .38943 .70639 L .654 .726 .902 r
F
.4196 .70283 m .41196 .70243 L .40261 .70484 L F
.41196 .70243 m .38856 .70121 L .40261 .70484 L F
.41778 .6878 m .41669 .68813 L .41666 .70122 L .57 .345 .536 r
F
.41868 .70749 m .41621 .7058 L .41555 .70626 L .675 .735 .895 r
F
.4168 .70963 m .41709 .70976 L .41708 .71241 L .844 .572 .527 r
F
.4156 .70445 m .41611 .7049 L .4161 .71193 L .927 .648 .492 r
F
.4089 .71815 m .40885 .71531 L .41332 .71657 L .793 .53 .539 r
F
.41214 .71172 m .41334 .71651 L .4151 .71256 L .675 .735 .895 r
F
.41214 .71172 m .4089 .71526 L .41334 .71651 L F
.40963 .71327 m .4089 .71815 L .41216 .7146 L F
.41542 .71104 m .41216 .7146 L .41514 .71544 L F
.41384 .71313 m .40516 .7181 L .41637 .71291 L .654 .726 .902 r
F
.40516 .7181 m .39657 .72302 L .40566 .71838 L F
.40632 .71874 m .4051 .71617 L .4089 .71815 L .86 .586 .522 r
F
.4051 .71617 m .40885 .71531 L .4089 .71815 L F
.40963 .71327 m .4051 .71617 L .4089 .71815 L .675 .735 .895 r
F
.40516 .7181 m .40566 .71838 L .41637 .71291 L .654 .726 .902 r
F
.40632 .71874 m .4089 .71815 L .40894 .72019 L .86 .586 .522 r
F
.41218 .71505 m .40566 .71838 L .40957 .71979 L .654 .726 .902 r
F
.40566 .71838 m .39657 .72302 L .40864 .72002 L F
.40566 .71838 m .40864 .72002 L .40957 .71979 L F
.40516 .719 m .40632 .71874 L .40896 .72099 L .86 .586 .522 r
F
.40632 .71874 m .40894 .72019 L .40896 .72099 L F
.40516 .719 m .40514 .71808 L .40632 .71874 L F
.40514 .71808 m .4051 .71617 L .40632 .71874 L F
.4089 .71815 m .41332 .71657 L .41337 .71941 L .793 .53 .539 r
F
.41216 .7146 m .4089 .71815 L .41337 .71941 L .675 .735 .895 r
F
.41637 .71291 m .41218 .71505 L .40957 .71979 L .654 .726 .902 r
F
.41627 .71302 m .41421 .71322 L .41548 .71388 L .675 .735 .895 r
F
.41874 .71033 m .41581 .7122 L .41627 .71302 L F
.41581 .7122 m .41421 .71322 L .41627 .71302 L F
.41633 .70572 m .41554 .70627 L .41554 .70895 L .403 .215 .509 r
F
.41415 .71038 m .41216 .7146 L .41542 .71104 L .675 .735 .895 r
F
.41412 .70753 m .40962 .71041 L .41214 .71172 L F
.41319 .70952 m .40963 .71327 L .41415 .71038 L F
.41916 .71009 m .41249 .71087 L .4117 .71137 L .654 .726 .902 r
F
.40962 .71041 m .4089 .71526 L .41214 .71172 L .675 .735 .895 r
F
.41377 .71177 m .4117 .71137 L .40844 .71343 L .654 .726 .902 r
F
.41916 .71009 m .4117 .71137 L .41377 .71177 L F
.41763 .70984 m .41709 .70976 L .41757 .70998 L .675 .735 .895 r
F
.41744 .70545 m .41761 .71251 L .4171 .70538 L .751 .492 .541 r
F
.41847 .72378 m .40991 .73616 L .41795 .73726 L .654 .726 .902 r
F
.41556 .71778 m .41035 .7289 L .41565 .7191 L F
.41343 .72225 m .41342 .72161 L .41443 .72175 L .731 .478 .546 r
F
.4152 .71828 m .41343 .72225 L .41826 .7227 L .675 .735 .895 r
F
.41742 .72014 m .4155 .72422 L .41858 .72116 L .654 .726 .902 r
F
.4155 .72422 m .40991 .73616 L .41564 .72624 L F
.4155 .72422 m .41564 .72624 L .41858 .72116 L F
.41503 .71017 m .41507 .71068 L .41505 .71771 L .789 .63 .07 r
F
.41778 .72254 m .40991 .73616 L .41847 .72378 L .654 .726 .902 r
F
.4152 .7109 m .41544 .71135 L .41544 .71155 L .989 .721 .392 r
F
.4051 .71617 m .40504 .71333 L .40885 .71531 L .86 .586 .522 r
F
.40844 .71343 m .39521 .72179 L .39657 .72302 L .654 .726 .902 r
F
.40228 .71643 m .40323 .71634 L .40516 .719 L .932 .65 .485 r
F
.40323 .71634 m .4051 .71617 L .40514 .71808 L F
.40516 .7181 m .40398 .71703 L .39657 .72302 L .654 .726 .902 r
F
.40323 .71634 m .40514 .71808 L .40516 .719 L .932 .65 .485 r
F
.41415 .71038 m .40963 .71327 L .41216 .7146 L .675 .735 .895 r
F
.41916 .71009 m .40844 .71343 L .40398 .71703 L .654 .726 .902 r
F
.41916 .71009 m .40398 .71703 L .40516 .7181 L F
.40323 .71634 m .40222 .71359 L .4051 .71617 L .932 .65 .485 r
F
.40218 .71539 m .39177 .71864 L .40348 .71657 L .654 .726 .902 r
F
.40228 .71643 m .40226 .71545 L .40323 .71634 L .932 .65 .485 r
F
.40226 .71545 m .40222 .71359 L .40323 .71634 L F
.40348 .71657 m .39177 .71864 L .39521 .72179 L .654 .726 .902 r
F
.40222 .71359 m .40504 .71333 L .4051 .71617 L .932 .65 .485 r
F
.40771 .71155 m .40222 .71359 L .4051 .71617 L .675 .735 .895 r
F
.40844 .71343 m .40218 .71539 L .40348 .71657 L .654 .726 .902 r
F
.41556 .71778 m .41565 .7191 L .41768 .71533 L F
.41697 .7143 m .4152 .71828 L .41842 .71858 L .675 .735 .895 r
F
.41676 .71251 m .40957 .71979 L .41748 .71315 L .654 .726 .902 r
F
.41763 .71282 m .41548 .71388 L .41697 .7143 L .675 .735 .895 r
F
.41694 .71234 m .41676 .71251 L .41789 .7128 L .654 .726 .902 r
F
.41874 .71033 m .4168 .71244 L .41763 .71282 L .675 .735 .895 r
F
.41676 .71251 m .41748 .71315 L .41789 .7128 L .654 .726 .902 r
F
.4168 .71244 m .41548 .71388 L .41763 .71282 L .675 .735 .895 r
F
.41644 .71209 m .41708 .71241 L .41708 .71257 L .844 .572 .527 r
F
.41645 .71228 m .41708 .71257 L .41707 .71944 L F
.41644 .71209 m .41708 .71257 L .41645 .71228 L F
.4098 .72636 m .40917 .72752 L .41533 .72176 L .654 .726 .902 r
F
.4152 .71828 m .41826 .7227 L .41842 .71858 L .675 .735 .895 r
F
.41527 .72084 m .41532 .7216 L .41769 .71956 L .654 .726 .902 r
F
.41609 .71896 m .41701 .75097 L .41603 .7505 L .844 .572 .527 r
F
.4161 .71193 m .41627 .71905 L .41609 .71896 L F
.41627 .71905 m .41701 .75097 L .41609 .71896 L F
.41532 .7216 m .41533 .72176 L .41756 .71968 L .654 .726 .902 r
F
.41755 .71968 m .41756 .71968 L .41769 .71956 L F
.41532 .7216 m .41756 .71968 L .41755 .71968 L F
.4098 .72636 m .41533 .72176 L .41532 .7216 L F
.41518 .7126 m .41325 .71236 L .41421 .71322 L .675 .735 .895 r
F
.41874 .71033 m .41512 .71167 L .41518 .7126 L F
.41512 .71167 m .41325 .71236 L .41518 .7126 L F
.41761 .71251 m .41732 .71246 L .4171 .70538 L .751 .492 .541 r
F
.41296 .70663 m .40876 .70621 L .39712 .7157 L .654 .726 .902 r
F
.40876 .70621 m .39235 .71134 L .39574 .71444 L F
.40876 .70621 m .39574 .71444 L .39712 .7157 L F
.40771 .7087 m .40511 .71328 L .40962 .71041 L .675 .735 .895 r
F
.40771 .7087 m .40225 .71072 L .40511 .71328 L F
.40046 .71059 m .40217 .71075 L .40222 .71359 L .987 .713 .388 r
F
.40653 .70956 m .40222 .71359 L .40771 .71155 L .675 .735 .895 r
F
.40222 .71359 m .40217 .71075 L .40504 .71333 L .932 .65 .485 r
F
.40653 .70956 m .40046 .71059 L .40222 .71359 L .675 .735 .895 r
F
.40003 .70965 m .38797 .70845 L .40047 .71229 L .654 .726 .902 r
F
.4 .71023 m .40015 .71034 L .40052 .71343 L .86 .661 .127 r
F
.40015 .71034 m .40046 .71059 L .4005 .71247 L F
.40015 .71034 m .4005 .71247 L .40052 .71343 L F
.40047 .71229 m .38797 .70845 L .38883 .71367 L .654 .726 .902 r
F
.41249 .71087 m .40003 .70965 L .40047 .71229 L F
.4164 .70944 m .41644 .71209 L .41632 .70941 L .844 .572 .527 r
F
.41916 .71009 m .41416 .70983 L .41249 .71087 L .654 .726 .902 r
F
.40046 .71059 m .40041 .70775 L .40217 .71075 L .987 .713 .388 r
F
.40654 .70671 m .40225 .71072 L .40771 .7087 L .675 .735 .895 r
F
.41261 .70852 m .40771 .71155 L .41319 .70952 L F
.41261 .70852 m .40653 .70956 L .40771 .71155 L F
.40015 .71034 m .39994 .70739 L .40046 .71059 L .86 .661 .127 r
F
.4 .71023 m .39998 .70934 L .40015 .71034 L F
.39998 .70934 m .39994 .70739 L .40015 .71034 L F
.41416 .70983 m .39994 .70908 L .41249 .71087 L .654 .726 .902 r
F
.39994 .70908 m .38797 .70845 L .40003 .70965 L F
.40619 .70742 m .40046 .71059 L .40653 .70956 L .675 .735 .895 r
F
.39994 .70908 m .40003 .70965 L .41249 .71087 L .654 .726 .902 r
F
.41556 .70345 m .41434 .70172 L .41332 .70257 L .675 .735 .895 r
F
.41862 .70465 m .41621 .703 L .41556 .70345 L F
.41769 .71956 m .41756 .71968 L .41762 .71971 L .654 .726 .902 r
F
.41779 .71958 m .41755 .71953 L .41732 .71246 L .751 .492 .541 r
F
.41872 .71735 m .41672 .71937 L .41769 .71956 L .654 .726 .902 r
F
.41697 .7143 m .41842 .71858 L .41858 .71445 L .675 .735 .895 r
F
.41761 .71251 m .41779 .71958 L .41732 .71246 L .751 .492 .541 r
F
.41707 .71944 m .41857 .75123 L .41701 .75097 L F
.41708 .71241 m .41735 .71949 L .41707 .71944 L F
.41735 .71949 m .41857 .75123 L .41707 .71944 L F
.40886 .72107 m .40541 .72733 L .41035 .7289 L .654 .726 .902 r
F
.40886 .72107 m .4029 .72652 L .40541 .72733 L F
.4155 .72422 m .40917 .72752 L .40991 .73616 L F
.41762 .71971 m .41534 .72182 L .4155 .72422 L F
.41534 .72182 m .40917 .72752 L .4155 .72422 L F
.41503 .71017 m .41503 .71729 L .41502 .71002 L .789 .63 .07 r
F
.40957 .71979 m .4029 .72652 L .40886 .72107 L .654 .726 .902 r
F
.41789 .7128 m .41864 .71317 L .41864 .71279 L F
.41864 .71317 m .41881 .71325 L .41864 .71279 L F
.41864 .71279 m .41881 .71325 L .41906 .71279 L F
.41864 .7128 m .41697 .7143 L .41858 .71445 L .675 .735 .895 r
F
.41761 .71251 m .41864 .71271 L .41864 .7128 L .751 .492 .541 r
F
.41761 .71251 m .41864 .7128 L .41763 .71265 L F
.41874 .71033 m .4177 .71266 L .41864 .7128 L .675 .735 .895 r
F
.41789 .7128 m .41682 .71379 L .41715 .71438 L .654 .726 .902 r
F
.4177 .71266 m .41697 .7143 L .41864 .7128 L .675 .735 .895 r
F
.41763 .71265 m .41864 .7128 L .41863 .71974 L .751 .492 .541 r
F
.41858 .72116 m .41778 .72254 L .41847 .72378 L .654 .726 .902 r
F
.41779 .71958 m .41863 .71974 L .41857 .75123 L .751 .492 .541 r
F
.41761 .71251 m .41863 .71974 L .41779 .71958 L F
.40957 .71979 m .40929 .7203 L .41789 .7128 L .654 .726 .902 r
F
.40929 .7203 m .40886 .72107 L .4096 .72039 L F
.40929 .7203 m .4096 .72039 L .41789 .7128 L F
.41014 .72057 m .4089 .71815 L .41337 .71941 L .793 .53 .539 r
F
.40896 .72099 m .40894 .72019 L .41014 .72057 L F
.40894 .72019 m .4089 .71815 L .41014 .72057 L F
.41222 .71744 m .40896 .72099 L .41343 .72225 L .675 .735 .895 r
F
.41557 .71915 m .40813 .72065 L .39613 .73028 L .654 .726 .902 r
F
.41548 .71388 m .4152 .71828 L .41697 .7143 L .675 .735 .895 r
F
.41567 .71154 m .4161 .71193 L .41609 .71896 L .927 .648 .492 r
F
.41872 .71735 m .41394 .71884 L .41557 .71915 L .654 .726 .902 r
F
.41222 .71744 m .41343 .72225 L .4152 .71828 L .675 .735 .895 r
F
.41394 .71884 m .40813 .72065 L .41557 .71915 L .654 .726 .902 r
F
.40957 .71979 m .39657 .72302 L .4029 .72652 L F
.40813 .72065 m .39133 .72589 L .3948 .72907 L F
.40813 .72065 m .3948 .72907 L .39613 .73028 L F
.4152 .7109 m .41544 .71155 L .4152 .71112 L .989 .721 .392 r
F
.41874 .71033 m .41266 .71136 L .41325 .71236 L .675 .735 .895 r
F
.41627 .70849 m .41612 .71561 L .41648 .70836 L .403 .215 .509 r
F
.41756 .71968 m .41664 .72053 L .41762 .71971 L .654 .726 .902 r
F
.41664 .72053 m .40917 .72752 L .41667 .72058 L F
.41664 .72053 m .41667 .72058 L .41762 .71971 L F
.4152 .7109 m .41523 .71802 L .41513 .71078 L .989 .721 .392 r
F
.41672 .71937 m .41527 .72084 L .41769 .71956 L .654 .726 .902 r
F
.41644 .71209 m .41654 .71918 L .41625 .712 L .844 .572 .527 r
F
.41654 .71918 m .41701 .75097 L .41639 .71911 L F
.41654 .71918 m .41639 .71911 L .41625 .712 L F
.4151 .71848 m .41213 .71812 L .40813 .72065 L .654 .726 .902 r
F
.41567 .71154 m .41609 .71896 L .41573 .71864 L .927 .648 .492 r
F
.41872 .71735 m .41395 .71791 L .4151 .71848 L .654 .726 .902 r
F
.41395 .71791 m .41213 .71812 L .4151 .71848 L F
.41625 .712 m .41639 .71911 L .4161 .71193 L .844 .572 .527 r
F
.41639 .71911 m .41701 .75097 L .41627 .71905 L F
.41639 .71911 m .41627 .71905 L .4161 .71193 L F
.40968 .71611 m .40896 .72099 L .41222 .71744 L .675 .735 .895 r
F
.41395 .71791 m .38752 .71571 L .38839 .72093 L .654 .726 .902 r
F
.41868 .70749 m .41506 .70883 L .41594 .70924 L .675 .735 .895 r
F
.41874 .71033 m .41249 .71029 L .41266 .71136 L F
.41648 .70836 m .41629 .7155 L .41665 .70825 L .403 .215 .509 r
F
.4159 .71921 m .41611 .71958 L .41672 .71937 L .654 .726 .902 r
F
.41557 .71915 m .41611 .71958 L .4159 .71921 L F
.41573 .71864 m .41609 .71896 L .41603 .7505 L .927 .648 .492 r
F
.40962 .71041 m .40511 .71328 L .4089 .71526 L .675 .735 .895 r
F
.40771 .71155 m .4051 .71617 L .40963 .71327 L F
.40052 .71343 m .40046 .71059 L .40222 .71359 L .987 .713 .388 r
F
.40844 .71343 m .40131 .71219 L .40061 .71267 L .654 .726 .902 r
F
.40221 .71538 m .40061 .71267 L .39177 .71864 L F
.4011 .71348 m .40222 .71359 L .40226 .71545 L .987 .713 .388 r
F
.40844 .71343 m .40061 .71267 L .40221 .71538 L .654 .726 .902 r
F
.40052 .71343 m .4011 .71348 L .40228 .71643 L .987 .713 .388 r
F
.4011 .71348 m .40226 .71545 L .40228 .71643 L F
.40131 .71219 m .38883 .71367 L .38972 .71518 L .654 .726 .902 r
F
.40131 .71219 m .38972 .71518 L .39177 .71864 L F
.40776 .71439 m .40516 .719 L .40968 .71611 L .675 .735 .895 r
F
.40776 .71439 m .40228 .71643 L .40516 .719 L F
.41032 .71691 m .38878 .71061 L .38752 .71571 L .654 .726 .902 r
F
.41644 .71209 m .41707 .71944 L .41654 .71918 L .844 .572 .527 r
F
.4156 .70445 m .4161 .71193 L .41567 .71154 L .927 .648 .492 r
F
.41611 .7049 m .41625 .712 L .4161 .71193 L .844 .572 .527 r
F
.41627 .70849 m .41554 .70895 L .41553 .71598 L .403 .215 .509 r
F
.41872 .71735 m .41477 .71646 L .41378 .71709 L .654 .726 .902 r
F
.41567 .71154 m .41573 .71864 L .41555 .71144 L .927 .648 .492 r
F
.41573 .71864 m .41603 .7505 L .41563 .71856 L F
.41573 .71864 m .41563 .71856 L .41555 .71144 L F
.41319 .70952 m .40771 .71155 L .40963 .71327 L .675 .735 .895 r
F
.41249 .71087 m .40131 .71219 L .40844 .71343 L .654 .726 .902 r
F
.40625 .71026 m .40052 .71343 L .40659 .7124 L .675 .735 .895 r
F
.40625 .71026 m .4 .71023 L .40052 .71343 L F
.40654 .70671 m .4005 .70774 L .40225 .71072 L F
.39994 .70739 m .40041 .70775 L .40046 .71059 L .86 .661 .127 r
F
.39994 .70739 m .39989 .70455 L .40041 .70775 L F
.40619 .70742 m .39994 .70739 L .40046 .71059 L .675 .735 .895 r
F
.41114 .70967 m .40065 .70665 L .40005 .70909 L .654 .726 .902 r
F
.40076 .70703 m .40053 .70713 L .4 .71023 L 0 0 .252 r
F
.40053 .70713 m .39994 .70739 L .39998 .70934 L F
.40053 .70713 m .39998 .70934 L .4 .71023 L F
.40005 .70909 m .38922 .70335 L .38797 .70845 L .654 .726 .902 r
F
.40065 .70665 m .38922 .70335 L .40005 .70909 L F
.41916 .71009 m .41401 .70893 L .41114 .70967 L F
.41316 .70667 m .40771 .7087 L .40962 .71041 L .675 .735 .895 r
F
.41243 .70746 m .40653 .70956 L .41261 .70852 L F
.41411 .70454 m .40876 .70621 L .41296 .70663 L .654 .726 .902 r
F
.41258 .70568 m .40654 .70671 L .40771 .7087 L .675 .735 .895 r
F
.41243 .70746 m .40619 .70742 L .40653 .70956 L F
.4062 .70458 m .4005 .70774 L .40654 .70671 L F
.4067 .70529 m .39994 .70739 L .40619 .70742 L F
.4062 .70458 m .39998 .70455 L .4005 .70774 L F
.4067 .70529 m .4007 .70419 L .39994 .70739 L F
.40053 .70713 m .4007 .70419 L .39994 .70739 L 0 0 .252 r
F
.40076 .70703 m .40075 .70628 L .40053 .70713 L F
.40075 .70628 m .4007 .70419 L .40053 .70713 L F
.41258 .70568 m .40771 .7087 L .41316 .70667 L .675 .735 .895 r
F
.41401 .70893 m .40082 .70596 L .41114 .70967 L .654 .726 .902 r
F
.40082 .70596 m .38922 .70335 L .40065 .70665 L F
.40082 .70596 m .40065 .70665 L .41114 .70967 L F
.41558 .68891 m .41503 .70288 L .41543 .70213 L 0 0 .377 r
F
.41224 .70117 m .3931 .6915 L .38981 .69613 L .654 .726 .902 r
F
.41669 .68813 m .41555 .70192 L .41641 .70138 L .403 .215 .509 r
F
.4196 .70283 m .41541 .70104 L .41224 .70117 L .654 .726 .902 r
F
.41541 .70104 m .3931 .6915 L .41224 .70117 L F
.41887 .68771 m .41778 .6878 L .41776 .70094 L .661 .418 .542 r
F
.41862 .70465 m .41778 .70234 L .41692 .7026 L .675 .735 .895 r
F
.41558 .68891 m .41543 .70213 L .41555 .70192 L 0 0 .377 r
F
.41669 .68813 m .41558 .68891 L .41555 .70192 L .403 .215 .509 r
F
.41698 .70097 m .40474 .68483 L .39819 .68765 L .654 .726 .902 r
F
.4196 .70283 m .41803 .70093 L .41698 .70097 L F
.41803 .70093 m .40474 .68483 L .41698 .70097 L F
.4196 .70283 m .39819 .68765 L .3931 .6915 L F
.41669 .68813 m .41641 .70138 L .41666 .70122 L .403 .215 .509 r
F
.41868 .69273 m .419 .70565 L .41865 .70568 L .642 .403 .542 r
F
.4196 .70283 m .41231 .68324 L .40474 .68483 L .654 .726 .902 r
F
.4007 .70419 m .39989 .70455 L .39994 .70739 L 0 0 .252 r
F
.4067 .70246 m .40074 .70136 L .39998 .70455 L .675 .735 .895 r
F
.4007 .70419 m .40065 .70135 L .39989 .70455 L 0 0 .252 r
F
.41102 .70825 m .40248 .70385 L .40095 .70599 L .654 .726 .902 r
F
.40274 .70405 m .40231 .70408 L .40076 .70703 L .118 .01 .444 r
F
.40231 .70408 m .4007 .70419 L .40075 .70628 L F
.40231 .70408 m .40075 .70628 L .40076 .70703 L F
.40095 .70599 m .39252 .6987 L .38922 .70335 L .654 .726 .902 r
F
.40248 .70385 m .39252 .6987 L .40095 .70599 L F
.4152 .7109 m .41513 .71078 L .41508 .70365 L .989 .721 .392 r
F
.41508 .70365 m .41513 .71078 L .41507 .71068 L F
.41916 .71009 m .41452 .70811 L .41102 .70825 L .654 .726 .902 r
F
.4067 .70246 m .39998 .70455 L .4062 .70458 L .675 .735 .895 r
F
.41269 .70639 m .40619 .70742 L .41243 .70746 L F
.41241 .70462 m .40654 .70671 L .41258 .70568 L F
.41269 .70639 m .4067 .70529 L .40619 .70742 L F
.40802 .7033 m .4007 .70419 L .4067 .70529 L F
.40802 .7033 m .40269 .70121 L .4007 .70419 L F
.40231 .70408 m .40269 .70121 L .4007 .70419 L .118 .01 .444 r
F
.40297 .70317 m .40248 .70385 L .41102 .70825 L .654 .726 .902 r
F
.40274 .70405 m .40273 .70349 L .40231 .70408 L .118 .01 .444 r
F
.40273 .70349 m .40269 .70121 L .40231 .70408 L F
.41452 .70811 m .40297 .70317 L .41102 .70825 L .654 .726 .902 r
F
.40297 .70317 m .39252 .6987 L .40248 .70385 L F
.41196 .70243 m .39642 .69761 L .38856 .70121 L F
.41241 .70462 m .4062 .70458 L .40654 .70671 L .675 .735 .895 r
F
.41266 .70356 m .4067 .70246 L .4062 .70458 L F
.4147 .70173 m .39642 .69761 L .41196 .70243 L .654 .726 .902 r
F
.40802 .70049 m .40074 .70136 L .4067 .70246 L .675 .735 .895 r
F
.41335 .7054 m .4067 .70529 L .41269 .70639 L F
.40802 .70049 m .40271 .6984 L .40074 .70136 L F
.40269 .70121 m .40065 .70135 L .4007 .70419 L .118 .01 .444 r
F
.40269 .70121 m .40263 .69837 L .40065 .70135 L F
.41266 .70356 m .4062 .70458 L .41241 .70462 L .675 .735 .895 r
F
.41335 .7054 m .40802 .7033 L .4067 .70529 L F
.41452 .70811 m .40575 .70121 L .40309 .70322 L .654 .726 .902 r
F
.40582 .7015 m .40542 .70146 L .40274 .70405 L .359 .189 .51 r
F
.40542 .70146 m .40269 .70121 L .40273 .70349 L F
.40542 .70146 m .40273 .70349 L .40274 .70405 L F
.40309 .70322 m .39764 .69483 L .39252 .6987 L .654 .726 .902 r
F
.41007 .70161 m .40576 .69866 L .40269 .70121 L .675 .735 .895 r
F
.40582 .7015 m .40576 .69866 L .40269 .70121 L .359 .189 .51 r
F
.40575 .70121 m .39764 .69483 L .40309 .70322 L .654 .726 .902 r
F
.41748 .70701 m .41865 .71 L .41755 .70983 L .751 .492 .541 r
F
.41744 .70545 m .41787 .70707 L .41748 .70701 L F
.41787 .70707 m .41865 .71 L .41748 .70701 L F
.41862 .70465 m .41668 .70677 L .41709 .70695 L .675 .735 .895 r
F
.41757 .70703 m .41709 .70695 L .41751 .70715 L F
.41862 .70465 m .41709 .70695 L .41757 .70703 L F
.41868 .70749 m .41674 .7096 L .41709 .70976 L F
.41916 .71009 m .41626 .70803 L .41452 .70811 L .654 .726 .902 r
F
.41503 .71017 m .41502 .71002 L .41503 .70288 L .789 .63 .07 r
F
.41438 .70455 m .40802 .7033 L .41335 .7054 L .675 .735 .895 r
F
.41332 .70257 m .40802 .70049 L .4067 .70246 L F
.41007 .70161 m .40269 .70121 L .40802 .7033 L F
.40576 .69866 m .40263 .69837 L .40269 .70121 L .359 .189 .51 r
F
.41626 .70803 m .39764 .69483 L .41452 .70811 L .654 .726 .902 r
F
.4186 .7009 m .41776 .70094 L .41776 .70234 L .661 .418 .542 r
F
.41751 .701 m .41748 .70242 L .41776 .70094 L .57 .345 .536 r
F
.41748 .70242 m .41768 .70236 L .41776 .70094 L F
.41778 .70234 m .41878 .70055 L .41717 .70068 L .675 .735 .895 r
F
.41862 .70465 m .41872 .70225 L .41778 .70234 L F
.4186 .7009 m .41857 .70226 L .41884 .70089 L .661 .418 .542 r
F
.41857 .70226 m .41877 .70225 L .41884 .70089 L F
.4186 .7009 m .41776 .70234 L .41857 .70226 L F
.41872 .70225 m .41878 .70055 L .41778 .70234 L .675 .735 .895 r
F
.41868 .70749 m .41877 .70505 L .41782 .70514 L F
.41868 .70749 m .41709 .70976 L .41763 .70984 L F
.41638 .70287 m .41627 .70849 L .41658 .70274 L .403 .215 .509 r
F
.41868 .70749 m .41555 .70626 L .41524 .70686 L .675 .735 .895 r
F
.41627 .70849 m .41648 .70836 L .41655 .70556 L .403 .215 .509 r
F
.41484 .70396 m .41332 .70257 L .41266 .70356 L .675 .735 .895 r
F
.41862 .70465 m .41556 .70345 L .41484 .70396 L F
.41556 .70345 m .41332 .70257 L .41484 .70396 L F
.41642 .70565 m .41655 .70556 L .41662 .70271 L .403 .215 .509 r
F
.4196 .70283 m .4147 .70173 L .41196 .70243 L .654 .726 .902 r
F
.41658 .70274 m .41662 .70271 L .41666 .70122 L .403 .215 .509 r
F
.41642 .70565 m .41662 .70271 L .41658 .70274 L F
.41627 .70849 m .41655 .70556 L .41642 .70565 L F
.4168 .70523 m .41722 .7035 L .41569 .7039 L .675 .735 .895 r
F
.41751 .701 m .41666 .70122 L .41666 .70268 L .57 .345 .536 r
F
.41734 .70247 m .41666 .70268 L .41665 .70825 L F
.41751 .701 m .41666 .70268 L .41734 .70247 L F
.41862 .70465 m .41692 .7026 L .41621 .703 L .675 .735 .895 r
F
.41692 .7026 m .41687 .70254 L .41666 .70268 L F
.41692 .7026 m .41666 .70268 L .41621 .703 L F
.41633 .70572 m .41554 .70895 L .41627 .70849 L .403 .215 .509 r
F
.41536 .70928 m .41546 .7091 L .41555 .70192 L 0 0 .377 r
F
.41543 .70213 m .41503 .70288 L .41502 .70447 L F
.41516 .70379 m .4152 .7109 L .41508 .70365 L .989 .721 .392 r
F
.41529 .70396 m .41502 .70447 L .41502 .70727 L 0 0 .377 r
F
.41543 .70213 m .41502 .70447 L .41529 .70396 L F
.41641 .70138 m .41555 .70346 L .41611 .70306 L .403 .215 .509 r
F
.41621 .703 m .4159 .70279 L .41556 .70345 L .675 .735 .895 r
F
.4159 .70279 m .41434 .70172 L .41556 .70344 L F
.4159 .70279 m .41556 .70344 L .41556 .70345 L F
.41862 .70465 m .41508 .70525 L .41512 .70595 L F
.41555 .70626 m .41486 .70488 L .41493 .70602 L F
.41517 .70698 m .41502 .70727 L .41501 .7099 L 0 0 .377 r
F
.41543 .70213 m .41502 .70727 L .41517 .70698 L F
.41486 .70488 m .41438 .70455 L .41493 .70602 L .675 .735 .895 r
F
.41543 .70213 m .41501 .7099 L .41536 .70928 L 0 0 .377 r
F
.41524 .70686 m .41493 .70602 L .41499 .70681 L .675 .735 .895 r
F
.41555 .70626 m .41493 .70602 L .41524 .70686 L F
.41493 .70602 m .41335 .7054 L .41499 .70681 L F
.41332 .70257 m .4067 .70246 L .41266 .70356 L F
.41434 .70172 m .40802 .70049 L .41332 .70257 L F
.41434 .70172 m .41006 .6988 L .40802 .70049 L F
.41006 .6988 m .40271 .6984 L .40802 .70049 L F
.41438 .70455 m .41007 .70161 L .40802 .7033 L F
.41569 .7039 m .41007 .70161 L .41438 .70455 L F
.41006 .6988 m .40577 .69587 L .40271 .6984 L F
.40576 .69866 m .40571 .69582 L .40263 .69837 L .359 .189 .51 r
F
.41271 .70031 m .40576 .69866 L .41007 .70161 L .675 .735 .895 r
F
.41268 .69751 m .40577 .69587 L .41006 .6988 L F
.41271 .70031 m .40972 .69672 L .40576 .69866 L F
.40972 .69672 m .40571 .69582 L .40576 .69866 L .498 .295 .535 r
F
.41857 .70967 m .41015 .6993 L .40629 .70096 L .654 .726 .902 r
F
.40978 .69956 m .40964 .69952 L .40582 .7015 L .498 .295 .535 r
F
.40964 .69952 m .40576 .69866 L .40581 .70117 L F
.40964 .69952 m .40581 .70117 L .40582 .7015 L F
.40629 .70096 m .40422 .692 L .39764 .69483 L .654 .726 .902 r
F
.40978 .69956 m .40972 .69672 L .40576 .69866 L .498 .295 .535 r
F
.41015 .6993 m .40422 .692 L .40629 .70096 L .654 .726 .902 r
F
.41868 .70749 m .41782 .70514 L .41775 .70515 L .675 .735 .895 r
F
.41868 .70749 m .41775 .70515 L .41694 .7054 L F
.41839 .70509 m .41775 .70515 L .41775 .70795 L .661 .418 .542 r
F
.41874 .71033 m .41786 .70794 L .41696 .7082 L .675 .735 .895 r
F
.41502 .71002 m .41502 .71021 L .41501 .7099 L .789 .63 .07 r
F
.41502 .71021 m .41501 .71009 L .41501 .7099 L F
.41874 .71033 m .41274 .70923 L .41249 .71029 L .675 .735 .895 r
F
.4182 .70791 m .41775 .70795 L .41773 .715 L .661 .418 .542 r
F
.41611 .70306 m .41555 .70346 L .41554 .70627 L .403 .215 .509 r
F
.41543 .70213 m .41539 .70656 L .41555 .70192 L 0 0 .377 r
F
.41539 .70656 m .41536 .70928 L .41543 .70648 L F
.41539 .70656 m .41543 .70648 L .41555 .70192 L F
.4159 .70559 m .41569 .7039 L .41438 .70455 L .675 .735 .895 r
F
.41641 .70138 m .41554 .70627 L .41633 .70572 L .403 .215 .509 r
F
.41621 .7058 m .41606 .70527 L .4159 .70559 L .675 .735 .895 r
F
.41606 .70527 m .41569 .7039 L .4159 .70559 L F
.41868 .70749 m .41694 .7054 L .41621 .7058 L F
.41743 .70525 m .41665 .70825 L .41737 .70807 L .57 .345 .536 r
F
.41751 .701 m .41699 .70538 L .41743 .70525 L F
.41699 .70538 m .41665 .70825 L .41743 .70525 L F
.41694 .7054 m .41688 .70533 L .41666 .70549 L .675 .735 .895 r
F
.41694 .7054 m .41666 .70549 L .41621 .7058 L F
.41688 .70533 m .41569 .7039 L .41621 .7058 L F
.41666 .70549 m .41648 .70836 L .41665 .70825 L .403 .215 .509 r
F
.41666 .70122 m .41655 .70556 L .41666 .70549 L F
.41655 .70556 m .41648 .70836 L .41666 .70549 L F
.41839 .70509 m .41775 .70795 L .4182 .70791 L .661 .418 .542 r
F
.41786 .70794 m .41785 .70792 L .41775 .70795 L .675 .735 .895 r
F
.41874 .71033 m .41883 .70785 L .41786 .70794 L F
.41708 .70747 m .41727 .70633 L .41646 .70655 L F
.41737 .70807 m .41747 .70804 L .4176 .70519 L .57 .345 .536 r
F
.41785 .70792 m .41727 .70633 L .41696 .7082 L .675 .735 .895 r
F
.41737 .70807 m .4176 .70519 L .41752 .70522 L .57 .345 .536 r
F
.41694 .7054 m .41775 .70515 L .4168 .70523 L .675 .735 .895 r
F
.41641 .70138 m .41555 .70192 L .41555 .70346 L .403 .215 .509 r
F
.41621 .703 m .41565 .70108 L .41434 .70172 L .675 .735 .895 r
F
.41565 .70108 m .41006 .6988 L .41434 .70172 L F
.41565 .70108 m .41268 .69751 L .41006 .6988 L F
.41717 .70068 m .41268 .69751 L .41565 .70108 L F
.41722 .7035 m .41271 .70031 L .41569 .7039 L F
.41644 .70136 m .41657 .70174 L .41666 .70122 L .403 .215 .509 r
F
.41641 .70138 m .41657 .70174 L .41644 .70136 L F
.41641 .70138 m .41638 .70287 L .41657 .70174 L F
.41638 .70287 m .41658 .70274 L .41666 .70122 L F
.41687 .70254 m .41565 .70108 L .41621 .703 L .675 .735 .895 r
F
.41722 .7035 m .41575 .6995 L .41271 .70031 L F
.41268 .69751 m .40971 .69393 L .40577 .69587 L F
.41571 .6967 m .40971 .69393 L .41268 .69751 L F
.41747 .70804 m .40422 .692 L .41857 .70967 L .654 .726 .902 r
F
.41727 .70633 m .41581 .70234 L .41276 .70315 L .675 .735 .895 r
F
.41571 .6967 m .41425 .69272 L .40971 .69393 L F
.41575 .6995 m .40972 .69672 L .41271 .70031 L F
.41717 .70068 m .41571 .6967 L .41268 .69751 L F
.41575 .6995 m .41429 .6955 L .40972 .69672 L F
.41429 .6955 m .40966 .69388 L .40972 .69672 L .593 .369 .545 r
F
.41429 .6955 m .41423 .69266 L .40966 .69388 L F
.41581 .70234 m .41434 .69834 L .40978 .69956 L .675 .735 .895 r
F
.41434 .69834 m .40972 .69672 L .40977 .69946 L .593 .369 .545 r
F
.41621 .7058 m .41486 .70488 L .41555 .70626 L .675 .735 .895 r
F
.41569 .7039 m .41271 .70031 L .41007 .70161 L F
.40972 .69672 m .40966 .69388 L .40571 .69582 L .498 .295 .535 r
F
.41747 .70804 m .40631 .69156 L .40422 .692 L .654 .726 .902 r
F
.41143 .69912 m .40977 .69946 L .40978 .69956 L .593 .369 .545 r
F
.41434 .69834 m .40977 .69946 L .41143 .69912 L F
.41154 .69909 m .41183 .6904 L .40631 .69156 L .654 .726 .902 r
F
.41916 .71009 m .41481 .69841 L .41154 .69909 L F
.41434 .69834 m .41429 .6955 L .40972 .69672 L .593 .369 .545 r
F
.41481 .69841 m .41183 .6904 L .41154 .69909 L .654 .726 .902 r
F
.41786 .70794 m .41775 .70795 L .41747 .70804 L .675 .735 .895 r
F
.41786 .70794 m .41747 .70804 L .41748 .70805 L F
.41916 .71009 m .40631 .69156 L .41747 .70804 L .654 .726 .902 r
F
.41748 .70805 m .41747 .70804 L .41696 .7082 L .675 .735 .895 r
F
.41786 .70794 m .41889 .7062 L .41727 .70633 L F
.41846 .70794 m .41866 .70793 L .41884 .70089 L .661 .418 .542 r
F
.41883 .70785 m .41889 .7062 L .41786 .70794 L .675 .735 .895 r
F
.41916 .71009 m .41747 .70804 L .41857 .70967 L .654 .726 .902 r
F
.41846 .70789 m .41773 .715 L .41831 .71497 L .661 .418 .542 r
F
.41857 .70226 m .4182 .70791 L .41846 .70789 L F
.4182 .70791 m .41773 .715 L .41846 .70789 L F
.41696 .7082 m .41708 .70747 L .41575 .70674 L .675 .735 .895 r
F
.41708 .70747 m .41646 .70655 L .41575 .70674 L F
.41752 .70522 m .4176 .70519 L .41776 .70094 L .57 .345 .536 r
F
.41782 .70514 m .41722 .7035 L .4168 .70523 L .675 .735 .895 r
F
.41857 .70226 m .41776 .70234 L .41775 .70515 L .661 .418 .542 r
F
.41857 .70226 m .41775 .70515 L .41839 .70509 L F
.41779 .71958 m .41857 .75123 L .41755 .71953 L .751 .492 .541 r
F
.41266 .71136 m .40659 .7124 L .40776 .71439 L .675 .735 .895 r
F
.40675 .70813 m .4 .71023 L .40625 .71026 L F
.40675 .70813 m .40076 .70703 L .4 .71023 L F
.41364 .71517 m .3972 .70209 L .39208 .70596 L .654 .726 .902 r
F
.41548 .71388 m .41222 .71744 L .4152 .71828 L .675 .735 .895 r
F
.41523 .71802 m .41517 .71791 L .41513 .71078 L .989 .721 .392 r
F
.41507 .71068 m .41512 .71783 L .41505 .71771 L F
.4152 .7109 m .41543 .71838 L .41523 .71802 L F
.41872 .71735 m .41554 .71509 L .41364 .71517 L .654 .726 .902 r
F
.41503 .71729 m .41502 .71717 L .41502 .71002 L .789 .63 .07 r
F
.41502 .71717 m .41501 .71708 L .41501 .7099 L F
.41503 .71017 m .41505 .71771 L .41503 .71729 L F
.41513 .71078 m .41517 .71791 L .41507 .71068 L .989 .721 .392 r
F
.41517 .71791 m .41537 .74991 L .41512 .71783 L F
.41517 .71791 m .41512 .71783 L .41507 .71068 L F
.41421 .71322 m .41222 .71744 L .41548 .71388 L .675 .735 .895 r
F
.41554 .71509 m .41228 .71278 L .41364 .71517 L .654 .726 .902 r
F
.41325 .71236 m .40968 .71611 L .41421 .71322 L .675 .735 .895 r
F
.41266 .71136 m .40776 .71439 L .41325 .71236 L F
.41249 .71029 m .40625 .71026 L .40659 .7124 L F
.41274 .70923 m .40675 .70813 L .40625 .71026 L F
.41228 .71278 m .3972 .70209 L .41362 .71516 L .654 .726 .902 r
F
.41421 .71322 m .40968 .71611 L .41222 .71744 L .675 .735 .895 r
F
.41228 .71278 m .41362 .71516 L .41364 .71517 L .654 .726 .902 r
F
.41874 .71033 m .41341 .70824 L .41274 .70923 L .675 .735 .895 r
F
.41846 .70794 m .41831 .71497 L .41866 .70793 L .661 .418 .542 r
F
.41872 .71735 m .41742 .72014 L .41858 .72116 L .654 .726 .902 r
F
.41831 .71497 m .41768 .7463 L .41848 .71497 L .661 .418 .542 r
F
.41831 .71497 m .41848 .71497 L .41866 .70793 L F
.41543 .71838 m .41603 .7505 L .41537 .74991 L .927 .648 .492 r
F
.41544 .71135 m .41555 .71848 L .41543 .71838 L F
.41555 .71848 m .41603 .7505 L .41543 .71838 L F
.41479 .71781 m .41378 .71709 L .41395 .71791 L .654 .726 .902 r
F
.41872 .71735 m .41399 .7171 L .41479 .71781 L F
.41399 .7171 m .41378 .71709 L .41479 .71781 L F
.41536 .71628 m .41543 .71616 L .41554 .70895 L 0 0 .377 r
F
.41555 .71144 m .41563 .71856 L .41544 .71135 L .927 .648 .492 r
F
.41563 .71856 m .41603 .7505 L .41555 .71848 L F
.41563 .71856 m .41555 .71848 L .41544 .71135 L F
.41664 .71945 m .41239 .72166 L .4098 .72636 L .654 .726 .902 r
F
.41672 .71937 m .41662 .71943 L .41664 .71945 L F
.41662 .71943 m .41239 .72166 L .41664 .71945 L F
.41554 .70895 m .41543 .71616 L .41553 .71598 L 0 0 .377 r
F
.41501 .7099 m .41501 .71708 L .415 .71693 L .789 .63 .07 r
F
.41536 .70928 m .415 .71693 L .41528 .71642 L 0 0 .377 r
F
.4152 .71112 m .41544 .71155 L .41543 .71838 L .989 .721 .392 r
F
.41249 .71029 m .40659 .7124 L .41266 .71136 L .675 .735 .895 r
F
.40808 .70614 m .40076 .70703 L .40675 .70813 L F
.40808 .70614 m .40274 .70405 L .40076 .70703 L F
.41013 .70445 m .40274 .70405 L .40808 .70614 L F
.41013 .70445 m .40582 .7015 L .40274 .70405 L F
.41228 .71278 m .40378 .69926 L .3972 .70209 L .654 .726 .902 r
F
.41528 .71642 m .41536 .71628 L .41546 .7091 L 0 0 .377 r
F
.41737 .70807 m .41665 .70825 L .41664 .71528 L .57 .345 .536 r
F
.41872 .71735 m .41557 .71915 L .41672 .71937 L .654 .726 .902 r
F
.41654 .71918 m .41707 .71944 L .41701 .75097 L .844 .572 .527 r
F
.41722 .71513 m .41664 .71528 L .41658 .74663 L .57 .345 .536 r
F
.41737 .70807 m .41664 .71528 L .41722 .71513 L F
.41274 .70923 m .40625 .71026 L .41249 .71029 L .675 .735 .895 r
F
.41341 .70824 m .40808 .70614 L .40675 .70813 L F
.41603 .71544 m .40657 .70263 L .41228 .71278 L .654 .726 .902 r
F
.41732 .71246 m .41857 .75123 L .41708 .71241 L .751 .492 .541 r
F
.41872 .71735 m .41695 .7152 L .41603 .71544 L .654 .726 .902 r
F
.41341 .70824 m .40675 .70813 L .41274 .70923 L .675 .735 .895 r
F
.41695 .7152 m .40657 .70263 L .41603 .71544 L .654 .726 .902 r
F
.40657 .70263 m .40378 .69926 L .41228 .71278 L F
.41831 .71497 m .41773 .715 L .41768 .7463 L .661 .418 .542 r
F
.41872 .71735 m .41364 .71517 L .41275 .716 L .654 .726 .902 r
F
.41364 .71517 m .41012 .71367 L .4119 .71525 L F
.41364 .71517 m .4119 .71525 L .41275 .716 L F
.41748 .70242 m .41743 .70525 L .41768 .70236 L .57 .345 .536 r
F
.41743 .70525 m .41737 .70807 L .41752 .70522 L F
.41743 .70525 m .41752 .70522 L .41768 .70236 L F
.41781 .70513 m .41884 .70336 L .41722 .7035 L .675 .735 .895 r
F
.41782 .70514 m .41783 .70512 L .41781 .70513 L F
.41783 .70512 m .41884 .70336 L .41781 .70513 L F
.41851 .70508 m .41861 .70507 L .41877 .70225 L .661 .418 .542 r
F
.41877 .70505 m .41884 .70336 L .41782 .70514 L .675 .735 .895 r
F
.41857 .70226 m .41851 .70508 L .41877 .70225 L .661 .418 .542 r
F
.41851 .70508 m .41846 .70794 L .41861 .70507 L F
.41883 .70792 m .41768 .7463 L .41876 .74621 L F
.41911 .70993 m .42022 .71257 L .41918 .71266 L .642 .403 .542 r
F
.41916 .71009 m .41906 .71267 L .42009 .71258 L .654 .726 .902 r
F
.41874 .71033 m .4196 .71267 L .42042 .71256 L .675 .735 .895 r
F
.41874 .71033 m .42026 .71216 L .41926 .71069 L F
.41959 .70512 m .41882 .71495 L .41939 .71504 L .734 .478 .542 r
F
.41887 .68771 m .4186 .7009 L .41884 .70089 L .661 .418 .542 r
F
.41887 .68771 m .41776 .70094 L .4186 .7009 L F
.41778 .6878 m .41751 .701 L .41776 .70094 L .57 .345 .536 r
F
.41994 .68784 m .41887 .68771 L .41884 .70089 L .734 .478 .542 r
F
.41778 .6878 m .41666 .70122 L .41751 .701 L .57 .345 .536 r
F
.41888 .7009 m .42037 .68298 L .41231 .68324 L .654 .726 .902 r
F
.4196 .70283 m .41967 .70101 L .41888 .7009 L F
.41994 .68784 m .4194 .70097 L .41968 .70101 L .734 .478 .542 r
F
.41994 .68784 m .41884 .70089 L .4194 .70097 L F
.41967 .70101 m .42037 .68298 L .41888 .7009 L .654 .726 .902 r
F
.4218 .70207 m .42099 .70144 L .42099 .70271 L .908 .63 .503 r
F
.42066 .70243 m .42313 .70177 L .42187 .70111 L .675 .735 .895 r
F
.42075 .70135 m .41992 .70105 L .41992 .70235 L .809 .541 .534 r
F
.41862 .70465 m .42143 .70285 L .42054 .70256 L .675 .735 .895 r
F
.4206 .70258 m .41992 .70235 L .41991 .70808 L .809 .541 .534 r
F
.42075 .70135 m .41992 .70235 L .4206 .70258 L F
.42054 .70256 m .4219 .70256 L .42066 .70243 L .675 .735 .895 r
F
.4218 .70207 m .42099 .70271 L .42178 .7033 L .908 .63 .503 r
F
.42143 .70285 m .4219 .70256 L .42054 .70256 L .675 .735 .895 r
F
.4218 .70207 m .42178 .7033 L .42204 .70226 L .908 .63 .503 r
F
.4219 .70256 m .42313 .70177 L .42066 .70243 L .675 .735 .895 r
F
.41965 .70232 m .41923 .70509 L .41959 .70512 L .734 .478 .542 r
F
.41968 .70101 m .41953 .70231 L .41965 .70232 L F
.42025 .69253 m .42046 .70546 L .42023 .70554 L .519 .305 .529 r
F
.41862 .70465 m .42187 .70111 L .42038 .70069 L .675 .735 .895 r
F
.41953 .70231 m .41923 .70509 L .41965 .70232 L .734 .478 .542 r
F
.4194 .70097 m .41934 .70229 L .41968 .70101 L F
.41862 .70465 m .41966 .70232 L .41884 .70224 L .675 .735 .895 r
F
.41872 .70225 m .41884 .70224 L .41872 .70223 L F
.41862 .70465 m .41884 .70224 L .41872 .70225 L F
.41884 .70224 m .41874 .70506 L .41884 .70505 L .661 .418 .542 r
F
.41884 .70089 m .41881 .70224 L .41884 .70224 L F
.41881 .70224 m .41874 .70506 L .41884 .70224 L F
.4194 .70097 m .41884 .70089 L .41884 .70505 L .734 .478 .542 r
F
.41868 .70749 m .41973 .70514 L .41877 .70505 L .675 .735 .895 r
F
.41973 .70514 m .41884 .70505 L .41877 .70505 L F
.41692 .7026 m .41717 .70068 L .41565 .70108 L F
.41777 .70233 m .41717 .70068 L .41692 .7026 L F
.41878 .70055 m .41571 .6967 L .41717 .70068 L F
.41878 .70055 m .41894 .69644 L .41571 .6967 L F
.41884 .70336 m .41575 .6995 L .41722 .7035 L F
.41884 .70336 m .419 .69924 L .41575 .6995 L F
.41889 .7062 m .41581 .70234 L .41727 .70633 L F
.41877 .70505 m .41879 .70504 L .41877 .70504 L F
.41874 .70506 m .41866 .70793 L .41884 .70505 L .661 .418 .542 r
F
.41889 .7062 m .41905 .70208 L .41581 .70234 L .675 .735 .895 r
F
.41894 .69644 m .41425 .69272 L .41571 .6967 L F
.41894 .69644 m .4191 .69233 L .41425 .69272 L F
.419 .69924 m .41429 .6955 L .41575 .6995 L F
.419 .69924 m .41915 .69511 L .41429 .6955 L F
.41905 .70208 m .41434 .69834 L .41581 .70234 L F
.41905 .70208 m .41921 .69795 L .41434 .69834 L F
.41915 .69511 m .41423 .69266 L .41429 .6955 L .666 .427 .548 r
F
.41915 .69511 m .4191 .69227 L .41423 .69266 L F
.41921 .69795 m .41429 .6955 L .41434 .69834 L F
.41921 .69795 m .41915 .69511 L .41429 .6955 L F
.41833 .70785 m .41994 .69014 L .41183 .6904 L .654 .726 .902 r
F
.41916 .71009 m .41924 .70798 L .41833 .70785 L F
.41923 .70509 m .41884 .70505 L .41883 .70792 L .734 .478 .542 r
F
.41868 .70749 m .42061 .70539 L .41991 .70516 L .675 .735 .895 r
F
.41923 .70509 m .41883 .70792 L .41911 .70796 L .734 .478 .542 r
F
.4194 .70097 m .41884 .70505 L .41923 .70509 L F
.41872 .70223 m .42038 .70069 L .41878 .70055 L .675 .735 .895 r
F
.41934 .70229 m .41953 .70231 L .41968 .70101 L .734 .478 .542 r
F
.41966 .70232 m .42038 .70069 L .41872 .70223 L .675 .735 .895 r
F
.41934 .70229 m .41923 .70509 L .41953 .70231 L .734 .478 .542 r
F
.41992 .70105 m .41982 .70515 L .41991 .70516 L F
.41877 .70504 m .42045 .70351 L .41884 .70336 L .675 .735 .895 r
F
.41879 .70504 m .42045 .70351 L .41877 .70504 L F
.41884 .70505 m .41866 .70793 L .41883 .70792 L .661 .418 .542 r
F
.42101 .68821 m .41992 .70105 L .42075 .70135 L .809 .541 .534 r
F
.4196 .70283 m .42098 .69988 L .41982 .69727 L .654 .726 .902 r
F
.42038 .70069 m .41894 .69644 L .41878 .70055 L .675 .735 .895 r
F
.42045 .70351 m .419 .69924 L .41884 .70336 L F
.42206 .68903 m .42099 .70144 L .4218 .70207 L .908 .63 .503 r
F
.42187 .70111 m .42214 .69674 L .42038 .70069 L .675 .735 .895 r
F
.42045 .70351 m .42222 .69954 L .419 .69924 L F
.42228 .70238 m .41921 .69795 L .41905 .70208 L F
.41924 .70798 m .41994 .69014 L .41833 .70785 L .654 .726 .902 r
F
.41911 .70796 m .41883 .70792 L .41882 .71495 L .734 .478 .542 r
F
.41973 .70514 m .41981 .70496 L .41884 .70505 L .675 .735 .895 r
F
.41923 .70509 m .41882 .71495 L .41959 .70512 L .734 .478 .542 r
F
.41968 .70101 m .41959 .70512 L .41992 .70105 L F
.42633 .71748 m .43571 .71824 L .4374 .71767 L .654 .726 .902 r
F
.42421 .7167 m .4374 .71767 L .42784 .71627 L F
.42195 .70923 m .42176 .71612 L .42203 .70929 L .908 .63 .503 r
F
.42232 .71099 m .42473 .71143 L .42272 .71035 L .675 .735 .895 r
F
.42295 .71094 m .44909 .71682 L .42378 .71033 L .654 .726 .902 r
F
.42232 .70994 m .42241 .71013 L .42241 .70997 L .985 .728 .345 r
F
.42232 .70994 m .42241 .70997 L .42233 .70978 L F
.42923 .70881 m .43453 .7109 L .4365 .70794 L .675 .735 .895 r
F
.43665 .71079 m .43659 .70795 L .43736 .70475 L 0 0 .254 r
F
.43665 .71079 m .43736 .70475 L .43741 .70759 L F
.43066 .70969 m .43665 .71079 L .43741 .70759 L .675 .735 .895 r
F
.43123 .7104 m .43747 .71043 L .43696 .70723 L F
.42923 .70881 m .4365 .70794 L .43054 .70684 L F
.43066 .70969 m .43741 .70759 L .43117 .70756 L F
.43123 .7104 m .43696 .70723 L .43088 .70826 L F
.42498 .71036 m .43123 .7104 L .43088 .70826 L F
.42498 .71036 m .43088 .70826 L .42481 .70929 L F
.42255 .70969 m .45036 .71172 L .4495 .7065 L .654 .726 .902 r
F
.41916 .71009 m .42335 .71031 L .42255 .70969 L F
.42335 .71031 m .45036 .71172 L .42255 .70969 L F
.42172 .70607 m .42166 .709 L .42203 .7063 L .908 .63 .503 r
F
.42202 .71632 m .42784 .71627 L .42398 .71571 L .654 .726 .902 r
F
.41872 .71735 m .42274 .71687 L .42202 .71632 L F
.42199 .71352 m .42256 .71555 L .42821 .72105 L F
.42274 .71687 m .42784 .71627 L .42202 .71632 L F
.42211 .70917 m .42256 .70951 L .42263 .70908 L .675 .735 .895 r
F
.42211 .70917 m .42263 .70908 L .42266 .70888 L F
.42203 .70911 m .42211 .70917 L .42266 .70888 L F
.41916 .71009 m .42386 .70953 L .42252 .70904 L .654 .726 .902 r
F
.42147 .71195 m .42193 .71168 L .42147 .71202 L .359 .182 .499 r
F
.42166 .709 m .42153 .71594 L .42195 .70923 L .908 .63 .503 r
F
.41872 .71735 m .42345 .71743 L .42274 .71687 L .654 .726 .902 r
F
.42153 .71594 m .42091 .74671 L .42176 .71612 L .908 .63 .503 r
F
.41916 .71009 m .42295 .71094 L .42357 .71048 L .654 .726 .902 r
F
.42153 .71594 m .42176 .71612 L .42195 .70923 L .908 .63 .503 r
F
.42166 .709 m .42195 .70923 L .42203 .7063 L F
.42398 .71571 m .44907 .71376 L .44614 .70879 L .654 .726 .902 r
F
.42784 .71627 m .44907 .71376 L .42398 .71571 L F
.41959 .70512 m .41939 .71504 L .41982 .70515 L .734 .478 .542 r
F
.42176 .71612 m .42182 .71617 L .42203 .70929 L .908 .63 .503 r
F
.42203 .70929 m .42182 .71617 L .42202 .71632 L F
.42254 .70968 m .42481 .70929 L .42266 .70888 L .675 .735 .895 r
F
.42386 .70953 m .42506 .70939 L .42252 .70904 L .654 .726 .902 r
F
.42335 .71031 m .42357 .71048 L .42378 .71033 L F
.42147 .71202 m .42155 .71898 L .4214 .71207 L .359 .182 .499 r
F
.42167 .70884 m .42097 .7155 L .42153 .71594 L .908 .63 .503 r
F
.42222 .70954 m .42202 .71632 L .42232 .70977 L .985 .728 .345 r
F
.42232 .70994 m .42226 .71685 L .42241 .71013 L F
.42022 .71257 m .42117 .75059 L .42015 .75103 L .519 .305 .529 r
F
.42458 .70575 m .43054 .70684 L .43105 .70472 L .675 .735 .895 r
F
.42392 .70673 m .43054 .70684 L .42458 .70575 L F
.42458 .70575 m .43105 .70472 L .42484 .70469 L F
.42484 .70469 m .43105 .70472 L .43071 .70259 L F
.42484 .70469 m .43071 .70259 L .42467 .70362 L F
.42467 .70362 m .42954 .7006 L .42408 .70263 L F
.42467 .70362 m .43071 .70259 L .42954 .7006 L F
.42492 .70752 m .43083 .70542 L .42475 .70646 L F
.43071 .70259 m .435 .69858 L .42954 .7006 L F
.43071 .70259 m .43675 .70156 L .435 .69858 L F
.42408 .70263 m .42954 .7006 L .42763 .69889 L F
.42475 .70646 m .42966 .70342 L .42417 .70546 L F
.42475 .70646 m .43083 .70542 L .42966 .70342 L F
.43105 .70472 m .43675 .70156 L .43071 .70259 L F
.43083 .70542 m .43515 .70139 L .42966 .70342 L F
.42417 .70546 m .42774 .7017 L .42321 .7046 L F
.42417 .70546 m .42966 .70342 L .42774 .7017 L F
.42203 .7063 m .42195 .70923 L .42203 .70929 L .908 .63 .503 r
F
.42954 .7006 m .435 .69858 L .43214 .69601 L .675 .735 .895 r
F
.42966 .70342 m .43227 .69881 L .42774 .7017 L F
.42966 .70342 m .43515 .70139 L .43227 .69881 L F
.43515 .70139 m .43509 .69855 L .43221 .69597 L .932 .65 .484 r
F
.42326 .70744 m .42526 .70322 L .422 .70677 L .675 .735 .895 r
F
.42326 .70744 m .42779 .70454 L .42526 .70322 L F
.43515 .70139 m .43221 .69597 L .43227 .69881 L .932 .65 .484 r
F
.4352 .70423 m .43515 .70139 L .43227 .69881 L F
.42779 .70454 m .42852 .69966 L .42526 .70322 L .675 .735 .895 r
F
.42779 .70454 m .43232 .70165 L .42852 .69966 L F
.4352 .70423 m .43227 .69881 L .43232 .70165 L .932 .65 .484 r
F
.42954 .7006 m .43214 .69601 L .42763 .69889 L .675 .735 .895 r
F
.42774 .7017 m .43227 .69881 L .42846 .69682 L F
.43232 .70165 m .43227 .69881 L .42846 .69682 L .86 .586 .522 r
F
.43232 .70165 m .42846 .69682 L .42852 .69966 L F
.41916 .71009 m .44178 .69714 L .43544 .69363 L .654 .726 .902 r
F
.42173 .70842 m .42422 .7083 L .42326 .70744 L .675 .735 .895 r
F
.41955 .70987 m .42022 .70978 L .42049 .70966 L F
.41874 .71033 m .42203 .70911 L .4218 .70859 L F
.42157 .70852 m .4218 .70859 L .42173 .70842 L F
.41874 .71033 m .4218 .70859 L .42157 .70852 L F
.42057 .71244 m .42047 .71248 L .42022 .71257 L .519 .305 .529 r
F
.42022 .70978 m .42057 .71244 L .42022 .71257 L F
.42026 .71216 m .42172 .71392 L .41926 .71069 L .675 .735 .895 r
F
.42057 .71244 m .42057 .71244 L .42047 .71248 L .519 .305 .529 r
F
.41926 .71069 m .42059 .71243 L .42133 .7121 L .675 .735 .895 r
F
.41916 .71009 m .42009 .71258 L .42114 .71249 L .654 .726 .902 r
F
.41874 .71033 m .42149 .71398 L .42026 .71216 L .675 .735 .895 r
F
.42098 .70832 m .42065 .71539 L .42097 .7155 L .809 .541 .534 r
F
.42099 .70271 m .42084 .70827 L .42098 .70832 L F
.42084 .70827 m .42065 .71539 L .42098 .70832 L F
.42203 .70911 m .42422 .7083 L .42173 .70842 L .675 .735 .895 r
F
.43054 .70684 m .43726 .70475 L .43105 .70472 L F
.42492 .70752 m .43117 .70756 L .43083 .70542 L F
.4369 .70439 m .43684 .70155 L .43509 .69855 L .987 .712 .387 r
F
.43083 .70542 m .4369 .70439 L .43515 .70139 L .675 .735 .895 r
F
.4369 .70439 m .43509 .69855 L .43515 .70139 L .987 .712 .387 r
F
.43696 .70723 m .4369 .70439 L .43515 .70139 L F
.42422 .7083 m .42779 .70454 L .42326 .70744 L .675 .735 .895 r
F
.42422 .7083 m .42971 .70626 L .42779 .70454 L F
.43696 .70723 m .43515 .70139 L .4352 .70423 L .987 .712 .387 r
F
.42971 .70626 m .43232 .70165 L .42779 .70454 L .675 .735 .895 r
F
.42971 .70626 m .4352 .70423 L .43232 .70165 L F
.41916 .71009 m .44657 .70153 L .44178 .69714 L .654 .726 .902 r
F
.42774 .7017 m .42846 .69682 L .4252 .70038 L .675 .735 .895 r
F
.41978 .71509 m .435 .70089 L .42755 .69851 L .654 .726 .902 r
F
.41872 .71735 m .42081 .71524 L .41978 .71509 L F
.4224 .71079 m .42248 .71029 L .42246 .71732 L 0 0 .138 r
F
.42081 .71524 m .435 .70089 L .41978 .71509 L .654 .726 .902 r
F
.43741 .70759 m .43684 .70155 L .4369 .70439 L .858 .66 .125 r
F
.43117 .70756 m .43741 .70759 L .4369 .70439 L .675 .735 .895 r
F
.43117 .70756 m .4369 .70439 L .43083 .70542 L F
.43088 .70826 m .4352 .70423 L .42971 .70626 L F
.43088 .70826 m .43696 .70723 L .4352 .70423 L F
.4278 .70739 m .4495 .7065 L .44657 .70153 L .654 .726 .902 r
F
.43747 .71043 m .43741 .70759 L .4369 .70439 L .858 .66 .125 r
F
.43747 .71043 m .4369 .70439 L .43696 .70723 L F
.42481 .70929 m .43088 .70826 L .42971 .70626 L .675 .735 .895 r
F
.42506 .70939 m .4495 .7065 L .4278 .70739 L .654 .726 .902 r
F
.42212 .71842 m .42206 .71852 L .422 .71158 L .077 0 .416 r
F
.42232 .70977 m .42202 .71632 L .42226 .71685 L .985 .728 .345 r
F
.42081 .71524 m .44134 .7044 L .435 .70089 L .654 .726 .902 r
F
.41872 .71735 m .42207 .71543 L .42081 .71524 L F
.42233 .71701 m .42238 .71713 L .42248 .71012 L .985 .728 .345 r
F
.42248 .71012 m .42238 .71713 L .42246 .71732 L F
.42226 .71685 m .42233 .71701 L .42241 .71013 L F
.42207 .71543 m .44134 .7044 L .42081 .71524 L .654 .726 .902 r
F
.41974 .70805 m .41956 .71506 L .41991 .70808 L .734 .478 .542 r
F
.41956 .71506 m .41876 .74621 L .4197 .71508 L F
.41956 .71506 m .4197 .71508 L .41991 .70808 L F
.4199 .71511 m .41876 .74621 L .41984 .74633 L F
.41991 .70808 m .4197 .71508 L .4199 .71511 L F
.4197 .71508 m .41876 .74621 L .4199 .71511 L F
.41939 .71504 m .41876 .74621 L .41956 .71506 L F
.41939 .71504 m .41956 .71506 L .41982 .70515 L F
.42176 .71612 m .42091 .74671 L .42182 .71617 L .908 .63 .503 r
F
.42274 .71687 m .42633 .71748 L .42421 .7167 L .654 .726 .902 r
F
.42345 .71743 m .42633 .71748 L .42274 .71687 L F
.42633 .71748 m .4374 .71767 L .42421 .7167 L F
.42061 .70834 m .41991 .70808 L .4199 .71511 L .809 .541 .534 r
F
.41872 .71735 m .42018 .72126 L .42099 .72008 L .654 .726 .902 r
F
.41936 .71968 m .42021 .7196 L .42015 .75103 L .642 .403 .542 r
F
.42047 .71532 m .4199 .71511 L .41984 .74633 L .809 .541 .534 r
F
.42061 .70834 m .4199 .71511 L .42047 .71532 L F
.42202 .71632 m .42091 .74671 L .42196 .74752 L .908 .63 .503 r
F
.41872 .71735 m .42368 .71761 L .42345 .71743 L .654 .726 .902 r
F
.42182 .71617 m .42091 .74671 L .42202 .71632 L .908 .63 .503 r
F
.42345 .71743 m .42718 .71779 L .42633 .71748 L .654 .726 .902 r
F
.42368 .71761 m .42718 .71779 L .42345 .71743 L F
.42718 .71779 m .43571 .71824 L .42633 .71748 L F
.42061 .7082 m .42047 .71532 L .42084 .70827 L .809 .541 .534 r
F
.42047 .71532 m .41984 .74633 L .42065 .71539 L F
.41916 .71009 m .42128 .71265 L .42176 .71193 L .654 .726 .902 r
F
.42047 .71532 m .42065 .71539 L .42084 .70827 L .809 .541 .534 r
F
.41959 .70512 m .41982 .70515 L .41992 .70105 L .734 .478 .542 r
F
.41981 .70496 m .42045 .70351 L .41879 .70504 L .675 .735 .895 r
F
.41884 .70505 m .41879 .70504 L .41877 .70505 L F
.41981 .70496 m .41879 .70504 L .41884 .70505 L F
.41866 .70793 m .41768 .7463 L .41883 .70792 L .661 .418 .542 r
F
.41737 .70807 m .41722 .71513 L .41749 .70803 L .57 .345 .536 r
F
.41275 .716 m .39208 .70596 L .38878 .71061 L .654 .726 .902 r
F
.41325 .71236 m .40776 .71439 L .40968 .71611 L .675 .735 .895 r
F
.41012 .71367 m .39208 .70596 L .41275 .716 L .654 .726 .902 r
F
.41612 .71561 m .41553 .71598 L .41547 .7474 L .403 .215 .509 r
F
.41627 .70849 m .41553 .71598 L .41612 .71561 L F
.41378 .71709 m .41333 .71613 L .41032 .71691 L .654 .726 .902 r
F
.41477 .71646 m .41333 .71613 L .41378 .71709 L F
.40659 .7124 m .40228 .71643 L .40776 .71439 L .675 .735 .895 r
F
.40659 .7124 m .40052 .71343 L .40228 .71643 L F
.41333 .71613 m .38878 .71061 L .41032 .71691 L .654 .726 .902 r
F
.41722 .71513 m .41658 .74663 L .41739 .71509 L .57 .345 .536 r
F
.41722 .71513 m .41739 .71509 L .41776 .70094 L F
.41629 .7155 m .41547 .7474 L .41643 .71541 L .403 .215 .509 r
F
.41629 .7155 m .41643 .71541 L .41665 .70825 L F
.41378 .71709 m .41209 .717 L .41312 .7175 L .654 .726 .902 r
F
.41378 .71709 m .41312 .7175 L .41395 .71791 L F
.41209 .717 m .38752 .71571 L .41395 .71791 L F
.41664 .71528 m .41547 .7474 L .41658 .74663 L .403 .215 .509 r
F
.41665 .70825 m .41643 .71541 L .41664 .71528 L F
.41643 .71541 m .41547 .7474 L .41664 .71528 L F
.40813 .72065 m .40002 .71955 L .39133 .72589 L .654 .726 .902 r
F
.40968 .71611 m .40516 .719 L .40896 .72099 L .675 .735 .895 r
F
.41213 .71812 m .40002 .71955 L .40813 .72065 L .654 .726 .902 r
F
.40002 .71955 m .38839 .72093 L .38922 .72233 L F
.40002 .71955 m .38922 .72233 L .39133 .72589 L F
.41773 .715 m .41658 .74663 L .41768 .7463 L .57 .345 .536 r
F
.41776 .70094 m .41739 .71509 L .41773 .715 L F
.41739 .71509 m .41658 .74663 L .41773 .715 L F
.41523 .71802 m .41537 .74991 L .41517 .71791 L .989 .721 .392 r
F
.41612 .71561 m .41547 .7474 L .41629 .7155 L .403 .215 .509 r
F
.41612 .71561 m .41629 .7155 L .41648 .70836 L F
.41503 .71729 m .41499 .74923 L .41502 .71717 L .789 .63 .07 r
F
.41505 .71771 m .41537 .74991 L .41499 .74923 L .989 .721 .392 r
F
.41512 .71783 m .41537 .74991 L .41505 .71771 L F
.41557 .71915 m .41295 .72065 L .41611 .71958 L .654 .726 .902 r
F
.41295 .72065 m .39613 .73028 L .41239 .72166 L F
.41295 .72065 m .41239 .72166 L .41672 .71937 L F
.41546 .7091 m .41536 .71628 L .41554 .70895 L 0 0 .377 r
F
.41536 .71628 m .41494 .74842 L .41543 .71616 L F
.41523 .71802 m .41543 .71838 L .41537 .74991 L .989 .721 .392 r
F
.41553 .71598 m .41494 .74842 L .41547 .7474 L 0 0 .377 r
F
.41543 .71616 m .41494 .74842 L .41553 .71598 L F
.4098 .72636 m .39613 .73028 L .40246 .73378 L .654 .726 .902 r
F
.41239 .72166 m .39613 .73028 L .4098 .72636 L F
.39642 .69761 m .38981 .69613 L .38969 .69663 L F
.39642 .69761 m .38969 .69663 L .38856 .70121 L F
.41502 .71021 m .41502 .71717 L .41501 .71009 L .789 .63 .07 r
F
.41502 .71717 m .41499 .74923 L .41501 .71708 L F
.415 .71693 m .41499 .74923 L .41494 .74842 L F
.41501 .71708 m .41499 .74923 L .415 .71693 L F
.41527 .72084 m .4098 .72636 L .41532 .7216 L .654 .726 .902 r
F
.4098 .72636 m .40246 .73378 L .40917 .72752 L F
.41536 .70928 m .41501 .7099 L .415 .71693 L 0 0 .377 r
F
.41503 .71729 m .41505 .71771 L .41499 .74923 L .789 .63 .07 r
F
.41528 .71642 m .415 .71693 L .41494 .74842 L 0 0 .377 r
F
.41536 .70928 m .41528 .71642 L .41546 .7091 L F
.41528 .71642 m .41494 .74842 L .41536 .71628 L F
.40917 .72752 m .40246 .73378 L .40523 .73466 L .654 .726 .902 r
F
.40917 .72752 m .40523 .73466 L .40991 .73616 L F
.41932 .71893 m .4193 .71968 L .41958 .71966 L F
.41872 .71735 m .4193 .71968 L .41932 .71893 L F
.41872 .71735 m .41863 .71974 L .4193 .71968 L F
.41939 .71504 m .41882 .71495 L .41876 .74621 L .734 .478 .542 r
F
.42784 .71627 m .4374 .71767 L .44907 .71376 L .654 .726 .902 r
F
.44099 .718 m .47255 .72546 L .44608 .71415 L F
.43571 .71824 m .44992 .71898 L .4496 .71701 L F
.43571 .71824 m .4496 .71701 L .44907 .71376 L F
.41883 .70785 m .42051 .70635 L .41889 .7062 L .675 .735 .895 r
F
.41991 .70516 m .41975 .70795 L .41991 .70796 L .734 .478 .542 r
F
.41979 .70795 m .42051 .70635 L .41883 .70785 L .675 .735 .895 r
F
.41991 .70796 m .41974 .70805 L .41991 .70808 L .734 .478 .542 r
F
.41975 .70795 m .41974 .70805 L .41991 .70796 L F
.41982 .70515 m .41974 .70805 L .41991 .70516 L F
.41973 .70514 m .41991 .70516 L .41974 .7051 L .675 .735 .895 r
F
.41994 .68784 m .41968 .70101 L .41992 .70105 L .734 .478 .542 r
F
.42072 .70262 m .42067 .70541 L .42099 .70271 L .809 .541 .534 r
F
.42178 .7033 m .42099 .70271 L .42098 .70551 L .908 .63 .503 r
F
.41974 .7051 m .42194 .70393 L .42045 .70351 L .675 .735 .895 r
F
.42061 .70539 m .42194 .70393 L .41974 .7051 L F
.42025 .69253 m .42127 .6921 L .42125 .70516 L .519 .305 .529 r
F
.42101 .68821 m .42072 .70262 L .42099 .70271 L .809 .541 .534 r
F
.42251 .69006 m .42206 .68903 L .42204 .70226 L .985 .728 .345 r
F
.42098 .69988 m .42838 .68408 L .41982 .69727 L .654 .726 .902 r
F
.42187 .70111 m .42511 .69757 L .42214 .69674 L .675 .735 .895 r
F
.42038 .70069 m .42214 .69674 L .41894 .69644 L F
.42178 .7033 m .42194 .70342 L .42204 .70226 L .908 .63 .503 r
F
.42194 .70393 m .42222 .69954 L .42045 .70351 L .675 .735 .895 r
F
.42511 .69757 m .42391 .69278 L .42214 .69674 L F
.42511 .69757 m .42836 .69403 L .42391 .69278 L F
.42051 .70635 m .41905 .70208 L .41889 .7062 L F
.42051 .70635 m .42228 .70238 L .41905 .70208 L F
.41982 .69727 m .42838 .68408 L .42037 .68298 L .654 .726 .902 r
F
.42214 .69674 m .4191 .69233 L .41894 .69644 L .675 .735 .895 r
F
.42214 .69674 m .42391 .69278 L .4191 .69233 L F
.4252 .70038 m .42399 .69556 L .42222 .69954 L F
.42222 .69954 m .41915 .69511 L .419 .69924 L F
.42222 .69954 m .42399 .69556 L .41915 .69511 L F
.42228 .70238 m .42405 .6984 L .41921 .69795 L F
.42399 .69556 m .42393 .69272 L .4191 .69227 L .731 .478 .546 r
F
.42846 .69682 m .42393 .69272 L .42399 .69556 L .793 .53 .539 r
F
.42399 .69556 m .4191 .69227 L .41915 .69511 L .731 .478 .546 r
F
.42405 .6984 m .42399 .69556 L .41915 .69511 L F
.42405 .6984 m .41915 .69511 L .41921 .69795 L F
.41925 .70784 m .42799 .69124 L .41994 .69014 L .654 .726 .902 r
F
.41924 .70798 m .41931 .70786 L .41925 .70784 L F
.4213 .70294 m .42408 .70263 L .42313 .70177 L .675 .735 .895 r
F
.42236 .70297 m .42409 .70384 L .42301 .70301 L .654 .726 .902 r
F
.42194 .70342 m .42408 .70263 L .4213 .70294 L .675 .735 .895 r
F
.42194 .70342 m .42204 .7035 L .422 .7034 L F
.42204 .7035 m .42257 .7039 L .422 .7034 L F
.42313 .70177 m .42511 .69757 L .42187 .70111 L F
.42194 .70393 m .4252 .70038 L .42222 .69954 L F
.41931 .70786 m .42799 .69124 L .41925 .70784 L .654 .726 .902 r
F
.42178 .7033 m .42172 .70607 L .42194 .70342 L .908 .63 .503 r
F
.42067 .70541 m .42061 .7082 L .4208 .70545 L .809 .541 .534 r
F
.422 .7034 m .42257 .7039 L .42268 .70315 L .675 .735 .895 r
F
.4226 .70351 m .42409 .70384 L .42236 .70297 L .654 .726 .902 r
F
.42268 .70315 m .42467 .70362 L .42408 .70263 L .675 .735 .895 r
F
.42256 .70398 m .42467 .70362 L .42268 .70315 L F
.42321 .7046 m .4252 .70038 L .42194 .70393 L F
.422 .70677 m .42526 .70322 L .42228 .70238 L F
.42009 .70811 m .42799 .69124 L .41924 .70798 L .654 .726 .902 r
F
.41872 .71735 m .4226 .71822 L .42302 .71791 L F
.4226 .71822 m .42342 .7184 L .42302 .71791 L F
.42156 .71572 m .4288 .71368 L .44134 .7044 L F
.4288 .71368 m .44614 .70879 L .44141 .70446 L F
.4288 .71368 m .44141 .70446 L .44134 .7044 L F
.41872 .71735 m .42265 .71612 L .42156 .71572 L F
.42265 .71612 m .44614 .70879 L .42156 .71572 L F
.42097 .7155 m .41984 .74633 L .42091 .74671 L .809 .541 .534 r
F
.42065 .71539 m .41984 .74633 L .42097 .7155 L F
.42153 .71594 m .42097 .7155 L .42091 .74671 L .908 .63 .503 r
F
.42368 .71761 m .42429 .71808 L .42533 .71769 L .654 .726 .902 r
F
.42342 .7184 m .44866 .72408 L .42533 .71769 L F
.42206 .71852 m .4223 .74936 L .422 .71859 L .077 0 .416 r
F
.42231 .71814 m .42235 .71808 L .42235 .7195 L F
.42231 .71814 m .42235 .7195 L .4223 .74936 L F
.42212 .71842 m .42231 .71814 L .4223 .74936 L F
.42233 .71701 m .42196 .74752 L .42238 .71713 L .985 .728 .345 r
F
.42235 .71808 m .42241 .74856 L .4223 .74936 L 0 0 .138 r
F
.42237 .71794 m .42241 .74856 L .42235 .71808 L F
.4224 .71773 m .42241 .74856 L .42239 .71784 L F
.4224 .71773 m .42246 .71732 L .42241 .74856 L F
.42246 .71732 m .42196 .74752 L .42241 .74856 L .985 .728 .345 r
F
.42238 .71713 m .42196 .74752 L .42246 .71732 L F
.42172 .71947 m .42421 .72124 L .42335 .71932 L .654 .726 .902 r
F
.42421 .72124 m .44023 .73259 L .42336 .71933 L F
.42421 .72124 m .42336 .71933 L .42335 .71932 L F
.42192 .71871 m .4223 .74936 L .42187 .75003 L .077 0 .416 r
F
.422 .71859 m .4223 .74936 L .42192 .71871 L F
.42226 .71685 m .42202 .71632 L .42196 .74752 L .985 .728 .345 r
F
.42212 .71842 m .4223 .74936 L .42206 .71852 L .077 0 .416 r
F
.42226 .71685 m .42196 .74752 L .42233 .71701 L .985 .728 .345 r
F
.42689 .72724 m .43081 .73601 L .43365 .73541 L .654 .726 .902 r
F
.42069 .70529 m .42321 .7046 L .42194 .70393 L .675 .735 .895 r
F
.42135 .70579 m .42321 .7046 L .42069 .70529 L F
.47255 .72546 m .50889 .72293 L .47914 .71623 L .654 .726 .902 r
F
.44608 .71415 m .47255 .72546 L .47914 .71623 L F
.38883 .71367 m .36439 .72718 L .39177 .71864 L F
.38883 .71367 m .35852 .71725 L .36439 .72718 L F
.47238 .73283 m .50891 .73028 L .47901 .72355 L F
.44578 .72146 m .47238 .73283 L .47901 .72355 L F
.44066 .72533 m .47238 .73283 L .44578 .72146 L F
.32557 .70519 m .32866 .71357 L .32821 .72083 L .927 .746 .262 r
F
0 g
.33124 .70487 m
.33748 .71253 L
s
.32557 .70519 m .32602 .69793 L .32866 .71357 L .927 .746 .262 r
F
0 g
.32614 .69859 m
.33124 .70487 L
s
.32866 .71357 m
.33265 .7203 L
s
.35753 .69958 m .32912 .71352 L .35927 .70996 L .654 .726 .902 r
F
.35753 .69958 m .32649 .69796 L .32912 .71352 L F
.50891 .73028 m .50934 .72303 L .51318 .70773 L 0 0 .147 r
F
0 g
.50481 .72936 m
.50934 .72303 L
s
.47914 .71623 m .50889 .72293 L .51271 .7077 L .654 .726 .902 r
F
.38839 .72093 m .36395 .73444 L .39133 .72589 L F
.38839 .72093 m .35807 .72451 L .36395 .73444 L F
.47195 .74009 m .50849 .73754 L .47858 .73081 L F
.44535 .72872 m .47195 .74009 L .47858 .73081 L F
.44023 .73259 m .47195 .74009 L .44535 .72872 L F
.32512 .71245 m .32821 .72083 L .32776 .72808 L .927 .746 .262 r
F
.32512 .71245 m .32557 .70519 L .32821 .72083 L F
.35677 .70682 m .32821 .72083 L .35852 .71725 L .654 .726 .902 r
F
.35677 .70682 m .32557 .70519 L .32821 .72083 L F
0 g
.32821 .72083 m
.3322 .72756 L
s
.50891 .73028 m .51318 .70773 L .51275 .71499 L 0 0 .147 r
F
.50849 .73754 m .50891 .73028 L .51275 .71499 L F
.47901 .72355 m .50891 .73028 L .51275 .71499 L .654 .726 .902 r
F
0 g
.50438 .73662 m
.50891 .73028 L
s
.38856 .70121 m .35927 .70996 L .38943 .70639 L .654 .726 .902 r
F
.38856 .70121 m .35753 .69958 L .35927 .70996 L F
.47914 .71623 m .51271 .7077 L .48167 .70608 L F
.44937 .70953 m .47914 .71623 L .48167 .70608 L F
.44608 .71415 m .47914 .71623 L .44937 .70953 L F
0 g
.42207 .68321 m
.42216 .63068 L
s
.41559 .68313 m
.41568 .63056 L
s
.35632 .71408 m .32776 .72808 L .35807 .72451 L .654 .726 .902 r
F
.35632 .71408 m .32512 .71245 L .32776 .72808 L F
0 g
.32776 .72808 m
.33659 .74297 L
s
.50849 .73754 m .51275 .71499 L .51233 .72225 L 0 0 .147 r
F
.47858 .73081 m .50849 .73754 L .51233 .72225 L .654 .726 .902 r
F
0 g
.49854 .75145 m
.50849 .73754 L
s
.38797 .70845 m .35852 .71725 L .38883 .71367 L .654 .726 .902 r
F
.38797 .70845 m .35677 .70682 L .35852 .71725 L F
.127 .923 .03 r
.35308 .70663 m
.35322 .70549 L
s
.35322 .70549 m
.35322 .70664 L
s
.47901 .72355 m .51275 .71499 L .48155 .71335 L .654 .726 .902 r
F
.44909 .71682 m .47901 .72355 L .48155 .71335 L F
.44578 .72146 m .47901 .72355 L .44909 .71682 L F
.44937 .70953 m .48167 .70608 L .45064 .70445 L F
.41625 .8271 m .41594 .82145 L .43539 .81956 L .672 .451 .576 r
F
.39694 .82593 m .41594 .82145 L .41625 .8271 L .733 .498 .571 r
F
.39694 .82593 m .39664 .82027 L .41594 .82145 L F
.41663 .80627 m .41595 .82122 L .4353 .81934 L .673 .758 .914 r
F
.40382 .80549 m .41595 .82122 L .41663 .80627 L F
.40382 .80549 m .39674 .82005 L .41595 .82122 L F
.4357 .82521 m .43539 .81956 L .45365 .81472 L .604 .398 .576 r
F
.41625 .8271 m .43539 .81956 L .4357 .82521 L .672 .451 .576 r
F
0 g
.41594 .82145 m
.43539 .81956 L
s
.42954 .80502 m .4353 .81934 L .45347 .81453 L .673 .758 .914 r
F
.41663 .80627 m .4353 .81934 L .42954 .80502 L F
.127 .923 .03 r
.3522 .71386 m
.35229 .71311 L
s
.38752 .71571 m .35807 .72451 L .38839 .72093 L .654 .726 .902 r
F
.38752 .71571 m .35632 .71408 L .35807 .72451 L F
.47858 .73081 m .51233 .72225 L .48113 .72061 L F
.44866 .72408 m .47858 .73081 L .48113 .72061 L F
.44535 .72872 m .47858 .73081 L .44866 .72408 L F
.127 .923 .03 r
.35325 .71239 m
.35326 .71392 L
s
.37908 .82176 m .39664 .82027 L .39694 .82593 L .793 .545 .562 r
F
0 g
.3838 .82136 m
.38385 .79947 L
s
.37908 .82176 m .37878 .81611 L .39664 .82027 L .793 .545 .562 r
F
0 g
.39664 .82027 m
.41594 .82145 L
s
.39197 .80272 m .39674 .82005 L .40382 .80549 L .673 .758 .914 r
F
.39197 .80272 m .37897 .81591 L .39674 .82005 L F
.41656 .83276 m .41625 .8271 L .4357 .82521 L .672 .451 .576 r
F
.39725 .83158 m .41625 .8271 L .41656 .83276 L .733 .498 .571 r
F
.39725 .83158 m .39694 .82593 L .41625 .8271 L F
.41693 .81208 m .41625 .8271 L .4357 .82521 L .673 .758 .914 r
F
.40405 .8113 m .41625 .8271 L .41693 .81208 L F
.40405 .8113 m .39694 .82593 L .41625 .8271 L F
.44909 .71682 m .48155 .71335 L .45036 .71172 L .654 .726 .902 r
F
.4357 .82521 m .45365 .81472 L .45396 .82037 L .604 .398 .576 r
F
.436 .83087 m .4357 .82521 L .45396 .82037 L F
.41656 .83276 m .4357 .82521 L .436 .83087 L .672 .451 .576 r
F
.4299 .81082 m .4357 .82521 L .45396 .82037 L .673 .758 .914 r
F
.41693 .81208 m .4357 .82521 L .4299 .81082 L F
0 g
.41625 .8271 m
.4357 .82521 L
s
.36002 .68942 m .33021 .68271 L .32649 .69796 L .654 .726 .902 r
F
.32931 .68987 m .32602 .69793 L .32557 .70519 L 0 0 .135 r
F
0 g
.32656 .70113 m
.32726 .70528 L
s
.32345 .69529 m
.32599 .69842 L
s
.32931 .68987 m .32976 .68261 L .32602 .69793 L 0 0 .135 r
F
.36002 .68942 m .32649 .69796 L .35753 .69958 L .654 .726 .902 r
F
.38981 .69613 m .35753 .69958 L .38856 .70121 L F
.38981 .69613 m .36002 .68942 L .35753 .69958 L F
.45064 .70445 m .47998 .6957 L .44978 .69926 L F
.45064 .70445 m .48167 .70608 L .47998 .6957 L F
.48167 .70608 m .51018 .69213 L .47998 .6957 L F
.48167 .70608 m .51271 .7077 L .51018 .69213 L F
.51275 .71499 m .51318 .70773 L .51064 .69208 L .921 .741 .252 r
F
0 g
.51211 .72311 m
.52036 .72011 L
s
.51137 .71491 m
.51238 .71092 L
s
.37938 .82742 m .39694 .82593 L .39725 .83158 L .793 .545 .562 r
F
0 g
.38378 .82705 m
.38379 .82286 L
s
.37938 .82742 m .37908 .82176 L .39694 .82593 L .793 .545 .562 r
F
.39214 .80851 m .39694 .82593 L .40405 .8113 L .673 .758 .914 r
F
.39214 .80851 m .37908 .82176 L .39694 .82593 L F
0 g
.39694 .82593 m
.41625 .8271 L
s
.45396 .82037 m .45365 .81472 L .4695 .80727 L .518 .333 .569 r
F
0 g
.4453 .81693 m
.45365 .81472 L
s
.44166 .80181 m .45347 .81453 L .46924 .80711 L .673 .758 .914 r
F
.42954 .80502 m .45347 .81453 L .44166 .80181 L F
.41724 .81774 m .41656 .83276 L .436 .83087 L .673 .758 .915 r
F
.40436 .81695 m .41656 .83276 L .41724 .81774 L F
.40436 .81695 m .39725 .83158 L .41656 .83276 L F
.5767 .70284 m .57711 .69558 L .60143 .69481 L .668 .433 .556 r
F
0 g
.52036 .72011 m
.57688 .69961 L
s
.58902 .6952 m
.65454 .67144 L
s
.55256 .69953 m .57711 .69558 L .5767 .70284 L .732 .489 .56 r
F
.55256 .69953 m .55298 .69228 L .57711 .69558 L F
.42408 .70263 m .42763 .69889 L .42313 .70177 L .675 .735 .895 r
F
.436 .83087 m .45396 .82037 L .45427 .82603 L .604 .398 .576 r
F
.43021 .81647 m .436 .83087 L .45427 .82603 L .673 .758 .915 r
F
.41724 .81774 m .436 .83087 L .43021 .81647 L F
0 g
.41656 .83276 m
.436 .83087 L
s
.57801 .67543 m .57713 .69528 L .60132 .69452 L .654 .726 .902 r
F
.56199 .67323 m .57713 .69528 L .57801 .67543 L F
.56199 .67323 m .55311 .69199 L .57713 .69528 L F
.44866 .72408 m .48113 .72061 L .44992 .71898 L F
.42313 .70177 m .42763 .69889 L .42511 .69757 L .675 .735 .895 r
F
.41874 .71033 m .41443 .70739 L .41341 .70824 L F
.41874 .71033 m .41575 .70674 L .41443 .70739 L F
0 g
.41553 .71348 m
.41554 .70907 L
s
.35927 .69661 m .32931 .68987 L .32557 .70519 L .654 .726 .902 r
F
.32886 .69713 m .32557 .70519 L .32512 .71245 L 0 0 .135 r
F
0 g
.32611 .70839 m
.32681 .71254 L
s
.32886 .69713 m .32931 .68987 L .32557 .70519 L 0 0 .135 r
F
.35927 .69661 m .32557 .70519 L .35677 .70682 L .654 .726 .902 r
F
.36388 .81488 m .37878 .81611 L .37908 .82176 L .858 .597 .542 r
F
.36388 .81488 m .36358 .80923 L .37878 .81611 L F
0 g
.37878 .81611 m
.38356 .81722 L
s
.39244 .81417 m .39725 .83158 L .40436 .81695 L .673 .758 .915 r
F
.39244 .81417 m .37938 .82742 L .39725 .83158 L F
0 g
.39725 .83158 m
.41656 .83276 L
s
.38368 .86754 m
.38378 .82844 L
s
.45396 .82037 m .4695 .80727 L .46981 .81292 L .518 .333 .569 r
F
.45427 .82603 m .45396 .82037 L .46981 .81292 L F
.44208 .80759 m .45396 .82037 L .46981 .81292 L .673 .758 .914 r
F
.4299 .81082 m .45396 .82037 L .44208 .80759 L F
0 g
.4456 .82259 m
.45396 .82037 L
s
.38922 .70335 m .35677 .70682 L .38797 .70845 L .654 .726 .902 r
F
.38922 .70335 m .35927 .69661 L .35677 .70682 L F
.38188 .79816 m .37897 .81591 L .39197 .80272 L .673 .758 .914 r
F
.38188 .79816 m .36385 .80906 L .37897 .81591 L F
.42321 .7046 m .42774 .7017 L .4252 .70038 L .675 .735 .895 r
F
.42763 .69889 m .42836 .69403 L .42511 .69757 L F
.42763 .69889 m .43214 .69601 L .42836 .69403 L F
.422 .70677 m .42228 .70238 L .42051 .70635 L F
.43227 .69881 m .43221 .69597 L .4284 .69398 L .86 .586 .522 r
F
.4252 .70038 m .42846 .69682 L .42399 .69556 L .675 .735 .895 r
F
.43227 .69881 m .4284 .69398 L .42846 .69682 L .86 .586 .522 r
F
.42846 .69682 m .4284 .69398 L .42393 .69272 L .793 .53 .539 r
F
.42526 .70322 m .42405 .6984 L .42228 .70238 L .675 .735 .895 r
F
.42526 .70322 m .42852 .69966 L .42405 .6984 L F
.42852 .69966 m .42846 .69682 L .42399 .69556 L .793 .53 .539 r
F
.42852 .69966 m .42399 .69556 L .42405 .6984 L F
.41916 .71009 m .43544 .69363 L .42799 .69124 L .654 .726 .902 r
F
0 g
.42203 .7103 m
.42203 .70929 L
s
.45036 .71172 m .47985 .70292 L .4495 .7065 L .654 .726 .902 r
F
.45036 .71172 m .48155 .71335 L .47985 .70292 L F
.48155 .71335 m .51021 .69934 L .47985 .70292 L F
.48155 .71335 m .51275 .71499 L .51021 .69934 L F
.53024 .69237 m .55298 .69228 L .55256 .69953 L .793 .543 .559 r
F
.53024 .69237 m .53066 .68512 L .55298 .69228 L F
0 g
.55298 .69228 m
.57711 .69558 L
s
.51275 .71499 m .51064 .69208 L .51021 .69934 L .921 .741 .252 r
F
.51233 .72225 m .51275 .71499 L .51021 .69934 L F
0 g
.51095 .72217 m
.51195 .71817 L
s
.60102 .70207 m .60143 .69481 L .62428 .69001 L .593 .37 .547 r
F
.5767 .70284 m .60143 .69481 L .60102 .70207 L .668 .433 .556 r
F
0 g
.57711 .69558 m
.60143 .69481 L
s
.54718 .66848 m .55311 .69199 L .56199 .67323 L .654 .726 .902 r
F
.54718 .66848 m .53091 .68487 L .55311 .69199 L F
.59415 .67491 m .60132 .69452 L .62405 .68974 L F
.57801 .67543 m .60132 .69452 L .59415 .67491 L F
.3931 .6915 m .36002 .68942 L .38981 .69613 L F
.44978 .69926 m .47416 .6858 L .44687 .69432 L F
.44978 .69926 m .47998 .6957 L .47416 .6858 L F
.41443 .70739 m .40808 .70614 L .41341 .70824 L .675 .735 .895 r
F
.57628 .7101 m .5767 .70284 L .60102 .70207 L .668 .433 .556 r
F
.55214 .70679 m .5767 .70284 L .57628 .7101 L .732 .489 .56 r
F
.55214 .70679 m .55256 .69953 L .5767 .70284 L F
.57758 .68289 m .5767 .70284 L .60102 .70207 L .654 .726 .902 r
F
.56148 .68068 m .5767 .70284 L .57758 .68289 L F
.56148 .68068 m .55256 .69953 L .5767 .70284 L F
.36418 .82054 m .37908 .82176 L .37938 .82742 L .858 .597 .542 r
F
.36418 .82054 m .36388 .81488 L .37908 .82176 L F
.382 .80393 m .37908 .82176 L .39214 .80851 L .673 .758 .914 r
F
.382 .80393 m .36388 .81488 L .37908 .82176 L F
0 g
.37908 .82176 m
.38386 .82288 L
s
.45427 .82603 m .46981 .81292 L .47012 .81858 L .518 .333 .569 r
F
.44239 .81325 m .45427 .82603 L .47012 .81858 L .673 .758 .915 r
F
.43021 .81647 m .45427 .82603 L .44239 .81325 L F
0 g
.436 .83087 m
.45427 .82603 L
s
.41443 .70739 m .41013 .70445 L .40808 .70614 L .675 .735 .895 r
F
.41575 .70674 m .41013 .70445 L .41443 .70739 L F
.41575 .70674 m .41276 .70315 L .41013 .70445 L F
.41727 .70633 m .41276 .70315 L .41575 .70674 L F
.35883 .70387 m .32512 .71245 L .35632 .71408 L .654 .726 .902 r
F
.35883 .70387 m .32886 .69713 L .32512 .71245 L F
0 g
.32512 .71245 m
.32776 .72808 L
s
.38878 .71061 m .35632 .71408 L .38752 .71571 L .654 .726 .902 r
F
.38878 .71061 m .35883 .70387 L .35632 .71408 L F
.41276 .70315 m .40582 .7015 L .41013 .70445 L .675 .735 .895 r
F
.41276 .70315 m .40978 .69956 L .40582 .7015 L F
.41581 .70234 m .40978 .69956 L .41276 .70315 L F
.41872 .71735 m .41139 .69766 L .40378 .69926 L .654 .726 .902 r
F
.41872 .71735 m .4195 .6974 L .41139 .69766 L F
.41872 .71735 m .42755 .69851 L .4195 .6974 L F
.44992 .71898 m .47942 .71018 L .44907 .71376 L F
.44992 .71898 m .48113 .72061 L .47942 .71018 L F
.48113 .72061 m .50979 .7066 L .47942 .71018 L F
.48113 .72061 m .51233 .72225 L .50979 .7066 L F
.52982 .69963 m .55256 .69953 L .55214 .70679 L .793 .543 .559 r
F
.52982 .69963 m .53024 .69237 L .55256 .69953 L F
.5466 .6759 m .55256 .69953 L .56148 .68068 L .654 .726 .902 r
F
.5466 .6759 m .53024 .69237 L .55256 .69953 L F
0 g
.55256 .69953 m
.5767 .70284 L
s
.46981 .81292 m .4695 .80727 L .48184 .7977 L .391 .238 .551 r
F
0 g
.46105 .81124 m
.4695 .80727 L
s
.51233 .72225 m .51021 .69934 L .50979 .7066 L .921 .741 .252 r
F
0 g
.50849 .73754 m
.51233 .72225 L
s
.60102 .70207 m .62428 .69001 L .62387 .69727 L .593 .37 .547 r
F
.6006 .70933 m .60102 .70207 L .62387 .69727 L F
.57628 .7101 m .60102 .70207 L .6006 .70933 L .668 .433 .556 r
F
.59381 .68237 m .60102 .70207 L .62387 .69727 L .654 .726 .902 r
F
.57758 .68289 m .60102 .70207 L .59381 .68237 L F
0 g
.5767 .70284 m
.60102 .70207 L
s
.45217 .79686 m .46924 .80711 L .48152 .7976 L .673 .758 .914 r
F
.44166 .80181 m .46924 .80711 L .45217 .79686 L F
.39252 .6987 m .35927 .69661 L .38922 .70335 L .654 .726 .902 r
F
.4495 .7065 m .47401 .69297 L .44657 .70153 L F
.4495 .7065 m .47985 .70292 L .47401 .69297 L F
.38231 .80958 m .37938 .82742 L .39244 .81417 L .673 .758 .915 r
F
.38231 .80958 m .36418 .82054 L .37938 .82742 L F
0 g
.37938 .82742 m
.39725 .83158 L
s
.3931 .6915 m .36658 .68017 L .36002 .68942 L .654 .726 .902 r
F
.39819 .68765 m .36658 .68017 L .3931 .6915 L F
.44687 .69432 m .46462 .67705 L .4421 .68995 L F
.44687 .69432 m .47416 .6858 L .46462 .67705 L F
.51125 .68184 m .53066 .68512 L .53024 .69237 L .857 .601 .551 r
F
.51125 .68184 m .51168 .67458 L .53066 .68512 L F
0 g
.53066 .68512 m
.53581 .68677 L
s
.36658 .68017 m .33021 .68271 L .36002 .68942 L .654 .726 .902 r
F
.57717 .69015 m .57628 .7101 L .6006 .70933 L F
.56107 .68794 m .57628 .7101 L .57717 .69015 L F
.56107 .68794 m .55214 .70679 L .57628 .7101 L F
.62387 .69727 m .62428 .69001 L .64411 .68151 L .496 .29 .529 r
F
0 g
.6137 .69223 m
.62428 .69001 L
s
.53458 .66148 m .53091 .68487 L .54718 .66848 L .654 .726 .902 r
F
.53458 .66148 m .51202 .67439 L .53091 .68487 L F
.47998 .6957 m .50148 .67727 L .47416 .6858 L F
.47998 .6957 m .51018 .69213 L .50148 .67727 L F
.60931 .67173 m .62405 .68974 L .64379 .68129 L F
.59415 .67491 m .62405 .68974 L .60931 .67173 L F
.46981 .81292 m .48184 .7977 L .48215 .80336 L .391 .238 .551 r
F
.47012 .81858 m .46981 .81292 L .48215 .80336 L F
.45265 .80262 m .46981 .81292 L .48215 .80336 L .673 .758 .914 r
F
.44208 .80759 m .46981 .81292 L .45265 .80262 L F
0 g
.46136 .8169 m
.46981 .81292 L
s
.35237 .80576 m .36358 .80923 L .36388 .81488 L .93 .657 .5 r
F
.35237 .80576 m .35207 .8001 L .36358 .80923 L F
0 g
.36358 .80923 m
.3691 .81173 L
s
.54618 .68316 m .55214 .70679 L .56107 .68794 L .654 .726 .902 r
F
.54618 .68316 m .52982 .69963 L .55214 .70679 L F
0 g
.55214 .70679 m
.57628 .7101 L
s
.37425 .7921 m .36385 .80906 L .38188 .79816 L .673 .758 .914 r
F
.37425 .7921 m .3524 .79999 L .36385 .80906 L F
.6006 .70933 m .62387 .69727 L .62346 .70453 L .593 .37 .547 r
F
.59339 .68963 m .6006 .70933 L .62346 .70453 L .654 .726 .902 r
F
.57717 .69015 m .6006 .70933 L .59339 .68963 L F
0 g
.57628 .7101 m
.6006 .70933 L
s
.41967 .79395 m .41776 .80616 L .42954 .80502 L .673 .758 .914 r
F
.42013 .79103 m .42954 .80502 L .42376 .79068 L F
.41731 .79131 m .41967 .79395 L .42013 .79103 L F
.41967 .79395 m .42954 .80502 L .42013 .79103 L F
.4223 .74936 m .42241 .74856 L .42236 .77676 L 0 0 .138 r
F
.41761 .79704 m .41693 .81208 L .4299 .81082 L .673 .758 .914 r
F
.41731 .79131 m .41776 .80616 L .41967 .79395 L F
.41761 .79704 m .4299 .81082 L .4241 .79641 L F
.42117 .75059 m .42187 .75003 L .42182 .77811 L .359 .182 .499 r
F
.42051 .7791 m .42376 .79068 L .42054 .77908 L .673 .758 .914 r
F
.41701 .75097 m .41857 .75123 L .41852 .7793 L .751 .492 .541 r
F
.42015 .75103 m .42117 .75059 L .42112 .77864 L .519 .305 .529 r
F
.42015 .75103 m .42112 .77864 L .42059 .77886 L F
.41857 .75123 m .42015 .75103 L .4201 .77907 L .642 .403 .542 r
F
.41857 .75123 m .4201 .77907 L .41928 .77919 L F
.42117 .75059 m .42182 .77811 L .42145 .77839 L .359 .182 .499 r
F
.42015 .75103 m .42059 .77886 L .4201 .77907 L .519 .305 .529 r
F
.42117 .75059 m .42145 .77839 L .42112 .77864 L .359 .182 .499 r
F
.41857 .75123 m .41928 .77919 L .41852 .7793 L .642 .403 .542 r
F
.41985 .78096 m .41731 .79131 L .42376 .79068 L .673 .758 .914 r
F
.42155 .78719 m .4241 .79641 L .42178 .78573 L F
.42388 .77986 m .42983 .78907 L .43508 .78659 L F
.41798 .77632 m .42676 .78577 L .42388 .77986 L F
.42676 .78577 m .42983 .78907 L .42388 .77986 L F
.42187 .75003 m .4223 .74936 L .42225 .77749 L .077 0 .416 r
F
.42187 .75003 m .42225 .77749 L .42203 .77781 L F
.42241 .74856 m .42196 .74752 L .42191 .77584 L .985 .728 .345 r
F
.42376 .79068 m .42954 .80502 L .44166 .80181 L .673 .758 .914 r
F
.42178 .78573 m .4241 .79641 L .43019 .79479 L F
.41872 .78261 m .41731 .79131 L .41985 .78096 L F
.41921 .77944 m .41731 .79131 L .41924 .77943 L F
.41731 .79131 m .41663 .80627 L .41776 .80616 L F
.4109 .79091 m .41663 .80627 L .41679 .80273 L F
.41594 .79122 m .41679 .80273 L .41731 .79131 L F
.4109 .79091 m .41679 .80273 L .41594 .79122 L F
.41494 .74842 m .41499 .74923 L .41494 .77762 L .789 .63 .07 r
F
.41785 .7794 m .41731 .79131 L .41915 .77921 L .673 .758 .914 r
F
.41499 .74923 m .41537 .74991 L .41532 .77822 L .989 .721 .392 r
F
.41494 .74842 m .41491 .77724 L .41489 .77689 L .789 .63 .07 r
F
.41494 .74842 m .41494 .77762 L .41491 .77724 L F
.41547 .7474 m .41494 .74842 L .41489 .77689 L 0 0 .377 r
F
.41616 .77958 m .41059 .78453 L .4163 .7798 L .673 .758 .914 r
F
.41059 .78453 m .40497 .78953 L .41041 .78485 L F
.41059 .78453 m .41041 .78485 L .4163 .7798 L F
.41576 .77894 m .40497 .78953 L .41616 .77958 L F
.41802 .7879 m .41117 .79665 L .41761 .79704 L F
.41781 .78014 m .4109 .79091 L .41731 .79131 L F
.41696 .77912 m .41784 .78453 L .41695 .78442 L .751 .492 .541 r
F
.41701 .75097 m .41771 .77921 L .41696 .77912 L F
.41785 .77922 m .41659 .7792 L .41781 .78014 L .673 .758 .914 r
F
.41664 .77908 m .41659 .7792 L .41785 .77922 L F
.41771 .77921 m .41784 .78453 L .41696 .77912 L .751 .492 .541 r
F
.41798 .77632 m .41664 .77908 L .41785 .77922 L .673 .758 .914 r
F
.41659 .7792 m .4109 .79091 L .41781 .78014 L F
.41738 .78686 m .41117 .79665 L .41802 .7879 L F
.4109 .79091 m .40382 .80549 L .41663 .80627 L F
.41117 .79665 m .41693 .81208 L .41761 .79704 L F
.41544 .7953 m .41147 .80231 L .41598 .80258 L .673 .758 .915 r
F
.41147 .80231 m .41724 .81774 L .41792 .8027 L F
.41517 .78076 m .40497 .78953 L .41526 .78193 L .673 .758 .914 r
F
.41603 .7505 m .41645 .77892 L .41598 .77873 L .844 .572 .527 r
F
.41537 .74991 m .41603 .7505 L .41598 .77873 L .927 .648 .492 r
F
.41537 .74991 m .41598 .77873 L .41587 .77865 L F
.41577 .77857 m .39993 .78724 L .40497 .78953 L .673 .758 .914 r
F
.41798 .77632 m .41511 .77806 L .41577 .77857 L F
.41511 .77806 m .39993 .78724 L .41577 .77857 L F
.41564 .77847 m .41597 .78403 L .41569 .78382 L .927 .648 .492 r
F
.41537 .74991 m .41587 .77865 L .41564 .77847 L F
.41577 .77857 m .41571 .77863 L .41598 .77873 L .673 .758 .914 r
F
.4163 .7798 m .41517 .78076 L .41526 .78193 L F
.41587 .77865 m .41597 .78403 L .41564 .77847 L .927 .648 .492 r
F
.41537 .74991 m .41564 .77847 L .41532 .77822 L F
.41499 .74923 m .41532 .77822 L .41512 .77791 L .989 .721 .392 r
F
.41478 .77826 m .39611 .78421 L .39993 .78724 L .673 .758 .914 r
F
.41798 .77632 m .41375 .77785 L .41478 .77826 L F
.41375 .77785 m .39611 .78421 L .41478 .77826 L F
.41603 .7505 m .41701 .75097 L .41696 .77912 L .844 .572 .527 r
F
.41681 .77906 m .41696 .77912 L .41695 .78442 L F
.41603 .7505 m .41696 .77912 L .41681 .77906 L F
.41499 .74923 m .41512 .77791 L .41494 .77762 L .989 .721 .392 r
F
.41375 .77785 m .39379 .78064 L .39611 .78421 L .673 .758 .914 r
F
.41658 .74663 m .41547 .7474 L .41541 .77596 L .403 .215 .509 r
F
.41544 .7953 m .41598 .80258 L .41792 .8027 L .673 .758 .915 r
F
.41596 .78934 m .4169 .80961 L .41592 .80914 L .844 .572 .527 r
F
.41564 .77847 m .41569 .78382 L .41532 .77822 L .927 .648 .492 r
F
.41524 .78154 m .41331 .78031 L .41396 .78136 L .673 .758 .914 r
F
.41598 .77873 m .41576 .77894 L .41659 .7792 L F
.41576 .77894 m .41616 .77958 L .41659 .7792 L F
.41659 .7792 m .41616 .77958 L .4163 .7798 L F
.41436 .7834 m .39397 .78633 L .39631 .78991 L F
.41653 .78426 m .41629 .78416 L .41598 .77873 L .844 .572 .527 r
F
.41618 .78412 m .41062 .78976 L .41708 .78447 L .673 .758 .914 r
F
.40497 .78953 m .40382 .80549 L .4109 .79091 L F
.41062 .78976 m .40521 .79525 L .40996 .79094 L F
.41491 .77724 m .41491 .78261 L .41489 .77689 L .789 .63 .07 r
F
.41708 .78447 m .41117 .79665 L .41816 .7849 L .673 .758 .914 r
F
.4153 .78883 m .41497 .78895 L .41588 .78928 L .673 .758 .915 r
F
.40497 .78953 m .39197 .80272 L .40382 .80549 L .673 .758 .914 r
F
.40978 .78598 m .40745 .79011 L .4109 .79091 L F
.4151 .78522 m .40014 .79296 L .40521 .79525 L F
.41661 .7896 m .4163 .78947 L .41614 .7841 L .844 .572 .527 r
F
.41629 .78416 m .41614 .7841 L .41598 .77873 L F
.41693 .78478 m .40521 .79525 L .41117 .79665 L .673 .758 .914 r
F
.41661 .7896 m .41614 .7841 L .41629 .78416 L .844 .572 .527 r
F
.41618 .78412 m .41501 .78397 L .4151 .78522 L .673 .758 .914 r
F
.41645 .77892 m .41695 .78442 L .41653 .78426 L .844 .572 .527 r
F
.41829 .78198 m .41532 .78378 L .41618 .78412 L .673 .758 .914 r
F
.41532 .78378 m .41501 .78397 L .41618 .78412 L F
.41526 .78193 m .40978 .78598 L .4109 .79091 L F
.41501 .78397 m .40014 .79296 L .4151 .78522 L F
.41488 .78219 m .41489 .78775 L .41487 .7875 L .789 .63 .07 r
F
.41489 .77689 m .41489 .78232 L .41488 .78219 L F
.41489 .78232 m .41489 .78775 L .41488 .78219 L F
.41497 .78895 m .39661 .79557 L .41502 .78956 L .673 .758 .915 r
F
.41783 .78546 m .41117 .79665 L .41812 .78569 L .673 .758 .914 r
F
.41497 .78895 m .41502 .78956 L .41588 .78928 L .673 .758 .915 r
F
.41491 .78261 m .4149 .78798 L .41489 .78232 L .789 .63 .07 r
F
.41117 .79665 m .40405 .8113 L .41693 .81208 L .673 .758 .914 r
F
.40521 .79525 m .40405 .8113 L .41117 .79665 L F
.41683 .79129 m .40551 .80091 L .41147 .80231 L .673 .758 .915 r
F
.41062 .78976 m .40996 .79094 L .41517 .78621 L .673 .758 .914 r
F
.39993 .78724 m .39197 .80272 L .40497 .78953 L F
.39993 .78724 m .38188 .79816 L .39197 .80272 L F
.41382 .78937 m .39428 .79199 L .39661 .79557 L .673 .758 .915 r
F
.41574 .78917 m .41553 .78901 L .41542 .78362 L .927 .648 .492 r
F
.41695 .78442 m .41727 .78977 L .41694 .78973 L .751 .492 .541 r
F
.4186 .78764 m .41436 .7884 L .41382 .78937 L .673 .758 .915 r
F
.40978 .78598 m .40497 .78953 L .40745 .79011 L .673 .758 .914 r
F
.41436 .7884 m .39428 .79199 L .41382 .78937 L .673 .758 .915 r
F
.4149 .78798 m .41489 .78775 L .41489 .78232 L .789 .63 .07 r
F
.41494 .77762 m .41505 .78844 L .41492 .78822 L .989 .721 .392 r
F
.41491 .77724 m .41492 .78822 L .4149 .78798 L .789 .63 .07 r
F
.4133 .785 m .39631 .78991 L .40014 .79296 L .673 .758 .914 r
F
.41829 .78198 m .41416 .78347 L .4133 .785 L F
.41416 .78347 m .39631 .78991 L .4133 .785 L F
.41531 .78353 m .41544 .78894 L .4153 .78883 L .927 .648 .492 r
F
.4154 .78126 m .41521 .78689 L .41539 .78656 L 0 0 .377 r
F
.41569 .78382 m .41542 .78362 L .41532 .77822 L .927 .648 .492 r
F
.41541 .77596 m .41531 .78142 L .4154 .78126 L 0 0 .377 r
F
.41515 .78327 m .41531 .78353 L .4153 .78883 L .989 .721 .392 r
F
.41532 .77822 m .41542 .78362 L .41531 .78353 L .927 .648 .492 r
F
.41512 .77791 m .41532 .77822 L .41531 .78353 L .989 .721 .392 r
F
.41531 .78142 m .41521 .78689 L .4154 .78126 L 0 0 .377 r
F
.4151 .7818 m .41488 .78219 L .41487 .7875 L F
.4149 .78798 m .41488 .80787 L .41489 .78775 L .789 .63 .07 r
F
.41487 .7875 m .41488 .80787 L .41483 .80706 L F
.41489 .78775 m .41488 .80787 L .41487 .7875 L F
.41492 .78822 m .41526 .80856 L .41488 .80787 L .989 .721 .392 r
F
.4149 .78798 m .41492 .78822 L .41488 .80787 L .789 .63 .07 r
F
.41683 .7847 m .40521 .79525 L .41693 .78478 L .673 .758 .914 r
F
.41198 .78882 m .3936 .7881 L .39428 .79199 L .673 .758 .915 r
F
.4186 .78764 m .41363 .78773 L .41198 .78882 L F
.41363 .78773 m .3936 .7881 L .41198 .78882 L F
.41542 .78362 m .41553 .78901 L .41531 .78353 L .927 .648 .492 r
F
.41512 .77791 m .41531 .78353 L .41515 .78327 L .989 .721 .392 r
F
.4151 .7818 m .41523 .78157 L .41541 .77596 L 0 0 .377 r
F
.41371 .77708 m .41241 .77732 L .413 .77755 L .673 .758 .914 r
F
.41571 .77863 m .40497 .78953 L .41598 .77873 L F
.41512 .77791 m .41515 .78327 L .41494 .77762 L .989 .721 .392 r
F
.41587 .77865 m .41598 .77873 L .41597 .78403 L .927 .648 .492 r
F
.41516 .78604 m .41517 .78621 L .41708 .78447 L .673 .758 .914 r
F
.41829 .78198 m .41463 .78263 L .41436 .7834 L F
.41645 .77892 m .41653 .78426 L .41598 .77873 L .844 .572 .527 r
F
.41653 .78426 m .41661 .7896 L .41629 .78416 L F
.41665 .78961 m .41596 .78934 L .41651 .78976 L .673 .758 .915 r
F
.41662 .79095 m .41521 .79221 L .41683 .79129 L F
.41596 .78934 m .41566 .78942 L .41651 .78976 L F
.41566 .78942 m .41604 .79002 L .41651 .78976 L F
.41651 .78976 m .41604 .79002 L .41612 .79015 L F
.4185 .78991 m .41544 .7953 L .41792 .8027 L F
.4163 .78947 m .4169 .80961 L .41596 .78934 L .844 .572 .527 r
F
.41598 .77873 m .41614 .7841 L .41597 .78403 L F
.40947 .78356 m .39329 .78244 L .39397 .78633 L .673 .758 .914 r
F
.40604 .77845 m .39311 .77678 L .39379 .78064 L F
.41798 .77632 m .41577 .77857 L .41659 .7792 L F
.41653 .77522 m .41587 .78095 L .41652 .78052 L .403 .215 .509 r
F
.41603 .7505 m .41681 .77906 L .41645 .77892 L .844 .572 .527 r
F
.41658 .74663 m .41598 .77558 L .41653 .77522 L .403 .215 .509 r
F
.41598 .77558 m .41587 .78095 L .41653 .77522 L F
.41371 .77708 m .41264 .77642 L .40604 .77845 L .673 .758 .914 r
F
.41798 .77632 m .41477 .77638 L .41371 .77708 L F
.41477 .77638 m .41264 .77642 L .41371 .77708 L F
.41264 .77642 m .39311 .77678 L .40604 .77845 L F
.41768 .7463 m .41658 .74663 L .41653 .77522 L .57 .345 .536 r
F
.4167 .77517 m .41653 .77522 L .41652 .78052 L F
.41768 .7463 m .41653 .77522 L .4167 .77517 L F
.41661 .7896 m .4169 .80961 L .4163 .78947 L .844 .572 .527 r
F
.41708 .78447 m .41683 .7847 L .41693 .78478 L .673 .758 .914 r
F
.41728 .79036 m .41662 .79095 L .41683 .79129 L .673 .758 .915 r
F
.41653 .78426 m .41695 .78442 L .41694 .78973 L .844 .572 .527 r
F
.41661 .7896 m .41694 .78973 L .4169 .80961 L F
.41653 .78426 m .41694 .78973 L .41661 .7896 L F
.41755 .7898 m .41748 .78994 L .4185 .78991 L .673 .758 .915 r
F
.41748 .78994 m .41147 .80231 L .41829 .79026 L F
.41815 .78518 m .41761 .79704 L .41937 .78467 L .673 .758 .914 r
F
.41748 .78994 m .41829 .79026 L .4185 .78991 L .673 .758 .915 r
F
.4186 .78764 m .4153 .78883 L .41588 .78928 L F
.41681 .77906 m .41695 .78442 L .41645 .77892 L .844 .572 .527 r
F
.41138 .78211 m .39432 .77853 L .39329 .78244 L .673 .758 .914 r
F
.41829 .78198 m .41386 .78134 L .41138 .78211 L F
.41386 .78134 m .39432 .77853 L .41138 .78211 L F
.41755 .7898 m .41651 .78976 L .41728 .79036 L .673 .758 .915 r
F
.41797 .78985 m .41727 .78977 L .41695 .78442 L .751 .492 .541 r
F
.4186 .78764 m .41658 .78969 L .41755 .7898 L .673 .758 .915 r
F
.41658 .78969 m .41651 .78976 L .41755 .7898 L F
.41812 .78569 m .41738 .78686 L .41802 .7879 L .673 .758 .914 r
F
.41784 .78453 m .41797 .78985 L .41695 .78442 L .751 .492 .541 r
F
.41939 .78471 m .41761 .79704 L .4241 .79641 L .673 .758 .914 r
F
.41797 .78985 m .41847 .80987 L .41727 .78977 L .751 .492 .541 r
F
.41694 .78973 m .41847 .80987 L .4169 .80961 L F
.41727 .78977 m .41847 .80987 L .41694 .78973 L F
.41012 .7878 m .39462 .78419 L .3936 .7881 L .673 .758 .915 r
F
.41062 .78976 m .41517 .78621 L .41516 .78604 L .673 .758 .914 r
F
.41597 .78403 m .4163 .78947 L .41596 .78934 L .844 .572 .527 r
F
.4186 .78764 m .41316 .78686 L .41012 .7878 L .673 .758 .915 r
F
.41316 .78686 m .39462 .78419 L .41012 .7878 L F
.39894 .78234 m .39329 .78244 L .40947 .78356 L .673 .758 .914 r
F
.41316 .78686 m .39728 .78051 L .39462 .78419 L .673 .758 .915 r
F
.41515 .78327 m .4153 .78883 L .41517 .78863 L .989 .721 .392 r
F
.41553 .78901 m .41544 .78894 L .41531 .78353 L .927 .648 .492 r
F
.4186 .78764 m .41477 .78636 L .41316 .78686 L .673 .758 .915 r
F
.41312 .7829 m .39397 .78633 L .41436 .7834 L .673 .758 .914 r
F
.41477 .78636 m .39728 .78051 L .41316 .78686 L .673 .758 .915 r
F
.41829 .78198 m .41138 .78211 L .40947 .78356 L .673 .758 .914 r
F
.41829 .78198 m .41678 .78035 L .41621 .78073 L F
.41698 .78038 m .41687 .78571 L .41761 .78018 L .57 .345 .536 r
F
.4186 .78764 m .41588 .78928 L .41596 .78934 L .673 .758 .915 r
F
.4186 .78764 m .41596 .78934 L .41665 .78961 L F
.41138 .78211 m .39894 .78234 L .40744 .78332 L .673 .758 .914 r
F
.41138 .78211 m .40744 .78332 L .40947 .78356 L F
.41241 .77732 m .39379 .78064 L .41375 .77785 L F
.41396 .78136 m .39698 .77484 L .39432 .77853 L F
.41477 .78636 m .40139 .77731 L .39728 .78051 L .673 .758 .915 r
F
.41651 .78583 m .41536 .80605 L .41647 .80527 L .403 .215 .509 r
F
.41829 .78198 m .41618 .78412 L .41708 .78447 L .673 .758 .914 r
F
.41652 .78052 m .41627 .78598 L .41651 .78583 L .403 .215 .509 r
F
.41627 .78598 m .41536 .80605 L .41651 .78583 L F
.41539 .78657 m .41589 .78602 L .41477 .78636 L .673 .758 .915 r
F
.4186 .78764 m .41606 .78612 L .41539 .78657 L F
.41829 .78198 m .41565 .7811 L .41524 .78154 L .673 .758 .914 r
F
.41521 .79221 m .41524 .7926 L .41683 .79129 L .673 .758 .915 r
F
.41574 .78917 m .41592 .80914 L .41553 .78901 L .927 .648 .492 r
F
.41614 .7841 m .4163 .78947 L .41597 .78403 L .844 .572 .527 r
F
.41588 .78928 m .41586 .7893 L .41596 .78934 L .673 .758 .915 r
F
.41586 .7893 m .41566 .78942 L .41596 .78934 L F
.41553 .78901 m .41592 .80914 L .41544 .78894 L .927 .648 .492 r
F
.41651 .78976 m .40551 .80091 L .41728 .79036 L .673 .758 .915 r
F
.4153 .78883 m .41592 .80914 L .41526 .80856 L .927 .648 .492 r
F
.41569 .78382 m .41597 .78403 L .41592 .80914 L F
.41587 .78095 m .41576 .78632 L .41652 .78052 L .403 .215 .509 r
F
.41576 .78632 m .41536 .80605 L .41627 .78598 L F
.41576 .78632 m .41627 .78598 L .41652 .78052 L F
.41504 .78719 m .41521 .78689 L .41531 .78142 L 0 0 .377 r
F
.41331 .78031 m .39698 .77484 L .41396 .78136 L .673 .758 .914 r
F
.41515 .78327 m .41517 .78863 L .41506 .78312 L .989 .721 .392 r
F
.41264 .77642 m .39413 .77288 L .39311 .77678 L .673 .758 .914 r
F
.41547 .7474 m .41489 .77689 L .41516 .77641 L 0 0 .377 r
F
.41798 .77632 m .41456 .77583 L .41264 .77642 L .673 .758 .914 r
F
.41456 .77583 m .39413 .77288 L .41264 .77642 L F
.41762 .77488 m .41698 .78038 L .41761 .78018 L .57 .345 .536 r
F
.41701 .75097 m .41852 .7793 L .41771 .77921 L .751 .492 .541 r
F
.41768 .7463 m .41709 .77504 L .41762 .77488 L .57 .345 .536 r
F
.41709 .77504 m .41698 .78038 L .41762 .77488 L F
.41491 .78261 m .41489 .78232 L .41489 .77689 L .789 .63 .07 r
F
.41798 .77632 m .41371 .77708 L .41375 .77785 L .673 .758 .914 r
F
.41515 .78327 m .41506 .78312 L .41494 .77762 L .989 .721 .392 r
F
.41516 .77641 m .41488 .78219 L .4151 .7818 L 0 0 .377 r
F
.41405 .78056 m .40109 .77165 L .39698 .77484 L .673 .758 .914 r
F
.41829 .78198 m .41565 .78039 L .41405 .78056 L F
.41456 .77583 m .39678 .76922 L .39413 .77288 L F
.41798 .77632 m .41557 .77551 L .41456 .77583 L F
.41557 .77551 m .39678 .76922 L .41456 .77583 L F
.41709 .77504 m .41652 .78052 L .41698 .78038 L .57 .345 .536 r
F
.41768 .7463 m .4167 .77517 L .41709 .77504 L F
.4167 .77517 m .41652 .78052 L .41709 .77504 L F
.41565 .78039 m .40109 .77165 L .41405 .78056 L .673 .758 .914 r
F
.41876 .74621 m .41768 .7463 L .41761 .78018 L .661 .418 .542 r
F
.41771 .77921 m .41851 .7846 L .41784 .78453 L .751 .492 .541 r
F
.41829 .78198 m .41708 .78447 L .41816 .7849 L .673 .758 .914 r
F
.41912 .77937 m .41731 .79131 L .41922 .77938 L F
.41807 .78013 m .41761 .78018 L .41757 .80494 L .661 .418 .542 r
F
.41876 .74621 m .41779 .77486 L .41818 .77482 L F
.41658 .74663 m .41541 .77596 L .41598 .77558 L .403 .215 .509 r
F
.41547 .7474 m .41516 .77641 L .41541 .77596 L 0 0 .377 r
F
.41741 .7749 m .41866 .76132 L .4122 .76195 L .673 .758 .914 r
F
.41798 .77632 m .41805 .77483 L .41741 .7749 L F
.41805 .77483 m .41866 .76132 L .41741 .7749 L F
.41798 .77632 m .41785 .7794 L .41915 .77921 L F
.41818 .77482 m .41761 .78018 L .41807 .78013 L .661 .418 .542 r
F
.41779 .77486 m .41761 .78018 L .41818 .77482 L F
.41606 .78612 m .40668 .77482 L .40139 .77731 L .673 .758 .915 r
F
.4186 .78764 m .41676 .78566 L .41606 .78612 L F
.41463 .78263 m .41312 .7829 L .41423 .78334 L .673 .758 .914 r
F
.41569 .78382 m .41574 .78917 L .41542 .78362 L .927 .648 .492 r
F
.41517 .78863 m .41505 .78844 L .41494 .77762 L .989 .721 .392 r
F
.41676 .78566 m .40668 .77482 L .41606 .78612 L .673 .758 .915 r
F
.41606 .78612 m .41589 .78602 L .41539 .78657 L F
.4151 .7818 m .41487 .7875 L .41504 .78719 L 0 0 .377 r
F
.41589 .78602 m .40139 .77731 L .41477 .78636 L .673 .758 .915 r
F
.41698 .78038 m .41652 .78052 L .41651 .78583 L .57 .345 .536 r
F
.41687 .78571 m .41651 .78583 L .41647 .80527 L F
.41698 .78038 m .41651 .78583 L .41687 .78571 L F
.41687 .78571 m .41647 .80527 L .41737 .78556 L F
.41687 .78571 m .41737 .78556 L .41761 .78018 L F
.4176 .78549 m .41647 .80527 L .41757 .80494 L F
.41761 .78018 m .41737 .78556 L .4176 .78549 L F
.41737 .78556 m .41647 .80527 L .4176 .78549 L F
.41771 .77921 m .41852 .7793 L .41851 .7846 L .751 .492 .541 r
F
.41816 .7849 m .41783 .78546 L .41812 .78569 L .673 .758 .914 r
F
.41784 .78453 m .41851 .7846 L .41847 .80987 L .751 .492 .541 r
F
.41598 .77558 m .4154 .78126 L .41569 .78107 L .403 .215 .509 r
F
.41565 .7811 m .41552 .78105 L .4154 .78126 L .673 .758 .914 r
F
.41565 .7811 m .4154 .78126 L .41524 .78154 L F
.41798 .77632 m .40087 .76604 L .39678 .76922 L F
.41621 .78073 m .40638 .76916 L .40109 .77165 L F
.41491 .77724 m .41494 .77762 L .41493 .78292 L .789 .63 .07 r
F
.41492 .78273 m .41493 .78292 L .41492 .78822 L F
.41491 .77724 m .41493 .78292 L .41492 .78273 L F
.41552 .78105 m .41478 .7808 L .41524 .78154 L .673 .758 .914 r
F
.41478 .7808 m .41331 .78031 L .41481 .78126 L F
.41478 .7808 m .41481 .78126 L .41524 .78154 L F
.41516 .77641 m .41489 .77689 L .41488 .78219 L 0 0 .377 r
F
.41523 .78157 m .41531 .78142 L .41541 .77596 L F
.41371 .77708 m .413 .77755 L .41375 .77785 L .673 .758 .914 r
F
.41678 .78035 m .40638 .76916 L .41621 .78073 L F
.41598 .77558 m .41541 .77596 L .4154 .78126 L .403 .215 .509 r
F
.41569 .78107 m .4154 .78126 L .41539 .78656 L F
.41544 .78894 m .41592 .80914 L .4153 .78883 L .927 .648 .492 r
F
.41576 .78632 m .41539 .78656 L .41536 .80605 L .403 .215 .509 r
F
.41598 .77558 m .41539 .78656 L .41576 .78632 L F
.41504 .78719 m .41487 .7875 L .41483 .80706 L 0 0 .377 r
F
.41504 .78719 m .41531 .78142 L .41523 .78157 L F
.41463 .78263 m .41423 .78334 L .41436 .7834 L .673 .758 .914 r
F
.41516 .77641 m .4151 .7818 L .41541 .77596 L 0 0 .377 r
F
.4151 .7818 m .41504 .78719 L .41523 .78157 L F
.41505 .78844 m .41526 .80856 L .41492 .78822 L .989 .721 .392 r
F
.41504 .78719 m .41483 .80706 L .41521 .78689 L 0 0 .377 r
F
.40014 .79296 m .39214 .80851 L .40521 .79525 L .673 .758 .914 r
F
.41282 .79113 m .39661 .79557 L .40044 .79862 L .673 .758 .915 r
F
.41588 .78928 m .41341 .79009 L .41282 .79113 L F
.41341 .79009 m .39661 .79557 L .41282 .79113 L F
.41521 .79221 m .40916 .79764 L .41524 .7926 L F
.40916 .79764 m .40551 .80091 L .40898 .79796 L F
.40916 .79764 m .40898 .79796 L .41683 .79129 L F
.41517 .78863 m .4153 .78883 L .41526 .80856 L .989 .721 .392 r
F
.41517 .78863 m .41526 .80856 L .41505 .78844 L F
.41539 .78656 m .41483 .80706 L .41536 .80605 L 0 0 .377 r
F
.41521 .78689 m .41483 .80706 L .41539 .78656 L F
.41566 .78942 m .40044 .79862 L .41604 .79002 L .673 .758 .915 r
F
.41612 .79015 m .40044 .79862 L .40551 .80091 L F
.41604 .79002 m .40044 .79862 L .41612 .79015 L F
.4186 .78764 m .41755 .7898 L .4185 .78991 L F
.41937 .78467 m .41937 .7847 L .41939 .78471 L .673 .758 .914 r
F
.41937 .7847 m .41761 .79704 L .41939 .78471 L F
.41792 .8027 m .41724 .81774 L .43021 .81647 L .673 .758 .915 r
F
.41792 .8027 m .43021 .81647 L .42441 .80207 L F
.42005 .79125 m .41792 .8027 L .41997 .8025 L F
.42126 .79426 m .41997 .8025 L .42441 .80207 L F
.42005 .79125 m .41997 .8025 L .42126 .79426 L F
.42223 .7881 m .42231 .8072 L .4222 .808 L 0 0 .138 r
F
.42054 .77908 m .42376 .79068 L .42983 .78907 L .673 .758 .914 r
F
.42376 .79068 m .44166 .80181 L .42983 .78907 L F
.42202 .78422 m .43019 .79479 L .43548 .7923 L F
.41924 .77943 m .42376 .79068 L .4201 .77907 L F
.42059 .77886 m .42111 .78394 L .42067 .78413 L .519 .305 .529 r
F
.41829 .78198 m .42178 .78573 L .42202 .78422 L .673 .758 .914 r
F
.42178 .78573 m .43019 .79479 L .42202 .78422 L F
.42224 .78279 m .42227 .78784 L .42223 .7881 L 0 0 .138 r
F
.42225 .77749 m .42226 .78267 L .42224 .78279 L F
.42226 .78267 m .42227 .78784 L .42224 .78279 L F
.42189 .78331 m .42195 .7885 L .42181 .78341 L .077 0 .416 r
F
.42046 .78431 m .41995 .78611 L .42088 .78477 L .673 .758 .914 r
F
.41924 .77943 m .41872 .78261 L .41985 .78096 L F
.41922 .77938 m .41921 .77944 L .41924 .77943 L F
.41915 .77921 m .41912 .77937 L .41922 .77938 L F
.41928 .77919 m .41954 .78975 L .41852 .7793 L .642 .403 .542 r
F
.41945 .78977 m .41912 .79261 L .42005 .79125 L .673 .758 .915 r
F
.41954 .78975 m .42005 .80967 L .41905 .78983 L .642 .403 .542 r
F
.4193 .78449 m .41815 .78518 L .41937 .78467 L .673 .758 .914 r
F
.41954 .78975 m .41905 .78983 L .41852 .7793 L .642 .403 .542 r
F
.4186 .78764 m .41945 .78977 L .42037 .78955 L .673 .758 .915 r
F
.41945 .78977 m .41951 .78991 L .42008 .78967 L F
.41928 .77919 m .42008 .78967 L .41954 .78975 L .642 .403 .542 r
F
.41945 .78977 m .42008 .78967 L .42037 .78955 L .673 .758 .915 r
F
.41829 .78198 m .4193 .78449 L .42046 .78431 L .673 .758 .914 r
F
.4193 .78449 m .41995 .78611 L .42046 .78431 L F
.41915 .77921 m .41924 .77943 L .4201 .77907 L F
.41928 .77919 m .4201 .77907 L .42009 .78437 L .642 .403 .542 r
F
.41968 .78443 m .42009 .78437 L .42008 .78967 L F
.41928 .77919 m .42009 .78437 L .41968 .78443 L F
.41951 .78991 m .41968 .79032 L .42029 .78964 L .673 .758 .915 r
F
.41951 .78991 m .42029 .78964 L .42008 .78967 L F
.41954 .78975 m .42008 .78967 L .42005 .80967 L .642 .403 .542 r
F
.42008 .78967 m .42029 .78964 L .42037 .78955 L .673 .758 .915 r
F
.41968 .79032 m .42441 .80207 L .42044 .78975 L F
.41968 .79032 m .42044 .78975 L .42037 .78955 L F
.4211 .78925 m .42177 .80868 L .42106 .80924 L .359 .182 .499 r
F
.42088 .78477 m .42155 .78719 L .42178 .78573 L .673 .758 .914 r
F
.42112 .77864 m .42134 .78907 L .4211 .78925 L .359 .182 .499 r
F
.42134 .78907 m .42177 .80868 L .4211 .78925 L F
.42195 .7885 m .4222 .808 L .42189 .78859 L .077 0 .416 r
F
.42195 .7885 m .42189 .78859 L .42181 .78341 L F
.4241 .79641 m .4299 .81082 L .44208 .80759 L .673 .758 .914 r
F
.42086 .79008 m .42441 .80207 L .42894 .80087 L .673 .758 .915 r
F
.4241 .79641 m .44208 .80759 L .43019 .79479 L .673 .758 .914 r
F
.42409 .79094 m .4305 .80045 L .43579 .79796 L .673 .758 .915 r
F
.42187 .75003 m .42203 .77781 L .42182 .77811 L .077 0 .416 r
F
.4223 .74936 m .42236 .77676 L .4223 .77714 L 0 0 .138 r
F
.4223 .74936 m .4223 .77714 L .42225 .77749 L F
.42251 .77624 m .44183 .77976 L .44285 .77586 L .673 .758 .914 r
F
.41798 .77632 m .42392 .77718 L .42251 .77624 L F
.42392 .77718 m .44183 .77976 L .42251 .77624 L F
.42181 .78341 m .42189 .78859 L .4218 .78872 L .077 0 .416 r
F
.41995 .78611 m .4241 .79641 L .42088 .78477 L .673 .758 .914 r
F
.42182 .77811 m .42189 .78331 L .42181 .78341 L .077 0 .416 r
F
.42145 .77839 m .42182 .77811 L .42181 .78341 L .359 .182 .499 r
F
.42983 .78907 m .44166 .80181 L .45217 .79686 L .673 .758 .914 r
F
.43019 .79479 m .45265 .80262 L .43548 .7923 L F
.42181 .78872 m .43579 .79796 L .4399 .79477 L .673 .758 .915 r
F
.4201 .77907 m .42019 .77934 L .42048 .77901 L .673 .758 .914 r
F
.42019 .77934 m .42051 .7791 L .42048 .77901 L F
.42048 .77901 m .42051 .7791 L .42054 .77908 L F
.42296 .77799 m .43508 .78659 L .43918 .78342 L F
.42388 .78279 m .43959 .78911 L .44226 .78543 L F
.42067 .78413 m .42043 .78423 L .4201 .77907 L .519 .305 .529 r
F
.42145 .77839 m .42181 .78341 L .42151 .78364 L .359 .182 .499 r
F
.42318 .77844 m .43508 .78659 L .42296 .77799 L .673 .758 .914 r
F
.42157 .77847 m .43508 .78659 L .4221 .7777 L F
.42392 .77718 m .43918 .78342 L .44183 .77976 L F
.41798 .77632 m .42737 .77946 L .42392 .77718 L F
.42737 .77946 m .43918 .78342 L .42392 .77718 L F
.42196 .74752 m .42091 .74671 L .42086 .77514 L .908 .63 .503 r
F
.42019 .77934 m .42376 .79068 L .42051 .7791 L .673 .758 .914 r
F
.42231 .78304 m .42247 .78338 L .42291 .78319 L F
.41829 .78198 m .42205 .78324 L .42231 .78304 L F
.4223 .77714 m .4223 .78238 L .42225 .77749 L 0 0 .138 r
F
.42216 .78328 m .42247 .78338 L .42219 .78313 L .673 .758 .914 r
F
.42086 .79008 m .42177 .79105 L .42139 .78932 L .673 .758 .915 r
F
.42177 .79105 m .42678 .79645 L .42193 .79003 L F
.42177 .79105 m .42193 .79003 L .42139 .78932 L F
.42131 .78379 m .42398 .7854 L .42205 .78324 L .673 .758 .914 r
F
.42398 .7854 m .43548 .7923 L .42336 .78412 L F
.42398 .7854 m .42336 .78412 L .42205 .78324 L F
.4223 .78238 m .42231 .78761 L .42226 .78267 L 0 0 .138 r
F
.42231 .78761 m .42227 .78784 L .42226 .78267 L F
.42219 .78313 m .42247 .78338 L .42231 .78304 L .673 .758 .914 r
F
.42235 .78206 m .42219 .78705 L .42234 .78737 L .985 .728 .345 r
F
.4223 .77714 m .42236 .77676 L .42235 .78206 L 0 0 .138 r
F
.4223 .77714 m .42235 .78206 L .4223 .78238 L F
.42236 .77676 m .42228 .7819 L .42235 .78206 L .985 .728 .345 r
F
.42228 .7819 m .42219 .78705 L .42235 .78206 L F
.42983 .78907 m .45217 .79686 L .43508 .78659 L .673 .758 .914 r
F
.42205 .78324 m .43548 .7923 L .43959 .78911 L F
.42249 .7882 m .4399 .79477 L .44257 .79109 L .673 .758 .915 r
F
.42067 .78413 m .4211 .78925 L .42075 .78939 L .519 .305 .529 r
F
.4186 .78764 m .42181 .78872 L .42249 .7882 L .673 .758 .915 r
F
.42181 .78872 m .4399 .79477 L .42249 .7882 L F
.42151 .78364 m .42156 .7889 L .42123 .78385 L .359 .182 .499 r
F
.42118 .78919 m .42139 .78932 L .4218 .78872 L .673 .758 .915 r
F
.42156 .7889 m .42177 .80868 L .42134 .78907 L .359 .182 .499 r
F
.42156 .7889 m .42134 .78907 L .42123 .78385 L F
.42231 .78761 m .42231 .8072 L .42227 .78784 L 0 0 .138 r
F
.4223 .78238 m .42226 .78267 L .42225 .77749 L F
.42205 .78324 m .42216 .78328 L .42219 .78313 L .673 .758 .914 r
F
.42145 .77839 m .42151 .78364 L .42112 .77864 L .359 .182 .499 r
F
.42151 .78364 m .42123 .78385 L .42112 .77864 L F
.42067 .78413 m .42111 .78394 L .4211 .78925 L .519 .305 .529 r
F
.42037 .78955 m .42086 .79008 L .4212 .78921 L .673 .758 .915 r
F
.42075 .78939 m .4211 .78925 L .42106 .80924 L .519 .305 .529 r
F
.42059 .77886 m .42112 .77864 L .42111 .78394 L F
.42303 .78189 m .44226 .78543 L .44329 .78152 L .673 .758 .914 r
F
.42206 .78306 m .42195 .78321 L .42182 .77811 L .077 0 .416 r
F
.42203 .77781 m .42206 .78306 L .42182 .77811 L F
.41798 .77632 m .42157 .77847 L .4221 .7777 L .673 .758 .914 r
F
.42215 .77632 m .42191 .77584 L .42191 .78115 L .985 .728 .345 r
F
.42208 .78831 m .42195 .7885 L .42182 .77811 L .077 0 .416 r
F
.42202 .78138 m .42191 .78115 L .4219 .78645 L .985 .728 .345 r
F
.42215 .77632 m .42191 .78115 L .42202 .78138 L F
.42228 .78191 m .42451 .78288 L .42303 .78189 L .673 .758 .914 r
F
.41829 .78198 m .42262 .7826 L .42228 .78191 L F
.42262 .7826 m .42451 .78288 L .42228 .78191 L F
.42451 .78288 m .44226 .78543 L .42303 .78189 L F
.4214 .7755 m .42086 .77514 L .42085 .78045 L .908 .63 .503 r
F
.42075 .78939 m .42044 .78953 L .4201 .77907 L .519 .305 .529 r
F
.4186 .78764 m .42118 .78919 L .42181 .78872 L .673 .758 .915 r
F
.42355 .78755 m .44257 .79109 L .4436 .78718 L F
.4186 .78764 m .4251 .78858 L .42355 .78755 L F
.4251 .78858 m .44257 .79109 L .42355 .78755 L F
.4213 .78074 m .42085 .78045 L .42084 .78575 L .908 .63 .503 r
F
.42247 .78338 m .43959 .78911 L .42388 .78279 L .673 .758 .914 r
F
.43508 .78659 m .46036 .79051 L .43918 .78342 L F
.42261 .78692 m .4436 .78718 L .44293 .7833 L .673 .758 .915 r
F
.42151 .78364 m .4218 .78872 L .42156 .7889 L .359 .182 .499 r
F
.4186 .78764 m .42355 .78755 L .42261 .78692 L .673 .758 .915 r
F
.42355 .78755 m .4436 .78718 L .42261 .78692 L F
.42156 .7889 m .4218 .78872 L .42177 .80868 L .359 .182 .499 r
F
.4219 .78645 m .42081 .80535 L .42186 .80617 L .908 .63 .503 r
F
.41829 .78198 m .42291 .78319 L .42262 .7826 L .673 .758 .914 r
F
.42151 .78364 m .42181 .78341 L .4218 .78872 L .359 .182 .499 r
F
.42191 .77584 m .42153 .78621 L .4219 .78645 L .908 .63 .503 r
F
.42065 .7904 m .42441 .80207 L .42086 .79008 L .673 .758 .915 r
F
.42153 .78621 m .42081 .80535 L .4219 .78645 L .908 .63 .503 r
F
.42203 .77781 m .42225 .77749 L .42224 .78279 L .077 0 .416 r
F
.42213 .78295 m .42224 .78279 L .42223 .7881 L F
.42203 .77781 m .42224 .78279 L .42213 .78295 L F
.42203 .77781 m .42223 .7881 L .42208 .78831 L F
.4218 .78872 m .4222 .808 L .42177 .80868 L F
.42215 .77632 m .4221 .78154 L .42236 .77676 L .985 .728 .345 r
F
.42208 .78831 m .4222 .808 L .42195 .7885 L .077 0 .416 r
F
.42198 .78967 m .42678 .79645 L .42409 .79094 L .673 .758 .915 r
F
.42139 .78932 m .42193 .79003 L .42198 .78967 L F
.42193 .79003 m .42678 .79645 L .42198 .78967 L F
.4223 .78238 m .42235 .78206 L .42234 .78737 L 0 0 .138 r
F
.42231 .78761 m .42234 .78737 L .42231 .8072 L F
.4223 .78238 m .42234 .78737 L .42231 .78761 L F
.42429 .77981 m .44262 .77763 L .44029 .77404 L .673 .758 .914 r
F
.42343 .78106 m .44262 .77763 L .42429 .77981 L F
.4221 .78154 m .42228 .7819 L .42236 .77676 L .985 .728 .345 r
F
.42215 .77632 m .42202 .78138 L .4221 .78154 L F
.42059 .77886 m .42067 .78413 L .4201 .77907 L .519 .305 .529 r
F
.4201 .77907 m .42106 .80924 L .42005 .80967 L F
.4223 .77555 m .44285 .77586 L .44219 .772 L .673 .758 .914 r
F
.41798 .77632 m .42461 .7762 L .4223 .77555 L F
.42461 .7762 m .44285 .77586 L .4223 .77555 L F
.42086 .77514 m .42024 .78027 L .42085 .78045 L .809 .541 .534 r
F
.42091 .74671 m .42034 .775 L .42086 .77514 L F
.42034 .775 m .42024 .78027 L .42086 .77514 L F
.42083 .78044 m .44029 .77404 L .43646 .77099 L .673 .758 .914 r
F
.41829 .78198 m .4218 .78071 L .42083 .78044 L F
.4218 .78071 m .44029 .77404 L .42083 .78044 L F
.42067 .78413 m .42075 .78939 L .42043 .78423 L .519 .305 .529 r
F
.42037 .78955 m .42065 .7904 L .42086 .79008 L .673 .758 .915 r
F
.42075 .78939 m .42106 .80924 L .42044 .78953 L .519 .305 .529 r
F
.42085 .78045 m .42061 .78569 L .42084 .78575 L .809 .541 .534 r
F
.4214 .7755 m .4212 .78599 L .42191 .77584 L .908 .63 .503 r
F
.4214 .7801 m .43646 .77099 L .42098 .77925 L .673 .758 .914 r
F
.4212 .78599 m .42153 .78621 L .42172 .78102 L .908 .63 .503 r
F
.42155 .78091 m .42172 .78102 L .42191 .77584 L F
.4212 .78599 m .42172 .78102 L .42155 .78091 L F
.41829 .78198 m .42286 .7819 L .42291 .78182 L .673 .758 .914 r
F
.42213 .78129 m .42291 .78182 L .42343 .78106 L F
.41829 .78198 m .42291 .78182 L .42213 .78129 L F
.42202 .78138 m .4219 .78645 L .4221 .78154 L .985 .728 .345 r
F
.4218 .78071 m .42343 .78106 L .42429 .77981 L .673 .758 .914 r
F
.41829 .78198 m .42319 .7811 L .4218 .78071 L F
.42319 .7811 m .42343 .78106 L .4218 .78071 L F
.42034 .775 m .41978 .78015 L .42024 .78027 L .809 .541 .534 r
F
.42091 .74671 m .41996 .77489 L .42034 .775 L F
.41996 .77489 m .41978 .78015 L .42034 .775 L F
.42091 .74671 m .41979 .77484 L .41996 .77489 L F
.42196 .74752 m .42086 .77514 L .4214 .7755 L .908 .63 .503 r
F
.42196 .74752 m .4214 .7755 L .42191 .77584 L F
.42241 .74856 m .42191 .77584 L .42215 .77632 L .985 .728 .345 r
F
.4185 .78991 m .41792 .8027 L .41945 .78977 L .673 .758 .915 r
F
.4185 .78991 m .42005 .80967 L .41847 .80987 L .642 .403 .542 r
F
.41912 .79261 m .41792 .8027 L .42005 .79125 L .673 .758 .915 r
F
.41817 .78466 m .41815 .78518 L .4193 .78449 L .673 .758 .914 r
F
.41879 .78456 m .42005 .80967 L .41851 .7846 L .642 .403 .542 r
F
.41977 .78545 m .41866 .80485 L .41974 .80498 L .734 .478 .542 r
F
.41798 .77632 m .41915 .77921 L .42048 .77901 L .673 .758 .914 r
F
.42241 .74856 m .42215 .77632 L .42236 .77676 L .985 .728 .345 r
F
.41946 .77482 m .43606 .76539 L .43101 .7631 L .673 .758 .914 r
F
.41798 .77632 m .42036 .77488 L .41946 .77482 L F
.42036 .77488 m .43606 .76539 L .41946 .77482 L F
.41979 .77484 m .41905 .7854 L .41977 .78545 L .734 .478 .542 r
F
.41984 .74633 m .41927 .7748 L .41979 .77484 L F
.41927 .7748 m .41916 .7801 L .41979 .77484 L F
.41984 .74633 m .41876 .74621 L .41871 .77476 L F
.41798 .77632 m .41946 .77482 L .41874 .77477 L .673 .758 .914 r
F
.41851 .7846 m .41883 .78986 L .4185 .78991 L .642 .403 .542 r
F
.4186 .78764 m .4185 .78991 L .41945 .78977 L .673 .758 .915 r
F
.42095 .77453 m .43987 .76842 L .43606 .76539 L .673 .758 .914 r
F
.41798 .77632 m .42379 .77423 L .42095 .77453 L F
.42379 .77423 m .43987 .76842 L .42095 .77453 L F
.41829 .78198 m .4192 .7801 L .4187 .78007 L F
.41829 .78198 m .4187 .78007 L .41838 .7801 L F
.41798 .77632 m .41883 .77457 L .41807 .77436 L F
.41798 .77632 m .44219 .772 L .43987 .76842 L F
.41757 .78019 m .41897 .7669 L .41248 .76754 L F
.41829 .78198 m .41838 .7801 L .41757 .78019 L F
.41818 .77482 m .41807 .78013 L .41871 .77476 L .661 .418 .542 r
F
.41807 .78013 m .41834 .78011 L .41871 .77476 L F
.41838 .7801 m .41897 .7669 L .41757 .78019 L .673 .758 .914 r
F
.41807 .78013 m .41797 .78545 L .41834 .78011 L .661 .418 .542 r
F
.41797 .78545 m .41757 .80494 L .41831 .78541 L F
.41797 .78545 m .41831 .78541 L .41871 .77476 L F
.41773 .78548 m .41928 .77257 L .41278 .7732 L .673 .758 .915 r
F
.4186 .78764 m .4187 .78537 L .41773 .78548 L F
.41838 .7801 m .4187 .78007 L .41838 .78004 L .673 .758 .914 r
F
.41871 .77476 m .41851 .78009 L .4187 .78007 L .661 .418 .542 r
F
.41851 .78009 m .41757 .80494 L .4187 .78007 L F
.41984 .74633 m .41871 .77476 L .41927 .7748 L .734 .478 .542 r
F
.41874 .77477 m .41952 .77477 L .41883 .77457 L .673 .758 .914 r
F
.41852 .7793 m .41879 .78456 L .41851 .7846 L .642 .403 .542 r
F
.41829 .78198 m .41817 .78466 L .4193 .78449 L .673 .758 .914 r
F
.4187 .78537 m .41928 .77257 L .41773 .78548 L .673 .758 .915 r
F
.4187 .78007 m .41757 .80494 L .41866 .80485 L .661 .418 .542 r
F
.41876 .74621 m .41818 .77482 L .41871 .77476 L F
.41927 .7748 m .41869 .78537 L .41905 .7854 L .734 .478 .542 r
F
.41946 .77482 m .41952 .77477 L .41874 .77477 L .673 .758 .914 r
F
.41916 .7801 m .41942 .78012 L .41979 .77484 L .734 .478 .542 r
F
.4192 .7801 m .42542 .7673 L .41838 .78004 L .673 .758 .914 r
F
.41916 .7801 m .41905 .7854 L .41942 .78012 L .734 .478 .542 r
F
.41996 .77489 m .41979 .77484 L .41978 .78015 L .809 .541 .534 r
F
.41829 .78198 m .4214 .7801 L .42098 .77925 L .673 .758 .914 r
F
.4214 .7755 m .42085 .78045 L .4213 .78074 L .908 .63 .503 r
F
.4221 .7777 m .42318 .77844 L .42296 .77799 L .673 .758 .914 r
F
.41829 .78198 m .43139 .76869 L .42542 .7673 L F
.4187 .78537 m .42573 .77296 L .41928 .77257 L .673 .758 .915 r
F
.4186 .78764 m .41967 .78544 L .4187 .78537 L F
.41829 .78198 m .42131 .78379 L .42205 .78324 L .673 .758 .914 r
F
.41967 .78544 m .42573 .77296 L .4187 .78537 L .673 .758 .915 r
F
.41927 .7748 m .41871 .77476 L .41869 .78537 L .734 .478 .542 r
F
.41883 .78986 m .42005 .80967 L .4185 .78991 L .642 .403 .542 r
F
.41905 .7854 m .41869 .78537 L .41866 .80485 L .734 .478 .542 r
F
.41883 .77457 m .42508 .76171 L .41807 .77436 L .673 .758 .914 r
F
.41883 .77457 m .43101 .7631 L .42508 .76171 L F
.41952 .77477 m .43101 .7631 L .41883 .77457 L F
.41838 .78004 m .42542 .7673 L .41897 .7669 L F
.4186 .78764 m .42054 .78567 L .41977 .78545 L .673 .758 .915 r
F
.4186 .78764 m .41977 .78545 L .41967 .78544 L F
.41905 .7854 m .41866 .80485 L .41977 .78545 L .734 .478 .542 r
F
.41967 .78544 m .41977 .78545 L .41968 .78542 L .673 .758 .915 r
F
.41807 .77436 m .42508 .76171 L .41866 .76132 L .673 .758 .914 r
F
.42091 .74671 m .41984 .74633 L .41979 .77484 L .809 .541 .534 r
F
.4186 .78764 m .42037 .78955 L .4212 .78921 L .673 .758 .915 r
F
.42343 .78106 m .44329 .78152 L .44262 .77763 L .673 .758 .914 r
F
.42286 .7819 m .44329 .78152 L .42343 .78106 L F
.42144 .78592 m .4406 .77971 L .43676 .77666 L .673 .758 .915 r
F
.4186 .78764 m .42252 .78622 L .42144 .78592 L F
.42252 .78622 m .4406 .77971 L .42144 .78592 L F
.42024 .78027 m .41978 .78015 L .41977 .78545 L .809 .541 .534 r
F
.42013 .78555 m .41977 .78545 L .41974 .80498 L F
.42024 .78027 m .41977 .78545 L .42013 .78555 L F
.41968 .78542 m .43169 .77436 L .42573 .77296 L .673 .758 .915 r
F
.4221 .78154 m .42205 .78676 L .42228 .7819 L .985 .728 .345 r
F
.4213 .78074 m .42084 .78575 L .4212 .78599 L .908 .63 .503 r
F
.42262 .7826 m .42291 .78319 L .42388 .78279 L .673 .758 .914 r
F
.42054 .78567 m .43169 .77436 L .41968 .78542 L .673 .758 .915 r
F
.42084 .78575 m .41974 .80498 L .42081 .80535 L .809 .541 .534 r
F
.42061 .78569 m .41974 .80498 L .42084 .78575 L F
.42054 .78567 m .42159 .78583 L .42119 .78501 L .673 .758 .915 r
F
.4186 .78764 m .42144 .78592 L .42054 .78567 L F
.42144 .78592 m .42159 .78583 L .42054 .78567 L F
.42024 .78027 m .42013 .78555 L .42085 .78045 L .809 .541 .534 r
F
.42013 .78555 m .41974 .80498 L .42061 .78569 L F
.42013 .78555 m .42061 .78569 L .42085 .78045 L F
.42119 .78501 m .43676 .77666 L .43169 .77436 L .673 .758 .915 r
F
.42205 .78676 m .42219 .78705 L .42228 .7819 L .985 .728 .345 r
F
.42206 .78306 m .42208 .78831 L .42195 .78321 L .077 0 .416 r
F
.4221 .78154 m .4219 .78645 L .42205 .78676 L .985 .728 .345 r
F
.42159 .78583 m .43676 .77666 L .42119 .78501 L .673 .758 .915 r
F
.42205 .78676 m .42186 .80617 L .42219 .78705 L .985 .728 .345 r
F
.42098 .77925 m .43646 .77099 L .43139 .76869 L .673 .758 .914 r
F
.4219 .78645 m .44293 .7833 L .4406 .77971 L .673 .758 .915 r
F
.4186 .78764 m .42261 .78692 L .4219 .78645 L F
.42261 .78692 m .44293 .7833 L .4219 .78645 L F
.4212 .78921 m .42086 .79008 L .42139 .78932 L F
.4212 .78599 m .42081 .80535 L .42153 .78621 L .908 .63 .503 r
F
.4212 .78599 m .42084 .78575 L .42081 .80535 L F
.4218 .78872 m .43579 .79796 L .42181 .78872 L .673 .758 .915 r
F
.42139 .78932 m .43579 .79796 L .4218 .78872 L F
.42208 .78831 m .42223 .7881 L .4222 .808 L .077 0 .416 r
F
.42678 .79645 m .4305 .80045 L .42409 .79094 L .673 .758 .915 r
F
.42189 .78859 m .4222 .808 L .4218 .78872 L .077 0 .416 r
F
.42205 .78676 m .4219 .78645 L .42186 .80617 L .985 .728 .345 r
F
.42227 .78784 m .42231 .8072 L .42223 .7881 L 0 0 .138 r
F
.42234 .78737 m .42186 .80617 L .42231 .8072 L .985 .728 .345 r
F
.42219 .78705 m .42186 .80617 L .42234 .78737 L F
.42678 .79645 m .42894 .80087 L .4305 .80045 L .673 .758 .915 r
F
.42086 .79008 m .42894 .80087 L .42678 .79645 L F
.39208 .70596 m .35883 .70387 L .38878 .71061 L .654 .726 .902 r
F
.44907 .71376 m .47358 .70023 L .44614 .70879 L F
.44907 .71376 m .47942 .71018 L .47358 .70023 L F
.47012 .81858 m .48215 .80336 L .48247 .80902 L .391 .238 .551 r
F
.45296 .80828 m .47012 .81858 L .48247 .80902 L .673 .758 .915 r
F
.44239 .81325 m .47012 .81858 L .45296 .80828 L F
0 g
.45427 .82603 m
.47012 .81858 L
s
.39252 .6987 m .36586 .68731 L .35927 .69661 L .654 .726 .902 r
F
.39764 .69483 m .36586 .68731 L .39252 .6987 L F
.39819 .68765 m .37675 .67245 L .36658 .68017 L F
.40474 .68483 m .37675 .67245 L .39819 .68765 L F
.44657 .70153 m .46442 .68418 L .44178 .69714 L F
.44657 .70153 m .47401 .69297 L .46442 .68418 L F
.4421 .68995 m .45201 .67006 L .43579 .68645 L F
.4421 .68995 m .46462 .67705 L .45201 .67006 L F
.51083 .6891 m .53024 .69237 L .52982 .69963 L .857 .601 .551 r
F
.51083 .6891 m .51125 .68184 L .53024 .69237 L F
.53393 .66887 m .53024 .69237 L .5466 .6759 L .654 .726 .902 r
F
.53393 .66887 m .51125 .68184 L .53024 .69237 L F
0 g
.53024 .69237 m
.53539 .69402 L
s
.36586 .68731 m .32931 .68987 L .35927 .69661 L .654 .726 .902 r
F
.62387 .69727 m .64411 .68151 L .6437 .68877 L .496 .29 .529 r
F
.62346 .70453 m .62387 .69727 L .6437 .68877 L F
.60905 .67917 m .62387 .69727 L .6437 .68877 L .654 .726 .902 r
F
.59381 .68237 m .62387 .69727 L .60905 .67917 L F
0 g
.61329 .69949 m
.62387 .69727 L
s
.47985 .70292 m .50146 .6844 L .47401 .69297 L .654 .726 .902 r
F
.47985 .70292 m .51021 .69934 L .50146 .6844 L F
.35267 .81142 m .36388 .81488 L .36418 .82054 L .93 .657 .5 r
F
.35267 .81142 m .35237 .80576 L .36388 .81488 L F
.37434 .79784 m .36388 .81488 L .382 .80393 L .673 .758 .914 r
F
.37434 .79784 m .35237 .80576 L .36388 .81488 L F
0 g
.36388 .81488 m
.36941 .81738 L
s
.36658 .68017 m .34004 .66882 L .33021 .68271 L .654 .726 .902 r
F
.33919 .67591 m .32976 .68261 L .32931 .68987 L .067 0 .393 r
F
.33919 .67591 m .33964 .66865 L .32976 .68261 L F
0 g
.32602 .69793 m
.32976 .68261 L
s
.51021 .69934 m .51064 .69208 L .50189 .67714 L .99 .743 .46 r
F
0 g
.51064 .69208 m
.51318 .70773 L
s
.57869 .56715 m .58037 .62534 L .57879 .62554 L .642 .403 .541 r
F
.57869 .56715 m .58027 .56695 L .58037 .62534 L F
.57714 .56689 m .57869 .56715 L .57879 .62554 L .751 .492 .54 r
F
0 g
.57869 .56715 m
.57869 .56715 L
s
.58027 .56695 m .58139 .6249 L .58037 .62534 L .519 .305 .529 r
F
.58027 .56695 m .58129 .56651 L .58139 .6249 L F
0 g
.57869 .56715 m
.58027 .56695 L
s
.57714 .56689 m .57879 .62554 L .57723 .62528 L .751 .492 .54 r
F
.57616 .56642 m .57714 .56689 L .57723 .62528 L .844 .571 .525 r
F
0 g
.57714 .56689 m
.57869 .56715 L
s
.58129 .56651 m .5821 .62434 L .58139 .6249 L .361 .183 .5 r
F
.58129 .56651 m .58199 .56595 L .5821 .62434 L F
0 g
.58027 .56695 m
.58129 .56651 L
s
.57616 .56642 m .57723 .62528 L .57625 .62481 L .844 .571 .525 r
F
.5755 .56583 m .57616 .56642 L .57625 .62481 L .928 .648 .489 r
F
0 g
.57616 .56642 m
.57714 .56689 L
s
.40521 .79525 m .39214 .80851 L .40405 .8113 L .673 .758 .914 r
F
.58199 .56595 m .58253 .62366 L .5821 .62434 L .082 0 .419 r
F
.58199 .56595 m .58243 .56527 L .58253 .62366 L F
0 g
.58129 .56651 m
.58199 .56595 L
s
.5755 .56583 m .57625 .62481 L .57559 .62422 L .928 .648 .489 r
F
.57513 .56513 m .5755 .56583 L .57559 .62422 L .988 .72 .386 r
F
0 g
.5755 .56583 m
.57616 .56642 L
s
.40474 .68483 m .38986 .66681 L .37675 .67245 L .654 .726 .902 r
F
.41231 .68324 m .38986 .66681 L .40474 .68483 L F
.43579 .68645 m .43718 .6653 L .42838 .68408 L F
.43579 .68645 m .45201 .67006 L .43718 .6653 L F
.58243 .56527 m .58265 .62285 L .58253 .62366 L 0 0 .148 r
F
.58243 .56527 m .58255 .56446 L .58265 .62285 L F
0 g
.58199 .56595 m
.58243 .56527 L
s
.57513 .56513 m .57559 .62422 L .57522 .62353 L .988 .72 .386 r
F
.57508 .56432 m .57513 .56513 L .57522 .62353 L .779 .622 .059 r
F
0 g
.57513 .56513 m
.5755 .56583 L
s
.37464 .8035 m .36418 .82054 L .38231 .80958 L .673 .758 .915 r
F
.37464 .8035 m .35267 .81142 L .36418 .82054 L F
0 g
.36418 .82054 m
.37938 .82742 L
s
.41147 .80231 m .40436 .81695 L .41724 .81774 L .673 .758 .915 r
F
.39208 .70596 m .36542 .69457 L .35883 .70387 L .654 .726 .902 r
F
.3972 .70209 m .36542 .69457 L .39208 .70596 L F
.48215 .80336 m .48184 .7977 L .48985 .78668 L .172 .076 .497 r
F
0 g
.47478 .80318 m
.48184 .7977 L
s
.39764 .69483 m .37609 .67956 L .36586 .68731 L .654 .726 .902 r
F
.40422 .692 m .37609 .67956 L .39764 .69483 L F
.44614 .70879 m .46399 .69144 L .44134 .7044 L F
.44614 .70879 m .47358 .70023 L .46399 .69144 L F
.46036 .79051 m .48152 .7976 L .48949 .78663 L .673 .758 .914 r
F
.45217 .79686 m .48152 .7976 L .46036 .79051 L F
.53351 .67613 m .52982 .69963 L .54618 .68316 L .654 .726 .902 r
F
.53351 .67613 m .51083 .6891 L .52982 .69963 L F
0 g
.52982 .69963 m
.55214 .70679 L
s
.44178 .69714 m .45174 .67716 L .43544 .69363 L .654 .726 .902 r
F
.44178 .69714 m .46442 .68418 L .45174 .67716 L F
.36542 .69457 m .32886 .69713 L .35883 .70387 L F
.58255 .56446 m .58221 .62181 L .58265 .62285 L .984 .727 .338 r
F
.58255 .56446 m .5821 .56342 L .58221 .62181 L F
.62346 .70453 m .6437 .68877 L .6433 .69603 L .496 .29 .529 r
F
.60864 .68643 m .62346 .70453 L .6433 .69603 L .654 .726 .902 r
F
.59339 .68963 m .62346 .70453 L .60864 .68643 L F
0 g
.6006 .70933 m
.62346 .70453 L
s
.57508 .56432 m .57522 .62353 L .57517 .62272 L .779 .622 .059 r
F
.57561 .5633 m .57508 .56432 L .57517 .62272 L 0 0 .381 r
F
.42441 .80207 m .43021 .81647 L .44239 .81325 L .673 .758 .915 r
F
.43019 .79479 m .44208 .80759 L .45265 .80262 L .673 .758 .914 r
F
.47942 .71018 m .50103 .69167 L .47358 .70023 L .654 .726 .902 r
F
.47942 .71018 m .50979 .7066 L .50103 .69167 L F
.41231 .68324 m .405 .66362 L .38986 .66681 L F
.42037 .68298 m .405 .66362 L .41231 .68324 L F
.42838 .68408 m .42114 .6631 L .42037 .68298 L F
.42838 .68408 m .43718 .6653 L .42114 .6631 L F
.5821 .56342 m .58116 .62099 L .58221 .62181 L .909 .63 .501 r
F
.5821 .56342 m .58106 .5626 L .58116 .62099 L F
0 g
.5821 .56342 m
.58255 .56446 L
s
.5821 .56342 m
.5821 .56342 L
s
.36586 .68731 m .33919 .67591 L .32931 .68987 L .654 .726 .902 r
F
.33874 .68317 m .32931 .68987 L .32886 .69713 L .067 0 .393 r
F
.33874 .68317 m .33919 .67591 L .32931 .68987 L F
0 g
.32557 .70519 m
.32931 .68987 L
s
.57673 .56252 m .57561 .5633 L .5757 .62169 L .404 .216 .509 r
F
.57561 .5633 m .57517 .62272 L .5757 .62169 L 0 0 .381 r
F
0 g
.57508 .56432 m
.57561 .5633 L
s
.57561 .5633 m
.57561 .5633 L
s
.40551 .80091 m .40436 .81695 L .41147 .80231 L .673 .758 .915 r
F
.40551 .80091 m .39244 .81417 L .40436 .81695 L F
.49688 .66865 m .51168 .67458 L .51125 .68184 L .927 .669 .528 r
F
.49688 .66865 m .49731 .66139 L .51168 .67458 L F
0 g
.51168 .67458 m
.51791 .67804 L
s
.37675 .67245 m .34004 .66882 L .36658 .68017 L .654 .726 .902 r
F
.51021 .69934 m .50189 .67714 L .50146 .6844 L .99 .743 .46 r
F
.50979 .7066 m .51021 .69934 L .50146 .6844 L F
0 g
.51021 .69934 m
.51275 .71499 L
s
.52506 .65273 m .51202 .67439 L .53458 .66148 L .654 .726 .902 r
F
.52506 .65273 m .49772 .66126 L .51202 .67439 L F
.42037 .68298 m .42114 .6631 L .405 .66362 L F
.6437 .68877 m .64411 .68151 L .65958 .66988 L .347 .169 .492 r
F
0 g
.63366 .68599 m
.64411 .68151 L
s
.47416 .6858 m .48717 .66414 L .46462 .67705 L .654 .726 .902 r
F
.47416 .6858 m .50148 .67727 L .48717 .66414 L F
.58106 .5626 m .58009 .62062 L .58116 .62099 L .809 .541 .533 r
F
.58106 .5626 m .57999 .56223 L .58009 .62062 L F
0 g
.58106 .5626 m
.5821 .56342 L
s
.57673 .56252 m .5757 .62169 L .57682 .62092 L .404 .216 .509 r
F
.57782 .56219 m .57673 .56252 L .57682 .62092 L .569 .345 .536 r
F
0 g
.57561 .5633 m
.57673 .56252 L
s
.62247 .66608 m .64379 .68129 L .65918 .66971 L .654 .726 .902 r
F
.60931 .67173 m .64379 .68129 L .62247 .66608 L F
.57999 .56223 m .57901 .62049 L .58009 .62062 L .734 .478 .541 r
F
.57999 .56223 m .57891 .5621 L .57901 .62049 L F
0 g
.57999 .56223 m
.58106 .5626 L
s
.40014 .79296 m .382 .80393 L .39214 .80851 L .673 .758 .914 r
F
.57782 .56219 m .57682 .62092 L .57792 .62058 L .569 .345 .536 r
F
.57891 .5621 m .57782 .56219 L .57792 .62058 L .66 .418 .542 r
F
0 g
.57673 .56252 m
.57782 .56219 L
s
.57891 .5621 m .57792 .62058 L .57901 .62049 L .66 .418 .542 r
F
0 g
.57891 .5621 m
.57999 .56223 L
s
.57782 .56219 m
.57891 .5621 L
s
.43508 .78659 m .45217 .79686 L .46036 .79051 L .673 .758 .914 r
F
.48215 .80336 m .48985 .78668 L .49016 .79234 L .172 .076 .497 r
F
.48247 .80902 m .48215 .80336 L .49016 .79234 L F
.46088 .79624 m .48215 .80336 L .49016 .79234 L .673 .758 .914 r
F
.45265 .80262 m .48215 .80336 L .46088 .79624 L F
0 g
.47509 .80883 m
.48215 .80336 L
s
.40422 .692 m .38927 .67389 L .37609 .67956 L .654 .726 .902 r
F
.41183 .6904 m .38927 .67389 L .40422 .692 L F
.4305 .80045 m .44239 .81325 L .45296 .80828 L .673 .758 .915 r
F
.42441 .80207 m .44239 .81325 L .4305 .80045 L F
.43544 .69363 m .43683 .67237 L .42799 .69124 L .654 .726 .902 r
F
.43544 .69363 m .45174 .67716 L .43683 .67237 L F
.3972 .70209 m .37565 .68682 L .36542 .69457 L F
.40378 .69926 m .37565 .68682 L .3972 .70209 L F
.44134 .7044 m .4513 .68442 L .435 .70089 L F
.44134 .7044 m .46399 .69144 L .4513 .68442 L F
.57889 .65554 m .57801 .67543 L .59415 .67491 L F
.57088 .65444 m .57801 .67543 L .57889 .65554 L F
.57088 .65444 m .56199 .67323 L .57801 .67543 L F
.34535 .79501 m .35207 .8001 L .35237 .80576 L .987 .713 .39 r
F
.127 .923 .03 r
.3447 .7753 m
.35136 .72073 L
s
.34535 .79501 m .34505 .78935 L .35207 .8001 L .987 .713 .39 r
F
0 g
.35207 .8001 m
.35707 .80407 L
s
.3696 .78497 m .3524 .79999 L .37425 .7921 L .673 .758 .914 r
F
.3696 .78497 m .34541 .78929 L .3524 .79999 L F
.40044 .79862 m .39244 .81417 L .40551 .80091 L .673 .758 .915 r
F
.40044 .79862 m .38231 .80958 L .39244 .81417 L F
.39611 .78421 m .38188 .79816 L .39993 .78724 L .673 .758 .914 r
F
.39611 .78421 m .37425 .7921 L .38188 .79816 L F
.41183 .6904 m .40449 .67068 L .38927 .67389 L .654 .726 .902 r
F
.41994 .69014 m .40449 .67068 L .41183 .6904 L F
.36542 .69457 m .33874 .68317 L .32886 .69713 L F
0 g
.32512 .71245 m
.32886 .69713 L
s
.42799 .69124 m .42071 .67017 L .41994 .69014 L .654 .726 .902 r
F
.42799 .69124 m .43683 .67237 L .42071 .67017 L F
.43548 .7923 m .45265 .80262 L .46088 .79624 L .673 .758 .914 r
F
.49646 .67591 m .51125 .68184 L .51083 .6891 L .927 .669 .528 r
F
0 g
.50665 .68526 m
.51064 .69208 L
s
.50146 .6844 m .50189 .67714 L .48751 .66395 L .927 .669 .528 r
F
.49646 .67591 m .49688 .66865 L .51125 .68184 L F
.52436 .66007 m .51125 .68184 L .53393 .66887 L .654 .726 .902 r
F
.52436 .66007 m .49688 .66865 L .51125 .68184 L F
0 g
.51125 .68184 m
.51748 .6853 L
s
.48247 .80902 m .49016 .79234 L .49047 .79799 L .172 .076 .497 r
F
.46119 .8019 m .48247 .80902 L .49047 .79799 L .673 .758 .915 r
F
.45296 .80828 m .48247 .80902 L .46119 .8019 L F
0 g
.47012 .81858 m
.48247 .80902 L
s
.56347 .65206 m .56199 .67323 L .57088 .65444 L .654 .726 .902 r
F
.56347 .65206 m .54718 .66848 L .56199 .67323 L F
.50979 .7066 m .50146 .6844 L .50103 .69167 L .99 .743 .46 r
F
0 g
.50979 .7066 m
.51233 .72225 L
s
.58697 .65529 m .59415 .67491 L .60931 .67173 L .654 .726 .902 r
F
.57889 .65554 m .59415 .67491 L .58697 .65529 L F
.37609 .67956 m .33919 .67591 L .36586 .68731 L F
.6437 .68877 m .65958 .66988 L .65917 .67714 L .347 .169 .492 r
F
.6433 .69603 m .6437 .68877 L .65917 .67714 L F
.62228 .6735 m .6437 .68877 L .65917 .67714 L .654 .726 .902 r
F
.60905 .67917 m .6437 .68877 L .62228 .6735 L F
0 g
.63325 .69325 m
.6437 .68877 L
s
.41994 .69014 m .42071 .67017 L .40449 .67068 L .654 .726 .902 r
F
.47401 .69297 m .48708 .67121 L .46442 .68418 L F
.47401 .69297 m .50146 .6844 L .48708 .67121 L F
.40378 .69926 m .38883 .68115 L .37565 .68682 L F
.41139 .69766 m .38883 .68115 L .40378 .69926 L F
.435 .70089 m .43639 .67964 L .42755 .69851 L F
.435 .70089 m .4513 .68442 L .43639 .67964 L F
.34565 .80067 m .35237 .80576 L .35267 .81142 L .987 .713 .39 r
F
.34565 .80067 m .34535 .79501 L .35237 .80576 L F
.36966 .79067 m .35237 .80576 L .37434 .79784 L .673 .758 .914 r
F
.36966 .79067 m .34535 .79501 L .35237 .80576 L F
0 g
.35237 .80576 m
.35737 .80973 L
s
.39631 .78991 m .382 .80393 L .40014 .79296 L .673 .758 .914 r
F
.39631 .78991 m .37434 .79784 L .382 .80393 L F
.43579 .79796 m .45296 .80828 L .46119 .8019 L .673 .758 .915 r
F
.4305 .80045 m .45296 .80828 L .43579 .79796 L F
.57847 .6629 m .57758 .68289 L .59381 .68237 L .654 .726 .902 r
F
.57042 .6618 m .57758 .68289 L .57847 .6629 L F
.57042 .6618 m .56148 .68068 L .57758 .68289 L F
.46036 .79051 m .48949 .78663 L .46566 .78319 L .673 .758 .914 r
F
.43918 .78342 m .46036 .79051 L .46566 .78319 L F
0 g
.42196 .74752 m
.42202 .71632 L
s
.41139 .69766 m .40405 .67795 L .38883 .68115 L .654 .726 .902 r
F
.4195 .6974 m .40405 .67795 L .41139 .69766 L F
.42755 .69851 m .42027 .67743 L .4195 .6974 L F
.42755 .69851 m .43639 .67964 L .42027 .67743 L F
0 g
.41547 .7474 m
.41553 .71598 L
s
.56297 .65941 m .56148 .68068 L .57042 .6618 L .654 .726 .902 r
F
.56297 .65941 m .5466 .6759 L .56148 .68068 L F
.58659 .66265 m .59381 .68237 L .60905 .67917 L F
.57847 .6629 m .59381 .68237 L .58659 .66265 L F
.55717 .64856 m .54718 .66848 L .56347 .65206 L F
.55717 .64856 m .53458 .66148 L .54718 .66848 L F
.52393 .66733 m .51083 .6891 L .53351 .67613 L F
.52393 .66733 m .49646 .67591 L .51083 .6891 L F
0 g
.51083 .6891 m
.52982 .69963 L
s
.49906 .67065 m
.50268 .67397 L
s
.59455 .65369 m .60931 .67173 L .62247 .66608 L .654 .726 .902 r
F
.58697 .65529 m .60931 .67173 L .59455 .65369 L F
.37565 .68682 m .33874 .68317 L .36542 .69457 L F
.6433 .69603 m .65917 .67714 L .65877 .68441 L .347 .169 .492 r
F
.62187 .68076 m .6433 .69603 L .65877 .68441 L .654 .726 .902 r
F
.60864 .68643 m .6433 .69603 L .62187 .68076 L F
0 g
.62346 .70453 m
.6433 .69603 L
s
.36713 .6589 m .349 .66128 L .37181 .65647 L .593 .369 .546 r
F
.37675 .67245 m .35981 .66044 L .34004 .66882 L .654 .726 .902 r
F
.35981 .66044 m .34773 .66299 L .34004 .66882 L F
.34891 .66274 m .349 .66128 L .36713 .6589 L .593 .369 .546 r
F
.34153 .64133 m .34888 .66098 L .37159 .65619 L .654 .726 .902 r
F
.38986 .66681 m .36381 .6596 L .37675 .67245 L F
.36381 .6596 m .3553 .65724 L .35981 .66044 L F
.36381 .6596 m .35981 .66044 L .37675 .67245 L F
.36713 .6589 m .37181 .65647 L .37172 .65793 L .593 .369 .546 r
F
.35668 .63814 m .37159 .65619 L .39126 .64772 L .654 .726 .902 r
F
.34153 .64133 m .37159 .65619 L .35668 .63814 L F
.36628 .66028 m .37496 .64876 L .3553 .65724 L F
.38986 .66681 m .3797 .65449 L .36628 .66028 L F
.37172 .65793 m .37181 .65647 L .38751 .65113 L .494 .287 .528 r
F
.3797 .65449 m .37496 .64876 L .36628 .66028 L .654 .726 .902 r
F
.38751 .65113 m .37181 .65647 L .39158 .64795 L .494 .287 .528 r
F
.405 .66362 m .38336 .65291 L .38986 .66681 L .654 .726 .902 r
F
.38336 .65291 m .37496 .64876 L .3797 .65449 L F
.38336 .65291 m .3797 .65449 L .38986 .66681 L F
.38751 .65113 m .39158 .64795 L .39149 .64941 L .494 .287 .528 r
F
.36979 .63248 m .39126 .64772 L .40656 .63612 L .654 .726 .902 r
F
.35668 .63814 m .39126 .64772 L .36979 .63248 L F
.38548 .65397 m .39769 .64397 L .37496 .64876 L F
.405 .66362 m .3979 .64455 L .38548 .65397 L F
.39149 .64941 m .39158 .64795 L .40377 .6401 L .342 .164 .489 r
F
.3979 .64455 m .39769 .64397 L .38548 .65397 L .654 .726 .902 r
F
.40377 .6401 m .39158 .64795 L .40696 .63629 L .342 .164 .489 r
F
.42114 .6631 m .39816 .64436 L .405 .66362 L .654 .726 .902 r
F
.39816 .64436 m .39769 .64397 L .3979 .64455 L F
.39816 .64436 m .3979 .64455 L .405 .66362 L F
.42114 .6631 m .42191 .6432 L .39769 .64397 L F
.39114 .65521 m .39899 .64582 L .39877 .64943 L .342 .164 .489 r
F
.42149 .65016 m .42193 .6429 L .39912 .64363 L .668 .433 .556 r
F
.39909 .64409 m .39912 .64363 L .39758 .64368 L F
.42149 .65016 m .39912 .64363 L .39909 .64409 L F
.39114 .65521 m .39149 .64941 L .39912 .64363 L .342 .164 .489 r
F
.39899 .64582 m .39912 .64363 L .40377 .6401 L F
.39114 .65521 m .39912 .64363 L .39899 .64582 L F
.39877 .64943 m .40377 .6401 L .40652 .64355 L F
.42149 .65016 m .39909 .64409 L .39868 .65089 L .668 .433 .556 r
F
.39899 .64582 m .40377 .6401 L .39877 .64943 L .342 .164 .489 r
F
.39262 .65045 m .39758 .64368 L .37474 .64849 L .593 .369 .546 r
F
.38751 .65113 m .39149 .64941 L .39114 .65521 L .494 .287 .528 r
F
.39722 .64948 m .39114 .65521 L .39877 .64943 L .654 .726 .902 r
F
.39262 .65045 m .37474 .64849 L .37438 .65429 L .593 .369 .546 r
F
.38367 .64991 m .3863 .65178 L .39722 .64948 L .654 .726 .902 r
F
.3863 .65178 m .39114 .65521 L .39722 .64948 L F
.37137 .66373 m .38751 .65113 L .39114 .65521 L .494 .287 .528 r
F
.37137 .66373 m .37172 .65793 L .38751 .65113 L F
.36713 .6589 m .37172 .65793 L .37137 .66373 L .593 .369 .546 r
F
.37964 .65202 m .37137 .66373 L .39114 .65521 L .654 .726 .902 r
F
.3704 .65601 m .37474 .64849 L .35498 .65701 L .494 .287 .528 r
F
.36641 .65773 m .37137 .66373 L .37964 .65202 L .654 .726 .902 r
F
.37429 .65575 m .37438 .65429 L .3704 .65601 L .494 .287 .528 r
F
.37438 .65429 m .37474 .64849 L .3704 .65601 L F
.34855 .66854 m .36713 .6589 L .37137 .66373 L .593 .369 .546 r
F
.36257 .65938 m .34855 .66854 L .37137 .66373 L .654 .726 .902 r
F
.3704 .65601 m .35498 .65701 L .35462 .66281 L .494 .287 .528 r
F
.35981 .66044 m .3553 .65724 L .34773 .66299 L .654 .726 .902 r
F
.347 .66859 m .349 .66128 L .34855 .66854 L .668 .433 .556 r
F
.34714 .66645 m .34736 .66279 L .33964 .66865 L .342 .164 .489 r
F
.32422 .66931 m .34742 .66179 L .347 .66859 L .668 .433 .556 r
F
.34742 .66179 m .349 .66128 L .347 .66859 L F
.35153 .66515 m .35498 .65701 L .34736 .66279 L .342 .164 .489 r
F
.35153 .66515 m .34736 .66279 L .34714 .66645 L F
.34855 .66854 m .34891 .66274 L .36713 .6589 L .593 .369 .546 r
F
.34754 .66586 m .34855 .66854 L .36257 .65938 L .654 .726 .902 r
F
.35453 .66427 m .35462 .66281 L .35153 .66515 L .342 .164 .489 r
F
.35462 .66281 m .35498 .65701 L .35153 .66515 L F
.32422 .66931 m .32467 .66205 L .349 .66128 L .668 .433 .556 r
F
.32539 .64185 m .32468 .66175 L .34888 .66098 L .654 .726 .902 r
F
.32539 .64185 m .34888 .66098 L .34153 .64133 L F
.34116 .64879 m .34754 .66586 L .35462 .66281 L F
.36049 .65835 m .35462 .66281 L .36257 .65938 L F
.34116 .64879 m .35462 .66281 L .36049 .65835 L F
.35638 .64558 m .36641 .65773 L .37964 .65202 L F
.34116 .64879 m .37137 .66373 L .35638 .64558 L F
.37429 .65575 m .3704 .65601 L .35453 .66427 L .494 .287 .528 r
F
.3704 .65601 m .35462 .66281 L .35453 .66427 L F
.35638 .64558 m .39114 .65521 L .36956 .6399 L .654 .726 .902 r
F
.39714 .65094 m .39262 .65045 L .37429 .65575 L .593 .369 .546 r
F
.39262 .65045 m .37438 .65429 L .37429 .65575 L F
.39714 .65094 m .39722 .64948 L .39262 .65045 L F
.39722 .64948 m .39758 .64368 L .39262 .65045 L F
.39846 .64944 m .39758 .64368 L .39722 .64948 L .668 .433 .556 r
F
.39909 .64409 m .39758 .64368 L .39868 .65089 L F
.38367 .64991 m .39722 .64948 L .40652 .64355 L .654 .726 .902 r
F
.39722 .64948 m .39877 .64943 L .39927 .64904 L F
.39722 .64948 m .39927 .64904 L .40652 .64355 L F
.36956 .6399 m .38367 .64991 L .40652 .64355 L F
.40333 .64736 m .39114 .65521 L .40652 .64355 L .342 .164 .489 r
F
.40449 .67068 m .39746 .65181 L .38517 .66113 L .654 .726 .902 r
F
.42071 .67017 m .39785 .65152 L .40449 .67068 L F
.39105 .65667 m .39114 .65521 L .40333 .64736 L .342 .164 .489 r
F
.39785 .65152 m .39714 .65094 L .39746 .65181 L .654 .726 .902 r
F
.39785 .65152 m .39746 .65181 L .40449 .67068 L F
.42071 .67017 m .42149 .65016 L .39714 .65094 L F
.3907 .66247 m .39855 .65309 L .39833 .65669 L .342 .164 .489 r
F
.42105 .65743 m .42149 .65016 L .39868 .65089 L .668 .433 .556 r
F
.39865 .65135 m .39868 .65089 L .39714 .65094 L F
.42105 .65743 m .39868 .65089 L .39865 .65135 L F
.3907 .66247 m .39105 .65667 L .39868 .65089 L .342 .164 .489 r
F
.39855 .65309 m .39868 .65089 L .40333 .64736 L F
.3907 .66247 m .39868 .65089 L .39855 .65309 L F
.39833 .65669 m .40333 .64736 L .40608 .65082 L F
.42105 .65743 m .39865 .65135 L .39824 .65816 L .668 .433 .556 r
F
.39855 .65309 m .40333 .64736 L .39833 .65669 L .342 .164 .489 r
F
.38517 .66113 m .39714 .65094 L .37429 .65575 L .654 .726 .902 r
F
.39868 .65089 m .39846 .64944 L .39714 .65094 L .668 .433 .556 r
F
.39746 .65181 m .39714 .65094 L .38517 .66113 L .654 .726 .902 r
F
.38707 .65839 m .37137 .66373 L .39114 .65521 L .494 .287 .528 r
F
.38927 .67389 m .36603 .66745 L .37609 .67956 L .654 .726 .902 r
F
.37128 .66519 m .37137 .66373 L .38707 .65839 L .494 .287 .528 r
F
.36668 .66616 m .34855 .66854 L .37137 .66373 L .593 .369 .546 r
F
.36365 .6668 m .37429 .65575 L .35453 .66427 L .654 .726 .902 r
F
.38927 .67389 m .38049 .66325 L .36365 .6668 L F
.38049 .66325 m .37429 .65575 L .36365 .6668 L F
.34846 .67 m .34855 .66854 L .36668 .66616 L .593 .369 .546 r
F
.37609 .67956 m .35937 .6677 L .33919 .67591 L .654 .726 .902 r
F
.35937 .6677 m .35453 .66427 L .34641 .67043 L F
.32377 .67657 m .34356 .67016 L .3481 .6758 L .668 .433 .556 r
F
.34691 .67005 m .33964 .66865 L .33919 .67591 L .342 .164 .489 r
F
.34698 .66905 m .34855 .66854 L .34691 .67005 L .668 .433 .556 r
F
.35453 .66427 m .34714 .66645 L .34691 .67005 L .342 .164 .489 r
F
.34714 .66645 m .33964 .66865 L .34545 .66977 L F
.34714 .66645 m .34545 .66977 L .347 .66859 L F
.32493 .64931 m .32422 .66931 L .347 .66859 L .654 .726 .902 r
F
.34783 .66796 m .347 .66859 L .34855 .66854 L F
.32493 .64931 m .347 .66859 L .34783 .66796 L F
.347 .66859 m .34545 .66977 L .34691 .67005 L .342 .164 .489 r
F
.34691 .67005 m .34855 .66854 L .34846 .67 L .668 .433 .556 r
F
.34356 .67016 m .34698 .66905 L .34691 .67005 L F
.35416 .66982 m .34641 .67043 L .33919 .67591 L .654 .726 .902 r
F
.35937 .6677 m .34846 .67 L .35416 .66982 L F
.34846 .67 m .34641 .67043 L .35416 .66982 L F
.36603 .66745 m .36167 .66933 L .37609 .67956 L F
.3481 .6758 m .36668 .66616 L .37092 .67099 L .593 .369 .546 r
F
.3481 .6758 m .34846 .67 L .36668 .66616 L F
.36603 .66745 m .35453 .66427 L .36167 .66933 L .654 .726 .902 r
F
.36996 .66327 m .35453 .66427 L .35417 .67007 L .494 .287 .528 r
F
.36668 .66616 m .37137 .66373 L .37128 .66519 L .593 .369 .546 r
F
.36668 .66616 m .37128 .66519 L .37092 .67099 L F
.40449 .67068 m .38309 .6601 L .38927 .67389 L .654 .726 .902 r
F
.38309 .6601 m .37429 .65575 L .37925 .66176 L F
.38309 .6601 m .37925 .66176 L .38927 .67389 L F
.37092 .67099 m .38707 .65839 L .3907 .66247 L .494 .287 .528 r
F
.38707 .65839 m .39114 .65521 L .39105 .65667 L F
.38707 .65839 m .39105 .65667 L .3907 .66247 L F
.37092 .67099 m .37128 .66519 L .38707 .65839 L F
.3792 .65929 m .37092 .67099 L .3907 .66247 L .654 .726 .902 r
F
.36996 .66327 m .37429 .65575 L .35453 .66427 L .494 .287 .528 r
F
.37394 .66155 m .37429 .65575 L .36996 .66327 L F
.35593 .65285 m .36597 .66499 L .3792 .65929 L .654 .726 .902 r
F
.36597 .66499 m .37092 .67099 L .3792 .65929 L F
.37385 .66302 m .37394 .66155 L .36996 .66327 L .494 .287 .528 r
F
.32493 .64931 m .34855 .66854 L .34116 .64879 L .654 .726 .902 r
F
.34071 .65606 m .37092 .67099 L .35593 .65285 L F
.37385 .66302 m .36996 .66327 L .35408 .67154 L .494 .287 .528 r
F
.35548 .66951 m .3481 .6758 L .36213 .66664 L .654 .726 .902 r
F
.36996 .66327 m .35417 .67007 L .35408 .67154 L .494 .287 .528 r
F
.36213 .66664 m .3481 .6758 L .37092 .67099 L .654 .726 .902 r
F
.36005 .66562 m .35548 .66951 L .36213 .66664 L F
.35264 .67124 m .35453 .66427 L .34691 .67005 L .342 .164 .489 r
F
.35417 .67007 m .35453 .66427 L .35264 .67124 L F
.34777 .67493 m .3481 .6758 L .36005 .66562 L .654 .726 .902 r
F
.34667 .67402 m .34846 .67 L .3481 .6758 L .668 .433 .556 r
F
.34691 .67005 m .34846 .67 L .34667 .67402 L F
.35408 .67154 m .34691 .67005 L .34669 .67371 L .342 .164 .489 r
F
.32377 .67657 m .32422 .66931 L .34855 .66854 L .668 .433 .556 r
F
.34071 .65606 m .34777 .67493 L .36005 .66562 L .654 .726 .902 r
F
.35408 .67154 m .35417 .67007 L .35264 .67124 L .342 .164 .489 r
F
.34669 .67371 m .34691 .67005 L .33919 .67591 L F
.34356 .67016 m .34691 .67005 L .34667 .67402 L .668 .433 .556 r
F
.39218 .65771 m .39714 .65094 L .37429 .65575 L .593 .369 .546 r
F
.39678 .65674 m .3907 .66247 L .39833 .65669 L .654 .726 .902 r
F
.39218 .65771 m .37429 .65575 L .37394 .66155 L .593 .369 .546 r
F
.38323 .65717 m .38586 .65904 L .39678 .65674 L .654 .726 .902 r
F
.38586 .65904 m .3907 .66247 L .39678 .65674 L F
.35593 .65285 m .3907 .66247 L .36912 .64716 L F
.39669 .6582 m .39218 .65771 L .37385 .66302 L .593 .369 .546 r
F
.39218 .65771 m .37394 .66155 L .37385 .66302 L F
.39669 .6582 m .39678 .65674 L .39218 .65771 L F
.39678 .65674 m .39714 .65094 L .39218 .65771 L F
.39802 .6567 m .39714 .65094 L .39678 .65674 L .668 .433 .556 r
F
.39865 .65135 m .39714 .65094 L .39824 .65816 L F
.38323 .65717 m .39678 .65674 L .40608 .65082 L .654 .726 .902 r
F
.39678 .65674 m .39833 .65669 L .39883 .65631 L F
.39678 .65674 m .39883 .65631 L .40608 .65082 L F
.36912 .64716 m .38323 .65717 L .40608 .65082 L F
.39824 .65816 m .39802 .6567 L .39669 .6582 L .668 .433 .556 r
F
.39802 .6567 m .39678 .65674 L .39669 .6582 L F
.40333 .64736 m .40652 .64355 L .40643 .64502 L .342 .164 .489 r
F
.40333 .64736 m .40643 .64502 L .40608 .65082 L F
.39846 .64944 m .39722 .64948 L .39714 .65094 L .668 .433 .556 r
F
.40377 .6401 m .40696 .63629 L .40687 .63775 L .342 .164 .489 r
F
.40377 .6401 m .40687 .63775 L .40652 .64355 L F
.4195 .6974 m .42027 .67743 L .40405 .67795 L .654 .726 .902 r
F
.47358 .70023 m .48665 .67847 L .46399 .69144 L F
.47358 .70023 m .50103 .69167 L .48665 .67847 L F
0 g
.42194 .76152 m
.42196 .74752 L
s
.46462 .67705 m .46824 .65364 L .45201 .67006 L .654 .726 .902 r
F
.46462 .67705 m .48717 .66414 L .46824 .65364 L F
.127 .923 .03 r
.48042 .66039 m
.48059 .64282 L
s
0 g
.41544 .76163 m
.41547 .7474 L
s
.36996 .79633 m .35267 .81142 L .37464 .8035 L .673 .758 .915 r
F
.36996 .79633 m .34565 .80067 L .35267 .81142 L F
0 g
.35267 .81142 m
.36418 .82054 L
s
.39661 .79557 m .38231 .80958 L .40044 .79862 L .673 .758 .915 r
F
.39661 .79557 m .37464 .8035 L .38231 .80958 L F
.49016 .79234 m .48985 .78668 L .49296 .77494 L 0 0 .325 r
F
0 g
.48527 .79299 m
.48985 .78668 L
s
.46566 .78319 m .48949 .78663 L .49259 .77494 L .673 .758 .914 r
F
0 g
.32931 .68987 m
.33906 .67609 L
s
.32976 .68261 m
.33427 .67624 L
s
.46088 .79624 m .49016 .79234 L .46621 .78889 L .673 .758 .914 r
F
.43959 .78911 m .46088 .79624 L .46621 .78889 L F
.43548 .7923 m .46088 .79624 L .43959 .78911 L F
.57806 .67017 m .57717 .69015 L .59339 .68963 L .654 .726 .902 r
F
.57 .66906 m .57717 .69015 L .57806 .67017 L F
.57 .66906 m .56107 .68794 L .57717 .69015 L F
.39379 .78064 m .37425 .7921 L .39611 .78421 L .673 .758 .914 r
F
.39379 .78064 m .3696 .78497 L .37425 .7921 L F
.55664 .65589 m .5466 .6759 L .56297 .65941 L .654 .726 .902 r
F
.55664 .65589 m .53393 .66887 L .5466 .6759 L F
.56255 .66667 m .56107 .68794 L .57 .66906 L F
.56255 .66667 m .54618 .68316 L .56107 .68794 L F
.58617 .66991 m .59339 .68963 L .60864 .68643 L F
.57806 .67017 m .59339 .68963 L .58617 .66991 L F
.59421 .66104 m .60905 .67917 L .62228 .6735 L F
.58659 .66265 m .60905 .67917 L .59421 .66104 L F
.48812 .65369 m .49731 .66139 L .49688 .66865 L .99 .743 .46 r
F
.48812 .65369 m .48855 .64643 L .49731 .66139 L F
0 g
.49731 .66139 m
.5031 .66671 L
s
.51925 .6428 m .49772 .66126 L .52506 .65273 L .654 .726 .902 r
F
.51925 .6428 m .489 .64638 L .49772 .66126 L F
.46442 .68418 m .46806 .66066 L .45174 .67716 L F
.46442 .68418 m .48708 .67121 L .46806 .66066 L F
.65917 .67714 m .65958 .66988 L .66963 .65591 L .081 0 .401 r
F
0 g
.651 .67634 m
.65958 .66988 L
s
.65908 .66979 m
.65985 .66951 L
s
.49016 .79234 m .49296 .77494 L .49328 .78059 L 0 0 .325 r
F
.49047 .79799 m .49016 .79234 L .49328 .78059 L F
.46621 .78889 m .49016 .79234 L .49328 .78059 L .673 .758 .914 r
F
0 g
.48558 .79865 m
.49016 .79234 L
s
.63273 .65836 m .65918 .66971 L .66918 .65581 L .654 .726 .902 r
F
.127 .923 .03 r
.65857 .65655 m
.65905 .64133 L
s
.62247 .66608 m .65918 .66971 L .63273 .65836 L .654 .726 .902 r
F
.46119 .8019 m .49047 .79799 L .46652 .79454 L .673 .758 .915 r
F
.4399 .79477 m .46119 .8019 L .46652 .79454 L F
.43579 .79796 m .46119 .8019 L .4399 .79477 L F
.39397 .78633 m .37434 .79784 L .39631 .78991 L .673 .758 .914 r
F
.39397 .78633 m .36966 .79067 L .37434 .79784 L F
.30004 .666 m .32467 .66205 L .32422 .66931 L .732 .488 .56 r
F
0 g
.27685 .63803 m
.32345 .69529 L
s
.30004 .666 m .3005 .65874 L .32467 .66205 L .732 .488 .56 r
F
.30934 .63965 m .32468 .66175 L .32539 .64185 L .654 .726 .902 r
F
.30934 .63965 m .30063 .65845 L .32468 .66175 L F
.32448 .65658 m .32377 .67657 L .34656 .67585 L F
.34739 .67522 m .34656 .67585 L .3481 .6758 L F
.32448 .65658 m .34656 .67585 L .34739 .67522 L F
.35408 .67154 m .35108 .67242 L .33874 .68317 L .342 .164 .489 r
F
.35108 .67242 m .33919 .67591 L .33883 .68171 L F
.35108 .67242 m .33883 .68171 L .33874 .68317 L F
.55241 .64418 m .53458 .66148 L .55717 .64856 L .654 .726 .902 r
F
.55241 .64418 m .52506 .65273 L .53458 .66148 L F
.60113 .65086 m .62247 .66608 L .63273 .65836 L F
.59455 .65369 m .62247 .66608 L .60113 .65086 L F
.50146 .6844 m .48751 .66395 L .48708 .67121 L .927 .669 .528 r
F
.50103 .69167 m .50146 .6844 L .48708 .67121 L F
0 g
.50146 .6844 m
.51021 .69934 L
s
.49863 .67791 m
.51083 .6891 L
s
.45201 .67006 m .44598 .6465 L .43718 .6653 L .654 .726 .902 r
F
.45201 .67006 m .46824 .65364 L .44598 .6465 L F
.46566 .78319 m .49259 .77494 L .46772 .7754 L .673 .758 .914 r
F
.44183 .77976 m .46566 .78319 L .46772 .7754 L F
.43918 .78342 m .46566 .78319 L .44183 .77976 L F
.74176 .66749 m .74216 .66023 L .76651 .65946 L .668 .433 .556 r
F
0 g
.6636 .66815 m
.73582 .64195 L
s
.71761 .66418 m .74216 .66023 L .74176 .66749 L .732 .488 .559 r
F
.71761 .66418 m .71801 .65692 L .74216 .66023 L F
.34329 .78337 m .34505 .78935 L .34535 .79501 L .839 .634 .088 r
F
.127 .923 .03 r
.34449 .77708 m
.3447 .7753 L
s
.34359 .7844 m
.34449 .77708 L
s
.34329 .78337 m .34299 .7777 L .34505 .78935 L .839 .634 .088 r
F
0 g
.34505 .78935 m
.34839 .79447 L
s
.36824 .77724 m .34541 .78929 L .3696 .78497 L .673 .758 .914 r
F
.36824 .77724 m .34337 .7777 L .34541 .78929 L F
.127 .923 .03 r
.35329 .71928 m
.35359 .77751 L
s
.32942 .90062 m
.34287 .7903 L
s
.34287 .7903 m
.34354 .78481 L
s
.74317 .64003 m .74217 .65993 L .7664 .65916 L .654 .726 .902 r
F
.72714 .63783 m .74217 .65993 L .74317 .64003 L F
.72714 .63783 m .71814 .65664 L .74217 .65993 L F
.27764 .65882 m .3005 .65874 L .30004 .666 L .793 .543 .559 r
F
.27764 .65882 m .2781 .65156 L .3005 .65874 L F
0 g
.3005 .65874 m
.32429 .662 L
s
.49047 .79799 m .49328 .78059 L .49359 .78626 L 0 0 .325 r
F
.46652 .79454 m .49047 .79799 L .49359 .78626 L .673 .758 .915 r
F
0 g
.48247 .80902 m
.49047 .79799 L
s
.55622 .66315 m .54618 .68316 L .56255 .66667 L .654 .726 .902 r
F
.55622 .66315 m .53351 .67613 L .54618 .68316 L F
.29448 .63488 m .30063 .65845 L .30934 .63965 L F
.29448 .63488 m .27835 .65132 L .30063 .65845 L F
.5938 .66831 m .60864 .68643 L .62187 .68076 L F
.58617 .66991 m .60864 .68643 L .5938 .66831 L F
.39428 .79199 m .37464 .8035 L .39661 .79557 L .673 .758 .915 r
F
.39428 .79199 m .36996 .79633 L .37464 .8035 L F
.48769 .66096 m .49688 .66865 L .49646 .67591 L .99 .743 .46 r
F
0 g
.49929 .68241 m
.50146 .6844 L
s
.48769 .66096 m .48812 .65369 L .49688 .66865 L .99 .743 .46 r
F
.51852 .6501 m .49688 .66865 L .52436 .66007 L .654 .726 .902 r
F
.51852 .6501 m .48812 .65369 L .49688 .66865 L F
0 g
.49688 .66865 m
.49906 .67065 L
s
.37565 .68682 m .35408 .67154 L .33874 .68317 L .654 .726 .902 r
F
0 g
.32886 .69713 m
.33874 .68317 L
s
.38883 .68115 m .35408 .67154 L .37565 .68682 L .654 .726 .902 r
F
.46399 .69144 m .46762 .66793 L .4513 .68442 L F
.46399 .69144 m .48665 .67847 L .46762 .66793 L F
.65917 .67714 m .66963 .65591 L .66922 .66317 L .081 0 .401 r
F
.65877 .68441 m .65917 .67714 L .66922 .66317 L F
.63259 .66574 m .65917 .67714 L .66922 .66317 L .654 .726 .902 r
F
.62228 .6735 m .65917 .67714 L .63259 .66574 L F
0 g
.65059 .6836 m
.65917 .67714 L
s
.6953 .65701 m .71801 .65692 L .71761 .66418 L .793 .542 .558 r
F
.6953 .65701 m .6957 .64974 L .71801 .65692 L F
0 g
.71801 .65692 m
.74216 .66023 L
s
.76612 .66672 m .76651 .65946 L .78942 .65465 L .593 .371 .547 r
F
.74176 .66749 m .76651 .65946 L .76612 .66672 L .668 .433 .556 r
F
0 g
.74216 .66023 m
.76651 .65946 L
s
.71234 .63306 m .71814 .65664 L .72714 .63783 L .654 .726 .902 r
F
.71234 .63306 m .69595 .6495 L .71814 .65664 L F
.29959 .67326 m .32422 .66931 L .32377 .67657 L .732 .488 .56 r
F
.29959 .67326 m .30004 .666 L .32422 .66931 L F
0 g
.33953 .66882 m
.34542 .66864 L
s
.3088 .6471 m .32422 .66931 L .32493 .64931 L .654 .726 .902 r
F
.3088 .6471 m .30004 .666 L .32422 .66931 L F
.75934 .63951 m .7664 .65916 L .7892 .65438 L F
.74317 .64003 m .7664 .65916 L .75934 .63951 L F
.46621 .78889 m .49328 .78059 L .46828 .78106 L .673 .758 .914 r
F
.44226 .78543 m .46621 .78889 L .46828 .78106 L F
.43959 .78911 m .46621 .78889 L .44226 .78543 L F
0 g
.33874 .68317 m
.34647 .67731 L
s
.55185 .65149 m .53393 .66887 L .55664 .65589 L .654 .726 .902 r
F
.55185 .65149 m .52436 .66007 L .53393 .66887 L F
.34359 .78903 m .34535 .79501 L .34565 .80067 L .839 .634 .088 r
F
.34359 .78903 m .34329 .78337 L .34535 .79501 L F
.36829 .7829 m .34535 .79501 L .36966 .79067 L .673 .758 .914 r
F
.36829 .7829 m .34329 .78337 L .34535 .79501 L F
0 g
.34535 .79501 m
.34869 .80013 L
s
0 0 0 r
2.5 Mabswid
.48749 .79574 Mdot
.127 .923 .03 r
.5 Mabswid
.39817 8.82823 m
.44421 4.68779 L
s
.60083 .6582 m .62228 .6735 L .63259 .66574 L .654 .726 .902 r
F
.59421 .66104 m .62228 .6735 L .60083 .6582 L F
.50103 .69167 m .48708 .67121 L .48665 .67847 L .927 .669 .528 r
F
0 g
.50103 .69167 m
.50979 .7066 L
s
.39311 .77678 m .3696 .78497 L .39379 .78064 L .673 .758 .914 r
F
.39311 .77678 m .36824 .77724 L .3696 .78497 L F
.43718 .6653 m .42191 .6432 L .42114 .6631 L .654 .726 .902 r
F
.43718 .6653 m .44598 .6465 L .42191 .6432 L F
.127 .923 .03 r
.65834 .66393 m
.65835 .66358 L
s
.45174 .67716 m .44568 .65348 L .43683 .67237 L .654 .726 .902 r
F
.45174 .67716 m .46806 .66066 L .44568 .65348 L F
.127 .923 .03 r
.48034 .66747 m
.48035 .66739 L
s
.74137 .67476 m .74176 .66749 L .76612 .66672 L .668 .433 .556 r
F
.71722 .67144 m .74176 .66749 L .74137 .67476 L .732 .488 .559 r
F
.71722 .67144 m .71761 .66418 L .74176 .66749 L F
.74277 .64749 m .74176 .66749 L .76612 .66672 L .654 .726 .902 r
F
.72666 .64528 m .74176 .66749 L .74277 .64749 L F
.72666 .64528 m .71761 .66418 L .74176 .66749 L F
.27718 .66609 m .30004 .666 L .29959 .67326 L .793 .543 .559 r
F
.27718 .66609 m .27764 .65882 L .30004 .666 L F
.29386 .64231 m .30004 .666 L .3088 .6471 L .654 .726 .902 r
F
.29386 .64231 m .27764 .65882 L .30004 .666 L F
0 g
.30004 .666 m
.32403 .66928 L
s
.44183 .77976 m .46772 .7754 L .44285 .77586 L .673 .758 .914 r
F
.5181 .65736 m .49646 .67591 L .52393 .66733 L .654 .726 .902 r
F
.5181 .65736 m .48769 .66096 L .49646 .67591 L F
0 g
.49646 .67591 m
.49863 .67791 L
s
.46652 .79454 m .49359 .78626 L .4686 .78672 L .673 .758 .915 r
F
.44257 .79109 m .46652 .79454 L .4686 .78672 L F
.4399 .79477 m .46652 .79454 L .44257 .79109 L F
.65877 .68441 m .66922 .66317 L .66882 .67044 L .081 0 .401 r
F
.63218 .673 m .65877 .68441 L .66882 .67044 L .654 .726 .902 r
F
.62187 .68076 m .65877 .68441 L .63218 .673 L F
0 g
.6433 .69603 m
.65877 .68441 L
s
.36859 .78857 m .34565 .80067 L .36996 .79633 L .673 .758 .915 r
F
.36859 .78857 m .34359 .78903 L .34565 .80067 L F
0 g
.34565 .80067 m
.35267 .81142 L
s
.6949 .66427 m .71761 .66418 L .71722 .67144 L .793 .542 .558 r
F
.6949 .66427 m .6953 .65701 L .71761 .66418 L F
.71177 .64049 m .71761 .66418 L .72666 .64528 L .654 .726 .902 r
F
.71177 .64049 m .6953 .65701 L .71761 .66418 L F
0 g
.71761 .66418 m
.74176 .66749 L
s
.76612 .66672 m .78942 .65465 L .78903 .66191 L .593 .371 .547 r
F
.76573 .67398 m .76612 .66672 L .78903 .66191 L F
.74137 .67476 m .76612 .66672 L .76573 .67398 L .668 .433 .556 r
F
.75902 .64697 m .76612 .66672 L .78903 .66191 L .654 .726 .902 r
F
.74277 .64749 m .76612 .66672 L .75902 .64697 L F
0 g
.74176 .66749 m
.76612 .66672 L
s
.25855 .64827 m .2781 .65156 L .27764 .65882 L .856 .601 .552 r
F
.25855 .64827 m .25901 .64101 L .2781 .65156 L F
0 g
.2781 .65156 m
.28318 .65319 L
s
.39329 .78244 m .36966 .79067 L .39397 .78633 L .673 .758 .914 r
F
.39329 .78244 m .36829 .7829 L .36966 .79067 L F
.30834 .65436 m .32377 .67657 L .32448 .65658 L .654 .726 .902 r
F
.30834 .65436 m .29959 .67326 L .32377 .67657 L F
0 g
.32377 .67657 m
.34656 .67585 L
s
.28181 .62788 m .27835 .65132 L .29448 .63488 L .654 .726 .902 r
F
.28181 .62788 m .25935 .64081 L .27835 .65132 L F
.55143 .65875 m .53351 .67613 L .55622 .66315 L F
.55143 .65875 m .52393 .66733 L .53351 .67613 L F
.60042 .66547 m .62187 .68076 L .63218 .673 L F
.5938 .66831 m .62187 .68076 L .60042 .66547 L F
.54951 .63921 m .52506 .65273 L .55241 .64418 L F
.54951 .63921 m .51925 .6428 L .52506 .65273 L F
.58103 .63905 m .57889 .65554 L .57966 .65552 L F
.58186 .64132 m .57966 .65552 L .58697 .65529 L F
.58103 .63905 m .57966 .65552 L .58186 .64132 L F
.57832 .65272 m .57826 .64988 L .58313 .64948 L .666 .426 .548 r
F
.57991 .65509 m .57847 .6629 L .57962 .66287 L .654 .726 .902 r
F
.57832 .65272 m .58313 .64948 L .5832 .65233 L .666 .426 .548 r
F
.57839 .65556 m .57832 .65272 L .5832 .65233 L F
.57851 .64858 m .57832 .65272 L .5832 .65233 L .675 .735 .895 r
F
.58067 .63957 m .57889 .65554 L .58103 .63905 L .654 .726 .902 r
F
.57844 .6457 m .58311 .64942 L .58167 .64544 L .675 .735 .895 r
F
.57869 .64444 m .58176 .64832 L .58031 .64431 L F
.58028 .6454 m .57928 .65511 L .57991 .65509 L .654 .726 .902 r
F
.57928 .65511 m .57847 .6629 L .57991 .65509 L F
.57851 .64858 m .5832 .65233 L .58176 .64832 L .675 .735 .895 r
F
.58029 .64543 m .57962 .66287 L .58172 .64933 L .654 .726 .902 r
F
.58075 .63846 m .57889 .65554 L .5808 .63842 L F
.58039 .63835 m .57889 .65554 L .58076 .63832 L F
.57965 .63842 m .57964 .63863 L .58039 .63835 L F
.57964 .63863 m .57889 .65554 L .58039 .63835 L F
.57862 .64158 m .58167 .64544 L .58024 .64145 L .675 .735 .895 r
F
.58067 .64248 m .58031 .64431 L .58184 .6439 L F
.58069 .63974 m .58024 .64145 L .58176 .64104 L F
.57625 .62481 m .57723 .62528 L .57725 .63819 L .844 .571 .525 r
F
.57522 .62353 m .57559 .62422 L .57562 .63712 L .988 .72 .386 r
F
.57941 .64395 m .57598 .64816 L .57889 .65554 L .654 .726 .902 r
F
.57598 .64816 m .57088 .65444 L .57643 .6552 L F
.57598 .64816 m .57643 .6552 L .57889 .65554 L F
.57517 .62272 m .57522 .62353 L .57524 .63645 L .779 .622 .059 r
F
.5785 .64232 m .57588 .64649 L .57941 .64395 L .654 .726 .902 r
F
.57588 .64649 m .57088 .65444 L .57598 .64816 L F
.57588 .64649 m .57598 .64816 L .57941 .64395 L F
.5791 .64024 m .57821 .64178 L .57955 .64064 L F
.57821 .64178 m .57088 .65444 L .5785 .64232 L F
.57821 .64178 m .5785 .64232 L .57955 .64064 L F
.57933 .63922 m .57888 .64003 L .57961 .63936 L F
.57888 .64003 m .57088 .65444 L .5791 .64024 L F
.57888 .64003 m .5791 .64024 L .57961 .63936 L F
.57954 .63863 m .57924 .63917 L .57964 .63865 L F
.57924 .63917 m .57088 .65444 L .57933 .63922 L F
.57924 .63917 m .57933 .63922 L .57964 .63865 L F
.5784 .63853 m .57088 .65444 L .57954 .63863 L F
.57881 .63849 m .57954 .63863 L .57965 .63842 L F
.5784 .63853 m .57954 .63863 L .57881 .63849 L F
.57978 .63563 m .56942 .64606 L .57088 .65444 L F
.56942 .64606 m .56347 .65206 L .56569 .65278 L F
.56942 .64606 m .56569 .65278 L .57088 .65444 L F
.57522 .62353 m .57532 .6366 L .57524 .63645 L .988 .72 .386 r
F
.57517 .62272 m .5752 .63585 L .57519 .63568 L .779 .622 .059 r
F
.57517 .62272 m .57524 .63645 L .5752 .63585 L F
.5757 .62169 m .57517 .62272 L .57519 .63568 L 0 0 .381 r
F
.56942 .64606 m .55717 .64856 L .56347 .65206 L .654 .726 .902 r
F
.57978 .63563 m .5731 .63945 L .56942 .64606 L F
.5731 .63945 m .55717 .64856 L .56942 .64606 L F
.57568 .65477 m .57042 .6618 L .57881 .6552 L F
.57355 .65511 m .57455 .65461 L .57839 .65556 L .731 .478 .546 r
F
.57455 .65461 m .57832 .65272 L .57838 .65514 L F
.57455 .65461 m .57838 .65514 L .57839 .65556 L F
.57881 .6552 m .57042 .6618 L .57847 .6629 L .654 .726 .902 r
F
.57903 .65029 m .57568 .65477 L .57881 .6552 L F
.57869 .63999 m .57702 .64143 L .57862 .64158 L .675 .735 .895 r
F
.5776 .63826 m .57881 .63849 L .57882 .64 L .751 .492 .54 r
F
.5776 .63826 m .57882 .64 L .57787 .63986 L F
.5788 .63745 m .57773 .63984 L .57869 .63999 L .675 .735 .895 r
F
.57773 .63984 m .57702 .64143 L .57869 .63999 L F
.57702 .64143 m .57844 .6457 L .57862 .64158 L F
.57876 .6428 m .57707 .64429 L .57869 .64444 L F
.57787 .63986 m .57882 .64281 L .57835 .64274 L .751 .492 .54 r
F
.57887 .64029 m .5778 .64266 L .57876 .6428 L .675 .735 .895 r
F
.5778 .64266 m .57707 .64429 L .57876 .6428 L F
.57787 .63986 m .57882 .64 L .57882 .64281 L .751 .492 .54 r
F
.57955 .64064 m .5785 .64232 L .57941 .64395 L .654 .726 .902 r
F
.57862 .64158 m .57844 .6457 L .58167 .64544 L .675 .735 .895 r
F
.57835 .64274 m .57857 .64278 L .57853 .64376 L .751 .492 .54 r
F
.57857 .64278 m .57882 .64281 L .57853 .64376 L F
.57973 .64269 m .57869 .64444 L .58031 .64431 L .675 .735 .895 r
F
.57968 .63989 m .57862 .64158 L .58024 .64145 L F
.57881 .63849 m .57897 .64279 L .57882 .64281 L .642 .403 .541 r
F
.57876 .64282 m .57869 .64444 L .57973 .64269 L .675 .735 .895 r
F
.57961 .63936 m .5791 .64024 L .57955 .64064 L .654 .726 .902 r
F
.57869 .64002 m .57862 .64158 L .57968 .63989 L .675 .735 .895 r
F
.57844 .6457 m .57826 .64982 L .58311 .64942 L F
.57869 .64444 m .57851 .64858 L .58176 .64832 L F
.57925 .64549 m .57847 .6629 L .58028 .6454 L .654 .726 .902 r
F
.57916 .63846 m .57937 .64548 L .57881 .63849 L .642 .403 .541 r
F
.57839 .65556 m .57906 .65511 L .58327 .65517 L .666 .426 .548 r
F
.58083 .65506 m .57962 .66287 L .58378 .65496 L .654 .726 .902 r
F
.57985 .65264 m .57806 .67017 L .5796 .67012 L F
.58158 .65735 m .5796 .67012 L .58617 .66991 L F
.57906 .65511 m .5832 .65233 L .58326 .65498 L .666 .426 .548 r
F
.57906 .65511 m .58326 .65498 L .58327 .65517 L F
.57857 .65142 m .57839 .65556 L .58327 .65517 L .675 .735 .895 r
F
.57985 .65264 m .5796 .67012 L .58158 .65735 L .654 .726 .902 r
F
.58378 .65496 m .57962 .66287 L .58659 .66265 L F
.58182 .65579 m .58617 .66991 L .5821 .65401 L F
.58037 .62534 m .58139 .6249 L .58141 .63797 L .519 .305 .529 r
F
.58158 .65735 m .58182 .65579 L .58077 .65239 L .654 .726 .902 r
F
.5821 .62434 m .58253 .62366 L .58255 .63683 L .082 0 .419 r
F
.58212 .63964 m .58697 .65529 L .59077 .65449 L .654 .726 .902 r
F
.58143 .63846 m .58202 .64026 L .58212 .63964 L F
.58202 .64026 m .58697 .65529 L .58212 .63964 L F
.58253 .62366 m .58265 .62285 L .58267 .63606 L 0 0 .148 r
F
.5821 .62434 m .58255 .63683 L .58222 .63732 L .082 0 .419 r
F
.58137 .63855 m .58697 .65529 L .58143 .63846 L .654 .726 .902 r
F
.58121 .63812 m .58697 .65529 L .58122 .63811 L F
.58148 .6393 m .58176 .64104 L .58308 .64039 L .675 .735 .895 r
F
.57879 .62554 m .58037 .62534 L .5804 .63979 L .642 .403 .541 r
F
.5808 .63842 m .58067 .63957 L .58103 .63905 L .654 .726 .902 r
F
.5788 .63745 m .58078 .63985 L .58148 .6393 L .675 .735 .895 r
F
.58122 .63811 m .58137 .63855 L .58143 .63846 L .654 .726 .902 r
F
.58119 .63806 m .58121 .63812 L .58122 .63811 L F
.58073 .63823 m .58697 .65529 L .58119 .63806 L F
.58076 .63832 m .58075 .63846 L .5808 .63842 L F
.58062 .63827 m .58141 .63797 L .58142 .63934 L .519 .305 .529 r
F
.58078 .63985 m .58176 .64104 L .58148 .63932 L .675 .735 .895 r
F
.58078 .63985 m .58148 .63932 L .58142 .63934 L F
.58024 .64145 m .58471 .64463 L .58176 .64104 L F
.58354 .65492 m .5832 .65233 L .58778 .65111 L .593 .369 .545 r
F
.58327 .65517 m .58326 .65498 L .58354 .65492 L F
.58326 .65498 m .5832 .65233 L .58354 .65492 L F
.58657 .65428 m .58659 .66265 L .59088 .66174 L .654 .726 .902 r
F
.5832 .65233 m .58771 .64827 L .58778 .65111 L .593 .369 .545 r
F
.5832 .65233 m .58313 .64948 L .58771 .64827 L F
.58176 .64832 m .5832 .65233 L .58778 .65111 L .675 .735 .895 r
F
.58667 .65426 m .58778 .65111 L .58785 .65395 L .593 .369 .545 r
F
.58439 .65474 m .58659 .66265 L .58657 .65428 L .654 .726 .902 r
F
.58327 .65517 m .58354 .65492 L .58667 .65426 L .593 .369 .545 r
F
.58354 .65492 m .58778 .65111 L .58667 .65426 L F
.58417 .65053 m .58785 .65395 L .58488 .65035 L .675 .735 .895 r
F
.58255 .64811 m .58439 .65474 L .58583 .653 L .654 .726 .902 r
F
.58071 .64657 m .58659 .66265 L .58202 .64732 L F
.58167 .64544 m .58311 .64942 L .58767 .64821 L .675 .735 .895 r
F
.58031 .64431 m .58176 .64832 L .58481 .64751 L F
.57978 .63563 m .59455 .65369 L .60113 .65086 L .654 .726 .902 r
F
.58253 .63814 m .5841 .63955 L .58477 .63855 L .675 .735 .895 r
F
.58157 .63786 m .58212 .63746 L .58212 .63878 L .361 .183 .5 r
F
.57978 .63563 m .59077 .65449 L .58562 .64278 L .654 .726 .902 r
F
.58157 .63786 m .58212 .63878 L .58168 .63913 L .361 .183 .5 r
F
.5788 .63745 m .58213 .63877 L .58253 .63814 L .675 .735 .895 r
F
.58213 .63877 m .5841 .63955 L .58253 .63814 L F
.57978 .63563 m .60113 .65086 L .60185 .65033 L .654 .726 .902 r
F
.57978 .63563 m .60185 .65033 L .58689 .63868 L F
.58024 .64145 m .58167 .64544 L .58471 .64463 L .675 .735 .895 r
F
.58036 .64434 m .58481 .64751 L .58039 .64429 L F
.58171 .64505 m .58191 .64674 L .58323 .64609 L F
.58039 .64429 m .58481 .64751 L .58184 .6439 L F
.58153 .64492 m .58159 .64523 L .58171 .64505 L F
.58159 .64523 m .58191 .64674 L .58171 .64505 L F
.58258 .63665 m .58258 .63791 L .58255 .63683 L 0 0 .148 r
F
.58169 .63944 m .58308 .64039 L .58213 .63877 L .675 .735 .895 r
F
.58244 .63889 m .58308 .64039 L .5841 .63955 L F
.58308 .64039 m .5894 .64164 L .5841 .63955 L F
.58275 .63963 m .58513 .64033 L .58496 .63926 L F
.58259 .64068 m .58258 .64076 L .58256 .63806 L 0 0 .148 r
F
.58213 .63877 m .58239 .63921 L .58244 .63889 L .675 .735 .895 r
F
.58222 .63732 m .58256 .64092 L .58225 .64139 L .082 0 .419 r
F
.58212 .63746 m .58217 .64153 L .58213 .64159 L F
.58078 .64524 m .58191 .64674 L .58153 .64492 L .675 .735 .895 r
F
.5804 .64259 m .58076 .64525 L .58041 .64539 L .519 .305 .529 r
F
.58045 .64498 m .58191 .64674 L .57946 .6435 L .675 .735 .895 r
F
.58112 .64597 m .58202 .64732 L .58147 .64546 L .654 .726 .902 r
F
.58144 .65204 m .5822 .68288 L .58149 .68344 L .361 .183 .5 r
F
.58735 .64807 m .58767 .64821 L .58713 .64757 L .675 .735 .895 r
F
.58735 .64807 m .58713 .64757 L .58471 .64463 L F
.58562 .64278 m .59077 .65449 L .59455 .65369 L .654 .726 .902 r
F
.58778 .65111 m .58771 .64827 L .59169 .64632 L .499 .296 .536 r
F
.58778 .65111 m .59169 .64632 L .59175 .64916 L F
.59182 .652 m .59175 .64916 L .59485 .6466 L .361 .191 .511 r
F
.58471 .64463 m .58767 .64821 L .59162 .64627 L .675 .735 .895 r
F
.58481 .64751 m .59175 .64916 L .58746 .6462 L F
.59182 .652 m .59485 .6466 L .59492 .64944 L .361 .191 .511 r
F
.58481 .64751 m .58778 .65111 L .59175 .64916 L .675 .735 .895 r
F
.58785 .65395 m .59175 .64916 L .59182 .652 L .499 .296 .536 r
F
.58753 .64904 m .59182 .652 L .59492 .64944 L .675 .735 .895 r
F
.58167 .64544 m .58735 .64807 L .58471 .64463 L F
.58184 .6439 m .58481 .64751 L .58746 .6462 L F
.58753 .64904 m .59492 .64944 L .58959 .64734 L F
.58323 .64609 m .58753 .64904 L .58959 .64734 L F
.58323 .64609 m .58959 .64734 L .58426 .64524 L F
.58249 .64423 m .60083 .6582 L .60598 .65432 L .654 .726 .902 r
F
.58062 .63827 m .58143 .64501 L .58076 .64526 L .519 .305 .529 r
F
.58061 .6425 m .58076 .64525 L .5804 .64259 L F
.58184 .6439 m .58746 .6462 L .58316 .64325 L .675 .735 .895 r
F
.58364 .644 m .58426 .64524 L .58493 .64424 L F
.57893 .64314 m .58323 .64609 L .58426 .64524 L F
.58167 .64477 m .58213 .64449 L .58167 .64483 L .361 .183 .5 r
F
.5817 .64225 m .58184 .6439 L .58316 .64325 L .675 .735 .895 r
F
.58157 .64245 m .58184 .6439 L .5817 .64225 L F
.58157 .63786 m .58212 .6444 L .58167 .64477 L .361 .183 .5 r
F
.58212 .6444 m .58213 .64449 L .58167 .64477 L F
.58281 .64385 m .58245 .64452 L .58364 .644 L .675 .735 .895 r
F
.58142 .64215 m .58184 .6439 L .58151 .64211 L F
.58067 .64248 m .58081 .64265 L .58142 .64215 L F
.58081 .64265 m .58184 .6439 L .58142 .64215 L F
.58142 .64215 m .58154 .64493 L .58143 .64501 L .361 .183 .5 r
F
.58141 .63797 m .58149 .6421 L .58142 .64215 L F
.58149 .6421 m .58154 .64493 L .58142 .64215 L F
.5811 .64229 m .58142 .64215 L .58143 .64501 L .519 .305 .529 r
F
.57893 .64314 m .58213 .6444 L .58281 .64385 L .675 .735 .895 r
F
.58213 .6444 m .58245 .64452 L .58281 .64385 L F
.58245 .64452 m .58426 .64524 L .58364 .644 L F
.57936 .64289 m .58187 .64468 L .58249 .64423 L .654 .726 .902 r
F
.58228 .64417 m .58228 .64428 L .5822 .6443 L .082 0 .419 r
F
.58176 .64832 m .58778 .65111 L .58481 .64751 L .675 .735 .895 r
F
.58785 .65395 m .58778 .65111 L .59175 .64916 L .499 .296 .536 r
F
.58488 .65035 m .58785 .65395 L .59182 .652 L .675 .735 .895 r
F
.58191 .64674 m .58488 .65035 L .58753 .64904 L F
.58269 .64696 m .59421 .66104 L .58269 .64546 L .654 .726 .902 r
F
.58269 .64696 m .58269 .64546 L .58238 .64505 L F
.58218 .64634 m .58269 .64696 L .58238 .64505 L F
.58261 .6436 m .58268 .6431 L .5827 .65013 L 0 0 .148 r
F
.58583 .653 m .58544 .65347 L .58649 .65415 L .654 .726 .902 r
F
.58544 .65347 m .58439 .65474 L .58649 .65415 L F
.58649 .65415 m .58439 .65474 L .58657 .65428 L F
.58203 .64734 m .58659 .66265 L .58255 .64811 L F
.58167 .6468 m .58488 .65035 L .58191 .64674 L .675 .735 .895 r
F
.58203 .64733 m .58255 .64811 L .58214 .64663 L .654 .726 .902 r
F
.58203 .64734 m .58255 .64811 L .58203 .64733 L F
.58202 .64732 m .58203 .64734 L .58203 .64733 L F
.58038 .64715 m .58329 .64922 L .58167 .6468 L .675 .735 .895 r
F
.58329 .64922 m .58488 .65035 L .58167 .6468 L F
.58182 .65116 m .58327 .65517 L .58667 .65426 L F
.58172 .64933 m .58083 .65506 L .58378 .65496 L .654 .726 .902 r
F
.5812 .65291 m .58708 .66009 L .58172 .65214 L F
.58708 .66009 m .5938 .66831 L .58624 .65818 L F
.58708 .66009 m .58624 .65818 L .58172 .65214 L F
.58329 .64922 m .58417 .65053 L .58488 .65035 L .675 .735 .895 r
F
.58584 .65302 m .58785 .65395 L .58417 .65053 L F
.58147 .64546 m .58583 .653 L .58635 .65143 L .654 .726 .902 r
F
.58191 .64674 m .58753 .64904 L .58323 .64609 L .675 .735 .895 r
F
.58228 .64428 m .58235 .65124 L .5822 .6444 L .082 0 .419 r
F
.58196 .64475 m .60083 .6582 L .58213 .64449 L .654 .726 .902 r
F
.58213 .64449 m .60083 .6582 L .58249 .64423 L F
.5821 .65401 m .58617 .66991 L .59095 .6689 L F
.58708 .66009 m .59095 .6689 L .5938 .66831 L F
.5821 .65401 m .59095 .6689 L .58708 .66009 L F
.58258 .64374 m .58261 .65066 L .58256 .64386 L 0 0 .148 r
F
.58256 .64386 m .5826 .65076 L .58258 .6509 L F
.58253 .64275 m .58249 .64966 L .58268 .6431 L .984 .727 .338 r
F
.58583 .653 m .58657 .65428 L .58655 .65409 L .654 .726 .902 r
F
.58584 .65302 m .58667 .65426 L .58785 .65395 L .675 .735 .895 r
F
.58182 .65116 m .58667 .65426 L .58584 .65302 L F
.58657 .65428 m .59088 .66174 L .58752 .65408 L .654 .726 .902 r
F
.58635 .65143 m .59088 .66174 L .59421 .66104 L F
.58172 .65214 m .60042 .66547 L .58214 .65153 L F
.58488 .65035 m .59182 .652 L .58753 .64904 L .675 .735 .895 r
F
.58407 .64625 m .59421 .66104 L .60083 .6582 L .654 .726 .902 r
F
.58548 .65163 m .60557 .66158 L .60891 .65692 L F
.58182 .65116 m .58584 .65302 L .58417 .65053 L .675 .735 .895 r
F
.58583 .653 m .58655 .65409 L .58635 .65143 L .654 .726 .902 r
F
.58657 .65428 m .58752 .65408 L .58635 .65143 L F
.58214 .65153 m .58263 .6822 L .5822 .68288 L .082 0 .419 r
F
.58038 .64715 m .58182 .65116 L .58417 .65053 L .675 .735 .895 r
F
.58213 .64449 m .58222 .65141 L .58214 .65153 L .082 0 .419 r
F
.58222 .65141 m .58263 .6822 L .58214 .65153 L F
.58253 .65097 m .58928 .65459 L .58548 .65163 L .654 .726 .902 r
F
.58071 .64657 m .58202 .64732 L .58112 .64597 L F
.58117 .6451 m .58122 .64516 L .58143 .64501 L F
.58076 .64526 m .58143 .64501 L .58144 .65204 L .519 .305 .529 r
F
.58081 .6525 m .58182 .65579 L .58084 .65248 L .654 .726 .902 r
F
.57857 .65142 m .58327 .65517 L .58182 .65116 L .675 .735 .895 r
F
.58089 .65225 m .58144 .65204 L .58149 .68344 L .519 .305 .529 r
F
.57875 .64728 m .58182 .65116 L .58038 .64715 L .675 .735 .895 r
F
.58076 .64526 m .58144 .65204 L .58089 .65225 L .519 .305 .529 r
F
.58028 .64544 m .57962 .66287 L .58029 .64543 L .654 .726 .902 r
F
.57875 .64728 m .57857 .65142 L .58182 .65116 L .675 .735 .895 r
F
.57895 .65016 m .58154 .65201 L .58214 .65153 L .654 .726 .902 r
F
.58154 .65201 m .58172 .65214 L .58191 .65187 L F
.58154 .65201 m .58191 .65187 L .58214 .65153 L F
.57895 .65016 m .58214 .65153 L .58253 .65097 L F
.58214 .65153 m .58928 .65459 L .58253 .65097 L F
.58928 .65459 m .60557 .66158 L .58548 .65163 L F
.58084 .65248 m .58182 .65579 L .5821 .65401 L F
.58166 .65188 m .5822 .68288 L .58144 .65204 L .361 .183 .5 r
F
.58172 .65214 m .58227 .65287 L .58232 .65256 L .654 .726 .902 r
F
.58187 .64468 m .58196 .64475 L .58213 .64449 L F
.58147 .64546 m .58202 .64732 L .58214 .64663 L F
.58202 .64732 m .58203 .64733 L .58214 .64663 L F
.58143 .64501 m .58218 .64634 L .58202 .64479 L F
.58158 .65735 m .58617 .66991 L .58182 .65579 L F
.58167 .64483 m .58213 .64449 L .58214 .65153 L .361 .183 .5 r
F
.58177 .6518 m .58214 .65153 L .5822 .68288 L F
.58167 .64483 m .58214 .65153 L .58177 .6518 L F
.58524 .64892 m .59421 .66104 L .58407 .64625 L .654 .726 .902 r
F
.59175 .64916 m .59169 .64632 L .59478 .64376 L .361 .191 .511 r
F
.59175 .64916 m .59478 .64376 L .59485 .6466 L F
.59492 .64944 m .59485 .6466 L .59686 .64361 L .124 .015 .447 r
F
.58471 .64463 m .59162 .64627 L .58735 .64333 L .675 .735 .895 r
F
.58746 .6462 m .59485 .6466 L .58952 .6445 L F
.58316 .64325 m .58746 .6462 L .58952 .6445 L F
.58746 .6462 m .59175 .64916 L .59485 .6466 L F
.58959 .64734 m .59492 .64944 L .59693 .64645 L F
.59492 .64944 m .59686 .64361 L .59693 .64645 L .124 .015 .447 r
F
.58959 .64734 m .59693 .64645 L .59093 .64535 L .675 .735 .895 r
F
.58426 .64524 m .59093 .64535 L .58493 .64424 L F
.58487 .64414 m .60598 .65432 L .60933 .64966 L .654 .726 .902 r
F
.57979 .64286 m .58031 .64431 L .58067 .64248 L .675 .735 .895 r
F
.58151 .64211 m .58157 .64245 L .5817 .64225 L F
.58157 .63786 m .58167 .64483 L .58141 .63797 L .361 .183 .5 r
F
.58122 .64516 m .58218 .64634 L .58143 .64501 L .654 .726 .902 r
F
.58426 .64524 m .58959 .64734 L .59093 .64535 L .675 .735 .895 r
F
.58809 .64664 m .60598 .65432 L .58487 .64414 L .654 .726 .902 r
F
.58214 .64663 m .58255 .64811 L .58583 .653 L F
.58261 .6436 m .5827 .65013 L .58263 .65054 L 0 0 .148 r
F
.58235 .65124 m .58228 .65133 L .5822 .6444 L .082 0 .419 r
F
.58168 .63913 m .58212 .63878 L .58213 .64159 L .361 .183 .5 r
F
.5819 .64177 m .58213 .64159 L .58213 .64449 L F
.58168 .63913 m .58213 .64159 L .5819 .64177 L F
.58176 .64104 m .58471 .64463 L .58735 .64333 L .675 .735 .895 r
F
.58213 .64158 m .58316 .64325 L .5842 .6424 L F
.58078 .63962 m .58142 .64215 L .5811 .64229 L .519 .305 .529 r
F
.57959 .6399 m .5804 .64259 L .57921 .63995 L .642 .403 .541 r
F
.58039 .63835 m .58061 .6425 L .5804 .64259 L .519 .305 .529 r
F
.57887 .64029 m .58149 .6421 L .58213 .64158 L .675 .735 .895 r
F
.58223 .63861 m .58225 .64139 L .58215 .63874 L .082 0 .419 r
F
.5817 .64225 m .58316 .64325 L .58213 .64159 L .675 .735 .895 r
F
.58225 .64139 m .58228 .64417 L .58222 .64145 L .082 0 .419 r
F
.58225 .64139 m .58222 .64145 L .58215 .63874 L F
.58213 .64159 m .58316 .64325 L .58213 .64158 L .675 .735 .895 r
F
.58149 .6421 m .5817 .64225 L .58213 .64159 L F
.58139 .6249 m .5821 .62434 L .58212 .63746 L .361 .183 .5 r
F
.5821 .62434 m .58222 .63732 L .58212 .63746 L .082 0 .419 r
F
.58427 .63664 m .60626 .647 L .60959 .64236 L .654 .726 .902 r
F
.57978 .63563 m .58689 .63868 L .58427 .63664 L F
.58689 .63868 m .60626 .647 L .58427 .63664 L F
.58221 .62181 m .58116 .62099 L .58118 .63424 L .909 .63 .501 r
F
.58167 .64483 m .58177 .6518 L .58154 .64493 L .361 .183 .5 r
F
.58177 .6518 m .58166 .65188 L .58154 .64493 L F
.58142 .63934 m .58148 .63932 L .58148 .6393 L .675 .735 .895 r
F
.58167 .64483 m .58154 .64493 L .58141 .63797 L .361 .183 .5 r
F
.57937 .64548 m .57907 .64551 L .57881 .63849 L .642 .403 .541 r
F
.57893 .64314 m .58493 .64424 L .58499 .64399 L .675 .735 .895 r
F
.58316 .64325 m .58952 .6445 L .5842 .6424 L F
.5839 .64316 m .58499 .64399 L .58519 .64317 L F
.58258 .64365 m .58499 .64399 L .58265 .64316 L F
.58261 .64345 m .58268 .6431 L .58261 .6436 L 0 0 .148 r
F
.58176 .64104 m .58735 .64333 L .58308 .64039 L .675 .735 .895 r
F
.58255 .64097 m .5842 .6424 L .58486 .6414 L F
.58078 .63962 m .58142 .63934 L .58142 .64215 L .519 .305 .529 r
F
.57968 .63989 m .58024 .64145 L .58069 .63974 L .675 .735 .895 r
F
.58014 .63982 m .5804 .63979 L .5804 .64259 L .642 .403 .541 r
F
.58062 .63827 m .58076 .64526 L .58039 .63835 L .519 .305 .529 r
F
.57887 .64029 m .58244 .64171 L .58255 .64097 L .675 .735 .895 r
F
.58244 .64171 m .5842 .6424 L .58255 .64097 L F
.58259 .64068 m .58268 .64295 L .58261 .64345 L 0 0 .148 r
F
.58258 .63791 m .58263 .64043 L .58259 .64068 L F
.58263 .64043 m .58268 .64295 L .58259 .64068 L F
.58268 .64295 m .58268 .6431 L .58261 .64345 L F
.58265 .64316 m .58499 .64399 L .5839 .64316 L .675 .735 .895 r
F
.58213 .64159 m .58216 .64445 L .58213 .64449 L .082 0 .419 r
F
.57893 .64314 m .58258 .64365 L .58265 .64316 L .675 .735 .895 r
F
.58139 .6249 m .58157 .63786 L .58141 .63797 L .361 .183 .5 r
F
.58194 .63439 m .60717 .62707 L .60241 .62268 L .654 .726 .902 r
F
.57978 .63563 m .58216 .63489 L .58194 .63439 L F
.58216 .63489 m .60717 .62707 L .58194 .63439 L F
.58257 .63583 m .58223 .63629 L .58256 .63706 L .984 .727 .338 r
F
.58253 .62366 m .58258 .63665 L .58255 .63683 L 0 0 .148 r
F
.58265 .62285 m .58227 .63514 L .58257 .63583 L .984 .727 .338 r
F
.58253 .62366 m .58267 .63606 L .58258 .63665 L 0 0 .148 r
F
.58139 .6249 m .58212 .63746 L .58157 .63786 L .361 .183 .5 r
F
.58369 .63517 m .61088 .63726 L .61006 .63204 L .654 .726 .902 r
F
.57978 .63563 m .5858 .63595 L .58369 .63517 L F
.5858 .63595 m .61088 .63726 L .58369 .63517 L F
.57895 .65016 m .58226 .64913 L .58162 .64863 L F
.57895 .65016 m .58282 .65103 L .58368 .65041 L F
.58077 .65239 m .58081 .6525 L .58084 .65248 L F
.58042 .65242 m .58149 .68344 L .58047 .68387 L .519 .305 .529 r
F
.58061 .65235 m .58149 .68344 L .58042 .65242 L F
.58076 .64526 m .58089 .65225 L .58041 .64539 L F
.57979 .65248 m .58158 .65735 L .58077 .65239 L .654 .726 .902 r
F
.58089 .65225 m .58149 .68344 L .58061 .65235 L .519 .305 .529 r
F
.58089 .65225 m .58061 .65235 L .58041 .64539 L F
.58154 .65201 m .5812 .65291 L .58172 .65214 L .654 .726 .902 r
F
.58031 .64431 m .58036 .64434 L .58039 .64429 L .675 .735 .895 r
F
.57973 .64269 m .57979 .64286 L .5804 .64259 L F
.58028 .6454 m .58028 .64544 L .58029 .64543 L .654 .726 .902 r
F
.57929 .64275 m .5804 .64259 L .58041 .6454 L .642 .403 .541 r
F
.57978 .64549 m .58038 .64715 L .58076 .64535 L .675 .735 .895 r
F
.57961 .64551 m .58041 .6454 L .58042 .65242 L .642 .403 .541 r
F
.57929 .64275 m .58041 .6454 L .57961 .64551 L F
.58076 .64535 m .58038 .64715 L .58191 .64674 L .675 .735 .895 r
F
.58076 .64525 m .58066 .64529 L .58041 .64539 L .519 .305 .529 r
F
.57973 .6439 m .57925 .64549 L .58028 .6454 L .654 .726 .902 r
F
.57936 .64289 m .57934 .64332 L .57973 .6439 L F
.57929 .64275 m .58042 .65242 L .57957 .6525 L .642 .403 .541 r
F
.57934 .64332 m .57925 .64549 L .57973 .6439 L .654 .726 .902 r
F
.57893 .64314 m .57978 .64549 L .58071 .64536 L .675 .735 .895 r
F
.58045 .64498 m .58071 .64536 L .58076 .64535 L F
.58076 .64525 m .58076 .64526 L .58066 .64529 L .519 .305 .529 r
F
.57946 .6435 m .58078 .64524 L .58153 .64492 L .675 .735 .895 r
F
.57936 .64289 m .58071 .64657 L .58147 .64546 L .654 .726 .902 r
F
.57893 .64314 m .58071 .64536 L .58045 .64498 L .675 .735 .895 r
F
.57895 .65016 m .58071 .65232 L .58154 .65201 L .654 .726 .902 r
F
.58071 .65232 m .5812 .65291 L .58154 .65201 L F
.5858 .63595 m .60959 .64236 L .61088 .63726 L F
.57978 .63563 m .59308 .63863 L .5858 .63595 L F
.59308 .63863 m .60959 .64236 L .5858 .63595 L F
.58116 .62099 m .58009 .62062 L .58011 .63384 L .809 .541 .533 r
F
.58037 .62534 m .58062 .63827 L .58039 .63835 L .519 .305 .529 r
F
.5788 .63745 m .58149 .63574 L .58118 .6355 L .675 .735 .895 r
F
.5788 .63745 m .58169 .63944 L .58213 .63877 L F
.58062 .63827 m .58142 .63934 L .58078 .63962 L .519 .305 .529 r
F
.57936 .64289 m .58117 .6451 L .58202 .64479 L .654 .726 .902 r
F
.58037 .62534 m .58141 .63797 L .58062 .63827 L .519 .305 .529 r
F
.58227 .63514 m .58223 .63505 L .58223 .63629 L .984 .727 .338 r
F
.58265 .62285 m .58257 .63583 L .58267 .63606 L F
.58378 .63438 m .61006 .63204 L .60717 .62707 L .654 .726 .902 r
F
.57978 .63563 m .58671 .63481 L .58378 .63438 L F
.58671 .63481 m .61006 .63204 L .58378 .63438 L F
.58735 .64333 m .59162 .64627 L .5947 .64373 L .675 .735 .895 r
F
.58735 .64333 m .5947 .64373 L .5894 .64164 L F
.5842 .6424 m .58952 .6445 L .59086 .64251 L F
.58493 .64424 m .59093 .64535 L .59145 .64321 L F
.58493 .64424 m .59145 .64321 L .58519 .64317 L F
.58309 .64309 m .59536 .6465 L .58661 .64327 L .654 .726 .902 r
F
.5822 .6444 m .58216 .64445 L .58213 .64159 L .082 0 .419 r
F
.57936 .64289 m .58271 .64365 L .58309 .64309 L .654 .726 .902 r
F
.58271 .64365 m .59536 .6465 L .58309 .64309 L F
.58217 .64153 m .5822 .6444 L .58213 .64159 L .082 0 .419 r
F
.58689 .63868 m .60185 .65033 L .60626 .647 L .654 .726 .902 r
F
.58952 .6445 m .59485 .6466 L .59686 .64361 L .675 .735 .895 r
F
.59485 .6466 m .59478 .64376 L .59679 .64077 L .124 .015 .447 r
F
.59693 .64645 m .59686 .64361 L .59764 .6404 L 0 0 .262 r
F
.59693 .64645 m .59764 .6404 L .59771 .64324 L F
.59093 .64535 m .59693 .64645 L .59771 .64324 L .675 .735 .895 r
F
.59485 .6466 m .59679 .64077 L .59686 .64361 L .124 .015 .447 r
F
.58952 .6445 m .59686 .64361 L .59086 .64251 L .675 .735 .895 r
F
.59093 .64535 m .59771 .64324 L .59145 .64321 L F
.58661 .64327 m .60933 .64966 L .61063 .64453 L .654 .726 .902 r
F
.59536 .6465 m .60933 .64966 L .58661 .64327 L F
.5894 .64164 m .5947 .64373 L .5967 .64076 L .675 .735 .895 r
F
.59686 .64361 m .59757 .63756 L .59764 .6404 L 0 0 .262 r
F
.59073 .63966 m .5967 .64076 L .59748 .63756 L .675 .735 .895 r
F
.59138 .64036 m .59764 .6404 L .59714 .63718 L F
.59771 .64324 m .59714 .63718 L .59721 .64002 L .85 .653 .114 r
F
.5894 .64164 m .5967 .64076 L .59073 .63966 L .675 .735 .895 r
F
.5841 .63955 m .5894 .64164 L .59073 .63966 L F
.59125 .63752 m .59748 .63756 L .59698 .63435 L F
.59764 .6404 m .59757 .63756 L .59708 .63434 L .85 .653 .114 r
F
.58486 .6414 m .59138 .64036 L .58513 .64033 L .675 .735 .895 r
F
.59764 .6404 m .59708 .63434 L .59714 .63718 L .85 .653 .114 r
F
.59771 .64324 m .59764 .6404 L .59714 .63718 L F
.59073 .63966 m .59748 .63756 L .59125 .63752 L .675 .735 .895 r
F
.59138 .64036 m .59714 .63718 L .59105 .63822 L F
.58503 .6421 m .58996 .63905 L .58444 .64109 L F
.58308 .64039 m .58735 .64333 L .5894 .64164 L F
.58513 .64033 m .59138 .64036 L .59105 .63822 L F
.58503 .6421 m .59112 .64106 L .58996 .63905 L F
.59112 .64106 m .59547 .63701 L .58996 .63905 L F
.59112 .64106 m .59721 .64002 L .59547 .63701 L F
.584 .64144 m .6098 .63929 L .60689 .6343 L .654 .726 .902 r
F
.5788 .63745 m .58118 .6355 L .58074 .63535 L .675 .735 .895 r
F
.57978 .63563 m .58073 .63823 L .58119 .63806 L .654 .726 .902 r
F
.58258 .63665 m .58267 .63606 L .58267 .63731 L 0 0 .148 r
F
.58219 .6362 m .58486 .63642 L .58428 .63542 L .675 .735 .895 r
F
.5788 .63745 m .58246 .63683 L .58219 .6362 L F
.58257 .63583 m .58256 .63706 L .58267 .63606 L .984 .727 .338 r
F
.58256 .63706 m .58265 .63725 L .58267 .63606 L F
.58246 .63683 m .58486 .63642 L .58219 .6362 L .675 .735 .895 r
F
.58258 .63791 m .58259 .64068 L .58256 .63806 L 0 0 .148 r
F
.58258 .63791 m .58256 .63806 L .58255 .63683 L F
.58258 .63665 m .58267 .63731 L .58258 .63791 L F
.58255 .63982 m .58259 .63992 L .58265 .63725 L .984 .727 .338 r
F
.58221 .63905 m .58496 .63926 L .58438 .63825 L .675 .735 .895 r
F
.58185 .636 m .58118 .6355 L .58119 .63831 L .909 .63 .501 r
F
.57887 .64029 m .58249 .63968 L .58224 .6391 L .675 .735 .895 r
F
.58222 .63732 m .58223 .63861 L .58212 .63746 L .082 0 .419 r
F
.58222 .63732 m .58255 .63811 L .58233 .63846 L F
.57879 .62554 m .58 .63839 L .57916 .63846 L .642 .403 .541 r
F
.57978 .63563 m .5784 .63853 L .57965 .63842 L .654 .726 .902 r
F
.5788 .63745 m .58477 .63855 L .58503 .63749 L .675 .735 .895 r
F
.58256 .63706 m .58255 .63982 L .58265 .63725 L .984 .727 .338 r
F
.58223 .63861 m .58215 .63874 L .58212 .63746 L .082 0 .419 r
F
.58222 .63732 m .58255 .63683 L .58255 .63811 L F
.58256 .63706 m .58223 .63629 L .58224 .6391 L .984 .727 .338 r
F
.57887 .64029 m .58265 .64032 L .58275 .63963 L .675 .735 .895 r
F
.58241 .6395 m .58224 .6391 L .58224 .64191 L .984 .727 .338 r
F
.58228 .64417 m .5822 .6443 L .58212 .63746 L .082 0 .419 r
F
.58223 .63505 m .58208 .64196 L .58224 .64209 L .909 .63 .501 r
F
.58239 .63921 m .58308 .64039 L .58244 .63889 L .675 .735 .895 r
F
.58233 .63846 m .58255 .63811 L .58256 .64092 L .082 0 .419 r
F
.58225 .64139 m .58256 .64092 L .58256 .64373 L F
.58235 .64407 m .58256 .64373 L .58258 .6509 L F
.58225 .64139 m .58256 .64373 L .58235 .64407 L F
.57887 .64029 m .58309 .64107 L .58276 .64032 L .675 .735 .895 r
F
.58241 .6395 m .58224 .64209 L .58255 .63982 L .984 .727 .338 r
F
.58154 .6403 m .58349 .64023 L .58222 .63956 L .675 .735 .895 r
F
.58256 .63706 m .58241 .6395 L .58255 .63982 L .984 .727 .338 r
F
.58249 .63968 m .58275 .63963 L .58221 .63905 L .675 .735 .895 r
F
.58275 .63963 m .58496 .63926 L .58283 .6391 L F
.58258 .63791 m .58268 .64012 L .58263 .64043 L 0 0 .148 r
F
.58275 .63963 m .58283 .6391 L .58221 .63905 L .675 .735 .895 r
F
.58258 .63791 m .58267 .63731 L .58268 .64012 L 0 0 .148 r
F
.58263 .64043 m .58268 .64012 L .58268 .6431 L F
.58477 .63855 m .59125 .63752 L .58503 .63749 L .675 .735 .895 r
F
.58503 .63749 m .59125 .63752 L .59092 .63539 L F
.58503 .63749 m .59092 .63539 L .58486 .63642 L F
.58486 .63642 m .59092 .63539 L .58977 .63339 L F
.59092 .63539 m .59525 .63136 L .58977 .63339 L F
.59092 .63539 m .59698 .63435 L .59525 .63136 L F
.58496 .63926 m .58989 .63621 L .58438 .63825 L F
.58438 .63825 m .58989 .63621 L .58798 .63448 L F
.58977 .63339 m .59525 .63136 L .59239 .62878 L F
.58989 .63621 m .59253 .63158 L .58798 .63448 L F
.58989 .63621 m .5954 .63417 L .59253 .63158 L F
.5954 .63417 m .59533 .63133 L .59246 .62873 L .933 .65 .482 r
F
.58265 .64032 m .58513 .64033 L .58275 .63963 L .675 .735 .895 r
F
.58349 .64023 m .58551 .63599 L .58222 .63956 L F
.58438 .63825 m .58798 .63448 L .58342 .63739 L F
.58349 .64023 m .58804 .63732 L .58551 .63599 L F
.5954 .63417 m .59246 .62873 L .59253 .63158 L .933 .65 .482 r
F
.58804 .63732 m .5888 .63242 L .58551 .63599 L .675 .735 .895 r
F
.58804 .63732 m .5926 .63442 L .5888 .63242 L F
.59547 .63701 m .59253 .63158 L .5926 .63442 L .933 .65 .482 r
F
.58977 .63339 m .59239 .62878 L .58786 .63167 L .675 .735 .895 r
F
.58798 .63448 m .59253 .63158 L .58873 .62958 L F
.5926 .63442 m .59253 .63158 L .58873 .62958 L .861 .586 .52 r
F
.5926 .63442 m .58873 .62958 L .5888 .63242 L F
.58103 .64121 m .60211 .62988 L .59577 .62636 L .654 .726 .902 r
F
.57887 .64029 m .58067 .64248 L .58151 .64211 L .675 .735 .895 r
F
.57893 .64314 m .58194 .64122 L .58154 .6403 L F
.57936 .64289 m .5818 .6415 L .58103 .64121 L .654 .726 .902 r
F
.58119 .64112 m .58119 .64127 L .58119 .64127 L .809 .541 .533 r
F
.58193 .63887 m .58119 .64112 L .58188 .64164 L .909 .63 .501 r
F
.57893 .64314 m .58519 .64317 L .58503 .6421 L .675 .735 .895 r
F
.58268 .64293 m .58253 .64275 L .58268 .6431 L .984 .727 .338 r
F
.58259 .64068 m .58261 .6436 L .58258 .64076 L 0 0 .148 r
F
.58261 .6436 m .58258 .64374 L .58255 .63683 L F
.58255 .63683 m .58258 .64374 L .58256 .64386 L F
.58267 .63606 m .58253 .64259 L .58268 .64293 L .984 .727 .338 r
F
.58253 .64259 m .58253 .64275 L .58268 .64293 L F
.58224 .64191 m .58452 .64122 L .5842 .64119 L .675 .735 .895 r
F
.57893 .64314 m .58227 .64199 L .58224 .64191 L F
.58227 .64199 m .58452 .64122 L .58224 .64191 L F
.58194 .64122 m .58349 .64023 L .58154 .6403 L F
.58241 .6395 m .58224 .64191 L .58225 .64193 L .984 .727 .338 r
F
.58255 .63982 m .58253 .64275 L .58259 .63992 L F
.58477 .63855 m .59073 .63966 L .59125 .63752 L .675 .735 .895 r
F
.58496 .63926 m .59105 .63822 L .58989 .63621 L F
.58996 .63905 m .5926 .63442 L .58804 .63732 L F
.59547 .63701 m .5954 .63417 L .59253 .63158 L .933 .65 .482 r
F
.5818 .6415 m .60211 .62988 L .58103 .64121 L .654 .726 .902 r
F
.58309 .64107 m .58486 .6414 L .58276 .64032 L .675 .735 .895 r
F
.58194 .64122 m .5842 .64118 L .58349 .64023 L F
.58276 .64032 m .58486 .6414 L .58513 .64033 L F
.5842 .64118 m .58433 .64099 L .58349 .64023 L F
.5841 .63955 m .59073 .63966 L .58477 .63855 L F
.59125 .63752 m .59698 .63435 L .59092 .63539 L F
.58513 .64033 m .59105 .63822 L .58496 .63926 L F
.59714 .63718 m .59708 .63434 L .59533 .63133 L .987 .711 .381 r
F
.59105 .63822 m .5954 .63417 L .58989 .63621 L .675 .735 .895 r
F
.59105 .63822 m .59714 .63718 L .5954 .63417 L F
.59714 .63718 m .59533 .63133 L .5954 .63417 L .987 .711 .381 r
F
.59721 .64002 m .59714 .63718 L .5954 .63417 L F
.58444 .64109 m .58804 .63732 L .58349 .64023 L .675 .735 .895 r
F
.58444 .64109 m .58996 .63905 L .58804 .63732 L F
.59721 .64002 m .5954 .63417 L .59547 .63701 L .987 .711 .381 r
F
.58996 .63905 m .59547 .63701 L .5926 .63442 L .675 .735 .895 r
F
.5818 .6415 m .60689 .6343 L .60211 .62988 L .654 .726 .902 r
F
.57921 .63995 m .5804 .64259 L .57929 .64275 L .642 .403 .541 r
F
.57973 .64269 m .5804 .64259 L .58067 .64248 L .675 .735 .895 r
F
.57893 .64314 m .58224 .64191 L .58194 .64122 L F
.58225 .64193 m .58224 .64191 L .58224 .64209 L .984 .727 .338 r
F
.58188 .64164 m .58119 .64112 L .58119 .64127 L .909 .63 .501 r
F
.57936 .64289 m .5812 .64368 L .58119 .64331 L .654 .726 .902 r
F
.5812 .64368 m .58249 .64423 L .58119 .64331 L F
.58038 .64715 m .58417 .65053 L .58329 .64922 L .675 .735 .895 r
F
.58228 .64428 m .58258 .6509 L .58235 .65124 L .082 0 .419 r
F
.58225 .64139 m .58235 .64418 L .58228 .64428 L F
.58235 .64418 m .58258 .6509 L .58228 .64428 L F
.58271 .64365 m .58249 .64423 L .58315 .64375 L .654 .726 .902 r
F
.58119 .64331 m .58237 .64415 L .58271 .64365 L F
.58237 .64415 m .58249 .64423 L .58271 .64365 L F
.58143 .64501 m .58166 .65188 L .58144 .65204 L .361 .183 .5 r
F
.58154 .64493 m .58166 .65188 L .58143 .64501 L F
.59686 .64361 m .59679 .64077 L .59757 .63756 L 0 0 .262 r
F
.59086 .64251 m .59686 .64361 L .59764 .6404 L .675 .735 .895 r
F
.59145 .64321 m .59771 .64324 L .59721 .64002 L F
.59086 .64251 m .59764 .6404 L .59138 .64036 L F
.59145 .64321 m .59721 .64002 L .59112 .64106 L F
.5874 .64194 m .61063 .64453 L .6098 .63929 L .654 .726 .902 r
F
.58176 .64874 m .58193 .64887 L .58208 .64196 L .909 .63 .501 r
F
.57964 .63865 m .57933 .63922 L .57961 .63936 L .654 .726 .902 r
F
.57965 .63842 m .57954 .63863 L .57964 .63865 L F
.58 .63839 m .5804 .64259 L .57916 .63846 L .642 .403 .541 r
F
.57887 .64029 m .58219 .63907 L .58155 .63858 L .675 .735 .895 r
F
.58152 .63856 m .58119 .64112 L .58193 .63887 L .909 .63 .501 r
F
.58152 .63856 m .58119 .63831 L .58119 .64112 L F
.57887 .64029 m .58224 .6391 L .58219 .63907 L .675 .735 .895 r
F
.58082 .64113 m .58102 .64121 L .58109 .63828 L .809 .541 .533 r
F
.58097 .63824 m .58109 .63828 L .58118 .63424 L F
.58082 .64113 m .58109 .63828 L .58097 .63824 L F
.57879 .62554 m .5804 .63979 L .58014 .63982 L .642 .403 .541 r
F
.57978 .63563 m .57965 .63842 L .58076 .63832 L .654 .726 .902 r
F
.5788 .63745 m .5838 .63748 L .58285 .63676 L .675 .735 .895 r
F
.58197 .6361 m .58152 .63856 L .58193 .63887 L .909 .63 .501 r
F
.58199 .63487 m .58185 .636 L .58197 .6361 L F
.58185 .636 m .58152 .63856 L .58197 .6361 L F
.58285 .63676 m .58503 .63749 L .58486 .63642 L .675 .735 .895 r
F
.5838 .63748 m .58503 .63749 L .58285 .63676 L F
.58185 .636 m .58119 .63831 L .58152 .63856 L .909 .63 .501 r
F
.58199 .63487 m .58193 .63887 L .58223 .63505 L F
.57936 .64289 m .58356 .64311 L .58276 .64249 L .654 .726 .902 r
F
.58232 .64197 m .58443 .6422 L .58302 .64173 L .675 .735 .895 r
F
.57893 .64314 m .58295 .64245 L .58232 .64197 L F
.58295 .64245 m .58443 .6422 L .58232 .64197 L F
.58193 .63887 m .58188 .64164 L .58209 .639 L .909 .63 .501 r
F
.58188 .64164 m .58176 .64874 L .582 .64173 L F
.58188 .64164 m .582 .64173 L .58209 .639 L F
.58193 .63887 m .58209 .639 L .58223 .63505 L F
.582 .64173 m .58208 .64179 L .58223 .63505 L F
.5809 .63809 m .58342 .63739 L .58215 .63672 L .675 .735 .895 r
F
.5788 .63745 m .5827 .63601 L .58163 .63565 L F
.58092 .63541 m .58087 .6382 L .58111 .63548 L .809 .541 .533 r
F
.58087 .6382 m .58082 .64113 L .58097 .63824 L F
.58087 .6382 m .58097 .63824 L .58111 .63548 L F
.58092 .63541 m .58011 .63514 L .58012 .64088 L F
.57995 .6379 m .58215 .63672 L .58066 .6363 L .675 .735 .895 r
F
.5788 .63745 m .57968 .63989 L .58069 .63974 L F
.57975 .64072 m .57996 .64074 L .58002 .63794 L .734 .478 .541 r
F
.5799 .63793 m .58002 .63794 L .58011 .63384 L F
.57887 .64029 m .58081 .63818 L .58012 .63795 L .675 .735 .895 r
F
.57975 .64072 m .58002 .63794 L .5799 .63793 L .734 .478 .541 r
F
.57993 .63793 m .58012 .63795 L .57995 .6379 L .675 .735 .895 r
F
.57916 .63846 m .57959 .6399 L .57921 .63995 L .642 .403 .541 r
F
.57887 .64029 m .58012 .63795 L .57993 .63793 L .675 .735 .895 r
F
.58081 .63818 m .58215 .63672 L .57995 .6379 L F
.58081 .63818 m .58096 .63814 L .5809 .63809 L F
.58096 .63814 m .58342 .63739 L .5809 .63809 L F
.57887 .64029 m .58171 .63848 L .58081 .63818 L F
.58171 .63848 m .58342 .63739 L .58081 .63818 L F
.58018 .64036 m .58222 .63956 L .58073 .63914 L F
.57887 .64029 m .57973 .64269 L .58067 .64248 L F
.57893 .64314 m .58095 .64094 L .58018 .64036 L F
.58118 .63424 m .58103 .64106 L .58119 .64112 L .809 .541 .533 r
F
.58095 .64094 m .58222 .63956 L .58018 .64036 L .675 .735 .895 r
F
.582 .6419 m .58208 .64196 L .58208 .64179 L .909 .63 .501 r
F
.582 .6419 m .58208 .64179 L .582 .64173 L F
.58253 .64258 m .58224 .64209 L .58253 .64275 L .984 .727 .338 r
F
.58226 .64195 m .58224 .64209 L .58253 .64258 L F
.57936 .64289 m .58407 .64234 L .58273 .64184 L .654 .726 .902 r
F
.58176 .64874 m .58208 .64196 L .582 .6419 L .909 .63 .501 r
F
.5842 .6424 m .59086 .64251 L .58486 .6414 L .675 .735 .895 r
F
.58519 .64317 m .59145 .64321 L .59112 .64106 L F
.58486 .6414 m .59086 .64251 L .59138 .64036 L F
.58519 .64317 m .59112 .64106 L .58503 .6421 L F
.58276 .64249 m .60196 .64408 L .5874 .64194 L .654 .726 .902 r
F
.58356 .64311 m .60196 .64408 L .58276 .64249 L F
.60196 .64408 m .61063 .64453 L .5874 .64194 L F
.5788 .63745 m .57869 .64002 L .57968 .63989 L .675 .735 .895 r
F
.58009 .62062 m .57901 .62049 L .57903 .63368 L .734 .478 .541 r
F
.57723 .62528 m .57879 .62554 L .57881 .63849 L .751 .492 .54 r
F
.57559 .62422 m .57625 .62481 L .57627 .63771 L .928 .648 .489 r
F
.57682 .62092 m .5757 .62169 L .57572 .63472 L .404 .216 .509 r
F
.57767 .63996 m .57553 .64101 L .57702 .64143 L .675 .735 .895 r
F
.5788 .63745 m .57685 .63958 L .57767 .63996 L F
.57685 .63958 m .57553 .64101 L .57767 .63996 L F
.57649 .63782 m .57652 .63943 L .57627 .63771 L .844 .571 .525 r
F
.57553 .64101 m .57226 .64456 L .57523 .6454 L .675 .735 .895 r
F
.57612 .64205 m .57336 .64234 L .57431 .6432 L F
.57553 .64101 m .57523 .6454 L .57702 .64143 L F
.57657 .64226 m .57649 .64222 L .57635 .63935 L .844 .571 .525 r
F
.57592 .63929 m .57332 .63949 L .57427 .64034 L .675 .735 .895 r
F
.57649 .63782 m .57725 .63819 L .57725 .63977 L .844 .571 .525 r
F
.57523 .6454 m .57826 .64982 L .57844 .6457 L .675 .735 .895 r
F
.57523 .6454 m .57345 .64937 L .57826 .64982 L F
.57707 .64429 m .57528 .64828 L .57851 .64858 L F
.57655 .64573 m .57652 .64576 L .57765 .64596 L .654 .726 .902 r
F
.57652 .64576 m .57695 .64654 L .57765 .64596 L F
.57655 .64573 m .57765 .64596 L .57732 .64567 L F
.57723 .62528 m .5776 .63826 L .57725 .63819 L .751 .492 .54 r
F
.57625 .62481 m .57649 .63782 L .57627 .63771 L .844 .571 .525 r
F
.57625 .62481 m .57725 .63819 L .57649 .63782 L F
.57978 .63563 m .56889 .63903 L .55717 .64856 L .654 .726 .902 r
F
.56889 .63903 m .55241 .64418 L .55579 .64729 L F
.56889 .63903 m .55579 .64729 L .55717 .64856 L F
.57552 .64774 m .57766 .64598 L .57765 .64596 L F
.5723 .64744 m .57349 .65227 L .57528 .64828 L .675 .735 .895 r
F
.56969 .65264 m .57552 .64776 L .57552 .64774 L .654 .726 .902 r
F
.57552 .64776 m .57766 .64598 L .57552 .64774 L F
.57529 .63876 m .57274 .63849 L .57332 .63949 L .675 .735 .895 r
F
.57578 .63889 m .57567 .63879 L .57562 .63712 L .928 .648 .489 r
F
.5788 .63745 m .57524 .63806 L .57529 .63876 L .675 .735 .895 r
F
.57524 .63806 m .57274 .63849 L .57529 .63876 L F
.57559 .62422 m .57576 .63725 L .57562 .63712 L .928 .648 .489 r
F
.57522 .62353 m .57562 .63712 L .57532 .6366 L .988 .72 .386 r
F
.57559 .62422 m .57627 .63771 L .57576 .63725 L .928 .648 .489 r
F
.57723 .62528 m .57881 .63849 L .5776 .63826 L .751 .492 .54 r
F
.57978 .63563 m .56273 .63765 L .55241 .64418 L .654 .726 .902 r
F
.56273 .63765 m .54951 .63921 L .55044 .64081 L F
.56273 .63765 m .55044 .64081 L .55241 .64418 L F
.57792 .62058 m .57682 .62092 L .57684 .63401 L .569 .345 .536 r
F
.57696 .64656 m .57698 .6466 L .57766 .64598 L .654 .726 .902 r
F
.57649 .63782 m .57725 .63977 L .57652 .63943 L .844 .571 .525 r
F
.5788 .63745 m .57611 .63917 L .57673 .63971 L .675 .735 .895 r
F
.57702 .64143 m .57523 .6454 L .57844 .6457 L F
.57652 .63943 m .57725 .63977 L .57726 .64258 L .844 .571 .525 r
F
.57774 .6428 m .57558 .64387 L .57707 .64429 L .675 .735 .895 r
F
.5769 .64241 m .57726 .64258 L .57726 .64523 L .844 .571 .525 r
F
.57652 .63943 m .57726 .64258 L .5769 .64241 L F
.57707 .64429 m .57851 .64858 L .57869 .64444 L .675 .735 .895 r
F
.57772 .64265 m .57882 .64553 L .5778 .64533 L .751 .492 .54 r
F
.5776 .63826 m .57835 .64274 L .57772 .64265 L F
.57835 .64274 m .57882 .64553 L .57772 .64265 L F
.5778 .64266 m .57726 .64258 L .57774 .6428 L .675 .735 .895 r
F
.57765 .64596 m .57766 .64598 L .57806 .64562 L .654 .726 .902 r
F
.57732 .64567 m .57765 .64596 L .57806 .64562 L F
.57655 .64573 m .57806 .64562 L .57802 .6456 L F
.57009 .65337 m .56898 .65391 L .57384 .65457 L F
.56908 .65385 m .57026 .65342 L .57355 .65511 L .794 .529 .538 r
F
.57026 .65342 m .57349 .65227 L .57354 .65448 L F
.57026 .65342 m .57354 .65448 L .57355 .65511 L F
.57384 .65457 m .56898 .65391 L .57042 .6618 L .654 .726 .902 r
F
.5757 .65062 m .57009 .65337 L .57384 .65457 L F
.57807 .64562 m .57553 .64794 L .5757 .65062 L F
.57349 .65227 m .57342 .64943 L .57826 .64988 L .731 .478 .546 r
F
.56901 .65101 m .57342 .64943 L .57349 .65227 L .794 .529 .538 r
F
.57553 .64794 m .56898 .65391 L .5757 .65062 L .654 .726 .902 r
F
.57524 .63806 m .57257 .63742 L .57274 .63849 L .675 .735 .895 r
F
.57532 .6366 m .57562 .63712 L .57562 .63874 L .988 .72 .386 r
F
.57532 .6366 m .57562 .63874 L .57534 .63823 L F
.57576 .63725 m .57578 .63889 L .57562 .63712 L .928 .648 .489 r
F
.57534 .63823 m .57527 .63812 L .57524 .63645 L .988 .72 .386 r
F
.5788 .63745 m .57521 .63743 L .57524 .63806 L .675 .735 .895 r
F
.57521 .63743 m .57257 .63742 L .57524 .63806 L F
.5752 .63585 m .57524 .63645 L .57524 .63807 L .779 .622 .059 r
F
.57557 .63865 m .57332 .63949 L .57592 .63929 L .675 .735 .895 r
F
.57522 .63767 m .57524 .63807 L .57525 .64088 L .779 .622 .059 r
F
.5752 .63585 m .57524 .63807 L .57522 .63767 L F
.57512 .63882 m .57457 .63734 L .57354 .63819 L .675 .735 .895 r
F
.57652 .63943 m .57635 .63935 L .57627 .63771 L .844 .571 .525 r
F
.5788 .63745 m .57582 .63911 L .57605 .63921 L .675 .735 .895 r
F
.56273 .63765 m .54867 .634 L .54951 .63921 L .654 .726 .902 r
F
.57978 .63563 m .57212 .63523 L .56273 .63765 L F
.57212 .63523 m .54867 .634 L .56273 .63765 L F
.5752 .63585 m .57525 .64088 L .57523 .64064 L .779 .622 .059 r
F
.5752 .63585 m .57521 .63747 L .57519 .63568 L F
.57521 .63747 m .57521 .64031 L .5752 .63733 L F
.57427 .64034 m .57226 .64456 L .57553 .64101 L .675 .735 .895 r
F
.5756 .64151 m .57278 .64133 L .57336 .64234 L F
.57726 .64258 m .57558 .64387 L .57774 .6428 L F
.57691 .64242 m .57683 .64251 L .57726 .64258 L F
.57683 .64251 m .57558 .64387 L .57726 .64258 L F
.57764 .6453 m .5775 .64527 L .57741 .6426 L .751 .492 .54 r
F
.57749 .64261 m .57741 .6426 L .57725 .63819 L F
.57764 .6453 m .57741 .6426 L .57749 .64261 L F
.57652 .63943 m .57726 .64523 L .57662 .64491 L .844 .571 .525 r
F
.57887 .64029 m .57527 .64091 L .5756 .64151 L .675 .735 .895 r
F
.57527 .64091 m .57278 .64133 L .5756 .64151 L F
.57534 .63823 m .57562 .63874 L .57562 .64155 L .988 .72 .386 r
F
.57549 .64131 m .57562 .64155 L .57563 .64416 L F
.57637 .6401 m .57427 .64034 L .57553 .64101 L .675 .735 .895 r
F
.57534 .63823 m .57562 .64155 L .57549 .64131 L .988 .72 .386 r
F
.57641 .64297 m .57431 .6432 L .57558 .64387 L .675 .735 .895 r
F
.57691 .64242 m .57622 .64263 L .57641 .64297 L F
.57622 .64263 m .57431 .6432 L .57641 .64297 L F
.57882 .65302 m .57576 .65832 L .57806 .67017 L .654 .726 .902 r
F
.57884 .65256 m .57864 .65293 L .57882 .65302 L F
.57349 .65227 m .57826 .64988 L .57832 .65272 L .731 .478 .546 r
F
.57455 .65461 m .57349 .65227 L .57832 .65272 L F
.57528 .64828 m .57832 .65272 L .57851 .64858 L .675 .735 .895 r
F
.57528 .64828 m .57349 .65227 L .57832 .65272 L F
.57732 .64721 m .57386 .65452 L .57903 .65029 L .654 .726 .902 r
F
.57386 .65452 m .57042 .6618 L .57568 .65477 L F
.57386 .65452 m .57568 .65477 L .57903 .65029 L F
.57355 .65511 m .57354 .65448 L .57455 .65461 L .731 .478 .546 r
F
.57354 .65448 m .57349 .65227 L .57455 .65461 L F
.57535 .65112 m .57355 .65511 L .57839 .65556 L .675 .735 .895 r
F
.57864 .65293 m .57576 .65832 L .57882 .65302 L .654 .726 .902 r
F
.57714 .64713 m .57535 .65112 L .57857 .65142 L .675 .735 .895 r
F
.57652 .64576 m .56969 .65264 L .57695 .64654 L .654 .726 .902 r
F
.57781 .64564 m .57565 .64671 L .57714 .64713 L .675 .735 .895 r
F
.57897 .64279 m .57907 .64551 L .57882 .64281 L .642 .403 .541 r
F
.57853 .64376 m .57882 .64281 L .57882 .64553 L .751 .492 .54 r
F
.57936 .64289 m .57655 .64573 L .57808 .64559 L .654 .726 .902 r
F
.57893 .64314 m .57698 .64526 L .57781 .64564 L .675 .735 .895 r
F
.57698 .64526 m .57565 .64671 L .57781 .64564 L F
.57535 .65112 m .57839 .65556 L .57857 .65142 L F
.57789 .65238 m .57568 .65706 L .57884 .65256 L .654 .726 .902 r
F
.57568 .65706 m .57 .66906 L .57576 .65832 L F
.57558 .64387 m .57528 .64828 L .57707 .64429 L .675 .735 .895 r
F
.57585 .64436 m .57594 .65146 L .57573 .64425 L .928 .648 .489 r
F
.57576 .65832 m .57649 .66995 L .57806 .67017 L .654 .726 .902 r
F
.56901 .65101 m .56895 .64816 L .57342 .64943 L .794 .529 .538 r
F
.57226 .64456 m .57345 .64937 L .57523 .6454 L .675 .735 .895 r
F
.56644 .65159 m .56521 .64901 L .56901 .65101 L .861 .586 .521 r
F
.56644 .65159 m .56901 .65101 L .56906 .65304 L F
.57226 .64456 m .569 .64811 L .57345 .64937 L .675 .735 .895 r
F
.56976 .6461 m .56901 .65101 L .5723 .64744 L F
.57249 .64759 m .56567 .65116 L .56969 .65264 L .654 .726 .902 r
F
.56567 .65116 m .55664 .65589 L .56875 .65287 L F
.56567 .65116 m .56875 .65287 L .56969 .65264 L F
.56528 .65185 m .56644 .65159 L .56908 .65385 L .861 .586 .521 r
F
.56644 .65159 m .56906 .65304 L .56908 .65385 L F
.56528 .65185 m .56526 .65093 L .56644 .65159 L F
.56526 .65093 m .56521 .64901 L .56644 .65159 L F
.57558 .64387 m .5723 .64744 L .57528 .64828 L .675 .735 .895 r
F
.57578 .64494 m .56528 .65094 L .57689 .64529 L .654 .726 .902 r
F
.56528 .65094 m .55664 .65589 L .56567 .65116 L F
.56521 .64901 m .56895 .64816 L .56901 .65101 L .861 .586 .521 r
F
.56976 .6461 m .56521 .64901 L .56901 .65101 L .675 .735 .895 r
F
.56528 .65094 m .56567 .65116 L .57689 .64529 L .654 .726 .902 r
F
.5767 .64512 m .57689 .64529 L .57708 .64519 L F
.57578 .64494 m .57689 .64529 L .5767 .64512 L F
.57622 .63984 m .57427 .64034 L .57637 .6401 L .675 .735 .895 r
F
.57605 .63921 m .57582 .63911 L .57592 .63929 L F
.57576 .63725 m .57627 .63771 L .57628 .64474 L .928 .648 .489 r
F
.57744 .6528 m .57552 .65459 L .57762 .65296 L .654 .726 .902 r
F
.57552 .65459 m .5693 .66038 L .57554 .65482 L F
.57552 .65459 m .57554 .65482 L .57762 .65296 L F
.57662 .64491 m .57643 .64482 L .57637 .64217 L .844 .571 .525 r
F
.56521 .64901 m .56515 .64617 L .56895 .64816 L .861 .586 .521 r
F
.5686 .64626 m .55529 .65465 L .55664 .65589 L .654 .726 .902 r
F
.56241 .64926 m .56335 .64918 L .56528 .65185 L .933 .65 .482 r
F
.56335 .64918 m .56521 .64901 L .56526 .65093 L F
.56528 .65095 m .56411 .64987 L .55664 .65589 L .654 .726 .902 r
F
.56335 .64918 m .56526 .65093 L .56528 .65185 L .933 .65 .482 r
F
.57431 .6432 m .5723 .64744 L .57558 .64387 L .675 .735 .895 r
F
.57431 .6432 m .56976 .6461 L .5723 .64744 L F
.57936 .64289 m .5686 .64626 L .56411 .64987 L .654 .726 .902 r
F
.57936 .64289 m .56411 .64987 L .56528 .65095 L F
.56335 .64918 m .56234 .64642 L .56521 .64901 L .933 .65 .482 r
F
.56231 .64822 m .55185 .65149 L .5636 .64941 L .654 .726 .902 r
F
.56241 .64926 m .56238 .64829 L .56335 .64918 L .933 .65 .482 r
F
.56238 .64829 m .56234 .64642 L .56335 .64918 L F
.5636 .64941 m .55185 .65149 L .55529 .65465 L .654 .726 .902 r
F
.56234 .64642 m .56515 .64617 L .56521 .64901 L .933 .65 .482 r
F
.56785 .64438 m .56234 .64642 L .56521 .64901 L .675 .735 .895 r
F
.5686 .64626 m .56231 .64822 L .5636 .64941 L .654 .726 .902 r
F
.57611 .63917 m .57427 .64034 L .57673 .63971 L .675 .735 .895 r
F
.57578 .63889 m .57582 .64172 L .57567 .63879 L .928 .648 .489 r
F
.57612 .64205 m .57431 .6432 L .57669 .64248 L .675 .735 .895 r
F
.57628 .64212 m .57669 .64248 L .57691 .64242 L F
.57612 .64205 m .57669 .64248 L .57628 .64212 L F
.57585 .64436 m .57573 .64425 L .57569 .64161 L .928 .648 .489 r
F
.57576 .64167 m .57569 .64161 L .57562 .63712 L F
.57585 .64436 m .57569 .64161 L .57576 .64167 L F
.57582 .64172 m .57585 .64436 L .57576 .64167 L F
.57582 .64172 m .57576 .64167 L .57567 .63879 L F
.57332 .63949 m .56974 .64324 L .57427 .64034 L .675 .735 .895 r
F
.57495 .64096 m .57261 .64026 L .57278 .64133 L F
.57649 .64222 m .57637 .64217 L .57627 .63771 L .844 .571 .525 r
F
.57521 .64031 m .57525 .64349 L .57522 .64297 L .779 .622 .059 r
F
.5752 .63585 m .57523 .64064 L .57521 .64031 L F
.57523 .64064 m .57525 .64349 L .57521 .64031 L F
.57525 .64091 m .57415 .64027 L .57495 .64096 L .675 .735 .895 r
F
.57673 .63971 m .57622 .63984 L .57637 .6401 L F
.57652 .63943 m .57657 .64226 L .57635 .63935 L .844 .571 .525 r
F
.57887 .64029 m .57521 .64027 L .57525 .64091 L .675 .735 .895 r
F
.57521 .64027 m .57415 .64027 L .57525 .64091 L F
.57415 .64027 m .57261 .64026 L .57495 .64096 L F
.5751 .64027 m .57287 .63919 L .57261 .64026 L F
.57534 .63823 m .57538 .64371 L .57527 .63812 L .988 .72 .386 r
F
.57887 .64029 m .57542 .63966 L .5751 .64027 L .675 .735 .895 r
F
.57542 .63966 m .57287 .63919 L .5751 .64027 L F
.57523 .64164 m .57336 .64234 L .57591 .64207 L F
.57582 .64191 m .57591 .64207 L .57612 .64205 L F
.57523 .64164 m .57591 .64207 L .57582 .64191 L F
.57536 .64108 m .57563 .64416 L .57538 .64371 L .988 .72 .386 r
F
.57534 .63823 m .57549 .64131 L .57536 .64108 L F
.57549 .64131 m .57563 .64416 L .57536 .64108 L F
.57538 .64371 m .57528 .64094 L .57533 .64102 L F
.57557 .63937 m .5752 .64271 L .57555 .64208 L 0 0 .381 r
F
.57561 .63493 m .57536 .63978 L .57557 .63937 L F
.57536 .63978 m .5752 .64271 L .57557 .63937 L F
.57652 .63852 m .57573 .63907 L .57574 .64175 L .404 .216 .509 r
F
.57762 .65296 m .57554 .65482 L .57568 .65706 L .654 .726 .902 r
F
.57553 .64781 m .57553 .64792 L .57698 .6466 L F
.57565 .64671 m .57535 .65112 L .57714 .64713 L .675 .735 .895 r
F
.57585 .64436 m .57628 .64474 L .57629 .65178 L .928 .648 .489 r
F
.57692 .65219 m .57646 .65267 L .57789 .65238 L .654 .726 .902 r
F
.5723 .64744 m .56901 .65101 L .57349 .65227 L .675 .735 .895 r
F
.57708 .64519 m .57249 .64759 L .56969 .65264 L .654 .726 .902 r
F
.56974 .64324 m .569 .64811 L .57226 .64456 L .675 .735 .895 r
F
.57427 .64034 m .56974 .64324 L .57226 .64456 L F
.57336 .64234 m .56976 .6461 L .57431 .6432 L F
.57936 .64289 m .57267 .64369 L .5686 .64626 L .654 .726 .902 r
F
.57568 .65706 m .57576 .65832 L .5783 .65357 L F
.57725 .63819 m .5775 .64527 L .57726 .64523 L .751 .492 .54 r
F
.57936 .64289 m .57578 .64494 L .57708 .64519 L .654 .726 .902 r
F
.57662 .64491 m .57726 .64539 L .57663 .6451 L .844 .571 .525 r
F
.57662 .64491 m .57675 .652 L .57643 .64482 L F
.57675 .652 m .57733 .68382 L .5766 .65193 L F
.57675 .652 m .5766 .65193 L .57643 .64482 L F
.57645 .64584 m .57438 .64604 L .57565 .64671 L .675 .735 .895 r
F
.57538 .64371 m .57544 .65083 L .57531 .64359 L .988 .72 .386 r
F
.56898 .65391 m .56548 .66021 L .57042 .6618 L .654 .726 .902 r
F
.56995 .65922 m .55622 .66315 L .56255 .66667 L F
.57646 .65267 m .57243 .65475 L .56995 .65922 L F
.57243 .65475 m .55622 .66315 L .56995 .65922 L F
.57635 .65247 m .5726 .65446 L .57646 .65267 L F
.5726 .65446 m .55622 .66315 L .57243 .65475 L F
.57236 .65028 m .57355 .65511 L .57535 .65112 L .675 .735 .895 r
F
.5726 .65446 m .57243 .65475 L .57646 .65267 L .654 .726 .902 r
F
.57573 .64425 m .57584 .65137 L .57563 .64416 L .928 .648 .489 r
F
.56898 .65391 m .56297 .65941 L .56548 .66021 L .654 .726 .902 r
F
.5762 .65173 m .576 .65184 L .5768 .65223 L F
.576 .65184 m .55622 .66315 L .57635 .65247 L F
.576 .65184 m .57635 .65247 L .5768 .65223 L F
.57576 .65832 m .57 .66906 L .57649 .66995 L F
.57924 .64561 m .57732 .64721 L .57903 .65029 L F
.57714 .64713 m .57857 .65142 L .57875 .64728 L .675 .735 .895 r
F
.5775 .64527 m .57776 .65236 L .57726 .64523 L .751 .492 .54 r
F
.57789 .65238 m .57744 .6528 L .57762 .65296 L .654 .726 .902 r
F
.57776 .65236 m .57889 .68408 L .57756 .65232 L .751 .492 .54 r
F
.57776 .65236 m .57756 .65232 L .57726 .64523 L F
.56969 .65264 m .56297 .65941 L .56898 .65391 L .654 .726 .902 r
F
.56969 .65264 m .5694 .65315 L .57553 .64792 L F
.5694 .65315 m .56898 .65391 L .56971 .65325 L F
.5694 .65315 m .56971 .65325 L .57553 .64792 L F
.57026 .65342 m .56901 .65101 L .57349 .65227 L .794 .529 .538 r
F
.56908 .65385 m .56906 .65304 L .57026 .65342 L F
.56906 .65304 m .56901 .65101 L .57026 .65342 L F
.57236 .65028 m .56908 .65385 L .57355 .65511 L .675 .735 .895 r
F
.57577 .65197 m .5683 .65348 L .55622 .66315 L .654 .726 .902 r
F
.57895 .65016 m .57415 .65166 L .57577 .65197 L F
.57415 .65166 m .5683 .65348 L .57577 .65197 L F
.56969 .65264 m .55664 .65589 L .56297 .65941 L F
.5683 .65348 m .55143 .65875 L .55489 .66194 L F
.5683 .65348 m .55489 .66194 L .55622 .66315 L F
.5762 .65173 m .5768 .65223 L .57629 .65178 L F
.57629 .65178 m .57733 .68382 L .57635 .68335 L .844 .571 .525 r
F
.57628 .64474 m .57647 .65187 L .57629 .65178 L F
.57647 .65187 m .57733 .68382 L .57629 .65178 L F
.57531 .65129 m .54852 .65376 L .55143 .65875 L .654 .726 .902 r
F
.57585 .64436 m .57629 .65178 L .57594 .65146 L .928 .648 .489 r
F
.57895 .65016 m .57416 .65073 L .57531 .65129 L .654 .726 .902 r
F
.56983 .64895 m .56528 .65185 L .56908 .65385 L .675 .735 .895 r
F
.57416 .65073 m .54852 .65376 L .57531 .65129 L .654 .726 .902 r
F
.57699 .65212 m .57635 .65247 L .57646 .65267 L F
.57643 .64482 m .5766 .65193 L .57628 .64474 L .844 .571 .525 r
F
.5766 .65193 m .57733 .68382 L .57647 .65187 L F
.5766 .65193 m .57647 .65187 L .57628 .64474 L F
.56983 .64895 m .56908 .65385 L .57236 .65028 L .675 .735 .895 r
F
.57416 .65073 m .54768 .64852 L .54852 .65376 L .654 .726 .902 r
F
.57887 .64029 m .57523 .64164 L .57612 .64205 L .675 .735 .895 r
F
.57522 .64297 m .57525 .64349 L .57525 .64368 L .779 .622 .059 r
F
.57599 .64502 m .57438 .64604 L .57645 .64584 L .675 .735 .895 r
F
.57522 .64317 m .57525 .64368 L .57526 .65052 L .779 .622 .059 r
F
.57662 .64491 m .57637 .64217 L .57649 .64222 L .844 .571 .525 r
F
.57538 .64371 m .57531 .64359 L .57528 .64094 L .988 .72 .386 r
F
.56146 .64501 m .5481 .64126 L .54894 .6465 L .654 .726 .902 r
F
.57657 .64226 m .57662 .64491 L .57649 .64222 L .844 .571 .525 r
F
.56784 .64152 m .56521 .64612 L .56974 .64324 L .675 .735 .895 r
F
.56784 .64152 m .56236 .64355 L .56521 .64612 L F
.56669 .64237 m .56234 .64642 L .56785 .64438 L F
.57336 .64234 m .56785 .64438 L .56976 .6461 L F
.57278 .64133 m .56785 .64438 L .57336 .64234 L F
.57936 .64289 m .57132 .64247 L .56146 .64501 L .654 .726 .902 r
F
.56059 .64341 m .56228 .64358 L .56234 .64642 L .987 .712 .382 r
F
.56059 .64341 m .56053 .64057 L .56228 .64358 L F
.56234 .64642 m .56228 .64358 L .56515 .64617 L .933 .65 .482 r
F
.56669 .64237 m .56059 .64341 L .56234 .64642 L .675 .735 .895 r
F
.57278 .64133 m .56669 .64237 L .56785 .64438 L F
.5601 .64189 m .5481 .64126 L .56055 .64476 L .654 .726 .902 r
F
.56016 .64303 m .5603 .64315 L .56066 .64625 L .852 .654 .116 r
F
.5603 .64315 m .56059 .64341 L .56064 .64529 L F
.5603 .64315 m .56064 .64529 L .56066 .64625 L F
.56016 .64303 m .56009 .64019 L .56059 .64341 L F
.57132 .64247 m .5601 .64189 L .56146 .64501 L .654 .726 .902 r
F
.56123 .64631 m .56059 .64341 L .56234 .64642 L .987 .712 .382 r
F
.56234 .64821 m .56075 .64549 L .55185 .65149 L .654 .726 .902 r
F
.56066 .64625 m .56064 .64529 L .56123 .64631 L .987 .712 .382 r
F
.56064 .64529 m .56059 .64341 L .56123 .64631 L F
.5686 .64626 m .56146 .64501 L .56075 .64549 L .654 .726 .902 r
F
.56974 .64324 m .56521 .64612 L .569 .64811 L .675 .735 .895 r
F
.56785 .64438 m .56521 .64901 L .56976 .6461 L F
.5686 .64626 m .56075 .64549 L .56234 .64821 L .654 .726 .902 r
F
.5601 .64189 m .56055 .64476 L .56146 .64501 L F
.5757 .62169 m .57519 .63568 L .57561 .63493 L 0 0 .381 r
F
.57241 .63397 m .55327 .62425 L .54996 .6289 L .654 .726 .902 r
F
.57682 .62092 m .57572 .63472 L .57659 .63417 L .404 .216 .509 r
F
.57978 .63563 m .57559 .63383 L .57241 .63397 L .654 .726 .902 r
F
.57559 .63383 m .55327 .62425 L .57241 .63397 L F
.57901 .62049 m .57792 .62058 L .57794 .63373 L .66 .418 .542 r
F
.5788 .63745 m .57796 .63513 L .5771 .63539 L .675 .735 .895 r
F
.5757 .62169 m .57561 .63493 L .57572 .63472 L 0 0 .381 r
F
.57716 .63376 m .56498 .61755 L .5584 .62038 L .654 .726 .902 r
F
.57978 .63563 m .57821 .63372 L .57716 .63376 L F
.57821 .63372 m .56498 .61755 L .57716 .63376 L F
.57884 .65256 m .57806 .67017 L .57979 .65248 L F
.57882 .64281 m .57907 .64551 L .57882 .64553 L .642 .403 .541 r
F
.5782 .65348 m .5783 .65357 L .57884 .65256 L .654 .726 .902 r
F
.57802 .6456 m .57806 .64562 L .57808 .64559 L F
.57808 .64559 m .57806 .64562 L .57807 .64562 L F
.57817 .6454 m .57732 .64721 L .57924 .64561 L F
.5778 .64533 m .57882 .64553 L .57883 .64562 L .751 .492 .54 r
F
.57883 .64562 m .57714 .64713 L .57875 .64728 L .675 .735 .895 r
F
.57788 .64548 m .57714 .64713 L .57883 .64562 L F
.578 .6524 m .57884 .65256 L .57889 .68408 L .751 .492 .54 r
F
.57905 .64775 m .57802 .67912 L .57911 .67903 L .66 .418 .542 r
F
.57936 .64289 m .57817 .6454 L .57924 .64561 L .654 .726 .902 r
F
.56791 .64722 m .56528 .65185 L .56983 .64895 L .675 .735 .895 r
F
.57192 .64936 m .57 .64814 L .56366 .64841 L .654 .726 .902 r
F
.57522 .64297 m .57525 .64368 L .57522 .64317 L .779 .622 .059 r
F
.57893 .64314 m .57522 .64312 L .57526 .64376 L .675 .735 .895 r
F
.57538 .64371 m .57563 .64416 L .57563 .64436 L .988 .72 .386 r
F
.57538 .64371 m .57563 .64436 L .57539 .64393 L F
.57893 .64314 m .57284 .64418 L .57342 .64518 L .675 .735 .895 r
F
.57647 .64136 m .57635 .64841 L .57668 .64122 L .404 .216 .509 r
F
.57887 .64029 m .57726 .64258 L .5778 .64266 L .675 .735 .895 r
F
.57657 .63567 m .57647 .64129 L .57677 .63553 L .404 .216 .509 r
F
.57257 .63742 m .56668 .63952 L .57274 .63849 L .675 .735 .895 r
F
.57257 .63742 m .56635 .63738 L .56668 .63952 L F
.57978 .63563 m .54996 .6289 L .54867 .634 L .654 .726 .902 r
F
.57283 .63635 m .56687 .63525 L .56635 .63738 L .675 .735 .895 r
F
.56687 .63525 m .5609 .63415 L .56012 .63735 L F
.5682 .63327 m .5609 .63415 L .56687 .63525 L F
.57354 .63819 m .56687 .63808 L .57287 .63919 L F
.5682 .63327 m .56289 .63118 L .5609 .63415 L F
.56288 .63399 m .56081 .63413 L .56087 .63698 L .123 .014 .446 r
F
.56288 .63399 m .56281 .63115 L .56081 .63413 L F
.57283 .63635 m .56635 .63738 L .57257 .63742 L .675 .735 .895 r
F
.57354 .63819 m .56821 .63609 L .56687 .63808 L F
.56821 .63609 m .56288 .63399 L .56087 .63698 L F
.57472 .6409 m .56597 .63398 L .56329 .636 L .654 .726 .902 r
F
.56604 .63427 m .56563 .63423 L .56294 .63683 L .36 .191 .511 r
F
.56563 .63423 m .56288 .63399 L .56293 .63627 L F
.56563 .63423 m .56293 .63627 L .56294 .63683 L F
.56329 .636 m .55787 .62757 L .55272 .63146 L .654 .726 .902 r
F
.57027 .63438 m .56597 .63143 L .56288 .63399 L .675 .735 .895 r
F
.56604 .63427 m .56597 .63143 L .56288 .63399 L .36 .191 .511 r
F
.56597 .63398 m .55787 .62757 L .56329 .636 L .654 .726 .902 r
F
.57887 .64029 m .57612 .64205 L .57691 .64242 L .675 .735 .895 r
F
.5776 .63826 m .5778 .64533 L .57725 .63819 L .751 .492 .54 r
F
.5778 .64533 m .57797 .65153 L .57764 .6453 L F
.5778 .64533 m .57764 .6453 L .57725 .63819 L F
.57887 .64029 m .5764 .6386 L .57574 .63906 L .675 .735 .895 r
F
.57621 .63567 m .57584 .63387 L .57453 .63451 L F
.5788 .63745 m .5771 .63539 L .57621 .63567 L F
.57657 .63567 m .57677 .63553 L .57684 .63401 L .404 .216 .509 r
F
.57659 .63417 m .57572 .63472 L .57573 .63626 L F
.57521 .63747 m .5752 .63733 L .57519 .63568 L .779 .622 .059 r
F
.57561 .63493 m .57519 .63568 L .5752 .63727 L 0 0 .381 r
F
.57521 .64031 m .57521 .64025 L .5752 .63733 L .779 .622 .059 r
F
.57532 .6366 m .57534 .63823 L .57524 .63645 L .988 .72 .386 r
F
.57546 .63676 m .5752 .63727 L .5752 .64008 L 0 0 .381 r
F
.57561 .63493 m .5752 .63727 L .57546 .63676 L F
.57511 .63743 m .57283 .63635 L .57257 .63742 L .675 .735 .895 r
F
.5788 .63745 m .57542 .63683 L .57511 .63743 L F
.57542 .63683 m .57283 .63635 L .57511 .63743 L F
.5763 .63586 m .57573 .63626 L .57573 .63907 L .404 .216 .509 r
F
.57659 .63417 m .57573 .63626 L .5763 .63586 L F
.57684 .63548 m .57584 .63387 L .57621 .63567 L .675 .735 .895 r
F
.57769 .63379 m .57684 .63548 L .57752 .63526 L .569 .345 .536 r
F
.5771 .63539 m .57705 .63533 L .57684 .63548 L .675 .735 .895 r
F
.57705 .63533 m .57584 .63387 L .57684 .63548 L F
.57978 .63563 m .5584 .62038 L .55327 .62425 L .654 .726 .902 r
F
.57769 .63379 m .57684 .63401 L .57684 .63548 L .569 .345 .536 r
F
.57752 .63526 m .57684 .63548 L .57685 .64105 L F
.56668 .63952 m .56236 .64355 L .56784 .64152 L .675 .735 .895 r
F
.56668 .63952 m .56062 .64055 L .56236 .64355 L F
.56009 .64019 m .56053 .64057 L .56059 .64341 L .852 .654 .116 r
F
.56635 .64023 m .56059 .64341 L .56669 .64237 L .675 .735 .895 r
F
.56635 .64023 m .56009 .64019 L .56059 .64341 L F
.5602 .64189 m .54849 .63967 L .55991 .64188 L .654 .726 .902 r
F
.57274 .63849 m .56668 .63952 L .56784 .64152 L .675 .735 .895 r
F
.57261 .64026 m .56635 .64023 L .56669 .64237 L F
.57936 .64289 m .56045 .64092 L .5602 .64189 L .654 .726 .902 r
F
.56045 .64092 m .54849 .63967 L .5602 .64189 L F
.5607 .63992 m .56009 .64019 L .56014 .64215 L 0 0 .26 r
F
.56009 .64019 m .56003 .63735 L .56053 .64057 L .852 .654 .116 r
F
.57248 .64218 m .54939 .63613 L .54849 .63967 L .654 .726 .902 r
F
.56094 .63982 m .5607 .63992 L .56016 .64303 L 0 0 .26 r
F
.5607 .63992 m .56014 .64215 L .56016 .64303 L F
.56791 .64722 m .56241 .64926 L .56528 .65185 L .675 .735 .895 r
F
.57052 .64972 m .56366 .64841 L .56171 .64926 L .654 .726 .902 r
F
.57576 .63725 m .57628 .64474 L .57585 .64436 L .928 .648 .489 r
F
.57627 .63771 m .57643 .64482 L .57628 .64474 L .844 .571 .525 r
F
.57647 .64129 m .57574 .64175 L .57575 .64879 L .404 .216 .509 r
F
.57584 .65137 m .57576 .6513 L .57563 .64416 L .928 .648 .489 r
F
.57895 .65016 m .5744 .64964 L .57399 .6499 L .654 .726 .902 r
F
.57726 .64523 m .57756 .65232 L .57728 .65226 L .751 .492 .54 r
F
.57662 .64491 m .57728 .65226 L .57675 .652 L .844 .571 .525 r
F
.57895 .65016 m .57499 .64927 L .5744 .64964 L .654 .726 .902 r
F
.57584 .65137 m .57635 .68335 L .57576 .6513 L .928 .648 .489 r
F
.57594 .65146 m .57635 .68335 L .57584 .65137 L F
.57594 .65146 m .57584 .65137 L .57573 .64425 L F
.57564 .65119 m .57635 .68335 L .57569 .68276 L F
.57563 .64416 m .57576 .6513 L .57564 .65119 L F
.57576 .6513 m .57635 .68335 L .57564 .65119 L F
.56969 .65264 m .57553 .64792 L .57553 .64781 L .654 .726 .902 r
F
.56969 .65264 m .57698 .6466 L .57696 .64656 L F
.57806 .64562 m .56898 .65391 L .57807 .64562 L F
.57565 .64671 m .57236 .65028 L .57535 .65112 L .675 .735 .895 r
F
.575 .65063 m .57399 .6499 L .57416 .65073 L .654 .726 .902 r
F
.5778 .64547 m .57884 .65256 L .578 .6524 L .751 .492 .54 r
F
.57895 .65016 m .5742 .64991 L .575 .65063 L .654 .726 .902 r
F
.5742 .64991 m .57399 .6499 L .575 .65063 L F
.55991 .64188 m .54849 .63967 L .5481 .64126 L F
.56642 .64307 m .56016 .64303 L .56066 .64625 L .675 .735 .895 r
F
.57 .64814 m .5523 .63873 L .54897 .6434 L .654 .726 .902 r
F
.57797 .65153 m .57798 .65868 L .5775 .64527 L .751 .492 .54 r
F
.57797 .65153 m .578 .6524 L .57797 .6524 L F
.57895 .65016 m .57692 .65219 L .57789 .65238 L .654 .726 .902 r
F
.57568 .65706 m .5783 .65357 L .5782 .65348 L F
.57728 .65226 m .57889 .68408 L .57733 .68382 L .751 .492 .54 r
F
.57756 .65232 m .57889 .68408 L .57728 .65226 L F
.57332 .63949 m .56784 .64152 L .56974 .64324 L .675 .735 .895 r
F
.57261 .64026 m .56669 .64237 L .57278 .64133 L F
.56635 .63738 m .56062 .64055 L .56668 .63952 L F
.56687 .63808 m .56009 .64019 L .56635 .64023 L F
.57274 .63849 m .56784 .64152 L .57332 .63949 L F
.5742 .64173 m .561 .63875 L .57248 .64218 L .654 .726 .902 r
F
.56635 .63738 m .56012 .63735 L .56062 .64055 L .675 .735 .895 r
F
.56687 .63808 m .56087 .63698 L .56009 .64019 L F
.5607 .63992 m .56087 .63698 L .56009 .64019 L 0 0 .26 r
F
.561 .63875 m .54939 .63613 L .5609 .63914 L .654 .726 .902 r
F
.561 .63875 m .5609 .63914 L .57248 .64218 L F
.56094 .63982 m .56092 .63907 L .5607 .63992 L 0 0 .26 r
F
.56092 .63907 m .56087 .63698 L .5607 .63992 L F
.57525 .64349 m .57535 .65067 L .57526 .65052 L .988 .72 .386 r
F
.57544 .65083 m .57538 .65073 L .57531 .64359 L F
.57267 .64369 m .56146 .64501 L .5686 .64626 L .654 .726 .902 r
F
.57342 .64518 m .56983 .64895 L .57438 .64604 L .675 .735 .895 r
F
.57284 .64418 m .56675 .64521 L .56791 .64722 L F
.56087 .63698 m .56003 .63735 L .56009 .64019 L 0 0 .26 r
F
.57268 .6431 m .56642 .64307 L .56675 .64521 L .675 .735 .895 r
F
.57521 .64031 m .57522 .64297 L .57521 .64025 L .779 .622 .059 r
F
.57523 .64064 m .57525 .64088 L .57525 .64349 L F
.57562 .63712 m .57573 .64425 L .57563 .64416 L .928 .648 .489 r
F
.55246 .63682 m .55272 .63146 L .54939 .63613 L .654 .726 .902 r
F
.57524 .63645 m .57531 .64359 L .57525 .64349 L .988 .72 .386 r
F
.57287 .63919 m .56635 .64023 L .57261 .64026 L .675 .735 .895 r
F
.57287 .63919 m .56687 .63808 L .56635 .64023 L F
.57936 .64289 m .57183 .63966 L .55246 .63682 L .654 .726 .902 r
F
.56687 .63525 m .56012 .63735 L .56635 .63738 L .675 .735 .895 r
F
.56087 .63698 m .56081 .63413 L .56003 .63735 L 0 0 .26 r
F
.56821 .63609 m .56087 .63698 L .56687 .63808 L .675 .735 .895 r
F
.57183 .63966 m .56316 .63594 L .56157 .63816 L .654 .726 .902 r
F
.56294 .63683 m .56251 .63686 L .56094 .63982 L .123 .014 .446 r
F
.56251 .63686 m .56087 .63698 L .56092 .63907 L F
.56251 .63686 m .56092 .63907 L .56094 .63982 L F
.56157 .63816 m .55272 .63146 L .55246 .63682 L .654 .726 .902 r
F
.56294 .63683 m .56288 .63399 L .56087 .63698 L .123 .014 .446 r
F
.56316 .63594 m .55272 .63146 L .56157 .63816 L .654 .726 .902 r
F
.57887 .64029 m .57876 .64282 L .57973 .64269 L .675 .735 .895 r
F
.57893 .64314 m .58001 .64075 L .57904 .64065 L F
.57975 .64072 m .57904 .64065 L .57904 .64072 L .734 .478 .541 r
F
.57893 .64314 m .58045 .64498 L .57946 .6435 L .675 .735 .895 r
F
.57978 .65266 m .57806 .67017 L .57985 .65264 L .654 .726 .902 r
F
.57907 .64551 m .57933 .65252 L .57882 .64553 L .642 .403 .541 r
F
.57933 .65252 m .58047 .68387 L .57913 .65254 L F
.57933 .65252 m .57913 .65254 L .57882 .64553 L F
.57975 .64082 m .57904 .64072 L .57905 .64775 L .734 .478 .541 r
F
.58369 .65024 m .59597 .65105 L .59767 .65048 L .654 .726 .902 r
F
.57957 .6525 m .57933 .65252 L .57907 .64551 L .642 .403 .541 r
F
.57895 .65016 m .58392 .65042 L .58369 .65024 L .654 .726 .902 r
F
.58392 .65042 m .59597 .65105 L .58369 .65024 L F
.58188 .64181 m .58119 .64127 L .5812 .64831 L .909 .63 .501 r
F
.58445 .64951 m .59767 .65048 L .58809 .64908 L .654 .726 .902 r
F
.58216 .64445 m .58225 .65138 L .58213 .64449 L .082 0 .419 r
F
.58225 .65138 m .58263 .6822 L .58222 .65141 L F
.58225 .65138 m .58222 .65141 L .58213 .64449 L F
.58345 .64963 m .58657 .65029 L .58445 .64951 L .654 .726 .902 r
F
.58041 .64539 m .58061 .65235 L .58042 .65242 L .519 .305 .529 r
F
.57895 .65016 m .58304 .65023 L .58345 .64963 L .654 .726 .902 r
F
.58304 .65023 m .58657 .65029 L .58345 .64963 L F
.58657 .65029 m .59767 .65048 L .58445 .64951 L F
.57936 .64289 m .58215 .64202 L .58162 .6416 L F
.58102 .64121 m .58087 .64818 L .58119 .64127 L .809 .541 .533 r
F
.5842 .64119 m .58452 .64122 L .58444 .64109 L .675 .735 .895 r
F
.58255 .63982 m .58226 .64195 L .58253 .64258 L .984 .727 .338 r
F
.58224 .64191 m .5842 .64118 L .58194 .64122 L .675 .735 .895 r
F
.5842 .64118 m .58444 .64109 L .58433 .64099 L F
.58273 .64184 m .60689 .6343 L .5818 .6415 L .654 .726 .902 r
F
.5874 .64194 m .6098 .63929 L .584 .64144 L F
.58315 .64375 m .58809 .64664 L .58487 .64414 L F
.58249 .64423 m .58809 .64664 L .58315 .64375 L F
.58253 .64275 m .58225 .64912 L .58249 .64966 L .984 .727 .338 r
F
.58104 .64805 m .6017 .63715 L .59536 .63363 L .654 .726 .902 r
F
.58082 .64113 m .5807 .64812 L .58102 .64121 L .809 .541 .533 r
F
.58289 .64893 m .60939 .64656 L .60648 .64156 L .654 .726 .902 r
F
.57895 .65016 m .58445 .64951 L .58289 .64893 L F
.58445 .64951 m .60939 .64656 L .58289 .64893 L F
.5812 .64831 m .58019 .67916 L .58126 .67954 L .809 .541 .533 r
F
.58119 .64127 m .58101 .64823 L .5812 .64831 L F
.58101 .64823 m .58019 .67916 L .5812 .64831 L F
.5807 .64812 m .58019 .67916 L .58087 .64818 L F
.5807 .64812 m .58087 .64818 L .58102 .64121 L F
.58188 .64181 m .5812 .64831 L .58176 .64874 L .909 .63 .501 r
F
.5809 .64819 m .58232 .64823 L .58104 .64805 L .654 .726 .902 r
F
.57895 .65016 m .5818 .64853 L .5809 .64819 L F
.5818 .64853 m .58232 .64823 L .5809 .64819 L F
.58268 .6431 m .58261 .64995 L .5827 .65013 L .984 .727 .338 r
F
.58261 .6436 m .58263 .65054 L .58258 .64374 L 0 0 .148 r
F
.58263 .65054 m .58261 .65066 L .58258 .64374 L F
.58261 .65066 m .5826 .65076 L .58256 .64386 L F
.58249 .64966 m .58261 .64995 L .58268 .6431 L .984 .727 .338 r
F
.58238 .64505 m .58524 .64892 L .58407 .64625 L .654 .726 .902 r
F
.58232 .64823 m .6017 .63715 L .58104 .64805 L F
.57975 .64082 m .57963 .64784 L .57995 .64085 L .734 .478 .541 r
F
.58087 .64818 m .581 .64823 L .58119 .64127 L .809 .541 .533 r
F
.581 .64823 m .58101 .64823 L .58119 .64127 L F
.58302 .64173 m .58503 .6421 L .58452 .64122 L .675 .735 .895 r
F
.58443 .6422 m .58503 .6421 L .58302 .64173 L F
.57979 .65248 m .57978 .65266 L .57985 .65264 L .654 .726 .902 r
F
.57957 .6525 m .58042 .65242 L .58047 .68387 L .642 .403 .541 r
F
.58082 .641 m .58012 .64088 L .58082 .64113 L .809 .541 .533 r
F
.58014 .64077 m .58012 .64088 L .58082 .641 L F
.58103 .64106 m .58102 .64121 L .58119 .64112 L F
.58256 .63706 m .58224 .6391 L .58241 .6395 L .984 .727 .338 r
F
.58191 .63835 m .58438 .63825 L .58342 .63739 L .675 .735 .895 r
F
.58155 .63858 m .58199 .63853 L .58191 .63835 L F
.58199 .63853 m .58438 .63825 L .58191 .63835 L F
.58219 .63907 m .58438 .63825 L .58155 .63858 L F
.58219 .63907 m .58224 .6391 L .58221 .63905 L F
.58163 .63565 m .58428 .63542 L .58333 .63456 L F
.58227 .63514 m .58223 .63629 L .58257 .63583 L .984 .727 .338 r
F
.5827 .63601 m .58428 .63542 L .58163 .63565 L .675 .735 .895 r
F
.57978 .63563 m .60241 .62268 L .59611 .61918 L .654 .726 .902 r
F
.58486 .63642 m .58977 .63339 L .58428 .63542 L .675 .735 .895 r
F
.58428 .63542 m .58786 .63167 L .58333 .63456 L F
.58428 .63542 m .58977 .63339 L .58786 .63167 L F
.58333 .63456 m .58786 .63167 L .58534 .63035 L F
.58342 .63739 m .58544 .63315 L .58215 .63672 L F
.58342 .63739 m .58798 .63448 L .58544 .63315 L F
.58786 .63167 m .58861 .62679 L .58534 .63035 L F
.58786 .63167 m .59239 .62878 L .58861 .62679 L F
.58222 .63956 m .58252 .63515 L .58073 .63914 L F
.58222 .63956 m .58551 .63599 L .58252 .63515 L F
.58798 .63448 m .58873 .62958 L .58544 .63315 L F
.59253 .63158 m .59246 .62873 L .58866 .62674 L .861 .586 .52 r
F
.58544 .63315 m .58873 .62958 L .58425 .62831 L .675 .735 .895 r
F
.59253 .63158 m .58866 .62674 L .58873 .62958 L .861 .586 .52 r
F
.58265 .62285 m .58223 .63505 L .58227 .63514 L .984 .727 .338 r
F
.57978 .63563 m .59611 .61918 L .58869 .61679 L .654 .726 .902 r
F
.58534 .63035 m .58861 .62679 L .58416 .62553 L .675 .735 .895 r
F
.58873 .62958 m .58866 .62674 L .58419 .62547 L .794 .529 .538 r
F
.58333 .63456 m .58534 .63035 L .58207 .6339 L .675 .735 .895 r
F
.58215 .63672 m .58544 .63315 L .58246 .63231 L F
.58551 .63599 m .58432 .63115 L .58252 .63515 L F
.58551 .63599 m .5888 .63242 L .58432 .63115 L F
.5888 .63242 m .58873 .62958 L .58425 .62831 L .794 .529 .538 r
F
.5888 .63242 m .58425 .62831 L .58432 .63115 L F
.57936 .64289 m .59577 .62636 L .58832 .62396 L .654 .726 .902 r
F
.58082 .64113 m .58012 .64088 L .58013 .64791 L .809 .541 .533 r
F
.5807 .64812 m .58013 .64791 L .58019 .67916 L F
.58082 .64113 m .58013 .64791 L .5807 .64812 L F
.58119 .64127 m .581 .64823 L .58119 .64127 L F
.57963 .64784 m .5798 .64786 L .57995 .64085 L .734 .478 .541 r
F
.57978 .64549 m .57875 .64728 L .58038 .64715 L .675 .735 .895 r
F
.57937 .64548 m .57937 .64555 L .57907 .64551 L .642 .403 .541 r
F
.57937 .64555 m .57908 .64559 L .57907 .64551 L F
.57893 .64314 m .57883 .64562 L .57978 .64549 L .675 .735 .895 r
F
.57883 .64562 m .57875 .64728 L .57978 .64549 L F
.57937 .64555 m .57957 .6525 L .57908 .64559 L .642 .403 .541 r
F
.57975 .64082 m .57905 .64775 L .57963 .64784 L .734 .478 .541 r
F
.57975 .64072 m .57904 .64072 L .57975 .64082 L F
.57978 .63563 m .57986 .63381 L .57907 .63369 L .654 .726 .902 r
F
.57984 .63512 m .57944 .63788 L .5798 .63792 L .734 .478 .541 r
F
.57887 .64029 m .57993 .63793 L .57904 .63784 L .675 .735 .895 r
F
.5788 .63745 m .57985 .63512 L .57903 .63503 L F
.57879 .62554 m .57916 .63846 L .57881 .63849 L .642 .403 .541 r
F
.57903 .63503 m .57894 .63785 L .57904 .63784 L .66 .418 .542 r
F
.57792 .62058 m .57684 .63401 L .57769 .63379 L .569 .345 .536 r
F
.57682 .62092 m .57659 .63417 L .57684 .63401 L .404 .216 .509 r
F
.57978 .63563 m .57258 .61595 L .56498 .61755 L .654 .726 .902 r
F
.57903 .63368 m .579 .63503 L .57903 .63503 L .66 .418 .542 r
F
.579 .63503 m .57894 .63785 L .57903 .63503 L F
.5788 .63745 m .57903 .63503 L .57891 .63504 L .675 .735 .895 r
F
.57879 .63369 m .57876 .63506 L .57903 .63368 L .66 .418 .542 r
F
.5788 .63745 m .57891 .63504 L .57796 .63513 L .675 .735 .895 r
F
.57876 .63506 m .57794 .63513 L .57795 .63794 L .66 .418 .542 r
F
.57876 .63506 m .57795 .63794 L .57859 .63788 L F
.57802 .63793 m .57905 .63615 L .57742 .63628 L .675 .735 .895 r
F
.57887 .64029 m .57897 .63785 L .57802 .63793 L F
.57871 .63787 m .57881 .63786 L .57896 .63504 L .66 .418 .542 r
F
.5778 .64533 m .57883 .64562 L .5778 .64547 L .751 .492 .54 r
F
.57893 .64314 m .57788 .64548 L .57883 .64562 L .675 .735 .895 r
F
.57867 .64073 m .57797 .6478 L .57855 .64778 L .66 .418 .542 r
F
.57876 .63506 m .57841 .64075 L .57867 .64073 L F
.5786 .64222 m .57904 .64065 L .57807 .64074 L .675 .735 .895 r
F
.57895 .64274 m .57904 .64065 L .5786 .64222 L F
.57936 .64289 m .57857 .64074 L .57764 .64078 L .654 .726 .902 r
F
.57533 .64102 m .57528 .64094 L .57524 .63645 L .988 .72 .386 r
F
.57542 .63966 m .57512 .63882 L .57517 .63961 L .675 .735 .895 r
F
.57887 .64029 m .57574 .63906 L .57542 .63966 L F
.57555 .64208 m .57568 .63916 L .57562 .63928 L 0 0 .381 r
F
.57652 .63852 m .57574 .64175 L .57647 .64129 L .404 .216 .509 r
F
.57512 .63882 m .57354 .63819 L .57517 .63961 L .675 .735 .895 r
F
.5735 .63536 m .56687 .63525 L .57283 .63635 L F
.5735 .63536 m .5682 .63327 L .56687 .63525 L F
.57457 .63734 m .56821 .63609 L .57354 .63819 L F
.57025 .63157 m .56289 .63118 L .5682 .63327 L F
.57457 .63734 m .57027 .63438 L .56821 .63609 L F
.57025 .63157 m .56597 .62863 L .56289 .63118 L F
.56597 .63143 m .56591 .62859 L .56281 .63115 L .36 .191 .511 r
F
.57453 .63451 m .57025 .63157 L .5682 .63327 L .675 .735 .895 r
F
.57292 .63308 m .56597 .63143 L .57027 .63438 L F
.56995 .62947 m .56591 .62859 L .56597 .63143 L .498 .296 .535 r
F
.57681 .64108 m .57011 .63218 L .56651 .63373 L .654 .726 .902 r
F
.57001 .63231 m .56987 .63228 L .56604 .63427 L .498 .296 .535 r
F
.56987 .63228 m .56597 .63143 L .56603 .63393 L F
.56987 .63228 m .56603 .63393 L .56604 .63427 L F
.56651 .63373 m .56449 .62472 L .55787 .62757 L .654 .726 .902 r
F
.57289 .63028 m .56597 .62863 L .57025 .63157 L .675 .735 .895 r
F
.57292 .63308 m .56995 .62947 L .56597 .63143 L F
.57001 .63231 m .56995 .62947 L .56597 .63143 L .498 .296 .535 r
F
.57011 .63218 m .56449 .62472 L .56651 .63373 L .654 .726 .902 r
F
.57887 .64029 m .578 .64123 L .57811 .64137 L .675 .735 .895 r
F
.578 .64123 m .57691 .64242 L .57811 .64137 L F
.57811 .64137 m .57691 .64242 L .57726 .64258 L F
.57878 .64248 m .57751 .64063 L .57681 .64108 L .654 .726 .902 r
F
.57648 .64129 m .57668 .64116 L .57674 .63836 L .404 .216 .509 r
F
.57893 .64314 m .5786 .64222 L .57596 .63953 L .675 .735 .895 r
F
.57757 .64086 m .57768 .64084 L .57785 .63797 L .569 .345 .536 r
F
.5786 .64222 m .57807 .64074 L .57768 .64084 L .675 .735 .895 r
F
.57562 .63928 m .57568 .63916 L .57572 .63472 L 0 0 .381 r
F
.57542 .63683 m .5735 .63536 L .57283 .63635 L .675 .735 .895 r
F
.57662 .63845 m .57674 .63836 L .57681 .6355 L .404 .216 .509 r
F
.57677 .63553 m .57681 .6355 L .57684 .63401 L F
.57561 .63493 m .57559 .63651 L .57572 .63472 L 0 0 .381 r
F
.57559 .63651 m .57567 .63636 L .57572 .63472 L F
.57514 .63601 m .57453 .63451 L .5735 .63536 L .675 .735 .895 r
F
.5788 .63745 m .57621 .63567 L .57514 .63601 L F
.57621 .63567 m .57453 .63451 L .57514 .63601 L F
.5788 .63745 m .57574 .63625 L .57542 .63683 L F
.57767 .63522 m .57719 .63818 L .57762 .63804 L .569 .345 .536 r
F
.57769 .63379 m .57752 .63526 L .57767 .63522 L F
.57752 .63526 m .57719 .63818 L .57767 .63522 L F
.57662 .63845 m .57681 .6355 L .57677 .63553 L .404 .216 .509 r
F
.57574 .63625 m .57573 .63624 L .57573 .63626 L .675 .735 .895 r
F
.57574 .63625 m .57573 .63626 L .57542 .63683 L F
.57573 .63624 m .5735 .63536 L .57542 .63683 L F
.57559 .63651 m .57557 .63937 L .57567 .63636 L 0 0 .381 r
F
.57557 .63937 m .57555 .64208 L .57562 .63928 L F
.57557 .63937 m .57562 .63928 L .57572 .63472 L F
.57609 .63838 m .57589 .63669 L .57457 .63734 L .675 .735 .895 r
F
.57659 .63417 m .57573 .63907 L .57652 .63852 L .404 .216 .509 r
F
.57623 .63848 m .57618 .63821 L .57609 .63838 L .675 .735 .895 r
F
.57618 .63821 m .57589 .63669 L .57609 .63838 L F
.57685 .63828 m .57668 .64116 L .57685 .64105 L .404 .216 .509 r
F
.57684 .63401 m .57674 .63836 L .57685 .63828 L F
.57674 .63836 m .57668 .64116 L .57685 .63828 L F
.57887 .64029 m .57714 .63819 L .57685 .63828 L .675 .735 .895 r
F
.5788 .63745 m .57557 .63865 L .57582 .63911 L F
.5764 .6386 m .57685 .63828 L .57623 .63848 L F
.57887 .64029 m .57685 .63828 L .5764 .6386 L F
.57714 .63819 m .57589 .63669 L .57623 .63848 L F
.57762 .63804 m .57685 .64105 L .57757 .64086 L .569 .345 .536 r
F
.57719 .63818 m .57685 .64105 L .57762 .63804 L F
.57859 .63788 m .57795 .64075 L .57841 .64071 L .66 .418 .542 r
F
.57807 .64074 m .57806 .64072 L .57795 .64075 L .675 .735 .895 r
F
.57807 .64074 m .57795 .64075 L .57768 .64084 L F
.57887 .64029 m .57802 .63793 L .57795 .63794 L F
.57887 .64029 m .57795 .63794 L .57714 .63819 L F
.57859 .63788 m .57795 .63794 L .57795 .64075 L .66 .418 .542 r
F
.57767 .64083 m .57763 .64078 L .57878 .64248 L .654 .726 .902 r
F
.57757 .64086 m .57785 .63797 L .57772 .63801 L .569 .345 .536 r
F
.57763 .64078 m .57751 .64063 L .57761 .64078 L .654 .726 .902 r
F
.57763 .64078 m .57761 .64078 L .57878 .64248 L F
.57841 .64071 m .57795 .64075 L .57795 .64076 L .66 .418 .542 r
F
.57936 .64289 m .57764 .64078 L .57767 .64083 L .654 .726 .902 r
F
.57893 .64314 m .57294 .64203 L .57268 .6431 L .675 .735 .895 r
F
.57841 .64075 m .57795 .64076 L .57797 .6478 L .66 .418 .542 r
F
.57841 .64071 m .57795 .64076 L .57841 .64075 L F
.57768 .64084 m .57778 .64081 L .57778 .6408 L .569 .345 .536 r
F
.57768 .64084 m .57778 .6408 L .57785 .63797 L F
.57768 .64084 m .57749 .63912 L .57667 .63934 L .675 .735 .895 r
F
.57806 .64072 m .57749 .63912 L .57768 .64084 L F
.57573 .63906 m .57512 .63882 L .57542 .63966 L F
.57573 .63906 m .57505 .63767 L .57512 .63882 L F
.57561 .63493 m .5752 .64008 L .57536 .63978 L 0 0 .381 r
F
.57505 .63767 m .57457 .63734 L .57512 .63882 L .675 .735 .895 r
F
.57573 .63907 m .57565 .6419 L .57574 .64175 L 0 0 .381 r
F
.57572 .63472 m .57568 .63916 L .57573 .63907 L F
.57568 .63916 m .57565 .6419 L .57573 .63907 L F
.5764 .6386 m .57609 .63838 L .57574 .63906 L .675 .735 .895 r
F
.57609 .63838 m .57505 .63767 L .57574 .63906 L F
.57609 .63838 m .57574 .63906 L .57574 .63906 L F
.57453 .63451 m .5682 .63327 L .5735 .63536 L F
.57589 .63669 m .57027 .63438 L .57457 .63734 L F
.57751 .64063 m .56449 .62472 L .57681 .64108 L .654 .726 .902 r
F
.57647 .64136 m .57674 .63836 L .57662 .63845 L .404 .216 .509 r
F
.57767 .64083 m .57764 .64078 L .57763 .64078 L .654 .726 .902 r
F
.57647 .64129 m .57647 .64129 L .57677 .63553 L .404 .216 .509 r
F
.5786 .64222 m .57667 .63934 L .57596 .63953 L .675 .735 .895 r
F
.57936 .64289 m .57767 .64083 L .57878 .64248 L .654 .726 .902 r
F
.57555 .64208 m .57565 .6419 L .57568 .63916 L 0 0 .381 r
F
.57936 .64289 m .57646 .64083 L .57472 .6409 L .654 .726 .902 r
F
.57647 .64136 m .57668 .64122 L .57668 .64116 L .404 .216 .509 r
F
.57647 .64136 m .57668 .64116 L .57648 .64129 L F
.57772 .63801 m .57785 .63797 L .57794 .63373 L .569 .345 .536 r
F
.57714 .63819 m .57795 .63794 L .577 .63803 L .675 .735 .895 r
F
.57893 .64314 m .57895 .64274 L .5786 .64222 L F
.57841 .64075 m .57797 .6478 L .57867 .64073 L .66 .418 .542 r
F
.57794 .63373 m .57778 .64081 L .57795 .64076 L .569 .345 .536 r
F
.57763 .64078 m .57834 .64011 L .57751 .64063 L .654 .726 .902 r
F
.57807 .64074 m .57911 .63899 L .57749 .63912 L .675 .735 .895 r
F
.57857 .64074 m .57834 .64011 L .57763 .64078 L .654 .726 .902 r
F
.57897 .63785 m .57905 .63615 L .57802 .63793 L .675 .735 .895 r
F
.57876 .63506 m .57871 .63787 L .57896 .63504 L .66 .418 .542 r
F
.57871 .63787 m .57867 .64073 L .57881 .63786 L F
.57876 .63506 m .57896 .63504 L .57903 .63368 L F
.57879 .63369 m .57794 .63373 L .57794 .63513 L F
.57769 .63379 m .57767 .63522 L .57794 .63373 L .569 .345 .536 r
F
.57767 .63522 m .57787 .63515 L .57794 .63373 L F
.57796 .63513 m .57898 .63333 L .57736 .63346 L .675 .735 .895 r
F
.57879 .63369 m .57794 .63513 L .57876 .63506 L .66 .418 .542 r
F
.57891 .63504 m .57898 .63333 L .57796 .63513 L .675 .735 .895 r
F
.57891 .63504 m .57903 .63503 L .57891 .63502 L F
.57897 .63785 m .57904 .63784 L .57897 .63783 L F
.57887 .64029 m .57904 .63784 L .57897 .63785 L F
.57904 .63784 m .57887 .64067 L .57904 .64065 L .66 .418 .542 r
F
.57894 .63785 m .57887 .64067 L .57904 .63784 L F
.57933 .63506 m .57904 .64065 L .57984 .63512 L .734 .478 .541 r
F
.57897 .63783 m .58066 .6363 L .57905 .63615 L .675 .735 .895 r
F
.58116 .62099 m .58011 .63384 L .58094 .63415 L .809 .541 .533 r
F
.57978 .63563 m .58118 .63267 L .58003 .63004 L .654 .726 .902 r
F
.57987 .63381 m .57984 .63512 L .58011 .63384 L .734 .478 .541 r
F
.5788 .63745 m .58086 .63522 L .57985 .63512 L .675 .735 .895 r
F
.57984 .63512 m .57975 .64072 L .58004 .63514 L .734 .478 .541 r
F
.57984 .63512 m .58004 .63514 L .58011 .63384 L F
.58094 .63415 m .58011 .63384 L .58011 .63514 L .809 .541 .533 r
F
.57985 .63512 m .58207 .6339 L .58059 .63348 L .675 .735 .895 r
F
.58094 .63415 m .58092 .63541 L .58118 .63424 L .809 .541 .533 r
F
.58094 .63415 m .58011 .63514 L .58092 .63541 L F
.58086 .63522 m .58207 .6339 L .57985 .63512 L .675 .735 .895 r
F
.57993 .63793 m .58066 .6363 L .57897 .63783 L F
.5798 .63792 m .57904 .64065 L .57975 .64072 L .734 .478 .541 r
F
.57944 .63788 m .57904 .64065 L .5798 .63792 L F
.58009 .62062 m .57933 .63506 L .57984 .63512 L F
.57891 .63502 m .58059 .63348 L .57898 .63333 L .675 .735 .895 r
F
.57985 .63512 m .58059 .63348 L .57891 .63502 L F
.57904 .64065 m .58002 .64073 L .57905 .64041 L F
.58001 .64075 m .58002 .64073 L .57904 .64065 L F
.57905 .64041 m .58073 .63914 L .57911 .63899 L F
.58002 .64073 m .58073 .63914 L .57905 .64041 L F
.58092 .63541 m .58014 .64077 L .58082 .641 L .809 .541 .533 r
F
.57975 .64072 m .57975 .64082 L .57996 .64074 L .734 .478 .541 r
F
.57975 .64082 m .57995 .64085 L .57996 .64074 L F
.58188 .64164 m .58119 .64127 L .58188 .64181 L .909 .63 .501 r
F
.58162 .6416 m .58273 .64184 L .5818 .6415 L .654 .726 .902 r
F
.58102 .64121 m .58119 .64127 L .58119 .64112 L .809 .541 .533 r
F
.57957 .6525 m .58047 .68387 L .57933 .65252 L .642 .403 .541 r
F
.57882 .64553 m .58047 .68387 L .57889 .68408 L F
.58013 .64791 m .57911 .67903 L .58019 .67916 L .734 .478 .541 r
F
.58012 .64088 m .57994 .64788 L .58013 .64791 L F
.57895 .65016 m .5809 .64819 L .58013 .64791 L .654 .726 .902 r
F
.57895 .65016 m .57979 .65248 L .58077 .65239 L F
.57994 .64788 m .57911 .67903 L .58013 .64791 L .734 .478 .541 r
F
.58002 .6479 m .58013 .64791 L .58003 .64787 L .654 .726 .902 r
F
.57895 .65016 m .58013 .64791 L .58002 .6479 L F
.58011 .63384 m .57995 .64085 L .58012 .64088 L .734 .478 .541 r
F
.58092 .63541 m .58111 .63548 L .58118 .63424 L .809 .541 .533 r
F
.58074 .63535 m .58118 .6355 L .58084 .63524 L .675 .735 .895 r
F
.58199 .63487 m .58118 .63424 L .58118 .6355 L .909 .63 .501 r
F
.58221 .62181 m .58199 .63487 L .58223 .63505 L F
.58084 .63524 m .58333 .63456 L .58207 .6339 L .675 .735 .895 r
F
.58199 .63487 m .58118 .6355 L .58185 .636 L .909 .63 .501 r
F
.58149 .63574 m .58333 .63456 L .58084 .63524 L .675 .735 .895 r
F
.58221 .62181 m .58118 .63424 L .58199 .63487 L .909 .63 .501 r
F
.58207 .6339 m .58237 .6295 L .58059 .63348 L .675 .735 .895 r
F
.58207 .6339 m .58534 .63035 L .58237 .6295 L F
.58009 .62062 m .57987 .63381 L .58011 .63384 L .734 .478 .541 r
F
.58116 .62099 m .58094 .63415 L .58118 .63424 L .809 .541 .533 r
F
.58265 .62285 m .58221 .62181 L .58223 .63505 L .984 .727 .338 r
F
.58118 .63267 m .58869 .61679 L .58003 .63004 L .654 .726 .902 r
F
.58009 .62062 m .57903 .63368 L .5794 .63374 L .734 .478 .541 r
F
.58059 .63348 m .58237 .6295 L .57916 .62921 L .675 .735 .895 r
F
.58215 .63672 m .58246 .63231 L .58066 .6363 L F
.58066 .6363 m .58246 .63231 L .57923 .632 L F
.58534 .63035 m .58416 .62553 L .58237 .6295 L F
.58073 .63914 m .5793 .63485 L .57911 .63899 L F
.58073 .63914 m .58252 .63515 L .5793 .63485 L F
.57917 .63255 m .58066 .61569 L .57875 .63281 L .654 .726 .902 r
F
.57986 .63381 m .58066 .61569 L .57907 .63369 L F
.58003 .63004 m .58869 .61679 L .58066 .61569 L F
.58237 .6295 m .57934 .62508 L .57916 .62921 L .675 .735 .895 r
F
.58237 .6295 m .58416 .62553 L .57934 .62508 L F
.58544 .63315 m .58425 .62831 L .58246 .63231 L F
.58059 .63348 m .57916 .62921 L .57898 .63333 L F
.58246 .63231 m .57941 .62786 L .57923 .632 L F
.58246 .63231 m .58425 .62831 L .57941 .62786 L F
.5794 .63374 m .57903 .63368 L .57904 .64065 L .734 .478 .541 r
F
.58066 .6363 m .57923 .632 L .57905 .63615 L .675 .735 .895 r
F
.58252 .63515 m .57948 .6307 L .5793 .63485 L F
.58252 .63515 m .58432 .63115 L .57948 .6307 L F
.58425 .62831 m .58419 .62547 L .57934 .62502 L .731 .478 .545 r
F
.58873 .62958 m .58419 .62547 L .58425 .62831 L .794 .529 .538 r
F
.58425 .62831 m .57934 .62502 L .57941 .62786 L .731 .478 .545 r
F
.58432 .63115 m .58425 .62831 L .57941 .62786 L F
.58432 .63115 m .57941 .62786 L .57948 .6307 L F
.57936 .64289 m .58832 .62396 L .58025 .62286 L .654 .726 .902 r
F
.5791 .64667 m .5879 .63123 L .57984 .63012 L F
.57906 .64752 m .5794 .6469 L .5791 .64667 L F
.5794 .6469 m .5879 .63123 L .5791 .64667 L F
.57895 .65016 m .58003 .64787 L .57906 .64752 L F
.58215 .64202 m .58273 .64184 L .58162 .6416 L F
.58003 .64787 m .5879 .63123 L .57906 .64752 L F
.58273 .64184 m .5874 .64194 L .584 .64144 L F
.58407 .64234 m .5874 .64194 L .58273 .64184 L F
.58208 .64196 m .58193 .64887 L .58224 .64209 L .909 .63 .501 r
F
.58253 .64275 m .58224 .64209 L .58225 .64912 L .984 .727 .338 r
F
.58228 .64428 m .5822 .6444 L .5822 .6443 L .082 0 .419 r
F
.58202 .64479 m .58218 .64634 L .58238 .64505 L .654 .726 .902 r
F
.58003 .64787 m .59536 .63363 L .5879 .63123 L F
.5822 .6444 m .58228 .65133 L .58216 .64445 L .082 0 .419 r
F
.58228 .65133 m .58225 .65138 L .58216 .64445 L F
.58224 .64209 m .58193 .64887 L .58225 .64912 L .909 .63 .501 r
F
.5809 .64819 m .59536 .63363 L .58003 .64787 L .654 .726 .902 r
F
.581 .64823 m .58019 .67916 L .58101 .64823 L .809 .541 .533 r
F
.57963 .64784 m .57911 .67903 L .5798 .64786 L .734 .478 .541 r
F
.58087 .64818 m .58019 .67916 L .581 .64823 L .809 .541 .533 r
F
.58176 .64874 m .5812 .64831 L .58126 .67954 L .909 .63 .501 r
F
.57956 .65185 m .57955 .6525 L .57979 .65248 L .654 .726 .902 r
F
.57895 .65016 m .57955 .6525 L .57956 .65185 L F
.57895 .65016 m .57884 .65256 L .57955 .6525 L F
.57963 .64784 m .57905 .64775 L .57911 .67903 L .734 .478 .541 r
F
.58809 .64908 m .59767 .65048 L .60939 .64656 L .654 .726 .902 r
F
.60113 .65086 m .63273 .65836 L .60626 .647 L F
.59597 .65105 m .61022 .6518 L .6099 .64982 L F
.59597 .65105 m .6099 .64982 L .60939 .64656 L F
.56694 .64092 m .56016 .64303 L .56642 .64307 L .675 .735 .895 r
F
.56694 .64092 m .56094 .63982 L .56016 .64303 L F
.57514 .64853 m .55745 .63484 L .5523 .63873 L .654 .726 .902 r
F
.57538 .64371 m .57564 .65119 L .57544 .65083 L .988 .72 .386 r
F
.57895 .65016 m .57626 .64824 L .57514 .64853 L .654 .726 .902 r
F
.57523 .64999 m .57522 .64989 L .5752 .64271 L .779 .622 .059 r
F
.57524 .6501 m .57523 .64999 L .57521 .64283 L F
.57522 .64297 m .57526 .65052 L .57524 .6501 L F
.57438 .64604 m .57236 .65028 L .57565 .64671 L .675 .735 .895 r
F
.57284 .64418 m .56791 .64722 L .57342 .64518 L F
.57626 .64824 m .55745 .63484 L .57514 .64853 L .654 .726 .902 r
F
.57778 .64081 m .57762 .64789 L .57795 .64076 L .569 .345 .536 r
F
.57397 .64311 m .57268 .6431 L .5728 .64392 L .675 .735 .895 r
F
.57397 .64311 m .5728 .64392 L .57284 .64418 L F
.57558 .64909 m .57565 .64896 L .57574 .64175 L 0 0 .381 r
F
.57574 .64175 m .57565 .64896 L .57575 .64879 L F
.57522 .64297 m .57522 .64316 L .57521 .64283 L .779 .622 .059 r
F
.57536 .64542 m .57342 .64518 L .57438 .64604 L .675 .735 .895 r
F
.57522 .64316 m .57524 .6501 L .57521 .64302 L .779 .622 .059 r
F
.57522 .64316 m .57521 .64302 L .57521 .64283 L F
.57893 .64314 m .5753 .64448 L .57536 .64542 L .675 .735 .895 r
F
.5753 .64448 m .57342 .64518 L .57536 .64542 L F
.57539 .64393 m .57563 .64436 L .57564 .65119 L .988 .72 .386 r
F
.5755 .64923 m .57558 .64909 L .57565 .6419 L 0 0 .381 r
F
.5752 .64271 m .57522 .64989 L .57521 .64975 L .779 .622 .059 r
F
.57268 .6431 m .56675 .64521 L .57284 .64418 L .675 .735 .895 r
F
.57294 .64203 m .56642 .64307 L .57268 .6431 L F
.57294 .64203 m .56694 .64092 L .56642 .64307 L F
.56827 .63893 m .56094 .63982 L .56694 .64092 L F
.56597 .63143 m .56281 .63115 L .56288 .63399 L .36 .191 .511 r
F
.56827 .63893 m .56294 .63683 L .56094 .63982 L .675 .735 .895 r
F
.57034 .63723 m .56294 .63683 L .56827 .63893 L F
.57034 .63723 m .56604 .63427 L .56294 .63683 L F
.57251 .64557 m .56407 .63199 L .55745 .63484 L .654 .726 .902 r
F
.57531 .64359 m .57538 .65073 L .57525 .64349 L .988 .72 .386 r
F
.57538 .65073 m .57535 .65067 L .57525 .64349 L F
.57555 .64208 m .57521 .64975 L .5755 .64923 L 0 0 .381 r
F
.5736 .64103 m .56694 .64092 L .57294 .64203 L .675 .735 .895 r
F
.5736 .64103 m .56827 .63893 L .56694 .64092 L F
.57611 .64814 m .56684 .63538 L .57251 .64557 L .654 .726 .902 r
F
.57663 .6451 m .57726 .64539 L .57728 .65226 L .844 .571 .525 r
F
.57895 .65016 m .57659 .64728 L .57611 .64814 L .654 .726 .902 r
F
.57659 .64728 m .56684 .63538 L .57611 .64814 L F
.56684 .63538 m .56407 .63199 L .57251 .64557 L F
.57646 .65267 m .56995 .65922 L .57684 .65336 L F
.57538 .65073 m .57547 .6603 L .57535 .65067 L .988 .72 .386 r
F
.57762 .64789 m .57692 .67946 L .57776 .64785 L .569 .345 .536 r
F
.57797 .65153 m .5775 .64527 L .57764 .6453 L .751 .492 .54 r
F
.57762 .64789 m .57776 .64785 L .57795 .64076 L .569 .345 .536 r
F
.57797 .6478 m .57692 .67946 L .57802 .67912 L F
.57795 .64076 m .57776 .64785 L .57797 .6478 L F
.57776 .64785 m .57692 .67946 L .57797 .6478 L F
.57438 .64604 m .56983 .64895 L .57236 .65028 L .675 .735 .895 r
F
.57354 .64894 m .57386 .64798 L .57 .64814 L .654 .726 .902 r
F
.57895 .65016 m .57514 .64853 L .57354 .64894 L F
.57514 .64853 m .57386 .64798 L .57354 .64894 L F
.57342 .64518 m .56791 .64722 L .56983 .64895 L .675 .735 .895 r
F
.56642 .64307 m .56066 .64625 L .56675 .64521 L F
.57386 .64798 m .5523 .63873 L .57 .64814 L .654 .726 .902 r
F
.57936 .64289 m .5742 .64173 L .57248 .64218 L F
.57893 .64314 m .5736 .64103 L .57294 .64203 L .675 .735 .895 r
F
.57867 .64073 m .57855 .64778 L .57887 .64073 L .66 .418 .542 r
F
.57895 .65016 m .57789 .65238 L .57884 .65256 L .654 .726 .902 r
F
.57797 .6524 m .57889 .68408 L .57798 .65868 L .751 .492 .54 r
F
.57855 .64778 m .57802 .67912 L .57872 .64777 L .66 .418 .542 r
F
.57855 .64778 m .57872 .64777 L .57887 .64073 L F
.57635 .64841 m .57575 .64879 L .5758 .68024 L .404 .216 .509 r
F
.57647 .64129 m .57575 .64879 L .57635 .64841 L F
.57399 .6499 m .57192 .64936 L .57052 .64972 L .654 .726 .902 r
F
.5744 .64964 m .57192 .64936 L .57399 .6499 L F
.57192 .64936 m .56366 .64841 L .57052 .64972 L F
.57662 .64491 m .57726 .64523 L .57726 .64539 L .844 .571 .525 r
F
.57893 .64314 m .57599 .64502 L .57645 .64584 L .675 .735 .895 r
F
.57757 .64086 m .57685 .64105 L .57687 .64808 L .569 .345 .536 r
F
.57895 .65016 m .5762 .65173 L .57699 .65212 L .654 .726 .902 r
F
.57646 .65267 m .57684 .65336 L .57789 .65238 L F
.57675 .652 m .57728 .65226 L .57733 .68382 L .844 .571 .525 r
F
.57745 .64793 m .57687 .64808 L .57692 .67946 L .569 .345 .536 r
F
.57757 .64086 m .57687 .64808 L .57745 .64793 L F
.57517 .63961 m .57354 .63819 L .57287 .63919 L .675 .735 .895 r
F
.57522 .64297 m .57521 .64283 L .57519 .63568 L .779 .622 .059 r
F
.57519 .63568 m .57521 .64283 L .5752 .64271 L F
.57536 .63978 m .5752 .64008 L .5752 .64271 L 0 0 .381 r
F
.57027 .63438 m .56288 .63399 L .56821 .63609 L .675 .735 .895 r
F
.57646 .64083 m .55787 .62757 L .57472 .6409 L .654 .726 .902 r
F
.57867 .64073 m .57887 .64073 L .57903 .63368 L .66 .418 .542 r
F
.57647 .64129 m .57647 .64136 L .57647 .64129 L .404 .216 .509 r
F
.57584 .63387 m .57025 .63157 L .57453 .63451 L .675 .735 .895 r
F
.57584 .63387 m .57289 .63028 L .57025 .63157 L F
.57589 .63669 m .57292 .63308 L .57027 .63438 L F
.57742 .63628 m .57292 .63308 L .57589 .63669 L F
.57289 .63028 m .56993 .62669 L .56597 .62863 L F
.57593 .62947 m .56993 .62669 L .57289 .63028 L F
.57749 .63912 m .57604 .63511 L .57417 .63561 L F
.56995 .62947 m .56988 .62663 L .56591 .62859 L .498 .296 .535 r
F
.57749 .64055 m .56659 .62428 L .56449 .62472 L .654 .726 .902 r
F
.57566 .63782 m .57417 .63561 L .57299 .63592 L .675 .735 .895 r
F
.57749 .63912 m .57417 .63561 L .57566 .63782 L F
.57751 .64063 m .57749 .64055 L .56449 .62472 L .654 .726 .902 r
F
.57598 .63227 m .56995 .62947 L .57292 .63308 L .675 .735 .895 r
F
.57736 .63346 m .57593 .62947 L .57289 .63028 L F
.57598 .63227 m .57453 .62826 L .56995 .62947 L F
.57453 .62826 m .56988 .62663 L .56995 .62947 L .592 .368 .545 r
F
.57593 .62947 m .57449 .62547 L .56993 .62669 L .675 .735 .895 r
F
.57453 .62826 m .57447 .62541 L .56988 .62663 L .592 .368 .545 r
F
.57659 .63417 m .57657 .63567 L .57684 .63401 L .404 .216 .509 r
F
.57736 .63346 m .57289 .63028 L .57584 .63387 L .675 .735 .895 r
F
.57742 .63628 m .57598 .63227 L .57292 .63308 L F
.57604 .63511 m .5746 .6311 L .57001 .63231 L F
.5746 .6311 m .56995 .62947 L .57001 .63222 L .592 .368 .545 r
F
.57167 .63187 m .57001 .63222 L .57001 .63231 L F
.5746 .6311 m .57001 .63222 L .57167 .63187 L F
.57167 .63187 m .57212 .62311 L .56659 .62428 L .654 .726 .902 r
F
.57604 .63511 m .57001 .63231 L .57299 .63592 L .675 .735 .895 r
F
.57749 .64055 m .57463 .63125 L .57167 .63187 L .654 .726 .902 r
F
.5746 .6311 m .57453 .62826 L .56995 .62947 L .592 .368 .545 r
F
.57463 .63125 m .57212 .62311 L .57167 .63187 L .654 .726 .902 r
F
.577 .63803 m .57742 .63628 L .57589 .63669 L .675 .735 .895 r
F
.57705 .63533 m .57736 .63346 L .57584 .63387 L F
.57712 .63528 m .57736 .63346 L .57705 .63533 L F
.57796 .63513 m .57736 .63346 L .5771 .63539 L F
.5771 .63539 m .57712 .63528 L .57705 .63533 L F
.57905 .63615 m .57598 .63227 L .57742 .63628 L F
.5793 .63485 m .5746 .6311 L .57604 .63511 L F
.57834 .64011 m .57212 .62311 L .57751 .64063 L .654 .726 .902 r
F
.57767 .63522 m .57762 .63804 L .57787 .63515 L .569 .345 .536 r
F
.57762 .63804 m .57757 .64086 L .57772 .63801 L F
.57762 .63804 m .57772 .63801 L .57787 .63515 L F
.57795 .63794 m .57742 .63628 L .577 .63803 L .675 .735 .895 r
F
.57802 .63793 m .57801 .63792 L .57795 .63794 L F
.57801 .63792 m .57742 .63628 L .57795 .63794 L F
.5778 .64547 m .57883 .64562 L .57884 .65256 L .751 .492 .54 r
F
.578 .6524 m .57889 .68408 L .57797 .6524 L F
.57855 .64778 m .57797 .6478 L .57802 .67912 L .66 .418 .542 r
F
.56146 .64501 m .54982 .64801 L .55185 .65149 L .654 .726 .902 r
F
.56366 .64841 m .54815 .64664 L .55848 .64863 L F
.56366 .64841 m .55848 .64863 L .56171 .64926 L F
.57629 .65177 m .57629 .65178 L .5763 .65783 L .928 .648 .489 r
F
.57629 .65177 m .5763 .65783 L .57635 .68335 L F
.57594 .65146 m .57629 .65177 L .57635 .68335 L F
.57635 .64841 m .5758 .68024 L .57652 .6483 L .404 .216 .509 r
F
.57635 .64841 m .57652 .6483 L .57668 .64122 L F
.5744 .64964 m .57354 .64894 L .57192 .64936 L .654 .726 .902 r
F
.57499 .64927 m .57354 .64894 L .5744 .64964 L F
.57354 .64894 m .57 .64814 L .57192 .64936 L F
.57757 .64086 m .57745 .64793 L .57778 .64081 L .569 .345 .536 r
F
.57745 .64793 m .57692 .67946 L .57762 .64789 L F
.57745 .64793 m .57762 .64789 L .57778 .64081 L F
.57904 .64065 m .57911 .63899 L .57807 .64074 L .675 .735 .895 r
F
.57904 .64065 m .57872 .64777 L .57905 .64775 L .66 .418 .542 r
F
.57887 .64067 m .57872 .64777 L .57904 .64065 L F
.57872 .64777 m .57802 .67912 L .57905 .64775 L F
.56146 .64501 m .54894 .6465 L .54982 .64801 L .654 .726 .902 r
F
.56366 .64841 m .54897 .6434 L .54815 .64664 L F
.56066 .64625 m .56234 .64642 L .56241 .64926 L .987 .712 .382 r
F
.56675 .64521 m .56241 .64926 L .56791 .64722 L .675 .735 .895 r
F
.56675 .64521 m .56066 .64625 L .56241 .64926 L F
.57 .64814 m .54897 .6434 L .56366 .64841 L .654 .726 .902 r
F
.56171 .64926 m .54815 .64664 L .54768 .64852 L F
.57901 .62049 m .57879 .63369 L .57903 .63368 L .66 .418 .542 r
F
.57901 .62049 m .57794 .63373 L .57879 .63369 L F
.57526 .64376 m .57397 .64311 L .57284 .64418 L .675 .735 .895 r
F
.57522 .64312 m .57397 .64311 L .57526 .64376 L F
.57668 .64116 m .57652 .6483 L .57685 .64105 L .404 .216 .509 r
F
.57652 .6483 m .5758 .68024 L .57666 .64821 L F
.57652 .6483 m .57666 .64821 L .57685 .64105 L F
.57399 .6499 m .5723 .64981 L .57332 .65032 L .654 .726 .902 r
F
.57399 .6499 m .57332 .65032 L .57416 .65073 L F
.5723 .64981 m .54768 .64852 L .57416 .65073 L F
.57687 .64808 m .5758 .68024 L .57692 .67946 L .404 .216 .509 r
F
.57685 .64105 m .57666 .64821 L .57687 .64808 L F
.57629 .65178 m .5768 .65223 L .57699 .65212 L .654 .726 .902 r
F
.57666 .64821 m .5758 .68024 L .57687 .64808 L .404 .216 .509 r
F
.57526 .65052 m .57547 .6603 L .57531 .67709 L .988 .72 .386 r
F
.57535 .65067 m .57547 .6603 L .57526 .65052 L F
.57565 .6419 m .57558 .64909 L .57574 .64175 L 0 0 .381 r
F
.57544 .65083 m .57569 .68276 L .57538 .65073 L .988 .72 .386 r
F
.57558 .64909 m .57527 .68126 L .57565 .64896 L 0 0 .381 r
F
.57544 .65083 m .57564 .65119 L .57569 .68276 L .988 .72 .386 r
F
.57547 .6603 m .57569 .68276 L .57531 .67709 L F
.57531 .67709 m .57569 .68276 L .57531 .68207 L F
.57575 .64879 m .57527 .68126 L .5758 .68024 L 0 0 .381 r
F
.57565 .64896 m .57527 .68126 L .57575 .64879 L F
.57555 .64208 m .5755 .64923 L .57565 .6419 L F
.5755 .64923 m .57527 .68126 L .57558 .64909 L F
.56995 .65922 m .56255 .66667 L .5693 .66038 L .654 .726 .902 r
F
.56995 .65922 m .5693 .66038 L .57684 .65336 L F
.57521 .64283 m .57523 .64999 L .5752 .64271 L .779 .622 .059 r
F
.57523 .64999 m .57531 .68207 L .57522 .64989 L F
.57521 .64975 m .57531 .68207 L .57527 .68126 L F
.57522 .64989 m .57531 .68207 L .57521 .64975 L F
.57568 .65706 m .5693 .66038 L .57 .66906 L .654 .726 .902 r
F
.57554 .65482 m .5693 .66038 L .57568 .65706 L F
.57555 .64208 m .5752 .64271 L .57521 .64975 L 0 0 .381 r
F
.57524 .6501 m .57531 .68207 L .57523 .64999 L .779 .622 .059 r
F
.57524 .6501 m .57526 .65052 L .57531 .68207 L F
.5755 .64923 m .57521 .64975 L .57527 .68126 L 0 0 .381 r
F
.5693 .66038 m .56255 .66667 L .56532 .66756 L .654 .726 .902 r
F
.5693 .66038 m .56532 .66756 L .57 .66906 L F
.57792 .62058 m .57769 .63379 L .57794 .63373 L .569 .345 .536 r
F
.57875 .63281 m .58066 .61569 L .57258 .61595 L .654 .726 .902 r
F
.57907 .63369 m .57917 .63255 L .57875 .63281 L F
.57995 .64085 m .57911 .67903 L .58012 .64088 L .734 .478 .541 r
F
.58575 .64627 m .58782 .64739 L .6017 .63715 L .654 .726 .902 r
F
.58162 .64863 m .58453 .64805 L .58575 .64627 L F
.58453 .64805 m .58782 .64739 L .58575 .64627 L F
.58228 .65133 m .58263 .6822 L .58225 .65138 L .082 0 .419 r
F
.58176 .64874 m .58126 .67954 L .58193 .64887 L .909 .63 .501 r
F
.58226 .64913 m .58782 .64739 L .58162 .64863 L .654 .726 .902 r
F
.58782 .64739 m .60648 .64156 L .60176 .63721 L F
.58782 .64739 m .60176 .63721 L .6017 .63715 L F
.58177 .6518 m .5822 .68288 L .58166 .65188 L .361 .183 .5 r
F
.58368 .65041 m .60891 .65692 L .61022 .6518 L .654 .726 .902 r
F
.58282 .65103 m .60891 .65692 L .58368 .65041 L F
.58225 .64912 m .58126 .67954 L .58231 .68035 L .909 .63 .501 r
F
.58193 .64887 m .58126 .67954 L .58225 .64912 L F
.58235 .65124 m .58258 .6509 L .58263 .6822 L .082 0 .419 r
F
.58263 .65054 m .5827 .65013 L .58275 .68139 L 0 0 .148 r
F
.58263 .65054 m .58275 .68139 L .58261 .65066 L F
.58261 .65066 m .58275 .68139 L .5826 .65076 L F
.58258 .6509 m .58275 .68139 L .58263 .6822 L F
.5826 .65076 m .58275 .68139 L .58258 .6509 L F
.5827 .65013 m .58231 .68035 L .58275 .68139 L .984 .727 .338 r
F
.58261 .64995 m .58231 .68035 L .5827 .65013 L F
.58358 .65215 m .60042 .66547 L .60557 .66158 L .654 .726 .902 r
F
.58214 .65153 m .5839 .65287 L .58358 .65215 L F
.5839 .65287 m .60042 .66547 L .58358 .65215 L F
.58249 .64966 m .58243 .66009 L .58258 .64986 L .984 .727 .338 r
F
.58235 .65124 m .58263 .6822 L .58228 .65133 L .082 0 .419 r
F
.58243 .66009 m .58231 .68035 L .58258 .64986 L .984 .727 .338 r
F
.58258 .64986 m .58231 .68035 L .58261 .64995 L F
.58249 .64966 m .58225 .64912 L .58231 .68035 L F
.58232 .65256 m .5938 .66831 L .60042 .66547 L .654 .726 .902 r
F
.58227 .65287 m .5938 .66831 L .58232 .65256 L F
.49328 .78059 m .49296 .77494 L .49097 .76328 L .831 .627 .078 r
F
0 g
.49145 .78063 m
.49267 .77604 L
s
.46772 .7754 m .49259 .77494 L .49061 .76334 L .673 .758 .914 r
F
.63273 .65836 m .66918 .65581 L .63939 .64908 L .654 .726 .902 r
F
.60626 .647 m .63273 .65836 L .63939 .64908 L F
.48708 .67121 m .48751 .66395 L .46849 .6534 L .857 .601 .551 r
F
0 g
.48751 .66395 m
.49169 .66779 L
s
.127 .923 .03 r
.35362 .78201 m
.35362 .78317 L
s
.38883 .68115 m .37385 .66302 L .35408 .67154 L .654 .726 .902 r
F
.40405 .67795 m .37385 .66302 L .38883 .68115 L F
.43683 .67237 m .42149 .65016 L .42071 .67017 L F
.43683 .67237 m .44568 .65348 L .42149 .65016 L F
.4513 .68442 m .44525 .66075 L .43639 .67964 L F
.4513 .68442 m .46762 .66793 L .44525 .66075 L F
.44226 .78543 m .46828 .78106 L .44329 .78152 L .673 .758 .914 r
F
.67634 .64645 m .6957 .64974 L .6953 .65701 L .858 .601 .55 r
F
.67634 .64645 m .67675 .63919 L .6957 .64974 L F
0 g
.6957 .64974 m
.70088 .65141 L
s
.127 .923 .03 r
.65811 .67119 m
.65813 .67051 L
s
.74238 .65476 m .74137 .67476 L .76573 .67398 L .654 .726 .902 r
F
.72626 .65255 m .74137 .67476 L .74238 .65476 L F
.72626 .65255 m .71722 .67144 L .74137 .67476 L F
.127 .923 .03 r
.48027 .67493 m
.48028 .67433 L
s
.78903 .66191 m .78942 .65465 L .80933 .64613 L .496 .29 .53 r
F
0 g
.77889 .65686 m
.78942 .65465 L
s
.69976 .62605 m .69595 .6495 L .71234 .63306 L .654 .726 .902 r
F
.69976 .62605 m .67709 .63899 L .69595 .6495 L F
.46772 .7754 m .49061 .76334 L .46639 .76767 L .673 .758 .914 r
F
.44285 .77586 m .46772 .7754 L .46639 .76767 L F
.2934 .64958 m .29959 .67326 L .30834 .65436 L .654 .726 .902 r
F
.2934 .64958 m .27718 .66609 L .29959 .67326 L F
0 g
.29959 .67326 m
.32377 .67657 L
s
.77454 .63632 m .7892 .65438 L .80901 .6459 L .654 .726 .902 r
F
.75934 .63951 m .7892 .65438 L .77454 .63632 L F
.32448 .65658 m .3481 .6758 L .34071 .65606 L F
0 g
.34647 .67731 m
.35408 .67154 L
s
.3936 .7881 m .36996 .79633 L .39428 .79199 L .673 .758 .915 r
F
.3936 .7881 m .36859 .78857 L .36996 .79633 L F
.44285 .77586 m .46639 .76767 L .44219 .772 L .673 .758 .914 r
F
.71138 .64776 m .71722 .67144 L .72626 .65255 L .654 .726 .902 r
F
.71138 .64776 m .6949 .66427 L .71722 .67144 L F
0 g
.71722 .67144 m
.74137 .67476 L
s
.76573 .67398 m .78903 .66191 L .78865 .66917 L .593 .371 .547 r
F
.75863 .65424 m .76573 .67398 L .78865 .66917 L .654 .726 .902 r
F
.74238 .65476 m .76573 .67398 L .75863 .65424 L F
0 g
.74137 .67476 m
.76573 .67398 L
s
.41798 .77632 m .40613 .76356 L .40087 .76604 L .673 .758 .914 r
F
.41798 .77632 m .4122 .76195 L .40613 .76356 L F
.49328 .78059 m .49097 .76328 L .49128 .76894 L .831 .627 .078 r
F
.46828 .78106 m .49328 .78059 L .49128 .76894 L .673 .758 .914 r
F
.49359 .78626 m .49328 .78059 L .49128 .76894 L .831 .627 .078 r
F
0 g
.49177 .78629 m
.49298 .7817 L
s
.25809 .65553 m .27764 .65882 L .27718 .66609 L .856 .601 .552 r
F
.25809 .65553 m .25855 .64827 L .27764 .65882 L F
.28112 .63527 m .27764 .65882 L .29386 .64231 L .654 .726 .902 r
F
.28112 .63527 m .25855 .64827 L .27764 .65882 L F
0 g
.27764 .65882 m
.28272 .66045 L
s
.44257 .79109 m .4686 .78672 L .4436 .78718 L .673 .758 .915 r
F
.127 .923 .03 r
.35364 .78722 m
.35365 .78884 L
s
.39413 .77288 m .36824 .77724 L .39311 .77678 L .673 .758 .914 r
F
.46828 .78106 m .49128 .76894 L .46695 .77329 L F
.44329 .78152 m .46828 .78106 L .46695 .77329 L F
.54894 .6465 m .52436 .66007 L .55185 .65149 L .654 .726 .902 r
F
.54894 .6465 m .51852 .6501 L .52436 .66007 L F
.63259 .66574 m .66922 .66317 L .63928 .65642 L F
.60598 .65432 m .63259 .66574 L .63928 .65642 L F
.60083 .6582 m .63259 .66574 L .60598 .65432 L F
.48556 .63799 m .48855 .64643 L .48812 .65369 L .921 .741 .253 r
F
.48556 .63799 m .48599 .63072 L .48855 .64643 L F
0 g
.48855 .64643 m
.4925 .65318 L
s
.51757 .63237 m .489 .64638 L .51925 .6428 L .654 .726 .902 r
F
.51757 .63237 m .48646 .63075 L .489 .64638 L F
.48708 .67121 m .46849 .6534 L .46806 .66066 L .857 .601 .551 r
F
.48665 .67847 m .48708 .67121 L .46806 .66066 L F
0 g
.48708 .67121 m
.49929 .68241 L
s
.40405 .67795 m .39669 .6582 L .37385 .66302 L .654 .726 .902 r
F
.42027 .67743 m .39669 .6582 L .40405 .67795 L F
.43639 .67964 m .42105 .65743 L .42027 .67743 L F
.43639 .67964 m .44525 .66075 L .42105 .65743 L F
.32613 .53346 m .32749 .59167 L .32591 .59187 L .641 .402 .541 r
F
.32613 .53346 m .32771 .53326 L .32749 .59167 L F
.32457 .5332 m .32613 .53346 L .32591 .59187 L .751 .492 .54 r
F
0 g
.32613 .53346 m
.32613 .53346 L
s
.67284 .64321 m .67675 .63919 L .67634 .64645 L .928 .669 .526 r
F
.66203 .63323 m .67314 .63773 L .67284 .64321 L F
.67314 .63773 m .67675 .63919 L .67284 .64321 L F
.66922 .66317 m .66963 .65591 L .67283 .64341 L 0 0 .156 r
F
.66203 .63323 m .66244 .62597 L .67675 .63919 L .928 .669 .526 r
F
.69027 .61728 m .67709 .63899 L .69976 .62605 L .654 .726 .902 r
F
.69027 .61728 m .66285 .62584 L .67709 .63899 L F
.6896 .62463 m .66203 .63323 L .67634 .64645 L F
.67275 .64476 m .67283 .64341 L .67356 .64054 L 0 0 .156 r
F
.66922 .66317 m .67283 .64341 L .67275 .64476 L F
0 g
.66508 .66224 m
.66963 .65591 L
s
.67594 .65371 m .6953 .65701 L .6949 .66427 L .858 .601 .55 r
F
.67594 .65371 m .67634 .64645 L .6953 .65701 L F
.69913 .63345 m .6953 .65701 L .71177 .64049 L .654 .726 .902 r
F
.69913 .63345 m .67634 .64645 L .6953 .65701 L F
0 g
.6953 .65701 m
.70048 .65867 L
s
.67974 .64086 m
.68298 .64266 L
s
.37027 .76944 m .34337 .7777 L .36824 .77724 L .673 .758 .914 r
F
.39413 .77288 m .37027 .76944 L .36824 .77724 L F
.63939 .64908 m .66918 .65581 L .67244 .64305 L .654 .726 .902 r
F
.63939 .64908 m .67244 .64305 L .67043 .64119 L F
.67274 .64499 m .67595 .64629 L .67244 .65048 L .928 .669 .526 r
F
.67595 .64629 m .67634 .64645 L .67633 .64664 L F
.67595 .64629 m .67633 .64664 L .67594 .65371 L F
.6896 .62463 m .67634 .64645 L .69913 .63345 L .654 .726 .902 r
F
.6892 .63189 m .67615 .63596 L .67594 .65371 L F
.67246 .6504 m .67356 .64054 L .67317 .64761 L 0 0 .156 r
F
.67275 .64476 m .67356 .64054 L .67243 .65067 L F
.63939 .64908 m .67043 .64119 L .64199 .63889 L .654 .726 .902 r
F
.67043 .64119 m .67309 .64051 L .66949 .64032 L F
.67043 .64119 m .66949 .64032 L .64199 .63889 L F
.67595 .64629 m .66203 .63323 L .67634 .64645 L .928 .669 .526 r
F
.66202 .63342 m .66203 .63323 L .67595 .64629 L F
.65334 .61824 m .66244 .62597 L .66203 .63323 L .99 .743 .456 r
F
.68452 .60733 m .66285 .62584 L .69027 .61728 L .654 .726 .902 r
F
.68381 .61463 m .66203 .63323 L .6896 .62463 L F
.66006 .63005 m .67309 .64051 L .67065 .62487 L F
.64199 .63889 m .66591 .64014 L .66006 .63005 L F
.66179 .63302 m .66203 .63323 L .66202 .63342 L .99 .743 .456 r
F
.66591 .64014 m .67309 .64051 L .66006 .63005 L .654 .726 .902 r
F
.64199 .63889 m .66006 .63005 L .64035 .62846 L F
.66179 .63302 m .65334 .61824 L .66203 .63323 L .99 .743 .456 r
F
.65334 .61824 m .65375 .61097 L .66244 .62597 L F
.68452 .60733 m .6542 .61092 L .66285 .62584 L .654 .726 .902 r
F
.68381 .61463 m .65334 .61824 L .66203 .63323 L F
.66006 .63005 m .67065 .62487 L .65794 .62637 L F
.66006 .63005 m .65794 .62637 L .64035 .62846 L F
.65333 .61843 m .65334 .61824 L .66179 .63302 L .99 .743 .456 r
F
.68289 .59688 m .6542 .61092 L .68452 .60733 L .654 .726 .902 r
F
.68218 .60413 m .65334 .61824 L .68381 .61463 L F
.65087 .60249 m .65375 .61097 L .65334 .61824 L .915 .736 .243 r
F
.65087 .60249 m .65128 .59522 L .65375 .61097 L F
.68289 .59688 m .65175 .59525 L .6542 .61092 L .654 .726 .902 r
F
.68218 .60413 m .65087 .60249 L .65334 .61824 L F
.65318 .61748 m .67065 .62487 L .66201 .60994 L F
.64035 .62846 m .65464 .62677 L .65318 .61748 L F
.65327 .61801 m .65334 .61824 L .65333 .61843 L .915 .736 .243 r
F
.65464 .62677 m .67065 .62487 L .65318 .61748 L .654 .726 .902 r
F
.64035 .62846 m .65318 .61748 L .63458 .61851 L F
.65318 .61748 m .66201 .60994 L .65247 .61292 L F
.65318 .61748 m .65247 .61292 L .63458 .61851 L F
.65327 .61801 m .65087 .60249 L .65334 .61824 L .915 .736 .243 r
F
.65086 .60268 m .65087 .60249 L .65327 .61801 L F
.63458 .61851 m .64789 .61435 L .64774 .59675 L .654 .726 .902 r
F
.68551 .58664 m .65175 .59525 L .68289 .59688 L F
.68481 .59384 m .65087 .60249 L .68218 .60413 L F
.68551 .58664 m .65566 .57989 L .65175 .59525 L F
.68481 .59384 m .65481 .58706 L .65087 .60249 L F
.64789 .61435 m .66201 .60994 L .65149 .60022 L F
.65097 .60227 m .65087 .60249 L .65086 .60268 L 0 0 .154 r
F
.64789 .61435 m .65149 .60022 L .64774 .59675 L .654 .726 .902 r
F
.65047 .60976 m .65327 .61801 L .65294 .6255 L .915 .736 .243 r
F
.65327 .61801 m .65333 .61843 L .65294 .6255 L F
.65294 .6255 m .65333 .61843 L .66179 .63302 L .99 .743 .456 r
F
.66498 .61961 m .65047 .60976 L .65294 .6255 L .654 .726 .902 r
F
.66174 .61662 m .66242 .60981 L .6516 .59981 L .928 .669 .526 r
F
.66203 .61689 m .66242 .60981 L .66174 .61662 L F
.66202 .61708 m .6516 .59981 L .6515 .60159 L F
.67048 .63149 m .67111 .62481 L .66242 .60981 L .99 .743 .456 r
F
.66611 .62394 m .65294 .6255 L .67104 .63245 L .654 .726 .902 r
F
.6707 .63208 m .67072 .63189 L .67048 .63149 L .99 .743 .456 r
F
.67072 .63189 m .67111 .62481 L .67048 .63149 L F
.65294 .6255 m .66179 .63302 L .66163 .64049 L F
.66179 .63302 m .66202 .63342 L .66163 .64049 L F
.66163 .64049 m .66202 .63342 L .67595 .64629 L .928 .669 .526 r
F
.67104 .63245 m .65294 .6255 L .66163 .64049 L .654 .726 .902 r
F
.67048 .63149 m .66242 .60981 L .66203 .61689 L .99 .743 .456 r
F
.68178 .6114 m .65294 .6255 L .68341 .62189 L .654 .726 .902 r
F
.6707 .63208 m .67048 .63149 L .66202 .61708 L .99 .743 .456 r
F
.67048 .63149 m .66203 .61689 L .66202 .61708 L F
.68178 .6114 m .65813 .61016 L .66498 .61961 L .654 .726 .902 r
F
.65047 .60976 m .65086 .60268 L .65327 .61801 L .915 .736 .243 r
F
.6512 .60688 m .65097 .60227 L .65047 .60976 L 0 0 .154 r
F
.65153 .60097 m .65097 .60227 L .6512 .60688 L F
.65097 .60227 m .65086 .60268 L .65047 .60976 L F
.65455 .60997 m .65047 .60976 L .66498 .61961 L .654 .726 .902 r
F
.66164 .61653 m .64808 .59656 L .64769 .60363 L .928 .669 .526 r
F
.68441 .60111 m .6544 .59433 L .65047 .60976 L .654 .726 .902 r
F
.66202 .61708 m .66164 .61653 L .64768 .60383 L .928 .669 .526 r
F
.66164 .61653 m .64769 .60363 L .64768 .60383 L F
.68441 .60111 m .65348 .60899 L .68178 .6114 L .654 .726 .902 r
F
.65348 .60899 m .65047 .60976 L .65455 .60997 L F
.65348 .60899 m .65455 .60997 L .68178 .6114 L F
.65813 .61016 m .65455 .60997 L .66203 .61689 L F
.65813 .61016 m .66203 .61689 L .66498 .61961 L F
.68341 .62189 m .66611 .62394 L .67104 .63245 L F
.66202 .61708 m .66203 .61689 L .66174 .61662 L .928 .669 .526 r
F
.6515 .60159 m .6516 .59981 L .64808 .59656 L F
.6544 .59433 m .65153 .60097 L .6512 .60688 L 0 0 .154 r
F
.66163 .64049 m .67274 .64499 L .67244 .65048 L .928 .669 .526 r
F
.67043 .64119 m .67244 .64305 L .67309 .64051 L .654 .726 .902 r
F
.6731 .64719 m .67356 .64054 L .67111 .62481 L .915 .736 .242 r
F
.67158 .63739 m .66163 .64049 L .67317 .64761 L .654 .726 .902 r
F
.67316 .6478 m .67317 .64761 L .6731 .64719 L .915 .736 .242 r
F
.67317 .64761 m .67356 .64054 L .6731 .64719 L F
.67317 .64761 m .66163 .64049 L .67244 .65048 L .654 .726 .902 r
F
.67615 .63596 m .67158 .63739 L .67317 .64761 L F
.67244 .65048 m .67595 .64629 L .67594 .65371 L .928 .669 .526 r
F
.67615 .63596 m .67244 .65048 L .67594 .65371 L .654 .726 .902 r
F
.67243 .65067 m .67246 .6504 L .67316 .6478 L 0 0 .156 r
F
.67246 .6504 m .67317 .64761 L .67316 .6478 L F
.66922 .66317 m .67275 .64476 L .67243 .65067 L F
.44329 .78152 m .46695 .77329 L .44262 .77763 L .673 .758 .914 r
F
.32771 .53326 m .32851 .59123 L .32749 .59167 L .517 .303 .528 r
F
.32771 .53326 m .32873 .53282 L .32851 .59123 L F
0 g
.32613 .53346 m
.32771 .53326 L
s
.32457 .5332 m .32591 .59187 L .32435 .59161 L .751 .492 .54 r
F
.32359 .53273 m .32457 .5332 L .32435 .59161 L .844 .572 .526 r
F
0 g
.32457 .5332 m
.32613 .53346 L
s
.78903 .66191 m .80933 .64613 L .80895 .65339 L .496 .29 .53 r
F
.78865 .66917 m .78903 .66191 L .80895 .65339 L F
.7743 .64376 m .78903 .66191 L .80895 .65339 L .654 .726 .902 r
F
.75902 .64697 m .78903 .66191 L .7743 .64376 L F
0 g
.7785 .66412 m
.78903 .66191 L
s
.127 .923 .03 r
.65606 .73624 m
.65791 .67745 L
s
.32873 .53282 m .32921 .59067 L .32851 .59123 L .356 .178 .497 r
F
.32873 .53282 m .32943 .53225 L .32921 .59067 L F
0 g
.32771 .53326 m
.32873 .53282 L
s
.32359 .53273 m .32435 .59161 L .32336 .59114 L .844 .572 .526 r
F
.32293 .53213 m .32359 .53273 L .32336 .59114 L .927 .648 .492 r
F
0 g
.32359 .53273 m
.32457 .5332 L
s
.37027 .76944 m .3464 .766 L .34337 .7777 L .673 .758 .914 r
F
.34634 .77161 m .34299 .7777 L .34329 .78337 L 0 0 .318 r
F
0 g
.34371 .78176 m
.34399 .78335 L
s
.34634 .77161 m .34604 .76595 L .34299 .7777 L 0 0 .318 r
F
.41829 .78198 m .41248 .76754 L .40638 .76916 L .673 .758 .914 r
F
0 g
.4154 .7842 m
.4154 .78126 L
s
.49359 .78626 m .49128 .76894 L .4916 .7746 L .831 .627 .078 r
F
.127 .923 .03 r
.40135 8.82751 m
.58706 2.92802 L
s
.4686 .78672 m .49359 .78626 L .4916 .7746 L .673 .758 .915 r
F
0 g
.49047 .79799 m
.49359 .78626 L
s
.32943 .53225 m .32964 .58999 L .32921 .59067 L .071 0 .412 r
F
.32943 .53225 m .32986 .53157 L .32964 .58999 L F
0 g
.32873 .53282 m
.32943 .53225 L
s
.42027 .67743 m .42105 .65743 L .39669 .6582 L .654 .726 .902 r
F
.32293 .53213 m .32336 .59114 L .3227 .59055 L .927 .648 .492 r
F
.32255 .53144 m .32293 .53213 L .3227 .59055 L .989 .721 .393 r
F
0 g
.32293 .53213 m
.32359 .53273 L
s
.127 .923 .03 r
.37393 .61583 m
.37398 .63289 L
s
.44219 .772 m .46176 .76052 L .43987 .76842 L .673 .758 .914 r
F
.44219 .772 m .46639 .76767 L .46176 .76052 L F
.74382 .53163 m .74571 .58984 L .74412 .59005 L .642 .403 .541 r
F
.74382 .53163 m .7454 .53143 L .74571 .58984 L F
.74226 .53137 m .74382 .53163 L .74412 .59005 L .751 .492 .54 r
F
0 g
.74382 .53163 m
.74382 .53163 L
s
.32986 .53157 m .32975 .58918 L .32964 .58999 L 0 0 .131 r
F
.32986 .53157 m .32997 .53076 L .32975 .58918 L F
0 g
.32943 .53225 m
.32986 .53157 L
s
.32255 .53144 m .3227 .59055 L .32232 .58985 L .989 .721 .393 r
F
.32249 .53063 m .32255 .53144 L .32232 .58985 L .794 .634 .076 r
F
0 g
.32255 .53144 m
.32293 .53213 L
s
.7454 .53143 m .74673 .58941 L .74571 .58984 L .519 .306 .53 r
F
.7454 .53143 m .74642 .53099 L .74673 .58941 L F
0 g
.74382 .53163 m
.7454 .53143 L
s
.74226 .53137 m .74412 .59005 L .74256 .58979 L .751 .492 .54 r
F
.74128 .5309 m .74226 .53137 L .74256 .58979 L .845 .571 .524 r
F
0 g
.74226 .53137 m
.74382 .53163 L
s
.39432 .77853 m .36829 .7829 L .39329 .78244 L .673 .758 .914 r
F
.4686 .78672 m .4916 .7746 L .46726 .77895 L .673 .758 .915 r
F
.4436 .78718 m .4686 .78672 L .46726 .77895 L F
.74642 .53099 m .74744 .58884 L .74673 .58941 L .362 .185 .501 r
F
.74642 .53099 m .74713 .53043 L .74744 .58884 L F
0 g
.7454 .53143 m
.74642 .53099 L
s
0 0 0 r
2.5 Mabswid
.35367 .79243 Mdot
.74128 .5309 m .74256 .58979 L .74158 .58931 L .845 .571 .524 r
F
.74063 .53031 m .74128 .5309 L .74158 .58931 L .929 .648 .486 r
F
0 g
.5 Mabswid
.74128 .5309 m
.74226 .53137 L
s
.28067 .64253 m .27718 .66609 L .2934 .64958 L .654 .726 .902 r
F
.28067 .64253 m .25809 .65553 L .27718 .66609 L F
0 g
.27718 .66609 m
.29959 .67326 L
s
.32997 .53076 m .3293 .58814 L .32975 .58918 L .986 .729 .347 r
F
.32997 .53076 m .32952 .52972 L .3293 .58814 L F
.32249 .53063 m .32232 .58985 L .32226 .58904 L .794 .634 .076 r
F
.32301 .5296 m .32249 .53063 L .32226 .58904 L 0 0 .373 r
F
.74713 .53043 m .74788 .58816 L .74744 .58884 L .088 0 .422 r
F
.74713 .53043 m .74757 .52975 L .74788 .58816 L F
0 g
.74642 .53099 m
.74713 .53043 L
s
.37033 .77507 m .34329 .78337 L .36829 .7829 L .673 .758 .914 r
F
.39432 .77853 m .37033 .77507 L .36829 .7829 L F
.74063 .53031 m .74158 .58931 L .74093 .58872 L .929 .648 .486 r
F
.74026 .52961 m .74063 .53031 L .74093 .58872 L .988 .719 .38 r
F
0 g
.74063 .53031 m
.74128 .5309 L
s
.4436 .78718 m .46726 .77895 L .44293 .7833 L .673 .758 .915 r
F
.54852 .65376 m .52393 .66733 L .55143 .65875 L .654 .726 .902 r
F
.54852 .65376 m .5181 .65736 L .52393 .66733 L F
.39678 .76922 m .37027 .76944 L .39413 .77288 L .673 .758 .914 r
F
0 g
.35408 .67154 m
.37385 .66302 L
s
.74757 .52975 m .748 .58735 L .74788 .58816 L 0 0 .158 r
F
.74757 .52975 m .74769 .52894 L .748 .58735 L F
0 g
.74713 .53043 m
.74757 .52975 L
s
.32952 .52972 m .32824 .58732 L .3293 .58814 L .908 .63 .503 r
F
.32952 .52972 m .32846 .5289 L .32824 .58732 L F
0 g
.32952 .52972 m
.32997 .53076 L
s
.32952 .52972 m
.32952 .52972 L
s
.63218 .673 m .66882 .67044 L .63887 .66368 L .654 .726 .902 r
F
.60557 .66158 m .63218 .673 L .63887 .66368 L F
.60042 .66547 m .63218 .673 L .60557 .66158 L F
.74026 .52961 m .74093 .58872 L .74056 .58803 L .988 .719 .38 r
F
.74021 .5288 m .74026 .52961 L .74056 .58803 L .769 .613 .047 r
F
0 g
.74026 .52961 m
.74063 .53031 L
s
.32412 .52882 m .32301 .5296 L .32279 .58802 L .4 .212 .507 r
F
.32301 .5296 m .32226 .58904 L .32279 .58802 L 0 0 .373 r
F
0 g
.32249 .53063 m
.32301 .5296 L
s
.32301 .5296 m
.32301 .5296 L
s
.48514 .64525 m .48812 .65369 L .48769 .66096 L .921 .741 .253 r
F
.48514 .64525 m .48556 .63799 L .48812 .65369 L F
.51683 .63962 m .48812 .65369 L .51852 .6501 L .654 .726 .902 r
F
.51683 .63962 m .48556 .63799 L .48812 .65369 L F
0 g
.48812 .65369 m
.49207 .66044 L
s
.48665 .67847 m .46806 .66066 L .46762 .66793 L .857 .601 .551 r
F
0 g
.48665 .67847 m
.50103 .69167 L
s
.24405 .63505 m .25901 .64101 L .25855 .64827 L .926 .669 .53 r
F
.24405 .63505 m .24452 .62779 L .25901 .64101 L F
0 g
.25901 .64101 m
.26521 .64443 L
s
.34664 .77728 m .34329 .78337 L .34359 .78903 L 0 0 .318 r
F
0 g
.34401 .78742 m
.34429 .78901 L
s
.37033 .77507 m .34634 .77161 L .34329 .78337 L .673 .758 .914 r
F
.34664 .77728 m .34634 .77161 L .34329 .78337 L 0 0 .318 r
F
.4186 .78764 m .41278 .7732 L .40668 .77482 L .673 .758 .915 r
F
.2722 .6191 m .25935 .64081 L .28181 .62788 L .654 .726 .902 r
F
.2722 .6191 m .24493 .62766 L .25935 .64081 L F
.66882 .67044 m .66922 .66317 L .67316 .6478 L 0 0 .156 r
F
.63928 .65642 m .66922 .66317 L .67316 .6478 L .654 .726 .902 r
F
0 g
.66467 .6695 m
.66922 .66317 L
s
.69873 .64071 m .6949 .66427 L .71138 .64776 L .654 .726 .902 r
F
.69873 .64071 m .67594 .65371 L .6949 .66427 L F
0 g
.6949 .66427 m
.71722 .67144 L
s
.67934 .64812 m
.68258 .64993 L
s
.39843 .64275 m
.39921 .64216 L
s
.74769 .52894 m .74756 .58631 L .748 .58735 L .982 .725 .331 r
F
.74769 .52894 m .74725 .5279 L .74756 .58631 L F
.32846 .5289 m .32717 .58694 L .32824 .58732 L .809 .541 .534 r
F
.32846 .5289 m .32739 .52853 L .32717 .58694 L F
0 g
.32846 .5289 m
.32952 .52972 L
s
.32412 .52882 m .32279 .58802 L .3239 .58724 L .4 .212 .507 r
F
.32522 .52849 m .32412 .52882 L .3239 .58724 L .568 .344 .535 r
F
0 g
.32301 .5296 m
.32412 .52882 L
s
.78865 .66917 m .80895 .65339 L .80857 .66065 L .496 .29 .53 r
F
.77391 .65103 m .78865 .66917 L .80857 .66065 L .654 .726 .902 r
F
.75863 .65424 m .78865 .66917 L .77391 .65103 L F
0 g
.76573 .67398 m
.78865 .66917 L
s
.74021 .5288 m .74056 .58803 L .74052 .58722 L .769 .613 .047 r
F
.74075 .52778 m .74021 .5288 L .74052 .58722 L 0 0 .386 r
F
.44262 .77763 m .46229 .7661 L .44029 .77404 L .673 .758 .914 r
F
.44262 .77763 m .46695 .77329 L .46229 .7661 L F
.32739 .52853 m .32609 .58681 L .32717 .58694 L .734 .478 .541 r
F
.32739 .52853 m .32631 .5284 L .32609 .58681 L F
0 g
.32739 .52853 m
.32846 .5289 L
s
.32522 .52849 m .3239 .58724 L .325 .5869 L .568 .344 .535 r
F
.32631 .5284 m .32522 .52849 L .325 .5869 L .66 .417 .541 r
F
0 g
.32412 .52882 m
.32522 .52849 L
s
.32631 .5284 m .325 .5869 L .32609 .58681 L .66 .417 .541 r
F
0 g
.32631 .5284 m
.32739 .52853 L
s
.32522 .52849 m
.32631 .5284 L
s
.39462 .78419 m .36859 .78857 L .3936 .7881 L .673 .758 .915 r
F
.54867 .634 m .51925 .6428 L .54951 .63921 L .654 .726 .902 r
F
.54867 .634 m .51757 .63237 L .51925 .6428 L F
.46639 .76767 m .48367 .75262 L .46176 .76052 L .673 .758 .914 r
F
.46639 .76767 m .49061 .76334 L .48367 .75262 L F
.41645 .88701 m .41596 .88245 L .43054 .88054 L .673 .455 .58 r
F
.127 .923 .03 r
.38663 .82477 m
.38736 .87975 L
s
.40198 .88665 m .41596 .88245 L .41645 .88701 L .733 .498 .572 r
F
.40198 .88665 m .4015 .88209 L .41596 .88245 L F
.74725 .5279 m .74652 .58549 L .74756 .58631 L .91 .629 .499 r
F
.74725 .5279 m .74621 .52708 L .74652 .58549 L F
0 g
.74725 .5279 m
.74769 .52894 L
s
.74725 .5279 m
.74725 .5279 L
s
.41648 .87121 m .41597 .88228 L .43047 .88038 L .683 .77 .917 r
F
.40688 .87097 m .41597 .88228 L .41648 .87121 L F
.40688 .87097 m .40158 .88192 L .41597 .88228 L F
.60959 .64236 m .63939 .64908 L .64199 .63889 L .654 .726 .902 r
F
.60626 .647 m .63939 .64908 L .60959 .64236 L F
.46806 .66066 m .46849 .6534 L .44612 .64622 L .793 .543 .559 r
F
0 g
.46849 .6534 m
.48751 .66395 L
s
.74187 .527 m .74075 .52778 L .74105 .58619 L .405 .218 .51 r
F
.74075 .52778 m .74052 .58722 L .74105 .58619 L 0 0 .386 r
F
0 g
.74021 .5288 m
.74075 .52778 L
s
.74075 .52778 m
.74075 .52778 L
s
.43102 .8851 m .43054 .88054 L .44422 .87648 L .607 .406 .584 r
F
.41645 .88701 m .43054 .88054 L .43102 .8851 L .673 .455 .58 r
F
0 g
.41596 .88245 m
.43054 .88054 L
s
.42615 .86994 m .43047 .88038 L .44409 .87634 L .683 .77 .917 r
F
.41648 .87121 m .43047 .88038 L .42615 .86994 L F
.43987 .76842 m .45414 .75445 L .43606 .76539 L .673 .758 .914 r
F
.43987 .76842 m .46176 .76052 L .45414 .75445 L F
.37064 .78073 m .34359 .78903 L .36859 .78857 L .673 .758 .915 r
F
.39462 .78419 m .37064 .78073 L .36859 .78857 L F
.80895 .65339 m .80933 .64613 L .82489 .63447 L .349 .172 .494 r
F
0 g
.79889 .6506 m
.80933 .64613 L
s
.83081 .60749 m
.87887 .59005 L
s
.74621 .52708 m .74545 .58512 L .74652 .58549 L .809 .541 .532 r
F
.74621 .52708 m .74514 .5267 L .74545 .58512 L F
0 g
.74621 .52708 m
.74725 .5279 L
s
.74187 .527 m .74105 .58619 L .74218 .58541 L .405 .218 .51 r
F
.74297 .52666 m .74187 .527 L .74218 .58541 L .57 .345 .536 r
F
0 g
.74075 .52778 m
.74187 .527 L
s
.78775 .63066 m .80901 .6459 L .82449 .6343 L .654 .726 .902 r
F
.77454 .63632 m .80901 .6459 L .78775 .63066 L F
.39698 .77484 m .37033 .77507 L .39432 .77853 L .673 .758 .914 r
F
.74514 .5267 m .74437 .58499 L .74545 .58512 L .734 .478 .541 r
F
.74514 .5267 m .74406 .52657 L .74437 .58499 L F
0 g
.74514 .5267 m
.74621 .52708 L
s
.74297 .52666 m .74218 .58541 L .74328 .58508 L .57 .345 .536 r
F
.74406 .52657 m .74297 .52666 L .74328 .58508 L .66 .418 .542 r
F
0 g
.74187 .527 m
.74297 .52666 L
s
.74406 .52657 m .74328 .58508 L .74437 .58499 L .66 .418 .542 r
F
0 g
.74406 .52657 m
.74514 .5267 L
s
.74297 .52666 m
.74406 .52657 L
s
.32609 .62192 m .32539 .64185 L .34153 .64133 L .654 .726 .902 r
F
.31806 .62082 m .32539 .64185 L .32609 .62192 L F
.31806 .62082 m .30934 .63965 L .32539 .64185 L F
.37064 .78073 m .34664 .77728 L .34359 .78903 L .673 .758 .915 r
F
0 g
.34359 .78903 m
.34565 .80067 L
s
.38859 .88403 m .4015 .88209 L .40198 .88665 L .793 .542 .558 r
F
.127 .923 .03 r
.38681 .98118 m
.39627 8.82864 L
s
.38859 .88403 m .38811 .87948 L .4015 .88209 L .793 .542 .558 r
F
0 g
.4015 .88209 m
.41596 .88245 L
s
.5821 .56342 m
.58219 .6159 L
s
.57561 .5633 m
.57569 .61585 L
s
.41693 .89157 m .41645 .88701 L .43102 .8851 L .673 .455 .58 r
F
.40246 .89121 m .41645 .88701 L .41693 .89157 L .733 .498 .572 r
F
.40246 .89121 m .40198 .88665 L .41645 .88701 L F
.41696 .87588 m .41645 .88701 L .43102 .8851 L .683 .77 .917 r
F
.127 .923 .03 r
.47888 .8127 m
.47892 .80847 L
s
.40731 .87564 m .41645 .88701 L .41696 .87588 L .683 .77 .917 r
F
.40731 .87564 m .40198 .88665 L .41645 .88701 L F
.398 .86923 m .40158 .88192 L .40688 .87097 L F
.398 .86923 m .38826 .87932 L .40158 .88192 L F
.127 .923 .03 r
.35367 .79243 m
.354 .85528 L
s
.44293 .7833 m .4626 .77177 L .4406 .77971 L .673 .758 .915 r
F
.44293 .7833 m .46726 .77895 L .4626 .77177 L F
.39678 .76922 m .37556 .76211 L .37027 .76944 L .673 .758 .914 r
F
.40087 .76604 m .37556 .76211 L .39678 .76922 L F
.51641 .64689 m .48769 .66096 L .5181 .65736 L .654 .726 .902 r
F
.51641 .64689 m .48514 .64525 L .48769 .66096 L F
0 g
.48769 .66096 m
.49646 .67591 L
s
.43102 .8851 m .44422 .87648 L .44471 .88104 L .607 .406 .584 r
F
.4315 .88966 m .43102 .8851 L .44471 .88104 L F
.41693 .89157 m .43102 .8851 L .4315 .88966 L .673 .455 .58 r
F
.42668 .8746 m .43102 .8851 L .44471 .88104 L .683 .77 .917 r
F
.127 .923 .03 r
.48679 .85846 m
.48749 .79574 L
s
.41696 .87588 m .43102 .8851 L .42668 .8746 L .683 .77 .917 r
F
0 g
.41645 .88701 m
.43102 .8851 L
s
.46695 .77329 m .48431 .75816 L .46229 .7661 L .673 .758 .914 r
F
.46695 .77329 m .49128 .76894 L .48431 .75816 L F
.24359 .64231 m .25855 .64827 L .25809 .65553 L .926 .669 .53 r
F
.24359 .64231 m .24405 .63505 L .25855 .64827 L F
.27146 .62645 m .25855 .64827 L .28112 .63527 L .654 .726 .902 r
F
.27146 .62645 m .24405 .63505 L .25855 .64827 L F
0 g
.25855 .64827 m
.26475 .6517 L
s
.31063 .61843 m .30934 .63965 L .31806 .62082 L .654 .726 .902 r
F
.31063 .61843 m .29448 .63488 L .30934 .63965 L F
.33417 .62166 m .34153 .64133 L .35668 .63814 L F
.32609 .62192 m .34153 .64133 L .33417 .62166 L F
.66882 .67044 m .67316 .6478 L .67276 .65507 L 0 0 .156 r
F
.63887 .66368 m .66882 .67044 L .67276 .65507 L .654 .726 .902 r
F
0 g
.65877 .68441 m
.66882 .67044 L
s
.74417 .6201 m .74317 .64003 L .75934 .63951 L .654 .726 .902 r
F
0 g
.74167 .63982 m
.74321 .63927 L
s
.75563 .63476 m
.83081 .60749 L
s
.73615 .619 m .74317 .64003 L .74417 .6201 L .654 .726 .902 r
F
.73615 .619 m .72714 .63783 L .74317 .64003 L F
.49128 .76894 m .49097 .76328 L .484 .7525 L .987 .712 .385 r
F
0 g
.49097 .76328 m
.49296 .77494 L
s
.44471 .88104 m .44422 .87648 L .45609 .87055 L .525 .347 .582 r
F
0 g
.43751 .87847 m
.44422 .87648 L
s
.44029 .77404 m .45464 .76 L .43646 .77099 L .673 .758 .914 r
F
.44029 .77404 m .46229 .7661 L .45464 .76 L F
.37556 .76211 m .3464 .766 L .37027 .76944 L F
.43523 .86725 m .44409 .87634 L .4559 .87045 L .683 .77 .917 r
F
.42615 .86994 m .44409 .87634 L .43523 .86725 L F
.5481 .64126 m .51852 .6501 L .54894 .6465 L .654 .726 .902 r
F
.5481 .64126 m .51683 .63962 L .51852 .6501 L F
.39728 .78051 m .37064 .78073 L .39462 .78419 L .673 .758 .915 r
F
.63928 .65642 m .67316 .6478 L .64189 .64617 L .654 .726 .902 r
F
.60933 .64966 m .63928 .65642 L .64189 .64617 L F
.60598 .65432 m .63928 .65642 L .60933 .64966 L F
.43606 .76539 m .44405 .74986 L .43101 .7631 L .673 .758 .914 r
F
.43606 .76539 m .45414 .75445 L .44405 .74986 L F
.46806 .66066 m .44612 .64622 L .44568 .65348 L .793 .543 .559 r
F
.46762 .66793 m .46806 .66066 L .44568 .65348 L F
0 g
.46806 .66066 m
.48708 .67121 L
s
.38908 .88859 m .40198 .88665 L .40246 .89121 L .793 .542 .558 r
F
.38908 .88859 m .38859 .88403 L .40198 .88665 L F
.39838 .87389 m .40198 .88665 L .40731 .87564 L .683 .77 .917 r
F
.39838 .87389 m .38859 .88403 L .40198 .88665 L F
0 g
.40198 .88665 m
.41645 .88701 L
s
.127 .923 .03 r
.354 .85528 m
.35402 .85947 L
s
.3561 .81511 m
.35612 .81933 L
s
.41744 .88044 m .41693 .89157 L .4315 .88966 L .683 .77 .917 r
F
.127 .923 .03 r
.47884 .81692 m
.47888 .8127 L
s
.40779 .8802 m .41693 .89157 L .41744 .88044 L .683 .77 .917 r
F
.40779 .8802 m .40246 .89121 L .41693 .89157 L F
.72874 .61661 m .72714 .63783 L .73615 .619 L .654 .726 .902 r
F
.72874 .61661 m .71234 .63306 L .72714 .63783 L F
.75226 .61984 m .75934 .63951 L .77454 .63632 L F
.74417 .6201 m .75934 .63951 L .75226 .61984 L F
.80895 .65339 m .82489 .63447 L .82451 .64173 L .349 .172 .494 r
F
.80857 .66065 m .80895 .65339 L .82451 .64173 L F
.78758 .63808 m .80895 .65339 L .82451 .64173 L .654 .726 .902 r
F
.7743 .64376 m .80895 .65339 L .78758 .63808 L F
0 g
.7985 .65786 m
.80895 .65339 L
s
.4315 .88966 m .44471 .88104 L .44519 .8856 L .607 .406 .584 r
F
.42716 .87916 m .4315 .88966 L .44519 .8856 L .683 .77 .917 r
F
.127 .923 .03 r
.48674 .86266 m
.48679 .85846 L
s
.41744 .88044 m .4315 .88966 L .42716 .87916 L .683 .77 .917 r
F
0 g
.41693 .89157 m
.4315 .88966 L
s
.39698 .77484 m .37565 .7677 L .37033 .77507 L .673 .758 .914 r
F
.40109 .77165 m .37565 .7677 L .39698 .77484 L F
.60959 .64236 m .64199 .63889 L .61088 .63726 L .654 .726 .902 r
F
.32564 .62928 m .32493 .64931 L .34116 .64879 L F
.31757 .62818 m .32493 .64931 L .32564 .62928 L F
.31757 .62818 m .3088 .6471 L .32493 .64931 L F
.40087 .76604 m .38374 .75575 L .37556 .76211 L .673 .758 .914 r
F
.40613 .76356 m .38374 .75575 L .40087 .76604 L F
.46726 .77895 m .48463 .76382 L .4626 .77177 L .673 .758 .915 r
F
.46726 .77895 m .4916 .7746 L .48463 .76382 L F
.44471 .88104 m .45609 .87055 L .45658 .87511 L .525 .347 .582 r
F
.44519 .8856 m .44471 .88104 L .45658 .87511 L F
.43581 .8719 m .44471 .88104 L .45658 .87511 L .683 .77 .917 r
F
.42668 .8746 m .44471 .88104 L .43581 .8719 L F
0 g
.438 .88303 m
.44471 .88104 L
s
.57641 .76018 m .57609 .75452 L .59558 .75262 L .672 .45 .575 r
F
.55708 .759 m .57609 .75452 L .57641 .76018 L .733 .497 .571 r
F
.55708 .759 m .55675 .75334 L .57609 .75452 L F
.44568 .65348 m .44612 .64622 L .42193 .6429 L .732 .488 .56 r
F
0 g
.44612 .64622 m
.46849 .6534 L
s
.49128 .76894 m .484 .7525 L .48431 .75816 L .987 .712 .385 r
F
.4916 .7746 m .49128 .76894 L .48431 .75816 L F
0 g
.49128 .76894 m
.49328 .78059 L
s
.4406 .77971 m .45495 .76566 L .43676 .77666 L .673 .758 .915 r
F
.4406 .77971 m .4626 .77177 L .45495 .76566 L F
.37565 .7677 m .34634 .77161 L .37033 .77507 L .673 .758 .914 r
F
.57687 .73927 m .5761 .7543 L .5955 .75241 L F
.56404 .73849 m .5761 .7543 L .57687 .73927 L F
.56404 .73849 m .55686 .75312 L .5761 .7543 L F
.39887 .87845 m .40246 .89121 L .40779 .8802 L .683 .77 .917 r
F
.39887 .87845 m .38908 .88859 L .40246 .89121 L F
0 g
.40246 .89121 m
.41693 .89157 L
s
.127 .923 .03 r
.35612 .81933 m
.35614 .82356 L
s
.35402 .85947 m
.35404 .86367 L
s
.37721 .87935 m .38811 .87948 L .38859 .88403 L .858 .591 .533 r
F
.127 .923 .03 r
.38663 .82477 m
.38669 .87946 L
s
0 g
.38365 .87942 m
.38368 .86754 L
s
.37721 .87935 m .37673 .87479 L .38811 .87948 L .858 .591 .533 r
F
0 g
.38811 .87948 m
.39222 .88028 L
s
.39045 .86612 m .38826 .87932 L .398 .86923 L .683 .77 .917 r
F
.39045 .86612 m .37693 .87466 L .38826 .87932 L F
.31009 .62578 m .3088 .6471 L .31757 .62818 L .654 .726 .902 r
F
.31009 .62578 m .29386 .64231 L .3088 .6471 L F
.33376 .62902 m .34116 .64879 L .35638 .64558 L F
.32564 .62928 m .34116 .64879 L .33376 .62902 L F
.30429 .61492 m .29448 .63488 L .31063 .61843 L F
.30429 .61492 m .28181 .62788 L .29448 .63488 L F
.271 .63371 m .25809 .65553 L .28067 .64253 L F
.271 .63371 m .24359 .64231 L .25809 .65553 L F
0 g
.25809 .65553 m
.27718 .66609 L
s
.43101 .7631 m .43218 .74708 L .42508 .76171 L .673 .758 .914 r
F
.43101 .7631 m .44405 .74986 L .43218 .74708 L F
.34175 .62006 m .35668 .63814 L .36979 .63248 L .654 .726 .902 r
F
.33417 .62166 m .35668 .63814 L .34175 .62006 L F
.43646 .77099 m .44449 .75539 L .43139 .76869 L .673 .758 .914 r
F
.43646 .77099 m .45464 .76 L .44449 .75539 L F
.59591 .75828 m .59558 .75262 L .61391 .74777 L .604 .398 .575 r
F
.57641 .76018 m .59558 .75262 L .59591 .75828 L .672 .45 .575 r
F
0 g
.57609 .75452 m
.59558 .75262 L
s
.74377 .62746 m .74277 .64749 L .75902 .64697 L .654 .726 .902 r
F
.73571 .62636 m .74277 .64749 L .74377 .62746 L F
.73571 .62636 m .72666 .64528 L .74277 .64749 L F
.58981 .73801 m .5955 .75241 L .61373 .74757 L .673 .758 .914 r
F
.57687 .73927 m .5955 .75241 L .58981 .73801 L F
.44519 .8856 m .45658 .87511 L .45707 .87967 L .525 .347 .582 r
F
.43629 .87646 m .44519 .8856 L .45707 .87967 L .683 .77 .917 r
F
.42716 .87916 m .44519 .8856 L .43629 .87646 L F
0 g
.4315 .88966 m
.44519 .8856 L
s
.54768 .64852 m .5181 .65736 L .54852 .65376 L .654 .726 .902 r
F
.54768 .64852 m .51641 .64689 L .5181 .65736 L F
.40613 .76356 m .39426 .75078 L .38374 .75575 L .673 .758 .914 r
F
.4122 .76195 m .39426 .75078 L .40613 .76356 L F
.39728 .78051 m .37595 .77337 L .37064 .78073 L .673 .758 .915 r
F
.40139 .77731 m .37595 .77337 L .39728 .78051 L F
0 g
.37385 .66302 m
.39669 .6582 L
s
.46176 .76052 m .47224 .7435 L .45414 .75445 L .673 .758 .914 r
F
.46176 .76052 m .48367 .75262 L .47224 .7435 L F
.44568 .65348 m .42193 .6429 L .42149 .65016 L .732 .488 .56 r
F
0 g
.42193 .6429 m
.44612 .64622 L
s
.40653 .64339 m
.42193 .6429 L
s
.63887 .66368 m .67276 .65507 L .64149 .65343 L .654 .726 .902 r
F
0 g
.67132 .65499 m
.67243 .65067 L
s
.60891 .65692 m .63887 .66368 L .64149 .65343 L .654 .726 .902 r
F
.60557 .66158 m .63887 .66368 L .60891 .65692 L F
.46762 .66793 m .44568 .65348 L .44525 .66075 L .793 .543 .559 r
F
0 g
.46762 .66793 m
.48665 .67847 L
s
.40109 .77165 m .38387 .76131 L .37565 .7677 L .673 .758 .914 r
F
.40638 .76916 m .38387 .76131 L .40109 .77165 L F
.72827 .62396 m .72666 .64528 L .73571 .62636 L .654 .726 .902 r
F
.72827 .62396 m .71177 .64049 L .72666 .64528 L F
.41699 .86012 m .41648 .87121 L .42615 .86994 L .683 .77 .917 r
F
.41699 .86012 m .42615 .86994 L .42183 .85949 L F
.41747 .86474 m .41696 .87588 L .42668 .8746 L F
.41747 .86474 m .42668 .8746 L .42234 .8641 L F
.4169 .80961 m .41847 .80987 L .41839 .85185 L .751 .492 .541 r
F
.41877 .8521 m .41699 .86012 L .42183 .85949 L .683 .77 .917 r
F
.41868 .85187 m .41862 .85216 L .41877 .8521 L F
.41862 .85216 m .41699 .86012 L .41877 .8521 L F
.41908 .85623 m .41747 .86474 L .42234 .8641 L F
.41737 .85203 m .41699 .86012 L .41864 .85187 L F
.41839 .85185 m .41864 .85187 L .41865 .8518 L F
.41737 .85203 m .41864 .85187 L .41839 .85185 L F
.41526 .80856 m .41592 .80914 L .41584 .85137 L .927 .648 .492 r
F
.41629 .85153 m .41599 .85215 L .41737 .85191 L .683 .77 .917 r
F
.41483 .80706 m .41488 .80787 L .41481 .8503 L .789 .63 .07 r
F
.41508 .85402 m .41219 .86 L .41518 .85533 L .683 .77 .917 r
F
.40775 .85913 m .40688 .87097 L .41219 .86 L F
.41496 .85673 m .40439 .86218 L .40818 .86374 L F
.4154 .85121 m .41539 .85121 L .41629 .85153 L F
.41735 .85246 m .41219 .86 L .41699 .86012 L F
.41669 .85626 m .41265 .86462 L .41743 .8568 L F
.41219 .86 m .41648 .87121 L .41699 .86012 L F
.41623 .85165 m .41101 .85625 L .41219 .86 L F
.41101 .85625 m .40775 .85913 L .40924 .85942 L F
.41101 .85625 m .40924 .85942 L .41219 .86 L F
.41483 .80706 m .41479 .8501 L .41475 .84959 L .789 .63 .07 r
F
.41488 .80787 m .41508 .85072 L .41481 .8503 L .989 .721 .392 r
F
.41483 .80706 m .41481 .8503 L .41479 .8501 L .789 .63 .07 r
F
.41488 .80787 m .41526 .80856 L .41518 .85089 L .989 .721 .392 r
F
.41536 .80605 m .41483 .80706 L .41475 .84959 L 0 0 .377 r
F
.41482 .85483 m .41403 .85514 L .41487 .85556 L .683 .77 .917 r
F
.41592 .80914 m .41655 .85162 L .41584 .85137 L .844 .572 .527 r
F
.41592 .80914 m .4169 .80961 L .41683 .85172 L F
.41592 .80914 m .41683 .85172 L .41674 .85169 L F
.41491 .85171 m .41498 .85269 L .41585 .85192 L .683 .77 .917 r
F
.41773 .85913 m .41265 .86462 L .41747 .86474 L F
.41219 .86 m .40688 .87097 L .41648 .87121 L F
.41265 .86462 m .40731 .87564 L .41696 .87588 L F
.40818 .86374 m .40731 .87564 L .41265 .86462 L F
.4167 .86181 m .40867 .86831 L .41313 .86918 L F
.41661 .85592 m .41682 .85599 L .41681 .86026 L .844 .572 .527 r
F
.41265 .86462 m .41696 .87588 L .41747 .86474 L .683 .77 .917 r
F
.41835 .86081 m .41313 .86918 L .41796 .8693 L F
.41737 .85191 m .41713 .8523 L .41735 .85246 L F
.41787 .85608 m .41773 .85632 L .41786 .85636 L F
.41795 .85181 m .41816 .86037 L .41683 .85172 L .751 .492 .541 r
F
.41784 .85678 m .41747 .86474 L .41908 .85623 L .683 .77 .917 r
F
.41837 .86039 m .41735 .86046 L .41835 .86081 L F
.41742 .86031 m .41735 .86046 L .41837 .86039 L F
.41816 .86037 m .41836 .86866 L .41761 .86033 L .751 .492 .541 r
F
.41786 .85636 m .41691 .85786 L .41773 .85913 L .683 .77 .917 r
F
.41669 .85626 m .41743 .8568 L .41787 .85608 L F
.41864 .85187 m .41699 .86012 L .41868 .85187 L F
.41816 .86037 m .41761 .86033 L .41683 .85172 L .751 .492 .541 r
F
.41787 .85608 m .41784 .85678 L .41906 .85617 L .683 .77 .917 r
F
.41805 .85609 m .41838 .85612 L .41836 .86866 L .751 .492 .541 r
F
.41847 .85815 m .41742 .86031 L .41837 .86039 L .683 .77 .917 r
F
.41735 .86046 m .41313 .86918 L .41835 .86081 L F
.41583 .85991 m .4168 .8684 L .41581 .86793 L .844 .572 .527 r
F
.41539 .85121 m .41585 .85192 L .41629 .85153 L .683 .77 .917 r
F
.41599 .85215 m .41508 .85402 L .41661 .8531 L F
.41713 .8523 m .41219 .86 L .41735 .85246 L F
.41584 .85137 m .41609 .85573 L .41584 .85564 L .844 .572 .527 r
F
.41799 .85359 m .41482 .85483 L .41485 .85529 L .683 .77 .917 r
F
.41514 .85539 m .41485 .85529 L .41487 .85556 L F
.41799 .85359 m .41485 .85529 L .41514 .85539 L F
.41773 .85632 m .41265 .86462 L .41786 .85636 L F
.41584 .85564 m .41633 .86009 L .41583 .85991 L .844 .572 .527 r
F
.41669 .85626 m .40818 .86374 L .41265 .86462 L .683 .77 .917 r
F
.41683 .85172 m .41722 .85602 L .41682 .85599 L .751 .492 .541 r
F
.41799 .85359 m .41594 .85571 L .41669 .85626 L .683 .77 .917 r
F
.41594 .85571 m .40818 .86374 L .41669 .85626 L F
.41539 .85121 m .41491 .85171 L .41585 .85192 L F
.41508 .85402 m .41518 .85533 L .41661 .8531 L F
.41566 .85123 m .4157 .85554 L .41518 .85089 L .927 .648 .492 r
F
.41527 .85531 m .41487 .85556 L .41569 .85596 L .683 .77 .917 r
F
.41526 .80856 m .41566 .85123 L .41518 .85089 L .927 .648 .492 r
F
.41526 .80856 m .41584 .85137 L .41566 .85123 L F
.41619 .85162 m .40775 .85913 L .41623 .85165 L .683 .77 .917 r
F
.41592 .80914 m .41674 .85169 L .41655 .85162 L .844 .572 .527 r
F
.4169 .80961 m .41795 .85181 L .41683 .85172 L .751 .492 .541 r
F
.4175 .84903 m .41101 .85157 L .40397 .85758 L .683 .77 .917 r
F
.41101 .85157 m .40112 .85544 L .40314 .85695 L F
.41101 .85157 m .40314 .85695 L .40397 .85758 L F
.41647 .80527 m .41536 .80605 L .41528 .84865 L .403 .215 .509 r
F
.4157 .85554 m .41535 .85528 L .41518 .85089 L .927 .648 .492 r
F
.41169 .85505 m .40397 .85758 L .40775 .85913 L .683 .77 .917 r
F
.40397 .85758 m .39045 .86612 L .398 .86923 L F
.40936 .85696 m .39977 .85744 L .40152 .86003 L F
.4149 .84933 m .41485 .85367 L .41528 .84865 L 0 0 .377 r
F
.4148 .85457 m .41492 .85905 L .41479 .85884 L .989 .721 .392 r
F
.41487 .85556 m .40439 .86218 L .41496 .85673 L .683 .77 .917 r
F
.4149 .85472 m .41499 .85915 L .4148 .85457 L .989 .721 .392 r
F
.41599 .86072 m .40867 .86831 L .4167 .86181 L .683 .77 .917 r
F
.41691 .85786 m .41265 .86462 L .41773 .85913 L F
.41499 .85915 m .41515 .86735 L .41492 .85905 L .989 .721 .392 r
F
.41499 .85915 m .41492 .85905 L .4148 .85457 L F
.40397 .85758 m .398 .86923 L .40775 .85913 L .683 .77 .917 r
F
.41487 .85556 m .40152 .86003 L .40439 .86218 L F
.41484 .85892 m .39974 .85915 L .40025 .862 L F
.41479 .85443 m .4148 .85457 L .41479 .85884 L .789 .63 .07 r
F
.40818 .86374 m .39838 .87389 L .40731 .87564 L .683 .77 .917 r
F
.40953 .86741 m .40487 .86674 L .40867 .86831 L F
.41847 .85815 m .41267 .86181 L .40953 .86741 L F
.41267 .86181 m .40487 .86674 L .40953 .86741 L F
.41479 .85884 m .41515 .86735 L .41477 .86666 L .989 .721 .392 r
F
.41569 .85596 m .41487 .85556 L .41496 .85673 L .683 .77 .917 r
F
.41101 .85157 m .39938 .85286 L .40112 .85544 L F
.41429 .85379 m .40003 .85167 L .39926 .85459 L F
.4151 .85504 m .41496 .85483 L .41481 .8503 L .989 .721 .392 r
F
.41546 .84852 m .41536 .85286 L .41558 .84844 L .403 .215 .509 r
F
.41566 .85123 m .41584 .85564 L .4157 .85554 L .927 .648 .492 r
F
.41799 .85359 m .41448 .85433 L .41403 .85514 L .683 .77 .917 r
F
.41536 .85286 m .41526 .85719 L .41542 .85281 L .403 .215 .509 r
F
.41536 .85286 m .41542 .85281 L .41558 .84844 L F
.41508 .85072 m .41518 .85516 L .4151 .85504 L .989 .721 .392 r
F
.41799 .85359 m .41479 .85325 L .41429 .85379 L .683 .77 .917 r
F
.41479 .85325 m .41388 .85315 L .4142 .85365 L F
.41479 .85325 m .4142 .85365 L .41429 .85379 L F
.41454 .8509 m .40397 .85758 L .4154 .85121 L F
.41388 .85315 m .40003 .85167 L .41429 .85379 L F
.41508 .85072 m .4151 .85504 L .41481 .8503 L .989 .721 .392 r
F
.4151 .85504 m .41512 .85935 L .41496 .85483 L F
.41512 .85935 m .41515 .86735 L .41499 .85915 L F
.41512 .85935 m .41499 .85915 L .41481 .8503 L F
.40775 .85913 m .398 .86923 L .40688 .87097 L .683 .77 .917 r
F
.41517 .85944 m .40025 .862 L .402 .86459 L F
.41661 .85592 m .41681 .86026 L .41668 .86021 L .844 .572 .527 r
F
.4151 .85504 m .41518 .85516 L .41515 .86735 L .989 .721 .392 r
F
.41847 .85815 m .41484 .85892 L .41517 .85944 L .683 .77 .917 r
F
.41484 .85892 m .40025 .862 L .41517 .85944 L F
.41526 .85719 m .41472 .86586 L .41525 .86484 L 0 0 .377 r
F
.41508 .85072 m .41518 .85089 L .41518 .85516 L .989 .721 .392 r
F
.41528 .84865 m .41499 .85769 L .41526 .85719 L 0 0 .377 r
F
.41576 .85986 m .40692 .8629 L .40487 .86674 L .683 .77 .917 r
F
.41492 .85905 m .41515 .86735 L .41479 .85884 L .989 .721 .392 r
F
.41499 .85769 m .41472 .86586 L .41526 .85719 L 0 0 .377 r
F
.41478 .85875 m .41479 .85884 L .41477 .86666 L .789 .63 .07 r
F
.41479 .85443 m .41479 .85884 L .41478 .85875 L F
.41847 .85815 m .41475 .85835 L .41484 .85892 L .683 .77 .917 r
F
.41475 .85835 m .41448 .85836 L .41479 .85884 L F
.41475 .85835 m .41479 .85884 L .41484 .85892 L F
.41448 .85836 m .39974 .85915 L .41484 .85892 L F
.41314 .85247 m .40397 .85758 L .41169 .85505 L F
.41264 .85472 m .39977 .85744 L .40936 .85696 L F
.41403 .85514 m .40152 .86003 L .41354 .856 L F
.41491 .85171 m .40775 .85913 L .41498 .85269 L F
.41477 .85427 m .39926 .85459 L .39977 .85744 L F
.41566 .85123 m .41584 .85137 L .41584 .85564 L .927 .648 .492 r
F
.41799 .85359 m .41474 .85376 L .41477 .85427 L .683 .77 .917 r
F
.41474 .85376 m .39926 .85459 L .41477 .85427 L F
.41479 .8501 m .41479 .85443 L .41475 .84959 L .789 .63 .07 r
F
.41479 .85443 m .41477 .86666 L .41476 .85404 L F
.41479 .85443 m .41476 .85404 L .41475 .84959 L F
.41494 .85777 m .40251 .85344 L .40051 .85623 L .683 .77 .917 r
F
.41735 .86046 m .41599 .86072 L .4167 .86181 L F
.41653 .86016 m .41599 .86072 L .41735 .86046 L F
.41629 .85153 m .41619 .85162 L .41623 .85165 L F
.41655 .85162 m .41661 .85592 L .41584 .85137 L .844 .572 .527 r
F
.41661 .85592 m .4168 .8684 L .41609 .85573 L F
.41661 .85592 m .41609 .85573 L .41584 .85137 L F
.41655 .85162 m .41682 .85599 L .41661 .85592 L F
.41799 .85359 m .41527 .85531 L .41538 .85547 L .683 .77 .917 r
F
.41596 .85568 m .41538 .85547 L .41569 .85596 L F
.41799 .85359 m .41538 .85547 L .41596 .85568 L F
.41847 .85815 m .41526 .8572 L .41494 .85777 L F
.41403 .85514 m .41264 .85472 L .40936 .85696 L F
.41526 .8572 m .40251 .85344 L .41494 .85777 L F
.41485 .85367 m .4148 .85801 L .41513 .85317 L 0 0 .377 r
F
.4148 .85801 m .41472 .86586 L .41499 .85769 L F
.4148 .85801 m .41499 .85769 L .41513 .85317 L F
.41485 .85367 m .41513 .85317 L .41528 .84865 L F
.41448 .85433 m .41264 .85472 L .41403 .85514 L .683 .77 .917 r
F
.4157 .85554 m .41574 .85985 L .41535 .85528 L .927 .648 .492 r
F
.4155 .85276 m .41526 .85719 L .41541 .85709 L .403 .215 .509 r
F
.41558 .84844 m .41542 .85281 L .4155 .85276 L F
.41542 .85281 m .41526 .85719 L .4155 .85276 L F
.41647 .80527 m .41546 .84852 L .41558 .84844 L F
.4175 .84903 m .41348 .84988 L .41101 .85157 L .683 .77 .917 r
F
.41348 .84988 m .39938 .85286 L .41101 .85157 L F
.4154 .85121 m .41314 .85247 L .41169 .85505 L F
.41479 .8501 m .41481 .8503 L .4148 .85457 L .789 .63 .07 r
F
.41574 .85985 m .41581 .86793 L .41551 .85968 L .927 .648 .492 r
F
.41633 .86009 m .4168 .8684 L .41583 .85991 L .844 .572 .527 r
F
.41638 .85643 m .41525 .86484 L .41636 .86407 L .403 .215 .509 r
F
.4175 .84903 m .41454 .8509 L .4154 .85121 L .683 .77 .917 r
F
.41348 .84988 m .39887 .85002 L .39938 .85286 L F
.41488 .80787 m .41518 .85089 L .41508 .85072 L .989 .721 .392 r
F
.4175 .84903 m .41449 .84919 L .41348 .84988 L .683 .77 .917 r
F
.41449 .84919 m .39887 .85002 L .41348 .84988 L F
.41639 .84788 m .41541 .85709 L .41638 .85643 L .403 .215 .509 r
F
.41647 .80527 m .41558 .84844 L .41639 .84788 L F
.4175 .84903 m .4154 .85121 L .41629 .85153 L .683 .77 .917 r
F
.4155 .85276 m .4159 .85249 L .41639 .84788 L .403 .215 .509 r
F
.41546 .84852 m .41528 .84865 L .41527 .85292 L F
.41536 .80605 m .4149 .84933 L .41528 .84865 L 0 0 .377 r
F
.41536 .80605 m .41475 .84959 L .4149 .84933 L F
.41581 .84808 m .40863 .83991 L .40469 .84188 L .683 .77 .917 r
F
.4175 .84903 m .41639 .84788 L .41581 .84808 L F
.41639 .84788 m .40863 .83991 L .41581 .84808 L F
.41757 .80494 m .41647 .80527 L .41639 .84788 L .57 .345 .536 r
F
.41354 .85311 m .40202 .84887 L .40003 .85167 L .683 .77 .917 r
F
.41481 .8503 m .4149 .85472 L .4148 .85457 L .989 .721 .392 r
F
.41479 .8501 m .4148 .85457 L .41479 .85443 L .789 .63 .07 r
F
.41799 .85359 m .41487 .85267 L .41354 .85311 L .683 .77 .917 r
F
.41487 .85267 m .40202 .84887 L .41354 .85311 L F
.4167 .84778 m .41639 .84788 L .41639 .85216 L .57 .345 .536 r
F
.41403 .85514 m .41354 .856 L .41487 .85556 L .683 .77 .917 r
F
.41599 .85215 m .41661 .8531 L .41737 .85191 L F
.41674 .85169 m .41682 .85599 L .41655 .85162 L .844 .572 .527 r
F
.4149 .84933 m .41474 .85386 L .41485 .85367 L 0 0 .377 r
F
.41475 .84959 m .41476 .85404 L .41474 .85386 L .789 .63 .07 r
F
.41674 .85169 m .41683 .85172 L .41682 .85599 L .844 .572 .527 r
F
.41215 .84931 m .39964 .84711 L .39887 .85002 L .683 .77 .917 r
F
.4175 .84903 m .41409 .84866 L .41215 .84931 L F
.41409 .84866 m .39964 .84711 L .41215 .84931 L F
.4175 .84903 m .41629 .85153 L .41737 .85191 L F
.41749 .84751 m .41661 .85208 L .41748 .85179 L .57 .345 .536 r
F
.41757 .80494 m .4167 .84778 L .41749 .84751 L F
.4167 .84778 m .41661 .85208 L .41749 .84751 L F
.41487 .85267 m .40511 .8464 L .40202 .84887 L .683 .77 .917 r
F
.41799 .85359 m .41578 .85236 L .41487 .85267 L F
.41578 .85236 m .40511 .8464 L .41487 .85267 L F
.41668 .86021 m .41681 .86026 L .4168 .8684 L .844 .572 .527 r
F
.41761 .86033 m .41734 .86031 L .41682 .85599 L .751 .492 .541 r
F
.41847 .85815 m .41653 .86016 L .41681 .86026 L .683 .77 .917 r
F
.41742 .86031 m .41681 .86026 L .41735 .86046 L F
.41847 .85815 m .41681 .86026 L .41742 .86031 L F
.41682 .85599 m .41669 .85626 L .41787 .85608 L F
.41722 .85602 m .41761 .86033 L .41682 .85599 L .751 .492 .541 r
F
.41761 .86033 m .41836 .86866 L .41734 .86031 L F
.41682 .85599 m .41836 .86866 L .4168 .8684 L F
.41748 .85179 m .41636 .86407 L .41746 .86374 L .57 .345 .536 r
F
.41847 .85815 m .41669 .85632 L .41576 .85664 L .683 .77 .917 r
F
.41799 .85359 m .41717 .85162 L .41651 .85207 L F
.41799 .85359 m .41651 .85207 L .41595 .85245 L F
.4157 .85554 m .41584 .85564 L .41581 .86793 L .927 .648 .492 r
F
.41847 .85815 m .41518 .85944 L .41576 .85986 L .683 .77 .917 r
F
.4155 .85276 m .41541 .85709 L .4159 .85249 L .403 .215 .509 r
F
.4175 .84903 m .40162 .84434 L .39964 .84711 L .683 .77 .917 r
F
.4175 .84903 m .40469 .84188 L .40162 .84434 L F
.41595 .85245 m .40907 .84442 L .40511 .8464 L F
.41546 .84852 m .41527 .85292 L .41536 .85286 L .403 .215 .509 r
F
.4149 .84933 m .41475 .84959 L .41474 .85386 L 0 0 .377 r
F
.41651 .85207 m .40907 .84442 L .41595 .85245 L .683 .77 .917 r
F
.41517 .85943 m .41581 .86793 L .41515 .86735 L .927 .648 .492 r
F
.41518 .85089 m .41551 .85968 L .41517 .85943 L F
.41551 .85968 m .41581 .86793 L .41517 .85943 L F
.41375 .8584 m .40051 .85623 L .39974 .85915 L .683 .77 .917 r
F
.41574 .85985 m .41551 .85968 L .41535 .85528 L .927 .648 .492 r
F
.41485 .85367 m .41474 .85386 L .41474 .85813 L 0 0 .377 r
F
.41474 .85386 m .41477 .86666 L .41472 .86586 L .789 .63 .07 r
F
.41476 .85404 m .41476 .8585 L .41474 .85386 L F
.41476 .8585 m .41477 .86666 L .41475 .85838 L F
.41476 .8585 m .41475 .85838 L .41474 .85386 L F
.41847 .85815 m .41494 .85777 L .41474 .85813 L .683 .77 .917 r
F
.41475 .85835 m .41474 .85813 L .41461 .85836 L F
.41847 .85815 m .41474 .85813 L .41475 .85835 L F
.4148 .85801 m .41474 .85813 L .41472 .86586 L 0 0 .377 r
F
.41485 .85367 m .41474 .85813 L .4148 .85801 L F
.41461 .85836 m .41252 .85751 L .41375 .8584 L .683 .77 .917 r
F
.41494 .85777 m .41252 .85751 L .41461 .85836 L F
.41252 .85751 m .40051 .85623 L .41375 .8584 L F
.41536 .85286 m .41527 .85292 L .41526 .85719 L .403 .215 .509 r
F
.41669 .85632 m .41412 .84763 L .40955 .84899 L .683 .77 .917 r
F
.4169 .80961 m .41839 .85185 L .41795 .85181 L .751 .492 .541 r
F
.41757 .80494 m .41639 .84788 L .4167 .84778 L .57 .345 .536 r
F
.41799 .85359 m .41807 .85171 L .41726 .85182 L .683 .77 .917 r
F
.41795 .85181 m .41839 .85185 L .41838 .85612 L .751 .492 .541 r
F
.41795 .85181 m .41838 .85612 L .41805 .85609 L F
.41799 .85359 m .41787 .85608 L .41906 .85617 L .683 .77 .917 r
F
.4175 .84903 m .41737 .85203 L .41865 .8518 L F
.42005 .80967 m .42106 .80924 L .42099 .85111 L .519 .305 .529 r
F
.41865 .8518 m .42183 .85949 L .41997 .85156 L .683 .77 .917 r
F
.42234 .8641 m .42668 .8746 L .43581 .8719 L F
.42165 .86141 m .42282 .86866 L .42739 .86731 L F
.42074 .86048 m .42139 .86303 L .42165 .86141 L F
.42139 .86303 m .42282 .86866 L .42165 .86141 L F
.42211 .85848 m .42221 .86599 L .4221 .86679 L 0 0 .138 r
F
.42188 .85147 m .42637 .85814 L .43031 .85617 L .683 .77 .917 r
F
.42005 .80967 m .4207 .85124 L .41997 .85156 L .519 .305 .529 r
F
.4175 .84903 m .4216 .85324 L .42188 .85147 L .683 .77 .917 r
F
.4216 .85324 m .42637 .85814 L .42188 .85147 L F
.4222 .808 m .42231 .8072 L .42224 .84921 L 0 0 .138 r
F
.4216 .85324 m .42183 .85949 L .42637 .85814 L .683 .77 .917 r
F
.42162 .85732 m .4269 .86275 L .42187 .85575 L F
.42024 .85269 m .42183 .85949 L .42058 .85219 L F
.42637 .85814 m .44311 .86331 L .43031 .85617 L F
.42203 .85478 m .43086 .86077 L .43394 .8583 L F
.41997 .85156 m .42022 .85572 L .41997 .85583 L .519 .305 .529 r
F
.41997 .85156 m .42024 .85269 L .42058 .85219 L .683 .77 .917 r
F
.4207 .85124 m .42077 .85548 L .41997 .85156 L .519 .305 .529 r
F
.42038 .86012 m .42056 .86074 L .42074 .86048 L .683 .77 .917 r
F
.41908 .85623 m .42234 .8641 L .42012 .85581 L F
.41997 .85583 m .42012 .85581 L .42011 .85577 L F
.41908 .85623 m .42012 .85581 L .41997 .85583 L F
.41952 .85164 m .41997 .85156 L .41997 .85583 L .642 .403 .542 r
F
.42031 .86004 m .41955 .86076 L .42038 .86012 L .683 .77 .917 r
F
.41933 .86022 m .41955 .86076 L .42031 .86004 L F
.41865 .8518 m .41864 .85187 L .41868 .85187 L F
.41952 .85164 m .41963 .8559 L .41839 .85185 L .642 .403 .542 r
F
.41899 .85601 m .41908 .85623 L .41997 .85583 L .683 .77 .917 r
F
.41939 .86036 m .41796 .8693 L .42282 .86866 L F
.41996 .86011 m .42096 .86803 L .41994 .86846 L .519 .305 .529 r
F
.41997 .85583 m .4203 .85995 L .41996 .86011 L F
.41955 .86076 m .42282 .86866 L .42038 .86012 L .683 .77 .917 r
F
.4203 .85995 m .42096 .86803 L .41996 .86011 L .519 .305 .529 r
F
.41933 .86022 m .4193 .8604 L .41939 .86036 L .683 .77 .917 r
F
.4193 .8604 m .41796 .8693 L .41939 .86036 L F
.41837 .86039 m .41796 .8693 L .41933 .86022 L F
.41906 .85617 m .41784 .85678 L .41908 .85623 L F
.41839 .85185 m .41994 .86846 L .41836 .86866 L .642 .403 .542 r
F
.41847 .85815 m .41837 .86039 L .41933 .86022 L .683 .77 .917 r
F
.41963 .8559 m .41973 .86015 L .41878 .85605 L .642 .403 .542 r
F
.41973 .86015 m .41994 .86846 L .41918 .86025 L F
.41973 .86015 m .41918 .86025 L .41878 .85605 L F
.41963 .8559 m .41878 .85605 L .41839 .85185 L F
.41799 .85359 m .41899 .85601 L .42011 .85577 L .683 .77 .917 r
F
.41952 .85164 m .41997 .85583 L .41963 .8559 L .642 .403 .542 r
F
.41899 .85601 m .41997 .85583 L .42011 .85577 L .683 .77 .917 r
F
.41847 .85815 m .41933 .86022 L .42031 .86004 L F
.41963 .8559 m .41997 .85583 L .41996 .86011 L .642 .403 .542 r
F
.41973 .86015 m .41996 .86011 L .41994 .86846 L F
.41963 .8559 m .41996 .86011 L .41973 .86015 L F
.42177 .80868 m .4222 .808 L .42212 .84994 L .077 0 .416 r
F
.4213 .85114 m .43031 .85617 L .42194 .85037 L .683 .77 .917 r
F
.42169 .85056 m .42194 .85037 L .42187 .85031 L F
.4213 .85114 m .42194 .85037 L .42169 .85056 L F
.42106 .80924 m .42177 .80868 L .42169 .85056 L .359 .182 .499 r
F
.4212 .85579 m .42183 .85949 L .4216 .85324 L .683 .77 .917 r
F
.42111 .85533 m .42187 .85575 L .422 .85493 L F
.42169 .85484 m .42205 .85857 L .42168 .85911 L .077 0 .416 r
F
.42169 .85056 m .42187 .85457 L .42169 .85484 L F
.42111 .85533 m .422 .85493 L .42203 .85478 L .683 .77 .917 r
F
.42187 .85457 m .42205 .85857 L .42169 .85484 L .077 0 .416 r
F
.42128 .85543 m .42162 .85732 L .42187 .85575 L .683 .77 .917 r
F
.42058 .85219 m .4212 .85579 L .4216 .85324 L F
.42108 .85531 m .42116 .85561 L .42128 .85543 L F
.42116 .85561 m .42162 .85732 L .42128 .85543 L F
.41799 .85359 m .42027 .85594 L .42108 .85531 L F
.42027 .85594 m .42162 .85732 L .42108 .85531 L F
.42149 .85072 m .42169 .85056 L .42169 .85484 L .359 .182 .499 r
F
.42183 .85949 m .42615 .86994 L .43523 .86725 L .683 .77 .917 r
F
.42066 .85633 m .42234 .8641 L .4269 .86275 L F
.42183 .85949 m .43523 .86725 L .42637 .85814 L F
.4269 .86274 m .4269 .86275 L .42396 .85692 L F
.42637 .85814 m .43523 .86725 L .44311 .86331 L F
.4269 .86275 m .44373 .86794 L .43086 .86077 L F
.42169 .8591 m .43135 .86533 L .43443 .86286 L F
.42045 .85664 m .42234 .8641 L .42066 .85633 L F
.42154 .85495 m .42167 .86747 L .42098 .85538 L .359 .182 .499 r
F
.42011 .85577 m .42018 .85601 L .42027 .85594 L .683 .77 .917 r
F
.42022 .85572 m .42096 .86803 L .41997 .85583 L .519 .305 .529 r
F
.41847 .85815 m .42106 .85959 L .42169 .8591 L .683 .77 .917 r
F
.42106 .85959 m .43135 .86533 L .42169 .8591 L F
.42154 .85495 m .42169 .85484 L .42168 .85911 L .359 .182 .499 r
F
.42158 .85919 m .42168 .85911 L .42167 .86747 L F
.42154 .85495 m .42168 .85911 L .42158 .85919 L F
.42149 .85072 m .42169 .85484 L .42154 .85495 L F
.42106 .80924 m .42169 .85056 L .42149 .85072 L F
.42208 .84999 m .42212 .84994 L .42212 .85421 L .077 0 .416 r
F
.42177 .80868 m .42212 .84994 L .42208 .84999 L F
.42187 .85031 m .43031 .85617 L .43338 .85372 L .683 .77 .917 r
F
.4175 .84903 m .4213 .85114 L .42187 .85031 L F
.42177 .80868 m .422 .85012 L .42169 .85056 L .077 0 .416 r
F
.42241 .84955 m .43338 .85372 L .43536 .85094 L .683 .77 .917 r
F
.42005 .80967 m .42099 .85111 L .4207 .85124 L .519 .305 .529 r
F
.4175 .84903 m .42296 .85064 L .42241 .84955 L .683 .77 .917 r
F
.42296 .85064 m .43338 .85372 L .42241 .84955 L F
.42231 .8072 m .42186 .80617 L .42179 .84832 L .985 .728 .345 r
F
.42183 .84841 m .42179 .84832 L .42178 .8526 L F
.42231 .8072 m .42179 .84832 L .42183 .84841 L F
.42234 .8641 m .43581 .8719 L .4269 .86275 L .683 .77 .917 r
F
.42108 .85961 m .42739 .86731 L .43135 .86533 L F
.42025 .85998 m .42667 .86657 L .42108 .85961 L F
.42667 .86657 m .42739 .86731 L .42648 .8662 L F
.42667 .86657 m .42648 .8662 L .42108 .85961 L F
.42221 .85786 m .42222 .85776 L .42221 .86599 L 0 0 .138 r
F
.42221 .85786 m .42221 .86599 L .42211 .85848 L F
.42168 .85911 m .4221 .86679 L .42167 .86747 L .077 0 .416 r
F
.42205 .85857 m .4221 .86679 L .42168 .85911 L F
.42222 .85776 m .42176 .86496 L .42221 .86599 L .985 .728 .345 r
F
.42212 .85421 m .42221 .85786 L .42211 .85848 L 0 0 .138 r
F
.42187 .85575 m .43086 .86077 L .42203 .85478 L .683 .77 .917 r
F
.42217 .8539 m .42221 .85786 L .42212 .85421 L 0 0 .138 r
F
.42221 .85364 m .42223 .85349 L .42222 .85776 L F
.42221 .85364 m .42222 .85776 L .42221 .85786 L F
.42223 .85349 m .42207 .85745 L .42222 .85776 L .985 .728 .345 r
F
.42203 .85434 m .42212 .85421 L .42211 .85848 L .077 0 .416 r
F
.42205 .85857 m .42211 .85848 L .4221 .86679 L F
.42203 .85434 m .42211 .85848 L .42205 .85857 L F
.42248 .85794 m .43642 .86007 L .4372 .85715 L .683 .77 .917 r
F
.42098 .85538 m .42121 .85947 L .42098 .85965 L .359 .182 .499 r
F
.41847 .85815 m .42207 .85854 L .42248 .85794 L .683 .77 .917 r
F
.42396 .85692 m .4269 .86275 L .43086 .86077 L F
.42187 .85575 m .4269 .86274 L .42396 .85692 L F
.42207 .85854 m .43642 .86007 L .42248 .85794 L F
.42207 .85745 m .42176 .86496 L .42222 .85776 L .985 .728 .345 r
F
.42083 .85972 m .42096 .86803 L .42047 .85988 L .519 .305 .529 r
F
.41847 .85815 m .42219 .85795 L .42229 .85734 L .683 .77 .917 r
F
.42056 .86074 m .42282 .86866 L .42074 .86048 L F
.42121 .85947 m .42167 .86747 L .42098 .85965 L .359 .182 .499 r
F
.42099 .85111 m .42154 .85495 L .42098 .85538 L F
.42106 .80924 m .42149 .85072 L .42099 .85111 L F
.42149 .85072 m .42154 .85495 L .42099 .85111 L F
.42413 .84867 m .43536 .85094 L .43613 .84803 L .683 .77 .917 r
F
.43031 .85617 m .44925 .8584 L .43338 .85372 L F
.4245 .85429 m .43394 .8583 L .43594 .85551 L F
.42077 .85548 m .42022 .85572 L .41997 .85156 L .519 .305 .529 r
F
.4207 .85124 m .42098 .85538 L .42077 .85548 L F
.41799 .85359 m .42827 .85662 L .4245 .85429 L .683 .77 .917 r
F
.42827 .85662 m .43394 .8583 L .4245 .85429 L F
.42018 .85601 m .42234 .8641 L .42027 .85594 L F
.42178 .8526 m .42071 .86415 L .42176 .86496 L .908 .63 .503 r
F
.42179 .84832 m .42151 .85243 L .42178 .8526 L F
.42113 .85647 m .42177 .85686 L .42147 .85626 L .683 .77 .917 r
F
.42027 .85594 m .42045 .85664 L .42066 .85633 L F
.42077 .85548 m .42083 .85972 L .42022 .85572 L .519 .305 .529 r
F
.41847 .85815 m .42177 .85686 L .42113 .85647 L .683 .77 .917 r
F
.42177 .85686 m .42177 .85686 L .42113 .85647 L F
.42295 .85332 m .43594 .85551 L .43671 .85259 L F
.41799 .85359 m .4245 .85429 L .42295 .85332 L F
.4245 .85429 m .43594 .85551 L .42295 .85332 L F
.4175 .84903 m .42293 .84961 L .42334 .84929 L F
.4175 .84903 m .42334 .84929 L .42249 .84876 L F
.42103 .84785 m .42095 .85208 L .42179 .84832 L .908 .63 .503 r
F
.42077 .85548 m .42098 .85538 L .42096 .86803 L .519 .305 .529 r
F
.42123 .85653 m .42141 .85664 L .42178 .8526 L .908 .63 .503 r
F
.42293 .84961 m .43536 .85094 L .42413 .84867 L .683 .77 .917 r
F
.4207 .85124 m .42099 .85111 L .42098 .85538 L .519 .305 .529 r
F
.422 .85012 m .42203 .85434 L .42169 .85056 L .077 0 .416 r
F
.42203 .85434 m .42205 .85857 L .42187 .85457 L F
.42203 .85434 m .42187 .85457 L .42169 .85056 L F
.42331 .85246 m .43671 .85259 L .43621 .84974 L .683 .77 .917 r
F
.42083 .85972 m .42047 .85988 L .42022 .85572 L .519 .305 .529 r
F
.42073 .85194 m .41963 .86377 L .42071 .86415 L .809 .541 .534 r
F
.4175 .84903 m .42249 .84876 L .42155 .84817 L .683 .77 .917 r
F
.42103 .84785 m .42072 .85621 L .42086 .8563 L .908 .63 .503 r
F
.42186 .80617 m .42091 .84778 L .42103 .84785 L F
.42082 .852 m .42088 .85203 L .42103 .84785 L F
.42183 .84841 m .42178 .8526 L .42192 .84858 L .985 .728 .345 r
F
.42249 .84876 m .42334 .84929 L .42413 .84867 L .683 .77 .917 r
F
.422 .85012 m .42212 .85421 L .42203 .85434 L .077 0 .416 r
F
.42177 .80868 m .42208 .84999 L .422 .85012 L F
.42208 .84999 m .42212 .85421 L .422 .85012 L F
.42363 .84773 m .43613 .84803 L .43563 .84519 L .683 .77 .917 r
F
.4217 .84814 m .42336 .84813 L .42363 .84773 L F
.42336 .84813 m .43613 .84803 L .42363 .84773 L F
.42212 .84994 m .42217 .8539 L .42212 .85421 L 0 0 .138 r
F
.42221 .84942 m .42224 .84921 L .42223 .85349 L F
.42221 .84942 m .42223 .85349 L .42221 .85364 L F
.42221 .84942 m .42221 .85364 L .42212 .84994 L F
.42221 .85364 m .42221 .85786 L .42217 .8539 L F
.42221 .85364 m .42217 .8539 L .42212 .84994 L F
.42249 .85183 m .43621 .84974 L .43447 .84714 L .683 .77 .917 r
F
.41847 .80987 m .41997 .85156 L .41952 .85164 L .642 .403 .542 r
F
.41996 .84748 m .41966 .85168 L .41988 .85173 L .809 .541 .534 r
F
.42081 .80535 m .41976 .84743 L .41996 .84748 L F
.41976 .84743 m .41966 .85168 L .41996 .84748 L F
.4222 .808 m .42224 .84921 L .42221 .84942 L 0 0 .138 r
F
.4222 .808 m .42221 .84942 L .42212 .84994 L F
.42231 .8072 m .42192 .84858 L .42224 .84921 L .985 .728 .345 r
F
.42231 .8072 m .42183 .84841 L .42192 .84858 L F
.42186 .80617 m .42103 .84785 L .42179 .84832 L .908 .63 .503 r
F
.41847 .80987 m .42005 .80967 L .41997 .85156 L .642 .403 .542 r
F
.41799 .85359 m .42066 .8519 L .42035 .85171 L .683 .77 .917 r
F
.42073 .84767 m .41988 .85173 L .42073 .85194 L .809 .541 .534 r
F
.41982 .85169 m .42035 .85171 L .42001 .85149 L .683 .77 .917 r
F
.41799 .85359 m .42035 .85171 L .41982 .85169 L F
.41966 .85168 m .41855 .86365 L .41963 .86377 L .734 .478 .542 r
F
.41966 .84741 m .41937 .85167 L .41966 .85168 L F
.41799 .85359 m .42241 .85235 L .42163 .85216 L .683 .77 .917 r
F
.41937 .85167 m .41908 .85593 L .41966 .85168 L .734 .478 .542 r
F
.41908 .85593 m .41926 .85594 L .41966 .85168 L F
.41847 .85815 m .41954 .85595 L .41857 .85591 L .683 .77 .917 r
F
.41847 .80987 m .41952 .85164 L .41839 .85185 L .642 .403 .542 r
F
.4175 .84903 m .41996 .84748 L .41966 .84741 L .683 .77 .917 r
F
.41888 .84738 m .41855 .86365 L .41966 .84741 L .734 .478 .542 r
F
.41974 .80498 m .41888 .84738 L .41966 .84741 L F
.41909 .84738 m .41966 .84741 L .41918 .84729 L .683 .77 .917 r
F
.41976 .84743 m .41966 .84741 L .41966 .85168 L .809 .541 .534 r
F
.42179 .84832 m .42171 .84817 L .42155 .84817 L .683 .77 .917 r
F
.42249 .84876 m .42171 .84817 L .42179 .84832 L F
.42091 .84778 m .42082 .852 L .42103 .84785 L .908 .63 .503 r
F
.41996 .84748 m .41988 .85173 L .42073 .84767 L .809 .541 .534 r
F
.42155 .84817 m .42171 .84817 L .4217 .84814 L .683 .77 .917 r
F
.42091 .84778 m .42073 .84767 L .42073 .85194 L .908 .63 .503 r
F
.41799 .85359 m .42271 .85334 L .42325 .85256 L .683 .77 .917 r
F
.42082 .852 m .42073 .85194 L .42072 .85621 L .908 .63 .503 r
F
.42091 .84778 m .42073 .85194 L .42082 .852 L F
.41996 .84748 m .43104 .84047 L .41918 .84729 L .683 .77 .917 r
F
.41858 .84737 m .41746 .86374 L .41855 .86365 L .661 .418 .542 r
F
.41866 .80485 m .41779 .84747 L .41858 .84737 L F
.4175 .84903 m .41918 .84729 L .41843 .84711 L .683 .77 .917 r
F
.4175 .84903 m .41843 .84711 L .4176 .8469 L F
.41779 .84747 m .41762 .85604 L .41858 .84737 L .661 .418 .542 r
F
.4175 .84903 m .41966 .84741 L .41909 .84738 L .683 .77 .917 r
F
.41799 .85359 m .41682 .85599 L .41787 .85608 L F
.41779 .84747 m .41748 .85606 L .41762 .85604 L .661 .418 .542 r
F
.41866 .80485 m .41767 .84749 L .41779 .84747 L F
.41767 .84749 m .41748 .85606 L .41779 .84747 L F
.41691 .84759 m .41802 .83792 L .41317 .83856 L .683 .77 .917 r
F
.4175 .84903 m .41757 .8475 L .41691 .84759 L F
.41866 .80485 m .41757 .80494 L .41748 .85179 L .661 .418 .542 r
F
.41757 .8475 m .41802 .83792 L .41691 .84759 L .683 .77 .917 r
F
.4176 .8469 m .41811 .84604 L .41765 .84576 L F
.41726 .85182 m .4185 .84243 L .41364 .84307 L F
.41807 .85171 m .4185 .84243 L .41726 .85182 L F
.41758 .85177 m .41748 .85179 L .41748 .85606 L .661 .418 .542 r
F
.41661 .85208 m .41652 .85638 L .41748 .85179 L .57 .345 .536 r
F
.4167 .84778 m .41639 .85216 L .41661 .85208 L F
.41558 .84844 m .4155 .85276 L .41639 .84788 L .403 .215 .509 r
F
.41717 .85162 m .41364 .84307 L .41651 .85207 L .683 .77 .917 r
F
.4176 .85604 m .41899 .84699 L .41412 .84763 L F
.41847 .85815 m .41857 .85591 L .4176 .85604 L F
.41762 .85604 m .41799 .85599 L .41829 .85168 L .661 .418 .542 r
F
.4175 .84903 m .41865 .8518 L .41997 .85156 L .683 .77 .917 r
F
.4181 .8517 m .41829 .85168 L .41858 .84737 L .661 .418 .542 r
F
.41762 .85604 m .41829 .85168 L .4181 .8517 L F
.42147 .84748 m .43563 .84519 L .4339 .84262 L .683 .77 .917 r
F
.4175 .84903 m .42432 .84759 L .42147 .84748 L F
.42432 .84759 m .43563 .84519 L .42147 .84748 L F
.41974 .80498 m .41866 .80485 L .41858 .84737 L .734 .478 .542 r
F
.41868 .84737 m .41858 .84737 L .41857 .85164 L F
.41974 .80498 m .41858 .84737 L .41868 .84737 L F
.41879 .85165 m .41857 .85164 L .41855 .86365 L F
.41974 .80498 m .41857 .85164 L .41879 .85165 L F
.42186 .80617 m .42081 .80535 L .42073 .84767 L .908 .63 .503 r
F
.41843 .84711 m .42332 .84257 L .42067 .84248 L .683 .77 .917 r
F
.42332 .84257 m .42727 .83891 L .42067 .84248 L F
.42067 .84248 m .42727 .83891 L .42282 .83804 L F
.41918 .84729 m .42727 .83891 L .41843 .84711 L F
.41811 .84604 m .42282 .83804 L .41765 .84576 L F
.41843 .84711 m .42282 .83804 L .4176 .8469 L F
.41808 .85162 m .42333 .84255 L .4185 .84243 L F
.41807 .85171 m .41812 .85162 L .41808 .85162 L F
.41812 .85162 m .42333 .84255 L .41808 .85162 L F
.41799 .85359 m .41896 .85158 L .41807 .85171 L F
.42081 .80535 m .41996 .84748 L .42073 .84767 L .809 .541 .534 r
F
.4175 .84903 m .42346 .8467 L .42056 .84709 L .683 .77 .917 r
F
.41896 .85158 m .42333 .84255 L .41807 .85171 L F
.41799 .85359 m .42001 .85149 L .41923 .85101 L F
.41857 .85591 m .41899 .84699 L .4176 .85604 L F
.41762 .85604 m .41746 .86374 L .41799 .85599 L .661 .418 .542 r
F
.42056 .84709 m .4339 .84262 L .43104 .84047 L .683 .77 .917 r
F
.42346 .8467 m .4339 .84262 L .42056 .84709 L F
.41923 .85101 m .4278 .84342 L .42333 .84255 L F
.42249 .84876 m .43613 .84803 L .42171 .84817 L F
.42001 .85149 m .4278 .84342 L .41923 .85101 L F
.42095 .85208 m .42151 .85243 L .42179 .84832 L .908 .63 .503 r
F
.41857 .85591 m .42382 .84711 L .41899 .84699 L .683 .77 .917 r
F
.41799 .85359 m .42236 .85266 L .42241 .85235 L F
.42192 .84858 m .42188 .85278 L .42224 .84921 L .985 .728 .345 r
F
.41954 .85595 m .42382 .84711 L .41857 .85591 L .683 .77 .917 r
F
.41847 .85815 m .42025 .85998 L .42108 .85961 L F
.41908 .85593 m .41855 .86365 L .41926 .85594 L .734 .478 .542 r
F
.41918 .84729 m .43104 .84047 L .42727 .83891 L .683 .77 .917 r
F
.42081 .80535 m .41974 .80498 L .41966 .84741 L .809 .541 .534 r
F
.42081 .80535 m .41966 .84741 L .41976 .84743 L F
.42224 .84921 m .42188 .85278 L .42223 .85349 L .985 .728 .345 r
F
.42163 .85216 m .42241 .85235 L .42249 .85183 L .683 .77 .917 r
F
.42171 .84817 m .43613 .84803 L .4217 .84814 L F
.42066 .8519 m .4316 .84499 L .42001 .85149 L F
.42082 .852 m .42072 .85621 L .42088 .85203 L .908 .63 .503 r
F
.42307 .85251 m .42325 .85256 L .42331 .85246 L .683 .77 .917 r
F
.41799 .85359 m .42325 .85256 L .42307 .85251 L F
.42192 .84858 m .42178 .8526 L .42188 .85278 L .985 .728 .345 r
F
.42095 .85208 m .42086 .8563 L .42151 .85243 L .908 .63 .503 r
F
.42151 .85243 m .42123 .85653 L .42178 .8526 L F
.41799 .85359 m .42111 .85533 L .42203 .85478 L .683 .77 .917 r
F
.41799 .85359 m .43447 .84714 L .4316 .84499 L F
.41955 .85593 m .42828 .84799 L .42382 .84711 L F
.41847 .85815 m .42041 .85614 L .41955 .85593 L F
.41988 .85173 m .41979 .85599 L .42073 .85194 L .809 .541 .534 r
F
.41847 .85815 m .42113 .85647 L .42072 .85621 L .683 .77 .917 r
F
.41847 .85815 m .42072 .85621 L .42041 .85614 L F
.41979 .85599 m .41963 .86377 L .42034 .85612 L .809 .541 .534 r
F
.41979 .85599 m .42034 .85612 L .42073 .85194 L F
.42041 .85614 m .42072 .85621 L .42048 .85607 L .683 .77 .917 r
F
.42086 .8563 m .42123 .85653 L .42151 .85243 L .908 .63 .503 r
F
.42188 .85278 m .42178 .8526 L .42177 .85687 L .985 .728 .345 r
F
.42041 .85614 m .42828 .84799 L .41955 .85593 L .683 .77 .917 r
F
.41988 .85173 m .41966 .85168 L .41965 .85595 L .809 .541 .534 r
F
.41979 .85599 m .41965 .85595 L .41963 .86377 L F
.41988 .85173 m .41965 .85595 L .41979 .85599 L F
.42236 .85266 m .43621 .84974 L .42249 .85183 L .683 .77 .917 r
F
.42001 .85149 m .4316 .84499 L .4278 .84342 L F
.41765 .84576 m .42282 .83804 L .41802 .83792 L F
.42271 .85334 m .43671 .85259 L .42331 .85246 L F
.42186 .80617 m .42073 .84767 L .42091 .84778 L .908 .63 .503 r
F
.42086 .8563 m .42072 .85621 L .42071 .86415 L F
.43086 .86077 m .44989 .86301 L .43394 .8583 L .683 .77 .917 r
F
.42496 .85884 m .43443 .86286 L .43642 .86007 L F
.41847 .85815 m .42871 .86117 L .42496 .85884 L F
.42871 .86117 m .43443 .86286 L .42496 .85884 L F
.42048 .85607 m .43208 .84955 L .42828 .84799 L F
.42188 .85278 m .42177 .85687 L .42184 .85699 L .985 .728 .345 r
F
.42113 .85647 m .43208 .84955 L .42048 .85607 L .683 .77 .917 r
F
.42086 .8563 m .42071 .86415 L .42123 .85653 L .908 .63 .503 r
F
.42123 .85653 m .42071 .86415 L .42141 .85664 L F
.42147 .85626 m .43495 .85171 L .43208 .84955 L .683 .77 .917 r
F
.42177 .85686 m .43495 .85171 L .42147 .85626 L F
.42184 .85699 m .42177 .85687 L .42176 .86496 L .985 .728 .345 r
F
.42229 .85734 m .4372 .85715 L .4367 .8543 L .683 .77 .917 r
F
.42219 .85795 m .4372 .85715 L .42229 .85734 L F
.42177 .85686 m .4367 .8543 L .43495 .85171 L F
.41847 .85815 m .42204 .8574 L .42177 .85686 L F
.42204 .8574 m .4367 .8543 L .42177 .85686 L F
.42188 .85278 m .42184 .85699 L .42223 .85349 L .985 .728 .345 r
F
.42184 .85699 m .42176 .86496 L .42207 .85745 L F
.42184 .85699 m .42207 .85745 L .42223 .85349 L F
.42098 .85965 m .42167 .86747 L .42096 .86803 L .359 .182 .499 r
F
.41866 .80485 m .41748 .85179 L .41758 .85177 L .661 .418 .542 r
F
.41847 .85815 m .4176 .85604 L .41669 .85632 L .683 .77 .917 r
F
.41762 .85604 m .41748 .85606 L .41746 .86374 L .661 .418 .542 r
F
.4176 .85604 m .41759 .85602 L .41748 .85606 L .683 .77 .917 r
F
.4176 .85604 m .41748 .85606 L .41669 .85632 L F
.41652 .85638 m .41708 .85619 L .41748 .85179 L .57 .345 .536 r
F
.41661 .85208 m .41639 .85216 L .41638 .85643 L F
.41661 .85208 m .41638 .85643 L .41652 .85638 L F
.41759 .85602 m .41412 .84763 L .41669 .85632 L .683 .77 .917 r
F
.41652 .85638 m .41636 .86407 L .41708 .85619 L .57 .345 .536 r
F
.41576 .85664 m .40955 .84899 L .40559 .85097 L .683 .77 .917 r
F
.41669 .85632 m .40955 .84899 L .41576 .85664 L F
.41652 .85638 m .41638 .85643 L .41636 .86407 L .57 .345 .536 r
F
.41651 .85207 m .41364 .84307 L .40907 .84442 L .683 .77 .917 r
F
.41609 .85573 m .41633 .86009 L .41584 .85564 L .844 .572 .527 r
F
.41541 .85709 m .41525 .86484 L .41638 .85643 L .403 .215 .509 r
F
.41518 .85944 m .40771 .86236 L .41576 .85986 L .683 .77 .917 r
F
.40439 .86218 m .39838 .87389 L .40818 .86374 L F
.40771 .86236 m .402 .86459 L .40692 .8629 L F
.40771 .86236 m .40692 .8629 L .41576 .85986 L F
.41647 .80527 m .41528 .84865 L .41546 .84852 L .403 .215 .509 r
F
.41541 .85709 m .41526 .85719 L .41525 .86484 L F
.40692 .8629 m .402 .86459 L .40317 .86547 L .683 .77 .917 r
F
.40692 .8629 m .40317 .86547 L .40487 .86674 L F
.75191 .6272 m .75902 .64697 L .7743 .64376 L .654 .726 .902 r
F
.74377 .62746 m .75902 .64697 L .75191 .6272 L F
.53921 .75481 m .55675 .75334 L .55708 .759 L .794 .544 .561 r
F
.53921 .75481 m .53889 .74915 L .55675 .75334 L F
0 g
.55675 .75334 m
.57609 .75452 L
s
.72246 .6131 m .71234 .63306 L .72874 .61661 L .654 .726 .902 r
F
.72246 .6131 m .69976 .62605 L .71234 .63306 L F
.6892 .63189 m .67594 .65371 L .69873 .64071 L F
0 g
.67298 .65098 m
.67594 .65371 L
s
.67594 .65371 m
.6949 .66427 L
s
.37556 .76211 m .35432 .755 L .3464 .766 L .673 .758 .914 r
F
.37769 .88391 m .38859 .88403 L .38908 .88859 L .858 .591 .533 r
F
0 g
.38364 .88398 m
.38364 .882 L
s
.127 .923 .03 r
.38741 .88355 m
.38742 .88402 L
s
.3867 .88325 m
.3867 .88401 L
s
.37769 .88391 m .37721 .87935 L .38859 .88403 L .858 .591 .533 r
F
.39079 .87077 m .38859 .88403 L .39838 .87389 L .683 .77 .917 r
F
.39079 .87077 m .37721 .87935 L .38859 .88403 L F
0 g
.38859 .88403 m
.3927 .88484 L
s
.75987 .61824 m .77454 .63632 L .78775 .63066 L .654 .726 .902 r
F
.75226 .61984 m .77454 .63632 L .75987 .61824 L F
.3543 .76056 m .34604 .76595 L .34634 .77161 L .167 .072 .494 r
F
.3543 .76056 m .354 .75489 L .34604 .76595 L F
0 g
.34299 .7777 m
.34604 .76595 L
s
.45658 .87511 m .45609 .87055 L .46534 .86316 L .406 .262 .57 r
F
.127 .923 .03 r
.48635 .89807 m
.48674 .86266 L
s
0 g
.44924 .87398 m
.45609 .87055 L
s
.55218 .7357 m .55686 .75312 L .56404 .73849 L .673 .758 .914 r
F
.55218 .7357 m .53909 .74895 L .55686 .75312 L F
.42508 .76171 m .41934 .7463 L .41866 .76132 L F
.42508 .76171 m .43218 .74708 L .41934 .7463 L F
.44311 .86331 m .4559 .87045 L .46511 .86309 L .683 .77 .917 r
F
.43523 .86725 m .4559 .87045 L .44311 .86331 L F
.80857 .66065 m .82451 .64173 L .82413 .649 L .349 .172 .494 r
F
.7872 .64534 m .80857 .66065 L .82413 .649 L .654 .726 .902 r
F
.77391 .65103 m .80857 .66065 L .7872 .64534 L F
0 g
.78865 .66917 m
.80857 .66065 L
s
.57674 .76584 m .57641 .76018 L .59591 .75828 L .672 .45 .575 r
F
.5574 .76466 m .57641 .76018 L .57674 .76584 L .733 .497 .571 r
F
.5574 .76466 m .55708 .759 L .57641 .76018 L F
.57719 .74509 m .57641 .76018 L .59591 .75828 L .673 .758 .914 r
F
.56429 .7443 m .57641 .76018 L .57719 .74509 L F
.56429 .7443 m .55708 .759 L .57641 .76018 L F
.4916 .7746 m .48431 .75816 L .48463 .76382 L .987 .712 .385 r
F
0 g
.4916 .7746 m
.49359 .78626 L
s
.37595 .77337 m .34664 .77728 L .37064 .78073 L .673 .758 .915 r
F
.60933 .64966 m .64189 .64617 L .61063 .64453 L .654 .726 .902 r
F
.4122 .76195 m .40641 .74756 L .39426 .75078 L .673 .758 .914 r
F
.41866 .76132 m .40641 .74756 L .4122 .76195 L F
.127 .923 .03 r
.37399 .63673 m
.374 .64034 L
s
.32519 .63655 m .32448 .65658 L .34071 .65606 L .654 .726 .902 r
F
.31711 .63544 m .32448 .65658 L .32519 .63655 L F
.31711 .63544 m .30834 .65436 L .32448 .65658 L F
.127 .923 .03 r
.46271 .66634 m
.46298 .73027 L
s
.46216 .73581 m
.46271 .66634 L
s
.41866 .76132 m .41934 .7463 L .40641 .74756 L .673 .758 .914 r
F
.43139 .76869 m .43256 .7526 L .42542 .7673 L F
.43139 .76869 m .44449 .75539 L .43256 .7526 L F
.43676 .77666 m .4448 .76106 L .43169 .77436 L .673 .758 .915 r
F
.43676 .77666 m .45495 .76566 L .4448 .76106 L F
.59591 .75828 m .61391 .74777 L .61424 .75343 L .604 .398 .575 r
F
.59623 .76394 m .59591 .75828 L .61424 .75343 L F
.57674 .76584 m .59591 .75828 L .59623 .76394 L .672 .45 .575 r
F
.59019 .74382 m .59591 .75828 L .61424 .75343 L .673 .758 .914 r
F
.57719 .74509 m .59591 .75828 L .59019 .74382 L F
0 g
.57641 .76018 m
.59591 .75828 L
s
.52012 .62217 m .49028 .61543 L .48646 .63075 L .654 .726 .902 r
F
.4894 .62259 m .48599 .63072 L .48556 .63799 L 0 0 .144 r
F
0 g
.48654 .63408 m
.48719 .63807 L
s
.4894 .62259 m .48983 .61533 L .48599 .63072 L 0 0 .144 r
F
.52012 .62217 m .48646 .63075 L .51757 .63237 L .654 .726 .902 r
F
.127 .923 .03 r
.49825 .61723 m
.49834 .60956 L
s
.44525 .66075 m .44568 .65348 L .42149 .65016 L .732 .488 .56 r
F
0 g
.44568 .65348 m
.46806 .66066 L
s
.54996 .6289 m .51757 .63237 L .54867 .634 L .654 .726 .902 r
F
.54996 .6289 m .52012 .62217 L .51757 .63237 L F
.61088 .63726 m .64035 .62846 L .61006 .63204 L F
.61088 .63726 m .64199 .63889 L .64035 .62846 L F
.30372 .62225 m .29386 .64231 L .31009 .62578 L F
.30372 .62225 m .28112 .63527 L .29386 .64231 L F
.40638 .76916 m .39445 .75632 L .38387 .76131 L .673 .758 .914 r
F
.41248 .76754 m .39445 .75632 L .40638 .76916 L F
.30964 .63305 m .30834 .65436 L .31711 .63544 L .654 .726 .902 r
F
.30964 .63305 m .2934 .64958 L .30834 .65436 L F
.127 .923 .03 r
.43963 .63242 m
.43979 .60016 L
s
.33331 .63629 m .34071 .65606 L .35593 .65285 L .654 .726 .902 r
F
.32519 .63655 m .34071 .65606 L .33331 .63629 L F
.34137 .62742 m .35638 .64558 L .36956 .6399 L F
.33376 .62902 m .35638 .64558 L .34137 .62742 L F
.39127 .87533 m .38908 .88859 L .39887 .87845 L .683 .77 .917 r
F
.39127 .87533 m .37769 .88391 L .38908 .88859 L F
0 g
.38908 .88859 m
.40246 .89121 L
s
.127 .923 .03 r
.38671 .89421 m
.38681 .98118 L
s
.3867 .88762 m
.38671 .89421 L
s
.38755 .89385 m
.38798 .92553 L
s
.38747 .88794 m
.38755 .89385 L
s
0 g
.3835 .93811 m
.38363 .88635 L
s
.46229 .7661 m .47283 .749 L .45464 .76 L .673 .758 .914 r
F
.46229 .7661 m .48431 .75816 L .47283 .749 L F
.45658 .87511 m .46534 .86316 L .46583 .86772 L .406 .262 .57 r
F
.45707 .87967 m .45658 .87511 L .46583 .86772 L F
.44373 .86794 m .45658 .87511 L .46583 .86772 L .683 .77 .917 r
F
.43581 .8719 m .45658 .87511 L .44373 .86794 L F
0 g
.44972 .87853 m
.45658 .87511 L
s
.42186 .80617 m
.4219 .78645 L
s
.41536 .80605 m
.41539 .78656 L
s
.74338 .63473 m .74238 .65476 L .75863 .65424 L .654 .726 .902 r
F
.73532 .63362 m .74238 .65476 L .74338 .63473 L F
.73532 .63362 m .72626 .65255 L .74238 .65476 L F
.40139 .77731 m .38418 .76697 L .37595 .77337 L .673 .758 .915 r
F
.40668 .77482 m .38418 .76697 L .40139 .77731 L F
.23515 .62006 m .24452 .62779 L .24405 .63505 L .989 .743 .466 r
F
.23515 .62006 m .23561 .61279 L .24452 .62779 L F
0 g
.24452 .62779 m
.25032 .63308 L
s
.38374 .75575 m .35432 .755 L .37556 .76211 L .673 .758 .914 r
F
.53953 .76047 m .55708 .759 L .5574 .76466 L .794 .544 .561 r
F
.53953 .76047 m .53921 .75481 L .55708 .759 L F
.55237 .7415 m .55708 .759 L .56429 .7443 L .673 .758 .914 r
F
.55237 .7415 m .53921 .75481 L .55708 .759 L F
0 g
.55708 .759 m
.57641 .76018 L
s
.61424 .75343 m .61391 .74777 L .62983 .74028 L .518 .333 .569 r
F
.127 .923 .03 r
.65574 .74628 m
.65606 .73624 L
s
0 g
.60559 .74997 m
.61391 .74777 L
s
.2663 .60915 m .24493 .62766 L .2722 .6191 L .654 .726 .902 r
F
.2663 .60915 m .23607 .61274 L .24493 .62766 L F
.37565 .7677 m .3543 .76056 L .34634 .77161 L .673 .758 .914 r
F
.35461 .76622 m .34634 .77161 L .34664 .77728 L .167 .072 .494 r
F
.35461 .76622 m .3543 .76056 L .34634 .77161 L F
0 g
.34329 .78337 m
.34634 .77161 L
s
.60197 .73479 m .61373 .74757 L .62957 .74012 L .673 .758 .914 r
F
.58981 .73801 m .61373 .74757 L .60197 .73479 L F
.40652 .64355 m .40696 .63629 L .41689 .62228 L .069 0 .394 r
F
0 g
.39921 .64216 m
.40696 .63629 L
s
.42542 .7673 m .41966 .75181 L .41897 .7669 L .673 .758 .914 r
F
.42542 .7673 m .43256 .7526 L .41966 .75181 L F
.57751 .75075 m .57674 .76584 L .59623 .76394 L .673 .758 .915 r
F
.56461 .74996 m .57674 .76584 L .57751 .75075 L F
.56461 .74996 m .5574 .76466 L .57674 .76584 L F
.37999 .62474 m .40656 .63612 L .41644 .62218 L .654 .726 .902 r
F
.36979 .63248 m .40656 .63612 L .37999 .62474 L F
0 g
.42181 .83802 m
.42186 .80617 L
s
.4153 .83828 m
.41536 .80605 L
s
.44525 .66075 m .42149 .65016 L .42105 .65743 L .732 .488 .56 r
F
.127 .923 .03 r
.43921 .7121 m
.43963 .63242 L
s
0 g
.42149 .65016 m
.44568 .65348 L
s
.44525 .66075 m
.46762 .66793 L
s
.40609 .65065 m
.42149 .65016 L
s
.41248 .76754 m .40665 .75308 L .39445 .75632 L .673 .758 .914 r
F
.41897 .7669 m .40665 .75308 L .41248 .76754 L F
.72195 .62043 m .71177 .64049 L .72827 .62396 L .654 .726 .902 r
F
.72195 .62043 m .69913 .63345 L .71177 .64049 L F
.72787 .63122 m .72626 .65255 L .73532 .63362 L F
.72787 .63122 m .71138 .64776 L .72626 .65255 L F
.41897 .7669 m .41966 .75181 L .40665 .75308 L .673 .758 .914 r
F
.75151 .63447 m .75863 .65424 L .77391 .65103 L .654 .726 .902 r
F
.74338 .63473 m .75863 .65424 L .75151 .63447 L F
.75955 .62559 m .7743 .64376 L .78758 .63808 L F
.75191 .6272 m .7743 .64376 L .75955 .62559 L F
.43169 .77436 m .43287 .75826 L .42573 .77296 L .673 .758 .915 r
F
.43169 .77436 m .4448 .76106 L .43287 .75826 L F
.59623 .76394 m .61424 .75343 L .61456 .75909 L .604 .398 .575 r
F
.59052 .74948 m .59623 .76394 L .61456 .75909 L .673 .758 .915 r
F
.57751 .75075 m .59623 .76394 L .59052 .74948 L F
0 g
.57674 .76584 m
.59623 .76394 L
s
.36859 .8729 m .37673 .87479 L .37721 .87935 L .931 .647 .48 r
F
.36859 .8729 m .36811 .86834 L .37673 .87479 L F
0 g
.37673 .87479 m
.38139 .87671 L
s
.38473 .86184 m .37693 .87466 L .39045 .86612 L .683 .77 .917 r
F
.38473 .86184 m .36836 .86825 L .37693 .87466 L F
.45707 .87967 m .46583 .86772 L .46632 .87228 L .406 .262 .57 r
F
.44421 .8725 m .45707 .87967 L .46632 .87228 L .683 .77 .917 r
F
.127 .923 .03 r
.46327 .80004 m
.46328 .80425 L
s
.43629 .87646 m .45707 .87967 L .44421 .8725 L .683 .77 .917 r
F
0 g
.44519 .8856 m
.45707 .87967 L
s
.29949 .61053 m .28181 .62788 L .30429 .61492 L .654 .726 .902 r
F
.29949 .61053 m .2722 .6191 L .28181 .62788 L F
.60891 .65692 m .64149 .65343 L .61022 .6518 L F
.82451 .64173 m .82489 .63447 L .83504 .62046 L .087 0 .405 r
F
0 g
.81629 .64092 m
.82489 .63447 L
s
.127 .923 .03 r
.56844 .8308 m
.56853 .82658 L
s
.56853 .82658 m
.56981 .76583 L
s
.56981 .76583 m
.56984 .76472 L
s
.34831 .61723 m .36979 .63248 L .37999 .62474 L .654 .726 .902 r
F
.34175 .62006 m .36979 .63248 L .34831 .61723 L F
.79807 .62292 m .82449 .6343 L .83459 .62036 L F
.78775 .63066 m .82449 .6343 L .79807 .62292 L F
.40668 .77482 m .39475 .76198 L .38418 .76697 L .673 .758 .915 r
F
.41278 .7732 m .39475 .76198 L .40668 .77482 L F
.4626 .77177 m .47314 .75466 L .45495 .76566 L F
.127 .923 .03 r
.46298 .73027 m
.463 .73551 L
s
.4626 .77177 m .48463 .76382 L .47314 .75466 L .673 .758 .915 r
F
.127 .923 .03 r
.37401 .64369 m
.37402 .64765 L
s
0 g
.39669 .6582 m
.42105 .65743 L
s
.57893 .64314 m .57464 .64018 L .5736 .64103 L .675 .735 .895 r
F
.57893 .64314 m .57596 .63953 L .57464 .64018 L F
.38387 .76131 m .3543 .76056 L .37565 .7677 L .673 .758 .914 r
F
.5194 .62936 m .4894 .62259 L .48556 .63799 L .654 .726 .902 r
F
.48897 .62986 m .48556 .63799 L .48514 .64525 L 0 0 .144 r
F
0 g
.48611 .64134 m
.48676 .64534 L
s
.48897 .62986 m .4894 .62259 L .48556 .63799 L 0 0 .144 r
F
.5194 .62936 m .48556 .63799 L .51683 .63962 L .654 .726 .902 r
F
.52402 .7479 m .53889 .74915 L .53921 .75481 L .859 .596 .541 r
F
.52402 .7479 m .5237 .74223 L .53889 .74915 L F
0 g
.53889 .74915 m
.54369 .75027 L
s
.55269 .74716 m .5574 .76466 L .56461 .74996 L .673 .758 .915 r
F
.55269 .74716 m .53953 .76047 L .5574 .76466 L F
0 g
.5574 .76466 m
.57674 .76584 L
s
.61424 .75343 m .62983 .74028 L .63016 .74594 L .518 .333 .569 r
F
.61456 .75909 m .61424 .75343 L .63016 .74594 L F
.60242 .74058 m .61424 .75343 L .63016 .74594 L .673 .758 .914 r
F
.59019 .74382 m .61424 .75343 L .60242 .74058 L F
0 g
.60591 .75563 m
.61424 .75343 L
s
.42105 .65743 m
.44525 .66075 L
s
.54939 .63613 m .51683 .63962 L .5481 .64126 L .654 .726 .902 r
F
.54939 .63613 m .5194 .62936 L .51683 .63962 L F
.54211 .73111 m .53909 .74895 L .55218 .7357 L .673 .758 .914 r
F
.54211 .73111 m .52398 .74207 L .53909 .74895 L F
.37595 .77337 m .35461 .76622 L .34664 .77728 L .673 .758 .915 r
F
0 g
.34359 .78903 m
.34664 .77728 L
s
.57898 .63333 m .57593 .62947 L .57736 .63346 L .675 .735 .895 r
F
.57898 .63333 m .57916 .62921 L .57593 .62947 L F
.57905 .63615 m .57923 .632 L .57598 .63227 L F
.57911 .63899 m .57604 .63511 L .57749 .63912 L F
.57911 .63899 m .5793 .63485 L .57604 .63511 L F
.57916 .62921 m .57449 .62547 L .57593 .62947 L F
.57916 .62921 m .57934 .62508 L .57449 .62547 L F
.57923 .632 m .57453 .62826 L .57598 .63227 L F
.57923 .632 m .57941 .62786 L .57453 .62826 L F
.5793 .63485 m .57948 .6307 L .5746 .6311 L F
.57941 .62786 m .57447 .62541 L .57453 .62826 L .666 .426 .548 r
F
.57941 .62786 m .57934 .62502 L .57447 .62541 L F
.57948 .6307 m .57453 .62826 L .5746 .6311 L F
.57948 .6307 m .57941 .62786 L .57453 .62826 L F
.57936 .64289 m .58025 .62286 L .57212 .62311 L .654 .726 .902 r
F
0 g
.57574 .64187 m
.57574 .64625 L
s
.61063 .64453 m .64025 .63569 L .6098 .63929 L .654 .726 .902 r
F
.61063 .64453 m .64189 .64617 L .64025 .63569 L F
.64189 .64617 m .6707 .63208 L .64025 .63569 L F
.68341 .62189 m .67083 .63263 L .6892 .63189 L F
.67083 .63263 m .66163 .64049 L .67158 .63739 L F
.6731 .64719 m .67111 .62481 L .67072 .63189 L .915 .736 .242 r
F
.67083 .63263 m .67158 .63739 L .6892 .63189 L .654 .726 .902 r
F
.67316 .6478 m .6731 .64719 L .6707 .63208 L .915 .736 .242 r
F
.6731 .64719 m .67072 .63189 L .6707 .63208 L F
.64189 .64617 m .67316 .6478 L .6707 .63208 L .654 .726 .902 r
F
.42573 .77296 m .41996 .75747 L .41928 .77257 L .673 .758 .915 r
F
.42573 .77296 m .43287 .75826 L .41996 .75747 L F
.67276 .65507 m .67316 .6478 L .6707 .63208 L .915 .736 .242 r
F
.30327 .62952 m .2934 .64958 L .30964 .63305 L .654 .726 .902 r
F
.30327 .62952 m .28067 .64253 L .2934 .64958 L F
.71771 .60871 m .69976 .62605 L .72246 .6131 L F
.71771 .60871 m .69027 .61728 L .69976 .62605 L F
.34092 .63468 m .35593 .65285 L .36912 .64716 L F
.33331 .63629 m .35593 .65285 L .34092 .63468 L F
.41278 .7732 m .40696 .75874 L .39475 .76198 L .673 .758 .915 r
F
.41928 .77257 m .40696 .75874 L .41278 .7732 L F
.76648 .61541 m .78775 .63066 L .79807 .62292 L .654 .726 .902 r
F
.75987 .61824 m .78775 .63066 L .76648 .61541 L F
.45414 .75445 m .45711 .73662 L .44405 .74986 L .673 .758 .914 r
F
.45414 .75445 m .47224 .7435 L .45711 .73662 L F
.36907 .87747 m .37721 .87935 L .37769 .88391 L .931 .647 .48 r
F
.36907 .87747 m .36859 .8729 L .37721 .87935 L F
.38505 .86647 m .37721 .87935 L .39079 .87077 L .683 .77 .917 r
F
.38505 .86647 m .36859 .8729 L .37721 .87935 L F
0 g
.37721 .87935 m
.38187 .88127 L
s
.23468 .62733 m .24405 .63505 L .24359 .64231 L .989 .743 .466 r
F
.23468 .62733 m .23515 .62006 L .24405 .63505 L F
.26554 .61645 m .24405 .63505 L .27146 .62645 L .654 .726 .902 r
F
.26554 .61645 m .23515 .62006 L .24405 .63505 L F
0 g
.24405 .63505 m
.24986 .64035 L
s
.41928 .77257 m .41996 .75747 L .40696 .75874 L .673 .758 .915 r
F
.55327 .62425 m .52012 .62217 L .54996 .6289 L .654 .726 .902 r
F
.48431 .75816 m .484 .7525 L .47252 .74333 L .931 .657 .498 r
F
0 g
.484 .7525 m
.49097 .76328 L
s
.61006 .63204 m .63458 .61851 L .60717 .62707 L .654 .726 .902 r
F
.61006 .63204 m .64035 .62846 L .63458 .61851 L F
.40652 .64355 m .41689 .62228 L .41645 .62955 L .069 0 .394 r
F
.40608 .65082 m .40652 .64355 L .41645 .62955 L F
.37981 .63212 m .40652 .64355 L .41645 .62955 L .654 .726 .902 r
F
.36956 .6399 m .40652 .64355 L .37981 .63212 L F
0 g
.39877 .64943 m
.40652 .64355 L
s
.46583 .86772 m .46534 .86316 L .47134 .85479 L .204 .118 .53 r
F
.127 .923 .03 r
.39973 8.82782 m
.56068 1.19895 L
s
0 g
.45956 .86778 m
.46534 .86316 L
s
.44925 .8584 m .46511 .86309 L .47107 .85476 L .683 .77 .917 r
F
.44311 .86331 m .46511 .86309 L .44925 .8584 L F
.57464 .64018 m .56827 .63893 L .5736 .64103 L .675 .735 .895 r
F
.72155 .6277 m .71138 .64776 L .72787 .63122 L .654 .726 .902 r
F
.72155 .6277 m .69873 .64071 L .71138 .64776 L F
.75916 .63286 m .77391 .65103 L .7872 .64534 L F
.75151 .63447 m .77391 .65103 L .75916 .63286 L F
.41796 .8693 m .41744 .88044 L .42716 .87916 L .683 .77 .917 r
F
.41313 .86918 m .41744 .88044 L .41796 .8693 L F
.41313 .86918 m .40779 .8802 L .41744 .88044 L F
.4269 .86275 m .43581 .8719 L .44373 .86794 L F
.38418 .76697 m .35461 .76622 L .37595 .77337 L .673 .758 .915 r
F
.52434 .75356 m .53921 .75481 L .53953 .76047 L .859 .596 .541 r
F
.52434 .75356 m .52402 .7479 L .53921 .75481 L F
.54225 .73689 m .53921 .75481 L .55237 .7415 L .673 .758 .914 r
F
.54225 .73689 m .52402 .7479 L .53921 .75481 L F
0 g
.53921 .75481 m
.54401 .75594 L
s
.61456 .75909 m .63016 .74594 L .63049 .7516 L .518 .333 .569 r
F
.60274 .74624 m .61456 .75909 L .63049 .7516 L .673 .758 .915 r
F
.59052 .74948 m .61456 .75909 L .60274 .74624 L F
0 g
.59623 .76394 m
.61456 .75909 L
s
.57464 .64018 m .57034 .63723 L .56827 .63893 L .675 .735 .895 r
F
.57596 .63953 m .57034 .63723 L .57464 .64018 L F
.2989 .61784 m .28112 .63527 L .30372 .62225 L .654 .726 .902 r
F
.2989 .61784 m .27146 .62645 L .28112 .63527 L F
.42282 .86866 m .42716 .87916 L .43629 .87646 L .683 .77 .917 r
F
.41796 .8693 m .42716 .87916 L .42282 .86866 L F
.34797 .62457 m .36956 .6399 L .37981 .63212 L .654 .726 .902 r
F
.34137 .62742 m .36956 .6399 L .34797 .62457 L F
.82451 .64173 m .83504 .62046 L .83466 .62772 L .087 0 .405 r
F
.82413 .649 m .82451 .64173 L .83466 .62772 L F
.79795 .6303 m .82451 .64173 L .83466 .62772 L .654 .726 .902 r
F
.78758 .63808 m .82451 .64173 L .79795 .6303 L F
0 g
.8159 .64818 m
.82451 .64173 L
s
.127 .923 .03 r
.40167 8.82713 m
.61239 2.53783 L
s
.67345 .71539 m
.67534 .659 L
s
.67534 .659 m
.67581 .64484 L
s
.38553 .87103 m .37769 .88391 L .39127 .87533 L .683 .77 .917 r
F
.38553 .87103 m .36907 .87747 L .37769 .88391 L F
0 g
.37769 .88391 m
.38908 .88859 L
s
.57596 .63953 m .57299 .63592 L .57034 .63723 L .675 .735 .895 r
F
.57749 .63912 m .57299 .63592 L .57596 .63953 L F
.38374 .75575 m .3666 .74545 L .35432 .755 L .673 .758 .914 r
F
.127 .923 .03 r
.35541 .67562 m
.35574 .74094 L
s
.39426 .75078 m .3666 .74545 L .38374 .75575 L .673 .758 .914 r
F
.45464 .76 m .45762 .74208 L .44449 .75539 L F
.45464 .76 m .47283 .749 L .45762 .74208 L F
.40867 .86831 m .40779 .8802 L .41313 .86918 L .683 .77 .917 r
F
.40867 .86831 m .39887 .87845 L .40779 .8802 L F
.51897 .63663 m .48514 .64525 L .51641 .64689 L .654 .726 .902 r
F
.51897 .63663 m .48897 .62986 L .48514 .64525 L F
0 g
.48514 .64525 m
.48769 .66096 L
s
.46583 .86772 m .47134 .85479 L .47183 .85935 L .204 .118 .53 r
F
.46632 .87228 m .46583 .86772 L .47183 .85935 L F
.44989 .86301 m .46583 .86772 L .47183 .85935 L .683 .77 .917 r
F
.44373 .86794 m .46583 .86772 L .44989 .86301 L F
0 g
.46005 .87234 m
.46583 .86772 L
s
.54897 .6434 m .51641 .64689 L .54768 .64852 L .654 .726 .902 r
F
.54897 .6434 m .51897 .63663 L .51641 .64689 L F
.43031 .85617 m .44311 .86331 L .44925 .8584 L .683 .77 .917 r
F
.48431 .75816 m .47252 .74333 L .47283 .749 L .931 .657 .498 r
F
.127 .923 .03 r
.47958 .74343 m
.48021 .68127 L
s
.47953 .74867 m
.47958 .74343 L
s
.48463 .76382 m .48431 .75816 L .47283 .749 L .931 .657 .498 r
F
0 g
.48431 .75816 m
.49128 .76894 L
s
.57299 .63592 m .56604 .63427 L .57034 .63723 L .675 .735 .895 r
F
.57299 .63592 m .57001 .63231 L .56604 .63427 L F
.57895 .65016 m .57171 .63038 L .56407 .63199 L .654 .726 .902 r
F
.57895 .65016 m .57984 .63012 L .57171 .63038 L F
.61022 .6518 m .63984 .64295 L .60939 .64656 L F
.61022 .6518 m .64149 .65343 L .63984 .64295 L F
.64149 .65343 m .6703 .63935 L .63984 .64295 L F
.64149 .65343 m .67276 .65507 L .6703 .63935 L F
.63016 .74594 m .62983 .74028 L .64226 .73067 L .392 .239 .551 r
F
0 g
.62139 .74425 m
.62983 .74028 L
s
.67276 .65507 m .6707 .63208 L .6703 .63935 L .915 .736 .242 r
F
0 g
.66882 .67044 m
.67276 .65507 L
s
.71718 .61602 m .69913 .63345 L .72195 .62043 L .654 .726 .902 r
F
.71718 .61602 m .6896 .62463 L .69913 .63345 L F
.61254 .72982 m .62957 .74012 L .64194 .73056 L .673 .758 .914 r
F
.60197 .73479 m .62957 .74012 L .61254 .72982 L F
.40439 .86218 m .39079 .87077 L .39838 .87389 L .683 .77 .917 r
F
.76619 .62275 m .78758 .63808 L .79795 .6303 L .654 .726 .902 r
F
.75955 .62559 m .78758 .63808 L .76619 .62275 L F
.42739 .86731 m .43629 .87646 L .44421 .8725 L .683 .77 .917 r
F
.42282 .86866 m .43629 .87646 L .42739 .86731 L F
.26507 .62372 m .24359 .64231 L .271 .63371 L .654 .726 .902 r
F
.26507 .62372 m .23468 .62733 L .24359 .64231 L F
0 g
.24359 .64231 m
.25809 .65553 L
s
.55272 .63146 m .5194 .62936 L .54939 .63613 L .654 .726 .902 r
F
.6098 .63929 m .63444 .62569 L .60689 .6343 L F
.6098 .63929 m .64025 .63569 L .63444 .62569 L F
.40608 .65082 m .41645 .62955 L .41601 .63681 L .069 0 .394 r
F
.37937 .63939 m .40608 .65082 L .41601 .63681 L .654 .726 .902 r
F
.36912 .64716 m .40608 .65082 L .37937 .63939 L F
0 g
.39833 .65669 m
.40608 .65082 L
s
.54257 .74255 m .53953 .76047 L .55269 .74716 L .673 .758 .915 r
F
.54257 .74255 m .52434 .75356 L .53953 .76047 L F
0 g
.53953 .76047 m
.5574 .76466 L
s
.86069 .56712 m
.87887 .59005 L
s
.87887 .59005 m
.94663 8.86555 L
s
.55327 .62425 m .52675 .61287 L .52012 .62217 L .654 .726 .902 r
F
.5584 .62038 m .52675 .61287 L .55327 .62425 L F
.36664 .75096 m .354 .75489 L .3543 .76056 L .389 .236 .549 r
F
.36664 .75096 m .36634 .74529 L .354 .75489 L F
0 g
.34604 .76595 m
.354 .75489 L
s
.127 .923 .03 r
.35574 .74094 m
.35576 .74618 L
s
.60717 .62707 m .62506 .60973 L .60241 .62268 L .654 .726 .902 r
F
.60717 .62707 m .63458 .61851 L .62506 .60973 L F
.46632 .87228 m .47183 .85935 L .47232 .86391 L .204 .118 .53 r
F
.45038 .86757 m .46632 .87228 L .47232 .86391 L .683 .77 .917 r
F
.44421 .8725 m .46632 .87228 L .45038 .86757 L F
0 g
.45707 .87967 m
.46632 .87228 L
s
.43086 .86077 m .44373 .86794 L .44989 .86301 L .683 .77 .917 r
F
.52675 .61287 m .49028 .61543 L .52012 .62217 L .654 .726 .902 r
F
.38387 .76131 m .36664 .75096 L .3543 .76056 L .673 .758 .914 r
F
.39445 .75632 m .36664 .75096 L .38387 .76131 L F
.44405 .74986 m .43929 .73244 L .43218 .74708 L F
.44405 .74986 m .45711 .73662 L .43929 .73244 L F
.45495 .76566 m .45793 .74775 L .4448 .76106 L .673 .758 .915 r
F
.45495 .76566 m .47314 .75466 L .45793 .74775 L F
.29844 .62511 m .28067 .64253 L .30327 .62952 L .654 .726 .902 r
F
.29844 .62511 m .271 .63371 L .28067 .64253 L F
.40487 .86674 m .39887 .87845 L .40867 .86831 L .683 .77 .917 r
F
.40487 .86674 m .39127 .87533 L .39887 .87845 L F
.48463 .76382 m .47283 .749 L .47314 .75466 L .931 .657 .498 r
F
0 g
.48463 .76382 m
.4916 .7746 L
s
.127 .923 .03 r
.47892 .80847 m
.47953 .74867 L
s
.40112 .85544 m .39045 .86612 L .40397 .85758 L .683 .77 .917 r
F
.40112 .85544 m .38473 .86184 L .39045 .86612 L F
.36334 .86514 m .36811 .86834 L .36859 .8729 L .981 .691 .346 r
F
.127 .923 .03 r
.35834 1.26798 m
.39569 8.82746 L
s
.36334 .86514 m .36286 .86058 L .36811 .86834 L .981 .691 .346 r
F
0 g
.36811 .86834 m
.37228 .87146 L
s
.38125 .85669 m .36836 .86825 L .38473 .86184 L .683 .77 .917 r
F
.38125 .85669 m .36313 .86052 L .36836 .86825 L F
.34752 .63184 m .36912 .64716 L .37937 .63939 L .654 .726 .902 r
F
.34092 .63468 m .36912 .64716 L .34752 .63184 L F
.82413 .649 m .83466 .62772 L .83428 .63499 L .087 0 .405 r
F
.79757 .63756 m .82413 .649 L .83428 .63499 L .654 .726 .902 r
F
.7872 .64534 m .82413 .649 L .79757 .63756 L F
0 g
.80857 .66065 m
.82413 .649 L
s
.29654 .60556 m .2722 .6191 L .29949 .61053 L .654 .726 .902 r
F
.29654 .60556 m .2663 .60915 L .2722 .6191 L F
.63016 .74594 m .64226 .73067 L .64259 .73633 L .392 .239 .551 r
F
.63049 .7516 m .63016 .74594 L .64259 .73633 L F
.127 .923 .03 r
.65419 .79576 m
.65574 .74628 L
s
.61303 .73558 m .63016 .74594 L .64259 .73633 L .673 .758 .914 r
F
.60242 .74058 m .63016 .74594 L .61303 .73558 L F
0 g
.62172 .74991 m
.63016 .74594 L
s
.32808 .60539 m .32609 .62192 L .32686 .62189 L .654 .726 .902 r
F
.32893 .60766 m .32686 .62189 L .33417 .62166 L F
.32808 .60539 m .32686 .62189 L .32893 .60766 L F
.32543 .61908 m .32538 .61624 L .33026 .61584 L .666 .426 .547 r
F
.32701 .62145 m .32564 .62928 L .32679 .62925 L .654 .726 .902 r
F
.32553 .61205 m .32538 .61618 L .33024 .61578 L .675 .735 .895 r
F
.32543 .61908 m .33026 .61584 L .33031 .61869 L .666 .426 .547 r
F
.3267 .60476 m .32609 .62192 L .32781 .60466 L .654 .726 .902 r
F
.32558 .61493 m .32543 .61908 L .32794 .61888 L .675 .735 .895 r
F
.3282 .61701 m .32794 .61888 L .33031 .61869 L F
.32558 .61493 m .32794 .61888 L .3282 .61701 L F
.32959 .60315 m .34831 .61723 L .3534 .61335 L .654 .726 .902 r
F
.32851 .59123 m .32921 .59067 L .32916 .60379 L .356 .178 .497 r
F
.33088 .62132 m .32679 .62925 L .33376 .62902 L .654 .726 .902 r
F
.32615 .62148 m .33031 .61869 L .33036 .62134 L .666 .426 .547 r
F
.32876 .61568 m .32793 .62142 L .33088 .62132 L .654 .726 .902 r
F
.32793 .62142 m .32679 .62925 L .33088 .62132 L F
.32615 .62148 m .32543 .61908 L .33031 .61869 L .666 .426 .547 r
F
.32435 .59161 m .32591 .59187 L .32586 .60483 L .751 .492 .54 r
F
.3227 .59055 m .32336 .59114 L .32331 .60404 L .927 .648 .492 r
F
.32226 .58904 m .32232 .58985 L .32227 .60278 L .794 .634 .076 r
F
.32311 .61452 m .31806 .62082 L .32362 .62158 L .654 .726 .902 r
F
.32558 .60866 m .32299 .61285 L .3265 .6103 L F
.32299 .61285 m .31806 .62082 L .32311 .61452 L F
.32299 .61285 m .32311 .61452 L .3265 .6103 L F
.32617 .60658 m .32528 .60813 L .32662 .60698 L F
.32528 .60813 m .31806 .62082 L .32558 .60866 L F
.32528 .60813 m .32558 .60866 L .32662 .60698 L F
.32639 .60556 m .32594 .60637 L .32667 .60569 L F
.32594 .60637 m .31806 .62082 L .32617 .60658 L F
.32594 .60637 m .32617 .60658 L .32667 .60569 L F
.32659 .60497 m .3263 .60551 L .32669 .60499 L F
.3263 .60551 m .31806 .62082 L .32639 .60556 L F
.3263 .60551 m .32639 .60556 L .32669 .60499 L F
.32545 .60487 m .31806 .62082 L .32659 .60497 L F
.32586 .60483 m .32659 .60497 L .3267 .60476 L F
.32545 .60487 m .32659 .60497 L .32586 .60483 L F
.32311 .61452 m .32362 .62158 L .32609 .62192 L F
.3265 .6103 m .32311 .61452 L .32609 .62192 L F
.32548 .6215 m .32543 .61908 L .32615 .62148 L .666 .426 .547 r
F
.32591 .62156 m .31757 .62818 L .32564 .62928 L .654 .726 .902 r
F
.32164 .62097 m .32543 .61908 L .32548 .6215 L .731 .478 .546 r
F
.32609 .61664 m .32277 .62113 L .32591 .62156 L .654 .726 .902 r
F
.32277 .62113 m .31757 .62818 L .32591 .62156 L F
.32063 .62147 m .32164 .62097 L .32548 .62192 L .731 .478 .546 r
F
.32164 .62097 m .32548 .6215 L .32548 .62192 L F
.32058 .61863 m .32538 .61624 L .32543 .61908 L F
.32058 .61863 m .32053 .61579 L .32538 .61624 L F
.32235 .61463 m .32058 .61863 L .32543 .61908 L .675 .735 .895 r
F
.32528 .6152 m .32183 .621 L .32609 .61664 L .654 .726 .902 r
F
.32183 .621 m .31757 .62818 L .32277 .62113 L F
.32164 .62097 m .32058 .61863 L .32543 .61908 L .731 .478 .546 r
F
.32183 .621 m .32277 .62113 L .32609 .61664 L .654 .726 .902 r
F
.32407 .60777 m .32553 .61205 L .32567 .60792 L .675 .735 .895 r
F
.32231 .61175 m .32538 .61618 L .32553 .61205 L F
.32411 .61063 m .32558 .61493 L .32572 .61078 L F
.32518 .61174 m .32508 .61196 L .32625 .61195 L .654 .726 .902 r
F
.31653 .61242 m .30429 .61492 L .31063 .61843 L F
.3268 .60196 m .32015 .60579 L .31653 .61242 L F
.32015 .60579 m .30429 .61492 L .31653 .61242 L F
.32232 .58985 m .32235 .60293 L .32227 .60278 L .989 .721 .393 r
F
.32226 .58904 m .32223 .60218 L .32221 .60201 L .794 .634 .076 r
F
.32226 .58904 m .32227 .60278 L .32223 .60218 L F
.32232 .58985 m .3227 .59055 L .32265 .60346 L .989 .721 .393 r
F
.32279 .58802 m .32226 .58904 L .32221 .60201 L 0 0 .373 r
F
.32231 .61175 m .32056 .61573 L .32538 .61618 L .675 .735 .895 r
F
.32411 .61063 m .32235 .61463 L .32558 .61493 L F
.32485 .61247 m .32434 .61355 L .32561 .61314 L .654 .726 .902 r
F
.32435 .59161 m .32464 .6046 L .3243 .60453 L .751 .492 .54 r
F
.32336 .59114 m .32353 .60415 L .32331 .60404 L .844 .572 .526 r
F
.32336 .59114 m .32435 .59161 L .3243 .60453 L F
.32336 .59114 m .3243 .60453 L .32353 .60415 L F
.32235 .61463 m .32543 .61908 L .32558 .61493 L .675 .735 .895 r
F
.3258 .61331 m .32287 .61859 L .32619 .61366 L .654 .726 .902 r
F
.32287 .61859 m .31757 .62818 L .32292 .61917 L F
.32287 .61859 m .32292 .61917 L .32619 .61366 L F
.326 .61242 m .32285 .6183 L .32623 .61253 L F
.32285 .6183 m .31757 .62818 L .32287 .61859 L F
.32285 .6183 m .32287 .61859 L .32623 .61253 L F
.3268 .60196 m .3213 .60369 L .32015 .60579 L F
.32231 .60509 m .31976 .60482 L .32035 .60582 L .675 .735 .895 r
F
.3268 .60196 m .31063 .61843 L .31806 .62082 L .654 .726 .902 r
F
.32353 .60415 m .32355 .60576 L .32331 .60404 L .844 .572 .526 r
F
.32471 .6063 m .32258 .60735 L .32407 .60777 L .675 .735 .895 r
F
.32258 .60735 m .31933 .61091 L .32231 .61175 L F
.32313 .60839 m .32037 .60867 L .32134 .60954 L F
.32258 .60735 m .32231 .61175 L .32407 .60777 L F
.32359 .6086 m .3235 .60856 L .32338 .60569 L .844 .572 .526 r
F
.32388 .60592 m .32258 .60735 L .32471 .6063 L .675 .735 .895 r
F
.32434 .61355 m .32276 .61698 L .32488 .6145 L .654 .726 .902 r
F
.32407 .60777 m .32231 .61175 L .32553 .61205 L .675 .735 .895 r
F
.32476 .60914 m .32261 .61021 L .32411 .61063 L F
.32573 .60632 m .32407 .60777 L .32567 .60792 L F
.32464 .6046 m .32586 .60483 L .32586 .60634 L .751 .492 .54 r
F
.32464 .6046 m .32586 .60634 L .32507 .60622 L F
.32582 .60379 m .32477 .60618 L .32573 .60632 L .675 .735 .895 r
F
.32477 .60618 m .32407 .60777 L .32573 .60632 L F
.32507 .60622 m .32586 .60634 L .32584 .60915 L .751 .492 .54 r
F
.32474 .60898 m .32583 .61187 L .3248 .61167 L F
.32635 .60923 m .32412 .61149 L .32427 .61157 L .654 .726 .902 r
F
.32518 .61174 m .32427 .61157 L .32508 .61196 L F
.32635 .60923 m .32427 .61157 L .32518 .61174 L F
.32587 .60663 m .32411 .61063 L .32572 .61078 L .675 .735 .895 r
F
.32474 .60898 m .32584 .60915 L .32583 .61187 L .751 .492 .54 r
F
.32434 .61355 m .32488 .6145 L .32561 .61314 L .654 .726 .902 r
F
.32508 .61196 m .32485 .61247 L .326 .61242 L F
.32485 .61247 m .32561 .61314 L .326 .61242 L F
.32553 .61205 m .33024 .61578 L .32876 .61179 L .675 .735 .895 r
F
.32572 .61078 m .32558 .61493 L .32883 .61467 L F
.32508 .61196 m .326 .61242 L .32625 .61195 L .654 .726 .902 r
F
.32548 .62192 m .32548 .6215 L .32615 .62148 L .666 .426 .547 r
F
.32062 .62084 m .32058 .61863 L .32164 .62097 L .731 .478 .546 r
F
.32295 .60563 m .32035 .60582 L .32131 .60668 L .675 .735 .895 r
F
.32353 .60415 m .3243 .60453 L .32429 .6061 L .844 .572 .526 r
F
.3238 .60588 m .32429 .6061 L .32428 .60891 L F
.32353 .60415 m .32429 .6061 L .3238 .60588 L F
.32582 .60379 m .32259 .60499 L .32285 .60544 L .675 .735 .895 r
F
.32308 .60555 m .32285 .60544 L .32295 .60563 L F
.32355 .60576 m .32338 .60569 L .32331 .60404 L .844 .572 .526 r
F
.32582 .60379 m .32285 .60544 L .32308 .60555 L .675 .735 .895 r
F
.32259 .60499 m .32035 .60582 L .32295 .60563 L F
.32235 .60293 m .32265 .60346 L .32264 .60508 L .989 .721 .393 r
F
.32428 .60891 m .32261 .61021 L .32476 .60914 L .675 .735 .895 r
F
.32393 .60876 m .32385 .60885 L .32428 .60891 L F
.32385 .60885 m .32261 .61021 L .32428 .60891 L F
.32428 .60891 m .32451 .61161 L .32427 .61157 L .751 .492 .54 r
F
.3243 .60453 m .32443 .60894 L .32428 .60891 L F
.32443 .60894 m .32451 .61161 L .32428 .60891 L F
.32355 .60576 m .32427 .61157 L .32362 .61125 L .844 .572 .526 r
F
.32353 .60415 m .3237 .60583 L .32355 .60576 L F
.3237 .60583 m .32427 .61157 L .32355 .60576 L F
.3228 .60359 m .32331 .60404 L .3233 .60565 L .927 .648 .492 r
F
.32376 .60605 m .32237 .606 L .32258 .60735 L .675 .735 .895 r
F
.32362 .60593 m .32237 .606 L .32376 .60605 L F
.32308 .60555 m .32237 .606 L .32362 .60593 L F
.3233 .60565 m .32362 .60593 L .32388 .60592 L F
.32308 .60555 m .32362 .60593 L .3233 .60565 L F
.3228 .60359 m .32281 .60522 L .32265 .60346 L .927 .648 .492 r
F
.32035 .60582 m .3168 .60958 L .32131 .60668 L .675 .735 .895 r
F
.32195 .6073 m .3196 .60659 L .31978 .60767 L F
.32283 .60806 m .32277 .60801 L .32269 .60512 L .927 .648 .492 r
F
.32092 .62093 m .31605 .62029 L .31757 .62818 L .654 .726 .902 r
F
.31733 .61978 m .32058 .61863 L .32062 .62084 L .794 .53 .538 r
F
.31935 .61378 m .32058 .61863 L .32235 .61463 L .675 .735 .895 r
F
.32434 .61355 m .31686 .61963 L .32092 .62093 L .654 .726 .902 r
F
.31686 .61963 m .31605 .62029 L .32092 .62093 L F
.31615 .6202 m .31733 .61978 L .32063 .62147 L .794 .53 .538 r
F
.31733 .61978 m .32062 .62084 L .32063 .62147 L F
.32401 .61295 m .31605 .62029 L .32434 .61355 L .654 .726 .902 r
F
.32241 .60467 m .32264 .60508 L .32263 .60789 L .989 .721 .393 r
F
.32252 .60769 m .32263 .60789 L .32262 .6105 L F
.32241 .60467 m .32263 .60789 L .32252 .60769 L F
.32131 .60668 m .31933 .61091 L .32258 .60735 L .675 .735 .895 r
F
.32227 .60724 m .32115 .6066 L .32195 .6073 L F
.32237 .606 m .32131 .60668 L .32246 .60729 L F
.32237 .606 m .32246 .60729 L .32258 .60735 L F
.32355 .60576 m .32359 .6086 L .32338 .60569 L .844 .572 .526 r
F
.32224 .60798 m .32037 .60867 L .32313 .60839 L .675 .735 .895 r
F
.3222 .60641 m .32219 .60916 L .32219 .60904 L .794 .634 .076 r
F
.32226 .60439 m .31976 .60482 L .32231 .60509 L .675 .735 .895 r
F
.32221 .60201 m .3222 .60649 L .3222 .60641 L .794 .634 .076 r
F
.32259 .60785 m .31978 .60767 L .32037 .60867 L .675 .735 .895 r
F
.32281 .60522 m .32329 .60846 L .32305 .60825 L .927 .648 .492 r
F
.32388 .60592 m .32362 .60593 L .32376 .60605 L .675 .735 .895 r
F
.32353 .60415 m .32428 .60891 L .32399 .60878 L .844 .572 .526 r
F
.32343 .60931 m .32134 .60954 L .32261 .61021 L .675 .735 .895 r
F
.32328 .60904 m .32134 .60954 L .32343 .60931 L F
.32261 .60784 m .32195 .6073 L .32259 .60785 L F
.32236 .60741 m .32262 .6105 L .32237 .61005 L .989 .721 .393 r
F
.32235 .60293 m .32252 .60769 L .32236 .60741 L F
.32252 .60769 m .32262 .6105 L .32236 .60741 L F
.3238 .6089 m .32328 .60904 L .32343 .60931 L .675 .735 .895 r
F
.32587 .60663 m .32318 .60836 L .3238 .6089 L F
.32362 .61125 m .32344 .61116 L .32339 .60851 L .844 .572 .526 r
F
.3235 .60856 m .32339 .60851 L .32331 .60404 L F
.32362 .61125 m .32339 .60851 L .3235 .60856 L F
.32329 .60846 m .32134 .60954 L .3238 .6089 L .675 .735 .895 r
F
.32318 .60836 m .32313 .60839 L .32329 .60846 L F
.32313 .60839 m .32134 .60954 L .32329 .60846 L F
.32291 .60813 m .32328 .61108 L .323 .61083 L .927 .648 .492 r
F
.32281 .60522 m .32305 .60825 L .32291 .60813 L F
.32305 .60825 m .32328 .61108 L .32291 .60813 L F
.32237 .61005 m .3223 .60992 L .32229 .60728 L .989 .721 .393 r
F
.32233 .60735 m .32229 .60728 L .32227 .60278 L F
.32237 .61005 m .32229 .60728 L .32233 .60735 L F
.32587 .60663 m .32227 .60724 L .32261 .60784 L .675 .735 .895 r
F
.32227 .60724 m .32195 .6073 L .32261 .60784 L F
.32221 .60665 m .32224 .60982 L .3222 .60931 L .794 .634 .076 r
F
.32222 .6038 m .32223 .60692 L .32221 .60665 L F
.32195 .6073 m .31978 .60767 L .3223 .60783 L .675 .735 .895 r
F
.32223 .60692 m .32224 .60982 L .32221 .60665 L .794 .634 .076 r
F
.32228 .60758 m .3223 .60783 L .32259 .60785 L .675 .735 .895 r
F
.32195 .6073 m .3223 .60783 L .32228 .60758 L F
.32281 .60522 m .3233 .60565 L .32329 .60846 L .927 .648 .492 r
F
.32305 .60825 m .32329 .60846 L .32328 .61108 L F
.3222 .60649 m .32219 .60916 L .3222 .60641 L .794 .634 .076 r
F
.32587 .60663 m .32221 .60661 L .32227 .60724 L .675 .735 .895 r
F
.32221 .60661 m .32191 .60661 L .32225 .60721 L F
.32223 .60392 m .32226 .6044 L .32225 .60721 L .794 .634 .076 r
F
.32224 .60698 m .32225 .60721 L .32224 .60982 L F
.32223 .60392 m .32225 .60721 L .32224 .60698 L F
.32221 .60661 m .31985 .60552 L .3196 .60659 L .675 .735 .895 r
F
.32281 .60522 m .32283 .60806 L .32269 .60512 L .927 .648 .492 r
F
.32587 .60663 m .32216 .60594 L .32221 .60661 L .675 .735 .895 r
F
.32216 .60594 m .31985 .60552 L .32221 .60661 L F
.32221 .60661 m .32225 .60721 L .32227 .60724 L F
.32191 .60661 m .32115 .6066 L .32227 .60724 L F
.3227 .59055 m .3228 .60359 L .32265 .60346 L .927 .648 .492 r
F
.32232 .58985 m .32265 .60346 L .32235 .60293 L .989 .721 .393 r
F
.3227 .59055 m .32331 .60404 L .3228 .60359 L .927 .648 .492 r
F
.32435 .59161 m .32586 .60483 L .32464 .6046 L .751 .492 .54 r
F
.31593 .60537 m .29654 .60556 L .29949 .61053 L .654 .726 .902 r
F
.3268 .60196 m .32004 .60276 L .31593 .60537 L F
.32004 .60276 m .29654 .60556 L .31593 .60537 L F
.32261 .61021 m .32235 .61463 L .32411 .61063 L .675 .735 .895 r
F
.31933 .61091 m .32056 .61573 L .32231 .61175 L F
.32261 .61021 m .31935 .61378 L .32235 .61463 L F
.32322 .61103 m .32013 .61281 L .32395 .61167 L .654 .726 .902 r
F
.31933 .61091 m .31609 .61447 L .32056 .61573 L .675 .735 .895 r
F
.31227 .61536 m .31604 .61452 L .3161 .61736 L .86 .586 .522 r
F
.3135 .61794 m .31227 .61536 L .3161 .61736 L F
.3161 .61736 m .31604 .61452 L .32053 .61579 L .794 .53 .538 r
F
.3135 .61794 m .3161 .61736 L .31613 .6194 L .86 .586 .522 r
F
.3168 .61245 m .3161 .61736 L .31935 .61378 L .675 .735 .895 r
F
.31947 .61401 m .31275 .61753 L .31675 .619 L .654 .726 .902 r
F
.31275 .61753 m .30372 .62225 L .31582 .61923 L F
.31275 .61753 m .31582 .61923 L .31675 .619 L F
.31232 .6182 m .3135 .61794 L .31615 .6202 L .86 .586 .522 r
F
.3135 .61794 m .31613 .6194 L .31615 .6202 L F
.31232 .6182 m .31231 .61728 L .3135 .61794 L F
.31231 .61728 m .31227 .61536 L .3135 .61794 L F
.32013 .61281 m .31233 .6173 L .31947 .61401 L .654 .726 .902 r
F
.31233 .6173 m .30372 .62225 L .31275 .61753 L F
.3168 .61245 m .31227 .61536 L .3161 .61736 L .675 .735 .895 r
F
.31233 .6173 m .31275 .61753 L .31947 .61401 L .654 .726 .902 r
F
.32013 .61281 m .31947 .61401 L .32395 .61167 L F
.32223 .60218 m .32223 .60392 L .32222 .6038 L .794 .634 .076 r
F
.32223 .60392 m .32224 .60698 L .32222 .6038 L F
.32224 .60698 m .32224 .60982 L .32223 .60692 L F
.32224 .60698 m .32223 .60692 L .32222 .6038 L F
.32216 .60594 m .32052 .60452 L .31985 .60552 L .675 .735 .895 r
F
.32253 .60841 m .32263 .60823 L .32267 .60549 L 0 0 .373 r
F
.32281 .60522 m .32269 .60512 L .32265 .60346 L .927 .648 .492 r
F
.3213 .60369 m .31593 .60537 L .32015 .60579 L .654 .726 .902 r
F
.32175 .60448 m .31958 .60375 L .31976 .60482 L .675 .735 .895 r
F
.32235 .60293 m .32264 .60508 L .32241 .60467 L .989 .721 .393 r
F
.32582 .60379 m .32212 .60377 L .32175 .60448 L .675 .735 .895 r
F
.32212 .60377 m .31958 .60375 L .32175 .60448 L F
.32223 .60218 m .32227 .60278 L .32226 .6044 L .794 .634 .076 r
F
.30976 .60398 m .29566 .60033 L .29654 .60556 L .654 .726 .902 r
F
.3268 .60196 m .31914 .60156 L .30976 .60398 L F
.31914 .60156 m .29566 .60033 L .30976 .60398 L F
.325 .5869 m .3239 .58724 L .32385 .60034 L .568 .344 .535 r
F
.32567 .62298 m .31711 .63544 L .32519 .63655 L .654 .726 .902 r
F
.3224 .61747 m .32548 .62192 L .32563 .61777 L .675 .735 .895 r
F
.32576 .62034 m .32496 .62173 L .32567 .62298 L .654 .726 .902 r
F
.32496 .62173 m .31711 .63544 L .32567 .62298 L F
.3161 .61736 m .32053 .61579 L .32058 .61863 L .794 .53 .538 r
F
.31935 .61378 m .3161 .61736 L .32058 .61863 L .675 .735 .895 r
F
.32395 .61167 m .31947 .61401 L .31675 .619 L .654 .726 .902 r
F
.32345 .61218 m .32139 .61238 L .32266 .61305 L .675 .735 .895 r
F
.32662 .60698 m .32558 .60866 L .3265 .6103 L .654 .726 .902 r
F
.32773 .60591 m .32609 .62192 L .32808 .60539 L F
.3278 .6048 m .32609 .62192 L .32785 .60476 L F
.32567 .60792 m .32553 .61205 L .32876 .61179 L .675 .735 .895 r
F
.32572 .61078 m .32883 .61467 L .32735 .61065 L F
.32584 .60915 m .32608 .61185 L .32583 .61187 L .641 .402 .541 r
F
.32672 .60622 m .32567 .60792 L .32729 .60779 L .675 .735 .895 r
F
.32586 .60483 m .32591 .60633 L .32586 .60634 L .641 .402 .541 r
F
.32667 .60569 m .32617 .60658 L .32662 .60698 L .654 .726 .902 r
F
.32573 .60636 m .32567 .60792 L .32672 .60622 L .675 .735 .895 r
F
.32578 .60916 m .32572 .61078 L .32675 .60903 L F
.32625 .61195 m .326 .61242 L .32623 .61253 L .654 .726 .902 r
F
.32626 .61183 m .32564 .62928 L .32729 .61174 L F
.32623 .61253 m .3258 .61331 L .32619 .61366 L F
.32679 .61183 m .32578 .61362 L .3274 .61349 L .675 .735 .895 r
F
.32638 .61189 m .3262 .61191 L .32586 .60483 L .641 .402 .541 r
F
.32599 .60913 m .32608 .61185 L .32584 .60915 L F
.32635 .60923 m .32518 .61174 L .32625 .61195 L .654 .726 .902 r
F
.32592 .60947 m .32583 .61196 L .32679 .61183 L .675 .735 .895 r
F
.32583 .61196 m .32578 .61362 L .32679 .61183 L F
.32567 .60792 m .32876 .61179 L .32729 .60779 L F
.32775 .60889 m .32735 .61065 L .32888 .61024 L F
.32675 .60903 m .32735 .61065 L .32775 .60889 L F
.32702 .62145 m .32679 .62925 L .32793 .62142 L .654 .726 .902 r
F
.32548 .62192 m .32615 .62148 L .33036 .62153 L .666 .426 .547 r
F
.32921 .59067 m .32964 .58999 L .32959 .60316 L .071 0 .412 r
F
.32878 .60436 m .33417 .62166 L .33797 .62086 L .654 .726 .902 r
F
.33271 .60912 m .33797 .62086 L .34175 .62006 L F
.32878 .60436 m .33797 .62086 L .33271 .60912 L F
.32975 .58918 m .3293 .58814 L .32925 .60138 L .986 .729 .347 r
F
.32777 .60457 m .33417 .62166 L .32867 .60423 L .654 .726 .902 r
F
.32927 .60371 m .32949 .60387 L .32954 .60352 L F
.32927 .60371 m .32954 .60352 L .32959 .60315 L F
.33077 .60478 m .34175 .62006 L .34831 .61723 L F
.33163 .6067 m .34175 .62006 L .33077 .60478 L F
.32932 .60501 m .34175 .62006 L .32949 .60387 L F
.32881 .60738 m .33443 .60968 L .33012 .60673 L .675 .735 .895 r
F
.33011 .60741 m .33122 .60873 L .33188 .60774 L F
.32873 .60442 m .33417 .62166 L .32878 .60436 L .654 .726 .902 r
F
.32729 .60779 m .32876 .61179 L .3318 .61098 L .675 .735 .895 r
F
.32949 .60387 m .33163 .6067 L .33077 .60478 L .654 .726 .902 r
F
.32956 .60448 m .33114 .60588 L .3318 .60489 L .675 .735 .895 r
F
.32851 .59123 m .32862 .60419 L .32846 .60431 L .356 .178 .497 r
F
.3268 .60196 m .32932 .60501 L .32949 .60387 L .654 .726 .902 r
F
.32926 .60495 m .3292 .60505 L .32916 .60379 L .071 0 .412 r
F
.32785 .60476 m .32773 .60591 L .32808 .60539 L .654 .726 .902 r
F
.32781 .60466 m .3278 .6048 L .32785 .60476 L F
.32767 .60461 m .32846 .60431 L .32845 .60568 L .517 .303 .528 r
F
.32768 .60602 m .32881 .60738 L .32854 .60565 L .675 .735 .895 r
F
.32793 .60591 m .32845 .60568 L .32844 .60849 L .517 .303 .528 r
F
.32767 .60461 m .32845 .60568 L .32793 .60591 L F
.32873 .60578 m .32881 .60738 L .33012 .60673 L .675 .735 .895 r
F
.32927 .60773 m .32918 .60786 L .32917 .6051 L .071 0 .412 r
F
.3292 .60505 m .32917 .6051 L .32916 .60379 L F
.32916 .6051 m .33012 .60673 L .33114 .60588 L .675 .735 .895 r
F
.32582 .60379 m .32873 .60578 L .32916 .6051 L F
.32873 .60578 m .33012 .60673 L .32916 .6051 L F
.32926 .60365 m .32959 .60316 L .32958 .60444 L .071 0 .412 r
F
.33012 .60673 m .33647 .60798 L .33114 .60588 L .675 .735 .895 r
F
.33047 .60584 m .33214 .60666 L .33196 .60559 L F
.32931 .60487 m .32957 .60725 L .32943 .60747 L .071 0 .412 r
F
.32859 .606 m .32881 .60738 L .32873 .60578 L .675 .735 .895 r
F
.32862 .60419 m .32892 .60811 L .32876 .60823 L .356 .178 .497 r
F
.32867 .60423 m .32873 .60442 L .32878 .60436 L .654 .726 .902 r
F
.32862 .60419 m .32916 .60379 L .32914 .60792 L .356 .178 .497 r
F
.32873 .60858 m .32888 .61024 L .3302 .60959 L .675 .735 .895 r
F
.32729 .60779 m .3318 .61098 L .32881 .60738 L F
.32892 .60811 m .32914 .60792 L .32913 .61083 L .356 .178 .497 r
F
.32862 .60419 m .32914 .60792 L .32892 .60811 L F
.32881 .60738 m .3318 .61098 L .33443 .60968 L .675 .735 .895 r
F
.32915 .60792 m .3302 .60959 L .33122 .60873 L F
.32768 .60602 m .32729 .60779 L .32881 .60738 L F
.32769 .60601 m .32844 .60849 L .32773 .6088 L .517 .303 .528 r
F
.32767 .60461 m .32793 .60591 L .32769 .60601 L F
.32793 .60591 m .32844 .60849 L .32769 .60601 L F
.3267 .60476 m .32659 .60497 L .32669 .60499 L .654 .726 .902 r
F
.32621 .6048 m .32744 .60469 L .32744 .60612 L .641 .402 .541 r
F
.32672 .60622 m .32678 .60641 L .32744 .60612 L .675 .735 .895 r
F
.32678 .60641 m .32729 .60779 L .32768 .60602 L F
.32737 .62044 m .32519 .63655 L .32673 .6365 L .654 .726 .902 r
F
.32859 .6237 m .32673 .6365 L .33331 .63629 L F
.32737 .62044 m .32673 .6365 L .32859 .6237 L F
.33124 .61293 m .33228 .61524 L .33479 .61457 L .675 .735 .895 r
F
.32876 .61179 m .33228 .61524 L .33124 .61293 L F
.32876 .61179 m .33024 .61578 L .33228 .61524 L F
.32735 .61065 m .32883 .61467 L .33188 .61385 L F
.32743 .61063 m .33188 .61385 L .32888 .61024 L F
.32735 .61065 m .3274 .61068 L .32743 .61063 L F
.3274 .61068 m .33188 .61385 L .32743 .61063 L F
.32851 .60844 m .3302 .60959 L .32915 .60792 L F
.32926 .60365 m .32934 .60762 L .32927 .60773 L .071 0 .412 r
F
.32926 .60365 m .32958 .60444 L .32931 .60487 L F
.32926 .60495 m .32927 .60773 L .3292 .60505 L F
.32977 .60381 m .3318 .60489 L .33205 .60382 L .675 .735 .895 r
F
.32926 .60365 m .32926 .60495 L .32916 .60379 L .071 0 .412 r
F
.32591 .59187 m .32744 .60469 L .32621 .6048 L .641 .402 .541 r
F
.3268 .60196 m .32545 .60487 L .3267 .60476 L .654 .726 .902 r
F
.32921 .59067 m .32959 .60316 L .32926 .60365 L .071 0 .412 r
F
.32921 .59067 m .32926 .60365 L .32916 .60379 L F
.33131 .60298 m .3534 .61335 L .35669 .6087 L .654 .726 .902 r
F
.3268 .60196 m .33395 .60502 L .33131 .60298 L F
.33395 .60502 m .3534 .61335 L .33131 .60298 L F
.33064 .62128 m .33031 .61869 L .33489 .61747 L .592 .367 .544 r
F
.33036 .62153 m .33036 .62134 L .33064 .62128 L F
.33036 .62134 m .33031 .61869 L .33064 .62128 L F
.33366 .62064 m .33376 .62902 L .33805 .62812 L .654 .726 .902 r
F
.33031 .61869 m .33483 .61462 L .33489 .61747 L .592 .367 .544 r
F
.33031 .61869 m .33026 .61584 L .33483 .61462 L F
.32883 .61467 m .33031 .61869 L .33489 .61747 L .675 .735 .895 r
F
.33376 .62062 m .33489 .61747 L .33494 .62031 L .592 .367 .544 r
F
.33149 .6211 m .33376 .62902 L .33366 .62064 L .654 .726 .902 r
F
.33036 .62153 m .33064 .62128 L .33376 .62062 L .592 .367 .544 r
F
.33064 .62128 m .33489 .61747 L .33376 .62062 L F
.33123 .61688 m .33494 .62031 L .33193 .6167 L .675 .735 .895 r
F
.32958 .61446 m .33149 .6211 L .33291 .61936 L .654 .726 .902 r
F
.32558 .61493 m .33031 .61869 L .32883 .61467 L .675 .735 .895 r
F
.32773 .61291 m .33376 .62902 L .32904 .61366 L .654 .726 .902 r
F
.32872 .61139 m .32893 .61308 L .33025 .61243 L .675 .735 .895 r
F
.32851 .61124 m .32859 .61159 L .32872 .61139 L F
.32859 .61159 m .32893 .61308 L .32872 .61139 L F
.32927 .60773 m .32928 .6105 L .32918 .60786 L .071 0 .412 r
F
.32615 .62148 m .33036 .62134 L .33036 .62153 L .666 .426 .547 r
F
.32883 .62206 m .33331 .63629 L .32908 .62035 L .654 .726 .902 r
F
.3273 .61177 m .32702 .62145 L .32876 .61568 L F
.32563 .61777 m .32548 .62192 L .33036 .62153 L .675 .735 .895 r
F
.32699 .61943 m .32737 .62044 L .32781 .61882 L .654 .726 .902 r
F
.33034 .61557 m .33123 .61688 L .33193 .6167 L .675 .735 .895 r
F
.33292 .61938 m .33494 .62031 L .33123 .61688 L F
.32904 .61366 m .32905 .61369 L .32906 .61367 L .654 .726 .902 r
F
.3287 .61315 m .33193 .6167 L .32893 .61308 L .675 .735 .895 r
F
.32905 .61369 m .32958 .61446 L .32906 .61367 L .654 .726 .902 r
F
.3274 .61349 m .33034 .61557 L .3287 .61315 L .675 .735 .895 r
F
.32883 .61467 m .33489 .61747 L .33188 .61385 L F
.33034 .61557 m .33193 .6167 L .3287 .61315 L F
.32905 .61369 m .33376 .62902 L .32958 .61446 L .654 .726 .902 r
F
.32906 .61367 m .32958 .61446 L .32916 .61297 L F
.32848 .6118 m .33291 .61936 L .33342 .61779 L F
.32928 .6105 m .32931 .61757 L .3292 .61063 L .071 0 .412 r
F
.32928 .6105 m .3292 .61063 L .32918 .60786 L F
.32876 .61179 m .33479 .61457 L .3318 .61098 L .675 .735 .895 r
F
.32888 .61024 m .33188 .61385 L .33452 .61255 L F
.32888 .61024 m .33452 .61255 L .3302 .60959 L F
.32981 .61019 m .33127 .61158 L .33194 .61058 L F
.3279 .61173 m .32893 .61308 L .32851 .61127 L F
.32843 .6113 m .32851 .61127 L .32851 .61124 L F
.3279 .61173 m .32851 .61127 L .32843 .6113 L F
.32844 .60849 m .32888 .61024 L .32853 .60845 L F
.32769 .60882 m .32783 .60899 L .32844 .60849 L F
.32783 .60899 m .32888 .61024 L .32844 .60849 L F
.32844 .60849 m .32854 .61121 L .32843 .6113 L .356 .178 .497 r
F
.32846 .60431 m .32851 .60844 L .32844 .60849 L F
.32851 .60844 m .32854 .61121 L .32844 .60849 L F
.32773 .6088 m .32844 .60849 L .32843 .6113 L .517 .303 .528 r
F
.32773 .61291 m .32904 .61366 L .32813 .61231 L .654 .726 .902 r
F
.32792 .61152 m .32843 .6113 L .32841 .61839 L .517 .303 .528 r
F
.32773 .6088 m .32843 .6113 L .32792 .61152 L F
.32702 .62145 m .32793 .62142 L .32876 .61568 L .654 .726 .902 r
F
.32729 .61174 m .32637 .62147 L .32701 .62145 L F
.32563 .61777 m .33036 .62153 L .32888 .61751 L .675 .735 .895 r
F
.32781 .61882 m .3285 .61835 L .32841 .61839 L .654 .726 .902 r
F
.32737 .62044 m .32859 .6237 L .32802 .61948 L F
.32786 .61859 m .32841 .61839 L .32829 .64979 L .517 .303 .528 r
F
.32749 .59167 m .32776 .61159 L .32742 .61173 L F
.32645 .60983 m .32778 .61158 L .32851 .61124 L .675 .735 .895 r
F
.32778 .61158 m .3279 .61173 L .32843 .6113 L F
.32778 .61158 m .32843 .6113 L .32851 .61124 L F
.32746 .61132 m .32893 .61308 L .32645 .60983 L F
.32776 .61159 m .32776 .6116 L .32767 .61163 L .517 .303 .528 r
F
.32776 .61159 m .32767 .61163 L .32742 .61173 L F
.32776 .61159 m .32792 .61154 L .32776 .6116 L F
.32773 .6088 m .32792 .61152 L .32776 .61159 L F
.32792 .61152 m .32792 .61154 L .32776 .61159 L F
.32945 .61086 m .33025 .61243 L .33127 .61158 L .675 .735 .895 r
F
.32934 .60762 m .32939 .61033 L .32927 .60773 L .071 0 .412 r
F
.32853 .61126 m .33025 .61243 L .32945 .61086 L .675 .735 .895 r
F
.32893 .61308 m .33458 .61539 L .33025 .61243 L F
.32822 .6115 m .33342 .61779 L .32887 .61102 L .654 .726 .902 r
F
.32939 .61033 m .32954 .61724 L .32935 .6104 L .071 0 .412 r
F
.32939 .61033 m .32935 .6104 L .32927 .60773 L F
.32592 .60947 m .32853 .61126 L .3289 .6111 L .675 .735 .895 r
F
.32913 .61073 m .3289 .6111 L .32945 .61086 L F
.32592 .60947 m .3289 .6111 L .32913 .61073 L F
.32635 .60923 m .32818 .61144 L .32887 .61102 L .654 .726 .902 r
F
.32818 .61144 m .32822 .6115 L .32843 .61135 L F
.32813 .61231 m .32904 .61366 L .32848 .6118 L F
.32854 .61121 m .32862 .61823 L .32843 .6113 L .356 .178 .497 r
F
.32818 .61144 m .32843 .61135 L .32887 .61102 L .654 .726 .902 r
F
.32578 .61362 m .32888 .61751 L .3274 .61349 L .675 .735 .895 r
F
.32776 .6116 m .32841 .61839 L .32786 .61859 L .517 .303 .528 r
F
.32792 .61154 m .32841 .61839 L .32776 .6116 L F
.33489 .61747 m .33483 .61462 L .3388 .61267 L .497 .294 .534 r
F
.33489 .61747 m .3388 .61267 L .33885 .61551 L F
.33188 .61385 m .33489 .61747 L .33885 .61551 L .675 .735 .895 r
F
.3389 .61835 m .33885 .61551 L .34193 .61295 L .357 .187 .509 r
F
.3318 .61098 m .33479 .61457 L .33873 .61262 L .675 .735 .895 r
F
.33188 .61385 m .33885 .61551 L .33452 .61255 L F
.3389 .61835 m .34193 .61295 L .34198 .61579 L .357 .187 .509 r
F
.33458 .61539 m .34198 .61579 L .33663 .61368 L .675 .735 .895 r
F
.32896 .61108 m .34797 .62457 L .32935 .61051 L .654 .726 .902 r
F
.32913 .61073 m .33127 .61158 L .32981 .61019 L .675 .735 .895 r
F
.32935 .61051 m .3295 .61063 L .32951 .61058 L .654 .726 .902 r
F
.3294 .61044 m .32956 .6102 L .32954 .61724 L .071 0 .412 r
F
.32952 .60908 m .32944 .616 L .3296 .60927 L .986 .729 .347 r
F
.33291 .61936 m .33366 .62064 L .33364 .62045 L .654 .726 .902 r
F
.33366 .62064 m .33805 .62812 L .33461 .62044 L F
.33302 .61955 m .33218 .62096 L .33366 .62064 L F
.33291 .61936 m .33218 .62096 L .33302 .61955 L F
.33291 .61936 m .33149 .6211 L .33218 .62096 L F
.32888 .61751 m .33036 .62153 L .33376 .62062 L .675 .735 .895 r
F
.33292 .61938 m .33376 .62062 L .33494 .62031 L F
.32888 .61751 m .33376 .62062 L .33292 .61938 L F
.33342 .61779 m .33805 .62812 L .34137 .62742 L .654 .726 .902 r
F
.33494 .62031 m .33489 .61747 L .33885 .61551 L .497 .294 .534 r
F
.33494 .62031 m .33885 .61551 L .3389 .61835 L F
.33193 .6167 m .33494 .62031 L .3389 .61835 L .675 .735 .895 r
F
.33193 .6167 m .3389 .61835 L .33458 .61539 L F
.33109 .61259 m .34137 .62742 L .34797 .62457 L .654 .726 .902 r
F
.32929 .6186 m .34752 .63184 L .34895 .63075 L F
.32589 .6165 m .3289 .61863 L .32929 .6186 L F
.33055 .61849 m .34895 .63075 L .33628 .62094 L F
.32911 .61787 m .32942 .64855 L .32899 .64923 L .071 0 .412 r
F
.3274 .61349 m .32888 .61751 L .33123 .61688 L .675 .735 .895 r
F
.32949 .60387 m .34831 .61723 L .32959 .60315 L .654 .726 .902 r
F
.33885 .61551 m .3388 .61267 L .34188 .61011 L .357 .187 .509 r
F
.33885 .61551 m .34188 .61011 L .34193 .61295 L F
.33452 .61255 m .33885 .61551 L .34193 .61295 L .675 .735 .895 r
F
.34198 .61579 m .34193 .61295 L .34391 .60995 L .114 .006 .441 r
F
.3318 .61098 m .33873 .61262 L .33443 .60968 L .675 .735 .895 r
F
.33452 .61255 m .34193 .61295 L .33658 .61084 L F
.3302 .60959 m .33452 .61255 L .33658 .61084 L F
.33663 .61368 m .34198 .61579 L .34396 .6128 L F
.34198 .61579 m .34391 .60995 L .34396 .6128 L .114 .006 .441 r
F
.33663 .61368 m .34396 .6128 L .33795 .61169 L .675 .735 .895 r
F
.33127 .61158 m .33663 .61368 L .33795 .61169 L F
.33127 .61158 m .33795 .61169 L .33194 .61058 L F
.32971 .60998 m .35309 .62068 L .35639 .616 L .654 .726 .902 r
F
.32876 .60823 m .32912 .61075 L .32886 .61096 L .356 .178 .497 r
F
.32592 .60947 m .32913 .61073 L .32981 .61019 L .675 .735 .895 r
F
.32935 .6104 m .32935 .61051 L .32928 .6105 L .071 0 .412 r
F
.32927 .60773 m .32935 .6104 L .32928 .6105 L F
.32592 .60947 m .32952 .61013 L .32992 .60949 L .675 .735 .895 r
F
.32635 .60923 m .32935 .61051 L .32971 .60998 L .654 .726 .902 r
F
.32935 .61051 m .35309 .62068 L .32971 .60998 L F
.32913 .61083 m .32924 .61767 L .32911 .61787 L .071 0 .412 r
F
.32916 .60379 m .3292 .61073 L .32913 .61083 L F
.32916 .61297 m .32958 .61446 L .33291 .61936 L .654 .726 .902 r
F
.3292 .61073 m .32924 .61767 L .32913 .61083 L .071 0 .412 r
F
.32924 .61767 m .32942 .64855 L .32911 .61787 L F
.32911 .61787 m .3311 .61972 L .33055 .61849 L .654 .726 .902 r
F
.32619 .61366 m .32528 .6152 L .32609 .61664 L F
.32729 .61178 m .32679 .62925 L .3273 .61177 L F
.32578 .61362 m .32563 .61777 L .32888 .61751 L .675 .735 .895 r
F
.32589 .6165 m .32882 .6183 L .32911 .61787 L .654 .726 .902 r
F
.32882 .6183 m .3311 .61972 L .32911 .61787 L F
.3311 .61972 m .34895 .63075 L .33055 .61849 L F
.3296 .60993 m .32959 .61688 L .32958 .61008 L 0 0 .131 r
F
.32887 .61102 m .33254 .61583 L .33109 .61259 L .654 .726 .902 r
F
.3296 .60927 m .32951 .61615 L .32967 .60943 L .986 .729 .347 r
F
.32888 .61751 m .33292 .61938 L .33123 .61688 L .675 .735 .895 r
F
.33291 .61936 m .33364 .62045 L .33342 .61779 L .654 .726 .902 r
F
.33366 .62064 m .33461 .62044 L .33342 .61779 L F
.33458 .61539 m .3389 .61835 L .34198 .61579 L .675 .735 .895 r
F
.33025 .61243 m .33458 .61539 L .33663 .61368 L F
.33025 .61243 m .33663 .61368 L .33127 .61158 L F
.32951 .61058 m .34797 .62457 L .35309 .62068 L .654 .726 .902 r
F
.3295 .61063 m .34797 .62457 L .32951 .61058 L F
.33254 .61583 m .34137 .62742 L .33109 .61259 L F
.33244 .61797 m .35264 .62795 L .35594 .62327 L F
.32776 .6116 m .32786 .61859 L .32742 .61173 L .517 .303 .528 r
F
.32737 .62044 m .32802 .61948 L .32781 .61882 L .654 .726 .902 r
F
.32786 .61859 m .32829 .64979 L .32758 .6187 L .517 .303 .528 r
F
.32786 .61859 m .32758 .6187 L .32742 .61173 L F
.33061 .61756 m .33628 .62094 L .33244 .61797 L .654 .726 .902 r
F
.32854 .60565 m .32859 .606 L .32873 .60578 L .675 .735 .895 r
F
.32853 .60845 m .3286 .60879 L .32873 .60858 L F
.33443 .60968 m .33873 .61262 L .34179 .61007 L F
.33658 .61084 m .34193 .61295 L .34391 .60995 L F
.3302 .60959 m .33658 .61084 L .33122 .60873 L F
.34193 .61295 m .34188 .61011 L .34386 .60711 L .114 .006 .441 r
F
.34396 .6128 m .34391 .60995 L .34467 .60673 L 0 0 .247 r
F
.34396 .6128 m .34467 .60673 L .34472 .60958 L F
.33795 .61169 m .34396 .6128 L .34472 .60958 L .675 .735 .895 r
F
.34193 .61295 m .34386 .60711 L .34391 .60995 L .114 .006 .441 r
F
.33443 .60968 m .34179 .61007 L .33647 .60798 L .675 .735 .895 r
F
.33658 .61084 m .34391 .60995 L .3379 .60885 L F
.33795 .61169 m .34472 .60958 L .33845 .60954 L F
.33122 .60873 m .33658 .61084 L .3379 .60885 L F
.33194 .61058 m .33795 .61169 L .33845 .60954 L F
.33194 .61058 m .33845 .60954 L .33219 .60951 L F
.33098 .60947 m .35639 .616 L .35765 .61087 L .654 .726 .902 r
F
.32848 .6118 m .32904 .61366 L .32916 .61297 L F
.32904 .61366 m .32906 .61367 L .32916 .61297 L F
.32886 .61103 m .32913 .61083 L .32911 .61787 L .356 .178 .497 r
F
.32922 .60842 m .32887 .6152 L .32919 .61546 L .908 .63 .503 r
F
.32927 .60773 m .32917 .6051 L .3292 .60505 L .071 0 .412 r
F
.32916 .6051 m .33114 .60588 L .32956 .60448 L .675 .735 .895 r
F
.32968 .60377 m .32968 .60645 L .32964 .60407 L 0 0 .131 r
F
.32958 .60448 m .33011 .60458 L .32967 .60381 L .675 .735 .895 r
F
.33011 .60458 m .3318 .60489 L .32977 .60381 L F
.32968 .60377 m .32964 .60407 L .32961 .60299 L 0 0 .131 r
F
.32749 .59167 m .32846 .60431 L .32767 .60461 L .517 .303 .528 r
F
.3268 .60196 m .32777 .60457 L .32867 .60423 L .654 .726 .902 r
F
.32967 .60257 m .3297 .60239 L .32969 .60364 L 0 0 .131 r
F
.32968 .60377 m .32969 .60364 L .32968 .60645 L F
.32967 .60257 m .32969 .60364 L .32968 .60377 L F
.32977 .60311 m .33205 .60382 L .33188 .60275 L .675 .735 .895 r
F
.32749 .59167 m .32851 .59123 L .32846 .60431 L .517 .303 .528 r
F
.3268 .60196 m .3267 .60476 L .32781 .60466 L .654 .726 .902 r
F
.32582 .60379 m .32967 .60381 L .32977 .60311 L .675 .735 .895 r
F
.32967 .60381 m .33205 .60382 L .32977 .60311 L F
.32953 .60327 m .32924 .60262 L .32923 .60543 L .986 .729 .347 r
F
.32862 .60419 m .32867 .61117 L .32846 .60431 L .356 .178 .497 r
F
.32949 .60601 m .32995 .60665 L .33047 .60584 L .675 .735 .895 r
F
.32587 .60663 m .32977 .60665 L .32949 .60601 L F
.32977 .60665 m .32995 .60665 L .32949 .60601 L F
.32943 .60747 m .32957 .60725 L .32956 .6102 L .071 0 .412 r
F
.32952 .60762 m .33058 .60848 L .32984 .60736 L .675 .735 .895 r
F
.32915 .60792 m .32946 .60804 L .32952 .60762 L F
.32946 .60804 m .33058 .60848 L .32952 .60762 L F
.3296 .60993 m .32958 .61008 L .32958 .60718 L 0 0 .131 r
F
.32959 .60709 m .32958 .60718 L .32959 .60316 L F
.3296 .60993 m .32958 .60718 L .32959 .60709 L F
.32926 .60365 m .32956 .6102 L .3294 .61044 L .071 0 .412 r
F
.32587 .60663 m .32915 .60792 L .32984 .60736 L .675 .735 .895 r
F
.32961 .60702 m .32968 .60645 L .32967 .60943 L 0 0 .131 r
F
.32964 .60636 m .3296 .60927 L .32968 .60645 L .986 .729 .347 r
F
.33012 .60673 m .33443 .60968 L .33647 .60798 L .675 .735 .895 r
F
.32977 .60665 m .33188 .60774 L .33214 .60666 L F
.32587 .60663 m .33011 .60741 L .32977 .60665 L F
.33011 .60741 m .33188 .60774 L .32977 .60665 L F
.32952 .60892 m .32961 .60911 L .32964 .60636 L .986 .729 .347 r
F
.33058 .60848 m .33122 .60873 L .33011 .60741 L .675 .735 .895 r
F
.32922 .60824 m .33201 .60843 L .33142 .60742 L F
.32867 .61117 m .3286 .61123 L .32846 .60431 L .356 .178 .497 r
F
.32582 .60379 m .32958 .60448 L .32967 .60381 L .675 .735 .895 r
F
.32582 .60379 m .32916 .6051 L .32956 .60448 L F
.32851 .59123 m .32916 .60379 L .32862 .60419 L .356 .178 .497 r
F
.33022 .60214 m .35669 .6087 L .35794 .60359 L .654 .726 .902 r
F
.3268 .60196 m .33131 .60298 L .33022 .60214 L F
.33131 .60298 m .35669 .6087 L .33022 .60214 L F
.3293 .58814 m .32824 .58732 L .32819 .60056 L .908 .63 .503 r
F
.3268 .60196 m .32927 .60371 L .32959 .60315 L .654 .726 .902 r
F
.32818 .60056 m .34933 .58898 L .34299 .58547 L F
.32824 .58732 m .32717 .58694 L .32712 .60017 L .809 .541 .534 r
F
.3268 .60196 m .32863 .60091 L .32819 .60056 L .654 .726 .902 r
F
.32582 .60379 m .3285 .60206 L .32819 .60183 L .675 .735 .895 r
F
.32592 .60947 m .3295 .60886 L .32922 .60824 L F
.32739 .61877 m .32829 .64979 L .32727 .65023 L .517 .303 .528 r
F
.32758 .6187 m .32829 .64979 L .32739 .61877 L F
.33438 .61694 m .35594 .62327 L .3572 .61813 L .654 .726 .902 r
F
.32886 .61096 m .32913 .61083 L .32886 .61103 L .356 .178 .497 r
F
.32912 .61075 m .32913 .61083 L .32886 .61096 L F
.32928 .6105 m .32935 .61051 L .32928 .61061 L .071 0 .412 r
F
.32635 .60923 m .32896 .61108 L .32935 .61051 L .654 .726 .902 r
F
.32886 .60797 m .32816 .60745 L .32814 .61464 L .908 .63 .503 r
F
.32589 .6165 m .32911 .61787 L .32978 .61737 L .654 .726 .902 r
F
.32841 .61839 m .3285 .61835 L .32848 .61833 L F
.32862 .61823 m .32854 .61829 L .32843 .6113 L .356 .178 .497 r
F
.32859 .6237 m .32883 .62206 L .32802 .61948 L .654 .726 .902 r
F
.32781 .61882 m .32883 .62206 L .32908 .62035 L F
.32843 .6113 m .32854 .61829 L .32841 .61839 L .356 .178 .497 r
F
.32992 .60949 m .33194 .61058 L .33219 .60951 L .675 .735 .895 r
F
.32952 .61013 m .33194 .61058 L .32992 .60949 L F
.33015 .61008 m .35639 .616 L .33098 .60947 L .654 .726 .902 r
F
.3296 .60993 m .32965 .61647 L .32959 .61688 L 0 0 .131 r
F
.32958 .61008 m .32957 .617 L .32956 .6102 L F
.32957 .617 m .32953 .64774 L .32956 .61709 L F
.32957 .617 m .32956 .61709 L .32956 .6102 L F
.33647 .60798 m .34179 .61007 L .34377 .6071 L .675 .735 .895 r
F
.34391 .60995 m .34386 .60711 L .34462 .60389 L 0 0 .247 r
F
.34391 .60995 m .34462 .60389 L .34467 .60673 L F
.3379 .60885 m .34391 .60995 L .34467 .60673 L .675 .735 .895 r
F
.33779 .60599 m .34377 .6071 L .34452 .60389 L F
.3384 .6067 m .34467 .60673 L .34414 .6035 L F
.34472 .60958 m .34467 .60673 L .34414 .6035 L .862 .663 .13 r
F
.34472 .60958 m .34414 .6035 L .3442 .60635 L F
.33845 .60954 m .34472 .60958 L .3442 .60635 L .675 .735 .895 r
F
.33647 .60798 m .34377 .6071 L .33779 .60599 L F
.33114 .60588 m .33647 .60798 L .33779 .60599 L F
.33829 .60386 m .34452 .60389 L .344 .60068 L F
.34467 .60673 m .34462 .60389 L .34409 .60066 L .862 .663 .13 r
F
.33072 .6015 m .35794 .60359 L .35707 .59836 L .654 .726 .902 r
F
.3268 .60196 m .33283 .60228 L .33072 .6015 L F
.33283 .60228 m .35794 .60359 L .33072 .6015 L F
.32925 .60138 m .32914 .60536 L .32923 .60543 L .908 .63 .503 r
F
.32964 .58999 m .32967 .60257 L .32961 .60299 L 0 0 .131 r
F
.32964 .58999 m .32975 .58918 L .3297 .60239 L F
.32964 .58999 m .3297 .60239 L .32967 .60257 L F
.32975 .58918 m .3296 .60216 L .3297 .60239 L .986 .729 .347 r
F
.32964 .58999 m .32961 .60299 L .32959 .60316 L 0 0 .131 r
F
.33079 .60071 m .35707 .59836 L .35413 .59338 L .654 .726 .902 r
F
.3268 .60196 m .33373 .60114 L .33079 .60071 L F
.33373 .60114 m .35707 .59836 L .33079 .60071 L F
.32589 .6165 m .33244 .61797 L .33087 .61676 L F
.32625 .60629 m .32744 .60612 L .32742 .61173 L .641 .402 .541 r
F
.32729 .61174 m .32729 .61178 L .3273 .61177 L .654 .726 .902 r
F
.32675 .61179 m .32742 .61173 L .32739 .61877 L .641 .402 .541 r
F
.32675 .60903 m .32572 .61078 L .32735 .61065 L .675 .735 .895 r
F
.32625 .60629 m .32742 .61173 L .32675 .61179 L .641 .402 .541 r
F
.32834 .61165 m .32773 .61291 L .32848 .6118 L .654 .726 .902 r
F
.32635 .60923 m .32729 .61174 L .32834 .61165 L F
.32729 .61174 m .32773 .61291 L .32807 .61222 L F
.32729 .61174 m .32807 .61222 L .32772 .6117 L F
.32631 .60909 m .32638 .61189 L .32617 .60911 L .641 .402 .541 r
F
.32625 .60629 m .32739 .61877 L .32654 .61884 L F
.32635 .60923 m .32626 .61183 L .32729 .61174 L .654 .726 .902 r
F
.32592 .60947 m .3274 .61349 L .3287 .61315 L .675 .735 .895 r
F
.32746 .61132 m .3287 .61315 L .32893 .61308 L F
.32592 .60947 m .3287 .61315 L .32746 .61132 L F
.32772 .6117 m .32807 .61222 L .32834 .61165 L .654 .726 .902 r
F
.32589 .6165 m .32699 .61943 L .32781 .61882 L F
.32679 .62129 m .32519 .63655 L .32737 .62044 L F
.32682 .61898 m .32677 .61959 L .32699 .61943 L F
.32677 .61882 m .32675 .61901 L .32682 .61898 L F
.32654 .61884 m .32727 .65023 L .3263 .61886 L .641 .402 .541 r
F
.32637 .62147 m .32564 .62928 L .32701 .62145 L .654 .726 .902 r
F
.32677 .61959 m .32519 .63655 L .32699 .61943 L F
.32675 .61901 m .32519 .63655 L .32682 .61898 L F
.32581 .61891 m .32519 .63655 L .32677 .61882 L F
.32583 .61187 m .32727 .65023 L .32569 .65043 L .641 .402 .541 r
F
.32608 .61185 m .3263 .61886 L .32583 .61187 L F
.3263 .61886 m .32727 .65023 L .3261 .61888 L F
.3263 .61886 m .3261 .61888 L .32583 .61187 L F
.33353 .61663 m .34294 .61739 L .34463 .61682 L .654 .726 .902 r
F
.32589 .6165 m .33438 .61694 L .33353 .61663 L F
.33438 .61694 m .34294 .61739 L .33353 .61663 L F
.32587 .60663 m .32769 .60882 L .32853 .60845 L .675 .735 .895 r
F
.32779 .60746 m .32709 .60721 L .32706 .61424 L .809 .541 .534 r
F
.32742 .61173 m .32758 .6187 L .32739 .61877 L .517 .303 .528 r
F
.32589 .6165 m .34463 .61682 L .33503 .61541 L .654 .726 .902 r
F
.32699 .61943 m .32679 .62129 L .32737 .62044 L F
.32654 .61884 m .32739 .61877 L .32727 .65023 L .641 .402 .541 r
F
.32589 .6165 m .32781 .61882 L .32848 .61833 L .654 .726 .902 r
F
.33188 .60774 m .3384 .6067 L .33214 .60666 L .675 .735 .895 r
F
.34467 .60673 m .34409 .60066 L .34414 .6035 L .862 .663 .13 r
F
.33779 .60599 m .34452 .60389 L .33829 .60386 L .675 .735 .895 r
F
.3384 .6067 m .34414 .6035 L .33805 .60455 L F
.33201 .60843 m .33692 .60538 L .33142 .60742 L F
.33214 .60666 m .3384 .6067 L .33805 .60455 L F
.33201 .60843 m .3381 .60739 L .33692 .60538 L F
.3381 .60739 m .34242 .60333 L .33692 .60538 L F
.3381 .60739 m .3442 .60635 L .34242 .60333 L F
.32971 .60817 m .35677 .60561 L .35382 .60061 L .654 .726 .902 r
F
.3379 .60885 m .34467 .60673 L .3384 .6067 L .675 .735 .895 r
F
.33188 .60774 m .3379 .60885 L .3384 .6067 L F
.33845 .60954 m .3442 .60635 L .3381 .60739 L F
.33106 .60867 m .35677 .60561 L .32971 .60817 L .654 .726 .902 r
F
.32931 .61757 m .32924 .61767 L .3292 .61063 L .071 0 .412 r
F
.3274 .61349 m .33123 .61688 L .33034 .61557 L .675 .735 .895 r
F
.32928 .61061 m .32954 .61724 L .32931 .61757 L .071 0 .412 r
F
.32935 .61051 m .32954 .61724 L .32928 .61061 L F
.32893 .61308 m .33193 .6167 L .33458 .61539 L .675 .735 .895 r
F
.32952 .60908 m .32919 .61546 L .32944 .616 L .986 .729 .347 r
F
.33829 .60386 m .344 .60068 L .33794 .60171 L .675 .735 .895 r
F
.33122 .60873 m .3379 .60885 L .33188 .60774 L F
.33219 .60951 m .33845 .60954 L .3381 .60739 L F
.33219 .60951 m .3381 .60739 L .33201 .60843 L F
.33805 .60455 m .34414 .6035 L .34237 .60049 L F
.32592 .60947 m .32922 .60824 L .32899 .60772 L F
.32952 .60908 m .32964 .60636 L .32959 .60625 L .986 .729 .347 r
F
.32891 .60755 m .33142 .60742 L .33046 .60656 L .675 .735 .895 r
F
.32955 .60615 m .32924 .60829 L .32952 .60891 L .986 .729 .347 r
F
.32984 .60736 m .33058 .60848 L .33011 .60741 L .675 .735 .895 r
F
.32959 .60316 m .32958 .61008 L .32956 .6102 L 0 0 .131 r
F
.32922 .60824 m .33142 .60742 L .32891 .60755 L .675 .735 .895 r
F
.3286 .61123 m .32854 .61127 L .32846 .60431 L .356 .178 .497 r
F
.32961 .60702 m .32967 .60943 L .3296 .60993 L 0 0 .131 r
F
.32968 .60645 m .3296 .60927 L .32967 .60943 L .986 .729 .347 r
F
.3295 .60886 m .33201 .60843 L .32922 .60824 L .675 .735 .895 r
F
.32913 .60835 m .33106 .60867 L .32971 .60817 L .654 .726 .902 r
F
.32952 .60891 m .32922 .60842 L .32952 .60908 L .986 .729 .347 r
F
.32924 .60829 m .32922 .60842 L .32952 .60891 L F
.32635 .60923 m .32974 .60882 L .32913 .60835 L .654 .726 .902 r
F
.32974 .60882 m .33106 .60867 L .32913 .60835 L F
.32892 .6052 m .32886 .60797 L .32909 .60533 L .908 .63 .503 r
F
.32938 .60577 m .32922 .60842 L .32955 .60615 L .986 .729 .347 r
F
.32938 .60577 m .32923 .60543 L .32922 .60842 L F
.32923 .60543 m .32906 .60829 L .32922 .60842 L .908 .63 .503 r
F
.32914 .60536 m .32906 .60829 L .32923 .60543 L F
.32793 .60727 m .33046 .60656 L .32918 .60589 L .675 .735 .895 r
F
.32587 .60663 m .32851 .60844 L .32915 .60792 L F
.32592 .60947 m .32858 .60776 L .32793 .60727 L F
.32886 .60797 m .32887 .60798 L .32909 .60533 L .908 .63 .503 r
F
.32885 .60814 m .32897 .60823 L .32909 .60533 L F
.32858 .60776 m .33046 .60656 L .32793 .60727 L .675 .735 .895 r
F
.32886 .60797 m .32885 .60814 L .32887 .60798 L .908 .63 .503 r
F
.32892 .60811 m .32913 .61083 L .32876 .60823 L .356 .178 .497 r
F
.32885 .60814 m .3287 .61508 L .32897 .60823 L .908 .63 .503 r
F
.3286 .60879 m .32888 .61024 L .32873 .60858 L .675 .735 .895 r
F
.32867 .61117 m .32911 .61787 L .32873 .61815 L .356 .178 .497 r
F
.32862 .60419 m .32886 .61103 L .32867 .61117 L F
.32886 .61103 m .32911 .61787 L .32867 .61117 L F
.33227 .60852 m .35765 .61087 L .35677 .60561 L .654 .726 .902 r
F
.32592 .60947 m .33219 .60951 L .33201 .60843 L .675 .735 .895 r
F
.32952 .60908 m .3296 .60927 L .32961 .60911 L .986 .729 .347 r
F
.32952 .60908 m .32961 .60911 L .32952 .60892 L F
.32635 .60923 m .33098 .60947 L .33227 .60852 L .654 .726 .902 r
F
.33098 .60947 m .35765 .61087 L .33227 .60852 L F
.3287 .61508 m .32887 .6152 L .32906 .60829 L .908 .63 .503 r
F
.32961 .60299 m .32961 .60702 L .32959 .60316 L 0 0 .131 r
F
.32961 .60702 m .3296 .60993 L .32959 .60709 L F
.32961 .60702 m .32959 .60709 L .32959 .60316 L F
.32987 .60514 m .33196 .60559 L .33137 .60458 L .675 .735 .895 r
F
.32961 .60299 m .32968 .60645 L .32961 .60702 L 0 0 .131 r
F
.32959 .60625 m .32964 .60636 L .3297 .60239 L .986 .729 .347 r
F
.32918 .6054 m .32983 .60544 L .32987 .60514 L .675 .735 .895 r
F
.32983 .60544 m .33196 .60559 L .32987 .60514 L F
.32669 .60499 m .32639 .60556 L .32667 .60569 L .654 .726 .902 r
F
.32621 .6048 m .32744 .60612 L .32625 .60629 L .641 .402 .541 r
F
.32672 .60622 m .32744 .60612 L .32768 .60602 L .675 .735 .895 r
F
.32587 .60663 m .3299 .60594 L .32918 .6054 L F
.32931 .60487 m .32958 .60444 L .32957 .60725 L .071 0 .412 r
F
.3299 .60594 m .33196 .60559 L .32918 .6054 L .675 .735 .895 r
F
.32897 .60823 m .32906 .60829 L .32914 .60536 L .908 .63 .503 r
F
.32909 .60533 m .32914 .60536 L .32925 .60138 L F
.32897 .60823 m .32914 .60536 L .32909 .60533 L F
.3287 .61508 m .32906 .60829 L .32897 .60823 L F
.3318 .60489 m .33779 .60599 L .33829 .60386 L .675 .735 .895 r
F
.33114 .60588 m .33779 .60599 L .3318 .60489 L F
.33205 .60382 m .33829 .60386 L .33794 .60171 L F
.33214 .60666 m .33805 .60455 L .33196 .60559 L F
.3318 .60489 m .33829 .60386 L .33205 .60382 L F
.33196 .60559 m .33805 .60455 L .33687 .60253 L F
.33805 .60455 m .34237 .60049 L .33687 .60253 L F
.33794 .60171 m .344 .60068 L .34224 .59768 L F
.34414 .6035 m .34232 .59765 L .34237 .60049 L .987 .713 .388 r
F
.32995 .60665 m .33214 .60666 L .33047 .60584 L .675 .735 .895 r
F
.33142 .60742 m .33499 .60365 L .33046 .60656 L F
.33142 .60742 m .33692 .60538 L .33499 .60365 L F
.33692 .60538 m .33953 .60073 L .33499 .60365 L F
.33794 .60171 m .34224 .59768 L .33676 .59971 L F
.33687 .60253 m .34237 .60049 L .33948 .59789 L F
.34242 .60333 m .34237 .60049 L .33948 .59789 L .932 .65 .484 r
F
.32859 .60793 m .335 .60651 L .34899 .59619 L .654 .726 .902 r
F
.32635 .60923 m .32913 .60835 L .32859 .60793 L F
.32913 .60835 m .335 .60651 L .32859 .60793 L F
.34414 .6035 m .34409 .60066 L .34232 .59765 L .987 .713 .388 r
F
.3442 .60635 m .34414 .6035 L .34237 .60049 L F
.3442 .60635 m .34237 .60049 L .34242 .60333 L F
.33692 .60538 m .34242 .60333 L .33953 .60073 L .675 .735 .895 r
F
.335 .60651 m .35382 .60061 L .34901 .5962 L .654 .726 .902 r
F
.335 .60651 m .34901 .5962 L .34899 .59619 L F
.32873 .61815 m .32862 .61823 L .32854 .61127 L .356 .178 .497 r
F
.32873 .61815 m .32854 .61127 L .3286 .61123 L F
.32798 .61438 m .34854 .60346 L .34217 .59993 L .654 .726 .902 r
F
.32589 .6165 m .32925 .61456 L .32798 .61438 L F
.32956 .6102 m .32956 .61709 L .32954 .61724 L 0 0 .131 r
F
.32959 .61688 m .32957 .617 L .32958 .61008 L F
.32951 .61615 m .32956 .61628 L .32967 .60943 L .986 .729 .347 r
F
.3296 .60993 m .32967 .60943 L .32965 .61647 L 0 0 .131 r
F
.32967 .60943 m .32956 .61628 L .32965 .61647 L .986 .729 .347 r
F
.32944 .616 m .32951 .61615 L .3296 .60927 L F
.32925 .61456 m .34854 .60346 L .32798 .61438 L .654 .726 .902 r
F
.32582 .60379 m .32768 .60602 L .32854 .60565 L .675 .735 .895 r
F
.32587 .60663 m .32675 .60903 L .32775 .60889 L F
.32582 .60379 m .32914 .60255 L .3285 .60206 L F
.32819 .60183 m .32796 .60456 L .32817 .60464 L .809 .541 .534 r
F
.3268 .60196 m .35413 .59338 L .34933 .58898 L .654 .726 .902 r
F
.32819 .60056 m .32812 .60181 L .32819 .60183 L .809 .541 .534 r
F
.32812 .60181 m .32796 .60456 L .32819 .60183 L F
.32971 .60234 m .33188 .60275 L .33129 .60175 L .675 .735 .895 r
F
.32898 .60243 m .32816 .60745 L .32886 .60797 L .908 .63 .503 r
F
.32901 .6012 m .32885 .60233 L .32898 .60243 L F
.32885 .60233 m .32816 .60745 L .32898 .60243 L F
.32914 .60255 m .33127 .60285 L .32971 .60234 L .675 .735 .895 r
F
.32967 .60257 m .32968 .60377 L .32961 .60299 L 0 0 .131 r
F
.32582 .60379 m .32987 .60309 L .32914 .60255 L .675 .735 .895 r
F
.3296 .60216 m .32924 .60262 L .32953 .60327 L .986 .729 .347 r
F
.32987 .60309 m .33127 .60285 L .32914 .60255 L .675 .735 .895 r
F
.33127 .60285 m .33188 .60275 L .32971 .60234 L F
.32591 .59187 m .32749 .59167 L .32744 .60469 L .641 .402 .541 r
F
.32582 .60379 m .32819 .60183 L .32774 .60168 L .675 .735 .895 r
F
.32795 .60047 m .32786 .60453 L .32819 .60056 L .809 .541 .534 r
F
.32587 .60663 m .32918 .6054 L .32854 .60491 L .675 .735 .895 r
F
.32786 .60453 m .32779 .60733 L .32796 .60456 L .809 .541 .534 r
F
.32786 .60453 m .32796 .60456 L .32819 .60056 L F
.32792 .60174 m .32711 .60147 L .32709 .60721 L F
.32855 .60084 m .32832 .60475 L .32901 .6012 L .908 .63 .503 r
F
.32832 .60475 m .32816 .60745 L .32851 .60489 L F
.32832 .60475 m .32851 .60489 L .32901 .6012 L F
.3271 .60383 m .32913 .60305 L .32763 .60262 L .675 .735 .895 r
F
.32693 .60422 m .32733 .60401 L .3271 .60383 L F
.32587 .60663 m .3287 .60481 L .3278 .60451 L F
.32792 .60174 m .32711 .6071 L .32779 .60733 L .809 .541 .534 r
F
.32817 .60464 m .32779 .60733 L .32816 .60745 L F
.32796 .60456 m .32779 .60733 L .32817 .60464 L F
.32697 .60708 m .32918 .60589 L .32768 .60547 L .675 .735 .895 r
F
.32592 .60947 m .328 .60719 L .32697 .60708 L F
.328 .60719 m .32918 .60589 L .32697 .60708 L F
.32582 .60379 m .32672 .60622 L .32768 .60602 L F
.32621 .6048 m .32631 .60909 L .32586 .60483 L .641 .402 .541 r
F
.32587 .60663 m .32793 .60437 L .32691 .60426 L .675 .735 .895 r
F
.32678 .60425 m .32672 .60705 L .32695 .60426 L .734 .478 .541 r
F
.32672 .60705 m .32656 .61417 L .32684 .60706 L F
.32672 .60705 m .32684 .60706 L .32695 .60426 L F
.32779 .60733 m .32709 .60721 L .32779 .60746 L .809 .541 .534 r
F
.32711 .6071 m .32709 .60721 L .32779 .60733 L F
.32582 .60379 m .32573 .60636 L .32672 .60622 L .675 .735 .895 r
F
.32717 .58694 m .32609 .58681 L .32604 .60001 L .734 .478 .541 r
F
.325 .5869 m .32385 .60034 L .3247 .60012 L .568 .344 .535 r
F
.3239 .58724 m .32279 .58802 L .32274 .60105 L .4 .212 .507 r
F
.3248 .61167 m .32451 .61161 L .3243 .60453 L .751 .492 .54 r
F
.32635 .60923 m .32371 .61146 L .32409 .61153 L .654 .726 .902 r
F
.32276 .61698 m .31757 .62818 L .32285 .6183 L F
.32063 .62147 m .32062 .62084 L .32164 .62097 L .731 .478 .546 r
F
.3224 .61747 m .32063 .62147 L .32548 .62192 L .675 .735 .895 r
F
.32543 .62004 m .3228 .62492 L .32576 .62034 L .654 .726 .902 r
F
.3228 .62492 m .31711 .63544 L .32283 .62545 L F
.3228 .62492 m .32283 .62545 L .32576 .62034 L F
.32299 .61135 m .32139 .61238 L .32345 .61218 L .675 .735 .895 r
F
.3222 .60931 m .32224 .60982 L .32221 .61686 L .794 .634 .076 r
F
.32561 .61928 m .32278 .62467 L .32579 .61937 L .654 .726 .902 r
F
.32278 .62467 m .31711 .63544 L .3228 .62492 L F
.32278 .62467 m .3228 .62492 L .32579 .61937 L F
.32486 .61872 m .32269 .62342 L .32581 .61891 L F
.32269 .62342 m .31711 .63544 L .32278 .62467 L F
.32412 .61149 m .32395 .61167 L .32508 .61196 L F
.31733 .61978 m .3161 .61736 L .32058 .61863 L .794 .53 .538 r
F
.3163 .61945 m .31009 .62578 L .31679 .61961 L .654 .726 .902 r
F
.31615 .6202 m .31613 .6194 L .31733 .61978 L .794 .53 .538 r
F
.31613 .6194 m .3161 .61736 L .31733 .61978 L F
.32395 .61167 m .3163 .61945 L .32469 .61233 L .654 .726 .902 r
F
.3163 .61945 m .31679 .61961 L .32469 .61233 L F
.32395 .61167 m .32469 .61233 L .32508 .61196 L F
.32266 .61305 m .3224 .61747 L .32416 .61347 L .675 .735 .895 r
F
.32285 .61069 m .32326 .61812 L .3229 .6178 L .927 .648 .492 r
F
.32281 .60522 m .323 .61083 L .32285 .61069 L F
.323 .61083 m .32326 .61812 L .32285 .61069 L F
.32462 .61243 m .32266 .61305 L .32416 .61347 L .675 .735 .895 r
F
.32592 .60947 m .32384 .61176 L .32462 .61243 L F
.32384 .61176 m .32266 .61305 L .32462 .61243 L F
.31227 .61536 m .31222 .61252 L .31604 .61452 L .86 .586 .522 r
F
.31561 .6126 m .30236 .62101 L .30372 .62225 L .654 .726 .902 r
F
.30942 .61561 m .31038 .61552 L .31232 .6182 L .932 .65 .485 r
F
.31038 .61552 m .31227 .61536 L .31231 .61728 L F
.31233 .6173 m .31115 .61622 L .30372 .62225 L .654 .726 .902 r
F
.31038 .61552 m .31231 .61728 L .31232 .6182 L .932 .65 .485 r
F
.3168 .60958 m .31609 .61447 L .31933 .61091 L .675 .735 .895 r
F
.32134 .60954 m .31935 .61378 L .32261 .61021 L F
.32134 .60954 m .3168 .61245 L .31935 .61378 L F
.32635 .60923 m .31561 .6126 L .31115 .61622 L .654 .726 .902 r
F
.32635 .60923 m .31115 .61622 L .31233 .6173 L F
.31038 .61552 m .30937 .61277 L .31227 .61536 L .932 .65 .485 r
F
.30933 .61457 m .2989 .61784 L .31063 .61576 L .654 .726 .902 r
F
.30942 .61561 m .30941 .61463 L .31038 .61552 L .932 .65 .485 r
F
.30941 .61463 m .30937 .61277 L .31038 .61552 L F
.31063 .61576 m .2989 .61784 L .30236 .62101 L .654 .726 .902 r
F
.30937 .61277 m .31222 .61252 L .31227 .61536 L .932 .65 .485 r
F
.31487 .61072 m .30937 .61277 L .31227 .61536 L .675 .735 .895 r
F
.31561 .6126 m .30933 .61457 L .31063 .61576 L .654 .726 .902 r
F
.32269 .62342 m .32278 .62467 L .32528 .61991 L F
.32362 .61125 m .32371 .61834 L .32344 .61116 L .844 .572 .526 r
F
.32236 .61176 m .32042 .61152 L .32139 .61238 L .675 .735 .895 r
F
.32285 .61069 m .32285 .6109 L .32272 .61059 L .927 .648 .492 r
F
.32285 .6109 m .32273 .61079 L .32272 .61059 L F
.32592 .60947 m .3223 .61082 L .32236 .61176 L .675 .735 .895 r
F
.3223 .61082 m .32042 .61152 L .32236 .61176 L F
.31593 .60537 m .29949 .61053 L .3029 .61365 L .654 .726 .902 r
F
.31593 .60537 m .3029 .61365 L .30429 .61492 L F
.30845 .61135 m .29505 .60759 L .29594 .61284 L F
.32262 .60126 m .32221 .60201 L .32221 .6036 L 0 0 .373 r
F
.32274 .60258 m .32151 .60084 L .32049 .60169 L .675 .735 .895 r
F
.32582 .60379 m .32339 .60212 L .32274 .60258 L F
.32223 .60218 m .32226 .6044 L .32223 .60392 L .794 .634 .076 r
F
.32262 .60126 m .32221 .6036 L .32252 .60299 L 0 0 .373 r
F
.32279 .58802 m .32221 .60201 L .32262 .60126 L F
.30599 .60087 m .2969 .59522 L .29566 .60033 L .654 .726 .902 r
F
.3268 .60196 m .31941 .60029 L .30599 .60087 L F
.31941 .60029 m .2969 .59522 L .30599 .60087 L F
.32609 .58681 m .325 .5869 L .32495 .60006 L .66 .417 .541 r
F
.32359 .6086 m .32362 .61125 L .3235 .60856 L .844 .572 .526 r
F
.32635 .60923 m .32132 .60896 L .31966 .61002 L .654 .726 .902 r
F
.32486 .61872 m .32424 .6186 L .32479 .61887 L F
.32508 .61196 m .32401 .61295 L .32434 .61355 L F
.32416 .61347 m .32563 .61777 L .32578 .61362 L .675 .735 .895 r
F
.32451 .61161 m .32473 .6187 L .32427 .61157 L .751 .492 .54 r
F
.32473 .6187 m .32569 .65043 L .32453 .61866 L F
.32276 .61698 m .32285 .6183 L .32488 .6145 L .654 .726 .902 r
F
.32416 .61347 m .3224 .61747 L .32563 .61777 L .675 .735 .895 r
F
.32473 .6187 m .32453 .61866 L .32427 .61157 L .751 .492 .54 r
F
.31605 .62029 m .31261 .62659 L .31757 .62818 L .654 .726 .902 r
F
.31605 .62029 m .31009 .62578 L .31261 .62659 L F
.32274 .61831 m .32012 .61982 L .32389 .61854 L F
.32012 .61982 m .30327 .62952 L .31956 .62084 L F
.3194 .61663 m .32063 .62147 L .3224 .61747 L .675 .735 .895 r
F
.32012 .61982 m .31956 .62084 L .32389 .61854 L .654 .726 .902 r
F
.32399 .60878 m .32428 .60891 L .32427 .61157 L .844 .572 .526 r
F
.3228 .60359 m .3233 .60565 L .32281 .60522 L .927 .648 .492 r
F
.32202 .60309 m .32049 .60169 L .31983 .60268 L .675 .735 .895 r
F
.32582 .60379 m .32274 .60258 L .32202 .60309 L F
.32274 .60258 m .32049 .60169 L .32202 .60309 L F
.3236 .6005 m .32274 .60105 L .32273 .60259 L .4 .212 .507 r
F
.32582 .60379 m .32243 .60316 L .32212 .60377 L .675 .735 .895 r
F
.32341 .60211 m .32273 .60259 L .32272 .6054 L .4 .212 .507 r
F
.32341 .60211 m .32272 .6054 L .32305 .60516 L F
.32261 .60561 m .32267 .60549 L .32274 .60105 L 0 0 .373 r
F
.3226 .60284 m .32256 .6057 L .32269 .60266 L F
.32256 .6057 m .32253 .60841 L .32261 .60561 L F
.32582 .60379 m .32226 .60439 L .32231 .60509 L .675 .735 .895 r
F
.32256 .6057 m .32261 .60561 L .32269 .60266 L 0 0 .373 r
F
.32262 .60126 m .32219 .60904 L .32253 .60841 L F
.32307 .60471 m .32286 .60301 L .32154 .60367 L .675 .735 .895 r
F
.3235 .60485 m .32271 .60808 L .32344 .60762 L .4 .212 .507 r
F
.3236 .6005 m .32305 .60516 L .3235 .60485 L F
.32587 .60663 m .32273 .60539 L .32241 .60599 L .675 .735 .895 r
F
.32344 .60762 m .32365 .60749 L .32373 .60469 L .4 .212 .507 r
F
.3236 .60478 m .32373 .60469 L .32385 .60034 L F
.32582 .60379 m .32308 .60555 L .32388 .60592 L .675 .735 .895 r
F
.32587 .60663 m .32338 .60493 L .32273 .60539 L F
.32344 .60762 m .32373 .60469 L .3236 .60478 L .4 .212 .507 r
F
.32305 .60516 m .32271 .60808 L .3235 .60485 L F
.32223 .60218 m .32221 .60665 L .32221 .60201 L .794 .634 .076 r
F
.32221 .60665 m .3222 .60931 L .32221 .60658 L F
.32221 .60665 m .32221 .60658 L .32221 .60201 L F
.32235 .60293 m .32237 .61005 L .32227 .60278 L .989 .721 .393 r
F
.32252 .60299 m .32221 .6036 L .3222 .60641 L 0 0 .373 r
F
.32265 .60346 m .32272 .61059 L .32262 .6105 L .927 .648 .492 r
F
.32272 .6054 m .32263 .60823 L .32271 .60808 L 0 0 .373 r
F
.32274 .60105 m .32267 .60549 L .32272 .6054 L F
.32267 .60549 m .32263 .60823 L .32272 .6054 L F
.32338 .60493 m .32307 .60471 L .32273 .60539 L .675 .735 .895 r
F
.32307 .60471 m .32203 .604 L .32272 .60539 L F
.32307 .60471 m .32272 .60539 L .32273 .60539 L F
.32203 .604 m .32154 .60367 L .32206 .60442 L F
.32227 .60278 m .3223 .60992 L .32224 .60982 L .989 .721 .393 r
F
.32203 .604 m .32206 .60442 L .32273 .60539 L .675 .735 .895 r
F
.3222 .60931 m .32219 .60916 L .32221 .60201 L .794 .634 .076 r
F
.32235 .60611 m .3222 .60641 L .32219 .60904 L 0 0 .373 r
F
.32252 .60299 m .3222 .60641 L .32235 .60611 L F
.32272 .60539 m .32154 .60367 L .32052 .60452 L .675 .735 .895 r
F
.32338 .60493 m .32324 .60439 L .32307 .60471 L F
.32324 .60439 m .32286 .60301 L .32307 .60471 L F
.32483 .609 m .32428 .60891 L .32476 .60914 L F
.32464 .6046 m .3248 .61167 L .3243 .60453 L .751 .492 .54 r
F
.32279 .58802 m .32262 .60126 L .32274 .60105 L 0 0 .373 r
F
.3239 .58724 m .32274 .60105 L .3236 .6005 L .4 .212 .507 r
F
.32259 .60016 m .30527 .58668 L .30018 .59056 L .654 .726 .902 r
F
.3268 .60196 m .32416 .60009 L .32259 .60016 L F
.32416 .60009 m .30527 .58668 L .32259 .60016 L F
.32131 .60668 m .3168 .60958 L .31933 .61091 L .675 .735 .895 r
F
.32037 .60867 m .3168 .61245 L .32134 .60954 L F
.32635 .60923 m .31966 .61002 L .31561 .6126 L .654 .726 .902 r
F
.32586 .60634 m .32599 .60913 L .32584 .60915 L .641 .402 .541 r
F
.32591 .60633 m .32599 .60913 L .32586 .60634 L F
.32579 .61937 m .32543 .62004 L .32576 .62034 L .654 .726 .902 r
F
.32581 .61891 m .32561 .61928 L .32579 .61937 L F
.32518 .61982 m .32528 .61991 L .32581 .61891 L F
.32496 .61874 m .32581 .61891 L .32569 .65043 L .751 .492 .54 r
F
.32237 .61005 m .32239 .61717 L .3223 .60992 L .989 .721 .393 r
F
.3194 .61663 m .31615 .6202 L .32063 .62147 L .675 .735 .895 r
F
.32296 .61818 m .31528 .61983 L .30327 .62952 L .654 .726 .902 r
F
.32237 .61005 m .32262 .6105 L .32262 .6107 L .989 .721 .393 r
F
.32262 .6107 m .31983 .61051 L .32042 .61152 L .675 .735 .895 r
F
.32237 .61005 m .32262 .6107 L .32238 .61026 L .989 .721 .393 r
F
.32592 .60947 m .32228 .61009 L .32262 .6107 L .675 .735 .895 r
F
.32228 .61009 m .31983 .61051 L .32262 .6107 L F
.32344 .60762 m .32328 .61474 L .32365 .60749 L .4 .212 .507 r
F
.32244 .62001 m .3225 .62084 L .32479 .61887 L .654 .726 .902 r
F
.31698 .62558 m .3163 .62682 L .32385 .61976 L F
.32382 .61971 m .32385 .61976 L .32479 .61887 L F
.31698 .62558 m .32385 .61976 L .32382 .61971 L F
.3223 .60992 m .32233 .61707 L .32224 .60982 L .989 .721 .393 r
F
.32233 .61707 m .32247 .64911 L .32228 .61698 L F
.32266 .61305 m .3194 .61663 L .3224 .61747 L .675 .735 .895 r
F
.32233 .61707 m .32228 .61698 L .32224 .60982 L .989 .721 .393 r
F
.3229 .6178 m .32326 .61812 L .32313 .6497 L .927 .648 .492 r
F
.32468 .60616 m .32584 .60915 L .32474 .60898 L .751 .492 .54 r
F
.32464 .6046 m .32507 .60622 L .32468 .60616 L F
.32507 .60622 m .32584 .60915 L .32468 .60616 L F
.32582 .60379 m .32388 .60592 L .32429 .6061 L .675 .735 .895 r
F
.32477 .60618 m .32429 .6061 L .32471 .6063 L F
.32582 .60379 m .32429 .6061 L .32477 .60618 L F
.32587 .60663 m .32393 .60876 L .32428 .60891 L F
.32592 .60947 m .31965 .60944 L .31983 .61051 L F
.32454 .60719 m .32438 .61426 L .32475 .60714 L .568 .344 .535 r
F
.31685 .61529 m .31615 .6202 L .3194 .61663 L .675 .735 .895 r
F
.31685 .61529 m .31232 .6182 L .31615 .6202 L F
.31928 .61728 m .31746 .61605 L .30714 .61872 L .654 .726 .902 r
F
.32589 .6165 m .32093 .61624 L .31928 .61728 L F
.32139 .61238 m .31685 .61529 L .3194 .61663 L .675 .735 .895 r
F
.32093 .61624 m .31746 .61605 L .31928 .61728 L .654 .726 .902 r
F
.32396 .61847 m .32244 .62001 L .32479 .61887 L F
.32326 .61812 m .32412 .65017 L .32313 .6497 L .844 .572 .526 r
F
.32328 .61108 m .32344 .61821 L .32326 .61812 L F
.32344 .61821 m .32412 .65017 L .32326 .61812 L F
.32227 .61763 m .31928 .61728 L .31528 .61983 L .654 .726 .902 r
F
.32589 .6165 m .32111 .61706 L .32227 .61763 L F
.32111 .61706 m .31928 .61728 L .32227 .61763 L F
.32344 .61116 m .32356 .61827 L .32328 .61108 L .844 .572 .526 r
F
.32356 .61827 m .32412 .65017 L .32344 .61821 L F
.32356 .61827 m .32344 .61821 L .32328 .61108 L F
.30937 .61277 m .30932 .60992 L .31222 .61252 L .932 .65 .485 r
F
.3168 .60958 m .31229 .61248 L .31609 .61447 L .675 .735 .895 r
F
.31487 .61072 m .31227 .61536 L .3168 .61245 L F
.30765 .61259 m .3076 .60975 L .30937 .61277 L .987 .713 .389 r
F
.32015 .60579 m .31593 .60537 L .30429 .61492 L .654 .726 .902 r
F
.31488 .60786 m .30941 .60989 L .31229 .61248 L .675 .735 .895 r
F
.31369 .60871 m .30937 .61277 L .31487 .61072 L F
.31561 .6126 m .30845 .61135 L .30775 .61183 L .654 .726 .902 r
F
.30936 .61456 m .30775 .61183 L .2989 .61784 L F
.30824 .61265 m .30937 .61277 L .30941 .61463 L .987 .713 .389 r
F
.31561 .6126 m .30775 .61183 L .30936 .61456 L .654 .726 .902 r
F
.30765 .61259 m .30824 .61265 L .30942 .61561 L .987 .713 .389 r
F
.30824 .61265 m .30941 .61463 L .30942 .61561 L F
.30845 .61135 m .29594 .61284 L .29683 .61436 L .654 .726 .902 r
F
.30845 .61135 m .29683 .61436 L .2989 .61784 L F
.31492 .61356 m .31232 .6182 L .31685 .61529 L .675 .735 .895 r
F
.31924 .61615 m .29584 .60972 L .29459 .61486 L .654 .726 .902 r
F
.32591 .59187 m .32621 .6048 L .32586 .60483 L .641 .402 .541 r
F
.32587 .60663 m .32596 .60417 L .325 .60426 L .675 .735 .895 r
F
.32496 .61874 m .32473 .6187 L .32451 .61161 L .751 .492 .54 r
F
.32587 .60663 m .32224 .60798 L .32313 .60839 L .675 .735 .895 r
F
.32365 .60749 m .32345 .61464 L .32382 .60738 L .4 .212 .507 r
F
.32582 .60379 m .32496 .60146 L .3241 .60172 L .675 .735 .895 r
F
.3268 .60196 m .31183 .58384 L .30527 .58668 L .654 .726 .902 r
F
.32579 .60002 m .32495 .60006 L .32494 .60146 L .66 .417 .541 r
F
.32587 .60663 m .32428 .60891 L .32483 .609 L .675 .735 .895 r
F
.32357 .602 m .32344 .60762 L .32376 .60186 L .4 .212 .507 r
F
.32398 .60436 m .32439 .60261 L .32286 .60301 L .675 .735 .895 r
F
.32587 .60663 m .32412 .60452 L .32338 .60493 L F
.32409 .61153 m .32371 .61146 L .32395 .61167 L .654 .726 .902 r
F
.3246 .60437 m .32383 .60461 L .32382 .60738 L .568 .344 .535 r
F
.3246 .60437 m .32382 .60738 L .32383 .60737 L F
.3246 .60437 m .32382 .60742 L .32437 .60725 L F
.32412 .60452 m .32383 .60461 L .32338 .60493 L .675 .735 .895 r
F
.32406 .60445 m .32286 .60301 L .32338 .60493 L F
.32262 .60126 m .3226 .60284 L .32274 .60105 L 0 0 .373 r
F
.32243 .60316 m .31983 .60268 L .32212 .60377 L .675 .735 .895 r
F
.3268 .60196 m .30018 .59056 L .2969 .59522 L .654 .726 .902 r
F
.32283 .60019 m .31721 .59789 L .32151 .60084 L .675 .735 .895 r
F
.32283 .60019 m .31983 .59659 L .31721 .59789 L F
.32151 .60084 m .31516 .59959 L .32049 .60169 L F
.32286 .60301 m .31986 .5994 L .31721 .6007 L F
.32441 .60162 m .32384 .6018 L .32383 .60461 L .568 .344 .535 r
F
.3226 .60284 m .32269 .60266 L .32274 .60105 L 0 0 .373 r
F
.32339 .60212 m .32151 .60084 L .32274 .60258 L .675 .735 .895 r
F
.32439 .60261 m .31986 .5994 L .32286 .60301 L F
.31983 .59659 m .3129 .59494 L .31721 .59789 L F
.31983 .59659 m .31684 .59299 L .3129 .59494 L F
.32287 .59578 m .31684 .59299 L .31983 .59659 L F
.3247 .60012 m .32383 .60461 L .3246 .60437 L .568 .344 .535 r
F
.32412 .60452 m .32406 .60445 L .32383 .60461 L .675 .735 .895 r
F
.32444 .60545 m .32296 .60143 L .32109 .60192 L F
.31721 .59789 m .3129 .59494 L .30984 .59749 L F
.31685 .59578 m .31283 .5949 L .31288 .59774 L .497 .293 .534 r
F
.31685 .59578 m .3168 .59294 L .31283 .5949 L F
.32366 .60572 m .3134 .59057 L .3113 .59102 L .654 .726 .902 r
F
.32286 .60301 m .31721 .6007 L .32154 .60367 L .675 .735 .895 r
F
.3226 .60414 m .32109 .60192 L .31991 .60224 L F
.32444 .60545 m .32109 .60192 L .3226 .60414 L F
.32378 .60612 m .32366 .60572 L .3113 .59102 L .654 .726 .902 r
F
.32291 .59858 m .31685 .59578 L .31986 .5994 L .675 .735 .895 r
F
.32435 .59978 m .32287 .59578 L .31983 .59659 L F
.32291 .59858 m .32143 .59456 L .31685 .59578 L F
.32143 .59456 m .3168 .59294 L .31685 .59578 L .592 .367 .544 r
F
.3239 .58724 m .3236 .6005 L .32385 .60034 L .4 .212 .507 r
F
.3268 .60196 m .31942 .58223 L .31183 .58384 L .654 .726 .902 r
F
.32287 .59578 m .3214 .59178 L .31684 .59299 L .675 .735 .895 r
F
.32143 .59456 m .32137 .59172 L .3168 .59294 L .592 .367 .544 r
F
.3236 .6005 m .32273 .60259 L .32341 .60211 L .4 .212 .507 r
F
.3236 .6005 m .32357 .602 L .32385 .60034 L F
.32357 .602 m .32376 .60186 L .32385 .60034 L F
.32321 .602 m .32283 .60019 L .32151 .60084 L .675 .735 .895 r
F
.32582 .60379 m .3241 .60172 L .32321 .602 L F
.3241 .60172 m .32283 .60019 L .32321 .602 L F
.3247 .60434 m .32483 .6043 L .32491 .60147 L .568 .344 .535 r
F
.32487 .60148 m .32491 .60147 L .32495 .60006 L F
.3247 .60434 m .32491 .60147 L .32487 .60148 L F
.32435 .59978 m .31983 .59659 L .32283 .60019 L .675 .735 .895 r
F
.32439 .60261 m .32291 .59858 L .31986 .5994 L F
.32296 .60143 m .32148 .5974 L .31855 .59818 L F
.32151 .60084 m .31721 .59789 L .31516 .59959 L F
.31986 .5994 m .31685 .59578 L .31288 .59774 L F
.31975 .59994 m .31855 .59818 L .3169 .59862 L F
.32296 .60143 m .31855 .59818 L .31975 .59994 L F
.32385 .60034 m .32365 .60749 L .32382 .60738 L .4 .212 .507 r
F
.32411 .60551 m .31893 .5894 L .32366 .60572 L .654 .726 .902 r
F
.32385 .60599 m .32366 .60572 L .32378 .60612 L F
.32305 .60516 m .32272 .6054 L .32271 .60808 L .4 .212 .507 r
F
.32253 .60841 m .32267 .60549 L .32261 .60561 L 0 0 .373 r
F
.32241 .60599 m .32211 .60515 L .32216 .60594 L .675 .735 .895 r
F
.32272 .60539 m .32211 .60515 L .32241 .60599 L F
.32211 .60515 m .32052 .60452 L .32216 .60594 L F
.32212 .60377 m .31983 .60268 L .31958 .60375 L F
.32049 .60169 m .31385 .60158 L .31983 .60268 L F
.32049 .60169 m .31516 .59959 L .31385 .60158 L F
.31983 .60268 m .31335 .60372 L .31958 .60375 L F
.32154 .60367 m .31516 .60241 L .32052 .60452 L F
.31721 .59789 m .30984 .59749 L .31516 .59959 L F
.32154 .60367 m .31721 .6007 L .31516 .60241 L F
.31288 .59774 m .31283 .5949 L .30975 .59746 L .356 .186 .508 r
F
.31516 .59959 m .30984 .59749 L .30786 .60048 L .675 .735 .895 r
F
.31721 .6007 m .31288 .59774 L .30981 .60031 L F
.31986 .5994 m .31288 .59774 L .31721 .6007 L F
.32576 .60881 m .31728 .59837 L .3134 .60004 L .654 .726 .902 r
F
.3169 .59862 m .31676 .59859 L .31293 .60058 L .497 .293 .534 r
F
.31676 .59859 m .31288 .59774 L .31293 .60025 L F
.31516 .59959 m .30786 .60048 L .31385 .60158 L .675 .735 .895 r
F
.31676 .59859 m .31293 .60025 L .31293 .60058 L .497 .293 .534 r
F
.3134 .60004 m .3113 .59102 L .30471 .59387 L .654 .726 .902 r
F
.3169 .59862 m .31685 .59578 L .31288 .59774 L .497 .293 .534 r
F
.31728 .59837 m .3113 .59102 L .3134 .60004 L .654 .726 .902 r
F
.32464 .60717 m .32475 .60713 L .32483 .6043 L .568 .344 .535 r
F
.31958 .60375 m .31335 .60372 L .3137 .60586 L .675 .735 .895 r
F
.31385 .60158 m .30786 .60048 L .30712 .60368 L F
.30981 .60031 m .30777 .60046 L .30782 .6033 L .112 .004 .44 r
F
.30981 .60031 m .30975 .59746 L .30777 .60046 L F
.31516 .60241 m .30981 .60031 L .30782 .6033 L .675 .735 .895 r
F
.31983 .60268 m .31385 .60158 L .31335 .60372 L F
.31385 .60158 m .30712 .60368 L .31335 .60372 L F
.31516 .60241 m .30782 .6033 L .31384 .60441 L F
.31878 .60599 m .31249 .60058 L .3102 .60232 L .654 .726 .902 r
F
.31293 .60058 m .31253 .60055 L .30986 .60315 L .356 .186 .508 r
F
.31253 .60055 m .30981 .60031 L .30985 .60259 L F
.31253 .60055 m .30985 .60259 L .30986 .60315 L F
.3102 .60232 m .30471 .59387 L .29959 .59777 L .654 .726 .902 r
F
.31249 .60058 m .30471 .59387 L .3102 .60232 L F
.32115 .6066 m .3196 .60659 L .32195 .6073 L .675 .735 .895 r
F
.32635 .60923 m .32256 .60654 L .31878 .60599 L .654 .726 .902 r
F
.31958 .60375 m .3137 .60586 L .31976 .60482 L .675 .735 .895 r
F
.32052 .60452 m .31384 .60441 L .31985 .60552 L F
.32052 .60452 m .31516 .60241 L .31384 .60441 L F
.31721 .6007 m .30981 .60031 L .31516 .60241 L F
.31288 .59774 m .30975 .59746 L .30981 .60031 L .356 .186 .508 r
F
.31253 .60055 m .31288 .59774 L .30981 .60031 L F
.3133 .59997 m .31249 .60058 L .31878 .60599 L .654 .726 .902 r
F
.31293 .60058 m .31293 .60025 L .31253 .60055 L .356 .186 .508 r
F
.31293 .60025 m .31288 .59774 L .31253 .60055 L F
.32256 .60654 m .3133 .59997 L .31878 .60599 L .654 .726 .902 r
F
.3133 .59997 m .30471 .59387 L .31249 .60058 L F
.32631 .60909 m .32617 .60911 L .32586 .60483 L .641 .402 .541 r
F
.32587 .60663 m .32578 .60916 L .32675 .60903 L .675 .735 .895 r
F
.32592 .60947 m .32697 .60708 L .32601 .60698 L F
.32672 .60705 m .32601 .60698 L .32601 .60705 L .734 .478 .541 r
F
.32592 .60947 m .32746 .61132 L .32645 .60983 L .675 .735 .895 r
F
.32638 .61189 m .32654 .61884 L .3262 .61191 L .641 .402 .541 r
F
.32654 .61884 m .3263 .61886 L .32586 .60483 L F
.32589 .6165 m .32581 .61891 L .32677 .61882 L .654 .726 .902 r
F
.32283 .60806 m .32285 .61069 L .32277 .60801 L .927 .648 .492 r
F
.32331 .60404 m .32344 .61116 L .32328 .61108 L .844 .572 .526 r
F
.3137 .60586 m .30941 .60989 L .31488 .60786 L .675 .735 .895 r
F
.3137 .60586 m .30764 .60689 L .30941 .60989 L F
.32035 .60582 m .31488 .60786 L .3168 .60958 L F
.30707 .60652 m .30755 .60691 L .3076 .60975 L .864 .664 .132 r
F
.30707 .60652 m .30702 .60368 L .30755 .60691 L F
.31334 .60656 m .3076 .60975 L .31369 .60871 L .675 .735 .895 r
F
.3076 .60975 m .30755 .60691 L .30932 .60992 L .987 .713 .389 r
F
.31334 .60656 m .30707 .60652 L .3076 .60975 L .675 .735 .895 r
F
.3196 .60659 m .31369 .60871 L .31978 .60767 L F
.31976 .60482 m .3137 .60586 L .31488 .60786 L F
.3196 .60659 m .31334 .60656 L .31369 .60871 L F
.30717 .60822 m .29629 .60245 L .29505 .60759 L .654 .726 .902 r
F
.32635 .60923 m .30794 .60508 L .30717 .60822 L F
.30765 .60625 m .30707 .60652 L .30711 .60848 L 0 0 .245 r
F
.31335 .60372 m .30712 .60368 L .30764 .60689 L .675 .735 .895 r
F
.31384 .60441 m .30782 .6033 L .30707 .60652 L F
.30787 .60614 m .30782 .6033 L .30707 .60652 L 0 0 .245 r
F
.30794 .60508 m .29629 .60245 L .30717 .60822 L .654 .726 .902 r
F
.30727 .60949 m .30707 .60652 L .3076 .60975 L .864 .664 .132 r
F
.30706 .60822 m .29505 .60759 L .30754 .6111 L .654 .726 .902 r
F
.30712 .60937 m .30711 .60848 L .30727 .60949 L .864 .664 .132 r
F
.30711 .60848 m .30707 .60652 L .30727 .60949 L F
.3076 .60975 m .30932 .60992 L .30937 .61277 L .987 .713 .389 r
F
.31369 .60871 m .3076 .60975 L .30937 .61277 L .675 .735 .895 r
F
.31488 .60786 m .31229 .61248 L .3168 .60958 L F
.31978 .60767 m .31369 .60871 L .31487 .61072 L F
.3183 .60881 m .30706 .60822 L .30845 .61135 L .654 .726 .902 r
F
.30712 .60937 m .3076 .60975 L .30765 .61259 L .864 .664 .132 r
F
.30706 .60822 m .30754 .6111 L .30845 .61135 L .654 .726 .902 r
F
.30787 .60614 m .30765 .60625 L .30712 .60937 L 0 0 .245 r
F
.30765 .60625 m .30711 .60848 L .30712 .60937 L F
.32285 .61069 m .32272 .61059 L .32265 .60346 L .927 .648 .492 r
F
.31976 .60482 m .31488 .60786 L .32035 .60582 L .675 .735 .895 r
F
.31335 .60372 m .30764 .60689 L .3137 .60586 L F
.30782 .6033 m .30702 .60368 L .30707 .60652 L 0 0 .245 r
F
.30782 .6033 m .30777 .60046 L .30702 .60368 L F
.31985 .60552 m .31334 .60656 L .3196 .60659 L .675 .735 .895 r
F
.31384 .60441 m .30707 .60652 L .31334 .60656 L F
.31985 .60552 m .31384 .60441 L .31334 .60656 L F
.30807 .6051 m .29959 .59777 L .29629 .60245 L .654 .726 .902 r
F
.32635 .60923 m .31008 .60226 L .30807 .6051 L F
.30943 .60318 m .30782 .6033 L .30786 .6054 L .112 .004 .44 r
F
.30986 .60315 m .30981 .60031 L .30782 .6033 L F
.31008 .60226 m .29959 .59777 L .30807 .6051 L .654 .726 .902 r
F
.30986 .60315 m .30943 .60318 L .30787 .60614 L .112 .004 .44 r
F
.30943 .60318 m .30786 .6054 L .30787 .60614 L F
.32876 .60765 m .32899 .60772 L .32891 .60755 L .675 .735 .895 r
F
.32592 .60947 m .32899 .60772 L .32876 .60765 L F
.33205 .60382 m .33794 .60171 L .33188 .60275 L F
.33188 .60275 m .33794 .60171 L .33676 .59971 L F
.33196 .60559 m .33687 .60253 L .33137 .60458 L F
.33137 .60458 m .33687 .60253 L .33494 .6008 L F
.33676 .59971 m .34224 .59768 L .33936 .59509 L F
.33687 .60253 m .33948 .59789 L .33494 .6008 L F
.34237 .60049 m .34232 .59765 L .33942 .59505 L .932 .65 .484 r
F
.33046 .60656 m .33244 .60231 L .32918 .60589 L .675 .735 .895 r
F
.33137 .60458 m .33494 .6008 L .3304 .60372 L F
.33046 .60656 m .33499 .60365 L .33244 .60231 L F
.34237 .60049 m .33942 .59505 L .33948 .59789 L .932 .65 .484 r
F
.33188 .60275 m .33676 .59971 L .33129 .60175 L .675 .735 .895 r
F
.33499 .60365 m .3357 .59873 L .33244 .60231 L F
.33499 .60365 m .33953 .60073 L .3357 .59873 L F
.34242 .60333 m .33948 .59789 L .33953 .60073 L .932 .65 .484 r
F
.33676 .59971 m .33936 .59509 L .33484 .59799 L .675 .735 .895 r
F
.33494 .6008 m .33948 .59789 L .33565 .59589 L F
.33953 .60073 m .33948 .59789 L .33565 .59589 L .86 .586 .522 r
F
.33953 .60073 m .33565 .59589 L .3357 .59873 L F
.32635 .60923 m .34899 .59619 L .34262 .59265 L .654 .726 .902 r
F
.32764 .61446 m .32794 .61457 L .32816 .60745 L .809 .541 .534 r
F
.32867 .61117 m .32873 .61815 L .3286 .61123 L .356 .178 .497 r
F
.32886 .60797 m .32814 .61464 L .3287 .61508 L .908 .63 .503 r
F
.32816 .60745 m .32794 .61457 L .32814 .61464 L .809 .541 .534 r
F
.32635 .60923 m .33015 .61008 L .33077 .60962 L .654 .726 .902 r
F
.32906 .60829 m .32887 .6152 L .32922 .60842 L .908 .63 .503 r
F
.33055 .60945 m .33077 .60962 L .33098 .60947 L .654 .726 .902 r
F
.32635 .60923 m .33077 .60962 L .33055 .60945 L F
.32952 .60908 m .32922 .60842 L .32919 .61546 L .986 .729 .347 r
F
.33129 .60175 m .33676 .59971 L .33484 .59799 L .675 .735 .895 r
F
.32863 .60091 m .34933 .58898 L .32818 .60056 L .654 .726 .902 r
F
.33494 .6008 m .33565 .59589 L .33239 .59947 L .675 .735 .895 r
F
.32695 .61423 m .34217 .59993 L .33469 .59752 L .654 .726 .902 r
F
.32589 .6165 m .32798 .61438 L .32695 .61423 L F
.32798 .61438 m .34217 .59993 L .32695 .61423 L F
.32672 .60715 m .32601 .60705 L .32598 .61409 L .734 .478 .541 r
F
.33342 .61779 m .33254 .61583 L .32887 .61102 L .654 .726 .902 r
F
.32589 .6165 m .35632 .61288 L .35337 .60788 L F
.32656 .61417 m .32598 .61409 L .32586 .64538 L .734 .478 .541 r
F
.32672 .60715 m .32598 .61409 L .32656 .61417 L F
.32672 .60705 m .32601 .60705 L .32672 .60715 L F
.32592 .60947 m .32558 .60855 L .32414 .60732 L .675 .735 .895 r
F
.32587 .60663 m .325 .60426 L .32493 .60427 L F
.32587 .60663 m .32493 .60427 L .32412 .60452 L F
.32552 .60421 m .32493 .60427 L .32492 .60708 L .66 .417 .541 r
F
.32558 .60855 m .32504 .60707 L .32464 .60717 L .675 .735 .895 r
F
.32037 .60867 m .31487 .61072 L .3168 .61245 L F
.32132 .60896 m .3183 .60881 L .31966 .61002 L .654 .726 .902 r
F
.3222 .60931 m .3222 .6095 L .32219 .60916 L .794 .634 .076 r
F
.3222 .6095 m .32219 .60935 L .32219 .60916 L F
.32592 .60947 m .31991 .60836 L .31965 .60944 L .675 .735 .895 r
F
.32534 .60704 m .32492 .60708 L .32489 .61413 L .66 .417 .541 r
F
.32552 .60421 m .32492 .60708 L .32534 .60704 L F
.32504 .60707 m .32503 .60704 L .32492 .60708 L .675 .735 .895 r
F
.32504 .60707 m .32492 .60708 L .32464 .60717 L F
.32504 .60707 m .32607 .60532 L .32444 .60545 L F
.32592 .60947 m .32601 .60698 L .32504 .60707 L F
.3257 .6042 m .32563 .60706 L .32587 .60418 L .66 .417 .541 r
F
.32592 .60947 m .3208 .60746 L .31991 .60836 L .675 .735 .895 r
F
.3208 .60746 m .32057 .60736 L .32049 .60748 L F
.3208 .60746 m .32049 .60748 L .31991 .60836 L F
.32583 .61196 m .32416 .61347 L .32578 .61362 L F
.3248 .61167 m .32583 .61187 L .32583 .61196 L .751 .492 .54 r
F
.3248 .61167 m .32583 .61196 L .32482 .61181 L F
.32592 .60947 m .32489 .61182 L .32583 .61196 L .675 .735 .895 r
F
.32489 .61182 m .32416 .61347 L .32583 .61196 L F
.32482 .61181 m .32583 .61196 L .32581 .61891 L .751 .492 .54 r
F
.32547 .61411 m .32564 .6141 L .32584 .60699 L .66 .417 .541 r
F
.32576 .607 m .32584 .60699 L .32604 .60001 L F
.32592 .60947 m .32159 .60651 L .32057 .60736 L .675 .735 .895 r
F
.32547 .61411 m .32584 .60699 L .32576 .607 L .66 .417 .541 r
F
.32563 .60706 m .32547 .61411 L .32575 .60706 L F
.32563 .60706 m .32575 .60706 L .32587 .60418 L F
.32635 .60923 m .32554 .60707 L .32464 .60716 L .654 .726 .902 r
F
.32601 .60698 m .32607 .60532 L .32504 .60707 L .675 .735 .895 r
F
.32554 .60707 m .32549 .60695 L .32492 .60709 L .654 .726 .902 r
F
.32554 .60707 m .32492 .60709 L .32464 .60716 L F
.32635 .60923 m .32464 .60716 L .32576 .60881 L F
.32563 .60701 m .32489 .61413 L .32547 .61411 L .66 .417 .541 r
F
.32579 .60002 m .32534 .60704 L .32563 .60701 L F
.32534 .60704 m .32489 .61413 L .32563 .60701 L F
.32464 .60716 m .3113 .59102 L .32576 .60881 L .654 .726 .902 r
F
.32558 .60855 m .32464 .60717 L .32414 .60732 L .675 .735 .895 r
F
.32414 .60732 m .32425 .60659 L .32291 .60586 L F
.32425 .60659 m .32444 .60545 L .32363 .60567 L F
.32464 .60716 m .32385 .60599 L .32378 .60612 L .654 .726 .902 r
F
.32425 .60659 m .32363 .60567 L .32291 .60586 L .675 .735 .895 r
F
.32464 .60716 m .32411 .60551 L .32385 .60599 L .654 .726 .902 r
F
.32454 .60719 m .32464 .60717 L .32483 .6043 L .568 .344 .535 r
F
.32592 .60947 m .32414 .60732 L .32321 .60762 L .675 .735 .895 r
F
.32635 .60923 m .32322 .61103 L .32371 .61146 L .654 .726 .902 r
F
.32592 .60947 m .32299 .61135 L .32345 .61218 L .675 .735 .895 r
F
.32362 .61125 m .32427 .61157 L .32424 .6186 L .844 .572 .526 r
F
.3246 .60437 m .32379 .61442 L .32438 .61426 L .568 .344 .535 r
F
.32503 .60704 m .32444 .60545 L .32414 .60732 L .675 .735 .895 r
F
.32464 .60716 m .32385 .60599 L .32464 .60716 L .654 .726 .902 r
F
.32411 .60551 m .32366 .60572 L .32385 .60599 L F
.32148 .5974 m .31685 .59578 L .3169 .59853 L .592 .367 .544 r
F
.31855 .59818 m .3169 .59853 L .3169 .59862 L F
.32148 .5974 m .3169 .59853 L .31855 .59818 L F
.31855 .59818 m .31893 .5894 L .3134 .59057 L .654 .726 .902 r
F
.32366 .60572 m .32131 .5976 L .31855 .59818 L F
.32148 .5974 m .32143 .59456 L .31685 .59578 L .592 .367 .544 r
F
.32131 .5976 m .31893 .5894 L .31855 .59818 L .654 .726 .902 r
F
.32464 .60717 m .32475 .60714 L .32475 .60713 L .568 .344 .535 r
F
.32454 .60719 m .32483 .6043 L .3247 .60434 L F
.32412 .60452 m .32493 .60427 L .32398 .60436 L .675 .735 .895 r
F
.32579 .60002 m .32494 .60146 L .3257 .60139 L .66 .417 .541 r
F
.32408 .60134 m .32384 .60136 L .32384 .6018 L .568 .344 .535 r
F
.3247 .60012 m .32384 .60136 L .32408 .60134 L F
.3247 .60012 m .32385 .60034 L .32384 .60136 L F
.3241 .60172 m .32435 .59978 L .32283 .60019 L .675 .735 .895 r
F
.3247 .60012 m .32384 .6018 L .32441 .60162 L .568 .344 .535 r
F
.32496 .60145 m .32435 .59978 L .3241 .60172 L .675 .735 .895 r
F
.32496 .60146 m .32596 .59965 L .32435 .59978 L F
.32582 .60379 m .3259 .60137 L .32496 .60146 L F
.32579 .60002 m .32576 .60138 L .32604 .60001 L .66 .417 .541 r
F
.32576 .60138 m .32593 .60137 L .32604 .60001 L F
.3259 .60137 m .32596 .59965 L .32496 .60146 L .675 .735 .895 r
F
.32576 .60138 m .3257 .6042 L .32593 .60137 L .66 .417 .541 r
F
.3257 .60139 m .32494 .60146 L .32493 .60427 L F
.3247 .60012 m .32454 .60719 L .32495 .60006 L .568 .344 .535 r
F
.32602 .60247 m .32291 .59858 L .32439 .60261 L .675 .735 .895 r
F
.32621 .60116 m .32148 .5974 L .32296 .60143 L F
.32549 .60695 m .31893 .5894 L .32464 .60716 L .654 .726 .902 r
F
.32383 .60737 m .32382 .60738 L .32382 .60742 L .568 .344 .535 r
F
.32437 .60725 m .32382 .60742 L .32379 .61442 L F
.32321 .60762 m .32291 .60586 L .32159 .60651 L .675 .735 .895 r
F
.32414 .60732 m .32291 .60586 L .32321 .60762 L F
.325 .60426 m .32439 .60261 L .32398 .60436 L F
.3257 .60139 m .32493 .60427 L .32552 .60421 L .66 .417 .541 r
F
.3248 .61167 m .32581 .61891 L .32496 .61874 L .751 .492 .54 r
F
.32589 .6165 m .32424 .6186 L .32486 .61872 L .654 .726 .902 r
F
.32496 .61874 m .32569 .65043 L .32473 .6187 L .751 .492 .54 r
F
.32239 .61717 m .32233 .61707 L .3223 .60992 L .989 .721 .393 r
F
.31966 .61002 m .30845 .61135 L .31561 .6126 L .654 .726 .902 r
F
.31978 .60767 m .31487 .61072 L .32037 .60867 L .675 .735 .895 r
F
.31966 .61002 m .3183 .60881 L .30845 .61135 L .654 .726 .902 r
F
.32042 .61152 m .31685 .61529 L .32139 .61238 L .675 .735 .895 r
F
.31983 .61051 m .31374 .61155 L .31492 .61356 L F
.31965 .60944 m .31339 .6094 L .31374 .61155 L F
.31389 .60725 m .30712 .60937 L .31339 .6094 L F
.31389 .60725 m .30787 .60614 L .30712 .60937 L F
.32207 .61486 m .30425 .60114 L .29913 .60504 L .654 .726 .902 r
F
.32237 .61005 m .32259 .61753 L .32239 .61717 L .989 .721 .393 r
F
.32362 .61125 m .32424 .6186 L .32371 .61834 L .844 .572 .526 r
F
.32589 .6165 m .32319 .61457 L .32207 .61486 L .654 .726 .902 r
F
.32218 .61644 m .32218 .61632 L .32219 .60916 L .794 .634 .076 r
F
.32224 .60982 m .32228 .61698 L .32221 .61686 L .989 .721 .393 r
F
.32218 .61632 m .32217 .61622 L .32219 .60904 L .794 .634 .076 r
F
.3222 .60931 m .32221 .61686 L .32218 .61644 L F
.32259 .61753 m .32313 .6497 L .32247 .64911 L .927 .648 .492 r
F
.32262 .6105 m .32272 .61764 L .32259 .61753 L F
.32272 .61764 m .32313 .6497 L .32259 .61753 L F
.3229 .6178 m .3228 .61771 L .32272 .61059 L F
.32589 .6165 m .32078 .61431 L .31904 .61438 L .654 .726 .902 r
F
.3199 .61514 m .31904 .61438 L .31693 .61447 L F
.32371 .61834 m .32356 .61827 L .32344 .61116 L .844 .572 .526 r
F
.32589 .6165 m .31904 .61438 L .3199 .61514 L .654 .726 .902 r
F
.32272 .61059 m .3228 .61771 L .32262 .6105 L .927 .648 .492 r
F
.3228 .61771 m .32313 .6497 L .32272 .61764 L F
.3228 .61771 m .32272 .61764 L .32262 .6105 L F
.32381 .61861 m .31956 .62084 L .31698 .62558 L .654 .726 .902 r
F
.32389 .61854 m .32379 .61859 L .32381 .61861 L F
.32379 .61859 m .31956 .62084 L .32381 .61861 L F
.32139 .61238 m .3194 .61663 L .32266 .61305 L .675 .735 .895 r
F
.31983 .61051 m .31492 .61356 L .32042 .61152 L F
.32319 .61457 m .30425 .60114 L .32207 .61486 L .654 .726 .902 r
F
.32475 .60714 m .32455 .61422 L .32492 .60709 L .568 .344 .535 r
F
.32269 .62342 m .32528 .61991 L .32518 .61982 L .654 .726 .902 r
F
.32479 .61887 m .32385 .61976 L .32414 .62028 L F
.32427 .61157 m .32569 .65043 L .32412 .65017 L .751 .492 .54 r
F
.32238 .61026 m .32262 .6107 L .32259 .61753 L .989 .721 .393 r
F
.32252 .61542 m .32259 .6153 L .32271 .60808 L 0 0 .373 r
F
.32271 .60808 m .32259 .6153 L .32268 .61512 L F
.32244 .61557 m .32252 .61542 L .32263 .60823 L F
.32253 .60841 m .32216 .61608 L .32244 .61557 L F
.32285 .6109 m .3229 .6178 L .32273 .61079 L .927 .648 .492 r
F
.32219 .60904 m .32217 .61622 L .32216 .61608 L .794 .634 .076 r
F
.323 .61083 m .32328 .61108 L .32326 .61812 L .927 .648 .492 r
F
.31965 .60944 m .31374 .61155 L .31983 .61051 L .675 .735 .895 r
F
.31991 .60836 m .31339 .6094 L .31965 .60944 L F
.31991 .60836 m .31389 .60725 L .31339 .6094 L F
.32057 .60736 m .31389 .60725 L .31991 .60836 L F
.32057 .60736 m .31521 .60526 L .31389 .60725 L F
.31521 .60526 m .30787 .60614 L .31389 .60725 L F
.31521 .60526 m .30986 .60315 L .30787 .60614 L F
.31726 .60355 m .30986 .60315 L .31521 .60526 L F
.31726 .60355 m .31293 .60058 L .30986 .60315 L F
.32589 .6165 m .31085 .59829 L .30425 .60114 L .654 .726 .902 r
F
.32455 .61422 m .32367 .6458 L .32469 .61418 L .568 .344 .535 r
F
.3248 .61167 m .32496 .61874 L .32451 .61161 L .751 .492 .54 r
F
.32455 .61422 m .32469 .61418 L .32492 .60709 L .568 .344 .535 r
F
.32547 .61411 m .32489 .61413 L .32477 .64546 L .66 .417 .541 r
F
.31693 .61447 m .29913 .60504 L .29584 .60972 L .654 .726 .902 r
F
.32042 .61152 m .31492 .61356 L .31685 .61529 L .675 .735 .895 r
F
.31339 .6094 m .30765 .61259 L .31374 .61155 L F
.31339 .6094 m .30712 .60937 L .30765 .61259 L F
.32078 .61431 m .29913 .60504 L .31693 .61447 L .654 .726 .902 r
F
.32345 .61464 m .32256 .64658 L .32359 .61455 L .4 .212 .507 r
F
.32345 .61464 m .32359 .61455 L .32382 .60738 L F
.32093 .61624 m .32048 .61527 L .31924 .61615 L .654 .726 .902 r
F
.32589 .6165 m .32193 .6156 L .32093 .61624 L F
.32193 .6156 m .32048 .61527 L .32093 .61624 L F
.32048 .61527 m .31693 .61447 L .31868 .61574 L F
.32048 .61527 m .31868 .61574 L .31924 .61615 L F
.32489 .61413 m .32367 .6458 L .32477 .64546 L .568 .344 .535 r
F
.32492 .60709 m .32469 .61418 L .32489 .61413 L F
.32589 .6165 m .32396 .61847 L .32424 .6186 L .654 .726 .902 r
F
.32469 .61418 m .32367 .6458 L .32489 .61413 L .568 .344 .535 r
F
.325 .60426 m .32602 .60247 L .32439 .60261 L .675 .735 .895 r
F
.32582 .60379 m .32685 .60144 L .3259 .60137 L F
.3268 .60196 m .32686 .60013 L .32607 .60002 L .654 .726 .902 r
F
.32684 .60144 m .32643 .60421 L .32678 .60425 L .734 .478 .541 r
F
.32587 .60663 m .32691 .60426 L .32596 .60416 L .675 .735 .895 r
F
.32633 .60139 m .32601 .60698 L .32684 .60144 L .734 .478 .541 r
F
.32685 .60144 m .32603 .60136 L .3259 .60137 L .675 .735 .895 r
F
.3293 .58814 m .32901 .6012 L .32925 .60138 L .908 .63 .503 r
F
.32975 .58918 m .32925 .60138 L .3296 .60216 L .986 .729 .347 r
F
.3268 .60196 m .34299 .58547 L .33555 .58308 L .654 .726 .902 r
F
.32795 .60047 m .32712 .60017 L .32711 .60147 L .809 .541 .534 r
F
.32685 .60144 m .32906 .60022 L .32757 .5998 L .675 .735 .895 r
F
.32582 .60379 m .32786 .60155 L .32685 .60144 L F
.32795 .60047 m .32711 .60147 L .32792 .60174 L .809 .541 .534 r
F
.32786 .60155 m .32906 .60022 L .32685 .60144 L .675 .735 .895 r
F
.32717 .58694 m .32687 .60013 L .32712 .60017 L .734 .478 .541 r
F
.32824 .58732 m .32795 .60047 L .32819 .60056 L .809 .541 .534 r
F
.32824 .58732 m .32712 .60017 L .32795 .60047 L F
.3293 .58814 m .32855 .60084 L .32901 .6012 L .908 .63 .503 r
F
.3293 .58814 m .32819 .60056 L .32855 .60084 L F
.3268 .60196 m .33555 .58308 L .32751 .58197 L .654 .726 .902 r
F
.32687 .60013 m .32684 .60144 L .32712 .60017 L .734 .478 .541 r
F
.32684 .60144 m .32678 .60425 L .32701 .60146 L F
.32684 .60144 m .32701 .60146 L .32712 .60017 L F
.32633 .60139 m .32603 .60136 L .32601 .60698 L F
.32678 .60425 m .32695 .60426 L .32712 .60017 L F
.32596 .60416 m .32763 .60262 L .32602 .60247 L .675 .735 .895 r
F
.32691 .60426 m .32763 .60262 L .32596 .60416 L F
.32678 .60425 m .32601 .60698 L .32672 .60705 L .734 .478 .541 r
F
.32643 .60421 m .32601 .60698 L .32678 .60425 L F
.32717 .58694 m .32633 .60139 L .32684 .60144 L F
.32641 .60006 m .32604 .60001 L .32603 .60136 L F
.32641 .60006 m .32603 .60136 L .32633 .60139 L F
.32593 .60137 m .32598 .60136 L .32604 .60001 L .66 .417 .541 r
F
.32717 .58694 m .32604 .60001 L .32641 .60006 L .734 .478 .541 r
F
.32607 .60002 m .32609 .59976 L .32599 .59979 L .654 .726 .902 r
F
.3259 .60134 m .32757 .5998 L .32596 .59965 L .675 .735 .895 r
F
.3259 .60137 m .32593 .60135 L .3259 .60134 L F
.32593 .60135 m .32757 .5998 L .3259 .60134 L F
.32685 .60144 m .32692 .60128 L .32603 .60136 L F
.3257 .6042 m .32587 .60418 L .32598 .60136 L .66 .417 .541 r
F
.3257 .6042 m .32598 .60136 L .32593 .60137 L F
.32692 .60128 m .32757 .5998 L .3259 .60137 L .675 .735 .895 r
F
.32596 .60417 m .32602 .60247 L .325 .60426 L F
.32589 .6165 m .32486 .61872 L .32581 .61891 L .654 .726 .902 r
F
.32547 .61411 m .32477 .64546 L .32564 .6141 L .66 .417 .541 r
F
.31693 .61447 m .3149 .61402 L .31592 .61452 L .654 .726 .902 r
F
.31693 .61447 m .31592 .61452 L .31924 .61615 L F
.31374 .61155 m .30942 .61561 L .31492 .61356 L .675 .735 .895 r
F
.31374 .61155 m .30765 .61259 L .30942 .61561 L F
.3149 .61402 m .29584 .60972 L .31924 .61615 L .654 .726 .902 r
F
.32379 .61442 m .32256 .64658 L .32367 .6458 L .4 .212 .507 r
F
.32382 .60738 m .32359 .61455 L .32379 .61442 L F
.32359 .61455 m .32256 .64658 L .32379 .61442 L F
.32371 .61834 m .32424 .6186 L .32412 .65017 L .844 .572 .526 r
F
.32438 .61426 m .32367 .6458 L .32455 .61422 L .568 .344 .535 r
F
.32438 .61426 m .32455 .61422 L .32475 .60714 L F
.30714 .61872 m .30063 .61517 L .29548 .62011 L .654 .726 .902 r
F
.31492 .61356 m .30942 .61561 L .31232 .6182 L .675 .735 .895 r
F
.31746 .61605 m .30063 .61517 L .30714 .61872 L .654 .726 .902 r
F
.29594 .61284 m .27146 .62645 L .2989 .61784 L F
.30063 .61517 m .29459 .61486 L .29469 .61543 L F
.30063 .61517 m .29469 .61543 L .29548 .62011 L F
.32598 .61409 m .32477 .64546 L .32586 .64538 L .66 .417 .541 r
F
.32604 .60001 m .32564 .6141 L .32598 .61409 L F
.32564 .6141 m .32477 .64546 L .32598 .61409 L F
.32328 .61474 m .32256 .64658 L .32345 .61464 L .4 .212 .507 r
F
.32328 .61474 m .32345 .61464 L .32365 .60749 L F
.31528 .61983 m .30714 .61872 L .29844 .62511 L .654 .726 .902 r
F
.31928 .61728 m .30714 .61872 L .31528 .61983 L F
.30714 .61872 m .29548 .62011 L .29632 .62152 L F
.30714 .61872 m .29632 .62152 L .29844 .62511 L F
.32589 .6165 m .32259 .61753 L .32296 .61818 L F
.32589 .6165 m .32274 .61831 L .32389 .61854 L F
.32371 .61834 m .32412 .65017 L .32356 .61827 L .844 .572 .526 r
F
.32438 .61426 m .32379 .61442 L .32367 .6458 L .568 .344 .535 r
F
.32239 .61717 m .32247 .64911 L .32233 .61707 L .989 .721 .393 r
F
.32259 .61753 m .31528 .61983 L .32296 .61818 L .654 .726 .902 r
F
.31675 .619 m .30372 .62225 L .31009 .62578 L F
.31528 .61983 m .29844 .62511 L .30193 .6283 L F
.31528 .61983 m .30193 .6283 L .30327 .62952 L F
.32344 .60762 m .32271 .60808 L .32268 .61512 L .4 .212 .507 r
F
.3229 .6178 m .32313 .6497 L .3228 .61771 L .927 .648 .492 r
F
.32328 .61474 m .32268 .61512 L .32256 .64658 L .4 .212 .507 r
F
.32344 .60762 m .32268 .61512 L .32328 .61474 L F
.32609 .58681 m .32579 .60002 L .32604 .60001 L .66 .417 .541 r
F
.32263 .60823 m .32252 .61542 L .32271 .60808 L 0 0 .373 r
F
.32252 .61542 m .32204 .6476 L .32259 .6153 L F
.32221 .61686 m .32247 .64911 L .32209 .64842 L .989 .721 .393 r
F
.32414 .62028 m .3163 .62682 L .31711 .63544 L .654 .726 .902 r
F
.32385 .61976 m .3163 .62682 L .32414 .62028 L F
.32239 .61717 m .32259 .61753 L .32247 .64911 L .989 .721 .393 r
F
.32268 .61512 m .32204 .6476 L .32256 .64658 L 0 0 .373 r
F
.32259 .6153 m .32204 .6476 L .32268 .61512 L F
.31698 .62558 m .30327 .62952 L .30964 .63305 L .654 .726 .902 r
F
.31956 .62084 m .30327 .62952 L .31698 .62558 L F
.32609 .58681 m .32495 .60006 L .32579 .60002 L .66 .417 .541 r
F
.32495 .60006 m .32475 .60714 L .32492 .60709 L .568 .344 .535 r
F
.3222 .6095 m .32218 .61644 L .32219 .60935 L .794 .634 .076 r
F
.32218 .61644 m .32209 .64842 L .32218 .61632 L F
.32244 .62001 m .31698 .62558 L .3225 .62084 L .654 .726 .902 r
F
.31698 .62558 m .30964 .63305 L .3163 .62682 L F
.32253 .60841 m .32244 .61557 L .32263 .60823 L 0 0 .373 r
F
.32228 .61698 m .32247 .64911 L .32221 .61686 L .989 .721 .393 r
F
.32244 .61557 m .32204 .6476 L .32252 .61542 L 0 0 .373 r
F
.3163 .62682 m .30964 .63305 L .31241 .63394 L .654 .726 .902 r
F
.3163 .62682 m .31241 .63394 L .31711 .63544 L F
.32219 .60916 m .32218 .61632 L .32219 .60904 L .794 .634 .076 r
F
.32253 .60841 m .32219 .60904 L .32216 .61608 L 0 0 .373 r
F
.32218 .61632 m .32209 .64842 L .32217 .61622 L .794 .634 .076 r
F
.32216 .61608 m .32209 .64842 L .32204 .6476 L F
.32217 .61622 m .32209 .64842 L .32216 .61608 L F
.32218 .61644 m .32221 .61686 L .32209 .64842 L F
.32244 .61557 m .32216 .61608 L .32204 .6476 L 0 0 .373 r
F
.325 .5869 m .3247 .60012 L .32495 .60006 L .568 .344 .535 r
F
.32599 .59979 m .32751 .58197 L .31942 .58223 L .654 .726 .902 r
F
.32609 .59976 m .32751 .58197 L .32599 .59979 L F
.32686 .60013 m .32751 .58197 L .32607 .60002 L F
.32601 .60698 m .32699 .60706 L .32602 .60673 L .675 .735 .895 r
F
.32697 .60708 m .32699 .60706 L .32601 .60698 L F
.32602 .60673 m .32768 .60547 L .32607 .60532 L F
.32656 .61417 m .32673 .6142 L .32712 .60017 L .734 .478 .541 r
F
.32699 .60706 m .32768 .60547 L .32602 .60673 L .675 .735 .895 r
F
.32733 .60401 m .32913 .60305 L .3271 .60383 L F
.32691 .60426 m .32696 .60423 L .32693 .60422 L F
.32696 .60423 m .32913 .60305 L .32693 .60422 L F
.32848 .60205 m .32819 .60183 L .32817 .60464 L .908 .63 .503 r
F
.32832 .60475 m .32817 .60464 L .32816 .60745 L F
.32848 .60205 m .32817 .60464 L .32832 .60475 L F
.32793 .60437 m .32913 .60305 L .32735 .60402 L .675 .735 .895 r
F
.32779 .60435 m .32735 .60402 L .32691 .60426 L F
.32793 .60437 m .32735 .60402 L .32779 .60435 L F
.32656 .61417 m .32586 .64538 L .32673 .6142 L .734 .478 .541 r
F
.32764 .61446 m .32706 .61424 L .32695 .6455 L .809 .541 .534 r
F
.32779 .60746 m .32706 .61424 L .32764 .61446 L F
.32706 .61424 m .32586 .64538 L .32695 .6455 L .734 .478 .541 r
F
.32712 .60017 m .32673 .6142 L .32706 .61424 L F
.32673 .6142 m .32586 .64538 L .32706 .61424 L F
.33503 .61541 m .34463 .61682 L .35632 .61288 L .654 .726 .902 r
F
.34831 .61723 m .37999 .62474 L .3534 .61335 L F
.34294 .61739 m .3572 .61813 L .35687 .61615 L F
.34294 .61739 m .35687 .61615 L .35632 .61288 L F
.3285 .60206 m .33129 .60175 L .33033 .60089 L .675 .735 .895 r
F
.32898 .60243 m .32915 .60255 L .32925 .60138 L .908 .63 .503 r
F
.3296 .60216 m .32925 .60138 L .32924 .60262 L .986 .729 .347 r
F
.32914 .60255 m .33129 .60175 L .3285 .60206 L .675 .735 .895 r
F
.32901 .6012 m .32898 .60243 L .32925 .60138 L .908 .63 .503 r
F
.32898 .60243 m .32892 .6052 L .32915 .60255 L F
.32892 .6052 m .32909 .60533 L .32925 .60138 L F
.32788 .60442 m .3304 .60372 L .32913 .60305 L .675 .735 .895 r
F
.3278 .60451 m .32795 .60447 L .32788 .60442 L F
.32795 .60447 m .3304 .60372 L .32788 .60442 L F
.32967 .60381 m .33011 .60458 L .32977 .60381 L F
.3287 .60481 m .3304 .60372 L .3278 .60451 L F
.32999 .61414 m .35337 .60788 L .34854 .60346 L .654 .726 .902 r
F
.32874 .61486 m .32993 .61452 L .32999 .61414 L F
.32993 .61452 m .35337 .60788 L .32999 .61414 L F
.32589 .6165 m .32983 .61526 L .32874 .61486 L F
.32983 .61526 m .35337 .60788 L .32874 .61486 L F
.32779 .60733 m .32764 .61446 L .32816 .60745 L .809 .541 .534 r
F
.32764 .61446 m .32695 .6455 L .32794 .61457 L F
.3287 .61508 m .32814 .61464 L .32802 .64588 L .908 .63 .503 r
F
.33087 .61676 m .34464 .62072 L .33438 .61694 L .654 .726 .902 r
F
.33244 .61797 m .34464 .62072 L .33087 .61676 L F
.34464 .62072 m .35594 .62327 L .33438 .61694 L F
.32814 .61464 m .32695 .6455 L .32802 .64588 L .809 .541 .534 r
F
.32794 .61457 m .32695 .6455 L .32814 .61464 L F
.32774 .60168 m .32819 .60183 L .32784 .60157 L .675 .735 .895 r
F
.32855 .60084 m .32819 .60056 L .32819 .60183 L .908 .63 .503 r
F
.32784 .60157 m .33033 .60089 L .32906 .60022 L .675 .735 .895 r
F
.32855 .60084 m .32819 .60183 L .32848 .60205 L .908 .63 .503 r
F
.3285 .60206 m .33033 .60089 L .32784 .60157 L .675 .735 .895 r
F
.3296 .60216 m .32938 .60577 L .32955 .60615 L .986 .729 .347 r
F
.32953 .60327 m .32923 .60543 L .32938 .60577 L F
.3296 .60216 m .32952 .60908 L .3297 .60239 L F
.3289 .60468 m .33137 .60458 L .3304 .60372 L .675 .735 .895 r
F
.32854 .60491 m .32898 .60486 L .3289 .60468 L F
.32898 .60486 m .33137 .60458 L .3289 .60468 L F
.3297 .60239 m .32964 .60636 L .32968 .60645 L .986 .729 .347 r
F
.32918 .6054 m .33137 .60458 L .32854 .60491 L .675 .735 .895 r
F
.32873 .61815 m .32899 .64923 L .32862 .61823 L .356 .178 .497 r
F
.32978 .61737 m .32942 .61801 L .33061 .61756 L .654 .726 .902 r
F
.32911 .61787 m .32942 .61801 L .32978 .61737 L F
.32942 .61801 m .33628 .62094 L .33061 .61756 L F
.33342 .61779 m .34137 .62742 L .33254 .61583 L F
.33628 .62094 m .35264 .62795 L .33244 .61797 L F
.32841 .61839 m .32899 .64923 L .32829 .64979 L .356 .178 .497 r
F
.3287 .61508 m .32802 .64588 L .32887 .6152 L .908 .63 .503 r
F
.32931 .61757 m .32954 .61724 L .32942 .64855 L .071 0 .412 r
F
.32951 .61615 m .32908 .6467 L .32956 .61628 L .986 .729 .347 r
F
.32954 .61724 m .32953 .64774 L .32942 .64855 L 0 0 .131 r
F
.32956 .61709 m .32953 .64774 L .32954 .61724 L F
.32959 .61688 m .32953 .64774 L .32957 .617 L F
.32959 .61688 m .32965 .61647 L .32953 .64774 L F
.32965 .61647 m .32908 .6467 L .32953 .64774 L .986 .729 .347 r
F
.32956 .61628 m .32908 .6467 L .32965 .61647 L F
.3289 .61863 m .33142 .62041 L .32929 .6186 L .654 .726 .902 r
F
.33142 .62041 m .34752 .63184 L .33123 .62001 L F
.33142 .62041 m .33123 .62001 L .32929 .6186 L F
.32862 .61823 m .32899 .64923 L .32854 .61829 L .356 .178 .497 r
F
.32854 .61829 m .32899 .64923 L .32841 .61839 L F
.32873 .61815 m .32911 .61787 L .32899 .64923 L F
.32919 .61546 m .32802 .64588 L .32908 .6467 L .908 .63 .503 r
F
.32887 .6152 m .32802 .64588 L .32919 .61546 L F
.33628 .62094 m .34895 .63075 L .35264 .62795 L .654 .726 .902 r
F
.32931 .61757 m .32942 .64855 L .32924 .61767 L .071 0 .412 r
F
.32944 .616 m .32908 .6467 L .32951 .61615 L .986 .729 .347 r
F
.32781 .61882 m .33412 .62645 L .3285 .61835 L .654 .726 .902 r
F
.33412 .62645 m .34092 .63468 L .33335 .62473 L F
.33412 .62645 m .33335 .62473 L .3285 .61835 L F
.32944 .616 m .32919 .61546 L .32908 .6467 L .986 .729 .347 r
F
.33142 .62041 m .34092 .63468 L .34752 .63184 L .654 .726 .902 r
F
.32848 .61833 m .33335 .62473 L .33142 .62041 L F
.33335 .62473 m .34092 .63468 L .33142 .62041 L F
.32859 .6237 m .33331 .63629 L .32883 .62206 L F
.32908 .62035 m .33331 .63629 L .34092 .63468 L F
.37999 .62474 m .41644 .62218 L .38657 .61544 L F
.3534 .61335 m .37999 .62474 L .38657 .61544 L F
0 0 0 r
2.5 Mabswid
.42283 .8753 Mdot
.127 .923 .03 r
.5 Mabswid
.49715 .70799 m
.49795 .64187 L
s
.39426 .75078 m .38238 .73799 L .3666 .74545 L .673 .758 .914 r
F
.40641 .74756 m .38238 .73799 L .39426 .75078 L F
.51255 .73873 m .5237 .74223 L .52402 .7479 L .931 .657 .497 r
F
.51255 .73873 m .51223 .73307 L .5237 .74223 L F
0 g
.5237 .74223 m
.52923 .74475 L
s
.43135 .86533 m .44421 .8725 L .45038 .86757 L .683 .77 .917 r
F
.127 .923 .03 r
.49619 .78691 m
.49715 .70799 L
s
.42739 .86731 m .44421 .8725 L .43135 .86533 L .683 .77 .917 r
F
.5345 .72503 m .52398 .74207 L .54211 .73111 L .673 .758 .914 r
F
.5345 .72503 m .51256 .73295 L .52398 .74207 L F
.57999 .72689 m .578 .73916 L .58981 .73801 L F
.58047 .72396 m .58981 .73801 L .58412 .7236 L F
.57764 .72423 m .57999 .72689 L .58047 .72396 L F
.57999 .72689 m .58981 .73801 L .58047 .72396 L F
.58263 .6822 m .58275 .68139 L .5828 .70962 L 0 0 .148 r
F
.57796 .72997 m .57719 .74509 L .59019 .74382 L .673 .758 .914 r
F
.57764 .72423 m .578 .73916 L .57999 .72689 L F
.57796 .72997 m .59019 .74382 L .58447 .72934 L F
.57829 .73564 m .57751 .75075 L .59052 .74948 L .673 .758 .915 r
F
.57829 .73564 m .59052 .74948 L .58479 .735 L F
.58149 .68344 m .58188 .71125 L .58154 .71151 L .361 .183 .5 r
F
.57889 .68408 m .57969 .71206 L .57894 .71217 L .642 .403 .541 r
F
.58474 .7113 m .59548 .7195 L .5996 .71631 L .673 .758 .914 r
F
.57733 .68382 m .57889 .68408 L .57894 .71217 L .751 .492 .54 r
F
.58149 .68344 m .5822 .68288 L .58225 .71098 L .361 .183 .5 r
F
.58026 .71384 m .57764 .72423 L .58412 .7236 L .673 .758 .914 r
F
.57984 .71279 m .57941 .71507 L .58026 .71384 L F
.57941 .71507 m .57764 .72423 L .58026 .71384 L F
.58131 .71232 m .58412 .7236 L .58891 .72233 L F
.58132 .71764 m .58718 .72402 L .58192 .71677 L F
.58412 .7236 m .60197 .73479 L .5902 .72199 L F
.58718 .72402 m .59058 .72772 L .58644 .72248 L F
.58718 .72402 m .58644 .72248 L .58192 .71677 L F
.58272 .73978 m .58273 .7398 L .58274 .74089 L .082 0 .419 r
F
.58047 .68387 m .58101 .71173 L .58052 .71193 L .519 .305 .529 r
F
.57889 .68408 m .58047 .68387 L .58052 .71193 L .642 .403 .541 r
F
.57889 .68408 m .58052 .71193 L .57969 .71206 L F
.5822 .68288 m .58263 .6822 L .58268 .71035 L .082 0 .419 r
F
.5822 .68288 m .58268 .71035 L .58246 .71068 L F
.58275 .68139 m .58231 .68035 L .58236 .7087 L .984 .727 .338 r
F
.58083 .7118 m .5902 .72199 L .58197 .71133 L .673 .758 .914 r
F
.57764 .72423 m .57687 .73927 L .578 .73916 L F
.57122 .72384 m .57687 .73927 L .57705 .73571 L F
.57628 .72415 m .57705 .73571 L .57764 .72423 L F
.57122 .72384 m .57705 .73571 L .57628 .72415 L F
.57527 .68126 m .57531 .68207 L .57536 .71048 L .779 .622 .059 r
F
.57827 .71209 m .57764 .72423 L .57963 .71225 L .673 .758 .914 r
F
.57531 .68207 m .57569 .68276 L .57573 .71109 L .988 .72 .386 r
F
.57527 .68126 m .57533 .7101 L .57531 .70975 L .779 .622 .059 r
F
.57527 .68126 m .57536 .71048 L .57533 .7101 L F
.5758 .68024 m .57527 .68126 L .57531 .70975 L 0 0 .381 r
F
.57657 .71245 m .57096 .71742 L .5767 .71267 L .673 .758 .914 r
F
.57096 .71742 m .56529 .72245 L .57077 .71775 L F
.57096 .71742 m .57077 .71775 L .5767 .71267 L F
.57618 .71181 m .56529 .72245 L .57657 .71245 L F
.57843 .72079 m .57151 .72958 L .57796 .72997 L F
.57855 .71857 m .5778 .71975 L .57843 .72079 L F
.57822 .71302 m .57122 .72384 L .57764 .72423 L F
.57737 .71199 m .57827 .7174 L .57738 .7173 L .751 .492 .54 r
F
.57733 .68382 m .57812 .71208 L .57737 .71199 L F
.57827 .71209 m .577 .71207 L .57822 .71302 L .673 .758 .914 r
F
.57705 .71195 m .577 .71207 L .57827 .71209 L F
.57812 .71208 m .57827 .7174 L .57737 .71199 L .751 .492 .54 r
F
.57842 .70918 m .57705 .71195 L .57827 .71209 L .673 .758 .914 r
F
.577 .71207 m .57122 .72384 L .57822 .71302 L F
.5778 .71975 m .57151 .72958 L .57843 .72079 L F
.57825 .71834 m .5776 .71943 L .57855 .71857 L F
.5776 .71943 m .57151 .72958 L .5778 .71975 L F
.5776 .71943 m .5778 .71975 L .57855 .71857 L F
.57151 .72958 m .57719 .74509 L .57796 .72997 L F
.57585 .7282 m .57183 .73524 L .57635 .73552 L .673 .758 .915 r
F
.57554 .71077 m .57573 .71109 L .57574 .71639 L .988 .72 .386 r
F
.578 .72268 m .57773 .72323 L .57895 .72279 L .673 .758 .915 r
F
.57773 .72323 m .57183 .73524 L .57839 .72375 L F
.57857 .71806 m .57796 .72997 L .5798 .71758 L .673 .758 .914 r
F
.57974 .71757 m .5798 .71758 L .57981 .71754 L F
.57857 .71806 m .5798 .71758 L .57974 .71757 L F
.57812 .71208 m .57894 .71217 L .57895 .71748 L .751 .492 .54 r
F
.57859 .71778 m .57825 .71834 L .57855 .71857 L .673 .758 .914 r
F
.57895 .72279 m .57585 .7282 L .57829 .73564 L .673 .758 .915 r
F
.57982 .71758 m .57796 .72997 L .58447 .72934 L .673 .758 .914 r
F
.56529 .72245 m .56404 .73849 L .57122 .72384 L F
.56529 .72245 m .55218 .7357 L .56404 .73849 L F
.56026 .72015 m .55218 .7357 L .56529 .72245 L F
.56026 .72015 m .54211 .73111 L .55218 .7357 L F
.57531 .68207 m .57573 .71109 L .57554 .71077 L .988 .72 .386 r
F
.57635 .68335 m .57686 .71179 L .57639 .7116 L .844 .571 .525 r
F
.57569 .68276 m .57635 .68335 L .57639 .7116 L .928 .648 .489 r
F
.57569 .68276 m .57639 .7116 L .57629 .71152 L F
.57618 .71143 m .56026 .72015 L .56529 .72245 L .673 .758 .914 r
F
.57842 .70918 m .57552 .71092 L .57618 .71143 L F
.57552 .71092 m .56026 .72015 L .57618 .71143 L F
.57605 .71133 m .5764 .7169 L .57612 .71669 L .928 .648 .489 r
F
.57569 .68276 m .57629 .71152 L .57605 .71133 L F
.57618 .71143 m .57613 .71149 L .57639 .7116 L .673 .758 .914 r
F
.5767 .71267 m .57557 .71364 L .57565 .71481 L F
.57629 .71152 m .5764 .7169 L .57605 .71133 L .928 .648 .489 r
F
.57558 .70926 m .57554 .71466 L .57584 .70881 L 0 0 .381 r
F
.57657 .72303 m .57557 .72403 L .57726 .72417 L .673 .758 .915 r
F
.57122 .72384 m .56404 .73849 L .57687 .73927 L .673 .758 .914 r
F
.57698 .71842 m .56555 .72818 L .57151 .72958 L F
.57557 .72403 m .56587 .73384 L .57567 .72552 L .673 .758 .915 r
F
.57557 .72403 m .57567 .72552 L .57726 .72417 L F
.56555 .72818 m .56429 .7443 L .57151 .72958 L .673 .758 .914 r
F
.57557 .72403 m .56081 .73153 L .56587 .73384 L .673 .758 .915 r
F
.57681 .71814 m .5756 .71922 L .57698 .71842 L .673 .758 .914 r
F
.5756 .71922 m .56555 .72818 L .57562 .71958 L F
.5756 .71922 m .57562 .71958 L .57698 .71842 L F
.57533 .7101 m .57535 .71547 L .57531 .70975 L .779 .622 .059 r
F
.57548 .72267 m .56081 .73153 L .57557 .72403 L .673 .758 .915 r
F
.57657 .71704 m .57101 .72266 L .57736 .71765 L .673 .758 .914 r
F
.57101 .72266 m .56555 .72818 L .57026 .72398 L F
.57101 .72266 m .57026 .72398 L .57736 .71765 L F
.57535 .71547 m .57533 .71518 L .57531 .70975 L .779 .622 .059 r
F
.57531 .70975 m .57533 .71518 L .57532 .71505 L F
.57613 .71149 m .56529 .72245 L .57639 .7116 L .673 .758 .914 r
F
.57554 .71077 m .57558 .71613 L .57536 .71048 L .988 .72 .386 r
F
.57557 .71364 m .56529 .72245 L .57565 .71481 L .673 .758 .914 r
F
.57533 .7101 m .57536 .71048 L .57537 .71578 L .779 .622 .059 r
F
.57565 .71481 m .57013 .71888 L .57122 .72384 L .673 .758 .914 r
F
.57544 .71684 m .56049 .72587 L .57549 .71761 L F
.57536 .7156 m .57537 .71578 L .57538 .72109 L .779 .622 .059 r
F
.57533 .7101 m .57537 .71578 L .57536 .7156 L F
.57569 .68276 m .57605 .71133 L .57573 .71109 L .928 .648 .489 r
F
.5752 .71112 m .55645 .7171 L .56026 .72015 L .673 .758 .914 r
F
.57842 .70918 m .57417 .71071 L .5752 .71112 L F
.57417 .71071 m .55645 .7171 L .5752 .71112 L F
.57635 .68335 m .57733 .68382 L .57737 .71199 L .844 .571 .525 r
F
.57722 .71193 m .57737 .71199 L .57738 .7173 L F
.57635 .68335 m .57737 .71199 L .57722 .71193 L F
.57531 .68207 m .57554 .71077 L .57536 .71048 L .988 .72 .386 r
F
.57417 .71071 m .55415 .71352 L .55645 .7171 L .673 .758 .914 r
F
.57692 .67946 m .5758 .68024 L .57584 .70881 L .404 .216 .509 r
F
.5771 .72249 m .57548 .72267 L .57557 .72403 L .673 .758 .915 r
F
.57575 .71665 m .57544 .71684 L .57649 .71697 L .673 .758 .914 r
F
.5764 .7169 m .57649 .71697 L .57661 .71699 L F
.57575 .71665 m .57649 .71697 L .5764 .7169 L F
.57619 .72204 m .57598 .72188 L .57586 .71648 L .928 .648 .489 r
F
.57596 .71656 m .57586 .71648 L .57573 .71109 L F
.57619 .72204 m .57586 .71648 L .57596 .71656 L F
.57751 .71735 m .57151 .72958 L .57859 .71778 L .673 .758 .914 r
F
.57738 .7173 m .57772 .72264 L .57739 .7226 L .751 .492 .54 r
F
.57906 .72051 m .57242 .7217 L .57426 .72224 L .673 .758 .915 r
F
.57242 .7217 m .5713 .7219 L .572 .72198 L F
.57242 .7217 m .572 .72198 L .57426 .72224 L F
.57605 .71133 m .57612 .71669 L .57573 .71109 L .928 .648 .489 r
F
.57612 .71669 m .57619 .72204 L .57596 .71656 L F
.57612 .71669 m .57596 .71656 L .57573 .71109 L F
.57386 .71493 m .55474 .71137 L .55369 .7153 L .673 .758 .914 r
F
.57554 .71077 m .57574 .71639 L .57558 .71613 L .988 .72 .386 r
F
.57573 .71109 m .57586 .71648 L .57574 .71639 L .928 .648 .489 r
F
.57675 .72235 m .57742 .7425 L .57661 .7223 L .844 .571 .525 r
F
.57585 .7282 m .57635 .73552 L .57829 .73564 L .673 .758 .915 r
F
.57183 .73524 m .57751 .75075 L .57829 .73564 L F
.57641 .72221 m .57742 .7425 L .57644 .74203 L .844 .571 .525 r
F
.5764 .7169 m .57661 .7223 L .57641 .72221 L F
.57661 .7223 m .57742 .7425 L .57641 .72221 L F
.57533 .71518 m .57534 .72062 L .57532 .71505 L .779 .622 .059 r
F
.57534 .72062 m .57534 .72052 L .57532 .71505 L F
.57532 .71505 m .57534 .72052 L .57533 .72036 L F
.57661 .71699 m .57314 .7189 L .57101 .72266 L .673 .758 .914 r
F
.57543 .71589 m .57551 .72131 L .57537 .71578 L .988 .72 .386 r
F
.57551 .72131 m .57578 .74144 L .57546 .72122 L F
.57551 .72131 m .57546 .72122 L .57537 .71578 L F
.57101 .72266 m .56049 .72587 L .56555 .72818 L .673 .758 .914 r
F
.57542 .72182 m .55699 .72847 L .57608 .72225 L .673 .758 .915 r
F
.57595 .72203 m .57608 .72225 L .57631 .72217 L F
.57542 .72182 m .57608 .72225 L .57595 .72203 L F
.57533 .7101 m .57538 .72109 L .57536 .72085 L .779 .622 .059 r
F
.57013 .71888 m .56529 .72245 L .56778 .72303 L .673 .758 .914 r
F
.57372 .71787 m .55666 .72281 L .56049 .72587 L F
.57874 .71484 m .57459 .71634 L .57372 .71787 L F
.57459 .71634 m .55666 .72281 L .57372 .71787 L F
.57544 .71684 m .57549 .71761 L .57661 .71699 L F
.57586 .71648 m .57598 .72188 L .57574 .71639 L .928 .648 .489 r
F
.57598 .72188 m .57644 .74203 L .57589 .72181 L F
.57598 .72188 m .57589 .72181 L .57574 .71639 L F
.57013 .71888 m .56778 .72303 L .57122 .72384 L .673 .758 .914 r
F
.57512 .72121 m .55401 .72097 L .55467 .72487 L .673 .758 .915 r
F
.57906 .72051 m .57432 .7206 L .57512 .72121 L F
.57432 .7206 m .55401 .72097 L .57512 .72121 L F
.57585 .71412 m .57567 .71975 L .57586 .71942 L 0 0 .381 r
F
.57584 .70881 m .57576 .71428 L .57585 .71412 L F
.57576 .71428 m .57567 .71975 L .57585 .71412 L F
.57554 .71466 m .57532 .71505 L .57533 .72036 L F
.56995 .71801 m .55435 .7192 L .55666 .72281 L .673 .758 .914 r
F
.57686 .71179 m .57738 .7173 L .57696 .71713 L .844 .571 .525 r
F
.57874 .71484 m .57327 .71582 L .56995 .71801 L .673 .758 .914 r
F
.57327 .71582 m .55435 .7192 L .56995 .71801 L F
.57874 .71484 m .57547 .71437 L .57464 .71492 L F
.57612 .71669 m .5764 .7169 L .57641 .72221 L .928 .648 .489 r
F
.57631 .72217 m .57548 .72267 L .57681 .72252 L .673 .758 .915 r
F
.57619 .72204 m .57641 .72221 L .57644 .74203 L .928 .648 .489 r
F
.57612 .71669 m .57641 .72221 L .57619 .72204 L F
.57641 .72221 m .57681 .72252 L .5771 .72249 L .673 .758 .915 r
F
.57631 .72217 m .57681 .72252 L .57641 .72221 L F
.57632 .7138 m .57586 .71942 L .57623 .71918 L .404 .216 .509 r
F
.57642 .70843 m .57614 .71393 L .57632 .7138 L F
.57614 .71393 m .57586 .71942 L .57632 .7138 L F
.57535 .71547 m .57536 .72085 L .57533 .71518 L .779 .622 .059 r
F
.57726 .72417 m .56936 .73088 L .57183 .73524 L .673 .758 .915 r
F
.57536 .72085 m .57541 .74075 L .57534 .72062 L .779 .622 .059 r
F
.57536 .72085 m .57534 .72062 L .57533 .71518 L F
.57534 .72058 m .55506 .71703 L .55401 .72097 L .673 .758 .915 r
F
.57675 .72235 m .57661 .7223 L .5764 .7169 L .844 .571 .525 r
F
.57906 .72051 m .5753 .71996 L .57534 .72058 L .673 .758 .915 r
F
.5753 .71996 m .55506 .71703 L .57534 .72058 L F
.57534 .72062 m .57541 .74075 L .57534 .72052 L .779 .622 .059 r
F
.57533 .72036 m .57541 .74075 L .57536 .73994 L F
.57534 .72052 m .57541 .74075 L .57533 .72036 L F
.57538 .72109 m .57578 .74144 L .57541 .74075 L .988 .72 .386 r
F
.57537 .71578 m .57546 .72122 L .57538 .72109 L F
.57546 .72122 m .57578 .74144 L .57538 .72109 L F
.57639 .7116 m .57657 .71697 L .5764 .7169 L .844 .571 .525 r
F
.57355 .71577 m .55369 .7153 L .55435 .7192 L .673 .758 .914 r
F
.56644 .71132 m .5535 .70963 L .55415 .71352 L F
.57639 .7116 m .57618 .71181 L .577 .71207 L F
.57618 .71181 m .57657 .71245 L .577 .71207 L F
.577 .71207 m .57657 .71245 L .5767 .71267 L F
.57686 .71179 m .57696 .71713 L .57639 .7116 L .844 .571 .525 r
F
.57842 .70918 m .57618 .71143 L .577 .71207 L .673 .758 .914 r
F
.57696 .70807 m .57632 .7138 L .57697 .71338 L .404 .216 .509 r
F
.57635 .68335 m .57722 .71193 L .57686 .71179 L .844 .571 .525 r
F
.57692 .67946 m .57642 .70843 L .57696 .70807 L .404 .216 .509 r
F
.57629 .71152 m .57639 .7116 L .5764 .7169 L .928 .648 .489 r
F
.57642 .70843 m .57632 .7138 L .57696 .70807 L .404 .216 .509 r
F
.57413 .70994 m .57306 .70927 L .56644 .71132 L .673 .758 .914 r
F
.57842 .70918 m .5752 .70923 L .57413 .70994 L F
.5752 .70923 m .57306 .70927 L .57413 .70994 L F
.57306 .70927 m .5535 .70963 L .56644 .71132 L F
.57802 .67912 m .57692 .67946 L .57696 .70807 L .569 .345 .536 r
F
.57714 .70801 m .57696 .70807 L .57697 .71338 L F
.57802 .67912 m .57696 .70807 L .57714 .70801 L F
.57696 .71713 m .57742 .7425 L .57657 .71697 L .844 .571 .525 r
F
.57906 .72051 m .57542 .72182 L .57631 .72217 L .673 .758 .915 r
F
.57722 .71193 m .57738 .7173 L .57686 .71179 L .844 .571 .525 r
F
.57874 .71484 m .57575 .71665 L .57661 .71699 L .673 .758 .914 r
F
.57736 .71765 m .57681 .71814 L .57698 .71842 L F
.57696 .71713 m .57738 .7173 L .57742 .7425 L .844 .571 .525 r
F
.57842 .70918 m .57413 .70994 L .57417 .71071 L .673 .758 .914 r
F
.57536 .71048 m .57543 .71589 L .57537 .71578 L .988 .72 .386 r
F
.57558 .71613 m .57543 .71589 L .57536 .71048 L F
.57558 .70926 m .57532 .71505 L .57554 .71466 L 0 0 .381 r
F
.57306 .70927 m .55454 .70572 L .5535 .70963 L .673 .758 .914 r
F
.5758 .68024 m .57531 .70975 L .57558 .70926 L 0 0 .381 r
F
.57842 .70918 m .57499 .70868 L .57306 .70927 L .673 .758 .914 r
F
.57499 .70868 m .55454 .70572 L .57306 .70927 L F
.57806 .70773 m .57744 .71323 L .57807 .71304 L .569 .345 .536 r
F
.57733 .68382 m .57894 .71217 L .57812 .71208 L .751 .492 .54 r
F
.57802 .67912 m .57753 .70789 L .57806 .70773 L .569 .345 .536 r
F
.57753 .70789 m .57744 .71323 L .57806 .70773 L F
.57562 .71379 m .56157 .70446 L .55743 .70767 L .673 .758 .914 r
F
.57874 .71484 m .57654 .71351 L .57562 .71379 L F
.57283 .71017 m .55415 .71352 L .57417 .71071 L F
.57499 .70868 m .55721 .70204 L .55454 .70572 L F
.57842 .70918 m .57601 .70836 L .57499 .70868 L F
.57601 .70836 m .55721 .70204 L .57499 .70868 L F
.57753 .70789 m .57697 .71338 L .57744 .71323 L .569 .345 .536 r
F
.57802 .67912 m .57714 .70801 L .57753 .70789 L F
.57714 .70801 m .57697 .71338 L .57753 .70789 L F
.57654 .71351 m .56157 .70446 L .57562 .71379 L .673 .758 .914 r
F
.57739 .7226 m .57899 .74276 L .57742 .7425 L .751 .492 .54 r
F
.57772 .72264 m .57899 .74276 L .57739 .7226 L F
.57156 .71497 m .55369 .7153 L .57355 .71577 L .673 .758 .914 r
F
.57527 .71434 m .55743 .70767 L .55474 .71137 L F
.57524 .71922 m .56189 .71012 L .55775 .71334 L .673 .758 .915 r
F
.57698 .71868 m .57589 .73892 L .57701 .73815 L .404 .216 .509 r
F
.57696 .71713 m .57657 .71697 L .57639 .7116 L .844 .571 .525 r
F
.57874 .71484 m .57657 .71704 L .57736 .71765 L .673 .758 .914 r
F
.57697 .71338 m .57674 .71884 L .57698 .71868 L .404 .216 .509 r
F
.57674 .71884 m .57589 .73892 L .57698 .71868 L F
.57585 .71943 m .57636 .71888 L .57524 .71922 L .673 .758 .915 r
F
.57906 .72051 m .57653 .71898 L .57585 .71943 L F
.57874 .71484 m .57523 .71366 L .57527 .71434 L .673 .758 .914 r
F
.57657 .71697 m .57675 .72235 L .5764 .7169 L .844 .571 .525 r
F
.57619 .72204 m .57644 .74203 L .57598 .72188 L .928 .648 .489 r
F
.57574 .71639 m .57644 .74203 L .57578 .74144 L F
.57632 .7138 m .57623 .71918 L .57697 .71338 L .404 .216 .509 r
F
.57623 .71918 m .57589 .73892 L .57674 .71884 L F
.57623 .71918 m .57674 .71884 L .57697 .71338 L F
.57181 .71497 m .57156 .71497 L .57166 .71501 L .673 .758 .914 r
F
.57181 .71497 m .57166 .71501 L .57355 .71577 L F
.57523 .71366 m .55743 .70767 L .57527 .71434 L F
.57558 .71613 m .57574 .71639 L .57575 .7217 L .988 .72 .386 r
F
.57653 .71898 m .5672 .70762 L .56189 .71012 L .673 .758 .915 r
F
.57874 .71484 m .57181 .71497 L .57355 .71577 L .673 .758 .914 r
F
.57744 .71323 m .57735 .71857 L .57807 .71304 L .569 .345 .536 r
F
.57773 .72323 m .57839 .72375 L .57895 .72279 L .673 .758 .915 r
F
.57827 .7174 m .57899 .74276 L .57738 .7173 L .751 .492 .54 r
F
.57906 .72051 m .5773 .71859 L .57653 .71898 L .673 .758 .915 r
F
.57827 .7174 m .57895 .72279 L .57842 .72272 L .751 .492 .54 r
F
.57906 .72051 m .57631 .72217 L .5771 .72249 L .673 .758 .915 r
F
.57906 .72051 m .57657 .72303 L .57726 .72417 L F
.57735 .71857 m .57701 .73815 L .57785 .71842 L .569 .345 .536 r
F
.57735 .71857 m .57785 .71842 L .57807 .71304 L F
.57744 .71323 m .57697 .71338 L .57698 .71868 L F
.57735 .71857 m .57698 .71868 L .57701 .73815 L F
.57744 .71323 m .57698 .71868 L .57735 .71857 L F
.57464 .71492 m .57259 .71395 L .57386 .71493 L .673 .758 .914 r
F
.57547 .71437 m .57259 .71395 L .57464 .71492 L F
.57413 .70994 m .57283 .71017 L .57342 .71041 L F
.57413 .70994 m .57342 .71041 L .57417 .71071 L F
.57554 .71466 m .57576 .71428 L .57584 .70881 L 0 0 .381 r
F
.5758 .68024 m .57558 .70926 L .57584 .70881 L F
.57506 .70805 m .56133 .69884 L .55721 .70204 L .673 .758 .914 r
F
.57842 .70918 m .57633 .70791 L .57506 .70805 L F
.57633 .70791 m .56133 .69884 L .57506 .70805 L F
.57911 .67903 m .57802 .67912 L .57806 .70773 L .66 .418 .542 r
F
.57906 .72051 m .5782 .71833 L .5773 .71859 L .673 .758 .915 r
F
.57812 .71208 m .57895 .71748 L .57827 .7174 L .751 .492 .54 r
F
.57874 .71484 m .57751 .71735 L .57859 .71778 L .673 .758 .914 r
F
.57862 .70767 m .57808 .71834 L .57844 .71831 L .66 .418 .542 r
F
.5782 .71833 m .57819 .71831 L .57808 .71834 L .673 .758 .915 r
F
.5782 .71833 m .57808 .71834 L .5773 .71859 L F
.57862 .70767 m .57806 .70773 L .57807 .71304 L .66 .418 .542 r
F
.57874 .71484 m .57884 .71295 L .57803 .71304 L .673 .758 .914 r
F
.57558 .71613 m .57575 .7217 L .57563 .7215 L .988 .72 .386 r
F
.57906 .72051 m .57397 .71879 L .57462 .71987 L .673 .758 .915 r
F
.57827 .7174 m .57895 .71748 L .57895 .72279 L .751 .492 .54 r
F
.57875 .72666 m .57829 .73564 L .5805 .72414 L .673 .758 .915 r
F
.57842 .72272 m .57895 .72279 L .57899 .74276 L .751 .492 .54 r
F
.57906 .72051 m .578 .72268 L .57895 .72279 L .673 .758 .915 r
F
.57953 .71303 m .57764 .72423 L .57984 .71279 L .673 .758 .914 r
F
.57962 .71231 m .57764 .72423 L .57965 .7123 L F
.57974 .71736 m .57857 .71806 L .57981 .71754 L F
.57894 .71217 m .57922 .71744 L .57895 .71748 L .642 .403 .541 r
F
.57874 .71484 m .5786 .71753 L .57974 .71736 L .673 .758 .914 r
F
.5786 .71753 m .57857 .71806 L .57974 .71736 L F
.5798 .71758 m .57796 .72997 L .57982 .71758 L F
.5805 .72414 m .57829 .73564 L .58035 .73544 L .673 .758 .915 r
F
.57895 .71748 m .58057 .74256 L .57899 .74276 L .642 .403 .541 r
F
.57991 .72264 m .57875 .72666 L .5805 .72414 L .673 .758 .915 r
F
.5795 .7227 m .57929 .72274 L .57895 .71748 L .642 .403 .541 r
F
.57981 .71754 m .5798 .71758 L .57982 .71758 L .673 .758 .914 r
F
.57965 .7123 m .57953 .71303 L .57984 .71279 L F
.57963 .71225 m .57962 .71231 L .57965 .7123 L F
.57969 .71206 m .57985 .71734 L .57894 .71217 L .642 .403 .541 r
F
.5902 .72199 m .60197 .73479 L .61254 .72982 L .673 .758 .914 r
F
.59058 .72772 m .61303 .73558 L .59589 .72522 L F
.58372 .72208 m .59622 .73088 L .60036 .72768 L .673 .758 .915 r
F
.57999 .718 m .58447 .72934 L .58096 .71726 L .673 .758 .914 r
F
.58169 .72716 m .58035 .73544 L .58479 .735 L .673 .758 .915 r
F
.58156 .72212 m .5823 .74156 L .58159 .74213 L .361 .183 .5 r
F
.58155 .71682 m .58171 .72201 L .58156 .72212 L F
.58171 .72201 m .5823 .74156 L .58156 .72212 L F
.58114 .71258 m .58412 .7236 L .58131 .71232 L .673 .758 .914 r
F
.58249 .7161 m .58228 .71698 L .58423 .71669 L F
.5809 .71188 m .58093 .71197 L .58096 .71194 L F
.57956 .71208 m .58412 .7236 L .5809 .71188 L F
.58434 .71565 m .60004 .72201 L .60273 .71831 L F
.58111 .717 m .58087 .7171 L .58052 .71193 L .519 .305 .529 r
F
.58188 .71125 m .58225 .71098 L .58226 .71628 L .361 .183 .5 r
F
.5819 .7205 m .58447 .72934 L .58221 .71861 L .673 .758 .914 r
F
.58047 .68387 m .58149 .68344 L .58154 .71151 L .519 .305 .529 r
F
.58047 .68387 m .58154 .71151 L .58101 .71173 L F
.5822 .68288 m .58246 .71068 L .58225 .71098 L .082 0 .419 r
F
.58149 .68344 m .58225 .71098 L .58188 .71125 L .361 .183 .5 r
F
.58436 .71004 m .5996 .71631 L .60228 .71263 L .673 .758 .914 r
F
.57842 .70918 m .5878 .71233 L .58436 .71004 L F
.5878 .71233 m .5996 .71631 L .58436 .71004 L F
.58089 .72263 m .58479 .735 L .58096 .72257 L .673 .758 .915 r
F
.58175 .71666 m .58228 .71698 L .58249 .7161 L .673 .758 .914 r
F
.58195 .71651 m .58226 .71628 L .58227 .72159 L .361 .183 .5 r
F
.57969 .71206 m .58052 .71193 L .58054 .72255 L .642 .403 .541 r
F
.57997 .72279 m .58013 .7232 L .58075 .72252 L .673 .758 .915 r
F
.57997 .72279 m .58075 .72252 L .58054 .72255 L F
.58 .72263 m .58054 .72255 L .58057 .74256 L .642 .403 .541 r
F
.5809 .71719 m .57999 .718 L .58096 .71726 L .673 .758 .914 r
F
.57985 .71734 m .57922 .71744 L .57894 .71217 L .642 .403 .541 r
F
.57874 .71484 m .57974 .71736 L .5809 .71719 L .673 .758 .914 r
F
.57974 .71736 m .57999 .718 L .5809 .71719 L F
.57985 .71734 m .58054 .72255 L .58 .72263 L .642 .403 .541 r
F
.57969 .71206 m .58012 .7173 L .57985 .71734 L F
.58012 .7173 m .58054 .72255 L .57985 .71734 L F
.58054 .72255 m .58075 .72252 L .58083 .72243 L .673 .758 .915 r
F
.58013 .7232 m .58479 .735 L .58089 .72263 L F
.58013 .7232 m .58089 .72263 L .58083 .72243 L F
.58096 .71726 m .5819 .7205 L .58221 .71861 L .673 .758 .914 r
F
.58167 .71672 m .58181 .72194 L .58155 .71682 L .361 .183 .5 r
F
.58181 .72194 m .5823 .74156 L .58171 .72201 L F
.58181 .72194 m .58171 .72201 L .58155 .71682 L F
.58203 .72177 m .58227 .72159 L .5823 .74156 L F
.58195 .71651 m .58227 .72159 L .58203 .72177 L F
.58447 .72934 m .59019 .74382 L .60242 .74058 L .673 .758 .914 r
F
.58218 .7242 m .58479 .735 L .58934 .7338 L .673 .758 .915 r
F
.58096 .72257 m .58193 .72571 L .58218 .7242 L F
.58193 .72571 m .58479 .735 L .58218 .7242 L F
.58263 .6822 m .5828 .70962 L .58274 .71 L 0 0 .148 r
F
.58263 .6822 m .58274 .71 L .58268 .71035 L F
.58295 .70909 m .60228 .71263 L .60334 .70872 L .673 .758 .914 r
F
.57842 .70918 m .58436 .71004 L .58295 .70909 L F
.58436 .71004 m .60228 .71263 L .58295 .70909 L F
.58231 .68035 m .58126 .67954 L .58131 .70799 L .909 .63 .501 r
F
.58276 .71524 m .58273 .71542 L .58268 .71035 L 0 0 .148 r
F
.58227 .72159 m .58206 .72232 L .58371 .72208 L .673 .758 .915 r
F
.58412 .7236 m .58981 .73801 L .60197 .73479 L .673 .758 .914 r
F
.58221 .71861 m .58447 .72934 L .59058 .72772 L F
.58131 .71232 m .58891 .72233 L .58715 .71868 L F
.58246 .71068 m .58268 .71035 L .5827 .72097 L .082 0 .419 r
F
.58256 .72117 m .5827 .72097 L .58273 .7398 L F
.58246 .71068 m .5827 .72097 L .58256 .72117 L F
.5902 .72199 m .61254 .72982 L .59548 .7195 L .673 .758 .914 r
F
.58423 .71669 m .59589 .72522 L .60004 .72201 L F
.58715 .71868 m .58891 .72233 L .5902 .72199 L F
.58246 .71709 m .59058 .72772 L .59589 .72522 L F
.58192 .71677 m .58241 .71738 L .58246 .71709 L F
.58241 .71738 m .59058 .72772 L .58246 .71709 L F
.58269 .71566 m .58274 .72071 L .5827 .72097 L 0 0 .148 r
F
.58268 .71035 m .58271 .71553 L .58269 .71566 L F
.58271 .71553 m .58274 .72071 L .58269 .71566 L F
.58266 .72103 m .60036 .72768 L .60305 .72398 L .673 .758 .915 r
F
.58111 .717 m .58155 .71682 L .58156 .72212 L .519 .305 .529 r
F
.58121 .72227 m .58156 .72212 L .58159 .74213 L F
.58111 .717 m .58156 .72212 L .58121 .72227 L F
.58573 .72039 m .60305 .72398 L .60411 .72005 L .673 .758 .915 r
F
.57906 .72051 m .58379 .72119 L .58573 .72039 L F
.58248 .71695 m .59589 .72522 L .58423 .71669 L .673 .758 .914 r
F
.58228 .71698 m .58246 .71709 L .58248 .71695 L F
.58246 .71709 m .59589 .72522 L .58248 .71695 L F
.58278 .72048 m .58274 .72071 L .58271 .71553 L 0 0 .148 r
F
.58273 .71542 m .58271 .71553 L .58268 .71035 L F
.58278 .72048 m .58271 .71553 L .58273 .71542 L F
.58379 .72119 m .60305 .72398 L .58573 .72039 L .673 .758 .915 r
F
.57906 .72051 m .58227 .72159 L .58266 .72103 L F
.58227 .72159 m .60036 .72768 L .58266 .72103 L F
.57842 .70918 m .58249 .71164 L .58474 .7113 L .673 .758 .914 r
F
.58259 .70917 m .58256 .7144 L .5828 .70962 L .984 .727 .338 r
F
.58255 .72118 m .58274 .74089 L .58242 .72137 L .082 0 .419 r
F
.58447 .72934 m .60242 .74058 L .59058 .72772 L .673 .758 .914 r
F
.58454 .72382 m .59091 .73338 L .59622 .73088 L .673 .758 .915 r
F
.58185 .72219 m .58656 .72801 L .58454 .72382 L F
.58656 .72801 m .59091 .73338 L .58454 .72382 L F
.58256 .7144 m .58252 .71962 L .58273 .71476 L .984 .727 .338 r
F
.58252 .71962 m .58241 .73904 L .58266 .71991 L F
.58252 .71962 m .58266 .71991 L .58273 .71476 L F
.58197 .71133 m .58634 .71699 L .5843 .71273 L .673 .758 .914 r
F
.58274 .71 m .58276 .71524 L .58268 .71035 L 0 0 .148 r
F
.58256 .7144 m .58273 .71476 L .5828 .70962 L .984 .727 .338 r
F
.58274 .71 m .58281 .71493 L .58276 .71524 L 0 0 .148 r
F
.58217 .7136 m .58295 .71409 L .58308 .71328 L .673 .758 .914 r
F
.58195 .71651 m .58199 .71944 L .58171 .71669 L .361 .183 .5 r
F
.58164 .72206 m .58206 .72232 L .58227 .72159 L .673 .758 .915 r
F
.59548 .7195 m .62078 .72344 L .5996 .71631 L .673 .758 .914 r
F
.58514 .71942 m .60411 .72005 L .60346 .71614 L .673 .758 .915 r
F
.58203 .72177 m .58184 .72192 L .58171 .71669 L .361 .183 .5 r
F
.5805 .72414 m .58035 .73544 L .58169 .72716 L .673 .758 .915 r
F
.58121 .72227 m .58159 .74213 L .58089 .7224 L .519 .305 .529 r
F
.58054 .72255 m .58159 .74213 L .58057 .74256 L F
.58182 .7167 m .58132 .71764 L .58192 .71677 L .673 .758 .914 r
F
.57874 .71484 m .58083 .71712 L .58182 .7167 L F
.58083 .71712 m .58132 .71764 L .58182 .7167 L F
.58053 .71724 m .58089 .7224 L .58054 .72255 L .519 .305 .529 r
F
.58052 .71193 m .58071 .71717 L .58053 .71724 L F
.58071 .71717 m .58089 .7224 L .58053 .71724 L F
.58083 .72243 m .58089 .72263 L .58096 .72257 L .673 .758 .915 r
F
.58089 .7224 m .58159 .74213 L .58054 .72255 L .519 .305 .529 r
F
.58166 .72208 m .58132 .72296 L .58185 .72219 L .673 .758 .915 r
F
.58 .72263 m .5795 .7227 L .57922 .71744 L .642 .403 .541 r
F
.57906 .72051 m .58083 .72243 L .58166 .72208 L .673 .758 .915 r
F
.58083 .72243 m .58132 .72296 L .58166 .72208 L F
.58627 .7147 m .60273 .71831 L .60379 .71438 L .673 .758 .914 r
F
.58188 .71125 m .58195 .71651 L .58154 .71151 L .361 .183 .5 r
F
.58185 .70836 m .58176 .7136 L .58236 .7087 L .909 .63 .501 r
F
.58171 .71669 m .58184 .72192 L .58167 .71672 L .361 .183 .5 r
F
.58184 .72192 m .58181 .72194 L .58167 .71672 L F
.58199 .71944 m .58203 .72177 L .58171 .71669 L F
.5825 .71593 m .5824 .71608 L .58225 .71098 L .082 0 .419 r
F
.58093 .71197 m .58412 .7236 L .58096 .71194 L .673 .758 .914 r
F
.58188 .71125 m .58226 .71628 L .58195 .71651 L .361 .183 .5 r
F
.58225 .71098 m .58233 .71617 L .58226 .71628 L .082 0 .419 r
F
.57874 .71484 m .58332 .71476 L .58383 .71401 L .673 .758 .914 r
F
.58365 .71396 m .58383 .71401 L .5839 .71392 L F
.57874 .71484 m .58383 .71401 L .58365 .71396 L F
.58275 .7084 m .60334 .70872 L .60269 .70483 L F
.57842 .70918 m .58506 .70905 L .58275 .7084 L F
.58506 .70905 m .60334 .70872 L .58275 .7084 L F
.58126 .67954 m .58019 .67916 L .58024 .70769 L .809 .541 .533 r
F
.5804 .70774 m .58024 .70769 L .58024 .713 L F
.58126 .67954 m .58024 .70769 L .5804 .70774 L F
.58184 .72192 m .5823 .74156 L .58181 .72194 L .361 .183 .5 r
F
.58203 .72177 m .5823 .74156 L .58184 .72192 L F
.58238 .71931 m .58136 .73823 L .58241 .73904 L .909 .63 .501 r
F
.58233 .71617 m .58242 .72137 L .58226 .71628 L .082 0 .419 r
F
.58242 .72137 m .58274 .74089 L .58236 .72146 L F
.58242 .72137 m .58236 .72146 L .58226 .71628 L F
.58132 .72296 m .58934 .7338 L .58721 .72936 L .673 .758 .915 r
F
.58096 .72257 m .58129 .723 L .58132 .72296 L F
.58129 .723 m .58934 .7338 L .58132 .72296 L F
.58237 .714 m .58215 .71916 L .58238 .71931 L .909 .63 .501 r
F
.58226 .71628 m .58236 .72146 L .58227 .72159 L .082 0 .419 r
F
.58215 .71916 m .58136 .73823 L .58238 .71931 L .909 .63 .501 r
F
.58276 .71524 m .58278 .72048 L .58273 .71542 L 0 0 .148 r
F
.58249 .71164 m .59548 .7195 L .58474 .7113 L .673 .758 .914 r
F
.58332 .71476 m .60379 .71438 L .5839 .71392 L F
.5825 .71593 m .58255 .72118 L .5824 .71608 L .082 0 .419 r
F
.58255 .72118 m .58242 .72137 L .58225 .71098 L F
.58109 .71846 m .58587 .7164 L .59227 .70716 L .673 .758 .915 r
F
.58111 .717 m .58121 .72227 L .58087 .7171 L .519 .305 .529 r
F
.58121 .72227 m .58089 .7224 L .58052 .71193 L F
.57906 .72051 m .58174 .71889 L .58109 .71846 L .673 .758 .915 r
F
.58174 .71889 m .58587 .7164 L .58109 .71846 L F
.58523 .712 m .60083 .70687 L .58652 .71014 L .673 .758 .914 r
F
.58308 .71328 m .60314 .71048 L .60083 .70687 L F
.58295 .71409 m .60314 .71048 L .58308 .71328 L F
.58587 .7164 m .59733 .70947 L .59228 .70717 L .673 .758 .915 r
F
.58587 .7164 m .59228 .70717 L .59227 .70716 L F
.58255 .72118 m .58273 .7398 L .58272 .73978 L .082 0 .419 r
F
.5825 .71593 m .58255 .72118 L .58255 .72118 L F
.58255 .72118 m .58273 .7398 L .58255 .72118 L F
.58246 .71068 m .58251 .71592 L .5825 .71593 L F
.58132 .72296 m .58222 .72394 L .58185 .72219 L .673 .758 .915 r
F
.58222 .72394 m .59091 .73338 L .58239 .72286 L F
.58222 .72394 m .58239 .72286 L .58185 .72219 L F
.58276 .71524 m .58281 .71493 L .58282 .72023 L 0 0 .148 r
F
.58278 .72048 m .58282 .72023 L .58285 .74008 L F
.58276 .71524 m .58282 .72023 L .58278 .72048 L F
.5843 .71273 m .5902 .72199 L .59548 .7195 L .673 .758 .914 r
F
.58349 .71475 m .59519 .71722 L .58627 .7147 L F
.5839 .71392 m .60379 .71438 L .60314 .71048 L F
.58587 .7164 m .60115 .71254 L .59733 .70947 L .673 .758 .915 r
F
.58266 .71991 m .58273 .72004 L .58281 .71493 L .984 .727 .338 r
F
.58 .72263 m .58057 .74256 L .5795 .7227 L .642 .403 .541 r
F
.5795 .7227 m .58057 .74256 L .57929 .72274 L F
.58025 .71831 m .57921 .73772 L .58029 .73785 L .734 .478 .541 r
F
.58019 .67916 m .57971 .70765 L .58024 .70769 L F
.57842 .70918 m .58083 .7118 L .58197 .71133 L .673 .758 .914 r
F
.58079 .70785 m .58024 .713 L .5807 .71313 L .809 .541 .533 r
F
.58126 .67954 m .5804 .70774 L .58079 .70785 L F
.5804 .70774 m .58024 .713 L .58079 .70785 L F
.58096 .71194 m .58114 .71258 L .58131 .71232 L .673 .758 .914 r
F
.58131 .70799 m .5807 .71313 L .58132 .7133 L .809 .541 .533 r
F
.58126 .67954 m .58079 .70785 L .58131 .70799 L F
.58079 .70785 m .5807 .71313 L .58131 .70799 L F
.58231 .68035 m .58131 .70799 L .58185 .70836 L .909 .63 .501 r
F
.58231 .68035 m .58185 .70836 L .58236 .7087 L F
.58275 .68139 m .58236 .7087 L .58259 .70917 L .984 .727 .338 r
F
.58275 .68139 m .58259 .70917 L .5828 .70962 L F
.57991 .70767 m .59659 .69819 L .59155 .69589 L .673 .758 .914 r
F
.57842 .70918 m .58081 .70773 L .57991 .70767 L F
.58081 .70773 m .59659 .69819 L .57991 .70767 L F
.58019 .67916 m .57911 .67903 L .57915 .70761 L .734 .478 .541 r
F
.57985 .71734 m .58 .72263 L .57922 .71744 L .642 .403 .541 r
F
.57906 .72051 m .57895 .72279 L .57991 .72264 L .673 .758 .915 r
F
.57895 .72279 m .57875 .72666 L .57991 .72264 L F
.57922 .71744 m .5795 .7227 L .57895 .71748 L .642 .403 .541 r
F
.57842 .70918 m .57956 .71208 L .5809 .71188 L .673 .758 .914 r
F
.57842 .70918 m .60039 .70124 L .59659 .69819 L F
.57842 .70918 m .60269 .70483 L .60039 .70124 L F
.58176 .7136 m .58218 .71388 L .58236 .7087 L .909 .63 .501 r
F
.58274 .71 m .5828 .70962 L .58281 .71493 L 0 0 .148 r
F
.58054 .71302 m .59701 .7038 L .59194 .70149 L .673 .758 .914 r
F
.57874 .71484 m .58162 .7131 L .58054 .71302 L F
.58236 .7087 m .58218 .71388 L .58237 .714 L .909 .63 .501 r
F
.58246 .71068 m .5825 .71593 L .58225 .71098 L .082 0 .419 r
F
.58259 .70917 m .58236 .7087 L .58237 .714 L .984 .727 .338 r
F
.58195 .71651 m .58167 .71672 L .58154 .71151 L .361 .183 .5 r
F
.58101 .71173 m .58155 .71682 L .58111 .717 L .519 .305 .529 r
F
.58154 .71151 m .58167 .71672 L .58155 .71682 L .361 .183 .5 r
F
.57874 .71484 m .58497 .71574 L .58349 .71475 L .673 .758 .914 r
F
.58101 .71173 m .58154 .71151 L .58155 .71682 L .519 .305 .529 r
F
.57874 .71484 m .58249 .7161 L .58314 .71562 L .673 .758 .914 r
F
.58307 .71547 m .58314 .71562 L .58329 .7155 L F
.57874 .71484 m .58314 .71562 L .58307 .71547 L F
.58251 .71592 m .58256 .72117 L .5825 .71593 L .082 0 .419 r
F
.58256 .7144 m .58238 .71931 L .58252 .71962 L .984 .727 .338 r
F
.58259 .70917 m .58248 .71424 L .58256 .7144 L F
.58248 .71424 m .58238 .71931 L .58256 .7144 L F
.58248 .71424 m .58237 .714 L .58238 .71931 L F
.58259 .70917 m .58237 .714 L .58248 .71424 L F
.58185 .70836 m .58131 .70799 L .58132 .7133 L .909 .63 .501 r
F
.58162 .7131 m .58186 .71295 L .58054 .71302 L .673 .758 .914 r
F
.58186 .71295 m .59701 .7038 L .58161 .71242 L F
.58186 .71295 m .58161 .71242 L .58054 .71302 L F
.57971 .70765 m .57915 .70761 L .57916 .71292 L .734 .478 .541 r
F
.57962 .71295 m .57916 .71292 L .57921 .73772 L F
.57971 .70765 m .57916 .71292 L .57962 .71295 L F
.58019 .67916 m .57915 .70761 L .57971 .70765 L F
.57915 .70761 m .57811 .73781 L .57921 .73772 L .66 .418 .542 r
F
.57911 .67903 m .57862 .70767 L .57915 .70761 L F
.57842 .70918 m .57918 .70761 L .5785 .70756 L .673 .758 .914 r
F
.57842 .70918 m .57827 .71209 L .57963 .71225 L F
.57862 .70767 m .57844 .71831 L .57915 .70761 L .66 .418 .542 r
F
.57915 .70761 m .57928 .70742 L .5785 .70756 L .673 .758 .914 r
F
.57918 .70761 m .57918 .70761 L .57915 .70761 L F
.57918 .70761 m .57928 .70742 L .57915 .70761 L F
.57928 .70742 m .57867 .70725 L .5785 .70756 L F
.57911 .67903 m .57806 .70773 L .57862 .70767 L .66 .418 .542 r
F
.5785 .70756 m .57867 .70725 L .57852 .7072 L .673 .758 .914 r
F
.57692 .67946 m .57584 .70881 L .57642 .70843 L .404 .216 .509 r
F
.57842 .70918 m .57919 .6941 L .57271 .69473 L .673 .758 .914 r
F
.57803 .71304 m .57952 .69969 L .573 .70033 L F
.57862 .70767 m .57807 .71304 L .57835 .71301 L .66 .418 .542 r
F
.57842 .70918 m .59155 .69589 L .58562 .69449 L .673 .758 .914 r
F
.57884 .71295 m .57952 .69969 L .57803 .71304 L F
.57835 .71301 m .57807 .71304 L .57808 .71834 L .66 .418 .542 r
F
.57874 .71484 m .57723 .7132 L .57666 .71358 L .673 .758 .914 r
F
.57642 .70843 m .57584 .70881 L .57585 .71412 L .404 .216 .509 r
F
.57642 .70843 m .57585 .71412 L .57614 .71393 L F
.57807 .71304 m .57785 .71842 L .57808 .71834 L .569 .345 .536 r
F
.5782 .71833 m .57984 .70536 L .57333 .706 L .673 .758 .915 r
F
.57906 .72051 m .57918 .71823 L .5782 .71833 L F
.57844 .71831 m .57879 .71827 L .57897 .71294 L .66 .418 .542 r
F
.5788 .71296 m .57897 .71294 L .57915 .70761 L F
.57844 .71831 m .57897 .71294 L .5788 .71296 L F
.57971 .71286 m .59194 .70149 L .58598 .70009 L .673 .758 .914 r
F
.57971 .70765 m .57962 .71295 L .58024 .70769 L .734 .478 .541 r
F
.57874 .71484 m .58054 .71302 L .57966 .71296 L .673 .758 .914 r
F
.57962 .71295 m .57953 .71825 L .57988 .71297 L .734 .478 .541 r
F
.57962 .71295 m .57988 .71297 L .58024 .70769 L F
.58024 .70769 m .57953 .71825 L .58025 .71831 L F
.57966 .71296 m .58081 .71274 L .57971 .71286 L .673 .758 .914 r
F
.58054 .71302 m .58081 .71274 L .57966 .71296 L F
.58185 .70836 m .58132 .7133 L .58176 .7136 L .909 .63 .501 r
F
.58081 .71274 m .59194 .70149 L .57971 .71286 L .673 .758 .914 r
F
.57928 .70742 m .58562 .69449 L .57867 .70725 L F
.57867 .70725 m .58562 .69449 L .57852 .7072 L F
.57874 .71484 m .58598 .70009 L .57952 .69969 L F
.57918 .71823 m .57984 .70536 L .5782 .71833 L .673 .758 .915 r
F
.57844 .71831 m .57811 .73781 L .57879 .71827 L .66 .418 .542 r
F
.57852 .7072 m .58562 .69449 L .57919 .6941 L .673 .758 .914 r
F
.57906 .72051 m .57997 .72279 L .58083 .72243 L .673 .758 .915 r
F
.57953 .71825 m .57921 .73772 L .58025 .71831 L .734 .478 .541 r
F
.57906 .72051 m .58434 .7186 L .58434 .7186 L .673 .758 .915 r
F
.58244 .71847 m .58434 .7186 L .58587 .7164 L F
.58176 .7136 m .58168 .71884 L .58218 .71388 L .909 .63 .501 r
F
.58168 .71884 m .58136 .73823 L .58201 .71907 L F
.58168 .71884 m .58201 .71907 L .58218 .71388 L F
.58174 .71889 m .58434 .7186 L .58244 .71847 L .673 .758 .915 r
F
.57906 .72051 m .58238 .71931 L .58174 .71889 L F
.58238 .71931 m .58434 .7186 L .58174 .71889 L F
.58497 .71574 m .59519 .71722 L .58349 .71475 L .673 .758 .914 r
F
.59519 .71722 m .60273 .71831 L .58627 .7147 L F
.58634 .71699 m .5902 .72199 L .5843 .71273 L F
.58434 .7186 m .60115 .71254 L .58587 .7164 L .673 .758 .915 r
F
.58256 .72117 m .58273 .7398 L .58255 .72118 L .082 0 .419 r
F
.58256 .72117 m .58255 .72118 L .5825 .71593 L F
.58652 .71014 m .60083 .70687 L .59701 .7038 L .673 .758 .914 r
F
.5813 .71329 m .58523 .712 L .58652 .71014 L F
.58101 .71173 m .58111 .717 L .58052 .71193 L .519 .305 .529 r
F
.57874 .71484 m .58191 .7137 L .5813 .71329 L .673 .758 .914 r
F
.5828 .70962 m .58273 .71476 L .58281 .71493 L .984 .727 .338 r
F
.58191 .7137 m .60083 .70687 L .5813 .71329 L .673 .758 .914 r
F
.58218 .71388 m .58201 .71907 L .58237 .714 L .909 .63 .501 r
F
.57874 .71484 m .58175 .71666 L .58249 .7161 L .673 .758 .914 r
F
.58132 .7133 m .58061 .71841 L .58132 .71861 L .809 .541 .533 r
F
.58229 .71384 m .58295 .71409 L .58217 .7136 L .673 .758 .914 r
F
.58259 .71415 m .58295 .71409 L .58191 .7137 L F
.58032 .71794 m .59227 .70716 L .5863 .70576 L .673 .758 .915 r
F
.57906 .72051 m .58109 .71846 L .58032 .71794 L F
.58329 .7155 m .58291 .71625 L .58434 .71565 L .673 .758 .914 r
F
.58249 .7161 m .58291 .71625 L .58329 .7155 L F
.58273 .71476 m .58266 .71991 L .58281 .71493 L .984 .727 .338 r
F
.58109 .71846 m .59227 .70716 L .58032 .71794 L .673 .758 .915 r
F
.58201 .71907 m .58136 .73823 L .58215 .71916 L .909 .63 .501 r
F
.58201 .71907 m .58215 .71916 L .58237 .714 L F
.5807 .71313 m .58024 .713 L .58029 .73785 L .809 .541 .533 r
F
.57874 .71484 m .58259 .71415 L .58191 .7137 L .673 .758 .914 r
F
.5807 .71313 m .58061 .71841 L .58132 .7133 L .809 .541 .533 r
F
.58796 .7173 m .60346 .71614 L .60115 .71254 L .673 .758 .915 r
F
.57906 .72051 m .58514 .71942 L .58796 .7173 L F
.58291 .71625 m .60004 .72201 L .58434 .71565 L .673 .758 .914 r
F
.58514 .71942 m .60346 .71614 L .58796 .7173 L .673 .758 .915 r
F
.58132 .71861 m .58029 .73785 L .58136 .73823 L .809 .541 .533 r
F
.57906 .72051 m .58164 .72206 L .58227 .72159 L .673 .758 .915 r
F
.58061 .71841 m .58029 .73785 L .58132 .71861 L .809 .541 .533 r
F
.57906 .72051 m .58382 .72042 L .58489 .71962 L .673 .758 .915 r
F
.58456 .71952 m .58489 .71962 L .58514 .71942 L F
.57906 .72051 m .58489 .71962 L .58456 .71952 L F
.58382 .72042 m .60411 .72005 L .58514 .71942 L F
.58191 .7137 m .58229 .71384 L .58217 .7136 L .673 .758 .914 r
F
.58176 .7136 m .58132 .7133 L .58136 .73823 L .909 .63 .501 r
F
.58278 .72048 m .58285 .74008 L .58274 .72071 L 0 0 .148 r
F
.58227 .72159 m .58274 .74089 L .5823 .74156 L .082 0 .419 r
F
.58236 .72146 m .58274 .74089 L .58227 .72159 L F
.58252 .71962 m .58238 .71931 L .58241 .73904 L .984 .727 .338 r
F
.58721 .72936 m .58934 .7338 L .59091 .73338 L .673 .758 .915 r
F
.58266 .71991 m .58241 .73904 L .58273 .72004 L .984 .727 .338 r
F
.5837 .72207 m .58371 .72208 L .58372 .72208 L .673 .758 .915 r
F
.58227 .72159 m .58371 .72208 L .5837 .72207 L F
.58206 .72232 m .59622 .73088 L .58372 .72208 L F
.57844 .71831 m .57808 .71834 L .57811 .73781 L .66 .418 .542 r
F
.57666 .71358 m .56688 .70195 L .56157 .70446 L .673 .758 .914 r
F
.57558 .70926 m .57531 .70975 L .57532 .71505 L 0 0 .381 r
F
.57723 .7132 m .56688 .70195 L .57666 .71358 L .673 .758 .914 r
F
.57614 .71393 m .57585 .71412 L .57586 .71942 L .404 .216 .509 r
F
.5773 .71859 m .57333 .706 L .5672 .70762 L .673 .758 .915 r
F
.57819 .71831 m .57333 .706 L .5773 .71859 L F
.5773 .71859 m .57723 .71852 L .57698 .71868 L F
.5773 .71859 m .57698 .71868 L .57653 .71898 L F
.57723 .71852 m .5672 .70762 L .57653 .71898 L F
.57653 .71898 m .57636 .71888 L .57585 .71943 L F
.57554 .71466 m .57533 .72036 L .5755 .72005 L 0 0 .381 r
F
.57259 .71395 m .55474 .71137 L .57386 .71493 L .673 .758 .914 r
F
.57636 .71888 m .56189 .71012 L .57524 .71922 L .673 .758 .915 r
F
.57808 .71834 m .57701 .73815 L .57811 .73781 L .569 .345 .536 r
F
.57785 .71842 m .57701 .73815 L .57808 .71834 L F
.57462 .71987 m .55775 .71334 L .55506 .71703 L .673 .758 .915 r
F
.57397 .71879 m .55775 .71334 L .57462 .71987 L F
.57536 .72085 m .57538 .72109 L .57541 .74075 L .779 .622 .059 r
F
.5755 .72005 m .57533 .72036 L .57536 .73994 L 0 0 .381 r
F
.56049 .72587 m .55237 .7415 L .56555 .72818 L .673 .758 .914 r
F
.57326 .72402 m .55699 .72847 L .56081 .73153 L .673 .758 .915 r
F
.57631 .72217 m .57385 .72298 L .57326 .72402 L F
.57385 .72298 m .55699 .72847 L .57326 .72402 L F
.57623 .71918 m .57586 .71942 L .57589 .73892 L .404 .216 .509 r
F
.57558 .71613 m .57578 .74144 L .57543 .71589 L .988 .72 .386 r
F
.57554 .71466 m .57536 .73994 L .57576 .71428 L 0 0 .381 r
F
.57314 .7189 m .56049 .72587 L .57101 .72266 L .673 .758 .914 r
F
.57426 .72224 m .55467 .72487 L .55699 .72847 L .673 .758 .915 r
F
.5713 .7219 m .55467 .72487 L .57426 .72224 L F
.57563 .7215 m .57575 .7217 L .57578 .74144 L .988 .72 .386 r
F
.57586 .71942 m .57536 .73994 L .57589 .73892 L 0 0 .381 r
F
.57567 .71975 m .57536 .73994 L .57586 .71942 L F
.56936 .73088 m .56587 .73384 L .56747 .73422 L .673 .758 .915 r
F
.56936 .73088 m .56747 .73422 L .57183 .73524 L F
.5827 .72097 m .58285 .74008 L .58274 .74089 L 0 0 .148 r
F
.58274 .72071 m .58285 .74008 L .5827 .72097 L F
.58281 .71493 m .58241 .73904 L .58285 .74008 L .984 .727 .338 r
F
.71678 .62329 m .69873 .64071 L .72155 .6277 L .654 .726 .902 r
F
.71678 .62329 m .6892 .63189 L .69873 .64071 L F
.7658 .63002 m .7872 .64534 L .79757 .63756 L F
.75916 .63286 m .7872 .64534 L .7658 .63002 L F
.71484 .60373 m .69027 .61728 L .71771 .60871 L F
.71484 .60373 m .68452 .60733 L .69027 .61728 L F
.127 .923 .03 r
.69093 .60656 m
.6913 .59623 L
s
.44925 .8584 m .47107 .85476 L .45322 .85285 L .683 .77 .917 r
F
.43338 .85372 m .44925 .8584 L .45322 .85285 L F
.36694 .75662 m .3543 .76056 L .35461 .76622 L .389 .236 .549 r
F
.36694 .75662 m .36664 .75096 L .3543 .76056 L F
0 g
.34634 .77161 m
.3543 .76056 L
s
.127 .923 .03 r
.35576 .74618 m
.35579 .75142 L
s
.74641 .60357 m .74417 .6201 L .74494 .62007 L .654 .726 .902 r
F
.74723 .60584 m .74494 .62007 L .75226 .61984 L F
.74641 .60357 m .74494 .62007 L .74723 .60584 L F
.74788 .58816 m .748 .58735 L .74807 .60057 L 0 0 .158 r
F
.74765 .60319 m .75226 .61984 L .75608 .61904 L .654 .726 .902 r
F
.75099 .6073 m .75608 .61904 L .75987 .61824 L F
.74765 .60319 m .75608 .61904 L .75099 .6073 L F
.74744 .58884 m .74788 .58816 L .74795 .60134 L .088 0 .422 r
F
.74789 .60208 m .75987 .61824 L .76648 .61541 L .654 .726 .902 r
F
.74635 .60282 m .74654 .60337 L .74696 .60276 L F
.74615 .60283 m .74618 .60294 L .74635 .60282 L F
.74618 .60294 m .75226 .61984 L .74635 .60282 L F
.74571 .58984 m .74673 .58941 L .7468 .60249 L .519 .306 .53 r
F
.74611 .60274 m .74615 .60283 L .74702 .60241 L .654 .726 .902 r
F
.74618 .60294 m .74605 .60409 L .74641 .60357 L F
.74615 .60283 m .74613 .60297 L .74618 .60294 L F
.74702 .60241 m .75099 .6073 L .74789 .60208 L F
.75099 .6073 m .75987 .61824 L .74991 .6048 L F
.75099 .6073 m .74991 .6048 L .74789 .60208 L F
.74744 .58884 m .74795 .60134 L .74761 .60183 L .088 0 .422 r
F
.748 .58735 m .74756 .58631 L .74763 .59956 L .982 .725 .331 r
F
.74757 .60371 m .75226 .61984 L .74765 .60319 L .654 .726 .902 r
F
.74709 .60396 m .74846 .60491 L .74753 .60328 L .675 .735 .895 r
F
.74517 .60014 m .76648 .61541 L .76719 .61487 L .654 .726 .902 r
F
.75228 .6032 m .76719 .61487 L .77163 .61153 L F
.74517 .60014 m .76719 .61487 L .75228 .6032 L F
.74795 .60265 m .7495 .60406 L .75017 .60307 L .675 .735 .895 r
F
.74601 .60278 m .7468 .60249 L .74681 .60386 L .519 .306 .53 r
F
.74562 .60596 m .75008 .60915 L .74714 .60556 L .675 .735 .895 r
F
.74601 .60278 m .74681 .60386 L .74617 .60413 L .519 .306 .53 r
F
.7442 .60196 m .74714 .60556 L .74846 .60491 L .675 .735 .895 r
F
.74366 .61726 m .74847 .61402 L .74855 .61686 L .666 .426 .548 r
F
.74913 .6195 m .74493 .62743 L .75191 .6272 L .654 .726 .902 r
F
.7444 .61965 m .74855 .61686 L .74862 .61952 L .666 .426 .548 r
F
.7471 .61386 m .74618 .6196 L .74913 .6195 L .654 .726 .902 r
F
.74618 .6196 m .74493 .62743 L .74913 .6195 L F
.74366 .61726 m .74359 .61442 L .74847 .61402 L .666 .426 .548 r
F
.74387 .61311 m .74855 .61686 L .74712 .61284 L .675 .735 .895 r
F
.74611 .61109 m .74549 .61962 L .7471 .61386 L .654 .726 .902 r
F
.74549 .61962 m .74493 .62743 L .74618 .6196 L F
.7444 .61965 m .74366 .61726 L .74855 .61686 L .666 .426 .548 r
F
.74549 .61962 m .74618 .6196 L .7471 .61386 L .654 .726 .902 r
F
.74158 .58931 m .74256 .58979 L .74263 .60271 L .845 .571 .524 r
F
.74056 .58803 m .74093 .58872 L .741 .60163 L .988 .719 .38 r
F
.74476 .60847 m .7413 .6127 L .74417 .6201 L .654 .726 .902 r
F
.7413 .6127 m .73615 .619 L .7417 .61976 L F
.7413 .6127 m .7417 .61976 L .74417 .6201 L F
.74052 .58722 m .74056 .58803 L .74063 .60096 L .769 .613 .047 r
F
.74386 .60684 m .7412 .61102 L .74476 .60847 L .654 .726 .902 r
F
.7412 .61102 m .73615 .619 L .7413 .6127 L F
.7412 .61102 m .7413 .6127 L .74476 .60847 L F
.74447 .60475 m .74356 .60631 L .74492 .60516 L F
.74356 .60631 m .73615 .619 L .74386 .60684 L F
.74356 .60631 m .74386 .60684 L .74492 .60516 L F
.74471 .60373 m .74425 .60455 L .74499 .60387 L F
.74425 .60455 m .73615 .619 L .74447 .60475 L F
.74425 .60455 m .74447 .60475 L .74499 .60387 L F
.74383 .60294 m .74369 .60323 L .74502 .60317 L F
.74369 .60323 m .73615 .619 L .74471 .60373 L F
.74369 .60323 m .74471 .60373 L .74502 .60317 L F
.74056 .58803 m .74071 .60111 L .74063 .60096 L .988 .719 .38 r
F
.74052 .58722 m .74059 .60036 L .74058 .60018 L .769 .613 .047 r
F
.74052 .58722 m .74063 .60096 L .74059 .60036 L F
.74105 .58619 m .74052 .58722 L .74058 .60018 L 0 0 .386 r
F
.74383 .60294 m .73408 .61177 L .73615 .619 L .654 .726 .902 r
F
.74262 .6027 m .73474 .61059 L .74383 .60294 L F
.73474 .61059 m .72874 .61661 L .73408 .61177 L F
.73474 .61059 m .73408 .61177 L .74383 .60294 L F
.74517 .60014 m .72246 .6131 L .72874 .61661 L F
.74131 .6038 m .7387 .604 L .73965 .60486 L .675 .735 .895 r
F
.74187 .60233 m .74263 .60271 L .74264 .60428 L .845 .571 .524 r
F
.74373 .61968 m .74366 .61726 L .7444 .61965 L .666 .426 .548 r
F
.74416 .61974 m .73571 .62636 L .74377 .62746 L .654 .726 .902 r
F
.73989 .61915 m .74366 .61726 L .74373 .61968 L .731 .478 .545 r
F
.74441 .61481 m .74102 .61931 L .74416 .61974 L .654 .726 .902 r
F
.74102 .61931 m .73571 .62636 L .74416 .61974 L F
.7389 .61965 m .73989 .61915 L .74374 .6201 L .731 .478 .545 r
F
.73989 .61915 m .74373 .61968 L .74374 .6201 L F
.74058 .60993 m .73877 .61391 L .74359 .61436 L .675 .735 .895 r
F
.73882 .61681 m .73875 .61397 L .74359 .61442 L .731 .478 .545 r
F
.74064 .61281 m .74366 .61726 L .74387 .61311 L .675 .735 .895 r
F
.74271 .61173 m .74107 .61515 L .74441 .61481 L .654 .726 .902 r
F
.73989 .61915 m .73882 .61681 L .74366 .61726 L .731 .478 .545 r
F
.73921 .61906 m .73571 .62636 L .74102 .61931 L .654 .726 .902 r
F
.7389 .61965 m .73888 .61901 L .73989 .61915 L .731 .478 .545 r
F
.73888 .61901 m .73882 .61681 L .73989 .61915 L F
.73882 .61681 m .74359 .61442 L .74366 .61726 L F
.74064 .61281 m .73882 .61681 L .74366 .61726 L .675 .735 .895 r
F
.74107 .61515 m .73921 .61906 L .74129 .61895 L .654 .726 .902 r
F
.73921 .61906 m .74102 .61931 L .74129 .61895 L F
.74107 .61515 m .74129 .61895 L .74441 .61481 L F
.74256 .58979 m .74298 .60277 L .74263 .60271 L .751 .492 .54 r
F
.74158 .58931 m .74187 .60233 L .74165 .60222 L .845 .571 .524 r
F
.74158 .58931 m .74263 .60271 L .74187 .60233 L F
.74517 .60014 m .73425 .60355 L .72246 .6131 L .654 .726 .902 r
F
.73425 .60355 m .71771 .60871 L .72108 .61183 L F
.73425 .60355 m .72108 .61183 L .72246 .6131 L F
.74093 .58872 m .74158 .58931 L .74165 .60222 L .929 .648 .486 r
F
.74093 .58872 m .74165 .60222 L .74114 .60176 L F
.74218 .58541 m .74105 .58619 L .74112 .59922 L .405 .218 .51 r
F
.74143 .60372 m .74121 .60362 L .74131 .6038 L .675 .735 .895 r
F
.73561 .61796 m .73418 .61869 L .73918 .61911 L .654 .726 .902 r
F
.73443 .61838 m .7356 .61796 L .7389 .61965 L .794 .529 .537 r
F
.7356 .61796 m .73882 .61681 L .73888 .61901 L F
.7356 .61796 m .73888 .61901 L .7389 .61965 L F
.73918 .61911 m .73418 .61869 L .73571 .62636 L .654 .726 .902 r
F
.74107 .61515 m .73561 .61796 L .73918 .61911 L F
.74271 .61173 m .74096 .61316 L .74107 .61515 L F
.73435 .61554 m .73875 .61397 L .73882 .61681 L .794 .529 .537 r
F
.73766 .61196 m .73882 .61681 L .74064 .61281 L .675 .735 .895 r
F
.74096 .61316 m .73418 .61869 L .74107 .61515 L .654 .726 .902 r
F
.74067 .60327 m .73813 .603 L .7387 .604 L .675 .735 .895 r
F
.74058 .60993 m .74359 .61436 L .74379 .61023 L F
.74246 .60881 m .74064 .61281 L .74387 .61311 L F
.74248 .61131 m .74093 .61269 L .74271 .61173 L .654 .726 .902 r
F
.74093 .61269 m .73418 .61869 L .74096 .61316 L F
.74093 .61269 m .74096 .61316 L .74271 .61173 L F
.74096 .60316 m .7387 .604 L .74131 .6038 L .675 .735 .895 r
F
.73989 .60399 m .73895 .6027 L .73828 .6037 L F
.74076 .60559 m .74073 .60553 L .74063 .60096 L .988 .719 .38 r
F
.74091 .60552 m .74058 .60993 L .74239 .60594 L .675 .735 .895 r
F
.7418 .60748 m .7397 .60772 L .74097 .60838 L F
.74165 .60721 m .7397 .60772 L .7418 .60748 L F
.74076 .60559 m .74104 .60867 L .74079 .60823 L .988 .719 .38 r
F
.74175 .60461 m .73965 .60486 L .74091 .60552 L .675 .735 .895 r
F
.74187 .60233 m .74264 .60428 L .7419 .60394 L .845 .571 .524 r
F
.7442 .60196 m .74131 .6038 L .74175 .60461 L .675 .735 .895 r
F
.74131 .6038 m .73965 .60486 L .74175 .60461 L F
.74073 .60274 m .74091 .60587 L .74076 .60559 L .988 .719 .38 r
F
.74071 .60111 m .74078 .60285 L .74073 .60274 L F
.74078 .60285 m .74091 .60587 L .74073 .60274 L F
.74091 .60552 m .73762 .60908 L .74058 .60993 L .675 .735 .895 r
F
.74156 .60654 m .73875 .60685 L .7397 .60772 L F
.74091 .60587 m .74104 .60867 L .74076 .60559 L .988 .719 .38 r
F
.74239 .60594 m .74058 .60993 L .74379 .61023 L .675 .735 .895 r
F
.74218 .60708 m .74165 .60721 L .7418 .60748 L F
.74323 .61064 m .74248 .61131 L .74271 .61173 L .654 .726 .902 r
F
.74122 .60623 m .74167 .60664 L .74169 .60926 L .929 .648 .486 r
F
.73504 .61717 m .72195 .62043 L .72827 .62396 L .654 .726 .902 r
F
.73762 .60908 m .73433 .61264 L .73877 .61391 L .675 .735 .895 r
F
.73435 .61554 m .73428 .6127 L .73875 .61397 L .794 .529 .537 r
F
.73766 .61196 m .73435 .61554 L .73882 .61681 L .675 .735 .895 r
F
.74234 .60985 m .73783 .61219 L .73504 .61717 L .654 .726 .902 r
F
.73408 .61177 m .73097 .61733 L .73615 .619 L F
.73105 .61571 m .72195 .62043 L .7341 .61741 L F
.73063 .61638 m .73179 .61612 L .73443 .61838 L .861 .585 .519 r
F
.73179 .61612 m .73435 .61554 L .73441 .61758 L F
.73179 .61612 m .73441 .61758 L .73443 .61838 L F
.73513 .61063 m .73435 .61554 L .73766 .61196 L .675 .735 .895 r
F
.73783 .61219 m .73105 .61571 L .73504 .61717 L .654 .726 .902 r
F
.73105 .61571 m .7341 .61741 L .73504 .61717 L F
.74071 .60111 m .74073 .60274 L .74063 .60096 L .988 .719 .38 r
F
.74073 .60274 m .74076 .60559 L .74068 .60265 L F
.74073 .60274 m .74068 .60265 L .74063 .60096 L F
.74063 .60257 m .73797 .60193 L .73813 .603 L .675 .735 .895 r
F
.74093 .58872 m .74114 .60176 L .741 .60163 L .929 .648 .486 r
F
.74056 .58803 m .741 .60163 L .74071 .60111 L .988 .719 .38 r
F
.74256 .58979 m .74419 .60301 L .74298 .60277 L .751 .492 .54 r
F
.73425 .60355 m .71484 .60373 L .71771 .60871 L .654 .726 .902 r
F
.74517 .60014 m .73839 .60094 L .73425 .60355 L F
.73839 .60094 m .71484 .60373 L .73425 .60355 L F
.7423 .6098 m .72195 .62043 L .74234 .60985 L F
.73408 .61177 m .72874 .61661 L .73097 .61733 L F
.73762 .60908 m .73877 .61391 L .74058 .60993 L .675 .735 .895 r
F
.73179 .61612 m .73056 .61354 L .73435 .61554 L .861 .585 .519 r
F
.73063 .61638 m .73061 .61546 L .73179 .61612 L F
.73061 .61546 m .73056 .61354 L .73179 .61612 L F
.74097 .60838 m .74064 .61281 L .74246 .60881 L .675 .735 .895 r
F
.74097 .60838 m .73766 .61196 L .74064 .61281 L F
.74119 .60946 m .73064 .61547 L .7423 .6098 L .654 .726 .902 r
F
.73064 .61547 m .72195 .62043 L .73102 .61569 L F
.73064 .61547 m .73102 .61569 L .7423 .6098 L F
.74211 .60963 m .7423 .6098 L .74248 .60971 L F
.74119 .60946 m .7423 .6098 L .74211 .60963 L F
.74114 .60176 m .74126 .60887 L .741 .60163 L .929 .648 .486 r
F
.73504 .61717 m .73475 .61769 L .74323 .61064 L .654 .726 .902 r
F
.73475 .61769 m .73418 .61869 L .73517 .61782 L F
.7356 .61796 m .73435 .61554 L .73882 .61681 L .794 .529 .537 r
F
.73475 .61769 m .73517 .61782 L .74323 .61064 L .654 .726 .902 r
F
.73443 .61838 m .73441 .61758 L .7356 .61796 L .794 .529 .537 r
F
.73441 .61758 m .73435 .61554 L .7356 .61796 L F
.74185 .61036 m .73978 .61056 L .74104 .61123 L .675 .735 .895 r
F
.74246 .60881 m .74387 .61311 L .74407 .60896 L F
.74265 .60709 m .74277 .60976 L .74267 .60974 L .751 .492 .54 r
F
.74406 .62115 m .73532 .63362 L .74338 .63473 L .654 .726 .902 r
F
.74338 .61991 m .73532 .63362 L .74406 .62115 L F
.74072 .61565 m .7389 .61965 L .74374 .6201 L .675 .735 .895 r
F
.74305 .61748 m .74108 .62159 L .7442 .61851 L .654 .726 .902 r
F
.74108 .62159 m .73532 .63362 L .74119 .62363 L F
.74108 .62159 m .74119 .62363 L .7442 .61851 L F
.74234 .60985 m .74192 .61028 L .74323 .61064 L F
.74192 .61028 m .73504 .61717 L .74246 .61126 L F
.74192 .61028 m .74246 .61126 L .74323 .61064 L F
.7442 .60196 m .74091 .60552 L .74239 .60594 L .675 .735 .895 r
F
.7419 .60394 m .74264 .60428 L .74265 .60709 L .845 .571 .524 r
F
.74239 .60594 m .74379 .61023 L .744 .60609 L .675 .735 .895 r
F
.74428 .6048 m .74156 .60654 L .74167 .60664 L F
.74221 .60689 m .74167 .60664 L .74209 .60701 L F
.74264 .60428 m .7428 .60711 L .74265 .60709 L .751 .492 .54 r
F
.74263 .60271 m .74269 .60429 L .74264 .60428 L F
.74269 .60429 m .7428 .60711 L .74264 .60428 L F
.74408 .6045 m .74239 .60594 L .744 .60609 L .675 .735 .895 r
F
.74311 .60435 m .74239 .60594 L .74408 .6045 L F
.74374 .6201 m .74373 .61968 L .7444 .61965 L .666 .426 .548 r
F
.74374 .6201 m .7444 .61965 L .74862 .6197 L F
.7444 .61965 m .74862 .61952 L .74862 .6197 L F
.74611 .61109 m .74377 .62746 L .74493 .62743 L .654 .726 .902 r
F
.74394 .61595 m .74374 .6201 L .74862 .6197 L .675 .735 .895 r
F
.7442 .61851 m .74338 .61991 L .74406 .62115 L .654 .726 .902 r
F
.74379 .61023 m .74359 .61436 L .74845 .61396 L .675 .735 .895 r
F
.74503 .60293 m .74417 .6201 L .74615 .60283 L .654 .726 .902 r
F
.74407 .60896 m .74387 .61311 L .74712 .61284 L .675 .735 .895 r
F
.74465 .61012 m .74271 .61173 L .74441 .61481 L .654 .726 .902 r
F
.74581 .61862 m .74338 .63473 L .74493 .63468 L F
.74698 .62188 m .74493 .63468 L .75151 .63447 L F
.74581 .61862 m .74493 .63468 L .74698 .62188 L F
.74761 .60183 m .74765 .60177 L .74765 .60191 L .088 0 .422 r
F
.74765 .60177 m .74795 .60134 L .74765 .60191 L F
.74765 .60191 m .74795 .60134 L .74795 .60262 L F
.74761 .60183 m .74795 .60262 L .74768 .60304 L F
.74815 .60198 m .75017 .60307 L .75043 .602 L .675 .735 .895 r
F
.74571 .58984 m .7468 .60249 L .74601 .60278 L .519 .306 .53 r
F
.74517 .60014 m .74702 .60241 L .74789 .60208 L .654 .726 .902 r
F
.74673 .58941 m .74696 .60237 L .7468 .60249 L .362 .185 .501 r
F
.7442 .60196 m .74848 .60275 L .74815 .60198 L .675 .735 .895 r
F
.74848 .60275 m .75017 .60307 L .74815 .60198 L F
.74673 .58941 m .74744 .58884 L .74751 .60197 L .362 .185 .501 r
F
.74673 .58941 m .74751 .60197 L .74696 .60237 L F
.74788 .58816 m .74807 .60057 L .74798 .60116 L 0 0 .158 r
F
.74788 .58816 m .74798 .60116 L .74795 .60134 L F
.74744 .58884 m .74761 .60183 L .74751 .60197 L .088 0 .422 r
F
.74795 .59981 m .77632 .60177 L .77552 .59654 L .654 .726 .902 r
F
.74517 .60014 m .7486 .60032 L .74795 .59981 L F
.7486 .60032 m .77632 .60177 L .74795 .59981 L F
.74756 .58631 m .74652 .58549 L .74659 .59874 L .91 .629 .499 r
F
.74691 .60663 m .74697 .60696 L .74711 .60676 L .675 .735 .895 r
F
.74696 .60276 m .75226 .61984 L .74728 .60273 L .654 .726 .902 r
F
.74654 .60337 m .75226 .61984 L .74696 .60276 L F
.74562 .60596 m .74703 .60996 L .75008 .60915 L .675 .735 .895 r
F
.74697 .60696 m .74723 .60842 L .74711 .60676 L F
.74607 .60699 m .74723 .60842 L .74691 .60663 L F
.7465 .60681 m .74682 .60667 L .74684 .60952 L .519 .306 .53 r
F
.74689 .60382 m .74709 .60396 L .74728 .60365 L .675 .735 .895 r
F
.74689 .60382 m .74728 .60365 L .74752 .60329 L F
.74696 .60237 m .74752 .60329 L .74698 .60372 L .362 .185 .501 r
F
.74728 .60273 m .74757 .60371 L .74765 .60319 L .654 .726 .902 r
F
.74742 .60337 m .74752 .60329 L .74753 .60328 L .675 .735 .895 r
F
.74689 .60382 m .74752 .60329 L .74742 .60337 L F
.74696 .60237 m .74751 .60197 L .74752 .60329 L .362 .185 .501 r
F
.74703 .60996 m .74845 .61396 L .75302 .61275 L .675 .735 .895 r
F
.7457 .60882 m .74712 .61284 L .75019 .61203 L F
.74731 .61126 m .75292 .61357 L .74864 .61061 L F
.74687 .60998 m .75173 .61596 L .74737 .60926 L .654 .726 .902 r
F
.74855 .61686 m .75306 .6128 L .75314 .61564 L .593 .369 .545 r
F
.75173 .61596 m .75955 .62559 L .75085 .61392 L .654 .726 .902 r
F
.74712 .61284 m .75314 .61564 L .75019 .61203 L .675 .735 .895 r
F
.74578 .6088 m .75019 .61203 L .74723 .60842 L F
.74492 .60516 m .74386 .60684 L .74476 .60847 L .654 .726 .902 r
F
.74605 .60409 m .74417 .6201 L .74641 .60357 L F
.74613 .60297 m .74417 .6201 L .74618 .60294 L F
.744 .60609 m .74379 .61023 L .74703 .60996 L .675 .735 .895 r
F
.7457 .60882 m .74574 .60886 L .74578 .6088 L F
.74574 .60886 m .75019 .61203 L .74578 .6088 L F
.74793 .60265 m .74783 .6034 L .74795 .60265 L F
.74763 .60312 m .74756 .60323 L .74751 .60197 L .088 0 .422 r
F
.74412 .59005 m .74578 .60287 L .74454 .60298 L .642 .403 .541 r
F
.74517 .60014 m .74383 .60294 L .74502 .60317 L .654 .726 .902 r
F
.74702 .60241 m .74615 .60283 L .74728 .60273 L F
.7442 .60196 m .74753 .60328 L .74793 .60265 L .675 .735 .895 r
F
.74753 .60328 m .74783 .6034 L .74793 .60265 L F
.74761 .60183 m .74763 .60312 L .74751 .60197 L .088 0 .422 r
F
.74763 .60312 m .74766 .6059 L .74756 .60323 L F
.74711 .60676 m .74723 .60842 L .74856 .60777 L .675 .735 .895 r
F
.74783 .6034 m .7495 .60406 L .74795 .60265 L F
.74517 .60014 m .77163 .61153 L .77363 .60876 L .654 .726 .902 r
F
.75848 .60314 m .77363 .60876 L .77499 .60688 L F
.74517 .60014 m .77363 .60876 L .75848 .60314 L F
.74617 .60413 m .74681 .60386 L .74682 .60667 L .519 .306 .53 r
F
.74617 .60413 m .74682 .60667 L .7465 .60681 L F
.74379 .61023 m .74845 .61396 L .74703 .60996 L .675 .735 .895 r
F
.74407 .60896 m .74712 .61284 L .7457 .60882 L F
.74708 .61132 m .75026 .61487 L .74731 .61126 L F
.74611 .61109 m .7471 .61386 L .74694 .61112 L .654 .726 .902 r
F
.7471 .61386 m .74742 .61186 L .74687 .60998 L F
.74578 .61167 m .74868 .61375 L .74708 .61132 L .675 .735 .895 r
F
.74868 .61375 m .75026 .61487 L .74708 .61132 L F
.74691 .60942 m .74731 .61126 L .74864 .61061 L F
.748 .60825 m .74806 .61517 L .74799 .60837 L 0 0 .158 r
F
.74855 .61686 m .74847 .61402 L .75306 .6128 L .593 .369 .545 r
F
.75204 .6188 m .75314 .61564 L .75322 .61849 L F
.7489 .61946 m .75314 .61564 L .75204 .6188 L F
.75193 .61882 m .75191 .6272 L .75621 .6263 L .654 .726 .902 r
F
.7489 .61946 m .74855 .61686 L .75314 .61564 L .593 .369 .545 r
F
.74712 .61284 m .74855 .61686 L .75314 .61564 L .675 .735 .895 r
F
.7512 .61753 m .7496 .61931 L .75193 .61882 L .654 .726 .902 r
F
.74742 .61184 m .7496 .61931 L .7512 .61753 L F
.74862 .6197 m .74862 .61952 L .7489 .61946 L .593 .369 .545 r
F
.74862 .61952 m .74855 .61686 L .7489 .61946 L F
.7496 .61931 m .75191 .6272 L .75193 .61882 L .654 .726 .902 r
F
.74862 .6197 m .7489 .61946 L .75204 .6188 L .593 .369 .545 r
F
.7471 .61386 m .75191 .6272 L .74742 .61186 L .654 .726 .902 r
F
.7472 .61569 m .74862 .6197 L .75204 .6188 L .675 .735 .895 r
F
.75121 .61755 m .75204 .6188 L .75322 .61849 L F
.7472 .61569 m .75204 .6188 L .75121 .61755 L F
.74687 .60998 m .74742 .61184 L .7512 .61753 L .654 .726 .902 r
F
.74956 .61506 m .75322 .61849 L .75026 .61487 L .675 .735 .895 r
F
.7472 .61569 m .75121 .61755 L .74956 .61506 L F
.75121 .61755 m .75322 .61849 L .74956 .61506 L F
.74759 .61086 m .75195 .61867 L .75173 .61596 L .654 .726 .902 r
F
.75195 .61867 m .75202 .6188 L .75202 .61878 L F
.75195 .61867 m .75202 .61878 L .75173 .61596 L F
.75202 .6188 m .75621 .6263 L .75288 .61862 L F
.75202 .6188 m .75288 .61862 L .75173 .61596 L F
.74687 .60998 m .74754 .61114 L .74759 .61086 L F
.74754 .61114 m .75621 .6263 L .74759 .61086 L F
.74783 .6034 m .74846 .60491 L .7495 .60406 L .675 .735 .895 r
F
.74753 .60328 m .74778 .60373 L .74783 .6034 L F
.74778 .60373 m .74846 .60491 L .74783 .6034 L F
.74798 .60116 m .74798 .60242 L .74795 .60134 L 0 0 .158 r
F
.74846 .60491 m .75479 .60615 L .7495 .60406 L .675 .735 .895 r
F
.74817 .60414 m .75054 .60484 L .75038 .60376 L F
.74801 .60519 m .74799 .60527 L .74796 .60257 L 0 0 .158 r
F
.7468 .60249 m .74695 .60939 L .74684 .60948 L .362 .185 .501 r
F
.74766 .6059 m .74757 .60604 L .74751 .60197 L .088 0 .422 r
F
.74768 .60304 m .74795 .60262 L .74799 .60837 L F
.74711 .60676 m .74856 .60777 L .74754 .60609 L .675 .735 .895 r
F
.74714 .60556 m .75008 .60915 L .75273 .60785 L F
.75008 .60915 m .75699 .6108 L .75273 .60785 L F
.74856 .60777 m .75284 .61073 L .75492 .60902 L F
.74835 .60767 m .75035 .60876 L .75062 .60768 L F
.7477 .60879 m .74762 .60891 L .74757 .60604 L .088 0 .422 r
F
.74762 .60891 m .74758 .60896 L .74753 .6061 L F
.74435 .60765 m .74794 .60831 L .74835 .60767 L .675 .735 .895 r
F
.74723 .60842 m .75284 .61073 L .74856 .60777 L F
.74794 .60831 m .75035 .60876 L .74835 .60767 L F
.74435 .60765 m .74968 .60975 L .75035 .60876 L F
.7477 .60868 m .74799 .60837 L .7477 .60879 L .088 0 .422 r
F
.74766 .6059 m .74797 .60826 L .7477 .60868 L F
.74797 .60826 m .74799 .60837 L .7477 .60868 L F
.74761 .60183 m .74783 .60564 L .74766 .6059 L F
.74783 .60564 m .74799 .60837 L .74766 .6059 L F
.74754 .60609 m .74856 .60777 L .7496 .60691 L .675 .735 .895 r
F
.744 .60609 m .74703 .60996 L .74562 .60596 L F
.74703 .60996 m .75302 .61275 L .75008 .60915 L F
.74723 .60842 m .75019 .61203 L .75284 .61073 L F
.74786 .60904 m .74864 .61061 L .74968 .60975 L F
.7461 .60698 m .74683 .60948 L .74617 .60977 L .519 .306 .53 r
F
.74435 .60765 m .74694 .60943 L .74786 .60904 L .675 .735 .895 r
F
.74694 .60943 m .74864 .61061 L .74786 .60904 L F
.74617 .60977 m .74607 .60981 L .7459 .60707 L .519 .306 .53 r
F
.74619 .60976 m .74684 .60948 L .74691 .60942 L .675 .735 .895 r
F
.74619 .60976 m .7463 .60991 L .74684 .60948 L F
.74683 .60948 m .74684 .60952 L .74617 .60977 L .519 .306 .53 r
F
.74478 .6074 m .74658 .60962 L .74737 .60926 L .654 .726 .902 r
F
.7463 .60991 m .74731 .61126 L .74691 .60942 L .675 .735 .895 r
F
.74695 .60939 m .74695 .60944 L .74684 .60948 L .362 .185 .501 r
F
.74695 .60944 m .7471 .6164 L .74684 .60952 L F
.74695 .60944 m .74684 .60952 L .74684 .60948 L F
.74684 .60952 m .74687 .60998 L .74731 .60935 L .654 .726 .902 r
F
.74658 .60962 m .74663 .60968 L .74684 .60952 L F
.74663 .60968 m .74687 .60998 L .74684 .60952 L F
.74912 .60483 m .75027 .60591 L .75054 .60484 L .675 .735 .895 r
F
.74698 .60372 m .74753 .6061 L .74726 .60632 L .362 .185 .501 r
F
.74714 .60556 m .75273 .60785 L .74846 .60491 L .675 .735 .895 r
F
.74908 .60569 m .7496 .60691 L .75027 .60591 L F
.74703 .6065 m .74755 .60901 L .74708 .60935 L .362 .185 .501 r
F
.74603 .60419 m .74562 .60596 L .74714 .60556 L .675 .735 .895 r
F
.74502 .60317 m .74471 .60373 L .74499 .60387 L .654 .726 .902 r
F
.74454 .60298 m .74578 .60287 L .74578 .6043 L .642 .403 .541 r
F
.74506 .6044 m .74513 .60458 L .74578 .6043 L .675 .735 .895 r
F
.74513 .60458 m .74562 .60596 L .74603 .60419 L F
.74499 .60387 m .74447 .60475 L .74492 .60516 L .654 .726 .902 r
F
.7442 .60196 m .744 .60609 L .74562 .60596 L .675 .735 .895 r
F
.74459 .60446 m .7458 .60711 L .74468 .60726 L .642 .403 .541 r
F
.74428 .6048 m .74513 .6072 L .74607 .60699 L .675 .735 .895 r
F
.74513 .6072 m .74519 .60737 L .7458 .60711 L F
.74513 .6072 m .7458 .60711 L .74607 .60699 L F
.74459 .60446 m .74578 .6043 L .7458 .60711 L .642 .403 .541 r
F
.74519 .60737 m .7457 .60882 L .74607 .60699 L .675 .735 .895 r
F
.74513 .6072 m .74407 .60896 L .7457 .60882 L F
.74419 .60301 m .74437 .60731 L .74422 .60733 L .642 .403 .541 r
F
.74415 .60734 m .74407 .60896 L .74513 .6072 L .675 .735 .895 r
F
.74387 .61311 m .74366 .61726 L .74855 .61686 L F
.74547 .61201 m .74377 .62746 L .74611 .61109 L .654 .726 .902 r
F
.74427 .61708 m .74338 .63473 L .74523 .617 L F
.74465 .61001 m .74423 .61004 L .74465 .61012 L F
.74454 .60298 m .74477 .61 L .74419 .60301 L .642 .403 .541 r
F
.74493 .61989 m .74338 .63473 L .74581 .61862 L .654 .726 .902 r
F
.75322 .61849 m .75314 .61564 L .75713 .61369 L .499 .297 .536 r
F
.75314 .61564 m .75306 .6128 L .75705 .61084 L F
.75314 .61564 m .75705 .61084 L .75713 .61369 L F
.75019 .61203 m .75314 .61564 L .75713 .61369 L .675 .735 .895 r
F
.75322 .61849 m .75713 .61369 L .7572 .61653 L .499 .297 .536 r
F
.75026 .61487 m .75322 .61849 L .7572 .61653 L .675 .735 .895 r
F
.75026 .61487 m .7572 .61653 L .75292 .61357 L F
.74948 .61077 m .75955 .62559 L .76619 .62275 L .654 .726 .902 r
F
.75085 .61392 m .75955 .62559 L .74948 .61077 L F
.74901 .61666 m .7658 .63002 L .77099 .62612 L F
.74578 .61167 m .7472 .61569 L .75026 .61487 L .675 .735 .895 r
F
.74684 .60948 m .74701 .61647 L .74688 .61656 L .362 .185 .501 r
F
.74463 .61034 m .74377 .62746 L .7457 .60995 L .654 .726 .902 r
F
.74394 .61595 m .74862 .6197 L .7472 .61569 L .675 .735 .895 r
F
.74439 .61467 m .74737 .61681 L .74901 .61666 L .654 .726 .902 r
F
.74803 .60811 m .74808 .61505 L .748 .60825 L 0 0 .158 r
F
.74607 .60699 m .7457 .60882 L .74723 .60842 L .675 .735 .895 r
F
.74617 .60977 m .7459 .60707 L .74601 .60702 L .519 .306 .53 r
F
.7457 .60995 m .74547 .61201 L .74611 .61109 L .654 .726 .902 r
F
.74415 .6118 m .7472 .61569 L .74578 .61167 L .675 .735 .895 r
F
.74468 .60726 m .74581 .6099 L .74477 .61 L .642 .403 .541 r
F
.74515 .60841 m .74463 .61034 L .7457 .60995 L .654 .726 .902 r
F
.74478 .6074 m .74476 .60783 L .74515 .60841 L F
.74476 .60783 m .74463 .61034 L .74515 .60841 L F
.74477 .61 m .74581 .6099 L .74581 .60992 L .642 .403 .541 r
F
.74515 .60841 m .74611 .61109 L .74652 .61049 L .654 .726 .902 r
F
.74607 .60981 m .74597 .60985 L .74597 .60984 L .519 .306 .53 r
F
.74435 .60765 m .74519 .61001 L .74612 .60988 L .675 .735 .895 r
F
.74607 .60981 m .74597 .60984 L .7459 .60707 L .519 .306 .53 r
F
.74586 .60949 m .74612 .60988 L .74617 .60987 L .675 .735 .895 r
F
.74543 .60901 m .74581 .60949 L .74581 .6099 L .642 .403 .541 r
F
.74468 .60726 m .74581 .60949 L .74543 .60901 L F
.74468 .60726 m .7458 .60711 L .74581 .60949 L F
.74435 .60765 m .74612 .60988 L .74586 .60949 L .675 .735 .895 r
F
.74519 .61001 m .74578 .61167 L .74617 .60987 L F
.74478 .61006 m .74581 .60992 L .74585 .61694 L .642 .403 .541 r
F
.74477 .61 m .74581 .60992 L .74478 .61006 L F
.74611 .61109 m .74694 .61112 L .74652 .61049 L .654 .726 .902 r
F
.74617 .60987 m .74578 .61167 L .74731 .61126 L .675 .735 .895 r
F
.74439 .61467 m .74614 .61683 L .74695 .61651 L .654 .726 .902 r
F
.74614 .61683 m .74628 .617 L .74688 .61656 L F
.74617 .60977 m .74688 .61656 L .74633 .61677 L .519 .306 .53 r
F
.74614 .61683 m .74688 .61656 L .74695 .61651 L .654 .726 .902 r
F
.74585 .61694 m .74704 .64797 L .74602 .6484 L .519 .306 .53 r
F
.74415 .6118 m .74394 .61595 L .7472 .61569 L .675 .735 .895 r
F
.74581 .6099 m .74604 .61687 L .74585 .61694 L .519 .306 .53 r
F
.74604 .61687 m .74704 .64797 L .74585 .61694 L F
.74578 .60287 m .74597 .60984 L .74581 .6099 L F
.74761 .60923 m .76619 .62275 L .76727 .62194 L .654 .726 .902 r
F
.75292 .61357 m .7572 .61653 L .76032 .61397 L .675 .735 .895 r
F
.74743 .6093 m .76619 .62275 L .74761 .60923 L .654 .726 .902 r
F
.7572 .61653 m .75713 .61369 L .76024 .61112 L .363 .193 .513 r
F
.7572 .61653 m .76024 .61112 L .76032 .61397 L F
.75008 .60915 m .75302 .61275 L .75699 .6108 L .675 .735 .895 r
F
.75019 .61203 m .75713 .61369 L .75284 .61073 L F
.75292 .61357 m .76032 .61397 L .755 .61186 L F
.7535 .61116 m .76727 .62194 L .77138 .61885 L .654 .726 .902 r
F
.74864 .61061 m .755 .61186 L .74968 .60975 L .675 .735 .895 r
F
.7479 .60875 m .76727 .62194 L .7535 .61116 L .654 .726 .902 r
F
.7465 .60681 m .74684 .60952 L .7461 .60698 L .519 .306 .53 r
F
.74478 .6074 m .74741 .6091 L .7479 .60875 L .654 .726 .902 r
F
.74864 .61061 m .75292 .61357 L .755 .61186 L .675 .735 .895 r
F
.74741 .6091 m .76727 .62194 L .7479 .60875 L .654 .726 .902 r
F
.74696 .60237 m .74708 .60935 L .7468 .60249 L .362 .185 .501 r
F
.74827 .61555 m .74901 .61666 L .75202 .6164 L .654 .726 .902 r
F
.74439 .61467 m .74758 .61605 L .74827 .61555 L F
.74758 .61605 m .74901 .61666 L .74827 .61555 L F
.74684 .60952 m .74731 .60935 L .74691 .60947 L F
.74708 .60935 m .74721 .61632 L .74695 .60944 L .362 .185 .501 r
F
.74721 .61632 m .74775 .6474 L .7471 .6164 L F
.74721 .61632 m .7471 .6164 L .74695 .60944 L F
.74708 .60935 m .74695 .60944 L .7468 .60249 L F
.7461 .60698 m .74617 .60977 L .74601 .60702 L .519 .306 .53 r
F
.75713 .61369 m .75705 .61084 L .76016 .60828 L .363 .193 .513 r
F
.75713 .61369 m .76016 .60828 L .76024 .61112 L F
.75284 .61073 m .76024 .61112 L .75492 .60902 L .675 .735 .895 r
F
.76032 .61397 m .76227 .60813 L .76235 .61097 L .129 .02 .45 r
F
.75284 .61073 m .75713 .61369 L .76024 .61112 L .675 .735 .895 r
F
.755 .61186 m .76032 .61397 L .76235 .61097 L F
.76032 .61397 m .76024 .61112 L .76227 .60813 L .129 .02 .45 r
F
.755 .61186 m .76235 .61097 L .75635 .60986 L .675 .735 .895 r
F
.7503 .60865 m .7736 .61577 L .76078 .61102 L .654 .726 .902 r
F
.74478 .6074 m .75102 .60921 L .7503 .60865 L F
.74968 .60975 m .75635 .60986 L .75035 .60876 L .675 .735 .895 r
F
.75102 .60921 m .7736 .61577 L .7503 .60865 L .654 .726 .902 r
F
.74698 .60372 m .74752 .60329 L .74753 .6061 L .362 .185 .501 r
F
.74826 .60127 m .75043 .602 L .75027 .60093 L .675 .735 .895 r
F
.74798 .60116 m .74808 .60182 L .748 .60233 L 0 0 .158 r
F
.74517 .60014 m .74611 .60274 L .74702 .60241 L .654 .726 .902 r
F
.74517 .60014 m .74503 .60293 L .74615 .60283 L F
.7442 .60196 m .74921 .60199 L .74826 .60127 L .675 .735 .895 r
F
.74921 .60199 m .75043 .602 L .74826 .60127 L F
.748 .58735 m .74797 .60034 L .74807 .60057 L .982 .725 .331 r
F
.74799 .59926 m .77552 .59654 L .77266 .59156 L .654 .726 .902 r
F
.74517 .60014 m .7491 .59967 L .74799 .59926 L F
.7491 .59967 m .77552 .59654 L .74799 .59926 L F
.74652 .58549 m .74545 .58512 L .74552 .59834 L .809 .541 .532 r
F
.74478 .6074 m .7535 .61116 L .75102 .60921 L .654 .726 .902 r
F
.7477 .60879 m .74779 .61575 L .74762 .60891 L .088 0 .422 r
F
.74779 .61575 m .74772 .61585 L .74762 .60891 L F
.7477 .60879 m .74799 .60837 L .74802 .61541 L F
.74621 .61705 m .75151 .63447 L .74628 .617 L .654 .726 .902 r
F
.74779 .61575 m .74802 .61541 L .74819 .64673 L .088 0 .422 r
F
.7477 .60879 m .74802 .61541 L .74779 .61575 L F
.74839 .61488 m .74997 .61541 L .74937 .61493 L .654 .726 .902 r
F
.745 .61702 m .74476 .61704 L .74448 .61002 L .642 .403 .541 r
F
.7471 .6164 m .74701 .61647 L .74684 .60948 L .362 .185 .501 r
F
.74439 .61467 m .74819 .61517 L .74839 .61488 L .654 .726 .902 r
F
.74819 .61517 m .74997 .61541 L .74839 .61488 L F
.74796 .60726 m .74767 .6066 L .74771 .61363 L .982 .725 .331 r
F
.74779 .61575 m .74819 .64673 L .74772 .61585 L .088 0 .422 r
F
.74528 .61715 m .74544 .6176 L .74614 .61683 L .654 .726 .902 r
F
.74762 .60891 m .74772 .61585 L .74758 .60896 L .088 0 .422 r
F
.74772 .61585 m .74819 .64673 L .74769 .61589 L F
.74772 .61585 m .74769 .61589 L .74758 .60896 L F
.74544 .6176 m .74581 .61862 L .74621 .61705 L .654 .726 .902 r
F
.74581 .61862 m .75151 .63447 L .74642 .61773 L F
.74581 .61862 m .74642 .61773 L .74621 .61705 L F
.74544 .6176 m .74621 .61705 L .74614 .61683 L F
.74691 .60947 m .74731 .60935 L .74737 .60926 L F
.74708 .60935 m .74755 .60901 L .74759 .61605 L .362 .185 .501 r
F
.74695 .61651 m .74769 .6175 L .74775 .61708 L .654 .726 .902 r
F
.74721 .61632 m .74759 .61605 L .74775 .6474 L .362 .185 .501 r
F
.74708 .60935 m .74759 .61605 L .74721 .61632 L F
.74759 .61605 m .74819 .64673 L .74775 .6474 L .088 0 .422 r
F
.74737 .61681 m .74775 .61708 L .7478 .61677 L .654 .726 .902 r
F
.74769 .61589 m .74819 .64673 L .74759 .61605 L .088 0 .422 r
F
.75102 .60921 m .77138 .61885 L .7736 .61577 L .654 .726 .902 r
F
.74968 .60975 m .755 .61186 L .75635 .60986 L .675 .735 .895 r
F
.7535 .61116 m .77138 .61885 L .75102 .60921 L .654 .726 .902 r
F
.74731 .61126 m .75026 .61487 L .75292 .61357 L .675 .735 .895 r
F
.75173 .61596 m .75085 .61392 L .74737 .60926 L .654 .726 .902 r
F
.75273 .60785 m .75699 .6108 L .76008 .60825 L .675 .735 .895 r
F
.75492 .60902 m .76024 .61112 L .76227 .60813 L F
.76024 .61112 m .76016 .60828 L .76219 .60529 L .129 .02 .45 r
F
.76235 .61097 m .76227 .60813 L .76307 .60491 L 0 0 .27 r
F
.76235 .61097 m .76307 .60491 L .76315 .60775 L F
.75635 .60986 m .76235 .61097 L .76315 .60775 L .675 .735 .895 r
F
.76024 .61112 m .76219 .60529 L .76227 .60813 L .129 .02 .45 r
F
.75273 .60785 m .76008 .60825 L .75479 .60615 L .675 .735 .895 r
F
.75492 .60902 m .76227 .60813 L .75627 .60702 L F
.75635 .60986 m .76315 .60775 L .75688 .60772 L F
.75204 .60778 m .77475 .61418 L .77609 .60904 L .654 .726 .902 r
F
.74856 .60777 m .75492 .60902 L .7496 .60691 L .675 .735 .895 r
F
.7496 .60691 m .75492 .60902 L .75627 .60702 L F
.75035 .60876 m .75635 .60986 L .75688 .60772 L F
.75035 .60876 m .75688 .60772 L .75062 .60768 L F
.74478 .6074 m .76078 .61102 L .75204 .60778 L .654 .726 .902 r
F
.76078 .61102 m .77475 .61418 L .75204 .60778 L F
.74704 .60015 m .7497 .59993 L .74875 .59906 L .675 .735 .895 r
F
.7442 .60196 m .74811 .60051 L .74704 .60015 L F
.74517 .60014 m .77499 .60688 L .77604 .60282 L .654 .726 .902 r
F
.76469 .60116 m .77604 .60282 L .77632 .60177 L F
.74517 .60014 m .77604 .60282 L .76469 .60116 L F
.74771 .61364 m .74991 .61402 L .74834 .61344 L F
.74675 .60982 m .7467 .60983 L .74687 .60998 L F
.74652 .61049 m .74694 .61112 L .74687 .60998 L F
.74617 .60977 m .74684 .60952 L .74688 .61656 L .519 .306 .53 r
F
.74439 .61467 m .74842 .61419 L .74771 .61364 L .654 .726 .902 r
F
.74842 .61419 m .74991 .61402 L .74771 .61364 L F
.7471 .6164 m .74775 .6474 L .74701 .61647 L .362 .185 .501 r
F
.74688 .61656 m .74775 .6474 L .74704 .64797 L F
.76648 .61541 m .79807 .62292 L .77163 .61153 L .654 .726 .902 r
F
.76078 .61102 m .7736 .61577 L .77475 .61418 L F
.75355 .61359 m .7757 .61631 L .7749 .61106 L F
.74625 .60564 m .74616 .61263 L .74646 .60572 L .809 .541 .532 r
F
.74614 .61683 m .74621 .61705 L .74628 .617 L .654 .726 .902 r
F
.74796 .60726 m .74771 .61363 L .74794 .61417 L .982 .725 .331 r
F
.74691 .60663 m .74711 .60676 L .7473 .60646 L .675 .735 .895 r
F
.74691 .60663 m .7473 .60646 L .74754 .60609 L F
.74726 .60632 m .74755 .60901 L .74703 .6065 L .362 .185 .501 r
F
.74766 .6059 m .7477 .60879 L .74757 .60604 L .088 0 .422 r
F
.74757 .60604 m .74762 .60891 L .74753 .6061 L F
.74751 .60647 m .74738 .61338 L .74767 .6066 L .91 .629 .499 r
F
.74617 .61682 m .74604 .61687 L .74581 .6099 L .519 .306 .53 r
F
.74477 .61 m .74585 .61694 L .745 .61702 L .642 .403 .541 r
F
.74439 .61467 m .74937 .61493 L .74842 .61419 L .654 .726 .902 r
F
.74663 .61743 m .74711 .61674 L .74695 .61651 L F
.74628 .617 m .74725 .62024 L .74752 .61853 L F
.74701 .61647 m .74775 .6474 L .74688 .61656 L .362 .185 .501 r
F
.74738 .61338 m .74683 .64406 L .74752 .61348 L .91 .629 .499 r
F
.74738 .61338 m .74752 .61348 L .74767 .6066 L F
.74842 .61419 m .75287 .61512 L .74991 .61402 L .654 .726 .902 r
F
.74937 .61493 m .75287 .61512 L .74842 .61419 L F
.74439 .61467 m .74857 .61562 L .74839 .6152 L F
.74658 .60962 m .74684 .60952 L .74691 .60947 L F
.74628 .617 m .74663 .61743 L .74695 .61651 L F
.74633 .61677 m .74688 .61656 L .74704 .64797 L .519 .306 .53 r
F
.74698 .60372 m .74726 .60632 L .74703 .6065 L .362 .185 .501 r
F
.74801 .60576 m .74803 .60811 L .748 .60597 L 0 0 .158 r
F
.74604 .60419 m .7461 .60698 L .74589 .60425 L .519 .306 .53 r
F
.74601 .60278 m .7465 .60681 L .7461 .60698 L F
.74428 .6048 m .74754 .6061 L .74791 .6058 L .675 .735 .895 r
F
.74796 .60549 m .74791 .6058 L .74824 .60554 L F
.74428 .6048 m .74791 .6058 L .74796 .60549 L F
.74786 .60622 m .7496 .60691 L .74908 .60569 L F
.7483 .60618 m .75046 .60661 L .74988 .6056 L F
.74801 .60519 m .7481 .60747 L .74803 .60796 L 0 0 .158 r
F
.74803 .60811 m .748 .60825 L .74798 .60536 L F
.74799 .60527 m .74798 .60536 L .74795 .60134 L F
.74803 .60811 m .74798 .60536 L .74799 .60527 L F
.74791 .6058 m .74786 .60622 L .74824 .60554 L .675 .735 .895 r
F
.74754 .6061 m .74785 .60622 L .74791 .6058 L F
.74785 .60622 m .74786 .60622 L .74791 .6058 L F
.74726 .60632 m .74753 .6061 L .74755 .60901 L .362 .185 .501 r
F
.74435 .60765 m .75062 .60768 L .75046 .60661 L .675 .735 .895 r
F
.74796 .60726 m .74804 .60745 L .74804 .60728 L .982 .725 .331 r
F
.74796 .6071 m .74804 .60728 L .74805 .60454 L F
.74795 .60134 m .748 .60825 L .74799 .60837 L 0 0 .158 r
F
.74796 .60726 m .74804 .60728 L .74796 .6071 L .982 .725 .331 r
F
.74824 .60554 m .74786 .60622 L .74908 .60569 L .675 .735 .895 r
F
.74805 .60489 m .74811 .60745 L .74801 .60519 L 0 0 .158 r
F
.74811 .60745 m .74811 .60761 L .7481 .60747 L F
.74811 .60745 m .7481 .60747 L .74801 .60519 L F
.74818 .60483 m .74842 .60539 L .74912 .60483 L .675 .735 .895 r
F
.74824 .60554 m .75027 .60591 L .74912 .60483 L F
.74846 .60491 m .75273 .60785 L .75479 .60615 L F
.74848 .60502 m .74988 .6056 L .74893 .60473 L F
.74801 .60576 m .748 .60597 L .74799 .60527 L 0 0 .158 r
F
.74428 .6048 m .74824 .60554 L .74842 .60539 L .675 .735 .895 r
F
.74801 .60519 m .74801 .60576 L .74799 .60527 L 0 0 .158 r
F
.74796 .60709 m .74805 .60454 L .74801 .60443 L .982 .725 .331 r
F
.74796 .60726 m .74796 .6071 L .74796 .60709 L F
.74796 .6071 m .74805 .60454 L .74796 .60709 L F
.74811 .60744 m .74804 .60745 L .74811 .60761 L F
.74428 .6048 m .74842 .60539 L .74818 .60483 L .675 .735 .895 r
F
.748 .60233 m .74808 .60182 L .74809 .60463 L 0 0 .158 r
F
.74805 .60489 m .74809 .60463 L .74811 .60761 L F
.748 .60233 m .74809 .60463 L .74805 .60489 L F
.7483 .60332 m .75038 .60376 L .7498 .60276 L .675 .735 .895 r
F
.74798 .60116 m .74805 .60489 L .74801 .60519 L 0 0 .158 r
F
.74751 .60197 m .74757 .60604 L .74753 .6061 L .088 0 .422 r
F
.74428 .6048 m .74809 .60463 L .7479 .60419 L .675 .735 .895 r
F
.74731 .60631 m .74756 .60354 L .74745 .60345 L .91 .629 .499 r
F
.74428 .6048 m .74817 .60414 L .74819 .60401 L .675 .735 .895 r
F
.74766 .60361 m .74751 .60647 L .74767 .6066 L .91 .629 .499 r
F
.74763 .59956 m .74756 .60354 L .74766 .60361 L F
.74756 .60354 m .74751 .60647 L .74766 .60361 L F
.74798 .60242 m .74796 .60257 L .74795 .60134 L 0 0 .158 r
F
.74797 .60034 m .7478 .60394 L .74796 .60433 L .982 .725 .331 r
F
.74798 .60242 m .74801 .60519 L .74796 .60257 L 0 0 .158 r
F
.74798 .60116 m .74807 .60057 L .74804 .60159 L F
.74804 .60159 m .74807 .60057 L .74808 .60182 L F
.7476 .6007 m .75027 .60093 L .7497 .59993 L .675 .735 .895 r
F
.74517 .60014 m .77266 .59156 L .76792 .58716 L .654 .726 .902 r
F
.7474 .59937 m .74659 .59874 L .74659 .6 L .91 .629 .499 r
F
.74428 .6048 m .74819 .60401 L .74761 .60357 L .675 .735 .895 r
F
.74726 .60051 m .74661 .60281 L .74695 .60307 L .91 .629 .499 r
F
.74745 .60345 m .74756 .60354 L .74763 .59956 L F
.74632 .60259 m .74885 .60189 L .74759 .60122 L .675 .735 .895 r
F
.74428 .6048 m .74806 .60483 L .74809 .60463 L F
.74627 .6055 m .74646 .60557 L .74651 .60278 L .809 .541 .532 r
F
.74454 .60298 m .74578 .6043 L .74459 .60446 L .642 .403 .541 r
F
.74506 .6044 m .74578 .6043 L .74603 .60419 L .675 .735 .895 r
F
.74604 .60419 m .74589 .60425 L .74578 .60287 L .519 .306 .53 r
F
.74428 .6048 m .74761 .60357 L .74697 .60309 L .675 .735 .895 r
F
.74625 .60564 m .74651 .60278 L .74639 .60274 L .809 .541 .532 r
F
.74695 .60307 m .74661 .60281 L .74662 .60578 L .91 .629 .499 r
F
.74545 .60523 m .74766 .60407 L .74617 .60364 L .675 .735 .895 r
F
.74509 .61235 m .74526 .61237 L .74539 .60525 L .734 .478 .541 r
F
.7442 .60196 m .74787 .60134 L .74764 .6008 L .675 .735 .895 r
F
.74639 .60274 m .74651 .60278 L .74659 .59874 L .809 .541 .532 r
F
.74726 .60051 m .74659 .6 L .74661 .60281 L .91 .629 .499 r
F
.7442 .60196 m .74764 .6008 L .74754 .60072 L .675 .735 .895 r
F
.74633 .59991 m .74629 .60271 L .74653 .59998 L .809 .541 .532 r
F
.74629 .60271 m .74625 .60564 L .74639 .60274 L F
.74629 .60271 m .74639 .60274 L .74653 .59998 L F
.74537 .6024 m .74759 .60122 L .7461 .6008 L .675 .735 .895 r
F
.7442 .60196 m .74506 .6044 L .74603 .60419 L F
.74428 .6048 m .74637 .60254 L .74535 .60244 L F
.74571 .58984 m .74601 .60278 L .74578 .60287 L .519 .306 .53 r
F
.748 .58735 m .74763 .59956 L .74797 .60034 L .982 .725 .331 r
F
.74517 .60014 m .76163 .58364 L .75421 .58125 L .654 .726 .902 r
F
.74635 .59865 m .74552 .59834 L .74553 .59965 L .809 .541 .532 r
F
.74601 .60278 m .74604 .60419 L .74578 .60287 L .519 .306 .53 r
F
.74428 .6048 m .74697 .60309 L .74661 .60281 L .675 .735 .895 r
F
.74628 .5999 m .74556 .60538 L .74597 .60553 L .809 .541 .532 r
F
.7461 .60698 m .74601 .60702 L .74578 .60287 L .519 .306 .53 r
F
.74601 .60702 m .7459 .60707 L .74578 .60287 L F
.74428 .6048 m .74607 .60699 L .74691 .60663 L .675 .735 .895 r
F
.74435 .60765 m .74632 .60552 L .74556 .60527 L F
.74488 .60801 m .74619 .60976 L .74691 .60942 L F
.74478 .6074 m .74515 .60841 L .7467 .60983 L .654 .726 .902 r
F
.74552 .59834 m .74526 .61237 L .74559 .61242 L .734 .478 .541 r
F
.74544 .60525 m .74556 .60527 L .74545 .60523 L .675 .735 .895 r
F
.74623 .60269 m .74661 .60281 L .74632 .60259 L F
.74754 .60072 m .74764 .6008 L .7476 .6007 L F
.7442 .60196 m .74689 .60382 L .74753 .60328 L F
.74659 .59874 m .74646 .60572 L .74662 .60578 L .809 .541 .532 r
F
.74797 .60034 m .74763 .59956 L .74764 .6008 L .982 .725 .331 r
F
.74797 .60034 m .74764 .6008 L .74792 .60145 L F
.74517 .60014 m .76792 .58716 L .76163 .58364 L .654 .726 .902 r
F
.7475 .60011 m .74761 .6001 L .74763 .59956 L .91 .629 .499 r
F
.74738 .6006 m .74761 .6001 L .7475 .60011 L F
.74738 .6006 m .74758 .60075 L .74761 .6001 L F
.74811 .60051 m .7497 .59993 L .74704 .60015 L .675 .735 .895 r
F
.74875 .59906 m .75079 .59484 L .74749 .5984 L F
.74759 .60122 m .7509 .59764 L .74792 .5968 L F
.7497 .59993 m .7533 .59617 L .74875 .59906 L F
.75097 .60049 m .74981 .59563 L .74799 .59964 L F
.74574 .60541 m .75386 .58843 L .74496 .60516 L .654 .726 .902 r
F
.74428 .6048 m .74691 .60663 L .74754 .60609 L .675 .735 .895 r
F
.7442 .60196 m .74627 .59972 L .74526 .59962 L F
.74435 .60765 m .74556 .60527 L .74544 .60525 L F
.74478 .6074 m .74574 .60541 L .74489 .60528 L .654 .726 .902 r
F
.7478 .60394 m .74767 .6066 L .74796 .60433 L .982 .725 .331 r
F
.7479 .60419 m .74809 .60463 L .74817 .60414 L .675 .735 .895 r
F
.74639 .60545 m .74893 .60473 L .74766 .60407 L F
.74817 .60414 m .75038 .60376 L .7483 .60332 L F
.75017 .60307 m .75667 .60203 L .75043 .602 L F
.75043 .602 m .75667 .60203 L .75635 .59989 L F
.75043 .602 m .75635 .59989 L .75027 .60093 L F
.75027 .60093 m .75635 .59989 L .7552 .59789 L F
.75635 .59989 m .7607 .59585 L .7552 .59789 L F
.75635 .59989 m .76242 .59885 L .7607 .59585 L F
.75038 .60376 m .75533 .60071 L .7498 .60276 L F
.7498 .60276 m .75533 .60071 L .75343 .59898 L F
.7552 .59789 m .7607 .59585 L .75786 .59327 L F
.75533 .60071 m .758 .59606 L .75343 .59898 L F
.75533 .60071 m .76086 .59866 L .758 .59606 L F
.76086 .59866 m .76078 .59582 L .75793 .59322 L .934 .65 .479 r
F
.74806 .60483 m .75054 .60484 L .74817 .60414 L .675 .735 .895 r
F
.74893 .60473 m .75097 .60049 L .74766 .60407 L F
.7498 .60276 m .75343 .59898 L .74885 .60189 L F
.74893 .60473 m .7535 .60182 L .75097 .60049 L F
.76086 .59866 m .75793 .59322 L .758 .59606 L .934 .65 .479 r
F
.75667 .60203 m .7629 .60207 L .76242 .59885 L .675 .735 .895 r
F
.76094 .60151 m .76086 .59866 L .758 .59606 L .934 .65 .479 r
F
.7535 .60182 m .75428 .5969 L .75097 .60049 L .675 .735 .895 r
F
.7535 .60182 m .75808 .59891 L .75428 .5969 L F
.76094 .60151 m .758 .59606 L .75808 .59891 L .934 .65 .479 r
F
.7552 .59789 m .75786 .59327 L .7533 .59617 L .675 .735 .895 r
F
.75343 .59898 m .758 .59606 L .75421 .59406 L F
.75808 .59891 m .758 .59606 L .75421 .59406 L .861 .585 .519 r
F
.74664 .60554 m .76764 .59436 L .76132 .59083 L .654 .726 .902 r
F
.74435 .60765 m .74704 .60594 L .74662 .60562 L .675 .735 .895 r
F
.74632 .60552 m .74662 .60562 L .74639 .60545 L F
.74435 .60765 m .74662 .60562 L .74632 .60552 L F
.74597 .60984 m .74617 .61682 L .74581 .6099 L .519 .306 .53 r
F
.74478 .6074 m .7467 .60983 L .74675 .60982 L .654 .726 .902 r
F
.74617 .60977 m .74704 .64797 L .74597 .60985 L .519 .306 .53 r
F
.74586 .60949 m .74731 .61126 L .74488 .60801 L .675 .735 .895 r
F
.74617 .60977 m .74684 .60952 L .74617 .60977 L .519 .306 .53 r
F
.74515 .60841 m .74652 .61049 L .74687 .60998 L .654 .726 .902 r
F
.74626 .6055 m .74559 .61242 L .74616 .61263 L .809 .541 .532 r
F
.74635 .59865 m .74598 .60541 L .74626 .6055 L F
.74598 .60541 m .74559 .61242 L .74626 .6055 L F
.74478 .6074 m .74776 .6057 L .74664 .60554 L .654 .726 .902 r
F
.74796 .60433 m .74796 .60726 L .74801 .60443 L .982 .725 .331 r
F
.74732 .60616 m .74751 .6063 L .74756 .60354 L .91 .629 .499 r
F
.74807 .60057 m .74804 .60728 L .74811 .60744 L .982 .725 .331 r
F
.74704 .60594 m .74893 .60473 L .74639 .60545 L .675 .735 .895 r
F
.75017 .60307 m .75613 .60417 L .75667 .60203 L F
.75038 .60376 m .75648 .60272 L .75533 .60071 L F
.75541 .60355 m .75808 .59891 L .7535 .60182 L F
.74776 .6057 m .76764 .59436 L .74664 .60554 L .654 .726 .902 r
F
.74412 .59005 m .74571 .58984 L .74578 .60287 L .642 .403 .541 r
F
.74545 .58512 m .74437 .58499 L .74444 .59819 L .734 .478 .541 r
F
.74256 .58979 m .74412 .59005 L .74419 .60301 L .751 .492 .54 r
F
.74328 .58508 m .74218 .58541 L .74225 .59852 L .57 .345 .536 r
F
.7397 .60772 m .73513 .61063 L .73766 .61196 L .675 .735 .895 r
F
.74119 .60946 m .73319 .61102 L .73941 .61047 L .654 .726 .902 r
F
.7416 .60922 m .73935 .6091 L .74119 .60946 L F
.74104 .61123 m .73774 .6148 L .74072 .61565 L .675 .735 .895 r
F
.74062 .60722 m .74066 .6144 L .74066 .61426 L .769 .613 .047 r
F
.74314 .60731 m .74097 .60838 L .74246 .60881 L .675 .735 .895 r
F
.74253 .61165 m .74394 .61595 L .74415 .6118 L F
.74312 .60716 m .74427 .61708 L .74343 .61692 L .751 .492 .54 r
F
.74298 .60277 m .74338 .6072 L .74312 .60716 L F
.74358 .60992 m .74271 .61173 L .74465 .61012 L .654 .726 .902 r
F
.74358 .60992 m .74234 .60985 L .74323 .61064 L F
.74362 .60993 m .74343 .60989 L .74312 .60716 L .751 .492 .54 r
F
.74437 .60731 m .74448 .61002 L .74422 .60733 L .642 .403 .541 r
F
.74415 .60732 m .74246 .60881 L .74407 .60896 L .675 .735 .895 r
F
.74338 .6072 m .74423 .61004 L .74362 .60993 L .751 .492 .54 r
F
.74298 .60277 m .74375 .60726 L .74338 .6072 L F
.74375 .60726 m .74423 .61004 L .74338 .6072 L F
.74298 .60277 m .74419 .60301 L .74423 .61004 L F
.74428 .6048 m .7432 .60717 L .74415 .60732 L .675 .735 .895 r
F
.7432 .60717 m .74246 .60881 L .74415 .60732 L F
.74478 .6074 m .74248 .60971 L .74358 .60992 L .654 .726 .902 r
F
.74248 .60971 m .74234 .60985 L .74358 .60992 L F
.74338 .6072 m .74362 .60993 L .74312 .60716 L .751 .492 .54 r
F
.74362 .60993 m .74427 .61708 L .74343 .60989 L F
.7432 .60717 m .74265 .60709 L .74314 .60731 L .675 .735 .895 r
F
.7351 .60776 m .73433 .61264 L .73762 .60908 L F
.7351 .60776 m .73055 .61065 L .73433 .61264 L F
.7277 .61094 m .73048 .6107 L .73056 .61354 L .934 .65 .479 r
F
.73056 .61354 m .73048 .6107 L .73428 .6127 L .861 .585 .519 r
F
.73322 .6089 m .73056 .61354 L .73513 .61063 L .675 .735 .895 r
F
.73322 .6089 m .7277 .61094 L .73056 .61354 L F
.72619 .61011 m .71429 .61102 L .7277 .61273 L .654 .726 .902 r
F
.72604 .61077 m .7266 .61083 L .72777 .61378 L .986 .71 .377 r
F
.7266 .61083 m .7277 .61094 L .72775 .61281 L F
.7266 .61083 m .72775 .61281 L .72777 .61378 L F
.7277 .61273 m .71429 .61102 L .71718 .61602 L .654 .726 .902 r
F
.73935 .6091 m .72619 .61011 L .7277 .61273 L F
.74222 .60703 m .74209 .60701 L .74218 .60708 L .675 .735 .895 r
F
.74229 .60692 m .74267 .6099 L .74196 .60677 L .845 .571 .524 r
F
.74284 .60801 m .74291 .60979 L .74274 .60804 L .751 .492 .54 r
F
.74284 .60801 m .74274 .60804 L .74265 .60709 L F
.74231 .60693 m .74097 .60838 L .74314 .60731 L .675 .735 .895 r
F
.7428 .60711 m .74284 .60801 L .74265 .60709 L .751 .492 .54 r
F
.74229 .60692 m .74265 .60709 L .74267 .6099 L .845 .571 .524 r
F
.74196 .60677 m .74267 .6099 L .74203 .6096 L F
.74478 .6074 m .74059 .60871 L .7416 .60922 L .654 .726 .902 r
F
.74139 .60953 m .73883 .60969 L .73978 .61056 L .675 .735 .895 r
F
.74435 .60765 m .74104 .60887 L .74139 .60953 L F
.7397 .60772 m .73766 .61196 L .74097 .60838 L F
.73935 .6091 m .73319 .61102 L .74119 .60946 L .654 .726 .902 r
F
.74104 .60887 m .73883 .60969 L .74139 .60953 L .675 .735 .895 r
F
.74122 .60623 m .74169 .60926 L .74126 .60887 L .929 .648 .486 r
F
.74187 .60233 m .74202 .60942 L .74165 .60222 L .845 .571 .524 r
F
.74072 .61565 m .74374 .6201 L .74394 .61595 L .675 .735 .895 r
F
.74291 .61736 m .74229 .61793 L .74305 .61748 L .654 .726 .902 r
F
.74139 .60953 m .73978 .61056 L .74185 .61036 L .675 .735 .895 r
F
.74064 .60749 m .74066 .608 L .7407 .61504 L .769 .613 .047 r
F
.74072 .6081 m .74082 .61524 L .74066 .608 L .988 .719 .38 r
F
.74064 .60749 m .74068 .61462 L .74063 .60734 L .769 .613 .047 r
F
.73418 .61869 m .73078 .62477 L .73571 .62636 L .654 .726 .902 r
F
.74167 .60664 m .7397 .60772 L .74218 .60708 L .675 .735 .895 r
F
.74156 .60654 m .74151 .60656 L .74167 .60664 L F
.74078 .60285 m .74101 .60325 L .74102 .60606 L .988 .719 .38 r
F
.74091 .60587 m .74102 .60606 L .74104 .60867 L F
.74078 .60285 m .74102 .60606 L .74091 .60587 L F
.74151 .60656 m .74135 .60667 L .74167 .60664 L .675 .735 .895 r
F
.74135 .60667 m .7397 .60772 L .74141 .60678 L F
.74135 .60667 m .74141 .60678 L .74167 .60664 L F
.74202 .60942 m .74184 .60933 L .74177 .60668 L .845 .571 .524 r
F
.74188 .60673 m .74177 .60668 L .74165 .60222 L F
.74202 .60942 m .74177 .60668 L .74188 .60673 L F
.74098 .60603 m .73875 .60685 L .74156 .60654 L .675 .735 .895 r
F
.74126 .60887 m .74114 .60876 L .741 .60163 L .929 .648 .486 r
F
.74109 .60612 m .74114 .60876 L .74102 .60606 L F
.74114 .60876 m .74127 .61589 L .74104 .60867 L F
.73418 .61869 m .72827 .62396 L .73078 .62477 L .654 .726 .902 r
F
.7412 .61649 m .72155 .6277 L .74225 .61677 L F
.74214 .61667 m .74225 .61677 L .74235 .61671 L F
.7412 .61649 m .74225 .61677 L .74214 .61667 L F
.74104 .61123 m .74072 .61565 L .74253 .61165 L .675 .735 .895 r
F
.74184 .60933 m .74203 .61645 L .74169 .60926 L .845 .571 .524 r
F
.74203 .61645 m .74287 .64835 L .7419 .61638 L F
.74253 .61165 m .74072 .61565 L .74394 .61595 L .675 .735 .895 r
F
.74203 .61645 m .7419 .61638 L .74169 .60926 L .845 .571 .524 r
F
.73504 .61717 m .72827 .62396 L .73418 .61869 L .654 .726 .902 r
F
.73774 .6148 m .73443 .61838 L .7389 .61965 L .675 .735 .895 r
F
.74163 .61625 m .73371 .618 L .72155 .6277 L .654 .726 .902 r
F
.74235 .61671 m .74225 .61677 L .74228 .61679 L F
.74321 .61015 m .74104 .61123 L .74253 .61165 L .675 .735 .895 r
F
.7431 .6101 m .74104 .61123 L .74321 .61015 L F
.74232 .60985 m .74104 .61123 L .74329 .61 L F
.74248 .60971 m .7423 .6098 L .74234 .60985 L .654 .726 .902 r
F
.74203 .6096 m .74267 .6099 L .7427 .61678 L .845 .571 .524 r
F
.74235 .61671 m .74188 .61719 L .74319 .61702 L .654 .726 .902 r
F
.74188 .61719 m .74227 .61788 L .74319 .61702 L F
.74227 .61788 m .74229 .61793 L .74325 .61705 L F
.74229 .61793 m .74237 .61808 L .74305 .61748 L F
.74218 .61652 m .7427 .61678 L .74287 .64835 L .845 .571 .524 r
F
.74203 .6096 m .7427 .61678 L .74218 .61652 L F
.74242 .61664 m .7412 .61649 L .74235 .61671 L .654 .726 .902 r
F
.74235 .61671 m .74319 .61702 L .7427 .61678 L F
.74319 .61702 m .74227 .61788 L .74325 .61705 L F
.7427 .61678 m .74443 .64861 L .74287 .64835 L .751 .492 .54 r
F
.74267 .60974 m .74299 .61684 L .7427 .61678 L F
.74299 .61684 m .74443 .64861 L .7427 .61678 L F
.73056 .61354 m .73428 .6127 L .73435 .61554 L .861 .585 .519 r
F
.73513 .61063 m .73056 .61354 L .73435 .61554 L .675 .735 .895 r
F
.73063 .61548 m .71718 .61602 L .72195 .62043 L .654 .726 .902 r
F
.72871 .6137 m .73056 .61354 L .73061 .61546 L .934 .65 .479 r
F
.73941 .61047 m .72823 .61326 L .73063 .61548 L .654 .726 .902 r
F
.72823 .61326 m .71718 .61602 L .73063 .61548 L F
.72777 .61378 m .72871 .6137 L .73063 .61638 L .934 .65 .479 r
F
.72871 .6137 m .73061 .61546 L .73063 .61638 L F
.73957 .61618 m .71389 .61828 L .71678 .62329 L .654 .726 .902 r
F
.74202 .60942 m .74218 .61652 L .74184 .60933 L .845 .571 .524 r
F
.74478 .6074 m .73926 .60806 L .74059 .60871 L .654 .726 .902 r
F
.7419 .60394 m .74229 .60692 L .74196 .60677 L .845 .571 .524 r
F
.7419 .60394 m .74265 .60709 L .74229 .60692 L F
.74428 .6048 m .74098 .60603 L .74156 .60654 L .675 .735 .895 r
F
.73926 .60806 m .73808 .6082 L .74059 .60871 L .654 .726 .902 r
F
.74079 .60823 m .74079 .60843 L .74072 .6081 L .988 .719 .38 r
F
.74071 .60827 m .73809 .60761 L .73825 .60869 L .675 .735 .895 r
F
.74102 .60606 m .74114 .60876 L .74104 .60867 L .929 .648 .486 r
F
.74435 .60765 m .74035 .60762 L .74071 .60827 L .675 .735 .895 r
F
.7432 .60985 m .74291 .60979 L .74263 .60271 L .751 .492 .54 r
F
.72684 .60953 m .71348 .60577 L .71429 .61102 L .654 .726 .902 r
F
.74062 .60163 m .74063 .60155 L .74064 .60258 L .769 .613 .047 r
F
.74059 .60036 m .74063 .60155 L .74062 .60163 L F
.74059 .60036 m .74063 .60096 L .74063 .60155 L F
.72809 .60216 m .71403 .59851 L .71484 .60373 L .654 .726 .902 r
F
.74517 .60014 m .73751 .59974 L .72809 .60216 L F
.73751 .59974 m .71403 .59851 L .72809 .60216 L F
.74478 .6074 m .73976 .60714 L .73808 .6082 L F
.74439 .61467 m .73776 .61546 L .73957 .61618 L F
.74329 .61 m .7431 .6101 L .74321 .61015 L .675 .735 .895 r
F
.7432 .60985 m .74343 .61692 L .74291 .60979 L .751 .492 .54 r
F
.74343 .61692 m .74319 .61687 L .74291 .60979 L F
.7427 .61678 m .74319 .61702 L .74332 .6169 L .654 .726 .902 r
F
.74325 .61705 m .74291 .61736 L .74305 .61748 L F
.74428 .6048 m .74265 .60709 L .7432 .60717 L .675 .735 .895 r
F
.74332 .6169 m .74319 .61702 L .74325 .61705 L .654 .726 .902 r
F
.74291 .60979 m .74292 .60994 L .7429 .60979 L .751 .492 .54 r
F
.74435 .60765 m .74232 .60985 L .74329 .61 L .675 .735 .895 r
F
.74423 .61004 m .74456 .61706 L .74427 .61708 L .642 .403 .541 r
F
.74439 .61467 m .74235 .61671 L .74332 .6169 L .654 .726 .902 r
F
.74277 .60976 m .74307 .61685 L .74267 .60974 L .751 .492 .54 r
F
.74307 .61685 m .74443 .64861 L .74299 .61684 L F
.74307 .61685 m .74299 .61684 L .74267 .60974 L F
.73521 .61347 m .73443 .61838 L .73774 .6148 L .675 .735 .895 r
F
.73658 .6156 m .71308 .61303 L .71389 .61828 L .654 .726 .902 r
F
.73319 .61102 m .72767 .61274 L .73941 .61047 L F
.72767 .61274 m .71718 .61602 L .72823 .61326 L F
.72871 .6137 m .7277 .61094 L .73056 .61354 L .934 .65 .479 r
F
.72767 .61274 m .72823 .61326 L .73941 .61047 L .654 .726 .902 r
F
.72777 .61378 m .72775 .61281 L .72871 .6137 L .934 .65 .479 r
F
.72775 .61281 m .7277 .61094 L .72871 .6137 L F
.7333 .61174 m .73063 .61638 L .73521 .61347 L .675 .735 .895 r
F
.73595 .61423 m .7144 .60789 L .71308 .61303 L .654 .726 .902 r
F
.74059 .60871 m .73808 .6082 L .73935 .6091 L F
.74079 .60823 m .74104 .60867 L .74104 .60887 L .988 .719 .38 r
F
.74079 .60823 m .74104 .60887 L .74079 .60843 L F
.74059 .60871 m .73935 .6091 L .7416 .60922 L .654 .726 .902 r
F
.74079 .60843 m .74073 .60831 L .74072 .6081 L .988 .719 .38 r
F
.74435 .60765 m .73825 .60869 L .73883 .60969 L .675 .735 .895 r
F
.7419 .6058 m .7418 .61292 L .74211 .60566 L .405 .218 .51 r
F
.74163 .61625 m .7412 .61649 L .74242 .61664 L .654 .726 .902 r
F
.73468 .62492 m .73463 .625 L .74325 .61705 L F
.74188 .61719 m .74088 .61819 L .74227 .61788 L F
.74094 .61918 m .74095 .61935 L .74237 .61808 L F
.74305 .61748 m .74095 .61935 L .74108 .62159 L F
.74137 .61598 m .74173 .6163 L .74189 .64788 L .929 .648 .486 r
F
.7332 .60603 m .72771 .60807 L .73055 .61065 L .675 .735 .895 r
F
.72597 .60793 m .72762 .6081 L .7277 .61094 L .986 .71 .377 r
F
.72597 .60793 m .72589 .60509 L .72762 .6081 L F
.7277 .61094 m .72762 .6081 L .73048 .6107 L .934 .65 .479 r
F
.73207 .60689 m .72597 .60793 L .7277 .61094 L .675 .735 .895 r
F
.7332 .60603 m .73055 .61065 L .7351 .60776 L F
.73817 .60585 m .73207 .60689 L .73322 .6089 L F
.72556 .60754 m .72548 .6047 L .72597 .60793 L .843 .647 .105 r
F
.73673 .60698 m .7255 .60639 L .72684 .60953 L .654 .726 .902 r
F
.7255 .60639 m .71348 .60577 L .72594 .60927 L F
.72569 .60766 m .72597 .60793 L .72602 .60981 L .843 .647 .105 r
F
.7266 .61083 m .72597 .60793 L .7277 .61094 L .986 .71 .377 r
F
.72604 .61077 m .72602 .60981 L .7266 .61083 L F
.72602 .60981 m .72597 .60793 L .7266 .61083 L F
.73875 .60685 m .73322 .6089 L .73513 .61063 L .675 .735 .895 r
F
.73597 .60845 m .72592 .60964 L .73935 .6091 L .654 .726 .902 r
F
.72592 .60964 m .71429 .61102 L .72619 .61011 L F
.73207 .60689 m .7277 .61094 L .73322 .6089 L .675 .735 .895 r
F
.72592 .60964 m .72619 .61011 L .73935 .6091 L .654 .726 .902 r
F
.7255 .60639 m .72594 .60927 L .72684 .60953 L F
.72556 .60754 m .72569 .60766 L .72604 .61077 L .843 .647 .105 r
F
.72569 .60766 m .72602 .60981 L .72604 .61077 L F
.73978 .61056 m .73521 .61347 L .73774 .6148 L .675 .735 .895 r
F
.73182 .60758 m .72604 .61077 L .73215 .60973 L F
.73182 .60758 m .72556 .60754 L .72604 .61077 L F
.73206 .60403 m .72771 .60807 L .7332 .60603 L F
.73206 .60403 m .72598 .60507 L .72771 .60807 L F
.72548 .6047 m .72589 .60509 L .72597 .60793 L .843 .647 .105 r
F
.72548 .6047 m .72541 .60186 L .72589 .60509 L F
.73175 .60473 m .72597 .60793 L .73207 .60689 L .675 .735 .895 r
F
.73175 .60473 m .72548 .6047 L .72597 .60793 L F
.73673 .60698 m .72624 .60394 L .7256 .6064 L .654 .726 .902 r
F
.72636 .60432 m .72612 .60442 L .72556 .60754 L 0 0 .268 r
F
.72612 .60442 m .72548 .6047 L .72554 .60666 L F
.72612 .60442 m .72554 .60666 L .72556 .60754 L F
.7256 .6064 m .7148 .60062 L .71348 .60577 L .654 .726 .902 r
F
.72624 .60394 m .7148 .60062 L .7256 .6064 L F
.74165 .60222 m .74184 .60933 L .74169 .60926 L .845 .571 .524 r
F
.74041 .60126 m .7389 .59986 L .73823 .60086 L .675 .735 .895 r
F
.7442 .60196 m .74114 .60075 L .74041 .60126 L F
.74059 .60036 m .74064 .60258 L .74061 .60209 L .769 .613 .047 r
F
.741 .59944 m .74059 .60178 L .74092 .60116 L 0 0 .386 r
F
.74114 .60075 m .7389 .59986 L .74041 .60126 L .675 .735 .895 r
F
.74105 .58619 m .74058 .60018 L .741 .59944 L 0 0 .386 r
F
.72436 .59905 m .71535 .59339 L .71403 .59851 L .654 .726 .902 r
F
.74517 .60014 m .73781 .59847 L .72436 .59905 L F
.73781 .59847 m .71535 .59339 L .72436 .59905 L F
.74437 .58499 m .74328 .58508 L .74335 .59823 L .66 .418 .542 r
F
.73776 .61546 m .73595 .61423 L .73658 .6156 L .654 .726 .902 r
F
.74439 .61467 m .73942 .61441 L .73776 .61546 L F
.73942 .61441 m .73595 .61423 L .73776 .61546 L F
.74478 .6074 m .74078 .6065 L .73976 .60714 L F
.74126 .60887 m .74137 .61598 L .74114 .60876 L .929 .648 .486 r
F
.7419 .6058 m .74116 .60626 L .74119 .6133 L .405 .218 .51 r
F
.74104 .60867 m .74119 .61582 L .74107 .61571 L .929 .648 .486 r
F
.74127 .61589 m .74119 .61582 L .74104 .60867 L F
.74218 .61652 m .74203 .61645 L .74184 .60933 L .845 .571 .524 r
F
.74126 .60887 m .74173 .6163 L .74137 .61598 L .929 .648 .486 r
F
.74169 .60926 m .7419 .61638 L .74173 .6163 L .845 .571 .524 r
F
.74137 .61598 m .74127 .61589 L .74114 .60876 L .929 .648 .486 r
F
.74439 .61467 m .74059 .61304 L .73898 .61345 L .654 .726 .902 r
F
.74439 .61467 m .74043 .61378 L .73942 .61441 L F
.74107 .61571 m .74189 .64788 L .74124 .64728 L .929 .648 .486 r
F
.74119 .61582 m .74189 .64788 L .74107 .61571 L F
.74127 .61589 m .74189 .64788 L .74119 .61582 L F
.74088 .61819 m .74093 .61901 L .74227 .61788 L .654 .726 .902 r
F
.74137 .61598 m .74189 .64788 L .74127 .61589 L .929 .648 .486 r
F
.7387 .604 m .7332 .60603 L .7351 .60776 L .675 .735 .895 r
F
.7387 .604 m .7351 .60776 L .73965 .60486 L F
.73801 .60477 m .73207 .60689 L .73817 .60585 L F
.73813 .603 m .73206 .60403 L .7332 .60603 L F
.73801 .60477 m .73175 .60473 L .73207 .60689 L F
.73174 .60189 m .72598 .60507 L .73206 .60403 L F
.73228 .60259 m .72548 .6047 L .73175 .60473 L F
.73813 .603 m .7332 .60603 L .7387 .604 L F
.73963 .60624 m .72642 .60325 L .73673 .60698 L .654 .726 .902 r
F
.73174 .60189 m .7255 .60186 L .72598 .60507 L .675 .735 .895 r
F
.73228 .60259 m .72628 .60148 L .72548 .6047 L F
.72612 .60442 m .72628 .60148 L .72548 .6047 L 0 0 .268 r
F
.72642 .60325 m .7148 .60062 L .72624 .60394 L .654 .726 .902 r
F
.72642 .60325 m .72624 .60394 L .73673 .60698 L F
.72636 .60432 m .72634 .60357 L .72612 .60442 L 0 0 .268 r
F
.72634 .60357 m .72628 .60148 L .72612 .60442 L F
.73965 .60486 m .7351 .60776 L .73762 .60908 L .675 .735 .895 r
F
.73817 .60585 m .73322 .6089 L .73875 .60685 L F
.73808 .6082 m .73673 .60698 L .72684 .60953 L .654 .726 .902 r
F
.73825 .60869 m .73215 .60973 L .7333 .61174 L .675 .735 .895 r
F
.72628 .60148 m .72541 .60186 L .72548 .6047 L 0 0 .268 r
F
.73809 .60761 m .73182 .60758 L .73215 .60973 L .675 .735 .895 r
F
.74076 .60559 m .74079 .60823 L .74073 .60553 L .988 .719 .38 r
F
.74079 .60823 m .74072 .6081 L .74069 .60545 L F
.74073 .60553 m .74069 .60545 L .74063 .60096 L F
.74079 .60823 m .74069 .60545 L .74073 .60553 L F
.73965 .60486 m .73762 .60908 L .74091 .60552 L .675 .735 .895 r
F
.741 .60602 m .73817 .60585 L .73875 .60685 L F
.74298 .60277 m .7432 .60985 L .74263 .60271 L .751 .492 .54 r
F
.74428 .6048 m .74067 .60542 L .741 .60602 L .675 .735 .895 r
F
.74067 .60542 m .73817 .60585 L .741 .60602 L F
.74063 .60096 m .74072 .6081 L .74066 .608 L .988 .719 .38 r
F
.73226 .59975 m .7263 .59865 L .7255 .60186 L .675 .735 .895 r
F
.72628 .60148 m .72621 .59863 L .72541 .60186 L 0 0 .268 r
F
.73663 .60556 m .72811 .60112 L .72655 .60328 L .654 .726 .902 r
F
.72838 .60132 m .72794 .60136 L .72636 .60432 L .128 .019 .449 r
F
.72794 .60136 m .72628 .60148 L .72634 .60357 L F
.72794 .60136 m .72634 .60357 L .72636 .60432 L F
.72655 .60328 m .71817 .59594 L .7148 .60062 L .654 .726 .902 r
F
.72811 .60112 m .71817 .59594 L .72655 .60328 L F
.74478 .6074 m .74015 .60541 L .73663 .60556 L F
.73226 .59975 m .7255 .60186 L .73174 .60189 L .675 .735 .895 r
F
.73828 .6037 m .73175 .60473 L .73801 .60477 L F
.73797 .60193 m .73206 .60403 L .73813 .603 L F
.73828 .6037 m .73228 .60259 L .73175 .60473 L F
.73363 .60059 m .72628 .60148 L .73228 .60259 L F
.73363 .60059 m .7283 .59848 L .72628 .60148 L F
.72794 .60136 m .7283 .59848 L .72628 .60148 L .128 .019 .449 r
F
.7286 .60044 m .72811 .60112 L .73663 .60556 L .654 .726 .902 r
F
.72838 .60132 m .72837 .60076 L .72794 .60136 L .128 .019 .449 r
F
.72837 .60076 m .7283 .59848 L .72794 .60136 L F
.74015 .60541 m .7286 .60044 L .73663 .60556 L .654 .726 .902 r
F
.7286 .60044 m .71817 .59594 L .72811 .60112 L F
.74477 .61 m .74448 .61002 L .74419 .60301 L .642 .403 .541 r
F
.74427 .61708 m .74305 .61748 L .7442 .61851 L .654 .726 .902 r
F
.74332 .6169 m .74305 .61748 L .74427 .61708 L F
.74343 .61692 m .74427 .61708 L .74443 .64861 L .751 .492 .54 r
F
.74428 .6048 m .74231 .60693 L .74265 .60709 L .675 .735 .895 r
F
.74428 .6048 m .74167 .60664 L .74221 .60689 L F
.74428 .6048 m .74209 .60701 L .74222 .60703 L F
.741 .60163 m .74109 .60612 L .74102 .60606 L .929 .648 .486 r
F
.74097 .60659 m .74107 .60641 L .74109 .60367 L 0 0 .386 r
F
.74061 .60459 m .74063 .60734 L .74062 .60722 L .769 .613 .047 r
F
.74064 .60257 m .73813 .603 L .74067 .60327 L .675 .735 .895 r
F
.74058 .60018 m .74061 .60466 L .74061 .60459 L .769 .613 .047 r
F
.74061 .60466 m .74063 .60734 L .74061 .60459 L F
.74065 .60542 m .73801 .60477 L .73817 .60585 L .675 .735 .895 r
F
.74114 .60176 m .74167 .60664 L .74122 .60623 L .929 .648 .486 r
F
.74428 .6048 m .74062 .60478 L .74065 .60542 L .675 .735 .895 r
F
.74062 .60478 m .73801 .60477 L .74065 .60542 L F
.74059 .60036 m .74066 .608 L .74064 .60749 L .769 .613 .047 r
F
.74064 .60749 m .74063 .60734 L .74058 .60018 L F
.73797 .60193 m .73174 .60189 L .73206 .60403 L .675 .735 .895 r
F
.73781 .59847 m .7187 .58873 L .71535 .59339 L .654 .726 .902 r
F
.74218 .58541 m .74112 .59922 L .74199 .59867 L .405 .218 .51 r
F
.74517 .60014 m .74099 .59833 L .73781 .59847 L .654 .726 .902 r
F
.74099 .59833 m .7187 .58873 L .73781 .59847 L F
.74412 .59005 m .74454 .60298 L .74419 .60301 L .642 .403 .541 r
F
.7442 .60196 m .74311 .60435 L .74408 .6045 L .675 .735 .895 r
F
.74428 .6048 m .7444 .60235 L .74344 .60244 L F
.74517 .60014 m .74262 .6027 L .74383 .60294 L .654 .726 .902 r
F
.74105 .58619 m .741 .59944 L .74112 .59922 L 0 0 .386 r
F
.74517 .60014 m .73046 .58201 L .72385 .58485 L .654 .726 .902 r
F
.74419 .5982 m .74335 .59823 L .74336 .59963 L .66 .418 .542 r
F
.7442 .60196 m .74432 .59955 L .74338 .59963 L .675 .735 .895 r
F
.7442 .60196 m .74179 .6003 L .74114 .60075 L F
.74071 .60111 m .741 .60163 L .74101 .60325 L .988 .719 .38 r
F
.74071 .60111 m .74101 .60325 L .74078 .60285 L F
.7442 .60196 m .7405 .60194 L .74063 .60257 L .675 .735 .895 r
F
.74197 .60017 m .7419 .6058 L .74217 .60003 L .405 .218 .51 r
F
.7405 .60478 m .73828 .6037 L .73801 .60477 L .675 .735 .895 r
F
.74428 .6048 m .74083 .60417 L .7405 .60478 L F
.74061 .60209 m .74064 .60258 L .74065 .60539 L .769 .613 .047 r
F
.74064 .60515 m .74065 .60539 L .74066 .608 L F
.74061 .60209 m .74065 .60539 L .74064 .60515 L F
.74061 .60459 m .73828 .6037 L .7405 .60478 L .675 .735 .895 r
F
.7406 .60194 m .73823 .60086 L .73797 .60193 L F
.7406 .60197 m .7406 .60186 L .74058 .60018 L .769 .613 .047 r
F
.741 .59944 m .741 .60101 L .74112 .59922 L 0 0 .386 r
F
.7406 .60197 m .74062 .60482 L .7406 .60186 L .769 .613 .047 r
F
.74062 .60482 m .74062 .60476 L .74058 .60018 L F
.74082 .60134 m .74059 .60178 L .7406 .60194 L .675 .735 .895 r
F
.74092 .60116 m .74059 .60178 L .74061 .60459 L 0 0 .386 r
F
.74062 .60482 m .74064 .60749 L .74062 .60476 L .769 .613 .047 r
F
.74076 .60429 m .74061 .60459 L .74062 .60722 L 0 0 .386 r
F
.74092 .60116 m .74061 .60459 L .74076 .60429 L F
.7442 .60196 m .74064 .60257 L .74067 .60327 L .675 .735 .895 r
F
.74115 .60357 m .74047 .60217 L .74054 .60332 L F
.74114 .60176 m .74165 .60222 L .74166 .60383 L .929 .648 .486 r
F
.7415 .60368 m .74121 .60362 L .74143 .60372 L .675 .735 .895 r
F
.74134 .60354 m .74121 .60362 L .7415 .60368 L F
.74134 .60354 m .74166 .60383 L .74167 .60664 L .929 .648 .486 r
F
.74114 .60176 m .74166 .60383 L .74134 .60354 L F
.7442 .60196 m .74134 .60354 L .7415 .60368 L .675 .735 .895 r
F
.74193 .60302 m .74116 .60626 L .7419 .6058 L .405 .218 .51 r
F
.7442 .60196 m .74082 .60134 L .7406 .60194 L .675 .735 .895 r
F
.74199 .59867 m .74148 .60334 L .74193 .60302 L .405 .218 .51 r
F
.74428 .6048 m .74115 .60357 L .74083 .60417 L .675 .735 .895 r
F
.7419 .6058 m .74211 .60566 L .74216 .60286 L .405 .218 .51 r
F
.74203 .60295 m .74216 .60286 L .74225 .59852 L F
.74428 .6048 m .74182 .6031 L .74115 .60357 L .675 .735 .895 r
F
.7442 .60196 m .74096 .60316 L .74121 .60362 L F
.7419 .6058 m .74216 .60286 L .74203 .60295 L .405 .218 .51 r
F
.74148 .60334 m .74116 .60626 L .74193 .60302 L F
.74182 .60028 m .74113 .60076 L .74116 .60626 L F
.74115 .60357 m .74151 .60289 L .74115 .60357 L .675 .735 .895 r
F
.74182 .6031 m .74151 .60289 L .74115 .60357 L F
.74098 .60387 m .74103 .60379 L .74109 .60084 L 0 0 .386 r
F
.741 .59944 m .74076 .60429 L .74098 .60387 L F
.7405 .60194 m .7404 .60214 L .74063 .60257 L .675 .735 .895 r
F
.74151 .60289 m .74047 .60217 L .74115 .60357 L F
.741 .60101 m .74098 .60387 L .74109 .60084 L 0 0 .386 r
F
.74098 .60387 m .74097 .60659 L .74103 .60379 L F
.741 .60101 m .74109 .60084 L .74112 .59922 L F
.74082 .60134 m .74056 .60129 L .74059 .60178 L .675 .735 .895 r
F
.74056 .60129 m .73823 .60086 L .7406 .60194 L F
.74059 .60036 m .7406 .60197 L .74058 .60018 L .769 .613 .047 r
F
.74029 .60194 m .73797 .60193 L .74063 .60257 L .675 .735 .895 r
F
.74054 .60332 m .73999 .60184 L .73895 .6027 L F
.74047 .60217 m .73999 .60184 L .74054 .60332 L F
.74083 .60417 m .74058 .60412 L .74061 .60459 L F
.74058 .60412 m .73828 .6037 L .74061 .60459 L F
.74098 .60387 m .74062 .60722 L .74097 .60659 L 0 0 .386 r
F
.74076 .60429 m .74062 .60722 L .74098 .60387 L F
.74227 .60279 m .74211 .60566 L .74228 .60555 L .405 .218 .51 r
F
.74225 .59852 m .74216 .60286 L .74227 .60279 L F
.74216 .60286 m .74211 .60566 L .74227 .60279 L F
.7405 .60194 m .74029 .60194 L .7404 .60214 L .675 .735 .895 r
F
.74103 .60379 m .74109 .60367 L .74112 .59922 L 0 0 .386 r
F
.74182 .6031 m .74132 .60119 L .73999 .60184 L .675 .735 .895 r
F
.74428 .6048 m .74256 .6027 L .74182 .6031 L F
.74304 .60255 m .74228 .60555 L .743 .60537 L .57 .345 .536 r
F
.7431 .5983 m .74261 .60268 L .74304 .60255 L F
.74261 .60268 m .74228 .60555 L .74304 .60255 L F
.74517 .60014 m .72385 .58485 L .7187 .58873 L .654 .726 .902 r
F
.7431 .5983 m .74225 .59852 L .74225 .59998 L .57 .345 .536 r
F
.7442 .60196 m .74251 .5999 L .74162 .60018 L .675 .735 .895 r
F
.74293 .59977 m .74225 .59998 L .74228 .60555 L .57 .345 .536 r
F
.7431 .5983 m .74225 .59998 L .74293 .59977 L F
.74199 .59867 m .74112 .59922 L .74113 .60076 L .405 .218 .51 r
F
.74162 .60018 m .74126 .59836 L .73994 .59901 L .675 .735 .895 r
F
.74199 .59867 m .74113 .60076 L .74182 .60028 L .405 .218 .51 r
F
.74197 .60017 m .74217 .60003 L .74225 .59852 L F
.74251 .5999 m .74126 .59836 L .74162 .60018 L .675 .735 .895 r
F
.74256 .6027 m .7425 .60263 L .74227 .60279 L F
.74256 .6027 m .74227 .60279 L .74182 .6031 L F
.7425 .60263 m .74132 .60119 L .74182 .6031 L F
.74242 .60253 m .74285 .60078 L .74132 .60119 L F
.74097 .60659 m .74109 .60367 L .74103 .60379 L 0 0 .386 r
F
.74083 .60417 m .73924 .60281 L .73989 .60399 L .675 .735 .895 r
F
.74115 .60357 m .73924 .60281 L .74083 .60417 L F
.73924 .60281 m .73895 .6027 L .73989 .60399 L F
.74112 .59922 m .74107 .60641 L .74116 .60626 L 0 0 .386 r
F
.7389 .59986 m .73226 .59975 L .73823 .60086 L .675 .735 .895 r
F
.7389 .59986 m .73361 .59777 L .73226 .59975 L F
.73994 .59901 m .73361 .59777 L .7389 .59986 L F
.73994 .59901 m .73567 .59607 L .73361 .59777 L F
.73823 .60086 m .73174 .60189 L .73797 .60193 L F
.73999 .60184 m .73363 .60059 L .73895 .6027 L F
.73567 .59607 m .72831 .59567 L .73361 .59777 L F
.73999 .60184 m .73571 .59888 L .73363 .60059 L F
.74132 .60119 m .73571 .59888 L .73999 .60184 L F
.73567 .59607 m .73141 .59312 L .72831 .59567 L F
.73142 .59592 m .73134 .59307 L .72823 .59564 L .362 .193 .512 r
F
.73361 .59777 m .72831 .59567 L .7263 .59865 L .675 .735 .895 r
F
.73571 .59888 m .73142 .59592 L .7283 .59848 L F
.73837 .59757 m .73142 .59592 L .73571 .59888 L F
.73832 .59477 m .73141 .59312 L .73567 .59607 L F
.73837 .59757 m .73541 .59396 L .73142 .59592 L F
.73541 .59396 m .73134 .59307 L .73142 .59592 L .499 .296 .536 r
F
.7442 .60698 m .73586 .59654 L .73196 .59822 L .654 .726 .902 r
F
.73548 .5968 m .73534 .59677 L .73149 .59876 L .499 .296 .536 r
F
.73534 .59677 m .73142 .59592 L .73148 .59842 L F
.73361 .59777 m .7263 .59865 L .73226 .59975 L .675 .735 .895 r
F
.73534 .59677 m .73148 .59842 L .73149 .59876 L .499 .296 .536 r
F
.73196 .59822 m .73 .58919 L .72335 .59204 L .654 .726 .902 r
F
.73548 .5968 m .73541 .59396 L .73142 .59592 L .499 .296 .536 r
F
.73586 .59654 m .73 .58919 L .73196 .59822 L .654 .726 .902 r
F
.74428 .6048 m .74344 .60244 L .74337 .60244 L .675 .735 .895 r
F
.74428 .6048 m .74337 .60244 L .74256 .6027 L F
.74396 .60239 m .74337 .60244 L .74339 .60525 L .66 .418 .542 r
F
.74435 .60765 m .7435 .60524 L .7426 .6055 L .675 .735 .895 r
F
.73976 .60714 m .73963 .60624 L .73673 .60698 L .654 .726 .902 r
F
.73875 .60685 m .73513 .61063 L .7397 .60772 L .675 .735 .895 r
F
.73976 .60714 m .73673 .60698 L .73808 .6082 L .654 .726 .902 r
F
.74435 .60765 m .73835 .60654 L .73809 .60761 L .675 .735 .895 r
F
.74381 .60522 m .74339 .60525 L .74342 .61231 L .66 .418 .542 r
F
.74396 .60239 m .74339 .60525 L .74381 .60522 L F
.7435 .60524 m .74349 .60522 L .74339 .60525 L .675 .735 .895 r
F
.74435 .60765 m .74448 .60515 L .7435 .60524 L F
.74273 .60477 m .74293 .60363 L .74211 .60384 L F
.743 .60537 m .74311 .60534 L .74322 .60249 L .57 .345 .536 r
F
.74349 .60522 m .74293 .60363 L .7426 .6055 L .675 .735 .895 r
F
.743 .60537 m .74322 .60249 L .74314 .60252 L .57 .345 .536 r
F
.74256 .6027 m .74337 .60244 L .74242 .60253 L .675 .735 .895 r
F
.741 .59944 m .74058 .60018 L .74059 .60178 L 0 0 .386 r
F
.74114 .60075 m .73994 .59901 L .7389 .59986 L .675 .735 .895 r
F
.74179 .6003 m .73994 .59901 L .74114 .60075 L F
.74126 .59836 m .73567 .59607 L .73994 .59901 L F
.74126 .59836 m .73832 .59477 L .73567 .59607 L F
.74278 .59796 m .73832 .59477 L .74126 .59836 L F
.74285 .60078 m .73837 .59757 L .74132 .60119 L F
.74199 .59867 m .74197 .60017 L .74225 .59852 L .405 .218 .51 r
F
.74285 .60078 m .74143 .59676 L .73837 .59757 L .675 .735 .895 r
F
.73832 .59477 m .73538 .59117 L .73141 .59312 L F
.74137 .59396 m .73538 .59117 L .73832 .59477 L F
.74311 .60534 m .73 .58919 L .7442 .60698 L .654 .726 .902 r
F
.74293 .60363 m .7415 .5996 L .73844 .60042 L .675 .735 .895 r
F
.74328 .58508 m .74225 .59852 L .7431 .5983 L .57 .345 .536 r
F
.74218 .58541 m .74199 .59867 L .74225 .59852 L .405 .218 .51 r
F
.74517 .60014 m .73808 .58041 L .73046 .58201 L .654 .726 .902 r
F
.74137 .59396 m .73995 .58995 L .73538 .59117 L .675 .735 .895 r
F
.74143 .59676 m .73541 .59396 L .73837 .59757 L F
.74278 .59796 m .74137 .59396 L .73832 .59477 L F
.74143 .59676 m .74 .59274 L .73541 .59396 L F
.74 .59274 m .73533 .59111 L .73541 .59396 L .592 .368 .545 r
F
.74 .59274 m .73993 .58989 L .73533 .59111 L F
.7415 .5996 m .74008 .59558 L .73548 .5968 L .675 .735 .895 r
F
.74008 .59558 m .73541 .59396 L .73548 .59671 L .592 .368 .545 r
F
.74132 .60119 m .73837 .59757 L .73571 .59888 L .675 .735 .895 r
F
.73541 .59396 m .73533 .59111 L .73134 .59307 L .499 .296 .536 r
F
.74311 .60534 m .7321 .58875 L .73 .58919 L .654 .726 .902 r
F
.73715 .59636 m .73548 .59671 L .73548 .5968 L .592 .368 .545 r
F
.74008 .59558 m .73548 .59671 L .73715 .59636 L F
.73726 .59633 m .73765 .58758 L .7321 .58875 L .654 .726 .902 r
F
.74478 .6074 m .74055 .59564 L .73726 .59633 L F
.74008 .59558 m .74 .59274 L .73541 .59396 L .592 .368 .545 r
F
.74055 .59564 m .73765 .58758 L .73726 .59633 L .654 .726 .902 r
F
.7435 .60524 m .74339 .60525 L .74311 .60534 L .675 .735 .895 r
F
.7435 .60524 m .74311 .60534 L .74312 .60535 L F
.74478 .6074 m .7321 .58875 L .74311 .60534 L .654 .726 .902 r
F
.74312 .60535 m .74311 .60534 L .7426 .6055 L .675 .735 .895 r
F
.7435 .60524 m .74456 .60349 L .74293 .60363 L F
.74517 .60014 m .74527 .59831 L .74448 .59819 L .654 .726 .902 r
F
.74526 .59962 m .74461 .60236 L .74522 .60242 L .734 .478 .541 r
F
.74545 .58512 m .74475 .59957 L .74526 .59962 L F
.74475 .59957 m .74461 .60236 L .74526 .59962 L F
.74545 .58512 m .74444 .59819 L .74481 .59824 L F
.74448 .59819 m .7445 .59794 L .74439 .59796 L .654 .726 .902 r
F
.74432 .59952 m .74601 .59798 L .7444 .59783 L .675 .735 .895 r
F
.7442 .60196 m .74526 .59962 L .74445 .59953 L F
.74445 .59953 m .74424 .60236 L .74446 .60234 L .66 .418 .542 r
F
.74444 .59819 m .74437 .59954 L .74445 .59953 L F
.74437 .59954 m .74424 .60236 L .74445 .59953 L F
.7442 .60196 m .74445 .59953 L .74432 .59955 L .675 .735 .895 r
F
.74419 .5982 m .7441 .60524 L .74444 .59819 L .66 .418 .542 r
F
.74432 .59955 m .74445 .59953 L .74432 .59952 L .675 .735 .895 r
F
.74652 .58549 m .74552 .59834 L .74635 .59865 L .809 .541 .532 r
F
.74652 .58549 m .74635 .59865 L .74659 .59874 L F
.74756 .58631 m .74659 .59874 L .7474 .59937 L .91 .629 .499 r
F
.74756 .58631 m .7474 .59937 L .74763 .59956 L F
.74517 .60014 m .75421 .58125 L .74618 .58015 L .654 .726 .902 r
F
.74528 .59831 m .74526 .59962 L .74552 .59834 L .734 .478 .541 r
F
.74526 .59962 m .74546 .59964 L .74552 .59834 L F
.74526 .59962 m .74601 .59798 L .74432 .59952 L .675 .735 .895 r
F
.74539 .60244 m .74544 .60245 L .74549 .59964 L .734 .478 .541 r
F
.74548 .59964 m .74549 .59964 L .74552 .59834 L F
.74539 .60244 m .74549 .59964 L .74548 .59964 L F
.74633 .59991 m .74653 .59998 L .74659 .59874 L .809 .541 .532 r
F
.74627 .59972 m .74875 .59906 L .74749 .5984 L .675 .735 .895 r
F
.7474 .59937 m .74659 .6 L .74726 .60051 L .91 .629 .499 r
F
.7442 .60196 m .74751 .59985 L .74627 .59972 L .675 .735 .895 r
F
.7474 .59937 m .74738 .6006 L .74763 .59956 L .91 .629 .499 r
F
.74751 .59985 m .74875 .59906 L .74627 .59972 L .675 .735 .895 r
F
.7444 .60234 m .7461 .6008 L .74448 .60065 L F
.74428 .6048 m .74535 .60244 L .7444 .60234 L F
.74526 .59962 m .74518 .60533 L .74546 .59964 L .734 .478 .541 r
F
.74535 .60244 m .7461 .6008 L .7444 .60234 L .675 .735 .895 r
F
.74522 .60242 m .74449 .60516 L .74518 .60523 L .734 .478 .541 r
F
.74531 .60524 m .74539 .60525 L .74544 .60245 L F
.74428 .6048 m .74661 .60281 L .74623 .60269 L .675 .735 .895 r
F
.74448 .60515 m .74617 .60364 L .74456 .60349 L F
.74428 .6048 m .74415 .60734 L .74513 .6072 L F
.74435 .60765 m .74544 .60525 L .74448 .60515 L F
.74544 .60525 m .74617 .60364 L .74448 .60515 L F
.74518 .60523 m .74448 .60522 L .74518 .60533 L .734 .478 .541 r
F
.74449 .60516 m .74448 .60522 L .74518 .60523 L F
.74461 .60236 m .74448 .60522 L .74522 .60242 L F
.74446 .60234 m .74411 .60519 L .74448 .60515 L .66 .418 .542 r
F
.74448 .60515 m .74456 .60349 L .7435 .60524 L .675 .735 .895 r
F
.74448 .60515 m .7441 .60524 L .74448 .60522 L .66 .418 .542 r
F
.74411 .60519 m .7441 .60524 L .74448 .60515 L F
.74478 .6074 m .74311 .60534 L .7442 .60698 L .654 .726 .902 r
F
.7426 .6055 m .74273 .60477 L .7414 .60403 L .675 .735 .895 r
F
.74273 .60477 m .74211 .60384 L .7414 .60403 L F
.74314 .60252 m .74322 .60249 L .74335 .59823 L .57 .345 .536 r
F
.74344 .60244 m .74285 .60078 L .74242 .60253 L .675 .735 .895 r
F
.74251 .5999 m .74278 .59796 L .74126 .59836 L F
.7442 .60196 m .74337 .59963 L .74251 .5999 L F
.74337 .59963 m .74278 .59796 L .74251 .5999 L F
.7431 .5983 m .74308 .59972 L .74335 .59823 L .57 .345 .536 r
F
.74308 .59972 m .743 .60537 L .74328 .59966 L F
.74308 .59972 m .74328 .59966 L .74335 .59823 L F
.74412 .59956 m .74336 .59963 L .74337 .60244 L .66 .418 .542 r
F
.74412 .59956 m .74337 .60244 L .74396 .60239 L F
.74419 .5982 m .74336 .59963 L .74412 .59956 L F
.74338 .59963 m .7444 .59783 L .74278 .59796 L .675 .735 .895 r
F
.74432 .59955 m .7444 .59783 L .74338 .59963 L F
.74344 .60244 m .74448 .60065 L .74285 .60078 L F
.74422 .60733 m .74448 .61002 L .74423 .61004 L .642 .403 .541 r
F
.74478 .6074 m .74358 .60992 L .74423 .61004 L .654 .726 .902 r
F
.74423 .61014 m .74253 .61165 L .74415 .6118 L .675 .735 .895 r
F
.74362 .60993 m .74423 .61004 L .74423 .61014 L .751 .492 .54 r
F
.74362 .60993 m .74423 .61014 L .74363 .61005 L F
.74435 .60765 m .74329 .61 L .74423 .61014 L .675 .735 .895 r
F
.74329 .61 m .74253 .61165 L .74423 .61014 L F
.74363 .61005 m .74423 .61014 L .74427 .61708 L .751 .492 .54 r
F
.74419 .5982 m .74342 .61231 L .74401 .61228 L .66 .418 .542 r
F
.7444 .60235 m .74448 .60065 L .74344 .60244 L .675 .735 .895 r
F
.74424 .60236 m .7441 .60524 L .74446 .60234 L .66 .418 .542 r
F
.74437 .58499 m .74419 .5982 L .74444 .59819 L F
.73823 .60086 m .73226 .59975 L .73174 .60189 L .675 .735 .895 r
F
.73895 .6027 m .73228 .60259 L .73828 .6037 L F
.7283 .59848 m .72621 .59863 L .72628 .60148 L .128 .019 .449 r
F
.7283 .59848 m .72823 .59564 L .72621 .59863 L F
.73895 .6027 m .73363 .60059 L .73228 .60259 L .675 .735 .895 r
F
.73571 .59888 m .7283 .59848 L .73363 .60059 L F
.73142 .59592 m .72823 .59564 L .7283 .59848 L .362 .193 .512 r
F
.72873 .60049 m .72335 .59204 L .71817 .59594 L .654 .726 .902 r
F
.74478 .6074 m .73186 .59814 L .72873 .60049 L F
.73108 .59872 m .7283 .59848 L .72837 .60076 L .362 .193 .512 r
F
.73149 .59876 m .73142 .59592 L .7283 .59848 L F
.73186 .59814 m .72335 .59204 L .72873 .60049 L .654 .726 .902 r
F
.73149 .59876 m .73108 .59872 L .72838 .60132 L .362 .193 .512 r
F
.73108 .59872 m .72837 .60076 L .72838 .60132 L F
.74448 .60522 m .74359 .64364 L .74468 .64355 L .66 .418 .542 r
F
.74439 .61467 m .74332 .6169 L .74427 .61708 L .654 .726 .902 r
F
.73808 .6082 m .73597 .60845 L .73728 .6087 L F
.73808 .6082 m .73728 .6087 L .73935 .6091 L F
.73809 .60761 m .73215 .60973 L .73825 .60869 L .675 .735 .895 r
F
.73835 .60654 m .73182 .60758 L .73809 .60761 L F
.73835 .60654 m .73236 .60543 L .73182 .60758 L F
.73903 .60554 m .73371 .60343 L .73236 .60543 L F
.73371 .60343 m .72636 .60432 L .73236 .60543 L F
.73371 .60343 m .72838 .60132 L .72636 .60432 L F
.73578 .60172 m .72838 .60132 L .73371 .60343 L F
.73578 .60172 m .73149 .59876 L .72838 .60132 L F
.74122 .6124 m .7296 .59646 L .72295 .59931 L .654 .726 .902 r
F
.74319 .61687 m .74307 .61685 L .74265 .60709 L .751 .492 .54 r
F
.74439 .61467 m .7425 .61235 L .74122 .6124 L .654 .726 .902 r
F
.74103 .6136 m .7411 .61347 L .74116 .60626 L 0 0 .386 r
F
.74116 .60626 m .7411 .61347 L .74119 .6133 L F
.74079 .60843 m .74104 .60887 L .74107 .61571 L .988 .719 .38 r
F
.73978 .61056 m .73774 .6148 L .74104 .61123 L .675 .735 .895 r
F
.74095 .61374 m .74103 .6136 L .74107 .60641 L 0 0 .386 r
F
.74126 .60887 m .74169 .60926 L .74173 .6163 L .929 .648 .486 r
F
.74082 .61524 m .74077 .61516 L .74066 .608 L .988 .719 .38 r
F
.74079 .60843 m .74107 .61571 L .74087 .61535 L F
.74087 .61535 m .74082 .61524 L .74072 .6081 L F
.74097 .60659 m .74066 .61426 L .74095 .61374 L 0 0 .386 r
F
.74079 .60843 m .74087 .61535 L .74073 .60831 L .988 .719 .38 r
F
.73903 .60554 m .73236 .60543 L .73835 .60654 L .675 .735 .895 r
F
.7425 .61235 m .7296 .59646 L .74122 .6124 L .654 .726 .902 r
F
.74435 .60765 m .74007 .60468 L .73903 .60554 L .675 .735 .895 r
F
.7441 .60524 m .74401 .61228 L .74448 .60522 L .66 .418 .542 r
F
.74401 .61228 m .74359 .64364 L .74431 .61227 L F
.74478 .6074 m .74423 .61004 L .74465 .61001 L .654 .726 .902 r
F
.74519 .61001 m .74415 .6118 L .74578 .61167 L .675 .735 .895 r
F
.74477 .61 m .74477 .61006 L .74448 .61002 L .642 .403 .541 r
F
.74477 .61006 m .74448 .6101 L .74448 .61002 L F
.74435 .60765 m .74423 .61014 L .74519 .61001 L .675 .735 .895 r
F
.74423 .61014 m .74415 .6118 L .74519 .61001 L F
.74477 .61006 m .745 .61702 L .74448 .6101 L .642 .403 .541 r
F
.74401 .61228 m .74431 .61227 L .74448 .60522 L .66 .418 .542 r
F
.73236 .60543 m .72556 .60754 L .73182 .60758 L .675 .735 .895 r
F
.73236 .60543 m .72636 .60432 L .72556 .60754 L F
.73931 .61248 m .72295 .59931 L .71777 .60321 L .654 .726 .902 r
F
.74066 .608 m .74077 .61516 L .7407 .61504 L .988 .719 .38 r
F
.74439 .61467 m .74122 .6124 L .73931 .61248 L .654 .726 .902 r
F
.74068 .61462 m .74067 .6145 L .74063 .60734 L .769 .613 .047 r
F
.74064 .60749 m .7407 .61504 L .74068 .61462 L F
.74067 .6145 m .74066 .6144 L .74062 .60722 L F
.73883 .60969 m .73521 .61347 L .73978 .61056 L .675 .735 .895 r
F
.73825 .60869 m .7333 .61174 L .73883 .60969 L F
.74122 .6124 m .72295 .59931 L .73931 .61248 L .654 .726 .902 r
F
.74343 .61692 m .74443 .64861 L .74319 .61687 L .751 .492 .54 r
F
.74319 .61687 m .74443 .64861 L .74307 .61685 L F
.74401 .61228 m .74342 .61231 L .74359 .64364 L .66 .418 .542 r
F
.7418 .61292 m .74119 .6133 L .74136 .64476 L .405 .218 .51 r
F
.7419 .6058 m .74119 .6133 L .7418 .61292 L F
.74437 .58499 m .74335 .59823 L .74419 .5982 L .66 .418 .542 r
F
.74078 .6065 m .73963 .60624 L .73976 .60714 L .654 .726 .902 r
F
.743 .60537 m .74291 .61244 L .74313 .60534 L .57 .345 .536 r
F
.73898 .61345 m .71777 .60321 L .7144 .60789 L .654 .726 .902 r
F
.73883 .60969 m .7333 .61174 L .73521 .61347 L .675 .735 .895 r
F
.74059 .61304 m .71777 .60321 L .73898 .61345 L .654 .726 .902 r
F
.74291 .60979 m .7429 .60979 L .74265 .60709 L .751 .492 .54 r
F
.74292 .60994 m .74281 .60992 L .74265 .60709 L F
.7446 .60759 m .74119 .60946 L .74248 .60971 L .654 .726 .902 r
F
.74435 .60765 m .74767 .60642 L .74737 .60572 L .675 .735 .895 r
F
.74478 .6074 m .74456 .60753 L .7446 .60759 L .654 .726 .902 r
F
.74456 .60753 m .74119 .60946 L .7446 .60759 L F
.74435 .60765 m .74139 .60953 L .74185 .61036 L .675 .735 .895 r
F
.743 .60537 m .74228 .60555 L .74232 .61259 L .57 .345 .536 r
F
.74439 .61467 m .74163 .61625 L .74242 .61664 L .654 .726 .902 r
F
.74291 .61244 m .74232 .61259 L .74248 .64398 L .57 .345 .536 r
F
.743 .60537 m .74232 .61259 L .74291 .61244 L F
.7418 .61292 m .74136 .64476 L .74197 .61281 L .405 .218 .51 r
F
.7418 .61292 m .74197 .61281 L .74211 .60566 L F
.73942 .61441 m .73898 .61345 L .73595 .61423 L .654 .726 .902 r
F
.74043 .61378 m .73898 .61345 L .73942 .61441 L F
.73215 .60973 m .72777 .61378 L .7333 .61174 L .675 .735 .895 r
F
.73215 .60973 m .72604 .61077 L .72777 .61378 L F
.73898 .61345 m .7144 .60789 L .73595 .61423 L .654 .726 .902 r
F
.74291 .61244 m .74248 .64398 L .74308 .6124 L .57 .345 .536 r
F
.74292 .60994 m .74319 .61687 L .74281 .60992 L .751 .492 .54 r
F
.74291 .61244 m .74308 .6124 L .74335 .59823 L .57 .345 .536 r
F
.74342 .61231 m .74248 .64398 L .74359 .64364 L F
.74335 .59823 m .74308 .6124 L .74342 .61231 L F
.74308 .6124 m .74248 .64398 L .74342 .61231 L F
.7333 .61174 m .72777 .61378 L .73063 .61638 L .675 .735 .895 r
F
.73595 .61423 m .72713 .61377 L .73319 .61494 L .654 .726 .902 r
F
.73595 .61423 m .73319 .61494 L .73658 .6156 L F
.72713 .61377 m .71308 .61303 L .73658 .6156 L F
.74328 .58508 m .7431 .5983 L .74335 .59823 L .57 .345 .536 r
F
.74035 .60762 m .73809 .60761 L .74071 .60827 L .675 .735 .895 r
F
.74211 .60566 m .74197 .61281 L .74228 .60555 L .405 .218 .51 r
F
.74229 .61793 m .74094 .61918 L .74237 .61808 L .654 .726 .902 r
F
.74173 .6163 m .74287 .64835 L .74189 .64788 L .845 .571 .524 r
F
.74197 .61281 m .74136 .64476 L .74211 .61272 L .405 .218 .51 r
F
.74197 .61281 m .74211 .61272 L .74228 .60555 L F
.73776 .61546 m .73658 .6156 L .73732 .61574 L .654 .726 .902 r
F
.73774 .6148 m .7389 .61965 L .74072 .61565 L .675 .735 .895 r
F
.73776 .61546 m .73732 .61574 L .73957 .61618 L .654 .726 .902 r
F
.73521 .61347 m .73063 .61638 L .73443 .61838 L .675 .735 .895 r
F
.73658 .6156 m .71389 .61828 L .73957 .61618 L .654 .726 .902 r
F
.74439 .61467 m .74074 .61581 L .74163 .61625 L F
.74074 .61581 m .73371 .618 L .74163 .61625 L F
.73371 .618 m .71678 .62329 L .72023 .62648 L F
.73371 .618 m .72023 .62648 L .72155 .6277 L F
.74218 .61652 m .74287 .64835 L .74203 .61645 L .845 .571 .524 r
F
.7419 .61638 m .74287 .64835 L .74173 .6163 L F
.74232 .61259 m .74136 .64476 L .74248 .64398 L .405 .218 .51 r
F
.74228 .60555 m .74211 .61272 L .74232 .61259 L F
.74211 .61272 m .74136 .64476 L .74232 .61259 L F
.74228 .61679 m .73798 .61902 L .73533 .62375 L .654 .726 .902 r
F
.74225 .61677 m .73798 .61902 L .74228 .61679 L F
.74107 .60641 m .74103 .6136 L .74116 .60626 L 0 0 .386 r
F
.74087 .61535 m .74107 .61571 L .74124 .64728 L .988 .719 .38 r
F
.74087 .61535 m .74124 .64728 L .74082 .61524 L F
.74103 .6136 m .74082 .64578 L .7411 .61347 L 0 0 .386 r
F
.73533 .62375 m .72155 .6277 L .72787 .63122 L .654 .726 .902 r
F
.73798 .61902 m .72155 .6277 L .73533 .62375 L F
.74068 .61462 m .74086 .64659 L .74067 .6145 L .769 .613 .047 r
F
.74088 .61819 m .73533 .62375 L .74093 .61901 L .654 .726 .902 r
F
.73533 .62375 m .72787 .63122 L .73468 .62492 L F
.73533 .62375 m .73468 .62492 L .74227 .61788 L F
.7407 .61504 m .74124 .64728 L .74086 .64659 L .988 .719 .38 r
F
.74119 .6133 m .74082 .64578 L .74136 .64476 L 0 0 .386 r
F
.7411 .61347 m .74082 .64578 L .74119 .6133 L F
.74082 .61524 m .74124 .64728 L .74077 .61516 L .988 .719 .38 r
F
.74077 .61516 m .74124 .64728 L .7407 .61504 L F
.74227 .61788 m .73468 .62492 L .74229 .61793 L .654 .726 .902 r
F
.73468 .62492 m .72787 .63122 L .73463 .625 L F
.74097 .60659 m .74095 .61374 L .74107 .60641 L 0 0 .386 r
F
.74095 .61374 m .74082 .64578 L .74103 .6136 L F
.74068 .61462 m .7407 .61504 L .74086 .64659 L .769 .613 .047 r
F
.74094 .61918 m .73463 .625 L .74095 .61935 L .654 .726 .902 r
F
.74063 .60734 m .74067 .6145 L .74062 .60722 L .769 .613 .047 r
F
.74067 .6145 m .74086 .64659 L .74066 .6144 L F
.74108 .62159 m .73463 .625 L .73532 .63362 L .654 .726 .902 r
F
.74095 .61935 m .73463 .625 L .74108 .62159 L F
.74097 .60659 m .74062 .60722 L .74066 .61426 L 0 0 .386 r
F
.74066 .61426 m .74086 .64659 L .74082 .64578 L .769 .613 .047 r
F
.74066 .6144 m .74086 .64659 L .74066 .61426 L F
.74095 .61374 m .74066 .61426 L .74082 .64578 L 0 0 .386 r
F
.73463 .625 m .72787 .63122 L .73064 .63211 L .654 .726 .902 r
F
.73463 .625 m .73064 .63211 L .73532 .63362 L F
.74439 .59796 m .74618 .58015 L .73808 .58041 L F
.7445 .59794 m .74618 .58015 L .74439 .59796 L F
.74545 .58512 m .74528 .59831 L .74552 .59834 L .734 .478 .541 r
F
.74527 .59831 m .74618 .58015 L .74448 .59819 L .654 .726 .902 r
F
.74481 .59824 m .74444 .59819 L .74448 .60522 L .734 .478 .541 r
F
.74435 .60765 m .74586 .60949 L .74488 .60801 L .675 .735 .895 r
F
.74448 .61002 m .74602 .6484 L .74423 .61004 L .642 .403 .541 r
F
.74439 .61467 m .74427 .61708 L .74523 .617 L .654 .726 .902 r
F
.74731 .60631 m .74751 .60647 L .74751 .6063 L .91 .629 .499 r
F
.74731 .60631 m .74751 .6063 L .74732 .60616 L F
.74737 .60572 m .7483 .60618 L .74848 .60502 L .675 .735 .895 r
F
.74796 .60433 m .74767 .6066 L .74796 .60726 L .982 .725 .331 r
F
.74767 .60642 m .7483 .60618 L .74737 .60572 L .675 .735 .895 r
F
.7483 .60618 m .74988 .6056 L .74848 .60502 L F
.75613 .60417 m .7629 .60207 L .75667 .60203 L F
.7495 .60406 m .75613 .60417 L .75017 .60307 L F
.75667 .60203 m .76242 .59885 L .75635 .59989 L F
.7495 .60406 m .75479 .60615 L .75613 .60417 L F
.75054 .60484 m .7568 .60487 L .75648 .60272 L F
.75054 .60484 m .75648 .60272 L .75038 .60376 L F
.76259 .60168 m .76251 .59884 L .76078 .59582 L .986 .71 .375 r
F
.75648 .60272 m .76086 .59866 L .75533 .60071 L .675 .735 .895 r
F
.75648 .60272 m .76259 .60168 L .76086 .59866 L F
.76259 .60168 m .76078 .59582 L .76086 .59866 L .986 .71 .375 r
F
.76267 .60452 m .76259 .60168 L .76086 .59866 L F
.74988 .6056 m .7535 .60182 L .74893 .60473 L .675 .735 .895 r
F
.74988 .6056 m .75541 .60355 L .7535 .60182 L F
.76267 .60452 m .76086 .59866 L .76094 .60151 L .986 .71 .375 r
F
.75541 .60355 m .76094 .60151 L .75808 .59891 L .675 .735 .895 r
F
.74478 .6074 m .77241 .59878 L .76764 .59436 L .654 .726 .902 r
F
.74767 .60642 m .74818 .60699 L .7483 .60618 L .675 .735 .895 r
F
.74435 .60765 m .74793 .60704 L .74767 .60642 L F
.74793 .60704 m .74818 .60699 L .74767 .60642 L F
.74818 .60699 m .75046 .60661 L .7483 .60618 L F
.75479 .60615 m .7621 .60527 L .75613 .60417 L F
.76227 .60813 m .76219 .60529 L .76299 .60207 L 0 0 .27 r
F
.75613 .60417 m .7621 .60527 L .7629 .60207 L .675 .735 .895 r
F
.76227 .60813 m .76299 .60207 L .76307 .60491 L 0 0 .27 r
F
.75627 .60702 m .76307 .60491 L .7568 .60487 L .675 .735 .895 r
F
.75027 .60591 m .75627 .60702 L .7568 .60487 L F
.76307 .60491 m .76299 .60207 L .76251 .59884 L .841 .646 .102 r
F
.75027 .60591 m .7568 .60487 L .75054 .60484 L .675 .735 .895 r
F
.76307 .60491 m .76251 .59884 L .76259 .60168 L .841 .646 .102 r
F
.7568 .60487 m .76307 .60491 L .76259 .60168 L .675 .735 .895 r
F
.76315 .60775 m .76307 .60491 L .76259 .60168 L .841 .646 .102 r
F
.7568 .60487 m .76259 .60168 L .75648 .60272 L .675 .735 .895 r
F
.76315 .60775 m .76259 .60168 L .76267 .60452 L .841 .646 .102 r
F
.75046 .60661 m .75541 .60355 L .74988 .6056 L .675 .735 .895 r
F
.75046 .60661 m .75656 .60556 L .75541 .60355 L F
.75656 .60556 m .76094 .60151 L .75541 .60355 L F
.75656 .60556 m .76267 .60452 L .76094 .60151 L F
.74478 .6074 m .77529 .60379 L .77241 .59878 L .654 .726 .902 r
F
.74804 .60728 m .74804 .60745 L .74811 .60744 L .982 .725 .331 r
F
.75479 .60615 m .76008 .60825 L .7621 .60527 L .675 .735 .895 r
F
.75627 .60702 m .76227 .60813 L .76307 .60491 L F
.7496 .60691 m .75627 .60702 L .75027 .60591 L F
.75688 .60772 m .76315 .60775 L .76267 .60452 L F
.75688 .60772 m .76267 .60452 L .75656 .60556 L F
.75062 .60768 m .75688 .60772 L .75656 .60556 L F
.75062 .60768 m .75656 .60556 L .75046 .60661 L F
.74478 .6074 m .77609 .60904 L .77529 .60379 L .654 .726 .902 r
F
.74803 .60796 m .74811 .60761 L .74803 .60811 L 0 0 .158 r
F
.7481 .60747 m .74811 .60761 L .74803 .60796 L F
.74731 .60631 m .74662 .60578 L .74666 .61282 L .91 .629 .499 r
F
.74808 .61505 m .74831 .64592 L .74806 .61517 L 0 0 .158 r
F
.74806 .61517 m .74831 .64592 L .74805 .61527 L F
.74802 .61541 m .74831 .64592 L .74819 .64673 L F
.74805 .61527 m .74831 .64592 L .74802 .61541 L F
.74808 .61505 m .74815 .61464 L .74831 .64592 L F
.74815 .61464 m .74788 .64488 L .74831 .64592 L .982 .725 .331 r
F
.74737 .60926 m .75085 .61392 L .74948 .61077 L .654 .726 .902 r
F
.74803 .60811 m .74811 .60761 L .74815 .61464 L 0 0 .158 r
F
.74803 .60811 m .74815 .61464 L .74808 .61505 L F
.74811 .60761 m .74807 .61446 L .74815 .61464 L .982 .725 .331 r
F
.74807 .61446 m .74788 .64488 L .74815 .61464 L F
.74799 .60837 m .74805 .61527 L .74802 .61541 L 0 0 .158 r
F
.74804 .60745 m .74801 .61433 L .74811 .60761 L .982 .725 .331 r
F
.74801 .61433 m .74788 .64488 L .74807 .61446 L F
.74808 .61505 m .74806 .61517 L .748 .60825 L 0 0 .158 r
F
.74806 .61517 m .74805 .61527 L .74799 .60837 L F
.74801 .61433 m .74807 .61446 L .74811 .60761 L .982 .725 .331 r
F
.74834 .61344 m .77202 .60605 L .74743 .61299 L .654 .726 .902 r
F
.74749 .61312 m .74743 .61299 L .74726 .61304 L F
.74834 .61344 m .74743 .61299 L .74749 .61312 L F
.74741 .61295 m .77202 .60605 L .76725 .60163 L F
.74722 .61325 m .74738 .61338 L .74751 .60647 L .91 .629 .499 r
F
.74726 .61304 m .74743 .61299 L .74741 .61295 L .654 .726 .902 r
F
.74743 .61299 m .77202 .60605 L .74741 .61295 L F
.74439 .61467 m .74834 .61344 L .74726 .61304 L F
.74617 .61682 m .74704 .64797 L .74604 .61687 L .519 .306 .53 r
F
.74666 .61282 m .74576 .64368 L .74683 .64406 L .809 .541 .532 r
F
.74478 .6074 m .74743 .6093 L .74761 .60923 L .654 .726 .902 r
F
.74662 .60578 m .74647 .61274 L .74666 .61282 L .809 .541 .532 r
F
.74647 .61274 m .74576 .64368 L .74666 .61282 L F
.74722 .61325 m .74666 .61282 L .74683 .64406 L .91 .629 .499 r
F
.74731 .60631 m .74666 .61282 L .74722 .61325 L F
.74731 .60631 m .74722 .61325 L .74751 .60647 L F
.74646 .60572 m .74633 .61269 L .74662 .60578 L .809 .541 .532 r
F
.74633 .61269 m .74576 .64368 L .74647 .61274 L F
.74633 .61269 m .74647 .61274 L .74662 .60578 L F
.74753 .6061 m .74769 .61589 L .74759 .61605 L .088 0 .422 r
F
.74767 .6066 m .74752 .61348 L .74771 .61363 L .91 .629 .499 r
F
.7465 .61255 m .76093 .5981 L .7455 .61238 L .654 .726 .902 r
F
.74559 .61242 m .7455 .61238 L .74548 .6124 L F
.7465 .61255 m .7455 .61238 L .74559 .61242 L F
.74796 .60726 m .74794 .61417 L .74804 .60745 L .982 .725 .331 r
F
.75027 .60093 m .7552 .59789 L .7497 .59993 L .675 .735 .895 r
F
.7497 .59993 m .7552 .59789 L .7533 .59617 L F
.75808 .59891 m .75421 .59406 L .75428 .5969 L .861 .585 .519 r
F
.74566 .61203 m .76093 .5981 L .75347 .5957 L .654 .726 .902 r
F
.74548 .6124 m .74578 .61212 L .74566 .61203 L F
.74578 .61212 m .76093 .5981 L .74566 .61203 L F
.74439 .61467 m .7465 .61255 L .74548 .6124 L F
.74518 .60533 m .74448 .60522 L .74451 .61226 L .734 .478 .541 r
F
.74456 .61706 m .74602 .6484 L .74427 .61708 L .642 .403 .541 r
F
.74509 .61235 m .74451 .61226 L .74468 .64355 L .734 .478 .541 r
F
.74518 .60533 m .74451 .61226 L .74509 .61235 L F
.74556 .60538 m .74496 .60516 L .74489 .60528 L .654 .726 .902 r
F
.74574 .60541 m .74496 .60516 L .74556 .60538 L F
.74628 .5999 m .74553 .59965 L .74556 .60538 L .809 .541 .532 r
F
.74597 .60553 m .74556 .60538 L .74559 .61242 L F
.74635 .59865 m .74553 .59965 L .74628 .5999 L F
.74529 .59957 m .74749 .5984 L .74601 .59798 L .675 .735 .895 r
F
.74526 .59962 m .74533 .59958 L .74529 .59957 L F
.74533 .59958 m .74749 .5984 L .74529 .59957 L F
.74635 .59865 m .74633 .59991 L .74659 .59874 L .809 .541 .532 r
F
.74627 .59972 m .74749 .5984 L .74526 .59962 L .675 .735 .895 r
F
.74518 .60533 m .74509 .61235 L .7453 .60534 L .734 .478 .541 r
F
.74518 .60533 m .7453 .60534 L .74552 .59834 L F
.74535 .60244 m .7454 .60241 L .74537 .6024 L .675 .735 .895 r
F
.7454 .60241 m .74759 .60122 L .74537 .6024 L F
.74637 .60254 m .74759 .60122 L .74535 .60244 L F
.74531 .60524 m .74544 .60245 L .74539 .60244 L .734 .478 .541 r
F
.74749 .5984 m .74782 .59399 L .74601 .59798 L .675 .735 .895 r
F
.74749 .5984 m .75079 .59484 L .74782 .59399 L F
.74601 .59798 m .74782 .59399 L .74461 .59369 L F
.74759 .60122 m .74792 .5968 L .7461 .6008 L F
.7461 .6008 m .74792 .5968 L .74469 .59649 L F
.75079 .59484 m .74963 .59001 L .74782 .59399 L F
.75079 .59484 m .75408 .59127 L .74963 .59001 L F
.74617 .60364 m .74476 .59934 L .74456 .60349 L F
.74617 .60364 m .74799 .59964 L .74476 .59934 L F
.74782 .59399 m .74481 .58956 L .74461 .59369 L F
.74782 .59399 m .74963 .59001 L .74481 .58956 L F
.7509 .59764 m .74974 .59279 L .74792 .5968 L F
.74601 .59798 m .74461 .59369 L .7444 .59783 L F
.74792 .5968 m .74489 .59234 L .74469 .59649 L F
.74792 .5968 m .74974 .59279 L .74489 .59234 L F
.7461 .6008 m .74469 .59649 L .74448 .60065 L F
.74799 .59964 m .74497 .59518 L .74476 .59934 L F
.74799 .59964 m .74981 .59563 L .74497 .59518 L F
.74974 .59279 m .74966 .58995 L .74481 .5895 L .731 .478 .545 r
F
.75421 .59406 m .74966 .58995 L .74974 .59279 L .794 .529 .537 r
F
.74974 .59279 m .74481 .5895 L .74489 .59234 L .731 .478 .545 r
F
.74981 .59563 m .74974 .59279 L .74489 .59234 L F
.74981 .59563 m .74489 .59234 L .74497 .59518 L F
.74489 .60528 m .75386 .58843 L .74579 .58732 L .654 .726 .902 r
F
.74509 .61235 m .74539 .60525 L .74531 .60524 L .734 .478 .541 r
F
.74632 .60552 m .74766 .60407 L .74545 .60523 L .675 .735 .895 r
F
.74625 .60564 m .74646 .60572 L .74646 .60557 L .809 .541 .532 r
F
.74625 .60564 m .74646 .60557 L .74627 .6055 L F
.74738 .6006 m .74731 .60631 L .74758 .60075 L .91 .629 .499 r
F
.74697 .60309 m .74885 .60189 L .74632 .60259 L .675 .735 .895 r
F
.74797 .60034 m .74797 .60157 L .74807 .60057 L .982 .725 .331 r
F
.74797 .60157 m .74804 .60173 L .74807 .60057 L F
.74787 .60134 m .75027 .60093 L .7476 .6007 L .675 .735 .895 r
F
.74797 .60157 m .74796 .60433 L .74804 .60173 L .982 .725 .331 r
F
.74796 .60433 m .74801 .60443 L .74807 .60057 L F
.74733 .60286 m .7498 .60276 L .74885 .60189 L .675 .735 .895 r
F
.7474 .59937 m .74662 .60578 L .74731 .60631 L .91 .629 .499 r
F
.74697 .60309 m .74741 .60304 L .74733 .60286 L .675 .735 .895 r
F
.74792 .60145 m .74764 .6008 L .74767 .6066 L .982 .725 .331 r
F
.74741 .60304 m .7498 .60276 L .74733 .60286 L .675 .735 .895 r
F
.74801 .60443 m .74805 .60454 L .74807 .60057 L .982 .725 .331 r
F
.74761 .60357 m .7498 .60276 L .74697 .60309 L .675 .735 .895 r
F
.74761 .60357 m .74819 .60401 L .7483 .60332 L F
.7465 .61255 m .76725 .60163 L .76093 .5981 L .654 .726 .902 r
F
.74439 .61467 m .74778 .61274 L .7465 .61255 L F
.74794 .61417 m .74801 .61433 L .74804 .60745 L .982 .725 .331 r
F
.74778 .61274 m .76725 .60163 L .7465 .61255 L .654 .726 .902 r
F
.745 .61702 m .74602 .6484 L .74476 .61704 L .642 .403 .541 r
F
.74509 .61235 m .74468 .64355 L .74526 .61237 L .734 .478 .541 r
F
.74616 .61263 m .74576 .64368 L .74633 .61269 L .809 .541 .532 r
F
.74616 .61263 m .74633 .61269 L .74646 .60572 L F
.74991 .61402 m .77012 .61602 L .75355 .61359 L .654 .726 .902 r
F
.75287 .61512 m .77012 .61602 L .74991 .61402 L F
.77012 .61602 m .7757 .61631 L .75355 .61359 L F
.74523 .617 m .74493 .61989 L .74581 .61862 L F
.745 .61702 m .74585 .61694 L .74602 .6484 L .642 .403 .541 r
F
.74427 .61708 m .74602 .6484 L .74443 .64861 L F
.74559 .61242 m .74468 .64355 L .74576 .64368 L .734 .478 .541 r
F
.74439 .61467 m .74528 .61715 L .74614 .61683 L .654 .726 .902 r
F
.74526 .61237 m .74468 .64355 L .74559 .61242 L .734 .478 .541 r
F
.74771 .61363 m .74683 .64406 L .74788 .64488 L .91 .629 .499 r
F
.74752 .61348 m .74683 .64406 L .74771 .61363 L F
.74834 .61344 m .7749 .61106 L .77202 .60605 L .654 .726 .902 r
F
.74991 .61402 m .7749 .61106 L .74834 .61344 L F
.74616 .61263 m .74559 .61242 L .74576 .64368 L .809 .541 .532 r
F
.74794 .61417 m .74771 .61363 L .74788 .64488 L .982 .725 .331 r
F
.74839 .6152 m .74909 .61574 L .74997 .61541 L .654 .726 .902 r
F
.74857 .61562 m .74909 .61574 L .74839 .6152 L F
.74937 .61493 m .74997 .61541 L .75102 .61502 L F
.74722 .61325 m .74683 .64406 L .74738 .61338 L .91 .629 .499 r
F
.75102 .61502 m .77436 .62145 L .7757 .61631 L .654 .726 .902 r
F
.74909 .61574 m .77436 .62145 L .75102 .61502 L F
.75202 .6164 m .77099 .62612 L .77436 .62145 L F
.74901 .61666 m .77099 .62612 L .75202 .6164 L F
.75173 .61596 m .75621 .6263 L .75955 .62559 L F
.7478 .61677 m .7658 .63002 L .74901 .61666 L F
.74775 .61708 m .7658 .63002 L .7478 .61677 L F
.74663 .61743 m .75248 .62463 L .74711 .61674 L F
.75248 .62463 m .75916 .63286 L .75173 .62291 L F
.75248 .62463 m .75173 .62291 L .74695 .61651 L F
.74794 .61417 m .74788 .64488 L .74801 .61433 L .982 .725 .331 r
F
.74775 .61708 m .75916 .63286 L .7658 .63002 L .654 .726 .902 r
F
.74769 .6175 m .75916 .63286 L .74775 .61708 L F
.74752 .61853 m .75151 .63447 L .75916 .63286 L F
.74725 .62024 m .75151 .63447 L .74752 .61853 L F
.40152 .86003 m .39079 .87077 L .40439 .86218 L .683 .77 .917 r
F
.40152 .86003 m .38505 .86647 L .39079 .87077 L F
.79807 .62292 m .83459 .62036 L .8048 .61362 L .654 .726 .902 r
F
.77163 .61153 m .79807 .62292 L .8048 .61362 L F
.36382 .8697 m .36859 .8729 L .36907 .87747 L .981 .691 .346 r
F
.36382 .8697 m .36334 .86514 L .36859 .8729 L F
.38155 .86129 m .36859 .8729 L .38505 .86647 L .683 .77 .917 r
F
.38155 .86129 m .36334 .86514 L .36859 .8729 L F
0 g
.36859 .8729 m
.37276 .87602 L
s
.38418 .76697 m .36694 .75662 L .35461 .76622 L .673 .758 .915 r
F
.127 .923 .03 r
.35579 .75142 m
.3561 .81511 L
s
0 g
.34664 .77728 m
.35461 .76622 L
s
.39475 .76198 m .36694 .75662 L .38418 .76697 L .673 .758 .915 r
F
.5523 .63873 m .51897 .63663 L .54897 .6434 L .654 .726 .902 r
F
.44449 .75539 m .43971 .73788 L .43256 .7526 L .673 .758 .914 r
F
.44449 .75539 m .45762 .74208 L .43971 .73788 L F
.60939 .64656 m .63404 .63296 L .60648 .64156 L .654 .726 .902 r
F
.60939 .64656 m .63984 .64295 L .63404 .63296 L F
.63049 .7516 m .64259 .73633 L .64292 .742 L .392 .239 .551 r
F
.61336 .74125 m .63049 .7516 L .64292 .742 L .673 .758 .915 r
F
.60274 .74624 m .63049 .7516 L .61336 .74125 L F
0 g
.61456 .75909 m
.63049 .7516 L
s
.55272 .63146 m .52606 .62002 L .5194 .62936 L .654 .726 .902 r
F
.55787 .62757 m .52606 .62002 L .55272 .63146 L F
.5584 .62038 m .537 .60512 L .52675 .61287 L F
.56498 .61755 m .537 .60512 L .5584 .62038 L F
.43218 .74708 m .42002 .73126 L .41934 .7463 L .673 .758 .914 r
F
.43218 .74708 m .43929 .73244 L .42002 .73126 L F
.60689 .6343 m .62488 .61686 L .60211 .62988 L .654 .726 .902 r
F
.60689 .6343 m .63444 .62569 L .62488 .61686 L F
.60241 .62268 m .61246 .6027 L .59611 .61918 L F
.60241 .62268 m .62506 .60973 L .61246 .6027 L F
.52606 .62002 m .4894 .62259 L .5194 .62936 L F
.47183 .85935 m .47134 .85479 L .47367 .84603 L 0 0 .389 r
F
.127 .923 .03 r
.49591 .80968 m
.49619 .78691 L
s
0 g
.46756 .86006 m
.47134 .85479 L
s
.45322 .85285 m .47107 .85476 L .47339 .84605 L .683 .77 .917 r
F
.64025 .63569 m .66202 .61708 L .63444 .62569 L .654 .726 .902 r
F
.64025 .63569 m .6707 .63208 L .66202 .61708 L F
.44989 .86301 m .47183 .85935 L .45389 .85743 L .683 .77 .917 r
F
.43394 .8583 m .44989 .86301 L .45389 .85743 L F
.29594 .61284 m .26554 .61645 L .27146 .62645 L .654 .726 .902 r
F
.40641 .74756 m .40061 .73315 L .38238 .73799 L .673 .758 .914 r
F
.41934 .7463 m .40061 .73315 L .40641 .74756 L F
.51287 .74439 m .52402 .7479 L .52434 .75356 L .931 .657 .497 r
F
.51287 .74439 m .51255 .73873 L .52402 .7479 L F
.5346 .73077 m .52402 .7479 L .54225 .73689 L .673 .758 .914 r
F
.5346 .73077 m .51255 .73873 L .52402 .7479 L F
0 g
.52402 .7479 m
.52955 .75041 L
s
.57151 .72958 m .56429 .7443 L .57719 .74509 L .673 .758 .914 r
F
.402 .86459 m .39127 .87533 L .40487 .86674 L .683 .77 .917 r
F
.402 .86459 m .38553 .87103 L .39127 .87533 L F
.39445 .75632 m .38251 .74346 L .36664 .75096 L .673 .758 .914 r
F
.40665 .75308 m .38251 .74346 L .39445 .75632 L F
.52675 .61287 m .50021 .60148 L .49028 .61543 L .654 .726 .902 r
F
.37981 .63212 m .41645 .62955 L .38642 .62278 L F
.35309 .62068 m .37981 .63212 L .38642 .62278 L F
.34797 .62457 m .37981 .63212 L .35309 .62068 L F
.38203 .86585 m .36907 .87747 L .38553 .87103 L .683 .77 .917 r
F
.38203 .86585 m .36382 .8697 L .36907 .87747 L F
0 g
.36907 .87747 m
.37769 .88391 L
s
.49938 .60857 m .48983 .61533 L .4894 .62259 L .072 0 .396 r
F
.49938 .60857 m .49981 .6013 L .48983 .61533 L F
0 g
.48599 .63072 m
.48983 .61533 L
s
.23245 .60431 m .23561 .61279 L .23515 .62006 L .929 .748 .267 r
F
0 g
.23554 .58726 m
.25449 .61055 L
s
.22479 .57406 m
.23554 .58726 L
s
.23245 .60431 m .23291 .59705 L .23561 .61279 L .929 .748 .267 r
F
0 g
.23561 .61279 m
.23961 .61953 L
s
.26452 .5987 m .23607 .61274 L .2663 .60915 L .654 .726 .902 r
F
.26452 .5987 m .23338 .59707 L .23607 .61274 L F
.41934 .7463 m .42002 .73126 L .40061 .73315 L .673 .758 .914 r
F
.41645 .62955 m .41689 .62228 L .42069 .60687 L 0 0 .14 r
F
0 g
.41239 .62863 m
.41689 .62228 L
s
.38657 .61544 m .41644 .62218 L .42022 .60685 L .654 .726 .902 r
F
.47283 .749 m .47252 .74333 L .45731 .73642 L .859 .596 .541 r
F
0 g
.47252 .74333 m
.484 .7525 L
s
.4448 .76106 m .44002 .74355 L .43287 .75826 L .673 .758 .915 r
F
.4448 .76106 m .45793 .74775 L .44002 .74355 L F
.39938 .85286 m .38473 .86184 L .40112 .85544 L .683 .77 .917 r
F
.39938 .85286 m .38125 .85669 L .38473 .86184 L F
.47183 .85935 m .47367 .84603 L .47416 .85059 L 0 0 .389 r
F
.47232 .86391 m .47183 .85935 L .47416 .85059 L F
.45389 .85743 m .47183 .85935 L .47416 .85059 L .683 .77 .917 r
F
0 g
.46805 .86463 m
.47183 .85935 L
s
.71429 .61102 m .6896 .62463 L .71718 .61602 L .654 .726 .902 r
F
.71429 .61102 m .68381 .61463 L .6896 .62463 L F
.56555 .72818 m .55237 .7415 L .56429 .7443 L .673 .758 .914 r
F
.79795 .6303 m .83466 .62772 L .80471 .62095 L .654 .726 .902 r
F
.77138 .61885 m .79795 .6303 L .80471 .62095 L F
.76619 .62275 m .79795 .6303 L .77138 .61885 L F
.43256 .7526 m .42034 .7367 L .41966 .75181 L .673 .758 .914 r
F
.43256 .7526 m .43971 .73788 L .42034 .7367 L F
.45038 .86757 m .47232 .86391 L .45437 .86199 L .683 .77 .917 r
F
.43443 .86286 m .45038 .86757 L .45437 .86199 L F
.43135 .86533 m .45038 .86757 L .43443 .86286 L F
.56498 .61755 m .55017 .59944 L .537 .60512 L .654 .726 .902 r
F
.57258 .61595 m .55017 .59944 L .56498 .61755 L F
.59611 .61918 m .59761 .59793 L .58869 .61679 L F
.59611 .61918 m .61246 .6027 L .59761 .59793 L F
.83466 .62772 m .83504 .62046 L .83907 .60505 L 0 0 .165 r
F
0 g
.83046 .62678 m
.83504 .62046 L
s
.8048 .61362 m .83459 .62036 L .8386 .60503 L .654 .726 .902 r
F
.53492 .73644 m .52434 .75356 L .54257 .74255 L .673 .758 .915 r
F
.53492 .73644 m .51287 .74439 L .52434 .75356 L F
0 g
.52434 .75356 m
.53953 .76047 L
s
.57183 .73524 m .56461 .74996 L .57751 .75075 L .673 .758 .915 r
F
.39475 .76198 m .38281 .74913 L .36694 .75662 L F
.40696 .75874 m .38281 .74913 L .39475 .76198 L F
.5523 .63873 m .52564 .62729 L .51897 .63663 L .654 .726 .902 r
F
.55745 .63484 m .52564 .62729 L .5523 .63873 L F
.40665 .75308 m .40083 .7386 L .38251 .74346 L .673 .758 .914 r
F
.41966 .75181 m .40083 .7386 L .40665 .75308 L F
.64259 .73633 m .64226 .73067 L .65035 .71959 L .176 .08 .499 r
F
.127 .923 .03 r
.671 .78846 m
.67345 .71539 L
s
0 g
.63518 .73615 m
.64226 .73067 L
s
.55787 .62757 m .53636 .61223 L .52606 .62002 L .654 .726 .902 r
F
.56449 .62472 m .53636 .61223 L .55787 .62757 L F
.60648 .64156 m .62447 .62413 L .6017 .63715 L F
.60648 .64156 m .63404 .63296 L .62447 .62413 L F
.62078 .72344 m .64194 .73056 L .64999 .71954 L .673 .758 .914 r
F
.61254 .72982 m .64194 .73056 L .62078 .72344 L F
.60211 .62988 m .61221 .60981 L .59577 .62636 L .654 .726 .902 r
F
.60211 .62988 m .62488 .61686 L .61221 .60981 L F
.52564 .62729 m .48897 .62986 L .51897 .63663 L F
.39977 .85744 m .38505 .86647 L .40152 .86003 L .683 .77 .917 r
F
.39977 .85744 m .38155 .86129 L .38505 .86647 L F
.58479 .735 m .59052 .74948 L .60274 .74624 L .673 .758 .915 r
F
.45322 .85285 m .47339 .84605 L .45476 .84704 L .683 .77 .917 r
F
.43536 .85094 m .45322 .85285 L .45476 .84704 L F
.43338 .85372 m .45322 .85285 L .43536 .85094 L F
.59058 .72772 m .60242 .74058 L .61303 .73558 L .673 .758 .914 r
F
.63984 .64295 m .66161 .62435 L .63404 .63296 L .654 .726 .902 r
F
.63984 .64295 m .6703 .63935 L .66161 .62435 L F
.41966 .75181 m .42034 .7367 L .40083 .7386 L .673 .758 .914 r
F
.47283 .749 m .45731 .73642 L .45762 .74208 L .859 .596 .541 r
F
.47314 .75466 m .47283 .749 L .45762 .74208 L F
0 g
.47283 .749 m
.48431 .75816 L
s
.47232 .86391 m .47416 .85059 L .47465 .85515 L 0 0 .389 r
F
.45437 .86199 m .47232 .86391 L .47465 .85515 L .683 .77 .917 r
F
0 g
.46632 .87228 m
.47232 .86391 L
s
.29548 .62011 m .271 .63371 L .29844 .62511 L .654 .726 .902 r
F
.29548 .62011 m .26507 .62372 L .271 .63371 L F
.57258 .61595 m .56537 .59624 L .55017 .59944 L F
.58066 .61569 m .56537 .59624 L .57258 .61595 L F
.58869 .61679 m .58155 .59572 L .58066 .61569 L F
.58869 .61679 m .59761 .59793 L .58155 .59572 L F
.37937 .63939 m .41601 .63681 L .38598 .63004 L F
.35264 .62795 m .37937 .63939 L .38598 .63004 L F
.34752 .63184 m .37937 .63939 L .35264 .62795 L F
.52606 .62002 m .49938 .60857 L .4894 .62259 L F
.49895 .61584 m .4894 .62259 L .48897 .62986 L .072 0 .396 r
F
.49895 .61584 m .49938 .60857 L .4894 .62259 L F
0 g
.48556 .63799 m
.4894 .62259 L
s
.23198 .61158 m .23515 .62006 L .23468 .62733 L .929 .748 .267 r
F
.23198 .61158 m .23245 .60431 L .23515 .62006 L F
.26375 .60595 m .23515 .62006 L .26554 .61645 L .654 .726 .902 r
F
.26375 .60595 m .23245 .60431 L .23515 .62006 L F
0 g
.23515 .62006 m
.23915 .6268 L
s
.56587 .73384 m .56461 .74996 L .57183 .73524 L .673 .758 .915 r
F
.56587 .73384 m .55269 .74716 L .56461 .74996 L F
.537 .60512 m .50021 .60148 L .52675 .61287 L .654 .726 .902 r
F
.6703 .63935 m .6707 .63208 L .66202 .61708 L .99 .743 .456 r
F
0 g
.6707 .63208 m
.67316 .6478 L
s
.38251 .74346 m .36634 .74529 L .36664 .75096 L .517 .331 .568 r
F
.38251 .74346 m .3822 .7378 L .36634 .74529 L F
0 g
.354 .75489 m
.36634 .74529 L
s
.41645 .62955 m .42069 .60687 L .42025 .61414 L 0 0 .14 r
F
.41601 .63681 m .41645 .62955 L .42025 .61414 L F
.38642 .62278 m .41645 .62955 L .42025 .61414 L .654 .726 .902 r
F
0 g
.41194 .6359 m
.41645 .62955 L
s
.43287 .75826 m .42065 .74236 L .41996 .75747 L .673 .758 .915 r
F
.43287 .75826 m .44002 .74355 L .42065 .74236 L F
.58066 .61569 m .58155 .59572 L .56537 .59624 L .654 .726 .902 r
F
.63458 .61851 m .64774 .59675 L .62506 .60973 L F
.3618 .85658 m .36286 .86058 L .36334 .86514 L .786 .569 .001 r
F
.3618 .85658 m .36132 .85202 L .36286 .86058 L F
0 g
.36286 .86058 m
.36562 .86466 L
s
.38024 .85101 m .36313 .86052 L .38125 .85669 L .683 .77 .917 r
F
.38024 .85101 m .36161 .85201 L .36313 .86052 L F
.56049 .72587 m .54225 .73689 L .55237 .7415 L .673 .758 .914 r
F
.40025 .862 m .38553 .87103 L .402 .86459 L .683 .77 .917 r
F
.40025 .862 m .38203 .86585 L .38553 .87103 L F
.29566 .60033 m .2663 .60915 L .29654 .60556 L .654 .726 .902 r
F
.29566 .60033 m .26452 .5987 L .2663 .60915 L F
.71389 .61828 m .6892 .63189 L .71678 .62329 L F
.71389 .61828 m .68341 .62189 L .6892 .63189 L F
.45389 .85743 m .47416 .85059 L .45544 .85159 L .683 .77 .917 r
F
.43594 .85551 m .45389 .85743 L .45544 .85159 L F
.43394 .8583 m .45389 .85743 L .43594 .85551 L F
.59548 .7195 m .61254 .72982 L .62078 .72344 L .673 .758 .914 r
F
.40696 .75874 m .40113 .74427 L .38281 .74913 L .673 .758 .915 r
F
.41996 .75747 m .40113 .74427 L .40696 .75874 L F
.64259 .73633 m .65035 .71959 L .65068 .72526 L .176 .08 .499 r
F
.64292 .742 m .64259 .73633 L .65068 .72526 L F
.62132 .72917 m .64259 .73633 L .65068 .72526 L .673 .758 .914 r
F
.61303 .73558 m .64259 .73633 L .62132 .72917 L F
0 g
.6355 .74181 m
.64259 .73633 L
s
.38657 .61544 m .42022 .60685 L .38908 .60522 L .654 .726 .902 r
F
.35669 .6087 m .38657 .61544 L .38908 .60522 L F
.3534 .61335 m .38657 .61544 L .35669 .6087 L F
.79757 .63756 m .83428 .63499 L .80433 .62822 L F
.77099 .62612 m .79757 .63756 L .80433 .62822 L F
.7658 .63002 m .79757 .63756 L .77099 .62612 L F
.56449 .62472 m .5496 .60653 L .53636 .61223 L F
.57212 .62311 m .5496 .60653 L .56449 .62472 L F
.59091 .73338 m .60274 .74624 L .61336 .74125 L .673 .758 .915 r
F
.58479 .735 m .60274 .74624 L .59091 .73338 L F
.59577 .62636 m .59729 .605 L .58832 .62396 L .654 .726 .902 r
F
.59577 .62636 m .61221 .60981 L .59729 .605 L F
.41996 .75747 m .42065 .74236 L .40113 .74427 L .673 .758 .915 r
F
.47314 .75466 m .45762 .74208 L .45793 .74775 L .859 .596 .541 r
F
0 g
.47314 .75466 m
.48463 .76382 L
s
.127 .923 .03 r
.463 .73551 m
.46327 .80004 L
s
.46161 .80492 m
.46216 .73581 L
s
.83466 .62772 m .83907 .60505 L .83869 .61232 L 0 0 .165 r
F
.83428 .63499 m .83466 .62772 L .83869 .61232 L F
.80471 .62095 m .83466 .62772 L .83869 .61232 L .654 .726 .902 r
F
0 g
.83008 .63404 m
.83466 .62772 L
s
.55745 .63484 m .53594 .6195 L .52564 .62729 L .654 .726 .902 r
F
.56407 .63199 m .53594 .6195 L .55745 .63484 L F
.6017 .63715 m .6118 .61708 L .59536 .63363 L F
.6017 .63715 m .62447 .62413 L .6118 .61708 L F
.71403 .59851 m .68452 .60733 L .71484 .60373 L F
.71403 .59851 m .68289 .59688 L .68452 .60733 L F
.36228 .86115 m .36334 .86514 L .36382 .8697 L .786 .569 .001 r
F
.36228 .86115 m .3618 .85658 L .36334 .86514 L F
.38053 .85559 m .36334 .86514 L .38155 .86129 L .683 .77 .917 r
F
.38053 .85559 m .3618 .85658 L .36334 .86514 L F
0 g
.36334 .86514 m
.3661 .86922 L
s
.39887 .85002 m .38125 .85669 L .39938 .85286 L .683 .77 .917 r
F
.39887 .85002 m .38024 .85101 L .38125 .85669 L F
.38281 .74913 m .36664 .75096 L .36694 .75662 L .517 .331 .568 r
F
0 g
.35461 .76622 m
.36694 .75662 L
s
.38281 .74913 m .38251 .74346 L .36664 .75096 L .517 .331 .568 r
F
0 g
.3543 .76056 m
.36664 .75096 L
s
.8048 .61362 m .8386 .60503 L .80746 .6034 L .654 .726 .902 r
F
.77499 .60688 m .8048 .61362 L .80746 .6034 L F
.77163 .61153 m .8048 .61362 L .77499 .60688 L F
.43536 .85094 m .45476 .84704 L .43613 .84803 L .683 .77 .917 r
F
0 g
.32932 .58222 m
.32952 .52972 L
s
.50558 .72793 m .51223 .73307 L .51255 .73873 L .987 .712 .384 r
F
.50558 .72793 m .50526 .72226 L .51223 .73307 L F
0 g
.51223 .73307 m
.51721 .73705 L
s
.45437 .86199 m .47465 .85515 L .45592 .85615 L .683 .77 .917 r
F
.43642 .86007 m .45437 .86199 L .45592 .85615 L F
.43443 .86286 m .45437 .86199 L .43642 .86007 L F
0 g
.32281 .58212 m
.32301 .5296 L
s
.52989 .71786 m .51256 .73295 L .5345 .72503 L .673 .758 .914 r
F
.52989 .71786 m .50563 .7222 L .51256 .73295 L F
.56081 .73153 m .55269 .74716 L .56587 .73384 L .673 .758 .915 r
F
.56081 .73153 m .54257 .74255 L .55269 .74716 L F
.55645 .7171 m .54211 .73111 L .56026 .72015 L .673 .758 .914 r
F
.55645 .7171 m .5345 .72503 L .54211 .73111 L F
.57212 .62311 m .56488 .60331 L .5496 .60653 L .654 .726 .902 r
F
.58025 .62286 m .56488 .60331 L .57212 .62311 L F
.52564 .62729 m .49895 .61584 L .48897 .62986 L F
0 g
.48514 .64525 m
.48897 .62986 L
s
.58832 .62396 m .58114 .60279 L .58025 .62286 L .654 .726 .902 r
F
.58832 .62396 m .59729 .605 L .58114 .60279 L F
.26329 .61322 m .23468 .62733 L .26507 .62372 L F
.26329 .61322 m .23198 .61158 L .23468 .62733 L F
0 g
.23468 .62733 m
.24359 .64231 L
s
.59589 .72522 m .61303 .73558 L .62132 .72917 L .673 .758 .914 r
F
.64292 .742 m .65068 .72526 L .65101 .73092 L .176 .08 .499 r
F
.62165 .73484 m .64292 .742 L .65101 .73092 L .673 .758 .915 r
F
.61336 .74125 m .64292 .742 L .62165 .73484 L F
0 g
.63049 .7516 m
.64292 .742 L
s
.32923 .60584 m
.32923 .60543 L
s
.32924 .60311 m
.32924 .60262 L
s
.6703 .63935 m .66202 .61708 L .66161 .62435 L .99 .743 .456 r
F
0 g
.6703 .63935 m
.67276 .65507 L
s
.47416 .85059 m .47367 .84603 L .47218 .83747 L .779 .564 0 r
F
.127 .923 .03 r
.39835 8.82702 m
.49261 1.08058 L
s
.47785 .91431 m
.47884 .81692 L
s
0 g
.47243 .85068 m
.47354 .84651 L
s
.41601 .63681 m .42025 .61414 L .41981 .62141 L 0 0 .14 r
F
.38598 .63004 m .41601 .63681 L .41981 .62141 L .654 .726 .902 r
F
0 g
.40608 .65082 m
.41601 .63681 L
s
.45476 .84704 m .47339 .84605 L .4719 .83753 L .683 .77 .917 r
F
.53636 .61223 m .49938 .60857 L .52606 .62002 L .654 .726 .902 r
F
.58025 .62286 m .58114 .60279 L .56488 .60331 L F
.63444 .62569 m .64768 .60383 L .62488 .61686 L F
.63444 .62569 m .66202 .61708 L .64768 .60383 L F
.45762 .74208 m .45731 .73642 L .4394 .73222 L .794 .544 .561 r
F
0 g
.45731 .73642 m
.47252 .74333 L
s
0 0 0 r
2.5 Mabswid
.32942 .90062 Mdot
0 g
.5 Mabswid
.74725 .5279 m
.74753 .58033 L
s
.38101 .86015 m .36382 .8697 L .38203 .86585 L .683 .77 .917 r
F
.38101 .86015 m .36228 .86115 L .36382 .8697 L F
0 g
.36382 .8697 m
.36907 .87747 L
s
.74075 .52778 m
.74102 .58031 L
s
.39926 .85459 m .38155 .86129 L .39977 .85744 L .683 .77 .917 r
F
.39926 .85459 m .38053 .85559 L .38155 .86129 L F
.29505 .60759 m .26554 .61645 L .29594 .61284 L .654 .726 .902 r
F
.29505 .60759 m .26375 .60595 L .26554 .61645 L F
.45476 .84704 m .4719 .83753 L .45377 .84136 L .683 .77 .917 r
F
.43613 .84803 m .45476 .84704 L .45377 .84136 L F
.43594 .85551 m .45544 .85159 L .43671 .85259 L F
.38642 .62278 m .42025 .61414 L .38895 .6125 L .654 .726 .902 r
F
.35639 .616 m .38642 .62278 L .38895 .6125 L F
.35309 .62068 m .38642 .62278 L .35639 .616 L F
.56407 .63199 m .54918 .6138 L .53594 .6195 L F
.57171 .63038 m .54918 .6138 L .56407 .63199 L F
0 g
.74766 .60361 m
.74766 .60407 L
s
.59536 .63363 m .59687 .61227 L .5879 .63123 L .654 .726 .902 r
F
.59536 .63363 m .6118 .61708 L .59687 .61227 L F
.83428 .63499 m .83869 .61232 L .83831 .61959 L 0 0 .165 r
F
.80433 .62822 m .83428 .63499 L .83831 .61959 L .654 .726 .902 r
F
0 g
.82413 .649 m
.83428 .63499 L
s
.50589 .73359 m .51255 .73873 L .51287 .74439 L .987 .712 .384 r
F
.50589 .73359 m .50558 .72793 L .51255 .73873 L F
.52996 .72357 m .51255 .73873 L .5346 .73077 L .673 .758 .914 r
F
.52996 .72357 m .50558 .72793 L .51255 .73873 L F
0 g
.51255 .73873 m
.51753 .74271 L
s
.43613 .84803 m .45377 .84136 L .43563 .84519 L .683 .77 .917 r
F
.35669 .6087 m .38908 .60522 L .35794 .60359 L .654 .726 .902 r
F
.55666 .72281 m .54225 .73689 L .56049 .72587 L .673 .758 .914 r
F
.55666 .72281 m .5346 .73077 L .54225 .73689 L F
.47416 .85059 m .47218 .83747 L .47266 .84203 L .779 .564 0 r
F
.45544 .85159 m .47416 .85059 L .47266 .84203 L .683 .77 .917 r
F
.47465 .85515 m .47416 .85059 L .47266 .84203 L .779 .564 0 r
F
0 g
.47292 .85525 m
.47403 .85108 L
s
.59622 .73088 m .61336 .74125 L .62165 .73484 L .673 .758 .915 r
F
.59091 .73338 m .61336 .74125 L .59622 .73088 L F
.71348 .60577 m .68381 .61463 L .71429 .61102 L .654 .726 .902 r
F
.71348 .60577 m .68218 .60413 L .68381 .61463 L F
.80471 .62095 m .83869 .61232 L .80739 .61068 L F
.77475 .61418 m .80471 .62095 L .80739 .61068 L F
.77138 .61885 m .80471 .62095 L .77475 .61418 L F
.39974 .85915 m .38203 .86585 L .40025 .862 L .683 .77 .917 r
F
.39974 .85915 m .38101 .86015 L .38203 .86585 L F
.4175 .84903 m .41317 .83856 L .40863 .83991 L F
.32344 .72665 m .32315 .72099 L .34265 .71909 L .672 .45 .575 r
F
.30406 .72547 m .32315 .72099 L .32344 .72665 L .733 .497 .571 r
F
.30406 .72547 m .30377 .7198 L .32315 .72099 L F
.45544 .85159 m .47266 .84203 L .45444 .84588 L .683 .77 .917 r
F
.43671 .85259 m .45544 .85159 L .45444 .84588 L F
.40083 .7386 m .3822 .7378 L .38251 .74346 L .604 .397 .575 r
F
.40083 .7386 m .40052 .73294 L .3822 .7378 L F
0 g
.36634 .74529 m
.3822 .7378 L
s
.127 .923 .03 r
.38599 .67388 m
.38683 .73657 L
s
.38599 .67388 m
.38607 .73677 L
s
.43642 .86007 m .45592 .85615 L .4372 .85715 L .683 .77 .917 r
F
.45762 .74208 m .4394 .73222 L .43971 .73788 L .794 .544 .561 r
F
.45793 .74775 m .45762 .74208 L .43971 .73788 L F
0 g
.45762 .74208 m
.47283 .749 L
s
.32378 .7057 m .32316 .72076 L .34256 .71887 L .673 .757 .914 r
F
.31092 .70491 m .32316 .72076 L .32378 .7057 L F
.31092 .70491 m .30387 .71958 L .32316 .72076 L F
.62078 .72344 m .64999 .71954 L .62614 .71609 L .673 .758 .914 r
F
.5996 .71631 m .62078 .72344 L .62614 .71609 L F
0 g
.58225 .64912 m
.58231 .68035 L
s
.57171 .63038 m .56446 .61058 L .54918 .6138 L .654 .726 .902 r
F
.57984 .63012 m .56446 .61058 L .57171 .63038 L F
.5879 .63123 m .58073 .61006 L .57984 .63012 L F
.5879 .63123 m .59687 .61227 L .58073 .61006 L F
0 g
.57575 .64879 m
.5758 .68024 L
s
.77499 .60688 m .80746 .6034 L .77632 .60177 L .654 .726 .902 r
F
.34295 .72475 m .34265 .71909 L .36096 .71422 L .604 .397 .575 r
F
.32344 .72665 m .34265 .71909 L .34295 .72475 L .672 .45 .575 r
F
0 g
.32315 .72099 m
.34265 .71909 L
s
.39964 .84711 m .38024 .85101 L .39887 .85002 L .683 .77 .917 r
F
.53594 .6195 m .49895 .61584 L .52564 .62729 L .654 .726 .902 r
F
.52161 .59085 m .50563 .58891 L .53002 .58812 L .667 .432 .555 r
F
.55017 .59944 m .52328 .59198 L .537 .60512 L .654 .726 .902 r
F
.52328 .59198 m .51557 .58984 L .51965 .59275 L F
.52328 .59198 m .51965 .59275 L .537 .60512 L F
.54502 .58739 m .53002 .58812 L .55293 .58329 L .593 .369 .546 r
F
.52988 .59059 m .53002 .58812 L .54502 .58739 L F
.50647 .5686 m .50564 .5886 L .52991 .58783 L .654 .726 .902 r
F
.52267 .56808 m .52991 .58783 L .55271 .58301 L F
.50647 .5686 m .52991 .58783 L .52267 .56808 L F
.51947 .59092 m .53534 .58132 L .51557 .58984 L F
.55017 .59944 m .54259 .59018 L .51947 .59092 L F
.52161 .59085 m .53002 .58812 L .52988 .59059 L .667 .432 .555 r
F
.54259 .59018 m .53534 .58132 L .51947 .59092 L .654 .726 .902 r
F
.537 .60512 m .51719 .59099 L .50021 .60148 L F
.51719 .59099 m .51391 .5911 L .50021 .60148 L F
.5052 .59617 m .50548 .59137 L .52161 .59085 L .667 .432 .555 r
F
.51288 .59745 m .51325 .59112 L .49981 .6013 L .343 .165 .49 r
F
.5052 .59617 m .51311 .59361 L .51297 .59592 L .667 .432 .555 r
F
.50548 .59137 m .50563 .58891 L .52161 .59085 L F
.50604 .57607 m .5052 .59617 L .51297 .59592 L .654 .726 .902 r
F
.51297 .59592 m .52161 .59085 L .5296 .59539 L .667 .432 .555 r
F
.52161 .59085 m .52988 .59059 L .5296 .59539 L F
.56537 .59624 m .5468 .58701 L .55017 .59944 L .654 .726 .902 r
F
.5468 .58701 m .53534 .58132 L .541 .58824 L F
.5468 .58701 m .541 .58824 L .55017 .59944 L F
.5296 .59539 m .54502 .58739 L .55251 .59056 L .593 .369 .546 r
F
.54502 .58739 m .55293 .58329 L .55279 .58575 L F
.53787 .56487 m .55271 .58301 L .57249 .57449 L .654 .726 .902 r
F
.52267 .56808 m .55271 .58301 L .53787 .56487 L F
.54822 .58772 m .55815 .5765 L .53534 .58132 L F
.56537 .59624 m .56034 .5825 L .54822 .58772 L F
.56593 .58009 m .55293 .58329 L .57281 .57472 L .494 .287 .528 r
F
.55279 .58575 m .55293 .58329 L .56593 .58009 L F
.56034 .5825 m .55815 .5765 L .54822 .58772 L .654 .726 .902 r
F
.58155 .59572 m .56369 .58105 L .56537 .59624 L F
.56369 .58105 m .55815 .5765 L .56034 .5825 L F
.56369 .58105 m .56034 .5825 L .56537 .59624 L F
.56593 .58009 m .57281 .57472 L .57267 .57718 L .494 .287 .528 r
F
.58155 .59572 m .58244 .57572 L .57426 .57599 L .654 .726 .902 r
F
.56554 .58258 m .57426 .57599 L .55815 .5765 L F
.58155 .59572 m .57426 .57599 L .56554 .58258 L F
.58291 .56944 m .57281 .57472 L .5883 .563 L .344 .166 .49 r
F
.55251 .59056 m .56593 .58009 L .57239 .58199 L .494 .287 .528 r
F
.56772 .58069 m .55251 .59056 L .57239 .58199 L .654 .726 .902 r
F
.56876 .58066 m .55804 .5762 L .55776 .58101 L .667 .432 .555 r
F
.54999 .58265 m .55804 .5762 L .53511 .58104 L .592 .369 .546 r
F
.55251 .59056 m .55279 .58575 L .56593 .58009 L .494 .287 .528 r
F
.55776 .58101 m .55251 .59056 L .56772 .58069 L .654 .726 .902 r
F
.54504 .58142 m .54663 .58336 L .55776 .58101 L F
.54663 .58336 m .55251 .59056 L .55776 .58101 L F
.5296 .59539 m .53578 .58934 L .54502 .58739 L .593 .369 .546 r
F
.5296 .59539 m .52988 .59059 L .53578 .58934 L F
.54059 .58463 m .5296 .59539 L .55251 .59056 L .654 .726 .902 r
F
.5281 .58875 m .53511 .58104 L .51525 .58961 L .494 .287 .528 r
F
.52672 .58756 m .5296 .59539 L .54059 .58463 L .654 .726 .902 r
F
.53469 .58831 m .53483 .58585 L .5281 .58875 L .494 .287 .528 r
F
.53483 .58585 m .53511 .58104 L .5281 .58875 L F
.52231 .57555 m .52672 .58756 L .53483 .58585 L .654 .726 .902 r
F
.54999 .58265 m .53511 .58104 L .53483 .58585 L .592 .369 .546 r
F
.53923 .58396 m .53483 .58585 L .54059 .58463 L .654 .726 .902 r
F
.52231 .57555 m .53483 .58585 L .53923 .58396 L F
.54502 .58739 m .55279 .58575 L .55251 .59056 L .593 .369 .546 r
F
.52231 .57555 m .55251 .59056 L .5376 .57232 L .654 .726 .902 r
F
.55762 .58347 m .54999 .58265 L .53469 .58831 L .592 .369 .546 r
F
.54999 .58265 m .53483 .58585 L .53469 .58831 L F
.55762 .58347 m .55776 .58101 L .54999 .58265 L F
.55776 .58101 m .55804 .5762 L .54999 .58265 L F
.5376 .57232 m .54504 .58142 L .55776 .58101 L .654 .726 .902 r
F
.56407 .57968 m .55776 .58101 L .56772 .58069 L F
.5376 .57232 m .55776 .58101 L .56407 .57968 L F
.57425 .58294 m .56876 .58066 L .55762 .58347 L .667 .432 .555 r
F
.56876 .58066 m .55776 .58101 L .55762 .58347 L F
.58204 .58269 m .57439 .58062 L .57425 .58294 L F
.56593 .58009 m .57267 .57718 L .57239 .58199 L .494 .287 .528 r
F
.53787 .56487 m .57249 .57449 L .55106 .55918 L .654 .726 .902 r
F
.57239 .58199 m .57267 .57718 L .57467 .57567 L .344 .166 .49 r
F
.57239 .58199 m .57467 .57567 L .57445 .57954 L F
.58204 .58269 m .58245 .57542 L .57467 .57567 L .667 .432 .555 r
F
.5739 .58049 m .57467 .57567 L .55804 .5762 L F
.5744 .58048 m .5883 .563 L .58789 .57027 L .344 .166 .49 r
F
.57445 .57954 m .5883 .563 L .5744 .58048 L F
.57445 .57954 m .57467 .57567 L .58291 .56944 L F
.57267 .57718 m .57281 .57472 L .58291 .56944 L F
.55106 .55918 m .57249 .57449 L .5879 .56283 L .654 .726 .902 r
F
.55086 .56661 m .57045 .5806 L .58789 .57027 L F
.57239 .58199 m .57445 .57954 L .5744 .58048 L .344 .166 .49 r
F
.57045 .5806 m .57239 .58199 L .5744 .58048 L .654 .726 .902 r
F
.5744 .58048 m .57467 .57567 L .5739 .58049 L .667 .432 .555 r
F
.57045 .5806 m .5744 .58048 L .58789 .57027 L .654 .726 .902 r
F
.57439 .58062 m .5744 .58048 L .5739 .58049 L .667 .432 .555 r
F
.58204 .58269 m .57467 .57567 L .57439 .58062 L F
.5376 .57232 m .56772 .58069 L .55086 .56661 L .654 .726 .902 r
F
.56772 .58069 m .57239 .58199 L .57045 .5806 L F
.5739 .58049 m .55804 .5762 L .56876 .58066 L .667 .432 .555 r
F
.56772 .58069 m .57045 .5806 L .55086 .56661 L .654 .726 .902 r
F
.59761 .59793 m .58244 .57572 L .58155 .59572 L F
.59761 .59793 m .60655 .57904 L .58244 .57572 L F
.58249 .57671 m .57239 .58199 L .58789 .57027 L .344 .166 .49 r
F
.58114 .60279 m .58204 .58269 L .57425 .58294 L .654 .726 .902 r
F
.54661 .59424 m .55762 .58347 L .53469 .58831 L F
.56488 .60331 m .56048 .59131 L .54661 .59424 L F
.56551 .58736 m .55251 .59056 L .57239 .58199 L .494 .287 .528 r
F
.56048 .59131 m .55992 .58977 L .55237 .59302 L .654 .726 .902 r
F
.5446 .59466 m .5296 .59539 L .55251 .59056 L .593 .369 .546 r
F
.52945 .59786 m .5296 .59539 L .5446 .59466 L F
.56488 .60331 m .54661 .59424 L .5496 .60653 L .654 .726 .902 r
F
.54661 .59424 m .53469 .58831 L .54058 .59551 L F
.54661 .59424 m .54058 .59551 L .5496 .60653 L F
.5496 .60653 m .5195 .59817 L .53636 .61223 L F
.50505 .59864 m .5052 .59617 L .52118 .59812 L .667 .432 .555 r
F
.5195 .59817 m .51483 .59688 L .51677 .59826 L .654 .726 .902 r
F
.5195 .59817 m .51677 .59826 L .53636 .61223 L F
.52118 .59812 m .5052 .59617 L .5296 .59539 L .667 .432 .555 r
F
.51283 .59839 m .49981 .6013 L .49938 .60857 L .343 .165 .49 r
F
.51483 .59688 m .51288 .59745 L .51283 .59839 L F
.51288 .59745 m .49981 .6013 L .51283 .59839 L F
.50477 .60344 m .50505 .59864 L .51283 .59839 L .667 .432 .555 r
F
.53636 .61223 m .51677 .59826 L .49938 .60857 L .654 .726 .902 r
F
.51677 .59826 m .51483 .59688 L .51283 .59839 L F
.51677 .59826 m .51283 .59839 L .49938 .60857 L F
.51268 .60088 m .51283 .59839 L .52118 .59812 L .667 .432 .555 r
F
.51246 .60472 m .51283 .59839 L .49938 .60857 L .343 .165 .49 r
F
.50477 .60344 m .51268 .60088 L .51255 .60319 L .667 .432 .555 r
F
.50477 .60344 m .51283 .59839 L .51268 .60088 L F
.50561 .58334 m .50477 .60344 L .51255 .60319 L .654 .726 .902 r
F
.51255 .60319 m .52118 .59812 L .52917 .60266 L .667 .432 .555 r
F
.52118 .59812 m .5296 .59539 L .52945 .59786 L F
.52377 .59062 m .51297 .59592 L .5296 .59539 L .654 .726 .902 r
F
.51311 .59361 m .52161 .59085 L .51297 .59592 L .667 .432 .555 r
F
.51719 .59099 m .51557 .58984 L .51391 .5911 L .654 .726 .902 r
F
.5281 .58875 m .51525 .58961 L .51497 .59441 L .494 .287 .528 r
F
.50604 .57607 m .5296 .59539 L .52231 .57555 L .654 .726 .902 r
F
.5496 .60653 m .53469 .58831 L .51483 .59688 L F
.52118 .59812 m .52945 .59786 L .52917 .60266 L .667 .432 .555 r
F
.52917 .60266 m .5446 .59466 L .55209 .59783 L .593 .369 .546 r
F
.52917 .60266 m .52945 .59786 L .5446 .59466 L F
.53469 .58831 m .5281 .58875 L .51483 .59688 L .494 .287 .528 r
F
.51497 .59441 m .51297 .59592 L .52377 .59062 L .654 .726 .902 r
F
.5281 .58875 m .51497 .59441 L .51483 .59688 L .494 .287 .528 r
F
.5446 .59466 m .55251 .59056 L .55237 .59302 L .593 .369 .546 r
F
.55237 .59302 m .55762 .58347 L .54661 .59424 L .654 .726 .902 r
F
.54957 .58992 m .53469 .58831 L .53441 .59312 L .592 .369 .546 r
F
.55237 .59302 m .55251 .59056 L .56551 .58736 L .494 .287 .528 r
F
.58114 .60279 m .56344 .58825 L .56488 .60331 L .654 .726 .902 r
F
.56344 .58825 m .55762 .58347 L .55992 .58977 L F
.56344 .58825 m .55992 .58977 L .56488 .60331 L F
.58114 .60279 m .57425 .58294 L .56526 .58975 L F
.55209 .59783 m .56551 .58736 L .57198 .58926 L .494 .287 .528 r
F
.56551 .58736 m .57239 .58199 L .57225 .58446 L F
.56551 .58736 m .57225 .58446 L .57198 .58926 L F
.55209 .59783 m .55237 .59302 L .56551 .58736 L F
.55992 .58977 m .55762 .58347 L .55237 .59302 L .654 .726 .902 r
F
.5673 .58796 m .55209 .59783 L .57198 .58926 L F
.56834 .58793 m .55762 .58347 L .55734 .58828 L .667 .432 .555 r
F
.54957 .58992 m .55762 .58347 L .53469 .58831 L .592 .369 .546 r
F
.54462 .58869 m .55209 .59783 L .5673 .58796 L .654 .726 .902 r
F
.5572 .59075 m .55734 .58828 L .54957 .58992 L .592 .369 .546 r
F
.55734 .58828 m .55762 .58347 L .54957 .58992 L F
.53718 .57959 m .54462 .58869 L .55734 .58828 L .654 .726 .902 r
F
.56365 .58695 m .55734 .58828 L .5673 .58796 L F
.53718 .57959 m .55734 .58828 L .56365 .58695 L F
.57384 .59021 m .56834 .58793 L .5572 .59075 L .667 .432 .555 r
F
.56834 .58793 m .55734 .58828 L .5572 .59075 L F
.52768 .59602 m .53469 .58831 L .51483 .59688 L .494 .287 .528 r
F
.5446 .59466 m .55237 .59302 L .55209 .59783 L .593 .369 .546 r
F
.52189 .58282 m .55209 .59783 L .53718 .57959 L .654 .726 .902 r
F
.5572 .59075 m .54957 .58992 L .53427 .59559 L .592 .369 .546 r
F
.54017 .5919 m .52917 .60266 L .55209 .59783 L .654 .726 .902 r
F
.54957 .58992 m .53441 .59312 L .53427 .59559 L .592 .369 .546 r
F
.53881 .59123 m .53782 .5924 L .54017 .5919 L .654 .726 .902 r
F
.53782 .5924 m .52917 .60266 L .54017 .5919 L F
.53441 .59312 m .53469 .58831 L .52768 .59602 L .494 .287 .528 r
F
.52189 .58282 m .52686 .59637 L .53881 .59123 L .654 .726 .902 r
F
.52686 .59637 m .52917 .60266 L .53881 .59123 L F
.53427 .59559 m .53441 .59312 L .52768 .59602 L .494 .287 .528 r
F
.51268 .60088 m .52118 .59812 L .51255 .60319 L .667 .432 .555 r
F
.52768 .59602 m .51483 .59688 L .51454 .60168 L .494 .287 .528 r
F
.52195 .58912 m .51497 .59441 L .52377 .59062 L .654 .726 .902 r
F
.51429 .59492 m .51525 .58961 L .51325 .59112 L .343 .165 .49 r
F
.51497 .59441 m .51525 .58961 L .51429 .59492 L F
.51483 .59688 m .51325 .59112 L .51288 .59745 L F
.50604 .57607 m .51297 .59592 L .52195 .58912 L .654 .726 .902 r
F
.50561 .58334 m .52917 .60266 L .52189 .58282 L F
.53427 .59559 m .52768 .59602 L .5144 .60415 L .494 .287 .528 r
F
.52335 .59789 m .51255 .60319 L .52917 .60266 L .654 .726 .902 r
F
.51454 .60168 m .51255 .60319 L .52335 .59789 L F
.52768 .59602 m .51454 .60168 L .5144 .60415 L .494 .287 .528 r
F
.52153 .59639 m .51454 .60168 L .52335 .59789 L .654 .726 .902 r
F
.51387 .60219 m .51483 .59688 L .51283 .59839 L .343 .165 .49 r
F
.51454 .60168 m .51483 .59688 L .51387 .60219 L F
.5144 .60415 m .51283 .59839 L .51246 .60472 L F
.51483 .59688 m .51497 .59441 L .51429 .59492 L F
.50561 .58334 m .51255 .60319 L .52153 .59639 L .654 .726 .902 r
F
.5144 .60415 m .51454 .60168 L .51387 .60219 L .343 .165 .49 r
F
.58162 .58996 m .57397 .5879 L .57384 .59021 L .667 .432 .555 r
F
.56526 .58975 m .57425 .58294 L .55762 .58347 L .654 .726 .902 r
F
.57198 .58926 m .57225 .58446 L .57425 .58294 L .344 .166 .49 r
F
.57198 .58926 m .57425 .58294 L .57403 .58681 L F
.58162 .58996 m .58204 .58269 L .57425 .58294 L .667 .432 .555 r
F
.57348 .58776 m .57425 .58294 L .55762 .58347 L F
.61246 .6027 m .60655 .57904 L .59761 .59793 L .654 .726 .902 r
F
.60627 .58602 m .60668 .57875 L .58245 .57542 L .732 .488 .559 r
F
.60627 .58602 m .58245 .57542 L .58204 .58269 L F
.57398 .58775 m .58789 .57027 L .58747 .57755 L .344 .166 .49 r
F
.57403 .58681 m .58789 .57027 L .57398 .58775 L F
.57403 .58681 m .57425 .58294 L .58249 .57671 L F
.57225 .58446 m .57239 .58199 L .58249 .57671 L F
.57439 .58062 m .5739 .58049 L .57425 .58294 L .667 .432 .555 r
F
.5739 .58049 m .56876 .58066 L .57425 .58294 L F
.55044 .57388 m .57003 .58788 L .58747 .57755 L .654 .726 .902 r
F
.57198 .58926 m .57403 .58681 L .57398 .58775 L .344 .166 .49 r
F
.57003 .58788 m .57198 .58926 L .57398 .58775 L .654 .726 .902 r
F
.57398 .58775 m .57425 .58294 L .57348 .58776 L .667 .432 .555 r
F
.57003 .58788 m .57398 .58775 L .58747 .57755 L .654 .726 .902 r
F
.57397 .5879 m .57398 .58775 L .57348 .58776 L .667 .432 .555 r
F
.58162 .58996 m .57425 .58294 L .57397 .5879 L F
.53718 .57959 m .5673 .58796 L .55044 .57388 L .654 .726 .902 r
F
.5673 .58796 m .57198 .58926 L .57003 .58788 L F
.57348 .58776 m .55762 .58347 L .56834 .58793 L .667 .432 .555 r
F
.5673 .58796 m .57003 .58788 L .55044 .57388 L .654 .726 .902 r
F
.57397 .5879 m .57348 .58776 L .57384 .59021 L .667 .432 .555 r
F
.57348 .58776 m .56834 .58793 L .57384 .59021 L F
.43671 .85259 m .45444 .84588 L .43621 .84974 L .683 .77 .917 r
F
.57984 .63012 m .58073 .61006 L .56446 .61058 L .654 .726 .902 r
F
.33673 .70444 m .34256 .71887 L .36078 .71403 L .673 .757 .914 r
F
.32378 .7057 m .34256 .71887 L .33673 .70444 L F
.63404 .63296 m .64727 .6111 L .62447 .62413 L .654 .726 .902 r
F
.63404 .63296 m .66161 .62435 L .64727 .6111 L F
.47465 .85515 m .47266 .84203 L .47315 .84659 L .779 .564 0 r
F
.45592 .85615 m .47465 .85515 L .47315 .84659 L .683 .77 .917 r
F
0 g
.47232 .86391 m
.47465 .85515 L
s
.58231 .68035 m
.58233 .69429 L
s
.62506 .60973 m .62882 .58621 L .61246 .6027 L .654 .726 .902 r
F
.62506 .60973 m .64774 .59675 L .62882 .58621 L F
0 g
.5758 .68024 m
.57582 .69443 L
s
.53028 .72923 m .51287 .74439 L .53492 .73644 L .673 .758 .915 r
F
.53028 .72923 m .50589 .73359 L .51287 .74439 L F
0 g
.51287 .74439 m
.52434 .75356 L
s
.7418 .72484 m .74146 .71917 L .76098 .71727 L .672 .45 .575 r
F
.72245 .72365 m .74146 .71917 L .7418 .72484 L .733 .497 .57 r
F
.72245 .72365 m .72212 .71798 L .74146 .71917 L F
.29459 .61486 m .26507 .62372 L .29548 .62011 L .654 .726 .902 r
F
.29459 .61486 m .26329 .61322 L .26507 .62372 L F
.74234 .70389 m .74147 .71895 L .7609 .71705 L .673 .758 .914 r
F
.7295 .7031 m .74147 .71895 L .74234 .70389 L F
.7295 .7031 m .72222 .71776 L .74147 .71895 L F
.55699 .72847 m .54257 .74255 L .56081 .73153 L .673 .758 .915 r
F
.55699 .72847 m .53492 .73644 L .54257 .74255 L F
.38177 .8452 m .36161 .85201 L .38024 .85101 L .683 .77 .917 r
F
.39964 .84711 m .38177 .8452 L .38024 .85101 L F
.38598 .63004 m .41981 .62141 L .3885 .61977 L .654 .726 .902 r
F
.35594 .62327 m .38598 .63004 L .3885 .61977 L F
.35264 .62795 m .38598 .63004 L .35594 .62327 L F
.43563 .84519 m .4503 .8362 L .4339 .84262 L .683 .77 .917 r
F
.43563 .84519 m .45377 .84136 L .4503 .8362 L F
.45592 .85615 m .47315 .84659 L .45492 .85045 L F
.4372 .85715 m .45592 .85615 L .45492 .85045 L F
.28613 .72126 m .30377 .7198 L .30406 .72547 L .793 .544 .561 r
F
.28613 .72126 m .28583 .7156 L .30377 .7198 L F
0 g
.30377 .7198 m
.32315 .72099 L
s
0 0 0 r
2.5 Mabswid
.38987 .86277 Mdot
.29901 .70212 m .30387 .71958 L .31092 .70491 L .673 .757 .914 r
F
.29901 .70212 m .28603 .7154 L .30387 .71958 L F
.76132 .72293 m .76098 .71727 L .77935 .7124 L .604 .398 .575 r
F
.7418 .72484 m .76098 .71727 L .76132 .72293 L .672 .45 .575 r
F
0 g
.5 Mabswid
.74146 .71917 m
.76098 .71727 L
s
.32374 .73232 m .32344 .72665 L .34295 .72475 L .672 .45 .575 r
F
.30436 .73113 m .32344 .72665 L .32374 .73232 L .733 .497 .571 r
F
.30436 .73113 m .30406 .72547 L .32344 .72665 L F
.32407 .71152 m .32344 .72665 L .34295 .72475 L .673 .757 .914 r
F
.31114 .71073 m .32344 .72665 L .32407 .71152 L F
.31114 .71073 m .30406 .72547 L .32344 .72665 L F
.65068 .72526 m .65035 .71959 L .65355 .70779 L 0 0 .332 r
F
0 g
.64573 .72592 m
.65035 .71959 L
s
.7553 .70262 m .7609 .71705 L .77918 .71221 L .673 .758 .914 r
F
.74234 .70389 m .7609 .71705 L .7553 .70262 L F
.62614 .71609 m .64999 .71954 L .65317 .7078 L F
0 g
.48983 .61533 m
.49981 .6013 L
s
.49981 .6013 m
.50503 .59735 L
s
.38177 .8452 m .36389 .84328 L .36161 .85201 L .683 .77 .917 r
F
.3641 .84782 m .36132 .85202 L .3618 .85658 L 0 0 .384 r
F
0 g
.362 .85582 m
.36214 .85657 L
s
.3641 .84782 m .36362 .84325 L .36132 .85202 L 0 0 .384 r
F
.40113 .74427 m .38251 .74346 L .38281 .74913 L .604 .397 .575 r
F
0 g
.36694 .75662 m
.38281 .74913 L
s
.40113 .74427 m .40083 .7386 L .38251 .74346 L .604 .397 .575 r
F
0 g
.36664 .75096 m
.38251 .74346 L
s
.127 .923 .03 r
.3869 .74189 m
.38691 .74226 L
s
.43971 .73788 m .4394 .73222 L .42003 .73103 L .733 .497 .571 r
F
0 g
.4394 .73222 m
.45731 .73642 L
s
.45793 .74775 m .43971 .73788 L .44002 .74355 L .794 .544 .561 r
F
0 g
.45793 .74775 m
.47314 .75466 L
s
.62132 .72917 m .65068 .72526 L .62671 .72179 L .673 .758 .914 r
F
.60004 .72201 m .62132 .72917 L .62671 .72179 L F
.59589 .72522 m .62132 .72917 L .60004 .72201 L F
.35639 .616 m .38895 .6125 L .35765 .61087 L .654 .726 .902 r
F
.40003 .85167 m .38053 .85559 L .39926 .85459 L .683 .77 .917 r
F
.4372 .85715 m .45492 .85045 L .4367 .8543 L F
.71308 .61303 m .68341 .62189 L .71389 .61828 L .654 .726 .902 r
F
.71308 .61303 m .68178 .6114 L .68341 .62189 L F
.55415 .71352 m .5345 .72503 L .55645 .7171 L .673 .758 .914 r
F
.55415 .71352 m .52989 .71786 L .5345 .72503 L F
.80433 .62822 m .83831 .61959 L .80701 .61795 L .654 .726 .902 r
F
.77436 .62145 m .80433 .62822 L .80701 .61795 L F
.77099 .62612 m .80433 .62822 L .77436 .62145 L F
.127 .923 .03 r
.38608 .74782 m
.38616 .81063 L
s
.38607 .74321 m
.38608 .74782 L
s
.34295 .72475 m .36096 .71422 L .36126 .71988 L .604 .397 .575 r
F
.34325 .73041 m .34295 .72475 L .36126 .71988 L F
.32374 .73232 m .34295 .72475 L .34325 .73041 L .672 .45 .575 r
F
.33708 .71025 m .34295 .72475 L .36126 .71988 L .673 .757 .914 r
F
.32407 .71152 m .34295 .72475 L .33708 .71025 L F
0 g
.32344 .72665 m
.34295 .72475 L
s
.26699 .58847 m .23707 .58172 L .23338 .59707 L .654 .726 .902 r
F
.23615 .58889 m .23291 .59705 L .23245 .60431 L 0 0 .128 r
F
0 g
.23345 .60015 m
.23417 .6044 L
s
.23615 .58889 m .23661 .58162 L .23291 .59705 L 0 0 .128 r
F
.26699 .58847 m .23338 .59707 L .26452 .5987 L .654 .726 .902 r
F
.2969 .59522 m .26452 .5987 L .29566 .60033 L F
.2969 .59522 m .26699 .58847 L .26452 .5987 L F
.127 .923 .03 r
.38698 .74748 m
.38793 .81836 L
s
.38691 .74226 m
.38698 .74748 L
s
0 0 0 r
2.5 Mabswid
.38691 .74226 Mdot
.7046 .71945 m .72212 .71798 L .72245 .72365 L .794 .544 .56 r
F
.7046 .71945 m .70426 .71378 L .72212 .71798 L F
0 g
.5 Mabswid
.72212 .71798 m
.74146 .71917 L
s
.40162 .84434 m .38177 .8452 L .39964 .84711 L .683 .77 .917 r
F
.38207 .84974 m .3618 .85658 L .38053 .85559 L F
.40003 .85167 m .38207 .84974 L .38053 .85559 L F
.127 .923 .03 r
.38616 .81063 m
.38616 .81485 L
s
.35794 .60359 m .38734 .59477 L .35707 .59836 L .654 .726 .902 r
F
.35794 .60359 m .38908 .60522 L .38734 .59477 L F
.71765 .7003 m .72222 .71776 L .7295 .7031 L .673 .758 .914 r
F
.71765 .7003 m .70446 .71358 L .72222 .71776 L F
.38908 .60522 m .41763 .59117 L .38734 .59477 L .654 .726 .902 r
F
.38908 .60522 m .42022 .60685 L .41763 .59117 L F
.41847 .85815 m .40559 .85097 L .40251 .85344 L .683 .77 .917 r
F
.43621 .84974 m .45095 .8407 L .43447 .84714 L F
.43621 .84974 m .45444 .84588 L .45095 .8407 L F
.45377 .84136 m .4667 .82978 L .4503 .8362 L F
.45377 .84136 m .4719 .83753 L .4667 .82978 L F
.42025 .61414 m .42069 .60687 L .41809 .59111 L .923 .743 .256 r
F
0 g
.41891 .61407 m
.41987 .61016 L
s
.42034 .7367 m .40052 .73294 L .40083 .7386 L .672 .45 .575 r
F
.42034 .7367 m .42003 .73103 L .40052 .73294 L F
0 g
.3822 .7378 m
.40052 .73294 L
s
.74214 .7305 m .7418 .72484 L .76132 .72293 L .672 .45 .575 r
F
.72279 .72931 m .7418 .72484 L .74214 .7305 L .733 .497 .57 r
F
.72279 .72931 m .72245 .72365 L .7418 .72484 L F
.74267 .7097 m .7418 .72484 L .76132 .72293 L .673 .758 .914 r
F
.72977 .70891 m .7418 .72484 L .74267 .7097 L F
.72977 .70891 m .72245 .72365 L .7418 .72484 L F
.77475 .61418 m .80739 .61068 L .77609 .60904 L .654 .726 .902 r
F
.36458 .85238 m .3618 .85658 L .36228 .86115 L 0 0 .384 r
F
0 g
.36248 .86038 m
.36262 .86113 L
s
.38207 .84974 m .3641 .84782 L .3618 .85658 L .683 .77 .917 r
F
.36458 .85238 m .3641 .84782 L .3618 .85658 L 0 0 .384 r
F
.28642 .72693 m .30406 .72547 L .30436 .73113 L .793 .544 .561 r
F
.28642 .72693 m .28613 .72126 L .30406 .72547 L F
.29918 .70792 m .30406 .72547 L .31114 .71073 L .673 .757 .914 r
F
.29918 .70792 m .28613 .72126 L .30406 .72547 L F
0 g
.30406 .72547 m
.32344 .72665 L
s
.36126 .71988 m .36096 .71422 L .37683 .70672 L .516 .331 .568 r
F
0 g
.35262 .71644 m
.36096 .71422 L
s
.4339 .84262 m .44459 .83191 L .43104 .84047 L .683 .77 .917 r
F
.4339 .84262 m .4503 .8362 L .44459 .83191 L F
.40051 .85623 m .38101 .86015 L .39974 .85915 L F
.127 .923 .03 r
.38616 .81485 m
.38617 .81908 L
s
.43971 .73788 m .42003 .73103 L .42034 .7367 L .733 .497 .571 r
F
0 g
.40052 .73294 m
.42003 .73103 L
s
.42003 .73103 m
.4394 .73222 L
s
.34888 .70121 m .36078 .71403 L .37658 .70656 L .673 .757 .914 r
F
.33673 .70444 m .36078 .71403 L .34888 .70121 L F
.76132 .72293 m .77935 .7124 L .7797 .71807 L .604 .398 .575 r
F
.76166 .7286 m .76132 .72293 L .7797 .71807 L F
.74214 .7305 m .76132 .72293 L .76166 .7286 L .672 .45 .575 r
F
.75569 .70843 m .76132 .72293 L .7797 .71807 L .673 .758 .914 r
F
.74267 .7097 m .76132 .72293 L .75569 .70843 L F
0 g
.7418 .72484 m
.76132 .72293 L
s
.62488 .61686 m .62866 .59323 L .61221 .60981 L .654 .726 .902 r
F
.62488 .61686 m .64768 .60383 L .62866 .59323 L F
.32437 .71719 m .32374 .73232 L .34325 .73041 L .673 .758 .914 r
F
.31144 .71639 m .32374 .73232 L .32437 .71719 L F
.31144 .71639 m .30436 .73113 L .32374 .73232 L F
.65068 .72526 m .65355 .70779 L .65388 .71346 L 0 0 .332 r
F
.65101 .73092 m .65068 .72526 L .65388 .71346 L F
.62671 .72179 m .65068 .72526 L .65388 .71346 L .673 .758 .914 r
F
0 g
.64606 .73158 m
.65068 .72526 L
s
.65481 .58706 m .65128 .59522 L .65087 .60249 L 0 0 .154 r
F
.65481 .58706 m .65521 .57979 L .65128 .59522 L F
.71535 .59339 m .68289 .59688 L .71403 .59851 L .654 .726 .902 r
F
.71535 .59339 m .68551 .58664 L .68289 .59688 L F
.44002 .74355 m .43971 .73788 L .42034 .7367 L .733 .497 .571 r
F
0 g
.43971 .73788 m
.45762 .74208 L
s
.62165 .73484 m .65101 .73092 L .62704 .72745 L .673 .758 .915 r
F
.60036 .72768 m .62165 .73484 L .62704 .72745 L F
.59622 .73088 m .62165 .73484 L .60036 .72768 L F
.77632 .60177 m .80588 .59294 L .77552 .59654 L .654 .726 .902 r
F
.77632 .60177 m .80746 .6034 L .80588 .59294 L F
.80746 .6034 m .83625 .58934 L .80588 .59294 L F
.80746 .6034 m .8386 .60503 L .83625 .58934 L F
.83869 .61232 m .83907 .60505 L .83671 .58929 L .908 .731 .232 r
F
0 g
.83719 .61224 m
.83831 .60794 L
s
.55435 .7192 m .5346 .73077 L .55666 .72281 L .673 .758 .914 r
F
.55435 .7192 m .52996 .72357 L .5346 .73077 L F
.40202 .84887 m .38207 .84974 L .40003 .85167 L .683 .77 .917 r
F
.38255 .85431 m .36228 .86115 L .38101 .86015 L F
.40051 .85623 m .38255 .85431 L .38101 .86015 L F
.33129 .60175 m .33484 .59799 L .33033 .60089 L .675 .735 .895 r
F
.34325 .73041 m .36126 .71988 L .36157 .72555 L .604 .397 .575 r
F
.33738 .71592 m .34325 .73041 L .36157 .72555 L .673 .758 .914 r
F
.32437 .71719 m .34325 .73041 L .33738 .71592 L F
0 g
.32374 .73232 m
.34325 .73041 L
s
.4367 .8543 m .45144 .84526 L .43495 .85171 L .683 .77 .917 r
F
.4367 .8543 m .45492 .85045 L .45144 .84526 L F
.45444 .84588 m .46744 .83425 L .45095 .8407 L F
.45444 .84588 m .47266 .84203 L .46744 .83425 L F
.47266 .84203 m .47218 .83747 L .46695 .82969 L .981 .69 .342 r
F
0 g
.47218 .83747 m
.47367 .84603 L
s
.127 .923 .03 r
.46468 1.14152 m
.49644 8.80042 L
s
.70493 .72511 m .72245 .72365 L .72279 .72931 L .794 .544 .56 r
F
.70493 .72511 m .7046 .71945 L .72245 .72365 L F
.71786 .7061 m .72245 .72365 L .72977 .70891 L .673 .758 .914 r
F
.71786 .7061 m .7046 .71945 L .72245 .72365 L F
0 g
.72245 .72365 m
.7418 .72484 L
s
.41986 .92392 m .41854 .92889 L .42178 .92883 L .644 .733 .913 r
F
.41836 .86866 m .41975 .92393 L .41826 .92405 L .642 .403 .542 r
F
.41885 .92134 m .41874 .92401 L .41986 .92392 L .644 .733 .913 r
F
.41874 .92401 m .41854 .92889 L .41986 .92392 L F
.41854 .92889 m .41823 .93644 L .4247 .9363 L F
.41954 .9275 m .41829 .9327 L .42154 .93263 L F
.41826 .92405 m .41984 .9274 L .41827 .9276 L .642 .403 .542 r
F
.4186 .92511 m .4185 .92758 L .41954 .9275 L .644 .733 .913 r
F
.4185 .92758 m .41829 .9327 L .41954 .9275 L F
.41975 .92393 m .41984 .9274 L .41826 .92405 L .642 .403 .542 r
F
.127 .923 .03 r
.40259 2.01454 m
.49362 8.7996 L
s
.42236 .92373 m .42482 .92825 L .42745 .9272 L .644 .733 .913 r
F
.41985 .92392 m .42086 .92697 L .41984 .9274 L .519 .305 .529 r
F
.41994 .86846 m .42081 .92359 L .41985 .92392 L F
.41885 .92134 m .42178 .92883 L .42482 .92825 L .644 .733 .913 r
F
.42081 .92359 m .42086 .92697 L .41985 .92392 L .519 .305 .529 r
F
.42157 .92309 m .42199 .92574 L .42156 .92641 L .077 0 .416 r
F
.42167 .86747 m .42198 .92252 L .42157 .92309 L F
.4217 .92328 m .42106 .92379 L .42236 .92373 L .644 .733 .913 r
F
.42101 .92384 m .42482 .92825 L .42236 .92373 L F
.42198 .92252 m .42199 .92574 L .42157 .92309 L .077 0 .416 r
F
.42106 .92379 m .42101 .92384 L .42103 .92383 L .644 .733 .913 r
F
.42106 .92379 m .42103 .92383 L .42236 .92373 L F
.41885 .92134 m .4208 .9236 L .4217 .92328 L F
.42087 .92357 m .42156 .92641 L .42086 .92697 L .359 .182 .499 r
F
.42096 .86803 m .42153 .92311 L .42087 .92357 L F
.42087 .92357 m .42101 .92384 L .4217 .92328 L .644 .733 .913 r
F
.42081 .92361 m .42101 .92384 L .42087 .92357 L F
.42153 .92311 m .42156 .92641 L .42087 .92357 L .359 .182 .499 r
F
.4208 .9236 m .42081 .92361 L .42087 .92357 L .644 .733 .913 r
F
.41836 .86866 m .41994 .86846 L .41985 .92392 L .642 .403 .542 r
F
.41975 .92393 m .41985 .92392 L .41984 .9274 L F
.41836 .86866 m .41985 .92392 L .41975 .92393 L F
.41758 .92391 m .41235 .92752 L .41533 .92845 L .644 .733 .913 r
F
.41874 .92414 m .41533 .92845 L .41854 .92889 L F
.41758 .92391 m .41533 .92845 L .41874 .92414 L F
.41235 .92752 m .4118 .93555 L .41533 .92845 L F
.41635 .92724 m .40952 .92995 L .41206 .93131 L F
.4167 .92375 m .41826 .9276 L .41669 .9273 L .751 .492 .541 r
F
.41552 .92675 m .41507 .92699 L .41642 .92718 L .644 .733 .913 r
F
.4157 .92684 m .41669 .92734 L .4157 .92688 L .844 .572 .527 r
F
.41645 .92363 m .40982 .92617 L .41235 .92752 L .644 .733 .913 r
F
.4168 .8684 m .41817 .92403 L .4167 .92375 L .751 .492 .541 r
F
.41885 .92134 m .41545 .92316 L .41645 .92363 L .644 .733 .913 r
F
.41545 .92316 m .40982 .92617 L .41645 .92363 L F
.41571 .92328 m .41669 .9273 L .4157 .92684 L .844 .572 .527 r
F
.41581 .86793 m .41664 .92372 L .41571 .92328 L F
.41664 .92372 m .41669 .9273 L .41571 .92328 L F
.41669 .9273 m .41669 .92734 L .4157 .92684 L F
.41642 .92718 m .41507 .92699 L .41635 .92724 L .644 .733 .913 r
F
.4186 .92511 m .41552 .92675 L .41642 .92718 L F
.41507 .92699 m .40952 .92995 L .41635 .92724 L F
.41533 .92845 m .4118 .93555 L .41823 .93644 L F
.4186 .92511 m .41206 .93131 L .41505 .93225 L F
.41669 .9273 m .41826 .9276 L .41669 .92734 L .751 .492 .541 r
F
.41533 .92845 m .41823 .93644 L .41854 .92889 L .644 .733 .913 r
F
.4186 .92511 m .41505 .93225 L .41829 .9327 L F
.41826 .9276 m .41826 .9276 L .41669 .9273 L .751 .492 .541 r
F
.41817 .92403 m .41826 .9276 L .4167 .92375 L F
.41885 .92134 m .41758 .92391 L .41874 .92414 L .644 .733 .913 r
F
.41885 .92134 m .41639 .92369 L .41758 .92391 L F
.41629 .92378 m .41235 .92752 L .41696 .92434 L F
.4079 .92449 m .40079 .93098 L .40982 .92617 L F
.4142 .92556 m .40607 .92437 L .40641 .92636 L F
.41505 .92272 m .4157 .92683 L .41504 .92628 L .927 .648 .492 r
F
.4186 .92511 m .4133 .9248 L .4142 .92556 L .644 .733 .913 r
F
.4168 .8684 m .41836 .86866 L .41826 .92405 L .751 .492 .541 r
F
.4168 .8684 m .41826 .92405 L .41817 .92403 L F
.41545 .92316 m .4079 .92449 L .40982 .92617 L .644 .733 .913 r
F
.41885 .92134 m .41435 .92264 L .41545 .92316 L F
.41435 .92264 m .4079 .92449 L .41545 .92316 L F
.41581 .86793 m .4168 .8684 L .4167 .92375 L .844 .572 .527 r
F
.41664 .92372 m .4167 .92375 L .41669 .92734 L F
.41581 .86793 m .4167 .92375 L .41664 .92372 L F
.4133 .9248 m .40607 .92437 L .4142 .92556 L .644 .733 .913 r
F
.40982 .92617 m .40585 .93369 L .41235 .92752 L F
.41507 .92699 m .40759 .92827 L .40952 .92995 L F
.41817 .92403 m .41826 .92405 L .41826 .9276 L .751 .492 .541 r
F
.41567 .92325 m .4157 .92684 L .41505 .92272 L .927 .648 .492 r
F
.4157 .92684 m .4157 .92688 L .4157 .92683 L F
.4157 .92684 m .4157 .92683 L .41505 .92272 L F
.41557 .92672 m .41324 .92665 L .41507 .92699 L .644 .733 .913 r
F
.4186 .92511 m .41491 .92617 L .41557 .92672 L F
.41491 .92617 m .41324 .92665 L .41557 .92672 L F
.41324 .92665 m .40759 .92827 L .41507 .92699 L F
.41504 .92628 m .4157 .92688 L .41504 .92629 L .927 .648 .492 r
F
.4157 .92683 m .4157 .92688 L .41504 .92628 L F
.41515 .86735 m .41567 .92325 L .41505 .92272 L F
.41639 .92369 m .41629 .92378 L .41758 .92391 L .644 .733 .913 r
F
.41629 .92378 m .41696 .92434 L .41758 .92391 L F
0 g
.41826 .92521 m
.41826 .92514 L
s
.41836 .86866 m
.41837 .86366 L
s
.7797 .71807 m .77935 .7124 L .79534 .7049 L .518 .334 .57 r
F
0 g
.77106 .7146 m
.77935 .7124 L
s
.5144 .60415 m .49938 .60857 L .49895 .61584 L .343 .165 .49 r
F
0 g
.4894 .62259 m
.49938 .60857 L
s
.40162 .84434 m .38573 .83964 L .38177 .8452 L .683 .77 .917 r
F
.40469 .84188 m .38573 .83964 L .40162 .84434 L F
.4227 .92294 m .42745 .9272 L .42949 .92575 L .644 .733 .913 r
F
.41885 .92134 m .4217 .92328 L .4227 .92294 L F
.4217 .92328 m .42745 .9272 L .4227 .92294 L F
.41994 .86846 m .42096 .86803 L .42087 .92357 L .519 .305 .529 r
F
.42081 .92359 m .42087 .92357 L .42086 .92697 L F
.41994 .86846 m .42087 .92357 L .42081 .92359 L F
.76749 .69939 m .77918 .71221 L .79508 .70474 L .673 .758 .914 r
F
.7553 .70262 m .77918 .71221 L .76749 .69939 L F
.35594 .62327 m .3885 .61977 L .3572 .61813 L .654 .726 .902 r
F
.42065 .74236 m .40083 .7386 L .40113 .74427 L .672 .45 .575 r
F
0 g
.38281 .74913 m
.40113 .74427 L
s
.42065 .74236 m .42034 .7367 L .40083 .7386 L .672 .45 .575 r
F
0 g
.38251 .74346 m
.40083 .7386 L
s
.33033 .60089 m .33231 .59666 L .32906 .60022 L .675 .735 .895 r
F
.33033 .60089 m .33484 .59799 L .33231 .59666 L F
.74301 .71537 m .74214 .7305 L .76166 .7286 L .673 .758 .915 r
F
.73011 .71458 m .74214 .7305 L .74301 .71537 L F
.73011 .71458 m .72279 .72931 L .74214 .7305 L F
.66161 .62435 m .66202 .61708 L .64768 .60383 L .928 .669 .526 r
F
0 g
.66202 .61708 m
.6707 .63208 L
s
.38255 .85431 m .36458 .85238 L .36228 .86115 L .683 .77 .917 r
F
0 g
.36228 .86115 m
.36382 .8697 L
s
.42282 .92223 m .42949 .92575 L .43082 .92401 L .644 .733 .913 r
F
.41885 .92134 m .42213 .9227 L .42282 .92223 L F
.42213 .9227 m .42949 .92575 L .42282 .92223 L F
.42096 .86803 m .42167 .86747 L .42157 .92309 L .359 .182 .499 r
F
.42153 .92311 m .42157 .92309 L .42156 .92641 L F
.42096 .86803 m .42157 .92309 L .42153 .92311 L F
.127 .923 .03 r
.47767 .93278 m
.47785 .91431 L
s
.43447 .84714 m .44521 .83639 L .4316 .84499 L .683 .77 .917 r
F
.43447 .84714 m .45095 .8407 L .44521 .83639 L F
.4148 .92251 m .40673 .92259 L .4079 .92449 L .644 .733 .913 r
F
.41885 .92134 m .41402 .92184 L .4148 .92251 L F
.41402 .92184 m .40673 .92259 L .4148 .92251 L F
.41515 .86735 m .41581 .86793 L .41571 .92328 L .927 .648 .492 r
F
.41567 .92325 m .41571 .92328 L .4157 .92688 L F
.41515 .86735 m .41571 .92328 L .41567 .92325 L F
.127 .923 .03 r
.60201 .57811 m
.60214 .57305 L
s
.61246 .6027 m .62882 .58621 L .60655 .57904 L .654 .726 .902 r
F
.32906 .60022 m .32933 .59582 L .32757 .5998 L .675 .735 .895 r
F
.32906 .60022 m .33231 .59666 L .32933 .59582 L F
.43104 .84047 m .43704 .82879 L .42727 .83891 L .683 .77 .917 r
F
.43104 .84047 m .44459 .83191 L .43704 .82879 L F
.26623 .59567 m .23615 .58889 L .23245 .60431 L .654 .726 .902 r
F
.23568 .59616 m .23245 .60431 L .23198 .61158 L 0 0 .128 r
F
0 g
.23298 .60742 m
.23371 .61167 L
s
.23568 .59616 m .23615 .58889 L .23245 .60431 L 0 0 .128 r
F
.26623 .59567 m .23245 .60431 L .26375 .60595 L .654 .726 .902 r
F
.27085 .71433 m .28583 .7156 L .28613 .72126 L .858 .596 .542 r
F
.27085 .71433 m .27055 .70867 L .28583 .7156 L F
0 g
.28583 .7156 m
.29058 .71671 L
s
.42267 .92157 m .43082 .92401 L .43132 .92208 L .644 .733 .913 r
F
.41885 .92134 m .42228 .92211 L .42267 .92157 L F
.42228 .92211 m .43082 .92401 L .42267 .92157 L F
.42167 .86747 m .4221 .86679 L .422 .92249 L .077 0 .416 r
F
.42198 .92252 m .422 .92249 L .42199 .92574 L F
.42167 .86747 m .422 .92249 L .42198 .92252 L F
.127 .923 .03 r
.39769 8.82727 m
.45999 1.00832 L
s
.62614 .71609 m .65317 .7078 L .62825 .70826 L .673 .758 .914 r
F
.60228 .71263 m .62614 .71609 L .62825 .70826 L F
.5996 .71631 m .62614 .71609 L .60228 .71263 L F
.29948 .71359 m .30436 .73113 L .31144 .71639 L F
.29948 .71359 m .28642 .72693 L .30436 .73113 L F
0 g
.30436 .73113 m
.32374 .73232 L
s
.36126 .71988 m .37683 .70672 L .37714 .71238 L .516 .331 .568 r
F
.36157 .72555 m .36126 .71988 L .37714 .71238 L F
.3493 .707 m .36126 .71988 L .37714 .71238 L .673 .757 .914 r
F
.33708 .71025 m .36126 .71988 L .3493 .707 L F
0 g
.35291 .7221 m
.36126 .71988 L
s
.29629 .60245 m .26375 .60595 L .29505 .60759 L .654 .726 .902 r
F
.29629 .60245 m .26623 .59567 L .26375 .60595 L F
.4145 .92179 m .40639 .92061 L .40673 .92259 L .644 .733 .913 r
F
.41885 .92134 m .41408 .92106 L .4145 .92179 L F
.41626 .91977 m .41514 .92379 L .41626 .92301 L .403 .215 .509 r
F
.41636 .86407 m .41521 .9204 L .41626 .91977 L F
.41521 .9204 m .41514 .92379 L .41626 .91977 L F
.41407 .92106 m .40639 .92061 L .4145 .92179 L .644 .733 .913 r
F
.41477 .86666 m .41515 .86735 L .41505 .92272 L .989 .721 .392 r
F
.41503 .92268 m .41505 .92272 L .41504 .92629 L F
.41477 .86666 m .41505 .92272 L .41503 .92268 L F
.50359 .71622 m .50526 .72226 L .50558 .72793 L .83 .626 .076 r
F
.50359 .71622 m .50327 .71056 L .50526 .72226 L F
0 g
.50526 .72226 m
.50857 .72739 L
s
.28888 .69752 m .28603 .7154 L .29901 .70212 L .673 .757 .914 r
F
.28888 .69752 m .27083 .7085 L .28603 .7154 L F
.44002 .74355 m .42034 .7367 L .42065 .74236 L .733 .497 .571 r
F
0 g
.40083 .7386 m
.42034 .7367 L
s
.42034 .7367 m
.43971 .73788 L
s
.44002 .74355 m
.45793 .74775 L
s
.127 .923 .03 r
.43885 .78249 m
.43921 .7121 L
s
.32757 .5998 m .32611 .59552 L .32596 .59965 L .675 .735 .895 r
F
.32596 .59965 m .32287 .59578 L .32435 .59978 L F
.32596 .59965 m .32611 .59552 L .32287 .59578 L F
.32763 .60262 m .32616 .59832 L .32602 .60247 L F
.32602 .60247 m .32616 .59832 L .32291 .59858 L F
.32607 .60532 m .32296 .60143 L .32444 .60545 L F
.32607 .60532 m .32621 .60116 L .32296 .60143 L F
.32611 .59552 m .3214 .59178 L .32287 .59578 L F
.32611 .59552 m .32625 .59138 L .3214 .59178 L F
.32616 .59832 m .32143 .59456 L .32291 .59858 L F
.32616 .59832 m .32631 .59416 L .32143 .59456 L F
.32621 .60116 m .32636 .59701 L .32148 .5974 L F
.32631 .59416 m .32137 .59172 L .32143 .59456 L .666 .426 .547 r
F
.32631 .59416 m .32626 .59132 L .32137 .59172 L F
.32636 .59701 m .32143 .59456 L .32148 .5974 L F
.32636 .59701 m .32631 .59416 L .32143 .59456 L F
.32635 .60923 m .32706 .58914 L .31893 .5894 L .654 .726 .902 r
F
0 g
.32269 .61262 m
.32271 .60821 L
s
.32757 .5998 m .32933 .59582 L .32611 .59552 L .675 .735 .895 r
F
.32913 .60305 m .3294 .59862 L .32763 .60262 L F
.32913 .60305 m .33239 .59947 L .3294 .59862 L F
.32763 .60262 m .3294 .59862 L .32616 .59832 L F
.33231 .59666 m .33108 .59183 L .32933 .59582 L F
.33231 .59666 m .33555 .5931 L .33108 .59183 L F
.32768 .60547 m .32621 .60116 L .32607 .60532 L F
.32768 .60547 m .32945 .60146 L .32621 .60116 L F
.32933 .59582 m .32625 .59138 L .32611 .59552 L F
.32933 .59582 m .33108 .59183 L .32625 .59138 L F
.33239 .59947 m .33116 .59462 L .3294 .59862 L F
.3294 .59862 m .32631 .59416 L .32616 .59832 L F
.3294 .59862 m .33116 .59462 L .32631 .59416 L F
.32945 .60146 m .32636 .59701 L .32621 .60116 L F
.32945 .60146 m .33121 .59746 L .32636 .59701 L F
.33116 .59462 m .33111 .59177 L .32626 .59132 L .731 .478 .545 r
F
.33565 .59589 m .33111 .59177 L .33116 .59462 L .794 .53 .538 r
F
.33116 .59462 m .32626 .59132 L .32631 .59416 L .731 .478 .545 r
F
.33121 .59746 m .33116 .59462 L .32631 .59416 L F
.33121 .59746 m .32631 .59416 L .32636 .59701 L F
.32635 .60923 m .33514 .59025 L .32706 .58914 L .654 .726 .902 r
F
.3304 .60372 m .33239 .59947 L .32913 .60305 L .675 .735 .895 r
F
.3304 .60372 m .33494 .6008 L .33239 .59947 L F
.33484 .59799 m .33555 .5931 L .33231 .59666 L F
.33484 .59799 m .33936 .59509 L .33555 .5931 L F
.32918 .60589 m .32945 .60146 L .32768 .60547 L F
.32918 .60589 m .33244 .60231 L .32945 .60146 L F
.33948 .59789 m .33942 .59505 L .3356 .59304 L .86 .586 .522 r
F
.33239 .59947 m .33565 .59589 L .33116 .59462 L .675 .735 .895 r
F
.33948 .59789 m .3356 .59304 L .33565 .59589 L .86 .586 .522 r
F
.33565 .59589 m .3356 .59304 L .33111 .59177 L .794 .53 .538 r
F
.33244 .60231 m .33121 .59746 L .32945 .60146 L .675 .735 .895 r
F
.33244 .60231 m .3357 .59873 L .33121 .59746 L F
.3357 .59873 m .33565 .59589 L .33116 .59462 L .794 .53 .538 r
F
.3357 .59873 m .33116 .59462 L .33121 .59746 L F
.32635 .60923 m .34262 .59265 L .33514 .59025 L .654 .726 .902 r
F
0 g
.32922 .60933 m
.32922 .60842 L
s
.52857 .71009 m .50563 .7222 L .52989 .71786 L .673 .758 .914 r
F
.52857 .71009 m .50365 .71055 L .50563 .7222 L F
.76166 .7286 m .7797 .71807 L .78004 .72373 L .604 .398 .575 r
F
.75604 .7141 m .76166 .7286 L .78004 .72373 L .673 .758 .915 r
F
.74301 .71537 m .76166 .7286 L .75604 .7141 L F
0 g
.74214 .7305 m
.76166 .7286 L
s
.38573 .83964 m .36389 .84328 L .38177 .8452 L .683 .77 .917 r
F
.35765 .61087 m .3872 .602 L .35677 .60561 L .654 .726 .902 r
F
.35765 .61087 m .38895 .6125 L .3872 .602 L F
.38895 .6125 m .41765 .59838 L .3872 .602 L F
.38895 .6125 m .42025 .61414 L .41765 .59838 L F
.65101 .73092 m .65388 .71346 L .65421 .71913 L 0 0 .332 r
F
.62704 .72745 m .65101 .73092 L .65421 .71913 L .673 .758 .915 r
F
0 g
.64292 .742 m
.65101 .73092 L
s
.42025 .61414 m .41809 .59111 L .41765 .59838 L .923 .743 .256 r
F
.41981 .62141 m .42025 .61414 L .41765 .59838 L F
0 g
.41847 .62134 m
.41944 .61743 L
s
.40251 .85344 m .38255 .85431 L .40051 .85623 L .683 .77 .917 r
F
0 g
.42065 .74236 m
.44002 .74355 L
s
.42166 .9208 m .4206 .92309 L .42166 .9239 L .908 .63 .503 r
F
.42176 .86496 m .42066 .92006 L .42166 .9208 L F
.4221 .86679 m .42211 .9218 L .422 .92249 L 0 0 .138 r
F
.42224 .921 m .43132 .92208 L .43098 .9201 L .644 .733 .913 r
F
.41885 .92134 m .42215 .92154 L .42224 .921 L F
.42215 .92154 m .43132 .92208 L .42224 .921 L F
.4221 .86679 m .42221 .86599 L .42211 .92176 L 0 0 .138 r
F
.42211 .9218 m .42211 .92176 L .42211 .92494 L F
.4221 .86679 m .42211 .92176 L .42211 .9218 L F
.42066 .92006 m .4206 .92309 L .42166 .9208 L .908 .63 .503 r
F
.41981 .91942 m .42276 .91763 L .42238 .91424 L .644 .733 .913 r
F
.42061 .92002 m .41953 .92272 L .4206 .92309 L .809 .541 .534 r
F
.42071 .86415 m .41959 .91966 L .42061 .92002 L F
.41885 .92134 m .42035 .91993 L .41968 .91969 L .644 .733 .913 r
F
.42221 .86599 m .42176 .86496 L .42166 .9208 L .985 .728 .345 r
F
.42169 .92085 m .42166 .9208 L .42166 .9239 L F
.42221 .86599 m .42166 .9208 L .42169 .92085 L F
.42097 .91933 m .42789 .91652 L .42536 .91517 L .644 .733 .913 r
F
.41885 .92134 m .42131 .92004 L .42097 .91933 L F
.42131 .92004 m .42789 .91652 L .42097 .91933 L F
.42131 .92004 m .42981 .9182 L .42789 .91652 L F
.41885 .92134 m .42156 .92057 L .42131 .92004 L F
.42156 .92057 m .42981 .9182 L .42131 .92004 L F
.422 .92249 m .42211 .92494 L .42199 .92574 L 0 0 .138 r
F
.42211 .9218 m .42211 .92494 L .422 .92249 L F
.42211 .92176 m .42166 .9239 L .42211 .92494 L .985 .728 .345 r
F
.42221 .86599 m .42169 .92085 L .42211 .92176 L F
.42169 .92085 m .42166 .9239 L .42211 .92176 L F
.41959 .91966 m .41953 .92272 L .42061 .92002 L .809 .541 .534 r
F
.41968 .91969 m .42041 .91987 L .41981 .91942 L .644 .733 .913 r
F
.42035 .91993 m .42041 .91987 L .41968 .91969 L F
.42041 .91987 m .42276 .91763 L .41981 .91942 L F
.42276 .91763 m .42536 .91517 L .42326 .91451 L F
.42276 .91763 m .42326 .91451 L .42238 .91424 L F
.127 .923 .03 r
.39726 8.82688 m
.43374 1.7712 L
s
.43203 4.08966 m
.49551 8.79951 L
s
.41407 .92106 m .40689 .91868 L .40639 .92061 L .644 .733 .913 r
F
.41885 .92134 m .41354 .92016 L .41407 .92106 L F
.41354 .92016 m .40689 .91868 L .41407 .92106 L F
.41467 .92208 m .41504 .92629 L .41466 .9256 L .989 .721 .392 r
F
.41477 .86666 m .41503 .92268 L .41467 .92208 L F
.41503 .92268 m .41504 .92629 L .41467 .92208 L F
.41455 .92039 m .40821 .91693 L .40689 .91868 L .644 .733 .913 r
F
.41885 .92134 m .41449 .91953 L .41455 .92039 L F
.41449 .91953 m .40821 .91693 L .41455 .92039 L F
.41472 .86586 m .41477 .86666 L .41467 .92208 L .789 .63 .07 r
F
.41467 .92203 m .41467 .92208 L .41466 .9256 L F
.41472 .86586 m .41467 .92208 L .41467 .92203 L F
.127 .923 .03 r
.40712 2.24185 m
.43203 4.08966 L
s
.77436 .62145 m .80701 .61795 L .7757 .61631 L .654 .726 .902 r
F
.45492 .85045 m .46793 .83881 L .45144 .84526 L .683 .77 .917 r
F
.45492 .85045 m .47315 .84659 L .46793 .83881 L F
.47266 .84203 m .46695 .82969 L .46744 .83425 L .981 .69 .342 r
F
.47315 .84659 m .47266 .84203 L .46744 .83425 L F
0 g
.47266 .84203 m
.47416 .85059 L
s
.74875 .59906 m .7533 .59617 L .75079 .59484 L .675 .735 .895 r
F
.55467 .72487 m .53492 .73644 L .55699 .72847 L .673 .758 .915 r
F
.55467 .72487 m .53028 .72923 L .53492 .73644 L F
.40202 .84887 m .38605 .84416 L .38207 .84974 L .683 .77 .917 r
F
.40511 .8464 m .38605 .84416 L .40202 .84887 L F
.30018 .59056 m .26699 .58847 L .2969 .59522 L .654 .726 .902 r
F
.53594 .6195 m .5144 .60415 L .49895 .61584 L F
0 g
.49938 .60857 m
.50621 .6034 L
s
.48897 .62986 m
.49895 .61584 L
s
.54918 .6138 m .5144 .60415 L .53594 .6195 L .654 .726 .902 r
F
.40469 .84188 m .39186 .83472 L .38573 .83964 L .683 .77 .917 r
F
.40863 .83991 m .39186 .83472 L .40469 .84188 L F
.35707 .59836 m .38148 .5848 L .35413 .59338 L .654 .726 .902 r
F
.35707 .59836 m .38734 .59477 L .38148 .5848 L F
.41449 .91953 m .41026 .91549 L .40821 .91693 L .644 .733 .913 r
F
.41885 .92134 m .4144 .91831 L .41449 .91953 L F
.4144 .91831 m .41026 .91549 L .41449 .91953 L F
.41462 .92134 m .41466 .9256 L .41461 .9248 L .789 .63 .07 r
F
.41472 .86586 m .41467 .92203 L .41462 .92134 L F
.41467 .92203 m .41466 .9256 L .41462 .92134 L F
.41514 .92044 m .41461 .9248 L .41514 .92379 L 0 0 .377 r
F
.41525 .86484 m .41465 .92129 L .41514 .92044 L F
.41465 .92129 m .41461 .9248 L .41514 .92044 L F
.41632 .91841 m .41593 .91386 L .41289 .91444 L .644 .733 .913 r
F
.41845 .91948 m .41736 .92268 L .41845 .92259 L .661 .418 .542 r
F
.41855 .86365 m .41742 .91951 L .41845 .91948 L F
.41885 .92134 m .41813 .91949 L .41727 .91952 L .644 .733 .913 r
F
.41647 .91972 m .41632 .91841 L .41582 .91928 L F
.41885 .92134 m .41729 .91953 L .41647 .91972 L F
.41746 .86374 m .41632 .91976 L .41736 .91951 L .57 .345 .536 r
F
.41729 .91953 m .41632 .91841 L .41647 .91972 L .644 .733 .913 r
F
.41736 .91951 m .41626 .92301 L .41736 .92268 L .57 .345 .536 r
F
.41632 .91976 m .41626 .92301 L .41736 .91951 L F
.41742 .91951 m .41736 .92268 L .41845 .91948 L .661 .418 .542 r
F
.41727 .91952 m .41715 .91699 L .41632 .91841 L .644 .733 .913 r
F
.41813 .91949 m .41715 .91699 L .41727 .91952 L F
.41715 .91699 m .41593 .91386 L .41632 .91841 L F
.41582 .91928 m .41289 .91444 L .41026 .91549 L F
.41632 .91841 m .41289 .91444 L .41582 .91928 L F
.41525 .86484 m .41472 .86586 L .41462 .92134 L 0 0 .377 r
F
.41465 .92129 m .41462 .92134 L .41461 .9248 L F
.41525 .86484 m .41462 .92134 L .41465 .92129 L F
.62447 .62413 m .62825 .6005 L .6118 .61708 L .654 .726 .902 r
F
.62447 .62413 m .64727 .6111 L .62825 .6005 L F
.74435 .60765 m .73903 .60554 L .73835 .60654 L .675 .735 .895 r
F
.74435 .60765 m .7414 .60403 L .74007 .60468 L F
.6544 .59433 m .65481 .58706 L .65087 .60249 L 0 0 .154 r
F
0 g
.65021 .59853 m
.6516 .59981 L
s
.65157 .59978 m
.65161 .59961 L
s
.68944 .71252 m .70426 .71378 L .7046 .71945 L .859 .596 .539 r
F
.68944 .71252 m .68911 .70685 L .70426 .71378 L F
0 g
.70426 .71378 m
.7091 .71492 L
s
.7182 .71177 m .72279 .72931 L .73011 .71458 L .673 .758 .915 r
F
.7182 .71177 m .70493 .72511 L .72279 .72931 L F
0 g
.72279 .72931 m
.74214 .7305 L
s
.7797 .71807 m .79534 .7049 L .79568 .71056 L .518 .334 .57 r
F
.78004 .72373 m .7797 .71807 L .79568 .71056 L F
.76795 .70518 m .7797 .71807 L .79568 .71056 L .673 .758 .914 r
F
.75569 .70843 m .7797 .71807 L .76795 .70518 L F
0 g
.7714 .72026 m
.7797 .71807 L
s
.43495 .85171 m .4457 .84095 L .43208 .84955 L .683 .77 .917 r
F
.43495 .85171 m .45144 .84526 L .4457 .84095 L F
.7148 .60062 m .68218 .60413 L .71348 .60577 L .654 .726 .902 r
F
.7148 .60062 m .68481 .59384 L .68218 .60413 L F
.7076 .6957 m .70446 .71358 L .71765 .7003 L .673 .758 .914 r
F
.7076 .6957 m .68938 .70668 L .70446 .71358 L F
.7444 .59783 m .74137 .59396 L .74278 .59796 L .675 .735 .895 r
F
.7444 .59783 m .74461 .59369 L .74137 .59396 L F
.74448 .60065 m .74143 .59676 L .74285 .60078 L F
.74448 .60065 m .74469 .59649 L .74143 .59676 L F
.74456 .60349 m .7415 .5996 L .74293 .60363 L F
.74456 .60349 m .74476 .59934 L .7415 .5996 L F
.74461 .59369 m .73995 .58995 L .74137 .59396 L F
.74461 .59369 m .74481 .58956 L .73995 .58995 L F
.74469 .59649 m .74 .59274 L .74143 .59676 L F
.74469 .59649 m .74489 .59234 L .74 .59274 L F
.74476 .59934 m .74008 .59558 L .7415 .5996 L F
.74476 .59934 m .74497 .59518 L .74008 .59558 L F
.74489 .59234 m .73993 .58989 L .74 .59274 L .666 .426 .548 r
F
.74489 .59234 m .74481 .5895 L .73993 .58989 L F
.74497 .59518 m .74 .59274 L .74008 .59558 L F
.74497 .59518 m .74489 .59234 L .74 .59274 L F
.74478 .6074 m .74579 .58732 L .73765 .58758 L .654 .726 .902 r
F
0 g
.74116 .60638 m
.74118 .61072 L
s
.74885 .60189 m .7509 .59764 L .74759 .60122 L .675 .735 .895 r
F
.74885 .60189 m .75343 .59898 L .7509 .59764 L F
.7533 .59617 m .75408 .59127 L .75079 .59484 L F
.7533 .59617 m .75786 .59327 L .75408 .59127 L F
.74766 .60407 m .74799 .59964 L .74617 .60364 L F
.74766 .60407 m .75097 .60049 L .74799 .59964 L F
.75343 .59898 m .75421 .59406 L .7509 .59764 L F
.758 .59606 m .75793 .59322 L .75413 .59122 L .861 .585 .519 r
F
.7509 .59764 m .75421 .59406 L .74974 .59279 L .675 .735 .895 r
F
.758 .59606 m .75413 .59122 L .75421 .59406 L .861 .585 .519 r
F
.75421 .59406 m .75413 .59122 L .74966 .58995 L .794 .529 .537 r
F
.75097 .60049 m .75428 .5969 L .74981 .59563 L .675 .735 .895 r
F
.75428 .5969 m .75421 .59406 L .74974 .59279 L .794 .529 .537 r
F
.75428 .5969 m .74974 .59279 L .74981 .59563 L F
.74478 .6074 m .76132 .59083 L .75386 .58843 L .654 .726 .902 r
F
0 g
.74767 .6066 m
.74768 .6078 L
s
.77609 .60904 m .8058 .60017 L .77529 .60379 L .654 .726 .902 r
F
.77609 .60904 m .80739 .61068 L .8058 .60017 L F
0 g
.40113 .74427 m
.42065 .74236 L
s
.80739 .61068 m .83633 .59656 L .8058 .60017 L .654 .726 .902 r
F
.80739 .61068 m .83869 .61232 L .83633 .59656 L F
.32159 .60651 m .31521 .60526 L .32057 .60736 L .675 .735 .895 r
F
.83869 .61232 m .83671 .58929 L .83633 .59656 L .908 .731 .232 r
F
.83831 .61959 m .83869 .61232 L .83633 .59656 L F
0 g
.83681 .61951 m
.83794 .61521 L
s
.42727 .83891 m .42815 .82705 L .42282 .83804 L .683 .77 .917 r
F
.42727 .83891 m .43704 .82879 L .42815 .82705 L F
.4316 .84499 m .43762 .83325 L .4278 .84342 L F
.4316 .84499 m .44521 .83639 L .43762 .83325 L F
.42141 .92061 m .43098 .9201 L .42981 .9182 L .644 .733 .913 r
F
.41885 .92134 m .42196 .92102 L .42141 .92061 L F
.42196 .92102 m .43098 .9201 L .42141 .92061 L F
.42176 .86496 m .42071 .86415 L .42061 .92002 L .908 .63 .503 r
F
.42066 .92006 m .42061 .92002 L .4206 .92309 L F
.42176 .86496 m .42061 .92002 L .42066 .92006 L F
0 g
.42167 .91566 m
.42176 .86496 L
s
.42176 .86496 m
.42177 .85687 L
s
.41636 .86407 m .41525 .86484 L .41514 .92379 L .403 .215 .509 r
F
0 g
.41516 .914 m
.41525 .86484 L
s
.41525 .86484 m
.41526 .85719 L
s
.38605 .84416 m .3641 .84782 L .38207 .84974 L .683 .77 .917 r
F
.4503 .8362 m .45815 .82335 L .44459 .83191 L F
.4503 .8362 m .4667 .82978 L .45815 .82335 L F
.62671 .72179 m .65388 .71346 L .62883 .71392 L .673 .758 .914 r
F
.60273 .71831 m .62671 .72179 L .62883 .71392 L F
.60004 .72201 m .62671 .72179 L .60273 .71831 L F
.27114 .72 m .28613 .72126 L .28642 .72693 L .858 .596 .542 r
F
.27114 .72 m .27085 .71433 L .28613 .72126 L F
.28899 .7033 m .28613 .72126 L .29918 .70792 L .673 .757 .914 r
F
.28899 .7033 m .27085 .71433 L .28613 .72126 L F
0 g
.28613 .72126 m
.29088 .72238 L
s
.36157 .72555 m .37714 .71238 L .37744 .71805 L .516 .331 .568 r
F
.3496 .71267 m .36157 .72555 L .37744 .71805 L .673 .758 .914 r
F
.33738 .71592 m .36157 .72555 L .3496 .71267 L F
0 g
.34325 .73041 m
.36157 .72555 L
s
.32159 .60651 m .31726 .60355 L .31521 .60526 L .675 .735 .895 r
F
.32291 .60586 m .31726 .60355 L .32159 .60651 L F
.7187 .58873 m .68551 .58664 L .71535 .59339 L .654 .726 .902 r
F
.5039 .72189 m .50558 .72793 L .50589 .73359 L .83 .626 .076 r
F
.5039 .72189 m .50359 .71622 L .50558 .72793 L F
.52864 .71576 m .50558 .72793 L .52996 .72357 L .673 .758 .914 r
F
.52864 .71576 m .50359 .71622 L .50558 .72793 L F
0 g
.50558 .72793 m
.50889 .73306 L
s
.42071 .86415 m .41963 .86377 L .41953 .92272 L .809 .541 .534 r
F
.47315 .84659 m .46744 .83425 L .46793 .83881 L .981 .69 .342 r
F
0 g
.47315 .84659 m
.47465 .85515 L
s
.77552 .59654 m .80016 .58297 L .77266 .59156 L .654 .726 .902 r
F
.77552 .59654 m .80588 .59294 L .80016 .58297 L F
.40863 .83991 m .39974 .83078 L .39186 .83472 L .683 .77 .917 r
F
.41317 .83856 m .39974 .83078 L .40863 .83991 L F
.41746 .86374 m .41636 .86407 L .41626 .92301 L .57 .345 .536 r
F
.66161 .62435 m .64768 .60383 L .64727 .6111 L .928 .669 .526 r
F
0 g
.65119 .60708 m
.66202 .61708 L
s
.64981 .6058 m
.65119 .60708 L
s
.66161 .62435 m
.6703 .63935 L
s
.6494 .61307 m
.66161 .62435 L
s
.41963 .86377 m .41845 .92259 L .41953 .92272 L .734 .478 .542 r
F
.41963 .86377 m .41855 .86365 L .41845 .92259 L F
.40251 .85344 m .38653 .84872 L .38255 .85431 L .683 .77 .917 r
F
.40559 .85097 m .38653 .84872 L .40251 .85344 L F
.32291 .60586 m .31991 .60224 L .31726 .60355 L .675 .735 .895 r
F
.32444 .60545 m .31991 .60224 L .32291 .60586 L F
.41855 .86365 m .41746 .86374 L .41736 .92268 L .661 .418 .542 r
F
.5535 .70963 m .52989 .71786 L .55415 .71352 L .673 .758 .914 r
F
.5535 .70963 m .52857 .71009 L .52989 .71786 L F
.42282 .83804 m .41853 .82681 L .41802 .83792 L .683 .77 .917 r
F
.42282 .83804 m .42815 .82705 L .41853 .82681 L F
.40511 .8464 m .39221 .83921 L .38605 .84416 L F
.40907 .84442 m .39221 .83921 L .40511 .8464 L F
.48097 .59285 m .50563 .58891 L .5052 .59617 L .732 .488 .559 r
F
.48097 .59285 m .4814 .58558 L .50563 .58891 L F
.74007 .60468 m .73371 .60343 L .73903 .60554 L .675 .735 .895 r
F
.61221 .60981 m .60627 .58602 L .59729 .605 L .654 .726 .902 r
F
.61221 .60981 m .62866 .59323 L .60627 .58602 L F
.26576 .60294 m .23198 .61158 L .26329 .61322 L F
.26576 .60294 m .23568 .59616 L .23198 .61158 L F
0 g
.23198 .61158 m
.23468 .62733 L
s
.49039 .56639 m .50564 .5886 L .50647 .5686 L .654 .726 .902 r
F
.49039 .56639 m .48154 .5853 L .50564 .5886 L F
.29584 .60972 m .26329 .61322 L .29459 .61486 L F
.29584 .60972 m .26576 .60294 L .26329 .61322 L F
.41317 .83856 m .40884 .82808 L .39974 .83078 L .683 .77 .917 r
F
.41802 .83792 m .40884 .82808 L .41317 .83856 L F
.31991 .60224 m .31293 .60058 L .31726 .60355 L .675 .735 .895 r
F
.31991 .60224 m .3169 .59862 L .31293 .60058 L F
.32296 .60143 m .3169 .59862 L .31991 .60224 L F
.32589 .6165 m .31847 .59667 L .31085 .59829 L .654 .726 .902 r
F
.32589 .6165 m .3266 .59641 L .31847 .59667 L F
.32589 .6165 m .33469 .59752 L .3266 .59641 L F
.41802 .83792 m .41853 .82681 L .40884 .82808 L .683 .77 .917 r
F
.3572 .61813 m .38676 .60927 L .35632 .61288 L .654 .726 .902 r
F
.3572 .61813 m .3885 .61977 L .38676 .60927 L F
.3885 .61977 m .41721 .60566 L .38676 .60927 L F
.3885 .61977 m .41981 .62141 L .41721 .60566 L F
.4278 .84342 m .42868 .8315 L .42333 .84255 L .683 .77 .917 r
F
.4278 .84342 m .43762 .83325 L .42868 .8315 L F
.43208 .84955 m .4381 .83782 L .42828 .84799 L F
.43208 .84955 m .4457 .84095 L .4381 .83782 L F
.38573 .83964 m .36983 .83495 L .36389 .84328 L F
.37714 .71238 m .37683 .70672 L .38919 .69709 L .389 .235 .549 r
F
0 g
.36842 .7107 m
.37683 .70672 L
s
.41981 .62141 m .41765 .59838 L .41721 .60566 L .923 .743 .256 r
F
0 g
.41601 .63681 m
.41981 .62141 L
s
.68978 .71818 m .7046 .71945 L .70493 .72511 L .859 .596 .539 r
F
.68978 .71818 m .68944 .71252 L .7046 .71945 L F
.70775 .70148 m .7046 .71945 L .71786 .7061 L .673 .758 .914 r
F
.70775 .70148 m .68944 .71252 L .7046 .71945 L F
0 g
.7046 .71945 m
.70943 .72058 L
s
.78004 .72373 m .79568 .71056 L .79603 .71623 L .518 .334 .57 r
F
.76829 .71085 m .78004 .72373 L .79603 .71623 L .673 .758 .915 r
F
.75604 .7141 m .78004 .72373 L .76829 .71085 L F
0 g
.76166 .7286 m
.78004 .72373 L
s
.37007 .83944 m .36362 .84325 L .3641 .84782 L .201 .115 .528 r
F
.37007 .83944 m .36959 .83488 L .36362 .84325 L F
0 g
.36132 .85202 m
.36362 .84325 L
s
.74007 .60468 m .73578 .60172 L .73371 .60343 L .675 .735 .895 r
F
.7414 .60403 m .73578 .60172 L .74007 .60468 L F
.35941 .69623 m .37658 .70656 L .38887 .69698 L .673 .757 .914 r
F
.127 .923 .03 r
.37403 .65066 m
.37415 .6966 L
s
.34888 .70121 m .37658 .70656 L .35941 .69623 L .673 .757 .914 r
F
.38653 .84872 m .36458 .85238 L .38255 .85431 L .683 .77 .917 r
F
.45095 .8407 m .45884 .82778 L .44521 .83639 L F
.45095 .8407 m .46744 .83425 L .45884 .82778 L F
.7414 .60403 m .73844 .60042 L .73578 .60172 L .675 .735 .895 r
F
.74293 .60363 m .73844 .60042 L .7414 .60403 L F
.60228 .71263 m .62825 .70826 L .60334 .70872 L .673 .758 .914 r
F
.29959 .59777 m .26623 .59567 L .29629 .60245 L .654 .726 .902 r
F
.40907 .84442 m .40014 .83525 L .39221 .83921 L .683 .77 .917 r
F
.41364 .84307 m .40014 .83525 L .40907 .84442 L F
.35677 .60561 m .38131 .59198 L .35382 .60061 L .654 .726 .902 r
F
.35677 .60561 m .3872 .602 L .38131 .59198 L F
.62704 .72745 m .65421 .71913 L .62916 .71959 L .673 .758 .915 r
F
.60305 .72398 m .62704 .72745 L .62916 .71959 L F
.60036 .72768 m .62704 .72745 L .60305 .72398 L F
.28929 .70897 m .28642 .72693 L .29948 .71359 L .673 .758 .914 r
F
.28929 .70897 m .27114 .72 L .28642 .72693 L F
0 g
.28642 .72693 m
.30436 .73113 L
s
.45856 .58564 m .4814 .58558 L .48097 .59285 L .793 .542 .558 r
F
.45856 .58564 m .45899 .57837 L .4814 .58558 L F
0 g
.4814 .58558 m
.50538 .58887 L
s
.7144 .60789 m .68178 .6114 L .71308 .61303 L .654 .726 .902 r
F
.7144 .60789 m .68441 .60111 L .68178 .6114 L F
.52896 .72143 m .50589 .73359 L .53028 .72923 L .673 .758 .915 r
F
.52896 .72143 m .5039 .72189 L .50589 .73359 L F
0 g
.50589 .73359 m
.51287 .74439 L
s
.40559 .85097 m .3927 .84378 L .38653 .84872 L .683 .77 .917 r
F
.40955 .84899 m .3927 .84378 L .40559 .85097 L F
.42333 .84255 m .41902 .83126 L .4185 .84243 L F
.42333 .84255 m .42868 .8315 L .41902 .83126 L F
.73844 .60042 m .73149 .59876 L .73578 .60172 L .675 .735 .895 r
F
.73844 .60042 m .73548 .5968 L .73149 .59876 L F
.7415 .5996 m .73548 .5968 L .73844 .60042 L F
.74439 .61467 m .73726 .59485 L .7296 .59646 L .654 .726 .902 r
F
.74439 .61467 m .7454 .59459 L .73726 .59485 L F
.74439 .61467 m .75347 .5957 L .7454 .59459 L F
.7757 .61631 m .80542 .60745 L .7749 .61106 L F
.7757 .61631 m .80701 .61795 L .80542 .60745 L F
.47552 .56161 m .48154 .5853 L .49039 .56639 L F
.47552 .56161 m .45924 .57812 L .48154 .5853 L F
.39186 .83472 m .36983 .83495 L .38573 .83964 L .683 .77 .917 r
F
.30018 .59056 m .27353 .57915 L .26699 .58847 L .654 .726 .902 r
F
.30527 .58668 m .27353 .57915 L .30018 .59056 L F
.80701 .61795 m .83595 .60383 L .80542 .60745 L F
.80701 .61795 m .83831 .61959 L .83595 .60383 L F
.79568 .71056 m .79534 .7049 L .80784 .69527 L .394 .241 .552 r
F
0 g
.7869 .70886 m
.79534 .7049 L
s
.83831 .61959 m .83633 .59656 L .83595 .60383 L .908 .731 .232 r
F
0 g
.83428 .63499 m
.83831 .61959 L
s
.35413 .59338 m .37188 .57599 L .34933 .58898 L .654 .726 .902 r
F
.35413 .59338 m .38148 .5848 L .37188 .57599 L F
.77809 .69441 m .79508 .70474 L .80752 .69516 L .673 .758 .914 r
F
.76749 .69939 m .79508 .70474 L .77809 .69441 L F
.27353 .57915 m .23707 .58172 L .26699 .58847 L .654 .726 .902 r
F
.55369 .7153 m .52996 .72357 L .55435 .7192 L .673 .758 .914 r
F
.55369 .7153 m .52864 .71576 L .52996 .72357 L F
.41364 .84307 m .40928 .83254 L .40014 .83525 L .683 .77 .917 r
F
.4185 .84243 m .40928 .83254 L .41364 .84307 L F
.4185 .84243 m .41902 .83126 L .40928 .83254 L F
.42828 .84799 m .42917 .83607 L .42382 .84711 L F
.42828 .84799 m .4381 .83782 L .42917 .83607 L F
.38734 .59477 m .40885 .57621 L .38148 .5848 L .654 .726 .902 r
F
.38734 .59477 m .41763 .59117 L .40885 .57621 L F
.37055 .844 m .3641 .84782 L .36458 .85238 L .201 .115 .528 r
F
.38605 .84416 m .37007 .83944 L .3641 .84782 L .683 .77 .917 r
F
.37055 .844 m .37007 .83944 L .3641 .84782 L .201 .115 .528 r
F
0 g
.3618 .85658 m
.3641 .84782 L
s
.71817 .59594 m .68481 .59384 L .7148 .60062 L .654 .726 .902 r
F
.45144 .84526 m .45933 .83235 L .4457 .84095 L .683 .77 .917 r
F
.45144 .84526 m .46793 .83881 L .45933 .83235 L F
.77529 .60379 m .80005 .59016 L .77241 .59878 L .654 .726 .902 r
F
.77529 .60379 m .8058 .60017 L .80005 .59016 L F
.37714 .71238 m .38919 .69709 L .38949 .70275 L .389 .235 .549 r
F
.37744 .71805 m .37714 .71238 L .38949 .70275 L F
.35988 .702 m .37714 .71238 L .38949 .70275 L .673 .757 .914 r
F
.3493 .707 m .37714 .71238 L .35988 .702 L F
0 g
.36872 .71636 m
.37714 .71238 L
s
.70809 .70715 m .70493 .72511 L .7182 .71177 L .673 .758 .915 r
F
.70809 .70715 m .68978 .71818 L .70493 .72511 L F
0 g
.70493 .72511 m
.72279 .72931 L
s
.65388 .71346 m .65355 .70779 L .65162 .69608 L .822 .619 .066 r
F
0 g
.652 .71349 m
.65327 .7088 L
s
.62825 .70826 m .65317 .7078 L .65126 .69614 L .673 .758 .914 r
F
.40955 .84899 m .40062 .83982 L .3927 .84378 L .683 .77 .917 r
F
.41412 .84763 m .40062 .83982 L .40955 .84899 L F
.64768 .60383 m .64808 .59656 L .62907 .58596 L .858 .601 .55 r
F
0 g
.64808 .59656 m
.65021 .59853 L
s
.54918 .6138 m .53427 .59559 L .5144 .60415 L .654 .726 .902 r
F
0 g
.49895 .61584 m
.5144 .60415 L
s
.56446 .61058 m .53427 .59559 L .54918 .6138 L .654 .726 .902 r
F
.7187 .58873 m .6922 .57732 L .68551 .58664 L F
.72385 .58485 m .6922 .57732 L .7187 .58873 L F
.48054 .60012 m .5052 .59617 L .50477 .60344 L .732 .488 .559 r
F
.48054 .60012 m .48097 .59285 L .5052 .59617 L F
.48988 .57385 m .5052 .59617 L .50604 .57607 L .654 .726 .902 r
F
.48988 .57385 m .48097 .59285 L .5052 .59617 L F
.59729 .605 m .58204 .58269 L .58114 .60279 L F
.59729 .605 m .60627 .58602 L .58204 .58269 L F
.77266 .59156 m .79068 .57417 L .76792 .58716 L F
.77266 .59156 m .80016 .58297 L .79068 .57417 L F
.6118 .61708 m .60586 .59329 L .59687 .61227 L F
.6118 .61708 m .62825 .6005 L .60586 .59329 L F
.60273 .71831 m .62883 .71392 L .60379 .71438 L .673 .758 .914 r
F
.46744 .83425 m .46695 .82969 L .45835 .82322 L .932 .647 .478 r
F
0 g
.46695 .82969 m
.47218 .83747 L
s
.44459 .83191 m .44681 .81866 L .43704 .82879 L .683 .77 .917 r
F
.44459 .83191 m .45815 .82335 L .44681 .81866 L F
.6922 .57732 m .65566 .57989 L .68551 .58664 L .654 .726 .902 r
F
.42382 .84711 m .4195 .83582 L .41899 .84699 L .683 .77 .917 r
F
.42382 .84711 m .42917 .83607 L .4195 .83582 L F
.39221 .83921 m .37007 .83944 L .38605 .84416 L F
.80588 .59294 m .82768 .57438 L .80016 .58297 L .654 .726 .902 r
F
.80588 .59294 m .83625 .58934 L .82768 .57438 L F
.25927 .70514 m .27055 .70867 L .27085 .71433 L .93 .657 .5 r
F
.25927 .70514 m .25897 .69948 L .27055 .70867 L F
0 g
.27055 .70867 m
.27606 .71117 L
s
.62825 .70826 m .65126 .69614 L .62697 .70049 L .673 .758 .914 r
F
.60334 .70872 m .62825 .70826 L .62697 .70049 L F
.2812 .69142 m .27083 .7085 L .28888 .69752 L .673 .757 .914 r
F
.2812 .69142 m .2593 .69936 L .27083 .7085 L F
.32678 .6933 m .32491 .70559 L .33673 .70444 L F
.32723 .69035 m .33673 .70444 L .33088 .68999 L F
.3244 .69063 m .32678 .6933 L .32723 .69035 L F
.32678 .6933 m .33673 .70444 L .32723 .69035 L F
.32942 .64855 m .32953 .64774 L .32943 .67598 L 0 0 .131 r
F
.3247 .69637 m .32407 .71152 L .33708 .71025 L .673 .757 .914 r
F
.3244 .69063 m .32491 .70559 L .32678 .6933 L F
.3247 .69637 m .33708 .71025 L .33121 .69573 L F
.32412 .65017 m .32569 .65043 L .32558 .67854 L .751 .492 .54 r
F
.325 .70204 m .32437 .71719 L .33738 .71592 L .673 .758 .914 r
F
.325 .70204 m .33738 .71592 L .33151 .7014 L F
.32829 .64979 m .32852 .67762 L .32818 .67787 L .356 .178 .497 r
F
.32727 .65023 m .32765 .67809 L .32716 .6783 L .517 .303 .528 r
F
.32569 .65043 m .32634 .67842 L .32558 .67854 L .641 .402 .541 r
F
.33139 .67767 m .34223 .68588 L .34632 .68269 L .673 .757 .914 r
F
.32727 .65023 m .32829 .64979 L .32818 .67787 L .517 .303 .528 r
F
.32692 .68021 m .3244 .69063 L .33088 .68999 L .673 .757 .914 r
F
.3265 .67916 m .32608 .68144 L .32692 .68021 L F
.32608 .68144 m .3244 .69063 L .32692 .68021 L F
.33088 .68999 m .34888 .70121 L .33696 .68838 L F
.32661 .68436 m .32701 .68536 L .32758 .68362 L F
.32701 .68536 m .33121 .69573 L .32777 .68425 L F
.32701 .68536 m .32777 .68425 L .32758 .68362 L F
.32796 .67869 m .33388 .68506 L .32864 .6777 L F
.33388 .68506 m .33696 .68838 L .33304 .68335 L F
.33388 .68506 m .33304 .68335 L .32864 .6777 L F
.32899 .64923 m .32942 .64855 L .32931 .67671 L .071 0 .412 r
F
.32953 .64774 m .32908 .6467 L .32897 .67505 L .986 .729 .347 r
F
.32761 .67831 m .33088 .68999 L .33696 .68838 L .673 .757 .914 r
F
.32569 .65043 m .32716 .6783 L .32634 .67842 L .641 .402 .541 r
F
.32503 .67553 m .3265 .67916 L .32761 .67831 L .673 .757 .914 r
F
.3265 .67916 m .33088 .68999 L .32761 .67831 L F
.32829 .64979 m .32899 .64923 L .32888 .67734 L .356 .178 .497 r
F
.32877 .67742 m .32888 .67734 L .32886 .68265 L F
.32829 .64979 m .32888 .67734 L .32877 .67742 L F
.32661 .68436 m .3247 .69637 L .33121 .69573 L .673 .757 .914 r
F
.32793 .68401 m .32884 .68498 L .32853 .68313 L F
.32884 .68498 m .33732 .69411 L .32903 .68375 L F
.32884 .68498 m .32903 .68375 L .32853 .68313 L F
.32584 .68911 m .325 .70204 L .32706 .70184 L .673 .758 .914 r
F
.32554 .68916 m .32705 .70894 L .32546 .70914 L .641 .402 .541 r
F
.32633 .68457 m .3247 .69637 L .32661 .68436 L .673 .757 .914 r
F
.32635 .68373 m .32519 .68443 L .32642 .68391 L F
.32618 .67939 m .3244 .69063 L .3265 .67916 L F
.32627 .67867 m .3244 .69063 L .3263 .67866 L F
.32618 .67861 m .3244 .69063 L .32628 .67862 L F
.3249 .67864 m .3244 .69063 L .32618 .67861 L F
.32558 .67854 m .32618 .67861 L .32621 .67844 L F
.3249 .67864 m .32618 .67861 L .32558 .67854 L F
.3244 .69063 m .32378 .7057 L .32491 .70559 L F
.31797 .69023 m .32378 .7057 L .32393 .70214 L F
.32304 .69054 m .32393 .70214 L .3244 .69063 L F
.31797 .69023 m .32393 .70214 L .32304 .69054 L F
.32204 .6476 m .32209 .64842 L .32198 .67684 L .794 .634 .076 r
F
.32247 .64911 m .32313 .6497 L .32302 .67796 L .927 .648 .492 r
F
.31823 .69597 m .32407 .71152 L .32412 .71026 L .673 .757 .914 r
F
.32305 .69627 m .32412 .71026 L .3247 .69637 L F
.31797 .69023 m .31092 .70491 L .32378 .7057 L F
.31823 .69597 m .32412 .71026 L .32305 .69627 L F
.32255 .68426 m .31797 .69023 L .32304 .69054 L F
.31202 .68883 m .31092 .70491 L .31797 .69023 L F
.31856 .68214 m .30695 .68653 L .31202 .68883 L F
.32421 .68042 m .31797 .69023 L .32479 .68135 L F
.31856 .68214 m .31451 .68942 L .31797 .69023 L F
.32276 .67785 m .32082 .6781 L .31856 .68214 L F
.32195 .67646 m .32198 .67684 L .32196 .68215 L .794 .634 .076 r
F
.32255 .68426 m .32304 .69054 L .3244 .69063 L .673 .757 .914 r
F
.32537 .69297 m .31853 .70164 L .325 .70204 L .673 .758 .914 r
F
.32508 .68716 m .31823 .69597 L .3247 .69637 L .673 .757 .914 r
F
.32517 .68494 m .32443 .68612 L .32508 .68716 L F
.32522 .68381 m .32397 .68402 L .32517 .68494 L F
.3249 .67871 m .32461 .67918 L .32487 .67938 L F
.32558 .67854 m .32576 .68227 L .32557 .68179 L .641 .402 .541 r
F
.32576 .68227 m .32583 .6838 L .32557 .68179 L F
.32557 .68179 m .32583 .6838 L .32556 .68385 L F
.32533 .6812 m .32522 .68381 L .32635 .68373 L .673 .757 .914 r
F
.32522 .68381 m .32522 .6839 L .32556 .68385 L F
.32522 .68381 m .32556 .68385 L .32635 .68373 L F
.32476 .67844 m .32558 .67854 L .32556 .68385 L .751 .492 .54 r
F
.32519 .68443 m .3247 .69637 L .32642 .68395 L .673 .757 .914 r
F
.32636 .68394 m .32642 .68395 L .32642 .68391 L F
.32519 .68443 m .32642 .68395 L .32636 .68394 L F
.32489 .68377 m .32554 .68916 L .32501 .68909 L .751 .492 .54 r
F
.32476 .67844 m .32515 .6838 L .32489 .68377 L F
.32515 .6838 m .32554 .68916 L .32489 .68377 L F
.32515 .6838 m .32556 .68385 L .32554 .68916 L F
.32476 .67844 m .32556 .68385 L .32515 .6838 L F
.32553 .68916 m .325 .70204 L .32584 .68919 L .673 .758 .914 r
F
.32501 .68909 m .32554 .68916 L .32546 .70914 L .751 .492 .54 r
F
.32554 .68916 m .32584 .68919 L .32584 .68911 L .673 .758 .914 r
F
.32553 .68916 m .32584 .68919 L .32554 .68916 L F
.32533 .6812 m .32414 .68368 L .32522 .68381 L .673 .757 .914 r
F
.32479 .68135 m .32255 .68426 L .3244 .69063 L F
.32414 .68368 m .32397 .68402 L .32522 .68381 L F
.32487 .67938 m .32421 .68042 L .32479 .68135 L F
.32476 .67844 m .32489 .68377 L .32401 .67835 L .751 .492 .54 r
F
.32397 .68402 m .31823 .69597 L .32517 .68494 L .673 .757 .914 r
F
.32489 .68377 m .32501 .68909 L .32451 .68372 L .751 .492 .54 r
F
.32489 .68377 m .32451 .68372 L .32401 .67835 L F
.32553 .68915 m .32386 .69054 L .32537 .69297 L .673 .758 .914 r
F
.32458 .68904 m .32386 .69054 L .32553 .68915 L F
.32501 .68909 m .32546 .70914 L .32452 .68904 L .751 .492 .54 r
F
.32501 .68909 m .32452 .68904 L .32401 .67835 L F
.32563 .68687 m .32458 .68904 L .32553 .68915 L .673 .758 .914 r
F
.32386 .69054 m .31853 .70164 L .32537 .69297 L F
.32443 .68612 m .31823 .69597 L .32508 .68716 L .673 .757 .914 r
F
.32204 .6832 m .30715 .69225 L .3221 .68398 L F
.32461 .67918 m .31797 .69023 L .32487 .67938 L F
.32194 .68184 m .32196 .68215 L .32194 .68746 L .794 .634 .076 r
F
.32364 .67843 m .31856 .68214 L .31797 .69023 L .673 .757 .914 r
F
.32268 .6777 m .32302 .67796 L .323 .68327 L .927 .648 .492 r
F
.32397 .68402 m .32214 .68446 L .32236 .68737 L .673 .757 .914 r
F
.31823 .69597 m .31114 .71073 L .32407 .71152 L F
.31225 .69457 m .31114 .71073 L .31823 .69597 L F
.32386 .69054 m .31601 .69727 L .31853 .70164 L .673 .758 .914 r
F
.31601 .69727 m .31254 .70024 L .31415 .70061 L F
.31601 .69727 m .31415 .70061 L .31853 .70164 L F
.32219 .68786 m .32232 .68807 L .32224 .70782 L .989 .721 .393 r
F
.32219 .68786 m .32224 .70782 L .32202 .68759 L F
.31766 .68904 m .30715 .69225 L .31225 .69457 L .673 .757 .914 r
F
.32373 .67824 m .31797 .69023 L .3249 .67871 L F
.32291 .68367 m .31966 .68544 L .31766 .68904 L F
.31966 .68544 m .30715 .69225 L .31766 .68904 L F
.32218 .6825 m .32234 .68276 L .32232 .68807 L .989 .721 .393 r
F
.32243 .68047 m .32206 .68641 L .32241 .68579 L 0 0 .373 r
F
.32281 .6778 m .31856 .68214 L .32364 .67843 L .673 .757 .914 r
F
.32217 .67713 m .32236 .67745 L .32234 .68276 L .989 .721 .393 r
F
.32217 .67713 m .32234 .68276 L .32218 .6825 L F
.32209 .64842 m .32247 .64911 L .32236 .67745 L F
.32082 .6781 m .30311 .68348 L .30695 .68653 L .673 .757 .914 r
F
.32247 .64911 m .32268 .6777 L .32236 .67745 L .927 .648 .492 r
F
.32503 .67553 m .32154 .6768 L .32082 .6781 L .673 .757 .914 r
F
.32154 .6768 m .30311 .68348 L .32082 .6781 L F
.32245 .67516 m .32213 .68102 L .32243 .68047 L 0 0 .373 r
F
.32256 .64658 m .32219 .67562 L .32245 .67516 L F
.32313 .6497 m .3235 .67815 L .32302 .67796 L .844 .572 .526 r
F
.32503 .67553 m .32182 .67748 L .32276 .67785 L .673 .757 .914 r
F
.32209 .64842 m .32236 .67745 L .32217 .67713 L .989 .721 .393 r
F
.32219 .67562 m .32213 .68102 L .32245 .67516 L 0 0 .373 r
F
.32218 .6825 m .32219 .68786 L .32196 .68215 L .989 .721 .393 r
F
.32236 .67745 m .32246 .68285 L .32234 .68276 L .927 .648 .492 r
F
.31856 .68214 m .31202 .68883 L .31451 .68942 L .673 .757 .914 r
F
.32235 .68301 m .3033 .68919 L .30715 .69225 L F
.32302 .67796 m .32318 .68334 L .323 .68327 L .844 .572 .526 r
F
.32533 .6812 m .32139 .68263 L .32235 .68301 L .673 .757 .914 r
F
.32139 .68263 m .3033 .68919 L .32235 .68301 L F
.3235 .67815 m .32401 .67835 L .32399 .68366 L .844 .572 .526 r
F
.32412 .68371 m .32376 .68385 L .32397 .68402 L .673 .757 .914 r
F
.32431 .6896 m .32365 .6902 L .32386 .69054 L .673 .758 .914 r
F
.32368 .68886 m .32269 .68866 L .32315 .6894 L F
.31202 .68883 m .29901 .70212 L .31092 .70491 L .673 .757 .914 r
F
.30695 .68653 m .29901 .70212 L .31202 .68883 L F
.30695 .68653 m .28888 .69752 L .29901 .70212 L F
.32083 .68861 m .30123 .69124 L .30359 .69486 L .673 .758 .914 r
F
.32399 .68366 m .3243 .68901 L .32397 .68897 L .751 .492 .54 r
F
.32214 .68446 m .31225 .69457 L .32236 .68737 L .673 .757 .914 r
F
.3235 .67815 m .32399 .68366 L .32357 .68349 L .844 .572 .526 r
F
.32357 .68349 m .32318 .68334 L .32302 .67796 L F
.32533 .6812 m .31986 .68218 L .31986 .68318 L .673 .757 .914 r
F
.31986 .68218 m .31648 .68279 L .31858 .68303 L F
.31986 .68218 m .31858 .68303 L .31986 .68318 L F
.32247 .64911 m .32302 .67796 L .32268 .6777 L .927 .648 .492 r
F
.31815 .67803 m .30076 .67988 L .30311 .68348 L .673 .757 .914 r
F
.32503 .67553 m .32074 .6763 L .31815 .67803 L F
.32074 .6763 m .30076 .67988 L .31815 .67803 L F
.32367 .6458 m .32256 .64658 L .32245 .67516 L .4 .212 .507 r
F
.32262 .67505 m .32245 .67516 L .32243 .68047 L F
.32367 .6458 m .32245 .67516 L .32262 .67505 L F
.32272 .68305 m .32246 .68285 L .32236 .67745 L .927 .648 .492 r
F
.32204 .6832 m .3221 .68398 L .32316 .68339 L .673 .757 .914 r
F
.32258 .68037 m .32243 .68047 L .32241 .68579 L .4 .212 .507 r
F
.32268 .6777 m .32272 .68305 L .32236 .67745 L .927 .648 .492 r
F
.32074 .6763 m .30007 .67599 L .30076 .67988 L .673 .757 .914 r
F
.32503 .67553 m .32181 .67559 L .32074 .6763 L F
.32181 .67559 m .30007 .67599 L .32074 .6763 L F
.32275 .67496 m .32243 .68047 L .32258 .68037 L .4 .212 .507 r
F
.32367 .6458 m .32262 .67505 L .32275 .67496 L F
.32262 .67505 m .32243 .68047 L .32275 .67496 L F
.32276 .68841 m .32255 .68825 L .32246 .68285 L .927 .648 .492 r
F
.32315 .6894 m .32213 .68995 L .32217 .69041 L .673 .758 .914 r
F
.32354 .68901 m .31675 .69594 L .32431 .6896 L F
.31675 .69594 m .31254 .70024 L .3162 .69694 L F
.32236 .68737 m .31611 .69182 L .31823 .69597 L .673 .757 .914 r
F
.31675 .69594 m .3162 .69694 L .32431 .6896 L .673 .758 .914 r
F
.32194 .68184 m .32194 .68746 L .32192 .68721 L .794 .634 .076 r
F
.32219 .68786 m .32202 .68759 L .32196 .68215 L .989 .721 .393 r
F
.32213 .68102 m .3219 .68142 L .32188 .68673 L 0 0 .373 r
F
.32192 .68721 m .32194 .68746 L .32186 .70713 L .794 .634 .076 r
F
.32194 .68184 m .32192 .68721 L .32191 .68154 L F
.32192 .68721 m .32186 .70713 L .3219 .68698 L F
.32192 .68721 m .3219 .68698 L .32191 .68154 L F
.32206 .68904 m .30359 .69486 L .30745 .69792 L .673 .758 .914 r
F
.32291 .68852 m .32204 .68881 L .32206 .68904 L F
.32204 .68881 m .30359 .69486 L .32206 .68904 L F
.32188 .68673 m .32186 .70713 L .32181 .70632 L .794 .634 .076 r
F
.3219 .68142 m .3219 .68688 L .32188 .68673 L F
.3219 .68688 m .32186 .70713 L .32188 .68673 L F
.32232 .68807 m .322 .68819 L .32291 .68852 L .673 .758 .914 r
F
.322 .68819 m .30359 .69486 L .32204 .68881 L F
.322 .68819 m .32204 .68881 L .32291 .68852 L F
.32365 .6902 m .31254 .70024 L .32386 .69054 L F
.32191 .68154 m .3219 .68698 L .3219 .68142 L .794 .634 .076 r
F
.3219 .68698 m .32186 .70713 L .3219 .68688 L F
.3219 .68698 m .3219 .68688 L .3219 .68142 L F
.32269 .68866 m .32206 .68904 L .32315 .6894 L .673 .758 .914 r
F
.31611 .69182 m .31225 .69457 L .31431 .69505 L .673 .757 .914 r
F
.32206 .68904 m .30745 .69792 L .32213 .68995 L .673 .758 .914 r
F
.32206 .68904 m .32213 .68995 L .32315 .6894 L F
.31853 .70164 m .32437 .71719 L .325 .70204 L F
.32232 .68807 m .32291 .70841 L .32224 .70782 L .927 .648 .492 r
F
.32234 .68276 m .32246 .68818 L .32232 .68807 L F
.32246 .68818 m .32291 .70841 L .32232 .68807 L F
.32168 .68758 m .30054 .68733 L .30123 .69124 L .673 .758 .914 r
F
.32357 .68349 m .32397 .68897 L .32364 .68884 L .844 .572 .526 r
F
.32235 .68301 m .32204 .6832 L .32316 .68339 L .673 .757 .914 r
F
.32272 .68305 m .32276 .68841 L .32246 .68285 L .927 .648 .492 r
F
.32563 .68687 m .32088 .68696 L .32168 .68758 L .673 .758 .914 r
F
.32088 .68696 m .30054 .68733 L .32168 .68758 L F
.32206 .68641 m .32188 .68673 L .32181 .70632 L 0 0 .373 r
F
.32196 .68215 m .32202 .68759 L .32194 .68746 L .989 .721 .393 r
F
.32213 .68102 m .32188 .68673 L .32206 .68641 L 0 0 .373 r
F
.32246 .68285 m .32255 .68825 L .32234 .68276 L .927 .648 .492 r
F
.32255 .68825 m .32291 .70841 L .32246 .68818 L F
.32255 .68825 m .32246 .68818 L .32234 .68276 L F
.32082 .6781 m .30695 .68653 L .31856 .68214 L .673 .757 .914 r
F
.31986 .68318 m .30094 .68557 L .3033 .68919 L F
.32284 .68356 m .30715 .69225 L .32291 .68367 L F
.32088 .68696 m .30155 .68339 L .30054 .68733 L .673 .758 .914 r
F
.32272 .68305 m .32298 .68858 L .32276 .68841 L .927 .648 .492 r
F
.32288 .68854 m .32269 .68866 L .32368 .68886 L .673 .758 .914 r
F
.32298 .68858 m .32389 .70888 L .32291 .70841 L .844 .572 .526 r
F
.323 .68327 m .32319 .68866 L .32298 .68858 L F
.32319 .68866 m .32389 .70888 L .32298 .68858 L F
.32426 .68369 m .32546 .70914 L .32399 .68366 L .751 .492 .54 r
F
.32376 .68385 m .32214 .68446 L .32397 .68402 L .673 .757 .914 r
F
.32357 .68349 m .32389 .70888 L .32318 .68334 L .844 .572 .526 r
F
.32322 .68336 m .32214 .68446 L .32412 .68371 L .673 .757 .914 r
F
.323 .68327 m .32316 .68339 L .32322 .68336 L F
.32318 .68334 m .32389 .70888 L .323 .68327 L .844 .572 .526 r
F
.32313 .6497 m .32412 .65017 L .32401 .67835 L F
.30984 .68398 m .30024 .68166 L .30094 .68557 L .673 .757 .914 r
F
.32235 .68301 m .32316 .68339 L .323 .68327 L F
.32322 .68336 m .32284 .68356 L .32291 .68367 L F
.32272 .68305 m .323 .68327 L .32298 .68858 L .927 .648 .492 r
F
.32354 .67973 m .32278 .68554 L .32352 .68504 L .4 .212 .507 r
F
.32313 .6497 m .32401 .67835 L .3235 .67815 L .844 .572 .526 r
F
.32181 .67559 m .30108 .67207 L .30007 .67599 L .673 .757 .914 r
F
.32503 .67553 m .32246 .67516 L .32181 .67559 L F
.32198 .67684 m .32218 .6825 L .32196 .68215 L .989 .721 .393 r
F
.32209 .64842 m .32217 .67713 L .32198 .67684 L F
.32217 .67713 m .32218 .6825 L .32198 .67684 L F
.32246 .67516 m .32079 .67492 L .32181 .67559 L .673 .757 .914 r
F
.32079 .67492 m .30108 .67207 L .32114 .67548 L F
.32079 .67492 m .32114 .67548 L .32181 .67559 L F
.3235 .67815 m .32357 .68349 L .32302 .67796 L .844 .572 .526 r
F
.32503 .67553 m .32281 .6778 L .32364 .67843 L .673 .757 .914 r
F
.32356 .67442 m .3229 .68016 L .32354 .67973 L .4 .212 .507 r
F
.32367 .6458 m .32302 .67478 L .32356 .67442 L F
.32302 .67478 m .3229 .68016 L .32356 .67442 L F
.3229 .68016 m .32278 .68554 L .32354 .67973 L F
.31986 .68218 m .31839 .68133 L .30984 .68398 L .673 .757 .914 r
F
.32268 .6777 m .323 .68327 L .32272 .68305 L .927 .648 .492 r
F
.32533 .6812 m .32122 .68128 L .31986 .68218 L .673 .757 .914 r
F
.32122 .68128 m .31839 .68133 L .31986 .68218 L F
.31839 .68133 m .30024 .68166 L .30984 .68398 L F
.32159 .67503 m .30372 .66838 L .30108 .67207 L F
.32503 .67553 m .32261 .67472 L .32159 .67503 L F
.32204 .6476 m .32195 .67646 L .32192 .67611 L .794 .634 .076 r
F
.32204 .6476 m .32198 .67684 L .32195 .67646 L F
.32256 .64658 m .32204 .6476 L .32192 .67611 L 0 0 .373 r
F
.32256 .64658 m .32192 .67611 L .32201 .67596 L F
.32261 .67472 m .30372 .66838 L .32159 .67503 L .673 .757 .914 r
F
.32477 .64546 m .32367 .6458 L .32356 .67442 L .568 .344 .535 r
F
.32374 .67437 m .32356 .67442 L .32354 .67973 L F
.32477 .64546 m .32356 .67442 L .32374 .67437 L F
.32369 .67969 m .32354 .67973 L .32352 .68504 L F
.32261 .67472 m .30782 .66517 L .30372 .66838 L .673 .757 .914 r
F
.32503 .67553 m .32331 .6745 L .32261 .67472 L F
.32302 .67478 m .32241 .68579 L .32278 .68554 L .4 .212 .507 r
F
.32367 .6458 m .32275 .67496 L .32302 .67478 L F
.32323 .67994 m .31332 .66828 L .30803 .67079 L .673 .757 .914 r
F
.31648 .68279 m .30094 .68557 L .31986 .68318 L F
.32017 .68608 m .30341 .6808 L .31472 .68529 L .673 .758 .914 r
F
.32218 .6825 m .32232 .68807 L .32219 .68786 L .989 .721 .393 r
F
.32563 .68687 m .32137 .68571 L .32017 .68608 L .673 .758 .914 r
F
.32137 .68571 m .30341 .6808 L .32017 .68608 L F
.32397 .68897 m .32546 .70914 L .32389 .70888 L .751 .492 .54 r
F
.3243 .68901 m .32546 .70914 L .32397 .68897 L F
.32563 .68687 m .32354 .68901 L .32431 .6896 L .673 .758 .914 r
F
.32462 .6847 m .32345 .70451 L .32455 .70418 L .568 .344 .535 r
F
.32464 .67939 m .32439 .68478 L .32462 .6847 L F
.31839 .68133 m .30126 .67772 L .30024 .68166 L .673 .757 .914 r
F
.32533 .6812 m .32088 .68056 L .31839 .68133 L F
.32088 .68056 m .30126 .67772 L .31839 .68133 L F
.32533 .6812 m .32322 .68336 L .32412 .68371 L F
.32401 .67959 m .32352 .68504 L .32389 .68493 L .568 .344 .535 r
F
.32412 .65017 m .32476 .67844 L .32401 .67835 L .751 .492 .54 r
F
.32503 .67553 m .3239 .67432 L .32338 .67454 L .673 .757 .914 r
F
.32477 .64546 m .32374 .67437 L .32386 .67433 L .568 .344 .535 r
F
.3239 .67432 m .32383 .67424 L .32356 .67442 L .673 .757 .914 r
F
.3239 .67432 m .32356 .67442 L .32338 .67454 L F
.32503 .67553 m .32373 .67824 L .3249 .67871 L F
.32413 .67425 m .32369 .67969 L .32401 .67959 L .568 .344 .535 r
F
.32477 .64546 m .32386 .67433 L .32413 .67425 L F
.32386 .67433 m .32369 .67969 L .32413 .67425 L F
.32533 .6812 m .32235 .68301 L .32322 .68336 L .673 .757 .914 r
F
.32369 .67969 m .32352 .68504 L .32401 .67959 L .568 .344 .535 r
F
.32178 .68558 m .30832 .67646 L .30421 .67968 L .673 .758 .914 r
F
.32563 .68687 m .32291 .68523 L .32178 .68558 L F
.32195 .67646 m .32196 .68215 L .32194 .68184 L .794 .634 .076 r
F
.31783 .68012 m .30391 .67401 L .30126 .67772 L .673 .757 .914 r
F
.32533 .6812 m .32107 .67977 L .31783 .68012 L F
.32107 .67977 m .30391 .67401 L .31783 .68012 L F
.32412 .65017 m .32558 .67854 L .32476 .67844 L .751 .492 .54 r
F
.32586 .64538 m .32477 .64546 L .32464 .67939 L .66 .417 .541 r
F
.32563 .68687 m .32288 .68854 L .32368 .68886 L .673 .758 .914 r
F
.32219 .67562 m .3219 .68142 L .32213 .68102 L 0 0 .373 r
F
.32194 .68184 m .32191 .68154 L .32192 .67611 L .794 .634 .076 r
F
.32192 .67611 m .32191 .68154 L .3219 .68142 L F
.32107 .67977 m .30803 .67079 L .30391 .67401 L .673 .757 .914 r
F
.32533 .6812 m .32267 .6796 L .32107 .67977 L F
.32267 .6796 m .30803 .67079 L .32107 .67977 L F
.32522 .6839 m .32519 .68443 L .32635 .68373 L F
.32556 .68385 m .32609 .68907 L .32554 .68916 L .641 .402 .541 r
F
.32563 .68687 m .32553 .68916 L .32584 .68911 L .673 .758 .914 r
F
.32573 .67928 m .32455 .70418 L .32564 .70409 L .66 .417 .541 r
F
.32503 .67553 m .3249 .67864 L .32621 .67844 L .673 .757 .914 r
F
.33026 .67629 m .34632 .68269 L .34897 .679 L F
.32503 .67553 m .32935 .67698 L .33026 .67629 L F
.32935 .67698 m .34632 .68269 L .33026 .67629 L F
.32852 .67762 m .32886 .68265 L .32856 .68288 L .356 .178 .497 r
F
.32829 .64979 m .32877 .67742 L .32852 .67762 L F
.32877 .67742 m .32886 .68265 L .32852 .67762 L F
.32899 .64923 m .32931 .67671 L .32925 .67681 L .071 0 .412 r
F
.33018 .67544 m .34897 .679 L .34999 .67508 L .673 .757 .914 r
F
.32833 .69354 m .32706 .70184 L .33151 .7014 L .673 .758 .914 r
F
.32894 .68254 m .32899 .68774 L .32886 .68265 L .071 0 .412 r
F
.32672 .68957 m .33151 .7014 L .32755 .68894 L .673 .758 .914 r
F
.32856 .68288 m .32886 .68265 L .32885 .68796 L .356 .178 .497 r
F
.32861 .68814 m .32885 .68796 L .32877 .70794 L F
.32855 .68687 m .33121 .69573 L .32884 .68498 L .673 .757 .914 r
F
.32856 .68288 m .32885 .68796 L .32861 .68814 L .356 .178 .497 r
F
.32888 .67734 m .32894 .68254 L .32886 .68265 L .071 0 .412 r
F
.32814 .68849 m .32877 .70794 L .32807 .7085 L .356 .178 .497 r
F
.32816 .68318 m .32829 .68838 L .32814 .68849 L F
.32829 .68838 m .32877 .70794 L .32814 .68849 L F
.33048 .68028 m .35041 .68074 L .34972 .67683 L .673 .757 .914 r
F
.32911 .68229 m .32901 .68244 L .32888 .67734 L .071 0 .412 r
F
.32846 .67471 m .32834 .67996 L .32897 .67505 L .908 .63 .503 r
F
.32852 .67762 m .32856 .68288 L .32818 .67787 L .356 .178 .497 r
F
.33121 .69573 m .33708 .71025 L .3493 .707 L .673 .757 .914 r
F
.32882 .69031 m .33151 .7014 L .33762 .69978 L .673 .758 .914 r
F
.32791 .68933 m .32861 .69168 L .32882 .69031 L F
.32861 .69168 m .33151 .7014 L .32882 .69031 L F
.32966 .67963 m .34972 .67683 L .34737 .67321 L .673 .757 .914 r
F
.32936 .6816 m .32933 .68178 L .32931 .67671 L 0 0 .131 r
F
.32909 .67704 m .32929 .68202 L .32911 .68229 L .071 0 .412 r
F
.32931 .67671 m .32931 .68189 L .32929 .68202 L 0 0 .131 r
F
.32765 .67809 m .32818 .67787 L .32816 .68318 L .517 .303 .528 r
F
.32937 .67636 m .32941 .68129 L .32936 .6816 L 0 0 .131 r
F
.32942 .64855 m .32943 .67598 L .32937 .67636 L F
.32942 .64855 m .32937 .67636 L .32931 .67671 L F
.32953 .64774 m .32921 .67553 L .32943 .67598 L .986 .729 .347 r
F
.3287 .67487 m .34999 .67508 L .3493 .67118 L .673 .757 .914 r
F
.32727 .65023 m .32818 .67787 L .32765 .67809 L .517 .303 .528 r
F
.32503 .67553 m .32957 .67545 L .3287 .67487 L .673 .757 .914 r
F
.32957 .67545 m .34999 .67508 L .3287 .67487 L F
.32908 .6467 m .32802 .64588 L .32791 .67435 L .908 .63 .503 r
F
.32808 .67446 m .32791 .67435 L .32789 .67966 L F
.32908 .6467 m .32791 .67435 L .32808 .67446 L F
.32533 .6812 m .32997 .68104 L .32918 .68051 L .673 .757 .914 r
F
.32755 .68894 m .32791 .68933 L .32821 .68846 L .673 .758 .914 r
F
.32814 .68849 m .32821 .68846 L .32822 .68843 L F
.32755 .68894 m .32821 .68846 L .32814 .68849 L F
.32758 .68362 m .32855 .68687 L .32884 .68498 L .673 .757 .914 r
F
.32772 .68337 m .32816 .68318 L .32814 .68849 L .517 .303 .528 r
F
.32655 .68916 m .32706 .70184 L .32833 .69354 L .673 .758 .914 r
F
.32712 .68892 m .32807 .7085 L .32705 .70894 L .517 .303 .528 r
F
.32843 .68307 m .32793 .68401 L .32853 .68313 L .673 .757 .914 r
F
.32634 .67842 m .32716 .6783 L .32712 .68892 L .641 .402 .541 r
F
.32533 .6812 m .32745 .68348 L .32843 .68307 L .673 .757 .914 r
F
.32745 .68348 m .32793 .68401 L .32843 .68307 L F
.32714 .68361 m .32748 .68877 L .32712 .68892 L .517 .303 .528 r
F
.32716 .6783 m .32732 .68353 L .32714 .68361 L F
.32732 .68353 m .32748 .68877 L .32714 .68361 L F
.32748 .68877 m .32807 .7085 L .32712 .68892 L F
.32649 .68901 m .3265 .68918 L .32655 .68916 L .673 .758 .914 r
F
.3265 .68918 m .32706 .70184 L .32655 .68916 L F
.32584 .68911 m .32706 .70184 L .32649 .68901 L F
.32642 .68391 m .32633 .68457 L .32661 .68436 L .673 .757 .914 r
F
.3263 .67866 m .32618 .67939 L .3265 .67916 L F
.32628 .67862 m .32627 .67867 L .3263 .67866 L F
.32621 .67844 m .32618 .67861 L .32628 .67862 L F
.32634 .67842 m .32658 .689 L .32558 .67854 L .641 .402 .541 r
F
.32658 .689 m .32705 .70894 L .32609 .68907 L F
.32658 .689 m .32609 .68907 L .32558 .67854 L F
.33696 .68838 m .34888 .70121 L .35941 .69623 L .673 .757 .914 r
F
.33732 .69411 m .35988 .702 L .34261 .6916 L F
.33031 .68844 m .34291 .69727 L .34703 .69406 L .673 .758 .914 r
F
.32563 .68687 m .32865 .68869 L .33031 .68844 L F
.33088 .68999 m .33673 .70444 L .34888 .70121 L .673 .757 .914 r
F
.32884 .68498 m .33121 .69573 L .33732 .69411 L F
.32865 .68869 m .34291 .69727 L .33031 .68844 L .673 .758 .914 r
F
.32563 .68687 m .32584 .68911 L .32649 .68901 L F
.32658 .689 m .32712 .68892 L .32705 .70894 L .641 .402 .541 r
F
.32751 .68355 m .32661 .68436 L .32758 .68362 L .673 .757 .914 r
F
.32533 .6812 m .32635 .68373 L .32751 .68355 L F
.32635 .68373 m .32661 .68436 L .32751 .68355 L F
.32646 .68371 m .32712 .68892 L .32658 .689 L .641 .402 .541 r
F
.32634 .67842 m .32673 .68367 L .32646 .68371 L F
.32673 .68367 m .32712 .68892 L .32646 .68371 L F
.3278 .68864 m .32814 .68849 L .32807 .7085 L .517 .303 .528 r
F
.32772 .68337 m .32814 .68849 L .3278 .68864 L F
.32818 .67787 m .32828 .68309 L .32816 .68318 L .356 .178 .497 r
F
.33096 .6791 m .33696 .68838 L .34223 .68588 L .673 .757 .914 r
F
.32967 .68183 m .34673 .68839 L .34939 .68468 L F
.32856 .68288 m .32828 .68309 L .32818 .67787 L .356 .178 .497 r
F
.32533 .6812 m .33016 .68282 L .32967 .68183 L .673 .757 .914 r
F
.33304 .68335 m .33696 .68838 L .33096 .6791 L F
.33016 .68282 m .34673 .68839 L .32967 .68183 L F
.32911 .68229 m .32913 .68754 L .32901 .68244 L .071 0 .412 r
F
.32913 .68754 m .32899 .68774 L .32888 .67734 L F
.32915 .68076 m .32893 .68567 L .32908 .68598 L .986 .729 .347 r
F
.32921 .67553 m .32907 .6806 L .32915 .68076 L F
.32907 .6806 m .32893 .68567 L .32915 .68076 L F
.33696 .68838 m .35941 .69623 L .34223 .68588 L .673 .757 .914 r
F
.3291 .68247 m .34261 .6916 L .34673 .68839 L F
.33216 .68782 m .34703 .69406 L .34969 .69035 L .673 .758 .914 r
F
.32856 .68288 m .32861 .68814 L .32828 .68309 L .356 .178 .497 r
F
.32861 .68814 m .32877 .70794 L .32839 .68831 L F
.32861 .68814 m .32839 .68831 L .32828 .68309 L F
.33312 .68886 m .33732 .69411 L .33105 .68465 L .673 .757 .914 r
F
.32953 .68744 m .33595 .69034 L .33216 .68782 L .673 .758 .914 r
F
.32563 .68687 m .32885 .68795 L .32953 .68744 L F
.32885 .68795 m .33595 .69034 L .32953 .68744 L F
.33105 .68465 m .33732 .69411 L .34261 .6916 L .673 .757 .914 r
F
.33595 .69034 m .34703 .69406 L .33216 .68782 L .673 .758 .914 r
F
.33008 .68111 m .34939 .68468 L .35041 .68074 L .673 .757 .914 r
F
.32909 .67704 m .32911 .68229 L .32888 .67734 L .071 0 .412 r
F
.32899 .64923 m .32909 .67704 L .32888 .67734 L F
.32503 .67553 m .32861 .67769 L .32988 .67716 L .673 .757 .914 r
F
.32921 .67553 m .32897 .67505 L .32895 .68036 L .986 .729 .347 r
F
.32907 .6806 m .32895 .68036 L .32893 .68567 L F
.32921 .67553 m .32895 .68036 L .32907 .6806 L F
.32933 .68113 m .33158 .68211 L .33008 .68111 L .673 .757 .914 r
F
.32765 .67809 m .32816 .68318 L .32772 .68337 L .517 .303 .528 r
F
.32533 .6812 m .32967 .68183 L .32933 .68113 L .673 .757 .914 r
F
.32967 .68183 m .33158 .68211 L .32933 .68113 L F
.32914 .678 m .34223 .68588 L .33139 .67767 L F
.33158 .68211 m .34939 .68468 L .33008 .68111 L F
.32775 .68956 m .33151 .7014 L .32791 .68933 L .673 .758 .914 r
F
.32828 .68309 m .32839 .68831 L .32816 .68318 L .356 .178 .497 r
F
.32839 .68831 m .32877 .70794 L .32829 .68838 L F
.32839 .68831 m .32829 .68838 L .32816 .68318 L F
.33039 .68678 m .34969 .69035 L .35071 .68641 L .673 .758 .914 r
F
.32563 .68687 m .32953 .68744 L .33039 .68678 L F
.32953 .68744 m .34969 .69035 L .33039 .68678 L F
.32836 .68303 m .32907 .68346 L .3291 .68247 L .673 .757 .914 r
F
.32907 .68346 m .34261 .6916 L .32921 .68255 L F
.32907 .68346 m .32921 .68255 L .3291 .68247 L F
.32935 .68685 m .32931 .68708 L .32931 .68189 L 0 0 .131 r
F
.32933 .68178 m .32931 .68189 L .32931 .67671 L F
.32935 .68685 m .32931 .68189 L .32933 .68178 L F
.34223 .68588 m .3676 .68983 L .34632 .68269 L .673 .757 .914 r
F
.32965 .68615 m .35071 .68641 L .35002 .6825 L .673 .758 .914 r
F
.32563 .68687 m .3306 .68678 L .32965 .68615 L F
.3306 .68678 m .35071 .68641 L .32965 .68615 L F
.32893 .68567 m .3278 .70459 L .32886 .70541 L .908 .63 .503 r
F
.32885 .68796 m .3292 .70726 L .32877 .70794 L .071 0 .412 r
F
.32886 .68265 m .32894 .68783 L .32885 .68796 L F
.32894 .68783 m .3292 .70726 L .32885 .68796 L F
.32895 .68036 m .32871 .68552 L .32893 .68567 L .908 .63 .503 r
F
.32877 .68024 m .32856 .68543 L .32895 .68036 L F
.32856 .68543 m .3278 .70459 L .32871 .68552 L F
.32856 .68543 m .32871 .68552 L .32895 .68036 L F
.32936 .6816 m .32935 .68685 L .32933 .68178 L 0 0 .131 r
F
.32991 .68112 m .35041 .68074 L .33048 .68028 L .673 .757 .914 r
F
.32966 .6762 m .34897 .679 L .33018 .67544 L F
.32764 .68481 m .33241 .68275 L .33872 .67349 L .673 .758 .914 r
F
.32755 .68894 m .32775 .68956 L .32791 .68933 L F
.32893 .68567 m .35002 .6825 L .34767 .67888 L F
.32899 .68774 m .32894 .68783 L .32886 .68265 L .071 0 .412 r
F
.32563 .68687 m .32965 .68615 L .32893 .68567 L .673 .758 .914 r
F
.32853 .68313 m .33312 .68886 L .33105 .68465 L .673 .757 .914 r
F
.32965 .68615 m .35002 .6825 L .32893 .68567 L .673 .758 .914 r
F
.32765 .67809 m .3278 .68864 L .32716 .6783 L .517 .303 .528 r
F
.32742 .6888 m .32755 .68894 L .32814 .68849 L .673 .758 .914 r
F
.3278 .68864 m .32807 .7085 L .32748 .68877 L .517 .303 .528 r
F
.3278 .68864 m .32748 .68877 L .32716 .6783 L F
.32563 .68687 m .32742 .6888 L .32822 .68843 L .673 .758 .914 r
F
.32742 .6888 m .32814 .68849 L .32822 .68843 L F
.32533 .6812 m .32832 .68115 L .32832 .6811 L .673 .757 .914 r
F
.32832 .68115 m .32991 .68112 L .32832 .6811 L F
.32864 .6777 m .33304 .68335 L .33096 .6791 L F
.32937 .67636 m .32936 .6816 L .32931 .67671 L 0 0 .131 r
F
.32925 .67681 m .32931 .67671 L .32929 .68202 L .071 0 .412 r
F
.32988 .67716 m .32914 .678 L .33139 .67767 L .673 .757 .914 r
F
.32937 .67636 m .32943 .67598 L .32941 .68129 L 0 0 .131 r
F
.32943 .67598 m .32915 .68076 L .32941 .68129 L .986 .729 .347 r
F
.32832 .6811 m .32991 .68112 L .32997 .68104 L .673 .757 .914 r
F
.32834 .67996 m .32823 .6852 L .32877 .68024 L .908 .63 .503 r
F
.32791 .68933 m .32838 .68863 L .32822 .68843 L .673 .758 .914 r
F
.32823 .6852 m .3278 .70459 L .32856 .68543 L .908 .63 .503 r
F
.32823 .6852 m .32856 .68543 L .32877 .68024 L F
.32787 .68497 m .32672 .70422 L .3278 .70459 L .809 .541 .534 r
F
.32533 .6812 m .32918 .68051 L .32849 .68006 L .673 .757 .914 r
F
.32533 .6812 m .32836 .68303 L .3291 .68247 L F
.32802 .64588 m .32739 .6742 L .32791 .67435 L .809 .541 .534 r
F
.32503 .67553 m .32796 .67869 L .32864 .6777 L .673 .757 .914 r
F
.32846 .67471 m .32789 .67966 L .32834 .67996 L .908 .63 .503 r
F
.32908 .6467 m .32808 .67446 L .32846 .67471 L F
.32503 .67553 m .32966 .6762 L .32999 .67573 L .673 .757 .914 r
F
.32503 .67553 m .32999 .67573 L .32957 .67545 L F
.32808 .67446 m .32789 .67966 L .32846 .67471 L .908 .63 .503 r
F
.32908 .6467 m .32846 .67471 L .32897 .67505 L F
.32575 .67397 m .3251 .67934 L .32573 .67928 L .66 .417 .541 r
F
.32586 .64538 m .32522 .67402 L .32575 .67397 L F
.32503 .67553 m .32578 .67396 L .32509 .67404 L .673 .757 .914 r
F
.32522 .67402 m .3251 .67934 L .32575 .67397 L .66 .417 .541 r
F
.32509 .67404 m .32587 .67377 L .32511 .67356 L .673 .757 .914 r
F
.32578 .67396 m .32587 .67377 L .32509 .67404 L F
.32563 .68687 m .32787 .68497 L .32757 .68488 L .673 .758 .914 r
F
.32802 .64588 m .32695 .6455 L .32684 .67404 L .809 .541 .534 r
F
.32899 .64923 m .32925 .67681 L .32909 .67704 L .071 0 .412 r
F
.32953 .64774 m .32897 .67505 L .32921 .67553 L .986 .729 .347 r
F
.32569 .65043 m .32727 .65023 L .32716 .6783 L .641 .402 .541 r
F
.32741 .67409 m .34696 .66758 L .34313 .66453 L .673 .757 .914 r
F
.32503 .67553 m .32875 .67418 L .32741 .67409 L F
.32875 .67418 m .34696 .66758 L .32741 .67409 L F
.32609 .68907 m .32705 .70894 L .32554 .68916 L .641 .402 .541 r
F
.32563 .68687 m .32672 .68957 L .32755 .68894 L .673 .758 .914 r
F
.32875 .67418 m .3493 .67118 L .34696 .66758 L .673 .757 .914 r
F
.32503 .67553 m .33146 .67438 L .32875 .67418 L F
.33146 .67438 m .3493 .67118 L .32875 .67418 L F
.32695 .6455 m .32586 .64538 L .32575 .67397 L .734 .478 .541 r
F
.32503 .67553 m .32656 .67397 L .32587 .67377 L .673 .757 .914 r
F
.32583 .6838 m .32609 .68907 L .32556 .68385 L .641 .402 .541 r
F
.32503 .67553 m .34313 .66453 L .33806 .66222 L .673 .757 .914 r
F
.32834 .67996 m .32877 .68024 L .32897 .67505 L .908 .63 .503 r
F
.32861 .67769 m .32914 .678 L .32988 .67716 L .673 .757 .914 r
F
.32925 .67681 m .32929 .68202 L .32909 .67704 L .071 0 .412 r
F
.32921 .67553 m .32915 .68076 L .32943 .67598 L .986 .729 .347 r
F
.32711 .67938 m .34352 .67014 L .33842 .66782 L .673 .757 .914 r
F
.32739 .6742 m .32684 .67404 L .32682 .67935 L .809 .541 .534 r
F
.3282 .67945 m .34737 .67321 L .34352 .67014 L .673 .757 .914 r
F
.32789 .67966 m .32716 .68477 L .32787 .68497 L .809 .541 .534 r
F
.32791 .67435 m .32753 .67956 L .32789 .67966 L F
.32753 .67956 m .32716 .68477 L .32789 .67966 L F
.32787 .67965 m .32982 .67957 L .3282 .67945 L .673 .757 .914 r
F
.32533 .6812 m .32885 .67993 L .32787 .67965 L F
.32897 .67505 m .32877 .68024 L .32895 .68036 L .908 .63 .503 r
F
.32885 .67993 m .32982 .67957 L .32787 .67965 L .673 .757 .914 r
F
.32982 .67957 m .34737 .67321 L .3282 .67945 L F
.32899 .68482 m .34767 .67888 L .34382 .67581 L .673 .758 .914 r
F
.32929 .68202 m .3293 .68718 L .32927 .68733 L 0 0 .131 r
F
.32563 .68687 m .33089 .68496 L .32899 .68482 L .673 .758 .914 r
F
.33089 .68496 m .34767 .67888 L .32899 .68482 L F
.3268 .68467 m .32564 .70409 L .32672 .70422 L .734 .478 .541 r
F
.32682 .67935 m .32656 .68465 L .3268 .68467 L F
.32656 .68465 m .32564 .70409 L .3268 .68467 L F
.32684 .67404 m .32663 .67934 L .32682 .67935 L F
.32533 .6812 m .32787 .67965 L .32707 .67942 L .673 .757 .914 r
F
.32663 .67934 m .32564 .70409 L .32682 .67935 L .734 .478 .541 r
F
.3282 .67945 m .34352 .67014 L .32711 .67938 L .673 .757 .914 r
F
.32849 .68006 m .32953 .68045 L .32966 .67963 L F
.32918 .68051 m .32953 .68045 L .32849 .68006 L F
.32918 .68051 m .32997 .68104 L .33048 .68028 L F
.3267 .68464 m .33872 .67349 L .33273 .67209 L .673 .758 .914 r
F
.32563 .68687 m .32757 .68488 L .3267 .68464 L F
.32834 .67996 m .32787 .68497 L .32823 .6852 L .908 .63 .503 r
F
.32757 .68488 m .33872 .67349 L .3267 .68464 L .673 .758 .914 r
F
.32727 .67948 m .32682 .67935 L .3268 .68467 L .809 .541 .534 r
F
.32716 .68477 m .3268 .68467 L .32672 .70422 L F
.32727 .67948 m .3268 .68467 L .32716 .68477 L F
.32739 .6742 m .32682 .67935 L .32727 .67948 L F
.32739 .6742 m .32727 .67948 L .32791 .67435 L F
.32727 .67948 m .32716 .68477 L .32753 .67956 L F
.32727 .67948 m .32753 .67956 L .32791 .67435 L F
.32957 .67545 m .32999 .67573 L .33018 .67544 L .673 .757 .914 r
F
.32629 .6792 m .33842 .66782 L .33243 .66641 L F
.32631 .67401 m .32619 .67931 L .32684 .67404 L .734 .478 .541 r
F
.32533 .6812 m .32707 .67942 L .32682 .67935 L .673 .757 .914 r
F
.32619 .67931 m .32564 .70409 L .32663 .67934 L .734 .478 .541 r
F
.32619 .67931 m .32663 .67934 L .32684 .67404 L F
.32624 .67931 m .32682 .67935 L .32629 .6792 L .673 .757 .914 r
F
.32533 .6812 m .32682 .67935 L .32624 .67931 L F
.32707 .67942 m .33842 .66782 L .32629 .6792 L F
.32707 .67942 m .3282 .67945 L .32711 .67938 L F
.32787 .67965 m .3282 .67945 L .32707 .67942 L F
.32631 .67401 m .32575 .67397 L .32573 .67928 L .734 .478 .541 r
F
.32619 .67931 m .32573 .67928 L .32564 .70409 L F
.32631 .67401 m .32573 .67928 L .32619 .67931 L F
.32695 .6455 m .32575 .67397 L .32631 .67401 L F
.32695 .6455 m .32631 .67401 L .32684 .67404 L F
.32802 .64588 m .32684 .67404 L .32739 .6742 L .809 .541 .534 r
F
.32587 .67377 m .33806 .66222 L .3321 .66082 L .673 .757 .914 r
F
.32656 .67397 m .33806 .66222 L .32587 .67377 L F
.32515 .67251 m .3321 .66082 L .32566 .66042 L F
.32511 .67356 m .32554 .67277 L .32515 .67251 L F
.32554 .67277 m .3321 .66082 L .32515 .67251 L F
.32587 .67377 m .3321 .66082 L .32511 .67356 L F
.32563 .68687 m .32829 .68525 L .32787 .68497 L .673 .758 .914 r
F
.32716 .68477 m .32672 .70422 L .32787 .68497 L .809 .541 .534 r
F
.32757 .68488 m .32787 .68497 L .32764 .68481 L .673 .758 .914 r
F
.32829 .68525 m .33241 .68275 L .32764 .68481 L F
.32953 .68045 m .34972 .67683 L .32966 .67963 L .673 .757 .914 r
F
.33241 .68275 m .34382 .67581 L .33873 .6735 L .673 .758 .914 r
F
.33241 .68275 m .33873 .6735 L .33872 .67349 L F
.32871 .68552 m .3278 .70459 L .32893 .68567 L .908 .63 .503 r
F
.32834 .67996 m .32789 .67966 L .32787 .68497 L F
.32823 .6852 m .32787 .68497 L .3278 .70459 L F
.32935 .68685 m .32931 .70645 L .32931 .68708 L 0 0 .131 r
F
.32913 .68754 m .3292 .70726 L .32899 .68774 L .071 0 .412 r
F
.32931 .68189 m .32931 .68708 L .32929 .68202 L 0 0 .131 r
F
.32931 .68708 m .32931 .70645 L .3293 .68718 L F
.32931 .68708 m .3293 .68718 L .32929 .68202 L F
.32791 .68933 m .32882 .69031 L .32838 .68863 L .673 .758 .914 r
F
.32882 .69031 m .33762 .69978 L .32897 .68933 L F
.32882 .69031 m .32897 .68933 L .32838 .68863 L F
.32908 .68598 m .32893 .68567 L .32886 .70541 L .986 .729 .347 r
F
.33121 .69573 m .3493 .707 L .33732 .69411 L .673 .757 .914 r
F
.33115 .69019 m .33762 .69978 L .34291 .69727 L .673 .758 .914 r
F
.32936 .6816 m .32941 .68129 L .32939 .6866 L 0 0 .131 r
F
.32935 .68685 m .32939 .6866 L .32931 .70645 L F
.32936 .6816 m .32939 .6866 L .32935 .68685 L F
.32903 .68892 m .33328 .69454 L .33115 .69019 L .673 .758 .914 r
F
.32822 .68843 m .32897 .68933 L .32903 .68892 L F
.32897 .68933 m .33328 .69454 L .32903 .68892 L F
.33328 .69454 m .33762 .69978 L .33115 .69019 L F
.3251 .67934 m .32455 .70418 L .32573 .67928 L .66 .417 .541 r
F
.32241 .68494 m .31362 .67395 L .30832 .67646 L .673 .758 .914 r
F
.32357 .68349 m .32399 .68366 L .32397 .68897 L .844 .572 .526 r
F
.32563 .68687 m .3237 .6848 L .32241 .68494 L .673 .758 .914 r
F
.3237 .6848 m .31362 .67395 L .32241 .68494 L F
.3251 .67934 m .32464 .67939 L .32462 .6847 L .66 .417 .541 r
F
.32498 .68466 m .32462 .6847 L .32455 .70418 L F
.3251 .67934 m .32462 .6847 L .32498 .68466 L F
.32466 .67408 m .32401 .67959 L .32464 .67939 L .568 .344 .535 r
F
.32477 .64546 m .32413 .67425 L .32466 .67408 L F
.32503 .67553 m .32447 .67414 L .3239 .67432 L .673 .757 .914 r
F
.32413 .67425 m .32401 .67959 L .32466 .67408 L .568 .344 .535 r
F
.32256 .64658 m .32201 .67596 L .32219 .67562 L 0 0 .373 r
F
.3239 .67432 m .31917 .66105 L .31309 .66268 L .673 .757 .914 r
F
.32447 .67414 m .31917 .66105 L .3239 .67432 L F
.32445 .6741 m .32566 .66042 L .31917 .66105 L F
.32503 .67553 m .32509 .67404 L .32445 .6741 L F
.32586 .64538 m .32483 .67406 L .32522 .67402 L .66 .417 .541 r
F
.32509 .67404 m .32566 .66042 L .32445 .6741 L .673 .757 .914 r
F
.32522 .67402 m .32464 .67939 L .3251 .67934 L .66 .417 .541 r
F
.32483 .67406 m .32464 .67939 L .32522 .67402 L F
.32291 .68523 m .30832 .67646 L .32178 .68558 L .673 .758 .914 r
F
.32533 .6812 m .32387 .67963 L .32323 .67994 L .673 .757 .914 r
F
.32401 .67835 m .32426 .68369 L .32399 .68366 L .751 .492 .54 r
F
.32401 .67959 m .32389 .68493 L .32464 .67939 L .568 .344 .535 r
F
.32364 .68884 m .32397 .68897 L .32389 .70888 L .844 .572 .526 r
F
.32389 .68493 m .32345 .70451 L .32439 .68478 L .568 .344 .535 r
F
.32389 .68493 m .32439 .68478 L .32464 .67939 L F
.32439 .68478 m .32345 .70451 L .32462 .6847 L F
.32387 .67963 m .3238 .67956 L .32354 .67973 L .673 .757 .914 r
F
.32387 .67963 m .32354 .67973 L .32323 .67994 L F
.32258 .68037 m .32271 .68028 L .32302 .67478 L .4 .212 .507 r
F
.32182 .67748 m .32082 .6781 L .32276 .67785 L .673 .757 .914 r
F
.32201 .67596 m .3219 .68142 L .32219 .67562 L 0 0 .373 r
F
.32195 .67646 m .32194 .67931 L .32192 .67611 L .794 .634 .076 r
F
.32194 .67931 m .32194 .68184 L .32192 .67611 L F
.32201 .67596 m .32192 .67611 L .3219 .68142 L 0 0 .373 r
F
.3238 .67956 m .31332 .66828 L .32323 .67994 L .673 .757 .914 r
F
.32275 .67496 m .32258 .68037 L .32302 .67478 L .4 .212 .507 r
F
.32258 .68037 m .32241 .68579 L .32271 .68028 L F
.32338 .67454 m .31309 .66268 L .30782 .66517 L .673 .757 .914 r
F
.32383 .67424 m .31309 .66268 L .32338 .67454 L F
.32331 .6745 m .30782 .66517 L .32261 .67472 L F
.32386 .67433 m .32354 .67973 L .32369 .67969 L .568 .344 .535 r
F
.32374 .67437 m .32354 .67973 L .32386 .67433 L F
.32563 .68687 m .32232 .68807 L .32291 .68852 L .673 .758 .914 r
F
.32389 .68493 m .32352 .68504 L .32345 .70451 L .568 .344 .535 r
F
.32137 .68571 m .30421 .67968 L .30341 .6808 L .673 .758 .914 r
F
.32563 .68687 m .32178 .68558 L .32137 .68571 L F
.32178 .68558 m .30421 .67968 L .32137 .68571 L F
.31472 .68529 m .30341 .6808 L .30155 .68339 L F
.32352 .68504 m .32233 .70529 L .32345 .70451 L .4 .212 .507 r
F
.32276 .68841 m .32298 .68858 L .32291 .70841 L .927 .648 .492 r
F
.32276 .68841 m .32291 .70841 L .32255 .68825 L F
.32278 .68554 m .32233 .70529 L .32352 .68504 L .4 .212 .507 r
F
.32563 .68687 m .32164 .68629 L .32088 .68696 L .673 .758 .914 r
F
.32164 .68629 m .31964 .68601 L .32077 .68687 L F
.32164 .68629 m .32077 .68687 L .32088 .68696 L F
.31964 .68601 m .30155 .68339 L .32088 .68696 L F
.32278 .68554 m .32241 .68579 L .32233 .70529 L .4 .212 .507 r
F
.32563 .68687 m .31899 .68806 L .32083 .68861 L .673 .758 .914 r
F
.31899 .68806 m .31786 .68826 L .31856 .68834 L F
.31899 .68806 m .31856 .68834 L .32083 .68861 L F
.31786 .68826 m .30123 .69124 L .32083 .68861 L F
.32213 .68102 m .32206 .68641 L .32243 .68047 L 0 0 .373 r
F
.32194 .68746 m .32224 .70782 L .32186 .70713 L .989 .721 .393 r
F
.32241 .68579 m .32181 .70632 L .32233 .70529 L 0 0 .373 r
F
.32202 .68759 m .32224 .70782 L .32194 .68746 L .989 .721 .393 r
F
.32206 .68641 m .32181 .70632 L .32241 .68579 L 0 0 .373 r
F
.31611 .69182 m .31431 .69505 L .31823 .69597 L .673 .757 .914 r
F
.32217 .69041 m .30745 .69792 L .31254 .70024 L .673 .758 .914 r
F
.32213 .68995 m .30745 .69792 L .32217 .69041 L F
.32927 .68733 m .32931 .70645 L .3292 .70726 L 0 0 .131 r
F
.3293 .68718 m .32931 .70645 L .32927 .68733 L F
.32899 .68774 m .3292 .70726 L .32894 .68783 L .071 0 .412 r
F
.32911 .68229 m .32929 .68202 L .3292 .70726 L F
.32941 .68129 m .32886 .70541 L .32931 .70645 L .986 .729 .347 r
F
.32915 .68076 m .32886 .70541 L .32941 .68129 L F
.41412 .84763 m .40976 .8371 L .40062 .83982 L .683 .77 .917 r
F
.41899 .84699 m .40976 .8371 L .41412 .84763 L F
.41899 .84699 m .4195 .83582 L .40976 .8371 L F
.38653 .84872 m .37055 .844 L .36458 .85238 L F
0 g
.36228 .86115 m
.36458 .85238 L
s
.79568 .71056 m .80784 .69527 L .80818 .70093 L .394 .241 .552 r
F
.79603 .71623 m .79568 .71056 L .80818 .70093 L F
.77861 .70018 m .79568 .71056 L .80818 .70093 L .673 .758 .914 r
F
.76795 .70518 m .79568 .71056 L .77861 .70018 L F
0 g
.78724 .71452 m
.79568 .71056 L
s
.55401 .72097 m .53028 .72923 L .55467 .72487 L .673 .758 .915 r
F
.55401 .72097 m .52896 .72143 L .53028 .72923 L F
.60334 .70872 m .62697 .70049 L .60269 .70483 L .673 .758 .914 r
F
.29913 .60504 m .26576 .60294 L .29584 .60972 L .654 .726 .902 r
F
.35632 .61288 m .38086 .59925 L .35337 .60788 L F
.35632 .61288 m .38676 .60927 L .38086 .59925 L F
.45813 .59291 m .48097 .59285 L .48054 .60012 L .793 .542 .558 r
F
.45813 .59291 m .45856 .58564 L .48097 .59285 L F
.47493 .56904 m .48097 .59285 L .48988 .57385 L .654 .726 .902 r
F
.47493 .56904 m .45856 .58564 L .48097 .59285 L F
0 g
.48097 .59285 m
.50508 .59616 L
s
.67802 .70332 m .68911 .70685 L .68944 .71252 L .932 .657 .495 r
F
.67802 .70332 m .67769 .69766 L .68911 .70685 L F
0 g
.68911 .70685 m
.69464 .70938 L
s
.37744 .71805 m .38949 .70275 L .3898 .70842 L .389 .235 .549 r
F
.36018 .70766 m .37744 .71805 L .3898 .70842 L .673 .758 .914 r
F
.3496 .71267 m .37744 .71805 L .36018 .70766 L F
0 g
.36157 .72555 m
.37744 .71805 L
s
.29959 .59777 m .27281 .5863 L .26623 .59567 L .654 .726 .902 r
F
.30471 .59387 m .27281 .5863 L .29959 .59777 L F
.46744 .83425 m .45835 .82322 L .45884 .82778 L .932 .647 .478 r
F
.46793 .83881 m .46744 .83425 L .45884 .82778 L F
0 g
.46744 .83425 m
.47266 .84203 L
s
.30527 .58668 m .28372 .57138 L .27353 .57915 L .654 .726 .902 r
F
.31183 .58384 m .28372 .57138 L .30527 .58668 L F
.70003 .6896 m .68938 .70668 L .7076 .6957 L .673 .758 .914 r
F
.70003 .6896 m .67802 .69754 L .68938 .70668 L F
.57842 .70918 m .56662 .69635 L .56133 .69884 L F
.57842 .70918 m .57271 .69473 L .56662 .69635 L F
.44521 .83639 m .44745 .82307 L .43762 .83325 L .683 .77 .917 r
F
.44521 .83639 m .45884 .82778 L .44745 .82307 L F
.74554 .69148 m .74347 .70378 L .7553 .70262 L .673 .758 .914 r
F
.74604 .68853 m .7553 .70262 L .74969 .68817 L F
.74321 .68881 m .74554 .69148 L .74604 .68853 L F
.74554 .69148 m .7553 .70262 L .74604 .68853 L F
.74819 .64673 m .74831 .64592 L .74846 .67415 L 0 0 .158 r
F
.74355 .69455 m .74267 .7097 L .75569 .70843 L .673 .758 .914 r
F
.74321 .68881 m .74347 .70378 L .74554 .69148 L F
.74355 .69455 m .75569 .70843 L .75006 .69391 L F
.74389 .70022 m .74301 .71537 L .75604 .7141 L .673 .758 .915 r
F
.74389 .70022 m .75604 .7141 L .7504 .69958 L F
.74704 .64797 m .74753 .67579 L .74719 .67605 L .362 .185 .501 r
F
.74443 .64861 m .74534 .6766 L .74458 .67671 L .642 .403 .541 r
F
.7504 .67585 m .76109 .68406 L .76524 .68086 L .673 .758 .914 r
F
.75276 .68324 m .7545 .6869 L .75579 .68656 L F
.74969 .68817 m .76749 .69939 L .75579 .68656 L F
.75008 .68282 m .75619 .69229 L .76152 .68978 L F
.74696 .67687 m .74969 .68817 L .7545 .6869 L F
.74775 .6474 m .74819 .64673 L .74834 .67489 L .088 0 .422 r
F
.74831 .64592 m .74788 .64488 L .74803 .67323 L .982 .725 .331 r
F
.74735 .69172 m .74595 .70002 L .7504 .69958 L .673 .758 .915 r
F
.7484 .68551 m .74863 .70463 L .7485 .70544 L 0 0 .158 r
F
.74813 .68163 m .75212 .68712 L .75008 .68282 L .673 .758 .914 r
F
.74617 .67648 m .74969 .68817 L .74655 .67642 L F
.74521 .67662 m .74529 .67684 L .74617 .67648 L F
.74704 .64797 m .74775 .6474 L .7479 .67552 L .362 .185 .501 r
F
.74759 .68131 m .74808 .68193 L .74813 .68163 L .673 .758 .914 r
F
.74678 .67712 m .74969 .68817 L .74696 .67687 L F
.74528 .67679 m .74321 .68881 L .74969 .68817 L F
.74287 .64835 m .74458 .67671 L .74377 .67662 L .751 .492 .54 r
F
.74408 .67371 m .74391 .67664 L .74528 .67679 L .673 .758 .914 r
F
.74391 .67664 m .74321 .68881 L .74528 .67679 L F
.74287 .64835 m .74443 .64861 L .74458 .67671 L .751 .492 .54 r
F
.74549 .68213 m .74355 .69455 L .75006 .69391 L .673 .758 .914 r
F
.74617 .68869 m .74389 .70022 L .74595 .70002 L .673 .758 .915 r
F
.7444 .69122 m .74389 .70022 L .74617 .68869 L F
.74461 .68202 m .74633 .70712 L .74474 .70732 L .642 .403 .541 r
F
.74458 .67671 m .74488 .68198 L .74461 .68202 L F
.74559 .68719 m .7444 .69122 L .74617 .68869 L .673 .758 .915 r
F
.74427 .68198 m .74355 .69455 L .74549 .68213 L .673 .758 .914 r
F
.74519 .68725 m .74497 .68728 L .74461 .68202 L .642 .403 .541 r
F
.7454 .68191 m .74461 .68202 L .74549 .68213 L .673 .758 .914 r
F
.74534 .6766 m .74551 .68189 L .74458 .67671 L .642 .403 .541 r
F
.75579 .68656 m .76749 .69939 L .77809 .69441 L .673 .758 .914 r
F
.75619 .69229 m .77861 .70018 L .76152 .68978 L F
.74941 .68662 m .76186 .69545 L .76603 .69224 L .673 .758 .915 r
F
.74549 .67733 m .74969 .68817 L .74625 .67676 L .673 .758 .914 r
F
.7465 .68166 m .74698 .68219 L .74749 .68125 L F
.74661 .67649 m .74678 .67712 L .74696 .67687 L F
.75232 .67923 m .76841 .68286 L .76949 .67892 L F
.74666 .67627 m .74722 .68136 L .74695 .68147 L .519 .306 .53 r
F
.74696 .67687 m .75579 .68656 L .74765 .67588 L .673 .758 .914 r
F
.74719 .67605 m .74734 .68127 L .74722 .68136 L .362 .185 .501 r
F
.74565 .68254 m .75006 .69391 L .74663 .6818 L .673 .758 .914 r
F
.74735 .68663 m .74775 .68687 L .74828 .68624 L .673 .758 .915 r
F
.74755 .68505 m .75006 .69391 L .74787 .68316 L .673 .758 .914 r
F
.74753 .67579 m .7479 .67552 L .74793 .68082 L .362 .185 .501 r
F
.74698 .68219 m .74787 .68316 L .74757 .68134 L .673 .758 .914 r
F
.74787 .68316 m .75619 .69229 L .74807 .68198 L F
.74787 .68316 m .74807 .68198 L .74757 .68134 L F
.74765 .67588 m .75196 .68153 L .74994 .67728 L F
.7484 .67454 m .74844 .67978 L .74834 .67489 L 0 0 .158 r
F
.74969 .68817 m .7553 .70262 L .76749 .69939 L .673 .758 .914 r
F
.74787 .68316 m .75006 .69391 L .75619 .69229 L F
.74828 .68624 m .74827 .68625 L .74941 .68662 L .673 .758 .915 r
F
.74827 .68625 m .74775 .68687 L .74818 .68681 L F
.74827 .68625 m .74818 .68681 L .74941 .68662 L F
.74696 .67687 m .7545 .6869 L .75276 .68324 L .673 .758 .914 r
F
.74795 .68153 m .76152 .68978 L .7499 .68123 L F
.74844 .67978 m .74848 .68502 L .74839 .68007 L 0 0 .158 r
F
.75006 .69391 m .75569 .70843 L .76795 .70518 L .673 .758 .914 r
F
.747 .68751 m .7504 .69958 L .75653 .69796 L .673 .758 .915 r
F
.74568 .68718 m .74519 .68725 L .74488 .68198 L .642 .403 .541 r
F
.75006 .69391 m .76795 .70518 L .75619 .69229 L .673 .758 .914 r
F
.75023 .68837 m .75653 .69796 L .76186 .69545 L .673 .758 .915 r
F
.74808 .68193 m .75212 .68712 L .74813 .68163 L .673 .758 .914 r
F
.74818 .68047 m .74837 .6802 L .7484 .68551 L .088 0 .422 r
F
.74825 .68572 m .7484 .68551 L .7485 .70544 L F
.74818 .68047 m .7484 .68551 L .74825 .68572 L F
.74817 .68065 m .74795 .68153 L .7499 .68123 L .673 .758 .914 r
F
.74655 .67642 m .74658 .67651 L .74661 .67649 L F
.75002 .68019 m .76569 .68657 L .76841 .68286 L F
.74678 .68154 m .74653 .68165 L .74617 .67648 L .519 .306 .53 r
F
.75002 .67457 m .76524 .68086 L .76794 .67718 L .673 .758 .914 r
F
.74811 .67521 m .74837 .6802 L .74818 .68047 L .088 0 .422 r
F
.74775 .6474 m .74827 .67499 L .74811 .67521 L F
.74763 .67587 m .74814 .67618 L .7489 .67534 L .673 .758 .914 r
F
.74827 .67499 m .74837 .6802 L .74811 .67521 L .088 0 .422 r
F
.7487 .67438 m .75345 .67688 L .75002 .67457 L .673 .758 .914 r
F
.74602 .6484 m .74719 .67605 L .74666 .67627 L .519 .306 .53 r
F
.74408 .67371 m .74819 .6751 L .7487 .67438 L .673 .758 .914 r
F
.74819 .6751 m .75345 .67688 L .7487 .67438 L F
.75345 .67688 m .76524 .68086 L .75002 .67457 L F
.74803 .67323 m .74745 .67813 L .74806 .67854 L .91 .629 .499 r
F
.74775 .6474 m .74811 .67521 L .7479 .67552 L .088 0 .422 r
F
.74788 .64488 m .74752 .67289 L .74803 .67323 L .91 .629 .499 r
F
.74704 .64797 m .7479 .67552 L .74753 .67579 L .362 .185 .501 r
F
.74752 .67289 m .74745 .67813 L .74803 .67323 L .91 .629 .499 r
F
.74959 .67845 m .76949 .67892 L .76887 .67501 L .673 .758 .914 r
F
.74818 .68047 m .74808 .68062 L .7479 .67552 L .088 0 .422 r
F
.74658 .67651 m .74969 .68817 L .74661 .67649 L .673 .758 .914 r
F
.74753 .67579 m .74793 .68082 L .74762 .68105 L .362 .185 .501 r
F
.7479 .67552 m .74801 .68072 L .74793 .68082 L .088 0 .422 r
F
.74862 .67363 m .76794 .67718 L .76902 .67325 L .673 .758 .914 r
F
.74408 .67371 m .75002 .67457 L .74862 .67363 L F
.75002 .67457 m .76794 .67718 L .74862 .67363 L F
.74788 .64488 m .74683 .64406 L .74698 .67253 L .91 .629 .499 r
F
.74714 .67264 m .74698 .67253 L .74701 .67784 L F
.74788 .64488 m .74698 .67253 L .74714 .67264 L F
.74442 .67938 m .74906 .67921 L .74828 .67869 L .673 .758 .914 r
F
.74762 .68105 m .74734 .68127 L .74719 .67605 L .362 .185 .501 r
F
.74617 .67648 m .74637 .68171 L .7462 .68179 L .519 .306 .53 r
F
.74442 .67938 m .74859 .68079 L .74903 .6806 L .673 .758 .914 r
F
.74442 .67938 m .74903 .6806 L .74875 .68001 L F
.74735 .68663 m .747 .68751 L .74754 .68674 L .673 .758 .915 r
F
.74666 .67627 m .74719 .67605 L .74722 .68136 L .519 .306 .53 r
F
.74663 .6818 m .74755 .68505 L .74787 .68316 L .673 .758 .914 r
F
.74695 .68147 m .74722 .68136 L .74725 .68667 L .519 .306 .53 r
F
.74652 .68697 m .747 .68751 L .74735 .68663 L .673 .758 .915 r
F
.7469 .68682 m .74725 .68667 L .74736 .70668 L .519 .306 .53 r
F
.74666 .67627 m .74725 .68667 L .7469 .68682 L F
.7469 .68682 m .74658 .68695 L .74617 .67648 L F
.74476 .68505 m .74735 .68663 L .74828 .68624 L .673 .758 .915 r
F
.74698 .68219 m .74757 .68134 L .74749 .68125 L .673 .758 .914 r
F
.75579 .68656 m .77809 .69441 L .76109 .68406 L F
.7499 .68123 m .76152 .68978 L .76569 .68657 L F
.74973 .68496 m .76875 .68853 L .76983 .68459 L .673 .758 .915 r
F
.74476 .68505 m .75127 .68599 L .74973 .68496 L F
.75127 .68599 m .76875 .68853 L .74973 .68496 L F
.74869 .67988 m .75002 .68019 L .75032 .68007 L .673 .758 .914 r
F
.74442 .67938 m .74875 .68001 L .74869 .67988 L F
.74875 .68001 m .75002 .68019 L .74869 .67988 L F
.74827 .67499 m .74834 .67489 L .74837 .6802 L .088 0 .422 r
F
.74825 .67371 m .74824 .67893 L .74846 .67415 L .982 .725 .331 r
F
.74684 .68774 m .7504 .69958 L .747 .68751 L .673 .758 .915 r
F
.74825 .68572 m .7485 .70544 L .74811 .68592 L .088 0 .422 r
F
.74813 .6871 m .75285 .69392 L .75023 .68837 L .673 .758 .915 r
F
.74581 .68775 m .7504 .69958 L .74665 .68712 L F
.74811 .68592 m .7485 .70544 L .74805 .686 L .088 0 .422 r
F
.76109 .68406 m .78639 .68801 L .76524 .68086 L .673 .758 .914 r
F
.74835 .68441 m .76983 .68459 L .76921 .68068 L .673 .758 .915 r
F
.74725 .68667 m .74807 .70612 L .74736 .70668 L .362 .185 .501 r
F
.74722 .68136 m .7474 .68656 L .74725 .68667 L F
.7474 .68656 m .74807 .70612 L .74725 .68667 L F
.74814 .67618 m .76109 .68406 L .7504 .67585 L .673 .758 .914 r
F
.749 .6793 m .76949 .67892 L .74959 .67845 L F
.74749 .68125 m .74757 .68134 L .74759 .68131 L F
.74762 .68105 m .74772 .68632 L .74734 .68127 L .362 .185 .501 r
F
.74772 .68632 m .74807 .70612 L .7475 .68648 L F
.74772 .68632 m .7475 .68648 L .74734 .68127 L F
.75002 .68019 m .76841 .68286 L .75232 .67923 L .673 .758 .914 r
F
.75368 .68183 m .76921 .68068 L .76692 .67706 L .673 .758 .915 r
F
.74811 .68592 m .74805 .686 L .74793 .68082 L .088 0 .422 r
F
.74762 .68105 m .74796 .68614 L .74772 .68632 L .362 .185 .501 r
F
.74793 .68082 m .74805 .686 L .74796 .68614 L .088 0 .422 r
F
.74529 .67684 m .74549 .67733 L .74617 .67648 L .673 .758 .914 r
F
.74549 .67733 m .74625 .67676 L .74617 .67648 L F
.74534 .6766 m .74617 .67648 L .74622 .6871 L .642 .403 .541 r
F
.74559 .68719 m .74581 .68775 L .74658 .68704 L .673 .758 .915 r
F
.74617 .68869 m .74595 .70002 L .74735 .69172 L F
.74568 .68718 m .74622 .6871 L .74633 .70712 L .642 .403 .541 r
F
.74657 .68173 m .74565 .68254 L .74663 .6818 L .673 .758 .914 r
F
.74551 .68189 m .74488 .68198 L .74458 .67671 L .642 .403 .541 r
F
.74442 .67938 m .7454 .68191 L .74657 .68173 L .673 .758 .914 r
F
.7454 .68191 m .74565 .68254 L .74657 .68173 L F
.74551 .68189 m .74622 .6871 L .74568 .68718 L .642 .403 .541 r
F
.74534 .6766 m .74578 .68185 L .74551 .68189 L F
.74578 .68185 m .74622 .6871 L .74551 .68189 L F
.74658 .68704 m .74581 .68775 L .74665 .68712 L .673 .758 .915 r
F
.74551 .68189 m .74568 .68718 L .74488 .68198 L .642 .403 .541 r
F
.74476 .68505 m .74559 .68719 L .74658 .68704 L .673 .758 .915 r
F
.74476 .68505 m .74796 .68613 L .74835 .68557 L F
.74665 .68712 m .74684 .68774 L .747 .68751 L F
.7469 .68682 m .74736 .70668 L .74658 .68695 L .519 .306 .53 r
F
.7462 .68179 m .74736 .70668 L .74633 .70712 L F
.74704 .68315 m .74607 .70239 L .74714 .70277 L .809 .541 .532 r
F
.74666 .67627 m .74678 .68154 L .74617 .67648 L .519 .306 .53 r
F
.74442 .67938 m .74742 .68121 L .74817 .68065 L .673 .758 .914 r
F
.74602 .6484 m .74704 .64797 L .74719 .67605 L .519 .306 .53 r
F
.74408 .67371 m .74763 .67587 L .7489 .67534 L .673 .758 .914 r
F
.74842 .67293 m .76902 .67325 L .7684 .66936 L F
.74408 .67371 m .75073 .67359 L .74842 .67293 L F
.75073 .67359 m .76902 .67325 L .74842 .67293 L F
.74442 .67938 m .75032 .68007 L .74917 .67929 L F
.74698 .67253 m .74632 .68294 L .74704 .68315 L .809 .541 .532 r
F
.74683 .64406 m .74646 .67238 L .74698 .67253 L F
.74602 .6484 m .74666 .67627 L .74617 .67648 L .519 .306 .53 r
F
.74408 .67371 m .74696 .67687 L .74765 .67588 L .673 .758 .914 r
F
.74639 .67766 m .74665 .67773 L .74698 .67253 L .809 .541 .532 r
F
.74753 .67579 m .74762 .68105 L .74719 .67605 L .362 .185 .501 r
F
.74752 .67289 m .74701 .67784 L .74745 .67813 L .91 .629 .499 r
F
.74788 .64488 m .74714 .67264 L .74752 .67289 L F
.74714 .67264 m .74701 .67784 L .74752 .67289 L F
.74443 .64861 m .74617 .67648 L .74534 .6766 L .642 .403 .541 r
F
.74742 .68121 m .74795 .68153 L .74817 .68065 L .673 .758 .914 r
F
.74762 .68105 m .74793 .68082 L .74796 .68614 L .362 .185 .501 r
F
.74808 .68385 m .75027 .68406 L .74872 .68362 L .673 .758 .915 r
F
.74476 .68505 m .74879 .68433 L .74808 .68385 L F
.74879 .68433 m .75027 .68406 L .74808 .68385 L F
.74754 .68674 m .74807 .68746 L .74813 .6871 L F
.74772 .68632 m .74796 .68614 L .74807 .70612 L .362 .185 .501 r
F
.74808 .68385 m .74714 .70277 L .74819 .70359 L .91 .629 .499 r
F
.74801 .68072 m .74811 .68592 L .74793 .68082 L .088 0 .422 r
F
.74806 .67854 m .74786 .6837 L .74808 .68385 L .91 .629 .499 r
F
.74786 .6837 m .74714 .70277 L .74808 .68385 L F
.74442 .67938 m .7465 .68166 L .74749 .68125 L .673 .758 .914 r
F
.74646 .67238 m .74597 .68284 L .74632 .68294 L .809 .541 .532 r
F
.74683 .64406 m .7462 .6723 L .74646 .67238 L F
.7462 .6723 m .74597 .68284 L .74646 .67238 L F
.74775 .6474 m .74834 .67489 L .74827 .67499 L .088 0 .422 r
F
.74831 .64592 m .74803 .67323 L .74825 .67371 L .982 .725 .331 r
F
.74819 .64673 m .74846 .67415 L .7484 .67454 L 0 0 .158 r
F
.74819 .64673 m .7484 .67454 L .74834 .67489 L F
.74831 .64592 m .74825 .67371 L .74846 .67415 L .982 .725 .331 r
F
.74568 .68718 m .74633 .70712 L .74519 .68725 L .642 .403 .541 r
F
.74519 .68725 m .74633 .70712 L .74497 .68728 L F
.74443 .64861 m .74602 .6484 L .74617 .67648 L F
.74648 .67226 m .76612 .66576 L .76234 .6627 L .673 .758 .914 r
F
.74408 .67371 m .74782 .67236 L .74648 .67226 L F
.74782 .67236 m .76612 .66576 L .74648 .67226 L F
.74576 .64368 m .74468 .64355 L .74483 .67214 L .734 .478 .541 r
F
.74408 .67371 m .74634 .67235 L .74564 .67214 L .673 .758 .914 r
F
.74408 .67371 m .74564 .67214 L .74495 .67195 L F
.74476 .68505 m .74463 .68734 L .74559 .68719 L .673 .758 .915 r
F
.74488 .68198 m .74519 .68725 L .74461 .68202 L .642 .403 .541 r
F
.74408 .67371 m .74521 .67662 L .74655 .67642 L .673 .758 .914 r
F
.74992 .6716 m .7684 .66936 L .76612 .66576 L F
.74408 .67371 m .76453 .67005 L .74992 .6716 L F
.76453 .67005 m .7684 .66936 L .74992 .6716 L F
.74468 .64355 m .74359 .64364 L .74374 .67226 L .66 .418 .542 r
F
.74394 .68194 m .74461 .68202 L .74464 .68733 L .751 .492 .54 r
F
.74411 .68727 m .74464 .68733 L .74474 .70732 L F
.74394 .68194 m .74464 .68733 L .74411 .68727 L F
.74321 .68881 m .74234 .70389 L .74347 .70378 L .673 .758 .914 r
F
.73679 .68841 m .74234 .70389 L .74255 .70032 L F
.74184 .68872 m .74255 .70032 L .74321 .68881 L F
.73679 .68841 m .74255 .70032 L .74184 .68872 L F
.74082 .64578 m .74086 .64659 L .74101 .67501 L .769 .613 .047 r
F
.74377 .67662 m .74461 .68202 L .74394 .68194 L .751 .492 .54 r
F
.74124 .64728 m .74189 .64788 L .74204 .67614 L .929 .648 .486 r
F
.74221 .67699 m .73656 .68198 L .74234 .67721 L .673 .758 .914 r
F
.73656 .68198 m .73086 .68701 L .73637 .68231 L F
.73656 .68198 m .73637 .68231 L .74234 .67721 L F
.74082 .64578 m .74099 .67464 L .74097 .67428 L .769 .613 .047 r
F
.74086 .64659 m .74124 .64728 L .74138 .67563 L .988 .719 .38 r
F
.74082 .64578 m .74101 .67501 L .74099 .67464 L .769 .613 .047 r
F
.74136 .64476 m .74082 .64578 L .74097 .67428 L 0 0 .386 r
F
.74408 .68534 m .73709 .69415 L .74355 .69455 L .673 .758 .914 r
F
.7436 .67736 m .74301 .67832 L .74386 .67756 L F
.74301 .67832 m .73679 .68841 L .74318 .6786 L F
.74301 .67832 m .74318 .6786 L .74386 .67756 L F
.74386 .67756 m .73679 .68841 L .74321 .68881 L F
.74344 .6843 m .73709 .69415 L .74408 .68534 L F
.73709 .69415 m .74267 .7097 L .74355 .69455 L F
.7415 .69276 m .73743 .69982 L .74194 .7001 L .673 .758 .915 r
F
.73743 .69982 m .74301 .71537 L .74389 .70022 L F
.73679 .68841 m .7295 .7031 L .74234 .70389 L .673 .758 .914 r
F
.73086 .68701 m .7295 .7031 L .73679 .68841 L F
.74177 .67603 m .74168 .67612 L .74274 .67642 L F
.74168 .67612 m .73086 .68701 L .74217 .67692 L F
.74168 .67612 m .74217 .67692 L .74274 .67642 L F
.74234 .67721 m .7412 .67818 L .74128 .67936 L F
.74119 .67531 m .74141 .68094 L .74125 .68068 L .988 .719 .38 r
F
.74086 .64659 m .74132 .67553 L .74119 .67531 L F
.74132 .67553 m .74141 .68094 L .74119 .67531 L F
.74097 .67428 m .741 .67972 L .741 .67959 L .769 .613 .047 r
F
.74119 .67531 m .74125 .68068 L .74101 .67501 L .988 .719 .38 r
F
.7412 .67818 m .73086 .68701 L .74128 .67936 L .673 .758 .914 r
F
.73751 .68032 m .72583 .68471 L .73086 .68701 L F
.74408 .67371 m .73983 .67627 L .73751 .68032 L F
.73983 .67627 m .72583 .68471 L .73751 .68032 L F
.7416 .68108 m .7411 .68138 L .74223 .68158 L F
.74128 .67936 m .73086 .68701 L .73679 .68841 L F
.7411 .68138 m .72608 .69043 L .74115 .68217 L F
.7411 .68138 m .74115 .68217 L .74223 .68158 L F
.74099 .67464 m .74102 .68001 L .74097 .67428 L .769 .613 .047 r
F
.73709 .69415 m .72977 .70891 L .74267 .7097 L .673 .758 .914 r
F
.73113 .69275 m .72977 .70891 L .73709 .69415 L F
.74144 .69174 m .73147 .69842 L .73743 .69982 L .673 .758 .915 r
F
.74118 .68264 m .74127 .68413 L .74264 .68297 L .673 .758 .914 r
F
.74152 .68103 m .74167 .68643 L .74141 .68094 L .929 .648 .486 r
F
.74463 .68733 m .7415 .69276 L .74389 .70022 L .673 .758 .915 r
F
.74167 .68643 m .7422 .70659 L .74158 .68636 L .929 .648 .486 r
F
.74264 .68297 m .73567 .68889 L .73709 .69415 L .673 .758 .914 r
F
.74167 .68643 m .74158 .68636 L .74141 .68094 L .929 .648 .486 r
F
.74274 .67642 m .73679 .68841 L .7439 .67688 L .673 .758 .914 r
F
.74223 .68158 m .73877 .68348 L .73663 .68722 L F
.74125 .68068 m .74131 .68604 L .7411 .68043 L .988 .719 .38 r
F
.74124 .64728 m .7417 .67587 L .74138 .67563 L .929 .648 .486 r
F
.74189 .64788 m .74251 .67633 L .74204 .67614 L .845 .571 .524 r
F
.74086 .64659 m .74138 .67563 L .74132 .67553 L .988 .719 .38 r
F
.74124 .64728 m .74204 .67614 L .7417 .67587 L .929 .648 .486 r
F
.74189 .64788 m .74287 .64835 L .74302 .67653 L .845 .571 .524 r
F
.74189 .64788 m .74302 .67653 L .74286 .67647 L F
.74084 .67566 m .72205 .68166 L .72583 .68471 L .673 .758 .914 r
F
.74408 .67371 m .73982 .67525 L .74084 .67566 L F
.73982 .67525 m .72205 .68166 L .74084 .67566 L F
.74251 .67633 m .74305 .68184 L .74262 .68167 L .845 .571 .524 r
F
.74189 .64788 m .74286 .67647 L .74251 .67633 L F
.74274 .67642 m .74258 .67656 L .74264 .67661 L .673 .758 .914 r
F
.74286 .67647 m .74305 .68184 L .74251 .67633 L .845 .571 .524 r
F
.74086 .64659 m .74119 .67531 L .74101 .67501 L .988 .719 .38 r
F
.73791 .67593 m .71976 .67806 L .72205 .68166 L .673 .758 .914 r
F
.74248 .64398 m .74136 .64476 L .74151 .67334 L .405 .218 .51 r
F
.7417 .67587 m .74179 .68123 L .74138 .67563 L .929 .648 .486 r
F
.74179 .68123 m .74187 .68659 L .74163 .68111 L F
.74179 .68123 m .74163 .68111 L .74138 .67563 L F
.74187 .68659 m .74167 .68643 L .74152 .68103 L F
.74163 .68111 m .74152 .68103 L .74138 .67563 L F
.74187 .68659 m .74152 .68103 L .74163 .68111 L F
.7441 .68226 m .74379 .6828 L .74425 .68232 L .673 .758 .914 r
F
.74379 .6828 m .73709 .69415 L .74391 .68289 L F
.74379 .6828 m .74391 .68289 L .74425 .68232 L F
.7434 .68778 m .73743 .69982 L .74407 .6883 L .673 .758 .915 r
F
.74319 .68186 m .74317 .68189 L .74427 .68198 L .673 .758 .914 r
F
.74317 .68189 m .73709 .69415 L .7441 .68226 L F
.74317 .68189 m .7441 .68226 L .74427 .68198 L F
.74256 .6881 m .74125 .68858 L .74294 .68872 L .673 .758 .915 r
F
.7415 .69276 m .74194 .7001 L .74389 .70022 L F
.74144 .68625 m .7422 .70659 L .74154 .706 L .929 .648 .486 r
F
.74141 .68094 m .74158 .68636 L .74144 .68625 L F
.74158 .68636 m .7422 .70659 L .74144 .68625 L F
.74102 .68001 m .74105 .68539 L .741 .67972 L .769 .613 .047 r
F
.74118 .68264 m .73113 .69275 L .74127 .68413 L .673 .758 .914 r
F
.74105 .68539 m .74104 .68516 L .741 .67972 L .769 .613 .047 r
F
.74103 .68014 m .74104 .68032 L .74107 .68563 L F
.7411 .68043 m .7412 .68585 L .74104 .68032 L .988 .719 .38 r
F
.7412 .68585 m .74154 .706 L .74115 .68576 L F
.7412 .68585 m .74115 .68576 L .74104 .68032 L F
.74259 .68715 m .74213 .6874 L .74264 .68718 L .673 .758 .915 r
F
.74196 .68185 m .74118 .68264 L .74264 .68297 L .673 .758 .914 r
F
.74179 .68123 m .74206 .68145 L .74209 .68676 L .929 .648 .486 r
F
.74199 .68672 m .74116 .68722 L .74249 .68707 L .673 .758 .915 r
F
.74187 .68659 m .74209 .68676 L .7422 .70659 L .929 .648 .486 r
F
.74179 .68123 m .74209 .68676 L .74187 .68659 L F
.74209 .68676 m .74249 .68707 L .74279 .68704 L .673 .758 .915 r
F
.74199 .68672 m .74249 .68707 L .74209 .68676 L F
.74116 .68722 m .72642 .6961 L .74121 .68791 L F
.74116 .68722 m .74121 .68791 L .74279 .68704 L F
.741 .67972 m .74104 .68516 L .741 .67959 L .769 .613 .047 r
F
.74125 .68858 m .73147 .69842 L .74144 .69174 L .673 .758 .915 r
F
.73663 .68722 m .72608 .69043 L .73113 .69275 L .673 .758 .914 r
F
.74107 .68563 m .74154 .706 L .74117 .7053 L .988 .719 .38 r
F
.74104 .68032 m .74115 .68576 L .74107 .68563 L F
.74115 .68576 m .74154 .706 L .74107 .68563 L F
.73567 .68889 m .73113 .69275 L .73319 .69323 L .673 .758 .914 r
F
.73086 .68701 m .71765 .7003 L .7295 .7031 L F
.74179 .68684 m .72261 .69303 L .72642 .6961 L .673 .758 .915 r
F
.74199 .68672 m .74177 .68679 L .74179 .68684 L F
.74177 .68679 m .72261 .69303 L .74179 .68684 L F
.74279 .68704 m .74259 .68715 L .74264 .68718 L F
.74264 .67661 m .74221 .67699 L .74234 .67721 L .673 .758 .914 r
F
.74391 .68289 m .73709 .69415 L .7442 .68312 L F
.74251 .67633 m .74262 .68167 L .74204 .67614 L .845 .571 .524 r
F
.73877 .68348 m .72608 .69043 L .73663 .68722 L .673 .758 .914 r
F
.72583 .68471 m .71765 .7003 L .73086 .68701 L F
.72583 .68471 m .7076 .6957 L .71765 .7003 L F
.74111 .68637 m .72032 .68942 L .72261 .69303 L .673 .758 .915 r
F
.74476 .68505 m .73997 .68591 L .74111 .68637 L F
.73997 .68591 m .72032 .68942 L .74111 .68637 L F
.74262 .68167 m .74274 .68702 L .74224 .68152 L .845 .571 .524 r
F
.74274 .68702 m .74318 .70706 L .74243 .6869 L F
.74274 .68702 m .74243 .6869 L .74224 .68152 L F
.74262 .68167 m .74224 .68152 L .74204 .67614 L F
.74142 .68119 m .72228 .68736 L .72608 .69043 L .673 .758 .914 r
F
.74204 .67614 m .74224 .68152 L .74206 .68145 L .845 .571 .524 r
F
.74442 .67938 m .74046 .68081 L .74142 .68119 L .673 .758 .914 r
F
.74046 .68081 m .72228 .68736 L .74142 .68119 L F
.74476 .68505 m .74111 .68637 L .74199 .68672 L .673 .758 .915 r
F
.74111 .68637 m .72261 .69303 L .74199 .68672 L F
.74224 .68152 m .74243 .6869 L .74206 .68145 L .845 .571 .524 r
F
.74264 .68718 m .74125 .68858 L .7434 .68778 L .673 .758 .915 r
F
.74243 .6869 m .74318 .70706 L .7423 .68684 L .845 .571 .524 r
F
.74243 .6869 m .7423 .68684 L .74206 .68145 L F
.74104 .68516 m .74117 .7053 L .74103 .68506 L .769 .613 .047 r
F
.74104 .68516 m .74103 .68506 L .741 .67959 L F
.74102 .6849 m .74117 .7053 L .74112 .70449 L F
.741 .67959 m .74103 .68506 L .74102 .6849 L F
.74103 .68506 m .74117 .7053 L .74102 .6849 L F
.74213 .6874 m .74121 .68791 L .74216 .68745 L .673 .758 .915 r
F
.74121 .68791 m .72642 .6961 L .74121 .68797 L F
.74121 .68791 m .74121 .68797 L .74216 .68745 L F
.74213 .6874 m .74216 .68745 L .74264 .68718 L F
.74099 .67464 m .74107 .68563 L .74105 .68539 L .769 .613 .047 r
F
.74122 .67919 m .741 .67959 L .74102 .6849 L 0 0 .386 r
F
.74105 .68539 m .74117 .7053 L .74104 .68516 L .769 .613 .047 r
F
.74105 .68539 m .74107 .68563 L .74117 .7053 L F
.73811 .68624 m .71969 .68551 L .72032 .68942 L .673 .758 .915 r
F
.74476 .68505 m .73977 .68514 L .73811 .68624 L F
.73977 .68514 m .71969 .68551 L .73811 .68624 L F
.7417 .67587 m .74206 .68145 L .74179 .68123 L .929 .648 .486 r
F
.73978 .67448 m .73762 .6759 L .73791 .67593 L .673 .758 .914 r
F
.74132 .67553 m .74138 .67563 L .74141 .68094 L .988 .719 .38 r
F
.74151 .67334 m .74122 .67919 L .74153 .67865 L 0 0 .386 r
F
.74099 .67464 m .74101 .67501 L .74104 .68032 L .769 .613 .047 r
F
.7417 .67587 m .74204 .67614 L .74206 .68145 L .929 .648 .486 r
F
.74264 .68718 m .73837 .68953 L .73575 .69412 L .673 .758 .915 r
F
.74209 .68676 m .74318 .70706 L .7422 .70659 L .845 .571 .524 r
F
.74206 .68145 m .7423 .68684 L .74209 .68676 L F
.7423 .68684 m .74318 .70706 L .74209 .68676 L F
.74408 .67371 m .73978 .67448 L .73791 .67593 L .673 .758 .914 r
F
.73561 .68256 m .71998 .68375 L .72228 .68736 L F
.74442 .67938 m .73894 .68036 L .73561 .68256 L F
.73894 .68036 m .71998 .68375 L .73561 .68256 L F
.74138 .67563 m .74152 .68103 L .74141 .68094 L .929 .648 .486 r
F
.74442 .67938 m .74115 .6789 L .74032 .67945 L .673 .758 .914 r
F
.74201 .67834 m .74156 .68396 L .74194 .68372 L .405 .218 .51 r
F
.74208 .67296 m .74182 .67846 L .74201 .67834 L F
.74182 .67846 m .74156 .68396 L .74201 .67834 L F
.74258 .67656 m .73086 .68701 L .74264 .67661 L .673 .758 .914 r
F
.74287 .64835 m .74377 .67662 L .74302 .67653 L .751 .492 .54 r
F
.73207 .67586 m .71913 .67417 L .71976 .67806 L .673 .758 .914 r
F
.74408 .67371 m .74177 .67603 L .74274 .67642 L F
.74263 .6726 m .74201 .67834 L .74266 .67791 L .405 .218 .51 r
F
.74248 .64398 m .74208 .67296 L .74263 .6726 L F
.74208 .67296 m .74201 .67834 L .74263 .6726 L F
.73978 .67448 m .73872 .67381 L .73207 .67586 L .673 .758 .914 r
F
.74408 .67371 m .74086 .67377 L .73978 .67448 L F
.74086 .67377 m .73872 .67381 L .73978 .67448 L F
.73872 .67381 m .71913 .67417 L .73207 .67586 L F
.74359 .64364 m .74248 .64398 L .74263 .6726 L .57 .345 .536 r
F
.74281 .67255 m .74263 .6726 L .74266 .67791 L F
.74359 .64364 m .74263 .6726 L .74281 .67255 L F
.74442 .67938 m .73749 .67951 L .7289 .68216 L .673 .758 .914 r
F
.7434 .68778 m .74256 .6881 L .74294 .68872 L .673 .758 .915 r
F
.74302 .67653 m .74394 .68194 L .74305 .68184 L .751 .492 .54 r
F
.74442 .67938 m .7416 .68108 L .74223 .68158 L .673 .758 .914 r
F
.74442 .67938 m .74196 .68185 L .74264 .68297 L F
.74286 .67647 m .74302 .67653 L .74305 .68184 L .845 .571 .524 r
F
.74262 .68167 m .74305 .68184 L .74307 .68715 L F
.74274 .68702 m .74307 .68715 L .74318 .70706 L F
.74262 .68167 m .74307 .68715 L .74274 .68702 L F
.73813 .68517 m .72076 .68156 L .71969 .68551 L .673 .758 .915 r
F
.74313 .67777 m .74266 .67791 L .74269 .68322 L .57 .345 .536 r
F
.7289 .68216 m .72302 .67977 L .71998 .68375 L .673 .758 .914 r
F
.73749 .67951 m .72302 .67977 L .7289 .68216 L F
.73572 .68374 m .72348 .67786 L .72076 .68156 L .673 .758 .915 r
F
.74269 .68322 m .74166 .70347 L .74279 .70269 L .405 .218 .51 r
F
.74266 .67791 m .74245 .68338 L .74269 .68322 L F
.74294 .68872 m .74125 .68858 L .74144 .69174 L .673 .758 .915 r
F
.74245 .68338 m .74166 .70347 L .74269 .68322 L .405 .218 .51 r
F
.74079 .68447 m .73965 .68332 L .73572 .68374 L .673 .758 .915 r
F
.74476 .68505 m .74156 .68397 L .74079 .68447 L F
.74131 .68604 m .7412 .68585 L .7411 .68043 L .988 .719 .38 r
F
.74156 .68397 m .73965 .68332 L .74079 .68447 L .673 .758 .915 r
F
.73965 .68332 m .72348 .67786 L .73572 .68374 L F
.74423 .67752 m .74376 .67757 L .74379 .68288 L .66 .418 .542 r
F
.74368 .68722 m .7434 .68778 L .74463 .68733 L .673 .758 .915 r
F
.7434 .68778 m .74407 .6883 L .74463 .68733 L F
.7442 .68312 m .74344 .6843 L .74408 .68534 L .673 .758 .914 r
F
.74394 .68194 m .74411 .68727 L .74305 .68184 L .751 .492 .54 r
F
.74411 .68727 m .74474 .70732 L .7434 .68719 L F
.74411 .68727 m .7434 .68719 L .74305 .68184 L F
.74368 .68722 m .74264 .68718 L .7434 .68778 L .673 .758 .915 r
F
.74476 .68505 m .74271 .68711 L .74368 .68722 L F
.74271 .68711 m .74264 .68718 L .74368 .68722 L F
.74415 .68284 m .74379 .68288 L .74389 .70236 L .66 .418 .542 r
F
.74425 .68232 m .74391 .68289 L .7442 .68312 L .673 .758 .914 r
F
.74442 .67938 m .74319 .68186 L .74427 .68198 L F
.74423 .67752 m .74379 .68288 L .74415 .68284 L .66 .418 .542 r
F
.73953 .67947 m .72042 .67589 L .71935 .67984 L .673 .758 .914 r
F
.73412 .67549 m .71976 .67806 L .73791 .67593 L F
.74095 .67888 m .72314 .67219 L .72042 .67589 L F
.74156 .68397 m .72764 .67464 L .72348 .67786 L .673 .758 .915 r
F
.74476 .68505 m .74224 .68352 L .74156 .68397 L F
.74122 .67919 m .74102 .6849 L .7412 .68459 L 0 0 .386 r
F
.73827 .67849 m .72042 .67589 L .73953 .67947 L .673 .758 .914 r
F
.74224 .68352 m .72764 .67464 L .74156 .68397 L .673 .758 .915 r
F
.74099 .67464 m .74104 .68032 L .74103 .68014 L .769 .613 .047 r
F
.74125 .68068 m .7411 .68043 L .74101 .67501 L .988 .719 .38 r
F
.74101 .67501 m .7411 .68043 L .74104 .68032 L F
.74442 .67938 m .74131 .67833 L .74095 .67888 L .673 .758 .914 r
F
.74102 .68001 m .741 .67972 L .74097 .67428 L .769 .613 .047 r
F
.74124 .6738 m .74097 .67428 L .741 .67959 L 0 0 .386 r
F
.74131 .67833 m .74091 .67819 L .74093 .67845 L .673 .758 .914 r
F
.74124 .6738 m .741 .67959 L .74122 .67919 L 0 0 .386 r
F
.74131 .67833 m .74093 .67845 L .74095 .67888 L .673 .758 .914 r
F
.74305 .68184 m .74474 .70732 L .74318 .70706 L .751 .492 .54 r
F
.74091 .67819 m .72314 .67219 L .74095 .67888 L .673 .758 .914 r
F
.73872 .67381 m .72021 .67024 L .71913 .67417 L F
.74136 .64476 m .74097 .67428 L .74124 .6738 L 0 0 .386 r
F
.74408 .67371 m .74065 .67321 L .73872 .67381 L .673 .758 .914 r
F
.74065 .67321 m .72021 .67024 L .73872 .67381 L F
.74408 .67371 m .74274 .67642 L .7439 .67688 L F
.74374 .67226 m .74313 .67777 L .74376 .67757 L .57 .345 .536 r
F
.74359 .64364 m .7432 .67243 L .74374 .67226 L F
.7432 .67243 m .74313 .67777 L .74374 .67226 L F
.73978 .67448 m .73412 .67549 L .73762 .6759 L .673 .758 .914 r
F
.74019 .67795 m .7273 .66897 L .72314 .67219 L F
.74442 .67938 m .74179 .67778 L .74019 .67795 L F
.74065 .67321 m .72291 .66655 L .72021 .67024 L F
.74408 .67371 m .74167 .6729 L .74065 .67321 L F
.74167 .6729 m .72291 .66655 L .74065 .67321 L F
.7432 .67243 m .74266 .67791 L .74313 .67777 L .57 .345 .536 r
F
.74359 .64364 m .74281 .67255 L .7432 .67243 L F
.74281 .67255 m .74266 .67791 L .7432 .67243 L F
.74179 .67778 m .7273 .66897 L .74019 .67795 L .673 .758 .914 r
F
.74463 .68734 m .7444 .69122 L .74559 .68719 L .673 .758 .915 r
F
.74442 .67938 m .74461 .68202 L .7454 .68191 L .673 .758 .914 r
F
.74486 .67745 m .74389 .70236 L .74499 .70227 L .66 .418 .542 r
F
.74468 .64355 m .7443 .6722 L .74483 .67214 L F
.74417 .67221 m .74525 .67136 L .74425 .67069 L .673 .758 .914 r
F
.74408 .67371 m .74486 .67214 L .74417 .67221 L F
.74486 .67214 m .74525 .67136 L .74417 .67221 L F
.74483 .67214 m .74423 .67752 L .74486 .67745 L .66 .418 .542 r
F
.7443 .6722 m .74423 .67752 L .74483 .67214 L F
.74427 .68198 m .7441 .68226 L .74425 .68232 L .673 .758 .914 r
F
.74476 .68505 m .74368 .68722 L .74463 .68733 L .673 .758 .915 r
F
.74442 .67938 m .74427 .68198 L .74461 .68202 L .673 .758 .914 r
F
.74377 .67662 m .74458 .67671 L .74461 .68202 L .751 .492 .54 r
F
.74423 .67752 m .74389 .70236 L .74486 .67745 L .66 .418 .542 r
F
.74207 .68341 m .73298 .67213 L .72764 .67464 L .673 .758 .915 r
F
.74476 .68505 m .743 .68312 L .74207 .68341 L F
.743 .68312 m .73298 .67213 L .74207 .68341 L F
.74379 .68288 m .74279 .70269 L .74389 .70236 L .57 .345 .536 r
F
.74376 .67757 m .74356 .68295 L .74379 .68288 L F
.74356 .68295 m .74279 .70269 L .74379 .68288 L F
.74442 .67938 m .74292 .67774 L .74235 .67812 L .673 .758 .914 r
F
.74476 .68505 m .74199 .68672 L .74279 .68704 L .673 .758 .915 r
F
.7439 .67688 m .7436 .67736 L .74386 .67756 L .673 .758 .914 r
F
.74377 .67662 m .74394 .68194 L .74302 .67653 L .751 .492 .54 r
F
.74194 .68372 m .74245 .68338 L .74266 .67791 L .405 .218 .51 r
F
.74032 .67945 m .73827 .67849 L .73953 .67947 L .673 .758 .914 r
F
.74115 .6789 m .73827 .67849 L .74032 .67945 L F
.74136 .64476 m .74124 .6738 L .74151 .67334 L 0 0 .386 r
F
.74408 .67371 m .72705 .66335 L .72291 .66655 L .673 .758 .914 r
F
.74235 .67812 m .73264 .66646 L .7273 .66897 L F
.74208 .67296 m .74153 .67865 L .74182 .67846 L .405 .218 .51 r
F
.74292 .67774 m .73264 .66646 L .74235 .67812 L .673 .758 .914 r
F
.74182 .67846 m .74153 .67865 L .74156 .68396 L .405 .218 .51 r
F
.743 .68312 m .73911 .6705 L .73298 .67213 L .673 .758 .915 r
F
.74476 .68505 m .74391 .68285 L .743 .68312 L F
.74201 .67834 m .74194 .68372 L .74266 .67791 L .405 .218 .51 r
F
.74313 .67777 m .74269 .68322 L .74305 .68311 L .57 .345 .536 r
F
.74391 .68285 m .73911 .6705 L .743 .68312 L .673 .758 .915 r
F
.74313 .67777 m .74305 .68311 L .74376 .67757 L .57 .345 .536 r
F
.74305 .68311 m .74279 .70269 L .74356 .68295 L F
.74305 .68311 m .74356 .68295 L .74376 .67757 L F
.74187 .68659 m .7422 .70659 L .74167 .68643 L .929 .648 .486 r
F
.74194 .68372 m .74166 .70347 L .74245 .68338 L .405 .218 .51 r
F
.74305 .68311 m .74269 .68322 L .74279 .70269 L .57 .345 .536 r
F
.74476 .68505 m .73932 .68426 L .73813 .68517 L .673 .758 .915 r
F
.73932 .68426 m .73388 .68347 L .73736 .68486 L F
.73932 .68426 m .73736 .68486 L .73813 .68517 L F
.73388 .68347 m .72076 .68156 L .73813 .68517 L F
.71976 .67806 m .70003 .6896 L .72205 .68166 L .673 .758 .914 r
F
.72302 .67977 m .71935 .67984 L .7194 .68016 L F
.72302 .67977 m .7194 .68016 L .71998 .68375 L F
.7443 .6722 m .74374 .67226 L .74376 .67757 L .66 .418 .542 r
F
.7443 .6722 m .74376 .67757 L .74423 .67752 L F
.74208 .67296 m .74151 .67334 L .74153 .67865 L .405 .218 .51 r
F
.74194 .68372 m .74156 .68396 L .74166 .70347 L F
.7412 .68459 m .74102 .6849 L .74112 .70449 L 0 0 .386 r
F
.73575 .69412 m .72642 .6961 L .73147 .69842 L .673 .758 .915 r
F
.73567 .68889 m .73319 .69323 L .73709 .69415 L .673 .758 .914 r
F
.73837 .68953 m .72642 .6961 L .73575 .69412 L .673 .758 .915 r
F
.74248 .64398 m .74151 .67334 L .74208 .67296 L .405 .218 .51 r
F
.74131 .68604 m .74154 .706 L .7412 .68585 L .988 .719 .38 r
F
.74124 .6738 m .74122 .67919 L .74151 .67334 L 0 0 .386 r
F
.74125 .68068 m .74141 .68094 L .74154 .706 L .988 .719 .38 r
F
.74153 .67865 m .74112 .70449 L .74166 .70347 L 0 0 .386 r
F
.74122 .67919 m .74112 .70449 L .74153 .67865 L F
.74468 .64355 m .74374 .67226 L .7443 .6722 L .66 .418 .542 r
F
.7489 .67534 m .74814 .67618 L .7504 .67585 L .673 .758 .914 r
F
.7484 .67454 m .74846 .67415 L .74849 .67946 L 0 0 .158 r
F
.74623 .67755 m .76277 .66832 L .75772 .666 L .673 .758 .914 r
F
.7462 .6723 m .74591 .67222 L .74594 .67753 L .809 .541 .532 r
F
.74608 .67757 m .74594 .67753 L .74597 .68284 L F
.7462 .6723 m .74594 .67753 L .74608 .67757 L F
.74619 .6776 m .74732 .67763 L .74623 .67755 L .673 .758 .914 r
F
.74442 .67938 m .74699 .67783 L .74619 .6776 L F
.74699 .67783 m .74732 .67763 L .74619 .6776 L F
.74811 .67521 m .74818 .68047 L .7479 .67552 L .088 0 .422 r
F
.74825 .67371 m .74803 .67323 L .74806 .67854 L .982 .725 .331 r
F
.74825 .68572 m .74811 .68592 L .7479 .67552 L .088 0 .422 r
F
.74817 .67878 m .74806 .67854 L .74808 .68385 L .982 .725 .331 r
F
.74825 .67371 m .74806 .67854 L .74817 .67878 L F
.74732 .67763 m .74756 .67749 L .74623 .67755 L .673 .758 .914 r
F
.74756 .67749 m .76277 .66832 L .7473 .67696 L F
.74756 .67749 m .7473 .67696 L .74623 .67755 L F
.74538 .67218 m .74483 .67214 L .74486 .67745 L .734 .478 .541 r
F
.74825 .67371 m .74817 .67878 L .74824 .67893 L .982 .725 .331 r
F
.74732 .67763 m .76658 .67139 L .76277 .66832 L .673 .758 .914 r
F
.7484 .67454 m .74849 .67946 L .74844 .67978 L 0 0 .158 r
F
.74442 .67938 m .74894 .67775 L .74732 .67763 L .673 .758 .914 r
F
.74844 .67978 m .74839 .68007 L .74834 .67489 L 0 0 .158 r
F
.74834 .67489 m .74839 .68007 L .74837 .6802 L F
.74824 .67893 m .74842 .6793 L .74846 .67415 L .982 .725 .331 r
F
.74846 .67415 m .74842 .6793 L .74849 .67946 L F
.74894 .67775 m .76658 .67139 L .74732 .67763 L .673 .758 .914 r
F
.74894 .67775 m .76887 .67501 L .76658 .67139 L F
.74442 .67938 m .7522 .67799 L .74894 .67775 L F
.7522 .67799 m .76887 .67501 L .74894 .67775 L F
.74538 .67218 m .74531 .67749 L .74591 .67222 L .734 .478 .541 r
F
.74442 .67938 m .74619 .6776 L .74541 .67738 L .673 .758 .914 r
F
.74531 .67749 m .74499 .70227 L .74575 .67752 L .734 .478 .541 r
F
.74531 .67749 m .74575 .67752 L .74591 .67222 L F
.74844 .67978 m .74849 .67946 L .74852 .68478 L 0 0 .158 r
F
.74917 .67929 m .75032 .68007 L .75232 .67923 L .673 .758 .914 r
F
.74839 .68007 m .74844 .68525 L .74837 .6802 L 0 0 .158 r
F
.74848 .68502 m .74852 .68478 L .74863 .70463 L F
.74848 .68502 m .74863 .70463 L .74844 .68525 L F
.74844 .68525 m .74863 .70463 L .7484 .68551 L F
.74852 .68478 m .74819 .70359 L .74863 .70463 L .982 .725 .331 r
F
.74844 .67978 m .74852 .68478 L .74848 .68502 L 0 0 .158 r
F
.74849 .67946 m .74843 .68458 L .74852 .68478 L .982 .725 .331 r
F
.74843 .68458 m .74819 .70359 L .74852 .68478 L F
.7474 .6824 m .76312 .67399 L .75806 .67167 L .673 .758 .915 r
F
.74734 .68127 m .74807 .70612 L .74722 .68136 L .362 .185 .501 r
F
.74745 .67813 m .74704 .68315 L .74739 .68338 L .91 .629 .499 r
F
.74689 .68291 m .74748 .68258 L .7474 .6824 L .673 .758 .915 r
F
.74994 .67728 m .75579 .68656 L .76109 .68406 L .673 .758 .914 r
F
.74748 .68258 m .76312 .67399 L .7474 .6824 L .673 .758 .915 r
F
.74678 .68154 m .7469 .68682 L .74653 .68165 L .519 .306 .53 r
F
.74476 .68505 m .74816 .683 L .74689 .68291 L .673 .758 .915 r
F
.74823 .68416 m .74837 .68445 L .74842 .6793 L .982 .725 .331 r
F
.74818 .68047 m .74825 .68572 L .74808 .68062 L .088 0 .422 r
F
.74824 .67893 m .74808 .68385 L .74823 .68416 L .982 .725 .331 r
F
.74842 .6793 m .74837 .68445 L .74849 .67946 L F
.74837 .68445 m .74819 .70359 L .74843 .68458 L F
.74848 .68502 m .74844 .68525 L .74839 .68007 L 0 0 .158 r
F
.74837 .6802 m .74844 .68525 L .7484 .68551 L F
.74837 .68445 m .74843 .68458 L .74849 .67946 L .982 .725 .331 r
F
.74816 .683 m .76312 .67399 L .74748 .68258 L .673 .758 .915 r
F
.74766 .68297 m .74748 .68258 L .74689 .68291 L F
.74442 .67938 m .749 .6793 L .74906 .67921 L .673 .758 .914 r
F
.74745 .67813 m .74739 .68338 L .74806 .67854 L .91 .629 .499 r
F
.74739 .68338 m .74714 .70277 L .74786 .6837 L F
.74739 .68338 m .74786 .6837 L .74806 .67854 L F
.74828 .67869 m .74906 .67921 L .74959 .67845 L .673 .758 .914 r
F
.74817 .67878 m .74808 .68385 L .74824 .67893 L .982 .725 .331 r
F
.74604 .68248 m .75806 .67167 L .7521 .67026 L .673 .758 .915 r
F
.74476 .68505 m .74681 .68299 L .74604 .68248 L F
.74824 .67893 m .74823 .68416 L .74842 .6793 L .982 .725 .331 r
F
.74875 .68001 m .74903 .6806 L .75002 .68019 L .673 .758 .914 r
F
.74681 .68299 m .75806 .67167 L .74604 .68248 L .673 .758 .915 r
F
.74816 .683 m .74748 .68258 L .74766 .68297 L F
.74597 .68284 m .74499 .70227 L .74607 .70239 L .734 .478 .541 r
F
.74594 .67753 m .74573 .68283 L .74597 .68284 L F
.74573 .68283 m .74499 .70227 L .74597 .68284 L F
.74591 .67222 m .74575 .67752 L .74594 .67753 L F
.74476 .68505 m .74652 .68697 L .74735 .68663 L .673 .758 .915 r
F
.74575 .67752 m .74499 .70227 L .74594 .67753 L .734 .478 .541 r
F
.74531 .67749 m .74486 .67745 L .74499 .70227 L F
.74538 .67218 m .74486 .67745 L .74531 .67749 L F
.74576 .64368 m .74483 .67214 L .74538 .67218 L F
.74576 .64368 m .74538 .67218 L .74591 .67222 L F
.74591 .67222 m .76234 .6627 L .74564 .67214 L .673 .758 .914 r
F
.74634 .67235 m .74648 .67226 L .74591 .67222 L F
.74648 .67226 m .76234 .6627 L .74591 .67222 L F
.74564 .67214 m .76234 .6627 L .75731 .66039 L F
.74495 .67195 m .75731 .66039 L .75138 .65899 L F
.74564 .67214 m .75731 .66039 L .74495 .67195 L F
.74683 .64406 m .74576 .64368 L .74591 .67222 L .809 .541 .532 r
F
.74683 .64406 m .74591 .67222 L .7462 .6723 L F
.74632 .68294 m .74597 .68284 L .74607 .70239 L F
.75196 .68153 m .75579 .68656 L .74994 .67728 L .673 .758 .914 r
F
.74764 .68332 m .75368 .68183 L .76312 .67399 L .673 .758 .915 r
F
.74476 .68505 m .74872 .68362 L .74764 .68332 L F
.74757 .68134 m .75212 .68712 L .74759 .68131 L .673 .758 .914 r
F
.74872 .68362 m .75368 .68183 L .74764 .68332 L .673 .758 .915 r
F
.74425 .67069 m .75138 .65899 L .74495 .6586 L .673 .758 .914 r
F
.74525 .67136 m .75138 .65899 L .74425 .67069 L F
.74541 .67738 m .75772 .666 L .75176 .66459 L F
.74619 .6776 m .75772 .666 L .74541 .67738 L F
.74646 .67238 m .74639 .67766 L .74698 .67253 L .809 .541 .532 r
F
.74639 .67766 m .74632 .68294 L .74665 .67773 L F
.74637 .68171 m .74736 .70668 L .7462 .68179 L .519 .306 .53 r
F
.74632 .68294 m .74607 .70239 L .74704 .68315 L .809 .541 .532 r
F
.74872 .68362 m .75085 .68396 L .75368 .68183 L .673 .758 .915 r
F
.75027 .68406 m .75085 .68396 L .74872 .68362 L F
.74859 .68079 m .76569 .68657 L .75002 .68019 L .673 .758 .914 r
F
.75085 .68396 m .76921 .68068 L .75368 .68183 L .673 .758 .915 r
F
.75368 .68183 m .76692 .67706 L .7636 .67438 L F
.75368 .68183 m .7636 .67438 L .76312 .67399 L F
.74476 .68505 m .74862 .68498 L .74835 .68441 L F
.74862 .68498 m .76983 .68459 L .74835 .68441 L F
.74823 .68416 m .74819 .70359 L .74837 .68445 L .982 .725 .331 r
F
.74745 .67813 m .74701 .67784 L .74704 .68315 L .91 .629 .499 r
F
.74739 .68338 m .74704 .68315 L .74714 .70277 L F
.74835 .68557 m .76603 .69224 L .76875 .68853 L .673 .758 .915 r
F
.75212 .68712 m .75619 .69229 L .75008 .68282 L .673 .758 .914 r
F
.74796 .68613 m .76603 .69224 L .74835 .68557 L .673 .758 .915 r
F
.74807 .68746 m .75285 .69392 L .74813 .6871 L F
.747 .68751 m .75285 .69392 L .74754 .68674 L F
.75285 .69392 m .75653 .69796 L .75023 .68837 L F
.74796 .68614 m .7485 .70544 L .74807 .70612 L .088 0 .422 r
F
.74805 .686 m .7485 .70544 L .74796 .68614 L F
.74823 .68416 m .74808 .68385 L .74819 .70359 L .982 .725 .331 r
F
.74775 .68687 m .76186 .69545 L .74941 .68662 L .673 .758 .915 r
F
.35382 .60061 m .37166 .58313 L .34899 .59619 L .654 .726 .902 r
F
.35382 .60061 m .38131 .59198 L .37166 .58313 L F
.65388 .71346 m .65162 .69608 L .65195 .70175 L .822 .619 .066 r
F
.62883 .71392 m .65388 .71346 L .65195 .70175 L .673 .758 .914 r
F
.65421 .71913 m .65388 .71346 L .65195 .70175 L .822 .619 .066 r
F
0 g
.65233 .71916 m
.6536 .71447 L
s
.34933 .58898 m .3592 .56896 L .34299 .58547 L .654 .726 .902 r
F
.34933 .58898 m .37188 .57599 L .3592 .56896 L F
.27281 .5863 m .23615 .58889 L .26623 .59567 L F
.3927 .84378 m .37055 .844 L .38653 .84872 L .683 .77 .917 r
F
.41766 .94786 m .41792 .94409 L .42767 .94389 L .67 .444 .569 r
F
.40797 .94651 m .41792 .94409 L .41766 .94786 L .733 .498 .573 r
F
.40797 .94651 m .40823 .94275 L .41792 .94409 L F
.3872 .602 m .40882 .58335 L .38131 .59198 L .654 .726 .902 r
F
.3872 .602 m .41765 .59838 L .40882 .58335 L F
.60305 .72398 m .62916 .71959 L .60411 .72005 L .673 .758 .915 r
F
.39186 .83472 m .37903 .82756 L .36983 .83495 L .683 .77 .917 r
F
.39974 .83078 m .37903 .82756 L .39186 .83472 L F
.41823 .93644 m .41792 .94398 L .42762 .94378 L .644 .733 .913 r
F
.127 .923 .03 r
.42264 .93383 m
.42266 .92866 L
s
.42271 .91434 m
.42283 .8753 L
s
.42283 .8753 m
.42319 .91449 L
s
.42332 .92853 m
.42338 .93471 L
s
.4118 .93555 m .41792 .94398 L .41823 .93644 L .644 .733 .913 r
F
.4118 .93555 m .40828 .94264 L .41792 .94398 L F
.71777 .60321 m .68441 .60111 L .7144 .60789 L .654 .726 .902 r
F
.7749 .61106 m .79966 .59743 L .77202 .60605 L F
.7749 .61106 m .80542 .60745 L .79966 .59743 L F
.55454 .70572 m .52857 .71009 L .5535 .70963 L .673 .758 .914 r
F
.62883 .71392 m .65195 .70175 L .62754 .70611 L F
.60379 .71438 m .62883 .71392 L .62754 .70611 L F
.25956 .71081 m .27085 .71433 L .27114 .72 L .93 .657 .5 r
F
.25956 .71081 m .25927 .70514 L .27085 .71433 L F
.28127 .69717 m .27085 .71433 L .28899 .7033 L .673 .757 .914 r
F
.28127 .69717 m .25927 .70514 L .27085 .71433 L F
0 g
.27085 .71433 m
.27635 .71683 L
s
.27353 .57915 m .24687 .56773 L .23707 .58172 L .654 .726 .902 r
F
.24601 .57483 m .23661 .58162 L .23615 .58889 L .06 0 .389 r
F
.24601 .57483 m .24647 .56756 L .23661 .58162 L F
0 g
.23291 .59705 m
.23661 .58162 L
s
.399 .94371 m .40823 .94275 L .40797 .94651 L .792 .552 .573 r
F
.127 .923 .03 r
.39032 1.10044 m
.40259 2.01454 L
s
.399 .94371 m .39926 .93995 L .40823 .94275 L .792 .552 .573 r
F
0 g
.40823 .94275 m
.41792 .94409 L
s
.42742 .94765 m .42767 .94389 L .43682 .94215 L .598 .382 .559 r
F
.41766 .94786 m .42767 .94389 L .42742 .94765 L .67 .444 .569 r
F
0 g
.41792 .94409 m
.42767 .94389 L
s
.40585 .93369 m .40828 .94264 L .4118 .93555 L .644 .733 .913 r
F
.127 .923 .03 r
.38833 .84735 m
.38872 .87682 L
s
.40585 .93369 m .39936 .93985 L .40828 .94264 L .644 .733 .913 r
F
.43948 .57504 m .45899 .57837 L .45856 .58564 L .857 .601 .55 r
F
.43948 .57504 m .43992 .56777 L .45899 .57837 L F
0 g
.45899 .57837 m
.4641 .58002 L
s
.4247 .9363 m .42762 .94378 L .43673 .94205 L .644 .733 .913 r
F
.41823 .93644 m .42762 .94378 L .4247 .9363 L F
.64768 .60383 m .62907 .58596 L .62866 .59323 L .858 .601 .55 r
F
.64727 .6111 m .64768 .60383 L .62866 .59323 L F
0 g
.64768 .60383 m
.64981 .6058 L
s
.56446 .61058 m .5572 .59075 L .53427 .59559 L .654 .726 .902 r
F
.58073 .61006 m .5572 .59075 L .56446 .61058 L F
.79603 .71623 m .80818 .70093 L .80853 .7066 L .394 .241 .552 r
F
.77895 .70584 m .79603 .71623 L .80853 .7066 L .673 .758 .915 r
F
.76829 .71085 m .79603 .71623 L .77895 .70584 L F
0 g
.78004 .72373 m
.79603 .71623 L
s
.48945 .58112 m .50477 .60344 L .50561 .58334 L .654 .726 .902 r
F
.48945 .58112 m .48054 .60012 L .50477 .60344 L F
0 g
.50477 .60344 m
.51255 .60319 L
s
.71817 .59594 m .69154 .58448 L .68481 .59384 L .654 .726 .902 r
F
.72335 .59204 m .69154 .58448 L .71817 .59594 L F
.59687 .61227 m .58162 .58996 L .58073 .61006 L F
.59687 .61227 m .60586 .59329 L .58162 .58996 L F
.72385 .58485 m .70251 .56955 L .6922 .57732 L F
.73046 .58201 m .70251 .56955 L .72385 .58485 L F
.46286 .55457 m .45924 .57812 L .47552 .56161 L F
.46286 .55457 m .44026 .56757 L .45924 .57812 L F
.41765 .59838 m .41809 .59111 L .40926 .57608 L .99 .743 .461 r
F
0 g
.41809 .59111 m
.42069 .60687 L
s
.77241 .59878 m .79052 .58131 L .76764 .59436 L .654 .726 .902 r
F
.77241 .59878 m .80005 .59016 L .79052 .58131 L F
.76792 .58716 m .7781 .56713 L .76163 .58364 L F
.76792 .58716 m .79068 .57417 L .7781 .56713 L F
.69154 .58448 m .65481 .58706 L .68481 .59384 L F
.53066 .70226 m .50365 .71055 L .52857 .71009 L .673 .758 .914 r
F
.55454 .70572 m .53066 .70226 L .52857 .71009 L F
.60379 .71438 m .62754 .70611 L .60314 .71048 L F
.43704 .82879 m .43347 .81605 L .42815 .82705 L .683 .77 .917 r
F
.43704 .82879 m .44681 .81866 L .43347 .81605 L F
.46793 .83881 m .45884 .82778 L .45933 .83235 L .932 .647 .478 r
F
0 g
.46793 .83881 m
.47315 .84659 L
s
.127 .923 .03 r
.45999 1.00832 m
.46161 .80492 L
s
.46328 .80425 m
.46468 1.14152 L
s
.8058 .60017 m .82771 .58152 L .80005 .59016 L .654 .726 .902 r
F
.8058 .60017 m .83633 .59656 L .82771 .58152 L F
.4457 .84095 m .44793 .82764 L .4381 .83782 L .683 .77 .917 r
F
.4457 .84095 m .45933 .83235 L .44793 .82764 L F
.41741 .95162 m .41766 .94786 L .42742 .94765 L .67 .444 .569 r
F
.40772 .95028 m .41766 .94786 L .41741 .95162 L .733 .498 .573 r
F
.40772 .95028 m .40797 .94651 L .41766 .94786 L F
.41797 .94028 m .41766 .94786 L .42742 .94765 L .644 .733 .913 r
F
.41151 .93938 m .41766 .94786 L .41797 .94028 L F
.41151 .93938 m .40797 .94651 L .41766 .94786 L F
.31225 .69457 m .29918 .70792 L .31114 .71073 L .673 .757 .914 r
F
.67835 .70899 m .68944 .71252 L .68978 .71818 L .932 .657 .495 r
F
.67835 .70899 m .67802 .70332 L .68944 .71252 L F
.70014 .69535 m .68944 .71252 L .70775 .70148 L .673 .758 .914 r
F
.70014 .69535 m .67802 .70332 L .68944 .71252 L F
0 g
.68944 .71252 m
.69498 .71505 L
s
.53066 .70226 m .50676 .6988 L .50365 .71055 L .673 .758 .914 r
F
.50672 .70441 m .50327 .71056 L .50359 .71622 L 0 0 .324 r
F
0 g
.50398 .71473 m
.50423 .71621 L
s
.50672 .70441 m .5064 .69875 L .50327 .71056 L 0 0 .324 r
F
.57874 .71484 m .573 .70033 L .56688 .70195 L .673 .758 .914 r
F
.65421 .71913 m .65195 .70175 L .65228 .70741 L .822 .619 .066 r
F
.62916 .71959 m .65421 .71913 L .65228 .70741 L .673 .758 .915 r
F
0 g
.65101 .73092 m
.65421 .71913 L
s
.6922 .57732 m .66569 .5659 L .65566 .57989 L .654 .726 .902 r
F
.39221 .83921 m .37932 .83202 L .37007 .83944 L .683 .77 .917 r
F
.40014 .83525 m .37932 .83202 L .39221 .83921 L F
0 0 0 r
2.5 Mabswid
.3742 .7154 Mdot
.127 .923 .03 r
.5 Mabswid
.3742 .7154 m
.37441 .79181 L
s
.58073 .61006 m .58162 .58996 L .5572 .59075 L .654 .726 .902 r
F
.37932 .83202 m .36959 .83488 L .37007 .83944 L .404 .26 .569 r
F
.37932 .83202 m .37883 .82746 L .36959 .83488 L F
0 g
.36362 .84325 m
.36959 .83488 L
s
.66488 .573 m .65521 .57979 L .65481 .58706 L .078 0 .4 r
F
.66488 .573 m .66529 .56573 L .65521 .57979 L F
0 g
.65128 .59522 m
.65521 .57979 L
s
.31183 .58384 m .29685 .56569 L .28372 .57138 L .654 .726 .902 r
F
.31942 .58223 m .29685 .56569 L .31183 .58384 L F
.39875 .94747 m .40797 .94651 L .40772 .95028 L .792 .552 .573 r
F
.39875 .94747 m .399 .94371 L .40797 .94651 L F
.40553 .93751 m .40797 .94651 L .41151 .93938 L .644 .733 .913 r
F
.127 .923 .03 r
.38872 .87682 m
.38877 .88032 L
s
.40553 .93751 m .399 .94371 L .40797 .94651 L .644 .733 .913 r
F
0 g
.40797 .94651 m
.41766 .94786 L
s
.34299 .58547 m .34431 .56417 L .33555 .58308 L .654 .726 .902 r
F
.34299 .58547 m .3592 .56896 L .34431 .56417 L F
.42742 .94765 m .43682 .94215 L .43657 .94592 L .598 .382 .559 r
F
.42716 .95142 m .42742 .94765 L .43657 .94592 L F
.41741 .95162 m .42742 .94765 L .42716 .95142 L .67 .444 .569 r
F
.42448 .94014 m .42742 .94765 L .43657 .94592 L .644 .733 .913 r
F
.127 .923 .03 r
.4385 .84955 m
.43852 .84601 L
s
.41797 .94028 m .42742 .94765 L .42448 .94014 L .644 .733 .913 r
F
0 g
.41766 .94786 m
.42742 .94765 L
s
.60269 .70483 m .62238 .69331 L .60039 .70124 L .673 .758 .914 r
F
.60269 .70483 m .62697 .70049 L .62238 .69331 L F
.83633 .59656 m .83671 .58929 L .82809 .57425 L .991 .743 .451 r
F
0 g
.83671 .58929 m
.83907 .60505 L
s
.127 .923 .03 r
.40269 8.8272 m
.60762 3.70624 L
s
.60762 3.70624 m
.69471 1.52981 L
s
.47449 .57631 m .48054 .60012 L .48945 .58112 L .654 .726 .902 r
F
.47449 .57631 m .45813 .59291 L .48054 .60012 L F
0 g
.48054 .60012 m
.50477 .60344 L
s
.39137 .93964 m .39926 .93995 L .399 .94371 L .855 .609 .566 r
F
.127 .923 .03 r
.35449 .94855 m
.39565 8.82811 L
s
.35404 .86367 m
.35449 .94855 L
s
.39137 .93964 m .39162 .93587 L .39926 .93995 L .855 .609 .566 r
F
0 g
.39926 .93995 m
.40205 .94082 L
s
.55474 .71137 m .52864 .71576 L .55369 .7153 L .673 .758 .914 r
F
.62916 .71959 m .65228 .70741 L .62787 .71178 L .673 .758 .915 r
F
.60411 .72005 m .62916 .71959 L .62787 .71178 L F
.28157 .70284 m .27114 .72 L .28929 .70897 L .673 .758 .914 r
F
.28157 .70284 m .25956 .71081 L .27114 .72 L F
0 g
.27114 .72 m
.28642 .72693 L
s
.40079 .93098 m .39936 .93985 L .40585 .93369 L .644 .733 .913 r
F
.40079 .93098 m .39176 .9358 L .39936 .93985 L F
.31853 .70164 m .31144 .71639 L .32437 .71719 L .673 .758 .914 r
F
.43657 .94592 m .43682 .94215 L .44476 .939 L .502 .302 .541 r
F
0 g
.431 .94326 m
.43682 .94215 L
s
.127 .923 .03 r
.44421 4.68779 m
.48402 1.10752 L
s
.48402 1.10752 m
.48635 .89807 L
s
.43078 .93515 m .43673 .94205 L .44463 .93891 L .644 .733 .913 r
F
.4247 .9363 m .43673 .94205 L .43078 .93515 L F
.29913 .60504 m .27235 .59357 L .26576 .60294 L .654 .726 .902 r
F
.30425 .60114 m .27235 .59357 L .29913 .60504 L F
.38949 .70275 m .38919 .69709 L .39718 .68598 L .167 .072 .494 r
F
0 g
.38216 .70256 m
.38919 .69709 L
s
.30471 .59387 m .28304 .5785 L .27281 .5863 L .654 .726 .902 r
F
.3113 .59102 m .28304 .5785 L .30471 .59387 L F
.35337 .60788 m .37122 .59041 L .34854 .60346 L F
.35337 .60788 m .38086 .59925 L .37122 .59041 L F
.39974 .83078 m .39085 .82164 L .37903 .82756 L .683 .77 .917 r
F
.40884 .82808 m .39085 .82164 L .39974 .83078 L F
.3676 .68983 m .38887 .69698 L .39682 .68593 L .673 .757 .914 r
F
.35941 .69623 m .38887 .69698 L .3676 .68983 L F
.34899 .59619 m .35892 .57606 L .34262 .59265 L .654 .726 .902 r
F
.34899 .59619 m .37166 .58313 L .35892 .57606 L F
.27235 .59357 m .23568 .59616 L .26576 .60294 L F
.41772 .94404 m .41741 .95162 L .42716 .95142 L .644 .733 .913 r
F
.41126 .94315 m .41741 .95162 L .41772 .94404 L F
.41126 .94315 m .40772 .95028 L .41741 .95162 L F
.73113 .69275 m .71786 .7061 L .72977 .70891 L .673 .758 .914 r
F
.43762 .83325 m .43404 .82045 L .42868 .8315 L .683 .77 .917 r
F
.43762 .83325 m .44745 .82307 L .43404 .82045 L F
.127 .923 .03 r
.4962 8.79943 m
.60473 2.63091 L
s
0 0 0 r
2.5 Mabswid
.63838 .71853 Mdot
.127 .923 .03 r
.5 Mabswid
.40101 8.82715 m
.59528 2.19089 L
s
.33151 .7014 m .33738 .71592 L .3496 .71267 L .673 .758 .914 r
F
.33732 .69411 m .3493 .707 L .35988 .702 L .673 .757 .914 r
F
.38676 .60927 m .40838 .59062 L .38086 .59925 L .654 .726 .902 r
F
.38676 .60927 m .41721 .60566 L .40838 .59062 L F
.53073 .70789 m .50359 .71622 L .52864 .71576 L .673 .758 .914 r
F
.55474 .71137 m .53073 .70789 L .52864 .71576 L F
.60411 .72005 m .62787 .71178 L .60346 .71614 L .673 .758 .915 r
F
.73046 .58201 m .71574 .56386 L .70251 .56955 L .654 .726 .902 r
F
.73808 .58041 m .71574 .56386 L .73046 .58201 L F
.76163 .58364 m .76326 .56234 L .75421 .58125 L F
.76163 .58364 m .7781 .56713 L .76326 .56234 L F
.42815 .82705 m .41904 .81568 L .41853 .82681 L .683 .77 .917 r
F
.42815 .82705 m .43347 .81605 L .41904 .81568 L F
.40528 .94128 m .40772 .95028 L .41126 .94315 L .644 .733 .913 r
F
.127 .923 .03 r
.38877 .88032 m
.38882 .88383 L
s
.40528 .94128 m .39875 .94747 L .40772 .95028 L .644 .733 .913 r
F
0 g
.40772 .95028 m
.41741 .95162 L
s
.3927 .84378 m .3798 .83659 L .37055 .844 L .683 .77 .917 r
F
.127 .923 .03 r
.37441 .79181 m
.37443 .80028 L
s
.40062 .83982 m .3798 .83659 L .3927 .84378 L .683 .77 .917 r
F
.3798 .83659 m .37007 .83944 L .37055 .844 L .404 .26 .569 r
F
0 g
.36458 .85238 m
.37055 .844 L
s
.3798 .83659 m .37932 .83202 L .37007 .83944 L .404 .26 .569 r
F
0 g
.3641 .84782 m
.37007 .83944 L
s
.127 .923 .03 r
.37443 .80028 m
.37458 .85728 L
s
.42716 .95142 m .43657 .94592 L .43632 .94968 L .598 .382 .559 r
F
.42422 .94391 m .42716 .95142 L .43632 .94968 L .644 .733 .913 r
F
.127 .923 .03 r
.43848 .85308 m
.4385 .84955 L
s
.41772 .94404 m .42716 .95142 L .42422 .94391 L .644 .733 .913 r
F
0 g
.41741 .95162 m
.42716 .95142 L
s
.55721 .70204 m .53066 .70226 L .55454 .70572 L .673 .758 .914 r
F
.31942 .58223 m .31203 .56248 L .29685 .56569 L .654 .726 .902 r
F
.32751 .58197 m .31203 .56248 L .31942 .58223 L F
.33555 .58308 m .32821 .56196 L .32751 .58197 L F
.33555 .58308 m .34431 .56417 L .32821 .56196 L F
0 g
.5144 .60415 m
.53427 .59559 L
s
.27281 .5863 m .24601 .57483 L .23615 .58889 L .654 .726 .902 r
F
.24554 .5821 m .23615 .58889 L .23568 .59616 L .06 0 .389 r
F
.24554 .5821 m .24601 .57483 L .23615 .58889 L F
0 g
.23245 .60431 m
.23615 .58889 L
s
.31254 .70024 m .31144 .71639 L .31853 .70164 L .673 .758 .914 r
F
.31254 .70024 m .29948 .71359 L .31144 .71639 L F
.43904 .58231 m .45856 .58564 L .45813 .59291 L .857 .601 .55 r
F
.43904 .58231 m .43948 .57504 L .45856 .58564 L F
.4622 .56197 m .45856 .58564 L .47493 .56904 L .654 .726 .902 r
F
.4622 .56197 m .43948 .57504 L .45856 .58564 L F
0 g
.45856 .58564 m
.46367 .58728 L
s
.70048 .70102 m .68978 .71818 L .70809 .70715 L .673 .758 .915 r
F
.70048 .70102 m .67835 .70899 L .68978 .71818 L F
0 g
.68978 .71818 m
.70493 .72511 L
s
.73743 .69982 m .73011 .71458 L .74301 .71537 L .673 .758 .915 r
F
.64727 .6111 m .62866 .59323 L .62825 .6005 L .858 .601 .55 r
F
0 g
.64727 .6111 m
.6494 .61307 L
s
.39111 .9434 m .399 .94371 L .39875 .94747 L .855 .609 .566 r
F
.39111 .9434 m .39137 .93964 L .399 .94371 L F
.40044 .9348 m .399 .94371 L .40553 .93751 L .644 .733 .913 r
F
.40044 .9348 m .39137 .93964 L .399 .94371 L F
0 g
.399 .94371 m
.40179 .94458 L
s
.127 .923 .03 r
.38624 .87759 m
.38625 .8811 L
s
.37458 .85728 m
.37459 .8608 L
s
.50704 .71008 m .50359 .71622 L .5039 .72189 L 0 0 .324 r
F
0 g
.5043 .7204 m
.50455 .72188 L
s
.53073 .70789 m .50672 .70441 L .50359 .71622 L .673 .758 .914 r
F
.50704 .71008 m .50672 .70441 L .50359 .71622 L 0 0 .324 r
F
.71777 .60321 m .69113 .59175 L .68441 .60111 L .654 .726 .902 r
F
.72295 .59931 m .69113 .59175 L .71777 .60321 L F
.57906 .72051 m .5863 .70576 L .57984 .70536 L .673 .758 .915 r
F
.80818 .70093 m .80784 .69527 L .81601 .68416 L .181 .084 .501 r
F
0 g
.80073 .70074 m
.80784 .69527 L
s
.28372 .57138 m .24687 .56773 L .27353 .57915 L .654 .726 .902 r
F
.41765 .59838 m .40926 .57608 L .40882 .58335 L .99 .743 .461 r
F
.41721 .60566 m .41765 .59838 L .40882 .58335 L F
0 g
.41765 .59838 m
.42025 .61414 L
s
.43657 .94592 m .44476 .939 L .4445 .94276 L .502 .302 .541 r
F
.43632 .94968 m .43657 .94592 L .4445 .94276 L F
.43058 .93898 m .43657 .94592 L .4445 .94276 L .644 .733 .913 r
F
.42448 .94014 m .43657 .94592 L .43058 .93898 L F
0 g
.43075 .94702 m
.43657 .94592 L
s
.72335 .59204 m .7019 .57667 L .69154 .58448 L .654 .726 .902 r
F
.73 .58919 m .7019 .57667 L .72335 .59204 L F
.77202 .60605 m .79014 .58858 L .76725 .60163 L F
.77202 .60605 m .79966 .59743 L .79014 .58858 L F
.78639 .68801 m .80752 .69516 L .81565 .68411 L .673 .758 .914 r
F
.77809 .69441 m .80752 .69516 L .78639 .68801 L F
.32751 .58197 m .32821 .56196 L .31203 .56248 L .654 .726 .902 r
F
.76764 .59436 m .77787 .57423 L .76132 .59083 L F
.76764 .59436 m .79052 .58131 L .77787 .57423 L F
.69113 .59175 m .6544 .59433 L .68441 .60111 L F
.45884 .82778 m .45835 .82322 L .44696 .81851 L .859 .591 .532 r
F
0 g
.45835 .82322 m
.46695 .82969 L
s
.38148 .5848 m .39446 .56299 L .37188 .57599 L .654 .726 .902 r
F
.38148 .5848 m .40885 .57621 L .39446 .56299 L F
.40884 .82808 m .4045 .81759 L .39085 .82164 L .683 .77 .917 r
F
.41853 .82681 m .4045 .81759 L .40884 .82808 L F
.7504 .69958 m .75604 .7141 L .76829 .71085 L .673 .758 .915 r
F
.75619 .69229 m .76795 .70518 L .77861 .70018 L .673 .758 .914 r
F
.80542 .60745 m .82733 .58879 L .79966 .59743 L .654 .726 .902 r
F
.80542 .60745 m .83595 .60383 L .82733 .58879 L F
.60314 .71048 m .62293 .69889 L .60083 .70687 L .673 .758 .914 r
F
.60314 .71048 m .62754 .70611 L .62293 .69889 L F
.30715 .69225 m .29918 .70792 L .31225 .69457 L .673 .757 .914 r
F
.30715 .69225 m .28899 .7033 L .29918 .70792 L F
.41853 .82681 m .41904 .81568 L .4045 .81759 L .683 .77 .917 r
F
.40014 .83525 m .3912 .82607 L .37932 .83202 L F
.40928 .83254 m .3912 .82607 L .40014 .83525 L F
.55506 .71703 m .52896 .72143 L .55401 .72097 L .673 .758 .915 r
F
.4381 .83782 m .43452 .82501 L .42917 .83607 L .683 .77 .917 r
F
.4381 .83782 m .44793 .82764 L .43452 .82501 L F
.34223 .68588 m .35941 .69623 L .3676 .68983 L .673 .757 .914 r
F
.62697 .70049 m .64437 .68537 L .62238 .69331 L .673 .758 .914 r
F
.62697 .70049 m .65126 .69614 L .64437 .68537 L F
.57693 .82009 m .57643 .81553 L .59104 .81361 L .673 .454 .58 r
F
.56244 .81972 m .57643 .81553 L .57693 .82009 L .733 .498 .572 r
F
.127 .923 .03 r
.4947 8.79995 m
.56817 .94297 L
s
.56934 .81765 m
.56984 .76472 L
s
.56244 .81972 m .56194 .81516 L .57643 .81553 L .733 .498 .572 r
F
.38949 .70275 m .39718 .68598 L .39749 .69165 L .167 .072 .494 r
F
.3898 .70842 m .38949 .70275 L .39749 .69165 L F
.36812 .69557 m .38949 .70275 L .39749 .69165 L .673 .757 .914 r
F
.35988 .702 m .38949 .70275 L .36812 .69557 L F
0 g
.38246 .70823 m
.38949 .70275 L
s
.73808 .58041 m .73097 .56065 L .71574 .56386 L .654 .726 .902 r
F
.74618 .58015 m .73097 .56065 L .73808 .58041 L F
.127 .923 .03 r
.42262 .94018 m
.42263 .93847 L
s
.75421 .58125 m .74719 .56013 L .74618 .58015 L .654 .726 .902 r
F
.75421 .58125 m .76326 .56234 L .74719 .56013 L F
.57702 .80423 m .57644 .81536 L .59097 .81345 L .683 .77 .917 r
F
.127 .923 .03 r
.65408 .79903 m
.65419 .79576 L
s
.56741 .80398 m .57644 .81536 L .57702 .80423 L .683 .77 .917 r
F
.56741 .80398 m .56202 .81499 L .57644 .81536 L F
.62866 .59323 m .62907 .58596 L .60668 .57875 L .793 .542 .558 r
F
0 g
.62907 .58596 m
.64808 .59656 L
s
.69154 .58448 m .66488 .573 L .65481 .58706 L .654 .726 .902 r
F
.66448 .58027 m .65481 .58706 L .6544 .59433 L .078 0 .4 r
F
.66448 .58027 m .66488 .573 L .65481 .58706 L F
0 g
.65161 .59961 m
.65481 .58706 L
s
.73147 .69842 m .73011 .71458 L .73743 .69982 L .673 .758 .915 r
F
.73147 .69842 m .7182 .71177 L .73011 .71458 L F
.50718 .45997 m .50877 .51822 L .50718 .51843 L .641 .402 .54 r
F
.50718 .45997 m .50876 .45976 L .50877 .51822 L F
.50561 .45971 m .50718 .45997 L .50718 .51843 L .751 .491 .539 r
F
0 g
.50718 .45997 m
.50718 .45997 L
s
.127 .923 .03 r
.42341 .93822 m
.42343 .94017 L
s
0 0 0 r
2.5 Mabswid
.31997 .71433 Mdot
.59153 .81817 m .59104 .81361 L .60477 .80953 L .607 .406 .584 r
F
.127 .923 .03 r
.5 Mabswid
.65303 .83253 m
.65408 .79903 L
s
.57693 .82009 m .59104 .81361 L .59153 .81817 L .673 .454 .58 r
F
0 g
.57643 .81553 m
.59104 .81361 L
s
.3113 .59102 m .29624 .57278 L .28304 .5785 L .654 .726 .902 r
F
.31893 .5894 m .29624 .57278 L .3113 .59102 L F
.33762 .69978 m .3496 .71267 L .36018 .70766 L .673 .758 .914 r
F
.33151 .7014 m .3496 .71267 L .33762 .69978 L F
.50876 .45976 m .50979 .51779 L .50877 .51822 L .517 .303 .528 r
F
.50876 .45976 m .50978 .45933 L .50979 .51779 L F
0 g
.50718 .45997 m
.50876 .45976 L
s
.34262 .59265 m .34394 .57125 L .33514 .59025 L .654 .726 .902 r
F
.34262 .59265 m .35892 .57606 L .34394 .57125 L F
.50561 .45971 m .50718 .51843 L .50562 .51817 L .751 .491 .539 r
F
.50463 .45923 m .50561 .45971 L .50562 .51817 L .845 .571 .524 r
F
0 g
.50561 .45971 m
.50718 .45997 L
s
.42868 .8315 m .41953 .82008 L .41902 .83126 L .683 .77 .917 r
F
.42868 .8315 m .43404 .82045 L .41953 .82008 L F
.70251 .56955 m .66569 .5659 L .6922 .57732 L .654 .726 .902 r
F
.58671 .80296 m .59097 .81345 L .60464 .8094 L .683 .77 .917 r
F
.127 .923 .03 r
.63663 .77822 m
.63838 .71853 L
s
.57702 .80423 m .59097 .81345 L .58671 .80296 L .683 .77 .917 r
F
.60039 .70124 m .61478 .6872 L .59659 .69819 L .673 .758 .914 r
F
.60039 .70124 m .62238 .69331 L .61478 .6872 L F
.83633 .59656 m .82809 .57425 L .82771 .58152 L .991 .743 .451 r
F
.83595 .60383 m .83633 .59656 L .82771 .58152 L F
0 g
.83633 .59656 m
.83869 .61232 L
s
.40019 .93856 m .39875 .94747 L .40528 .94128 L .644 .733 .913 r
F
.40019 .93856 m .39111 .9434 L .39875 .94747 L F
0 g
.39875 .94747 m
.40772 .95028 L
s
.127 .923 .03 r
.37459 .8608 m
.3746 .86433 L
s
.38625 .8811 m
.38625 .88462 L
s
.53105 .71356 m .5039 .72189 L .52896 .72143 L .673 .758 .915 r
F
.55506 .71703 m .53105 .71356 L .52896 .72143 L F
.74618 .58015 m .74719 .56013 L .73097 .56065 L .654 .726 .902 r
F
.38559 .93458 m .39162 .93587 L .39137 .93964 L .924 .676 .545 r
F
.127 .923 .03 r
.39002 1.07779 m
.39032 1.10044 L
s
.38798 .92553 m
.38811 .93512 L
s
.38559 .93458 m .38584 .93081 L .39162 .93587 L .924 .676 .545 r
F
0 g
.39162 .93587 m
.39502 .93769 L
s
.43632 .94968 m .4445 .94276 L .44425 .94652 L .502 .302 .541 r
F
.43033 .94275 m .43632 .94968 L .44425 .94652 L .644 .733 .913 r
F
.42422 .94391 m .43632 .94968 L .43033 .94275 L F
0 g
.42716 .95142 m
.43632 .94968 L
s
.39695 .92763 m .39176 .9358 L .40079 .93098 L .644 .733 .913 r
F
.39695 .92763 m .38601 .93077 L .39176 .9358 L F
.80016 .58297 m .81347 .56116 L .79068 .57417 L .654 .726 .902 r
F
.80016 .58297 m .82768 .57438 L .81347 .56116 L F
.50978 .45933 m .5105 .51722 L .50979 .51779 L .358 .18 .498 r
F
.50978 .45933 m .51049 .45876 L .5105 .51722 L F
0 g
.50876 .45976 m
.50978 .45933 L
s
.4445 .94276 m .44476 .939 L .45093 .93464 L .354 .181 .502 r
F
0 g
.43903 .94127 m
.44476 .939 L
s
.50463 .45923 m .50562 .51817 L .50463 .51769 L .845 .571 .524 r
F
.50397 .45864 m .50463 .45923 L .50463 .51769 L .929 .648 .488 r
F
0 g
.50463 .45923 m
.50561 .45971 L
s
.43604 .93306 m .44463 .93891 L .45077 .93457 L .644 .733 .913 r
F
.43078 .93515 m .44463 .93891 L .43604 .93306 L F
.127 .923 .03 r
.29908 2.30623 m
.32497 3.16549 L
s
.32497 3.16549 m
.34373 3.78797 L
s
.34373 3.78797 m
.48167 8.36537 L
s
.48167 8.36537 m
.49478 8.80031 L
s
.2476 .59826 m
.24896 .67452 L
s
.31873 4.60457 m
.33236 5.37227 L
s
.33236 5.37227 m
.39368 8.82643 L
s
.55743 .70767 m .53073 .70789 L .55474 .71137 L .673 .758 .914 r
F
.72608 .69043 m .71786 .7061 L .73113 .69275 L F
.72608 .69043 m .70775 .70148 L .71786 .7061 L F
.30425 .60114 m .28258 .58577 L .27235 .59357 L .654 .726 .902 r
F
.31085 .59829 m .28258 .58577 L .30425 .60114 L F
.45884 .82778 m .44696 .81851 L .44745 .82307 L .859 .591 .532 r
F
.45933 .83235 m .45884 .82778 L .44745 .82307 L F
0 g
.45884 .82778 m
.46744 .83425 L
s
.34854 .60346 m .35847 .58333 L .34217 .59993 L .654 .726 .902 r
F
.34854 .60346 m .37122 .59041 L .35847 .58333 L F
.51049 .45876 m .51093 .51654 L .5105 .51722 L .076 0 .415 r
F
.51049 .45876 m .51092 .45807 L .51093 .51654 L F
0 g
.50978 .45933 m
.51049 .45876 L
s
.76109 .68406 m .77809 .69441 L .78639 .68801 L .673 .758 .914 r
F
.50397 .45864 m .50463 .51769 L .50397 .5171 L .929 .648 .488 r
F
.50359 .45794 m .50397 .45864 L .50397 .5171 L .989 .72 .386 r
F
0 g
.50397 .45864 m
.50463 .45923 L
s
.40928 .83254 m .40492 .822 L .3912 .82607 L .683 .77 .917 r
F
.41902 .83126 m .40492 .822 L .40928 .83254 L F
.53105 .71356 m .50704 .71008 L .5039 .72189 L .673 .758 .915 r
F
0 g
.5039 .72189 m
.50589 .73359 L
s
.80818 .70093 m .81601 .68416 L .81635 .68983 L .181 .084 .501 r
F
.80853 .7066 m .80818 .70093 L .81635 .68983 L F
.78694 .69375 m .80818 .70093 L .81635 .68983 L .673 .758 .914 r
F
.77861 .70018 m .80818 .70093 L .78694 .69375 L F
0 g
.80107 .70641 m
.80818 .70093 L
s
.40062 .83982 m .39168 .83064 L .3798 .83659 L .683 .77 .917 r
F
.40976 .8371 m .39168 .83064 L .40062 .83982 L F
.41902 .83126 m .41953 .82008 L .40492 .822 L F
.54905 .81709 m .56194 .81516 L .56244 .81972 L .793 .542 .557 r
F
.54905 .81709 m .54855 .81253 L .56194 .81516 L F
0 g
.56194 .81516 m
.57643 .81553 L
s
.25218 .69431 m .25897 .69948 L .25927 .70514 L .987 .713 .391 r
F
.25218 .69431 m .25189 .68865 L .25897 .69948 L F
0 g
.25897 .69948 m
.26397 .70344 L
s
.51092 .45807 m .51105 .51572 L .51093 .51654 L 0 0 .142 r
F
.51092 .45807 m .51104 .45726 L .51105 .51572 L F
0 g
.51049 .45876 m
.51092 .45807 L
s
.57742 .82465 m .57693 .82009 L .59153 .81817 L .673 .454 .58 r
F
.56293 .82429 m .57693 .82009 L .57742 .82465 L .733 .498 .572 r
F
.127 .923 .03 r
.5693 .82238 m
.56932 .8199 L
s
.56293 .82429 m .56244 .81972 L .57693 .82009 L .733 .498 .572 r
F
.57751 .8089 m .57693 .82009 L .59153 .81817 L .683 .77 .917 r
F
.56785 .80866 m .57693 .82009 L .57751 .8089 L F
.56785 .80866 m .56244 .81972 L .57693 .82009 L F
.73 .58919 m .71519 .57095 L .7019 .57667 L .654 .726 .902 r
F
.73765 .58758 m .71519 .57095 L .73 .58919 L F
.2765 .68423 m .2593 .69936 L .2812 .69142 L .673 .757 .914 r
F
.2765 .68423 m .25225 .68858 L .2593 .69936 L F
.55852 .80224 m .56202 .81499 L .56741 .80398 L .683 .77 .917 r
F
.55852 .80224 m .5487 .81238 L .56202 .81499 L F
.50359 .45794 m .50397 .5171 L .5036 .5164 L .989 .72 .386 r
F
.50354 .45712 m .50359 .45794 L .5036 .5164 L .783 .625 .063 r
F
0 g
.50359 .45794 m
.50397 .45864 L
s
.75653 .69796 m .76829 .71085 L .77895 .70584 L .673 .758 .915 r
F
.7504 .69958 m .76829 .71085 L .75653 .69796 L F
.60346 .71614 m .62325 .70456 L .60115 .71254 L F
.60346 .71614 m .62787 .71178 L .62325 .70456 L F
.55721 .70204 m .536 .69489 L .53066 .70226 L .673 .758 .914 r
F
.56133 .69884 m .536 .69489 L .55721 .70204 L F
.76132 .59083 m .76296 .56942 L .75386 .58843 L .654 .726 .902 r
F
.76132 .59083 m .77787 .57423 L .76296 .56942 L F
.127 .923 .03 r
.42261 .94394 m
.42262 .94195 L
s
.30745 .69792 m .29948 .71359 L .31254 .70024 L .673 .758 .914 r
F
.30745 .69792 m .28929 .70897 L .29948 .71359 L F
.30311 .68348 m .28888 .69752 L .30695 .68653 L .673 .757 .914 r
F
.30311 .68348 m .2812 .69142 L .28888 .69752 L F
.41235 .92752 m .40585 .93369 L .4118 .93555 L .644 .733 .913 r
F
.31893 .5894 m .3115 .56955 L .29624 .57278 L .654 .726 .902 r
F
.32706 .58914 m .3115 .56955 L .31893 .5894 L F
.27235 .59357 m .24554 .5821 L .23568 .59616 L F
0 g
.23198 .61158 m
.23568 .59616 L
s
.42178 .92883 m .4247 .9363 L .43078 .93515 L .644 .733 .913 r
F
.41854 .92889 m .4247 .9363 L .42178 .92883 L F
.33514 .59025 m .32777 .56903 L .32706 .58914 L .654 .726 .902 r
F
.33514 .59025 m .34394 .57125 L .32777 .56903 L F
.34261 .6916 m .35988 .702 L .36812 .69557 L .673 .757 .914 r
F
.127 .923 .03 r
.42344 .94169 m
.42346 .94392 L
s
.59153 .81817 m .60477 .80953 L .60527 .8141 L .607 .406 .584 r
F
.59203 .82273 m .59153 .81817 L .60527 .8141 L F
.57742 .82465 m .59153 .81817 L .59203 .82273 L .673 .454 .58 r
F
.58725 .80762 m .59153 .81817 L .60527 .8141 L .683 .77 .917 r
F
.127 .923 .03 r
.63651 .78247 m
.63663 .77822 L
s
.63726 .78215 m
.63838 .71853 L
s
.57751 .8089 m .59153 .81817 L .58725 .80762 L .683 .77 .917 r
F
0 g
.57693 .82009 m
.59153 .81817 L
s
.38533 .93834 m .39137 .93964 L .39111 .9434 L .924 .676 .545 r
F
.127 .923 .03 r
.38813 .9368 m
.38816 .93895 L
s
.38533 .93834 m .38559 .93458 L .39137 .93964 L .924 .676 .545 r
F
.39659 .93142 m .39137 .93964 L .40044 .9348 L .644 .733 .913 r
F
.39659 .93142 m .38559 .93458 L .39137 .93964 L F
0 g
.39137 .93964 m
.39477 .94145 L
s
.46177 .56924 m .45813 .59291 L .47449 .57631 L .654 .726 .902 r
F
.46177 .56924 m .43904 .58231 L .45813 .59291 L F
0 g
.45813 .59291 m
.48054 .60012 L
s
.62754 .70611 m .64504 .69091 L .62293 .69889 L .673 .758 .914 r
F
.62754 .70611 m .65195 .70175 L .64504 .69091 L F
.42917 .83607 m .42002 .82464 L .4195 .83582 L .683 .77 .917 r
F
.42917 .83607 m .43452 .82501 L .42002 .82464 L F
.51104 .45726 m .5106 .51468 L .51105 .51572 L .984 .727 .339 r
F
.51104 .45726 m .51059 .45621 L .5106 .51468 L F
.3898 .70842 m .39749 .69165 L .39779 .69732 L .167 .072 .494 r
F
.36842 .70124 m .3898 .70842 L .39779 .69732 L .673 .758 .914 r
F
.36018 .70766 m .3898 .70842 L .36842 .70124 L F
0 g
.37744 .71805 m
.3898 .70842 L
s
.4445 .94276 m .45093 .93464 L .45067 .9384 L .354 .181 .502 r
F
.44425 .94652 m .4445 .94276 L .45067 .9384 L F
.43587 .93688 m .4445 .94276 L .45067 .9384 L .644 .733 .913 r
F
.43058 .93898 m .4445 .94276 L .43587 .93688 L F
0 g
.43877 .94504 m
.4445 .94276 L
s
.50354 .45712 m .5036 .5164 L .50355 .51559 L .783 .625 .063 r
F
.50407 .45609 m .50354 .45712 L .50355 .51559 L 0 0 .377 r
F
.41721 .60566 m .40882 .58335 L .40838 .59062 L .99 .743 .461 r
F
0 g
.41721 .60566 m
.41981 .62141 L
s
.72295 .59931 m .7015 .58394 L .69113 .59175 L .654 .726 .902 r
F
.7296 .59646 m .7015 .58394 L .72295 .59931 L F
.28304 .5785 m .24601 .57483 L .27281 .5863 L F
.76725 .60163 m .77749 .58151 L .76093 .5981 L F
.76725 .60163 m .79014 .58858 L .77749 .58151 L F
.127 .923 .03 r
.45876 2.17053 m
.49731 8.79909 L
s
0 0 0 r
2.5 Mabswid
.45098 .83353 Mdot
.127 .923 .03 r
.5 Mabswid
.45054 .89905 m
.45098 .83353 L
s
.32706 .58914 m .32777 .56903 L .3115 .56955 L .654 .726 .902 r
F
.65195 .70175 m .65162 .69608 L .64471 .68525 L .986 .711 .379 r
F
0 g
.65162 .69608 m
.65355 .70779 L
s
.38131 .59198 m .39435 .57007 L .37166 .58313 L .654 .726 .902 r
F
.38131 .59198 m .40882 .58335 L .39435 .57007 L F
.3912 .82607 m .37883 .82746 L .37932 .83202 L .524 .346 .581 r
F
.3912 .82607 m .39072 .82151 L .37883 .82746 L F
0 g
.36959 .83488 m
.37883 .82746 L
s
.60527 .8141 m .60477 .80953 L .6167 .80358 L .525 .347 .582 r
F
0 g
.59809 .81152 m
.60477 .80953 L
s
.60083 .70687 m .61529 .69276 L .59701 .7038 L .673 .758 .914 r
F
.60083 .70687 m .62293 .69889 L .61529 .69276 L F
.536 .69489 m .50676 .6988 L .53066 .70226 L F
0 0 0 r
2.5 Mabswid
.81121 .5405 Mdot
.45933 .83235 m .44745 .82307 L .44793 .82764 L .859 .591 .532 r
F
0 g
.5 Mabswid
.45933 .83235 m
.46793 .83881 L
s
.59583 .80025 m .60464 .8094 L .61651 .80347 L .683 .77 .917 r
F
.58671 .80296 m .60464 .8094 L .59583 .80025 L F
.67111 .69249 m .67769 .69766 L .67802 .70332 L .986 .711 .378 r
F
.67111 .69249 m .67078 .68683 L .67769 .69766 L F
0 g
.67769 .69766 m
.68265 .70165 L
s
.51059 .45621 m .50955 .51385 L .5106 .51468 L .909 .63 .5 r
F
.51059 .45621 m .50954 .45539 L .50955 .51385 L F
0 g
.51059 .45621 m
.51104 .45726 L
s
.51059 .45621 m
.51059 .45621 L
s
.41829 .9327 m .41797 .94028 L .42448 .94014 L .644 .733 .913 r
F
.127 .923 .03 r
.45052 .90256 m
.45054 .89905 L
s
.41505 .93225 m .41797 .94028 L .41829 .9327 L .644 .733 .913 r
F
.41505 .93225 m .41151 .93938 L .41797 .94028 L F
.40976 .8371 m .4054 .82656 L .39168 .83064 L .683 .77 .917 r
F
.4195 .83582 m .4054 .82656 L .40976 .8371 L F
.69545 .68241 m .67802 .69754 L .70003 .6896 L .673 .758 .914 r
F
.69545 .68241 m .67115 .68676 L .67802 .69754 L F
.127 .923 .03 r
.68822 .6837 m
.69016 .62851 L
s
.50519 .45531 m .50407 .45609 L .50408 .51456 L .401 .213 .507 r
F
.50407 .45609 m .50355 .51559 L .50408 .51456 L 0 0 .377 r
F
0 g
.50354 .45712 m
.50407 .45609 L
s
.50407 .45609 m
.50407 .45609 L
s
.55775 .71334 m .53105 .71356 L .55506 .71703 L .673 .758 .915 r
F
.72642 .6961 m .7182 .71177 L .73147 .69842 L F
.72642 .6961 m .70809 .70715 L .7182 .71177 L F
.40982 .92617 m .40079 .93098 L .40585 .93369 L .644 .733 .913 r
F
.42503 .56175 m .43992 .56777 L .43948 .57504 L .927 .669 .527 r
F
.42503 .56175 m .42547 .55448 L .43992 .56777 L F
0 g
.43992 .56777 m
.44612 .57122 L
s
.4195 .83582 m .42002 .82464 L .4054 .82656 L .683 .77 .917 r
F
.72205 .68166 m .7076 .6957 L .72583 .68471 L .673 .758 .914 r
F
.72205 .68166 m .70003 .6896 L .7076 .6957 L F
.59659 .69819 m .6047 .68259 L .59155 .69589 L F
.59659 .69819 m .61478 .6872 L .6047 .68259 L F
.73765 .58758 m .73051 .56772 L .71519 .57095 L .654 .726 .902 r
F
.74579 .58732 m .73051 .56772 L .73765 .58758 L F
.42482 .92825 m .43078 .93515 L .43604 .93306 L .644 .733 .913 r
F
.42178 .92883 m .43078 .93515 L .42482 .92825 L F
.62866 .59323 m .60668 .57875 L .60627 .58602 L .793 .542 .558 r
F
0 g
.60668 .57875 m
.62907 .58596 L
s
.62825 .6005 m .62866 .59323 L .60627 .58602 L .793 .542 .558 r
F
0 g
.62866 .59323 m
.64768 .60383 L
s
.54954 .82166 m .56244 .81972 L .56293 .82429 L .793 .542 .557 r
F
.54954 .82166 m .54905 .81709 L .56244 .81972 L F
.55892 .8069 m .56244 .81972 L .56785 .80866 L .683 .77 .917 r
F
.55892 .8069 m .54905 .81709 L .56244 .81972 L F
0 g
.56244 .81972 m
.57693 .82009 L
s
.69113 .59175 m .66448 .58027 L .6544 .59433 L .654 .726 .902 r
F
0 g
.6512 .60688 m
.6544 .59433 L
s
.75386 .58843 m .7468 .5672 L .74579 .58732 L .654 .726 .902 r
F
.75386 .58843 m .76296 .56942 L .7468 .5672 L F
.76152 .68978 m .77861 .70018 L .78694 .69375 L .673 .758 .914 r
F
.41206 .93131 m .41151 .93938 L .41505 .93225 L .644 .733 .913 r
F
.41206 .93131 m .40553 .93751 L .41151 .93938 L F
.45328 .54575 m .44026 .56757 L .46286 .55457 L .654 .726 .902 r
F
.45328 .54575 m .42588 .55435 L .44026 .56757 L F
.42154 .93263 m .42448 .94014 L .43058 .93898 L .644 .733 .913 r
F
.41829 .9327 m .42448 .94014 L .42154 .93263 L F
.57801 .81347 m .57742 .82465 L .59203 .82273 L .683 .771 .917 r
F
.56834 .81322 m .57742 .82465 L .57801 .81347 L F
.127 .923 .03 r
.56919 .83368 m
.56928 .82445 L
s
.56834 .81322 m .56293 .82429 L .57742 .82465 L .683 .771 .917 r
F
.31085 .59829 m .29578 .58005 L .28258 .58577 L .654 .726 .902 r
F
.31847 .59667 m .29578 .58005 L .31085 .59829 L F
0 0 0 r
2.5 Mabswid
.42261 .94543 Mdot
.50954 .45539 m .50847 .51347 L .50955 .51385 L .809 .541 .532 r
F
.50954 .45539 m .50846 .45501 L .50847 .51347 L F
0 g
.5 Mabswid
.50954 .45539 m
.51059 .45621 L
s
.80853 .7066 m .81635 .68983 L .8167 .69549 L .181 .084 .501 r
F
.78729 .69942 m .80853 .7066 L .8167 .69549 L .673 .758 .915 r
F
.77895 .70584 m .80853 .7066 L .78729 .69942 L F
0 g
.79603 .71623 m
.80853 .7066 L
s
.34217 .59993 m .34349 .57852 L .33469 .59752 L .654 .726 .902 r
F
.34217 .59993 m .35847 .58333 L .34349 .57852 L F
.39633 .93519 m .39111 .9434 L .40019 .93856 L .644 .733 .913 r
F
.127 .923 .03 r
.4505 .90606 m
.45052 .90256 L
s
.39633 .93519 m .38533 .93834 L .39111 .9434 L .644 .733 .913 r
F
0 g
.39111 .9434 m
.39875 .94747 L
s
.127 .923 .03 r
.38844 .96029 m
.39002 1.07779 L
s
.38818 .94084 m
.38844 .96029 L
s
.50519 .45531 m .50408 .51456 L .5052 .51377 L .401 .213 .507 r
F
.50629 .45497 m .50519 .45531 L .5052 .51377 L .568 .343 .534 r
F
0 g
.50407 .45609 m
.50519 .45531 L
s
.83595 .60383 m .82771 .58152 L .82733 .58879 L .991 .743 .451 r
F
0 g
.83595 .60383 m
.83831 .61959 L
s
.7019 .57667 m .66488 .573 L .69154 .58448 L .654 .726 .902 r
F
.127 .923 .03 r
.49646 8.79878 m
.6345 4.98802 L
s
.6345 4.98802 m
.7318 2.30207 L
s
0 0 0 r
2.5 Mabswid
.78957 .70738 Mdot
.127 .923 .03 r
.5 Mabswid
.40386 8.8271 m
.61646 4.35148 L
s
.61646 4.35148 m
.72294 2.10999 L
s
.44425 .94652 m .45067 .9384 L .45042 .94216 L .354 .181 .502 r
F
.43562 .94064 m .44425 .94652 L .45042 .94216 L .644 .733 .913 r
F
.43033 .94275 m .44425 .94652 L .43562 .94064 L F
0 g
.43632 .94968 m
.44425 .94652 L
s
.59203 .82273 m .60527 .8141 L .60577 .81866 L .607 .406 .584 r
F
.58775 .81219 m .59203 .82273 L .60577 .81866 L .683 .771 .917 r
F
.127 .923 .03 r
.63719 .78638 m
.63726 .78215 L
s
.63638 .78671 m
.63651 .78247 L
s
.57801 .81347 m .59203 .82273 L .58775 .81219 L .683 .771 .917 r
F
0 g
.57742 .82465 m
.59203 .82273 L
s
0 0 0 r
2.5 Mabswid
.42347 .94516 Mdot
.25247 .69998 m .25927 .70514 L .25956 .71081 L .987 .713 .391 r
F
.25247 .69998 m .25218 .69431 L .25927 .70514 L F
.27655 .68994 m .25927 .70514 L .28127 .69717 L .673 .757 .914 r
F
.27655 .68994 m .25218 .69431 L .25927 .70514 L F
0 g
.5 Mabswid
.25927 .70514 m
.26426 .70911 L
s
.50846 .45501 m .50739 .51335 L .50847 .51347 L .734 .477 .54 r
F
.50846 .45501 m .50738 .45488 L .50739 .51335 L F
0 g
.50846 .45501 m
.50954 .45539 L
s
.74579 .58732 m .7468 .5672 L .73051 .56772 L .654 .726 .902 r
F
.50629 .45497 m .5052 .51377 L .5063 .51343 L .568 .343 .534 r
F
.50738 .45488 m .50629 .45497 L .5063 .51343 L .66 .417 .541 r
F
0 g
.50519 .45531 m
.50629 .45497 L
s
.50738 .45488 m .5063 .51343 L .50739 .51335 L .66 .417 .541 r
F
0 g
.50738 .45488 m
.50846 .45501 L
s
.50629 .45497 m
.50738 .45488 L
s
.80005 .59016 m .81343 .56824 L .79052 .58131 L .654 .726 .902 r
F
.80005 .59016 m .82771 .58152 L .81343 .56824 L F
.55743 .70767 m .5361 .70049 L .53073 .70789 L .673 .758 .914 r
F
.56157 .70446 m .5361 .70049 L .55743 .70767 L F
.127 .923 .03 r
.49587 8.80054 m
.62067 1.37225 L
s
.63251 .66758 m
.63345 .61162 L
s
.63345 .61162 m
.63358 .60396 L
s
.40088 8.82644 m
.61765 1.16713 L
s
.63177 .66785 m
.63332 .61311 L
s
.63332 .61311 m
.63358 .60396 L
s
.3033 .68919 m .28899 .7033 L .30715 .69225 L .673 .757 .914 r
F
.3033 .68919 m .28127 .69717 L .28899 .7033 L F
.34291 .69727 m .36018 .70766 L .36842 .70124 L .673 .758 .914 r
F
.33762 .69978 m .36018 .70766 L .34291 .69727 L F
.56133 .69884 m .54424 .6885 L .536 .69489 L F
.56662 .69635 m .54424 .6885 L .56133 .69884 L F
0 0 0 r
2.5 Mabswid
.34455 .70828 Mdot
.62787 .71178 m .64537 .69658 L .62325 .70456 L .673 .758 .915 r
F
.62787 .71178 m .65228 .70741 L .64537 .69658 L F
.39168 .83064 m .37932 .83202 L .3798 .83659 L .524 .346 .581 r
F
0 g
.5 Mabswid
.37055 .844 m
.3798 .83659 L
s
.39168 .83064 m .3912 .82607 L .37932 .83202 L .524 .346 .581 r
F
0 g
.37007 .83944 m
.37932 .83202 L
s
.127 .923 .03 r
.38617 .81908 m
.38624 .87759 L
s
.38793 .81836 m
.38833 .84735 L
s
.60527 .8141 m .6167 .80358 L .6172 .80814 L .525 .347 .582 r
F
.60577 .81866 m .60527 .8141 L .6172 .80814 L F
.59642 .80491 m .60527 .8141 L .6172 .80814 L .683 .77 .917 r
F
.58725 .80762 m .60527 .8141 L .59642 .80491 L F
0 g
.59858 .81608 m
.60527 .8141 L
s
.44745 .82307 m .44696 .81851 L .43355 .81588 L .793 .542 .558 r
F
0 g
.44696 .81851 m
.45835 .82322 L
s
.41803 .93646 m .41772 .94404 L .42422 .94391 L .644 .733 .913 r
F
.4148 .93601 m .41772 .94404 L .41803 .93646 L F
.4148 .93601 m .41126 .94315 L .41772 .94404 L F
.38205 .92887 m .38584 .93081 L .38559 .93458 L .989 .751 .481 r
F
.38205 .92887 m .38231 .9251 L .38584 .93081 L F
0 g
.38584 .93081 m
.38902 .93359 L
s
.39461 .92384 m .38601 .93077 L .39695 .92763 L .644 .733 .913 r
F
.39461 .92384 m .38249 .92509 L .38601 .93077 L F
.40952 .92995 m .40553 .93751 L .41206 .93131 L F
.40952 .92995 m .40044 .9348 L .40553 .93751 L F
.42459 .93205 m .43058 .93898 L .43587 .93688 L F
.42154 .93263 m .43058 .93898 L .42459 .93205 L F
.45067 .9384 m .45093 .93464 L .45491 .92937 L .084 0 .407 r
F
.127 .923 .03 r
.46149 2.5368 m
.47767 .93278 L
s
.39802 8.82748 m
.46149 2.5368 L
s
0 g
.44624 .93794 m
.45093 .93464 L
s
.58755 .57612 m
.60668 .57875 L
s
.65195 .70175 m .64471 .68525 L .64504 .69091 L .986 .711 .379 r
F
.65228 .70741 m .65195 .70175 L .64504 .69091 L F
0 g
.65195 .70175 m
.65388 .71346 L
s
.44013 .93016 m .45077 .93457 L .45473 .92933 L .644 .733 .913 r
F
.127 .923 .03 r
.45098 .83353 m
.45136 .89879 L
s
.43604 .93306 m .45077 .93457 L .44013 .93016 L .644 .733 .913 r
F
.7296 .59646 m .71479 .57823 L .7015 .58394 L .654 .726 .902 r
F
.73726 .59485 m .71479 .57823 L .7296 .59646 L F
.41181 .93508 m .41126 .94315 L .4148 .93601 L .644 .733 .913 r
F
.41181 .93508 m .40528 .94128 L .41126 .94315 L F
.42128 .93639 m .42422 .94391 L .43033 .94275 L F
.41803 .93646 m .42422 .94391 L .42128 .93639 L F
.76093 .5981 m .76257 .57669 L .75347 .5957 L .654 .726 .902 r
F
.76093 .5981 m .77749 .58151 L .76257 .57669 L F
.60115 .71254 m .61562 .69843 L .59733 .70947 L .673 .758 .915 r
F
.60115 .71254 m .62325 .70456 L .61562 .69843 L F
.3676 .68983 m .39682 .68593 L .3729 .68246 L .673 .757 .914 r
F
.34632 .68269 m .3676 .68983 L .3729 .68246 L F
.5361 .70049 m .50672 .70441 L .53073 .70789 L .673 .758 .914 r
F
.55942 .81147 m .56293 .82429 L .56834 .81322 L .683 .771 .917 r
F
.55942 .81147 m .54954 .82166 L .56293 .82429 L F
0 g
.56293 .82429 m
.57742 .82465 L
s
.53767 .81238 m .54855 .81253 L .54905 .81709 L .859 .591 .531 r
F
.53767 .81238 m .53718 .80782 L .54855 .81253 L F
0 g
.54855 .81253 m
.55268 .81334 L
s
.32908 .6467 m
.32919 .61546 L
s
.31847 .59667 m .31104 .57682 L .29578 .58005 L .654 .726 .902 r
F
.3266 .59641 m .31104 .57682 L .31847 .59667 L F
.67145 .69816 m .67802 .70332 L .67835 .70899 L .986 .711 .378 r
F
.67145 .69816 m .67111 .69249 L .67802 .70332 L F
.69554 .68812 m .67802 .70332 L .70014 .69535 L .673 .758 .914 r
F
.69554 .68812 m .67111 .69249 L .67802 .70332 L F
0 g
.67802 .70332 m
.68299 .70732 L
s
.33469 .59752 m .32732 .5763 L .3266 .59641 L .654 .726 .902 r
F
.33469 .59752 m .34349 .57852 L .32732 .5763 L F
0 g
.32256 .64658 m
.32268 .61512 L
s
.55098 .79911 m .5487 .81238 L .55852 .80224 L .683 .77 .917 r
F
.55098 .79911 m .53739 .80769 L .5487 .81238 L F
.4079 .92449 m .39695 .92763 L .40079 .93098 L .644 .733 .913 r
F
.42745 .9272 m .43604 .93306 L .44013 .93016 L F
.42482 .92825 m .43604 .93306 L .42745 .9272 L F
.72228 .68736 m .70775 .70148 L .72608 .69043 L .673 .758 .914 r
F
.72228 .68736 m .70014 .69535 L .70775 .70148 L F
.50731 .54857 m .50647 .5686 L .52267 .56808 L .654 .726 .902 r
F
.49926 .54747 m .50647 .5686 L .50731 .54857 L F
.49926 .54747 m .49039 .56639 L .50647 .5686 L F
.59155 .69589 m .59283 .6798 L .58562 .69449 L .673 .758 .914 r
F
.59155 .69589 m .6047 .68259 L .59283 .6798 L F
.59701 .7038 m .60516 .68813 L .59194 .70149 L F
.59701 .7038 m .61529 .69276 L .60516 .68813 L F
.76186 .69545 m .77895 .70584 L .78729 .69942 L .673 .758 .915 r
F
.75653 .69796 m .77895 .70584 L .76186 .69545 L F
.28258 .58577 m .24554 .5821 L .27235 .59357 L .654 .726 .902 r
F
.28372 .57138 m .26215 .55607 L .24687 .56773 L F
.29685 .56569 m .26215 .55607 L .28372 .57138 L F
.3266 .59641 m .32732 .5763 L .31104 .57682 L F
.38086 .59925 m .39391 .57734 L .37122 .59041 L F
.38086 .59925 m .40838 .59062 L .39391 .57734 L F
0 g
.32903 .66063 m
.32908 .6467 L
s
.37188 .57599 m .37543 .55242 L .3592 .56896 L .654 .726 .902 r
F
.37188 .57599 m .39446 .56299 L .37543 .55242 L F
0 g
.32244 .67809 m
.32245 .67516 L
s
.3225 .66073 m
.32256 .64658 L
s
.27685 .69561 m .25956 .71081 L .28157 .70284 L .673 .758 .914 r
F
.27685 .69561 m .25247 .69998 L .25956 .71081 L F
0 g
.25956 .71081 m
.27114 .72 L
s
.38179 .93263 m .38559 .93458 L .38533 .93834 L .989 .751 .481 r
F
.38179 .93263 m .38205 .92887 L .38559 .93458 L F
.39423 .92762 m .38559 .93458 L .39659 .93142 L .644 .733 .913 r
F
.39423 .92762 m .38205 .92887 L .38559 .93458 L F
0 g
.38559 .93458 m
.38876 .93736 L
s
.40926 .93372 m .40528 .94128 L .41181 .93508 L .644 .733 .913 r
F
.127 .923 .03 r
.46283 .81698 m
.46289 .80987 L
s
.40926 .93372 m .40019 .93856 L .40528 .94128 L .644 .733 .913 r
F
.60577 .81866 m .6172 .80814 L .6177 .81271 L .525 .347 .582 r
F
.59691 .80947 m .60577 .81866 L .6177 .81271 L .683 .771 .917 r
F
.58775 .81219 m .60577 .81866 L .59691 .80947 L F
0 g
.59203 .82273 m
.60577 .81866 L
s
.44745 .82307 m .43355 .81588 L .43404 .82045 L .793 .542 .558 r
F
.44793 .82764 m .44745 .82307 L .43404 .82045 L F
0 g
.44745 .82307 m
.45884 .82778 L
s
.56662 .69635 m .55481 .68351 L .54424 .6885 L .673 .758 .914 r
F
.57271 .69473 m .55481 .68351 L .56662 .69635 L F
.55775 .71334 m .53642 .70616 L .53105 .71356 L .673 .758 .915 r
F
.56189 .71012 m .53642 .70616 L .55775 .71334 L F
.42434 .93581 m .43033 .94275 L .43562 .94064 L .644 .733 .913 r
F
.42128 .93639 m .43033 .94275 L .42434 .93581 L F
.30359 .69486 m .28929 .70897 L .30745 .69792 L .673 .758 .914 r
F
.30359 .69486 m .28157 .70284 L .28929 .70897 L F
0 g
.53427 .59559 m
.5572 .59075 L
s
.45067 .9384 m .45491 .92937 L .45466 .93313 L .084 0 .407 r
F
.127 .923 .03 r
.39773 8.82631 m
.41816 6.3128 L
s
.45042 .94216 m .45067 .9384 L .45466 .93313 L .084 0 .407 r
F
.127 .923 .03 r
.39749 8.82772 m
.4286 4.17856 L
s
.43999 .93397 m .45067 .9384 L .45466 .93313 L .644 .733 .913 r
F
.127 .923 .03 r
.45136 .89879 m
.45138 .90228 L
s
.43587 .93688 m .45067 .9384 L .43999 .93397 L .644 .733 .913 r
F
0 g
.44599 .94171 m
.45067 .9384 L
s
.62238 .69331 m .63298 .6762 L .61478 .6872 L .673 .758 .914 r
F
.62238 .69331 m .64437 .68537 L .63298 .6762 L F
.78639 .68801 m .81565 .68411 L .7918 .68064 L F
.76524 .68086 m .78639 .68801 L .7918 .68064 L F
0 g
.74771 .61363 m
.74788 .64488 L
s
.42459 .56902 m .43948 .57504 L .43904 .58231 L .927 .669 .527 r
F
.42459 .56902 m .42503 .56175 L .43948 .57504 L F
.45257 .5531 m .43948 .57504 L .4622 .56197 L .654 .726 .902 r
F
.45257 .5531 m .42503 .56175 L .43948 .57504 L F
0 g
.43948 .57504 m
.44569 .57849 L
s
.73726 .59485 m .73011 .575 L .71479 .57823 L .654 .726 .902 r
F
.7454 .59459 m .73011 .575 L .73726 .59485 L F
.62825 .6005 m .60627 .58602 L .60586 .59329 L .793 .542 .558 r
F
0 g
.62825 .6005 m
.64727 .6111 L
s
.49182 .54507 m .49039 .56639 L .49926 .54747 L .654 .726 .902 r
F
.49182 .54507 m .47552 .56161 L .49039 .56639 L F
.75347 .5957 m .74641 .57447 L .7454 .59459 L F
.75347 .5957 m .76257 .57669 L .74641 .57447 L F
0 g
.74119 .6133 m
.74136 .64476 L
s
.51541 .54831 m .52267 .56808 L .53787 .56487 L .654 .726 .902 r
F
.50731 .54857 m .52267 .56808 L .51541 .54831 L F
.56157 .70446 m .54439 .69406 L .5361 .70049 L .673 .758 .914 r
F
.56688 .70195 m .54439 .69406 L .56157 .70446 L F
.5776 .79309 m .57702 .80423 L .58671 .80296 L .683 .77 .917 r
F
.5776 .79309 m .58671 .80296 L .58245 .79245 L F
.5781 .79771 m .57751 .8089 L .58725 .80762 L F
.5781 .79771 m .58725 .80762 L .58297 .79707 L F
.57742 .7425 m .57899 .74276 L .57906 .78477 L .751 .492 .54 r
F
.57944 .78502 m .5776 .79309 L .58245 .79245 L .683 .77 .917 r
F
.57935 .7848 m .57928 .78509 L .57944 .78502 L F
.57928 .78509 m .5776 .79309 L .57944 .78502 L F
.57976 .78916 m .5781 .79771 L .58297 .79707 L F
.57803 .78496 m .5776 .79309 L .5793 .78479 L F
.57906 .78477 m .5793 .78479 L .57932 .78473 L F
.57803 .78496 m .5793 .78479 L .57906 .78477 L F
.57578 .74144 m .57644 .74203 L .57651 .78429 L .928 .648 .489 r
F
.57696 .78445 m .57665 .78507 L .57804 .78484 L .683 .77 .917 r
F
.57536 .73994 m .57541 .74075 L .57548 .78322 L .779 .622 .059 r
F
.57573 .78696 m .57279 .79297 L .57582 .78827 L .683 .77 .917 r
F
.56835 .79209 m .56741 .80398 L .57279 .79297 L F
.57563 .78966 m .56501 .79513 L .5688 .79671 L F
.57606 .78413 m .57606 .78413 L .57696 .78445 L F
.57801 .78538 m .57279 .79297 L .5776 .79309 L F
.57737 .78919 m .57326 .79759 L .57811 .78973 L F
.57279 .79297 m .57702 .80423 L .5776 .79309 L F
.5769 .78457 m .57164 .7892 L .57279 .79297 L F
.57164 .7892 m .56835 .79209 L .56984 .79238 L F
.57164 .7892 m .56984 .79238 L .57279 .79297 L F
.57536 .73994 m .57546 .78302 L .57543 .7825 L .779 .622 .059 r
F
.57541 .74075 m .57575 .78364 L .57548 .78322 L .988 .72 .386 r
F
.57536 .73994 m .57548 .78322 L .57546 .78302 L .779 .622 .059 r
F
.57541 .74075 m .57578 .74144 L .57585 .78381 L .988 .72 .386 r
F
.57589 .73892 m .57536 .73994 L .57543 .7825 L 0 0 .381 r
F
.5755 .78775 m .57471 .78806 L .57555 .78848 L .683 .77 .917 r
F
.57644 .74203 m .57721 .78454 L .57651 .78429 L .844 .571 .525 r
F
.57578 .74144 m .57651 .78429 L .57632 .78415 L .928 .648 .489 r
F
.57644 .74203 m .57742 .7425 L .57749 .78464 L .844 .571 .525 r
F
.57644 .74203 m .57749 .78464 L .5774 .78461 L F
.57557 .78464 m .57564 .78562 L .57651 .78485 L .683 .77 .917 r
F
.57839 .79207 m .57326 .79759 L .5781 .79771 L F
.57279 .79297 m .56741 .80398 L .57702 .80423 L F
.57326 .79759 m .56785 .80866 L .57751 .8089 L F
.5688 .79671 m .56785 .80866 L .57326 .79759 L F
.57738 .79475 m .5693 .80127 L .57376 .80215 L .683 .771 .917 r
F
.57729 .78884 m .5775 .78892 L .57751 .79319 L .844 .571 .525 r
F
.57326 .79759 m .57751 .8089 L .5781 .79771 L .683 .77 .917 r
F
.57904 .79375 m .57376 .80215 L .57859 .80228 L .683 .771 .917 r
F
.57804 .78484 m .57779 .78522 L .57801 .78538 L .683 .77 .917 r
F
.57855 .789 m .57841 .78924 L .57854 .78929 L F
.57852 .78971 m .5781 .79771 L .57976 .78916 L F
.57861 .78474 m .57885 .7933 L .57749 .78464 L .751 .492 .54 r
F
.57906 .79332 m .57805 .79339 L .57904 .79375 L .683 .771 .917 r
F
.57812 .79324 m .57805 .79339 L .57906 .79332 L F
.57885 .7933 m .57909 .8016 L .5783 .79326 L .751 .492 .54 r
F
.57854 .78929 m .57758 .7908 L .57839 .79207 L .683 .77 .917 r
F
.57737 .78919 m .57811 .78973 L .57855 .789 L F
.57885 .7933 m .5783 .79326 L .57749 .78464 L .751 .492 .54 r
F
.57855 .789 m .57852 .78971 L .57974 .7891 L .683 .77 .917 r
F
.57873 .78902 m .57907 .78905 L .57909 .8016 L .751 .492 .54 r
F
.57918 .79107 m .57812 .79324 L .57906 .79332 L .683 .771 .917 r
F
.57805 .79339 m .57376 .80215 L .57904 .79375 L F
.57652 .79284 m .57752 .80134 L .57654 .80087 L .844 .571 .525 r
F
.57606 .78413 m .57651 .78485 L .57696 .78445 L .683 .77 .917 r
F
.57665 .78507 m .57573 .78696 L .57726 .78603 L F
.57779 .78522 m .57279 .79297 L .57801 .78538 L F
.57651 .78429 m .57677 .78865 L .57652 .78856 L .844 .571 .525 r
F
.57868 .7865 m .5755 .78775 L .57553 .78821 L .683 .77 .917 r
F
.57582 .78831 m .57553 .78821 L .57555 .78848 L F
.57868 .7865 m .57553 .78821 L .57582 .78831 L F
.57841 .78924 m .57326 .79759 L .57854 .78929 L F
.57652 .78856 m .57703 .79302 L .57652 .79284 L .844 .571 .525 r
F
.57737 .78919 m .5688 .79671 L .57326 .79759 L .683 .77 .917 r
F
.57749 .78464 m .5779 .78895 L .5775 .78892 L .751 .492 .54 r
F
.57868 .7865 m .57662 .78864 L .57737 .78919 L .683 .77 .917 r
F
.57662 .78864 m .5688 .79671 L .57737 .78919 L F
.57606 .78413 m .57557 .78464 L .57651 .78485 L F
.57573 .78696 m .57582 .78827 L .57726 .78603 L F
.57632 .78415 m .57638 .78846 L .57585 .78381 L .928 .648 .489 r
F
.57758 .7908 m .57326 .79759 L .57839 .79207 L .683 .77 .917 r
F
.57578 .74144 m .57632 .78415 L .57585 .78381 L .928 .648 .489 r
F
.57685 .78454 m .56835 .79209 L .5769 .78457 L .683 .77 .917 r
F
.57644 .74203 m .5774 .78461 L .57721 .78454 L .844 .571 .525 r
F
.57742 .7425 m .57861 .78474 L .57749 .78464 L .751 .492 .54 r
F
.57819 .78194 m .57167 .78449 L .56458 .79053 L .683 .77 .917 r
F
.57167 .78449 m .56173 .78837 L .56375 .7899 L F
.57167 .78449 m .56375 .7899 L .56458 .79053 L F
.57701 .73815 m .57589 .73892 L .57596 .78156 L .404 .216 .509 r
F
.57638 .78846 m .57603 .78821 L .57585 .78381 L .928 .648 .489 r
F
.57232 .78799 m .56458 .79053 L .56835 .79209 L .683 .77 .917 r
F
.56458 .79053 m .55098 .79911 L .55852 .80224 L F
.57002 .78989 m .56041 .79037 L .56215 .79297 L F
.57557 .78224 m .57554 .78658 L .57596 .78156 L 0 0 .381 r
F
.57548 .78749 m .57562 .79198 L .57549 .79177 L .988 .72 .386 r
F
.57555 .78848 m .56501 .79513 L .57563 .78966 L .683 .77 .917 r
F
.57558 .78765 m .57568 .79207 L .57548 .78749 L .988 .72 .386 r
F
.57668 .79365 m .5693 .80127 L .57738 .79475 L .683 .771 .917 r
F
.57568 .79207 m .57588 .80028 L .57562 .79198 L .988 .72 .386 r
F
.57568 .79207 m .57562 .79198 L .57548 .78749 L F
.56458 .79053 m .55852 .80224 L .56835 .79209 L .683 .77 .917 r
F
.57555 .78848 m .56215 .79297 L .56501 .79513 L F
.57554 .79184 m .56042 .79207 L .56091 .79494 L .683 .771 .917 r
F
.57547 .78734 m .57548 .78749 L .57549 .79177 L .779 .622 .059 r
F
.5688 .79671 m .55892 .8069 L .56785 .80866 L .683 .77 .917 r
F
.57017 .80037 m .5655 .7997 L .5693 .80127 L .683 .771 .917 r
F
.57918 .79107 m .57335 .79475 L .57017 .80037 L F
.57335 .79475 m .5655 .7997 L .57017 .80037 L F
.57549 .79177 m .57588 .80028 L .5755 .79959 L .988 .72 .386 r
F
.57637 .78889 m .57555 .78848 L .57563 .78966 L .683 .77 .917 r
F
.57167 .78449 m .56001 .78578 L .56173 .78837 L F
.57498 .7867 m .56071 .78457 L .55992 .7875 L F
.57578 .78796 m .57564 .78775 L .57548 .78322 L .988 .72 .386 r
F
.57615 .78143 m .57606 .78577 L .57627 .78135 L .404 .216 .509 r
F
.57632 .78415 m .57652 .78856 L .57638 .78846 L .928 .648 .489 r
F
.57868 .7865 m .57517 .78725 L .57471 .78806 L .683 .77 .917 r
F
.57606 .78577 m .57597 .79011 L .57612 .78573 L .404 .216 .509 r
F
.57606 .78577 m .57612 .78573 L .57627 .78135 L F
.57575 .78364 m .57586 .78808 L .57578 .78796 L .988 .72 .386 r
F
.57868 .7865 m .57549 .78616 L .57498 .7867 L .683 .77 .917 r
F
.57549 .78616 m .57457 .78606 L .57489 .78656 L F
.57549 .78616 m .57489 .78656 L .57498 .7867 L F
.57521 .78382 m .56458 .79053 L .57606 .78413 L F
.57457 .78606 m .56071 .78457 L .57498 .7867 L F
.57575 .78364 m .57578 .78796 L .57548 .78322 L .988 .72 .386 r
F
.57578 .78796 m .57581 .79228 L .57564 .78775 L F
.57581 .79228 m .57588 .80028 L .57568 .79207 L F
.57581 .79228 m .57568 .79207 L .57548 .78322 L F
.56835 .79209 m .55852 .80224 L .56741 .80398 L .683 .77 .917 r
F
.57587 .79237 m .56091 .79494 L .56264 .79754 L .683 .771 .917 r
F
.57729 .78884 m .57751 .79319 L .57737 .79315 L .844 .571 .525 r
F
.57578 .78796 m .57586 .78808 L .57588 .80028 L .988 .72 .386 r
F
.57918 .79107 m .57554 .79184 L .57587 .79237 L .683 .771 .917 r
F
.57554 .79184 m .56091 .79494 L .57587 .79237 L F
.57597 .79011 m .57545 .79878 L .57599 .79776 L 0 0 .381 r
F
.57595 .78823 m .57555 .78848 L .57637 .78889 L .683 .77 .917 r
F
.57586 .78808 m .57654 .80087 L .57588 .80028 L .928 .648 .489 r
F
.57585 .78381 m .57603 .78821 L .57586 .78808 L F
.57603 .78821 m .57654 .80087 L .57586 .78808 L F
.57379 .7854 m .56458 .79053 L .57232 .78799 L .683 .77 .917 r
F
.57557 .78464 m .56835 .79209 L .57564 .78562 L F
.57482 .78732 m .55992 .7875 L .56041 .79037 L F
.57597 .78583 m .57569 .7906 L .57597 .79011 L 0 0 .381 r
F
.57596 .78156 m .57583 .78608 L .57597 .78583 L F
.57583 .78608 m .57569 .7906 L .57597 .78583 L F
.57517 .78725 m .57404 .78675 L .57482 .78732 L .683 .77 .917 r
F
.57632 .78415 m .57651 .78429 L .57652 .78856 L .928 .648 .489 r
F
.57868 .7865 m .57549 .78667 L .57517 .78725 L .683 .77 .917 r
F
.57549 .78667 m .57404 .78675 L .57517 .78725 L F
.57404 .78675 m .55992 .7875 L .57482 .78732 L F
.57646 .79279 m .56758 .79584 L .5655 .7997 L .683 .771 .917 r
F
.57562 .79198 m .57588 .80028 L .57549 .79177 L .988 .72 .386 r
F
.57569 .7906 m .57545 .79878 L .57597 .79011 L 0 0 .381 r
F
.57548 .79167 m .57549 .79177 L .5755 .79959 L .779 .622 .059 r
F
.57547 .78734 m .57549 .79177 L .57548 .79167 L F
.57918 .79107 m .57546 .79127 L .57554 .79184 L .683 .771 .917 r
F
.57546 .79127 m .57518 .79128 L .57549 .79177 L F
.57546 .79127 m .57549 .79177 L .57554 .79184 L F
.57518 .79128 m .56042 .79207 L .57554 .79184 L F
.57332 .78764 m .56041 .79037 L .57002 .78989 L .683 .77 .917 r
F
.57471 .78806 m .56215 .79297 L .57422 .78893 L F
.57564 .79069 m .56322 .78633 L .56121 .78913 L .683 .771 .917 r
F
.57805 .79339 m .57668 .79365 L .57738 .79475 L F
.57722 .79309 m .57668 .79365 L .57805 .79339 L F
.57696 .78445 m .57685 .78454 L .5769 .78457 L .683 .77 .917 r
F
.57721 .78454 m .57729 .78884 L .57651 .78429 L .844 .571 .525 r
F
.57729 .78884 m .57752 .80134 L .57677 .78865 L F
.57729 .78884 m .57677 .78865 L .57651 .78429 L F
.57721 .78454 m .5775 .78892 L .57729 .78884 L F
.57868 .7865 m .57595 .78823 L .57606 .7884 L .683 .77 .917 r
F
.57664 .78861 m .57606 .7884 L .57637 .78889 L F
.57868 .7865 m .57606 .7884 L .57664 .78861 L F
.57918 .79107 m .57597 .79012 L .57564 .79069 L .683 .771 .917 r
F
.57471 .78806 m .57332 .78764 L .57002 .78989 L .683 .77 .917 r
F
.57597 .79012 m .56322 .78633 L .57564 .79069 L .683 .771 .917 r
F
.57554 .78658 m .57551 .79093 L .57583 .78608 L 0 0 .381 r
F
.57551 .79093 m .57545 .79878 L .57569 .7906 L F
.57551 .79093 m .57569 .7906 L .57583 .78608 L F
.57575 .78364 m .57585 .78381 L .57586 .78808 L .988 .72 .386 r
F
.57554 .78658 m .57583 .78608 L .57596 .78156 L 0 0 .381 r
F
.57517 .78725 m .57332 .78764 L .57471 .78806 L .683 .77 .917 r
F
.57638 .78846 m .57643 .79277 L .57603 .78821 L .928 .648 .489 r
F
.57619 .78568 m .57597 .79011 L .57612 .79001 L .404 .216 .509 r
F
.57627 .78135 m .57612 .78573 L .57619 .78568 L F
.57612 .78573 m .57597 .79011 L .57619 .78568 L F
.57701 .73815 m .57615 .78143 L .57627 .78135 L F
.57819 .78194 m .57415 .78279 L .57167 .78449 L .683 .77 .917 r
F
.57415 .78279 m .56001 .78578 L .57167 .78449 L F
.57606 .78413 m .57379 .7854 L .57232 .78799 L F
.57546 .78302 m .57548 .78322 L .57548 .78749 L .779 .622 .059 r
F
.57643 .79277 m .57654 .80087 L .5762 .79261 L .928 .648 .489 r
F
.57703 .79302 m .57752 .80134 L .57652 .79284 L .844 .571 .525 r
F
.5771 .78934 m .57599 .79776 L .57711 .79699 L .404 .216 .509 r
F
.57819 .78194 m .57521 .78382 L .57606 .78413 L .683 .77 .917 r
F
.57819 .78194 m .57606 .78413 L .57696 .78445 L F
.57415 .78279 m .55952 .78293 L .56001 .78578 L F
.57541 .74075 m .57585 .78381 L .57575 .78364 L .988 .72 .386 r
F
.57819 .78194 m .57517 .7821 L .57415 .78279 L .683 .77 .917 r
F
.57517 .7821 m .55952 .78293 L .57415 .78279 L F
.57708 .78079 m .57612 .79001 L .5771 .78934 L .404 .216 .509 r
F
.57701 .73815 m .57627 .78135 L .57708 .78079 L F
.57619 .78568 m .5766 .7854 L .57708 .78079 L F
.57615 .78143 m .57596 .78156 L .57597 .78583 L F
.57589 .73892 m .57557 .78224 L .57596 .78156 L 0 0 .381 r
F
.57589 .73892 m .57543 .7825 L .57557 .78224 L F
.57649 .78099 m .56936 .77277 L .5654 .77475 L .683 .77 .917 r
F
.57819 .78194 m .57708 .78079 L .57649 .78099 L F
.57708 .78079 m .56936 .77277 L .57649 .78099 L F
.57811 .73781 m .57701 .73815 L .57708 .78079 L .569 .345 .536 r
F
.57638 .78846 m .57652 .78856 L .57654 .80087 L .928 .648 .489 r
F
.57918 .79107 m .57587 .79237 L .57646 .79279 L .683 .771 .917 r
F
.57424 .78602 m .56273 .78176 L .56071 .78457 L .683 .77 .917 r
F
.57548 .78322 m .57558 .78765 L .57548 .78749 L .988 .72 .386 r
F
.57546 .78302 m .57548 .78749 L .57547 .78734 L .779 .622 .059 r
F
.57868 .7865 m .57557 .78558 L .57424 .78602 L .683 .77 .917 r
F
.57557 .78558 m .56273 .78176 L .57424 .78602 L F
.57739 .78069 m .57708 .78079 L .57709 .78506 L .569 .345 .536 r
F
.57471 .78806 m .57422 .78893 L .57555 .78848 L .683 .77 .917 r
F
.57546 .78302 m .57548 .79167 L .57543 .7825 L .779 .622 .059 r
F
.57548 .79167 m .5755 .79959 L .57547 .79143 L F
.57548 .79167 m .57547 .79143 L .57543 .7825 L F
.57665 .78507 m .57726 .78603 L .57804 .78484 L .683 .77 .917 r
F
.5774 .78461 m .5775 .78892 L .57721 .78454 L .844 .571 .525 r
F
.57557 .78224 m .57543 .78677 L .57554 .78658 L 0 0 .381 r
F
.57543 .7825 m .57545 .78696 L .57543 .78677 L .779 .622 .059 r
F
.5774 .78461 m .57749 .78464 L .5775 .78892 L .844 .571 .525 r
F
.57282 .78222 m .5603 .78001 L .55952 .78293 L .683 .77 .917 r
F
.57819 .78194 m .57477 .78157 L .57282 .78222 L F
.57477 .78157 m .5603 .78001 L .57282 .78222 L F
.57819 .78194 m .57696 .78445 L .57804 .78484 L F
.57818 .78042 m .57731 .78499 L .57819 .78469 L .569 .345 .536 r
F
.57811 .73781 m .57739 .78069 L .57818 .78042 L F
.57739 .78069 m .57731 .78499 L .57818 .78042 L F
.57557 .78558 m .56583 .77928 L .56273 .78176 L .683 .77 .917 r
F
.57868 .7865 m .57648 .78527 L .57557 .78558 L F
.57648 .78527 m .56583 .77928 L .57557 .78558 L F
.57737 .79315 m .57751 .79319 L .57752 .80134 L .844 .571 .525 r
F
.5783 .79326 m .57804 .79324 L .5775 .78892 L .751 .492 .54 r
F
.57918 .79107 m .57722 .79309 L .57751 .79319 L .683 .771 .917 r
F
.57812 .79324 m .57751 .79319 L .57805 .79339 L F
.57918 .79107 m .57751 .79319 L .57812 .79324 L F
.5775 .78892 m .57737 .78919 L .57855 .789 L .683 .77 .917 r
F
.5779 .78895 m .5783 .79326 L .5775 .78892 L .751 .492 .54 r
F
.5783 .79326 m .57909 .8016 L .57804 .79324 L F
.5775 .78892 m .57909 .8016 L .57752 .80134 L F
.57819 .78469 m .57711 .79699 L .57821 .79665 L .569 .345 .536 r
F
.57918 .79107 m .57741 .78923 L .57647 .78955 L .683 .771 .917 r
F
.57868 .7865 m .57788 .78452 L .57721 .78498 L .683 .77 .917 r
F
.57868 .7865 m .57721 .78498 L .57665 .78536 L F
.57868 .7865 m .5775 .78892 L .57855 .789 L F
.57619 .78568 m .57612 .79001 L .5766 .7854 L .404 .216 .509 r
F
.57819 .78194 m .56231 .77722 L .5603 .78001 L .683 .77 .917 r
F
.57819 .78194 m .5654 .77475 L .56231 .77722 L F
.57665 .78536 m .56981 .77729 L .56583 .77928 L F
.57615 .78143 m .57597 .78583 L .57606 .78577 L .404 .216 .509 r
F
.57557 .78224 m .57543 .7825 L .57543 .78677 L 0 0 .381 r
F
.57721 .78498 m .56981 .77729 L .57665 .78536 L .683 .77 .917 r
F
.57606 .78577 m .57597 .78583 L .57597 .79011 L .404 .216 .509 r
F
.57741 .78923 m .57489 .7805 L .5703 .78186 L .683 .771 .917 r
F
.5793 .78479 m .5776 .79309 L .57935 .7848 L .683 .77 .917 r
F
.57742 .7425 m .57906 .78477 L .57861 .78474 L .751 .492 .54 r
F
.57811 .73781 m .57708 .78079 L .57739 .78069 L .569 .345 .536 r
F
.57868 .7865 m .57878 .78461 L .57796 .78473 L .683 .77 .917 r
F
.57861 .78474 m .57906 .78477 L .57907 .78905 L .751 .492 .54 r
F
.57861 .78474 m .57907 .78905 L .57873 .78902 L F
.57868 .7865 m .57855 .789 L .57974 .7891 L .683 .77 .917 r
F
.57819 .78194 m .57803 .78496 L .57932 .78473 L F
.58057 .74256 m .58159 .74213 L .58167 .78403 L .519 .305 .529 r
F
.57932 .78473 m .58245 .79245 L .58064 .78449 L .683 .77 .917 r
F
.58297 .79707 m .58725 .80762 L .59642 .80491 L F
.58234 .79435 m .58347 .80163 L .58805 .80028 L .683 .771 .917 r
F
.58144 .79341 m .58207 .79598 L .58234 .79435 L F
.58207 .79598 m .58347 .80163 L .58234 .79435 L F
.58086 .78894 m .58297 .79707 L .58096 .78886 L .683 .77 .917 r
F
.58282 .7914 m .58296 .79892 L .58284 .79972 L 0 0 .148 r
F
.58274 .74089 m .58285 .74008 L .58293 .78213 L F
.58226 .78617 m .58245 .79245 L .58701 .7911 L .683 .77 .917 r
F
.58245 .79245 m .59583 .80025 L .58701 .7911 L F
.58256 .78868 m .58755 .79571 L .59153 .79372 L F
.58184 .78874 m .58245 .79245 L .58226 .78617 L F
.58064 .78449 m .5809 .78562 L .58125 .78512 L F
.5809 .78562 m .58245 .79245 L .58125 .78512 L F
.58137 .78416 m .58145 .78841 L .58064 .78449 L .519 .305 .529 r
F
.58108 .79305 m .58126 .79368 L .58144 .79341 L .683 .771 .917 r
F
.58025 .7937 m .58347 .80163 L .58108 .79305 L F
.57976 .78916 m .58297 .79707 L .58081 .78873 L .683 .77 .917 r
F
.58065 .78876 m .58081 .78873 L .5808 .7887 L F
.57976 .78916 m .58081 .78873 L .58065 .78876 L F
.58019 .78457 m .58064 .78449 L .58065 .78876 L .642 .403 .541 r
F
.58101 .79297 m .58025 .7937 L .58108 .79305 L .683 .771 .917 r
F
.58003 .79315 m .58025 .7937 L .58101 .79297 L F
.57932 .78473 m .5793 .78479 L .57935 .7848 L .683 .77 .917 r
F
.58019 .78457 m .58031 .78882 L .57906 .78477 L .642 .403 .541 r
F
.57967 .78894 m .57976 .78916 L .58065 .78876 L .683 .77 .917 r
F
.58008 .79329 m .57859 .80228 L .58347 .80163 L .683 .771 .917 r
F
.58066 .79304 m .5817 .80096 L .58067 .8014 L .519 .305 .529 r
F
.58065 .78876 m .581 .79288 L .58066 .79304 L F
.581 .79288 m .5817 .80096 L .58066 .79304 L F
.58003 .79315 m .58 .79333 L .58008 .79329 L .683 .771 .917 r
F
.58 .79333 m .57859 .80228 L .58008 .79329 L F
.57906 .79332 m .57859 .80228 L .58003 .79315 L F
.57974 .7891 m .57852 .78971 L .57976 .78916 L .683 .77 .917 r
F
.57906 .78477 m .58067 .8014 L .57909 .8016 L .642 .403 .541 r
F
.57918 .79107 m .57906 .79332 L .58003 .79315 L .683 .771 .917 r
F
.58031 .78882 m .58043 .79308 L .57947 .78897 L .642 .403 .541 r
F
.58043 .79308 m .58067 .8014 L .57987 .79318 L F
.58043 .79308 m .57987 .79318 L .57947 .78897 L F
.58031 .78882 m .57947 .78897 L .57906 .78477 L F
.57868 .7865 m .57967 .78894 L .5808 .7887 L .683 .77 .917 r
F
.58019 .78457 m .58065 .78876 L .58031 .78882 L .642 .403 .541 r
F
.57967 .78894 m .58065 .78876 L .5808 .7887 L .683 .77 .917 r
F
.57918 .79107 m .58003 .79315 L .58101 .79297 L .683 .771 .917 r
F
.58031 .78882 m .58065 .78876 L .58066 .79304 L .642 .403 .541 r
F
.58043 .79308 m .58066 .79304 L .58067 .8014 L F
.58031 .78882 m .58066 .79304 L .58043 .79308 L F
.58255 .78323 m .59097 .78912 L .59406 .78665 L .683 .77 .917 r
F
.58057 .74256 m .58137 .78416 L .58064 .78449 L .519 .305 .529 r
F
.57819 .78194 m .58197 .78407 L .58255 .78323 L .683 .77 .917 r
F
.58159 .74213 m .5823 .74156 L .58237 .78348 L .361 .183 .5 r
F
.58197 .78407 m .58263 .78329 L .58237 .78348 L .683 .77 .917 r
F
.5818 .78825 m .5823 .79026 L .58256 .78868 L F
.58256 .78439 m .58701 .7911 L .5873 .79095 L F
.58701 .7911 m .60374 .7963 L .59097 .78912 L F
.58253 .78765 m .59153 .79372 L .59464 .79124 L F
.58145 .78841 m .58091 .78865 L .58064 .78449 L .519 .305 .529 r
F
.58064 .78449 m .58091 .78865 L .58065 .78876 L F
.57868 .7865 m .58177 .78824 L .58253 .78765 L .683 .77 .917 r
F
.5823 .79026 m .58755 .79571 L .58256 .78868 L F
.58282 .78713 m .58293 .79078 L .58282 .7914 L 0 0 .148 r
F
.58226 .78617 m .58701 .7911 L .58256 .78439 L .683 .77 .917 r
F
.58281 .78285 m .58287 .78682 L .58282 .78713 L 0 0 .148 r
F
.58256 .78868 m .59153 .79372 L .58271 .78777 L .683 .77 .917 r
F
.58287 .78682 m .58293 .79078 L .58282 .78713 L 0 0 .148 r
F
.58177 .78824 m .58256 .78868 L .58253 .78765 L .683 .77 .917 r
F
.58256 .78868 m .58271 .78777 L .58253 .78765 L F
.57819 .78194 m .58226 .78617 L .58256 .78439 L F
.58217 .78364 m .58237 .78348 L .58238 .78776 L .361 .183 .5 r
F
.58245 .79245 m .58671 .80296 L .59583 .80025 L .683 .77 .917 r
F
.58134 .78927 m .58297 .79707 L .58755 .79571 L F
.58701 .7911 m .59583 .80025 L .60374 .7963 L F
.58755 .79571 m .60437 .80094 L .59153 .79372 L F
.5824 .79203 m .59203 .79829 L .59513 .79581 L .683 .771 .917 r
F
.58113 .78957 m .58297 .79707 L .58134 .78927 L .683 .77 .917 r
F
.58223 .78788 m .5824 .8004 L .58167 .78831 L .361 .183 .5 r
F
.5808 .7887 m .58086 .78894 L .58096 .78886 L .683 .77 .917 r
F
.58091 .78865 m .5817 .80096 L .58065 .78876 L .519 .305 .529 r
F
.57918 .79107 m .58176 .79252 L .5824 .79203 L .683 .771 .917 r
F
.58197 .78407 m .58463 .78556 L .58263 .78329 L .683 .77 .917 r
F
.58463 .78556 m .59097 .78912 L .58397 .78423 L F
.58463 .78556 m .58397 .78423 L .58263 .78329 L F
.5823 .74156 m .58274 .74089 L .58281 .78285 L .082 0 .419 r
F
.58285 .74008 m .58241 .73904 L .58248 .78123 L .984 .727 .338 r
F
.58237 .78348 m .58263 .78329 L .58255 .78323 L .683 .77 .917 r
F
.58268 .78303 m .58272 .78726 L .58237 .78348 L .082 0 .419 r
F
.58272 .78726 m .58276 .79149 L .58257 .78749 L F
.58272 .78726 m .58257 .78749 L .58237 .78348 L F
.5831 .78247 m .59406 .78665 L .59606 .78387 L .683 .77 .917 r
F
.57819 .78194 m .58364 .78356 L .5831 .78247 L F
.58364 .78356 m .59406 .78665 L .5831 .78247 L F
.58463 .78556 m .5873 .79095 L .59097 .78912 L F
.59097 .78912 m .60992 .79137 L .59406 .78665 L F
.58323 .78699 m .59464 .79124 L .59665 .78844 L F
.58125 .78512 m .58184 .78874 L .58226 .78617 L F
.58167 .78403 m .58223 .78788 L .58167 .78831 L .361 .183 .5 r
F
.58159 .74213 m .58217 .78364 L .58167 .78403 L F
.58217 .78364 m .58223 .78788 L .58167 .78403 L F
.58482 .78158 m .59606 .78387 L .59685 .78094 L .683 .77 .917 r
F
.58159 .74213 m .58237 .78348 L .58217 .78364 L .361 .183 .5 r
F
.58223 .78788 m .58238 .78776 L .58239 .79204 L F
.58229 .79211 m .58239 .79204 L .5824 .8004 L F
.58223 .78788 m .58239 .79204 L .58229 .79211 L F
.58217 .78364 m .58238 .78776 L .58223 .78788 L F
.58126 .79368 m .58347 .80163 L .58144 .79341 L .683 .771 .917 r
F
.58192 .7924 m .5824 .8004 L .58168 .79258 L .361 .183 .5 r
F
.59153 .79372 m .61058 .79598 L .59464 .79124 L .683 .77 .917 r
F
.58567 .79177 m .59513 .79581 L .59715 .79301 L .683 .771 .917 r
F
.58154 .79265 m .58118 .79281 L .58091 .78865 L .519 .305 .529 r
F
.57918 .79107 m .58941 .79411 L .58567 .79177 L .683 .771 .917 r
F
.58941 .79411 m .59513 .79581 L .58567 .79177 L F
.5825 .78978 m .58146 .79707 L .58251 .79788 L .909 .63 .501 r
F
.58366 .78624 m .59665 .78844 L .59745 .78551 L .683 .77 .917 r
F
.5823 .74156 m .58268 .78303 L .58237 .78348 L .082 0 .419 r
F
.58256 .78138 m .58248 .78123 L .58249 .78551 L .984 .727 .338 r
F
.58137 .78416 m .58167 .78831 L .58145 .78841 L .519 .305 .529 r
F
.57868 .7865 m .58373 .788 L .58323 .78699 L .683 .77 .917 r
F
.58237 .78348 m .58276 .79149 L .58239 .79204 L .082 0 .419 r
F
.58253 .78558 m .58249 .78551 L .5825 .78978 L .984 .727 .338 r
F
.58256 .78138 m .58249 .78551 L .58253 .78558 L F
.58287 .78628 m .58521 .78721 L .58366 .78624 L .683 .77 .917 r
F
.58137 .78416 m .58167 .78403 L .58167 .78831 L .519 .305 .529 r
F
.57868 .7865 m .58323 .78699 L .58287 .78628 L .683 .77 .917 r
F
.58323 .78699 m .58521 .78721 L .58287 .78628 L F
.58256 .78439 m .5873 .79095 L .58463 .78556 L F
.58521 .78721 m .59665 .78844 L .58366 .78624 L F
.58249 .78551 m .58195 .78944 L .5825 .78978 L .909 .63 .501 r
F
.58248 .78123 m .58222 .78534 L .58249 .78551 L F
.58222 .78534 m .58195 .78944 L .58249 .78551 L F
.58195 .78944 m .58146 .79707 L .5825 .78978 L F
.58241 .73904 m .58173 .78076 L .58248 .78123 L F
.57819 .78194 m .58361 .78252 L .58403 .7822 L .683 .77 .917 r
F
.57819 .78194 m .58403 .7822 L .58319 .78167 L F
.57868 .7865 m .58342 .78625 L .5835 .78614 L F
.58272 .78565 m .5835 .78614 L .58402 .78537 L F
.57868 .7865 m .5835 .78614 L .58272 .78565 L F
.58173 .78076 m .58166 .78499 L .58248 .78123 L .909 .63 .501 r
F
.5808 .7887 m .5823 .79026 L .5818 .78825 L .683 .77 .917 r
F
.58167 .78831 m .58192 .7924 L .58168 .79258 L .361 .183 .5 r
F
.58145 .78841 m .58167 .78831 L .5817 .80096 L .519 .305 .529 r
F
.58361 .78252 m .59606 .78387 L .58482 .78158 L .683 .77 .917 r
F
.58095 .79291 m .58734 .79953 L .58179 .79254 L .683 .771 .917 r
F
.58297 .79707 m .59642 .80491 L .58755 .79571 L .683 .77 .917 r
F
.58734 .79953 m .58805 .80028 L .58716 .79917 L .683 .771 .917 r
F
.58734 .79953 m .58716 .79917 L .58179 .79254 L F
.58176 .79252 m .58257 .79297 L .5824 .79203 L F
.58257 .79297 m .58467 .79415 L .58268 .79229 L F
.58257 .79297 m .58268 .79229 L .5824 .79203 L F
.58291 .78656 m .58294 .7864 L .58294 .79068 L 0 0 .148 r
F
.58179 .79254 m .58805 .80028 L .59203 .79829 L .683 .771 .917 r
F
.58293 .79078 m .58294 .79068 L .58296 .79892 L 0 0 .148 r
F
.58291 .78656 m .58294 .79068 L .58293 .79078 L F
.58272 .78726 m .58282 .78713 L .58282 .7914 L .082 0 .419 r
F
.58276 .79149 m .58282 .7914 L .58284 .79972 L F
.58272 .78726 m .58282 .7914 L .58276 .79149 L F
.5832 .79086 m .59715 .79301 L .59794 .79007 L .683 .771 .917 r
F
.57918 .79107 m .58279 .79146 L .5832 .79086 L F
.58279 .79146 m .59715 .79301 L .5832 .79086 L F
.58293 .79078 m .58296 .79892 L .58282 .7914 L 0 0 .148 r
F
.58239 .79204 m .58284 .79972 L .5824 .8004 L .082 0 .419 r
F
.58294 .79068 m .58251 .79788 L .58296 .79892 L .984 .727 .338 r
F
.58294 .7864 m .58279 .79037 L .58294 .79068 L F
.58276 .79149 m .58284 .79972 L .58239 .79204 L .082 0 .419 r
F
.58279 .79037 m .58251 .79788 L .58294 .79068 L .984 .727 .338 r
F
.58154 .79265 m .5817 .80096 L .58118 .79281 L .519 .305 .529 r
F
.58241 .73904 m .58136 .73823 L .58143 .78057 L .909 .63 .501 r
F
.5823 .74156 m .58281 .78285 L .58277 .78291 L .082 0 .419 r
F
.58434 .78064 m .59685 .78094 L .59637 .77809 L .683 .77 .917 r
F
.58224 .78108 m .58404 .78106 L .58434 .78064 L F
.58404 .78106 m .59685 .78094 L .58434 .78064 L F
.58268 .78303 m .58282 .78713 L .58272 .78726 L .082 0 .419 r
F
.5823 .74156 m .58277 .78291 L .58268 .78303 L F
.58277 .78291 m .58282 .78713 L .58268 .78303 L F
.58274 .74089 m .58293 .78213 L .58289 .78234 L 0 0 .148 r
F
.58274 .74089 m .58289 .78234 L .58281 .78285 L F
.58319 .78167 m .59685 .78094 L .58224 .78108 L .683 .77 .917 r
F
.58261 .78149 m .58255 .78563 L .58258 .7857 L .984 .727 .338 r
F
.58256 .78138 m .58253 .78558 L .58261 .78149 L F
.58253 .78558 m .5825 .78978 L .58255 .78563 L F
.58253 .78558 m .58255 .78563 L .58261 .78149 L F
.58196 .78444 m .59523 .78003 L .59237 .77787 L .683 .77 .917 r
F
.58166 .78499 m .58222 .78534 L .58248 .78123 L .909 .63 .501 r
F
.58137 .78481 m .58203 .78458 L .58196 .78444 L .683 .77 .917 r
F
.58277 .78291 m .58281 .78285 L .58282 .78713 L .082 0 .419 r
F
.58203 .78458 m .59523 .78003 L .58196 .78444 L .683 .77 .917 r
F
.58096 .78886 m .58113 .78957 L .58134 .78927 L F
.58145 .78841 m .58154 .79265 L .58091 .78865 L .519 .305 .529 r
F
.58144 .78485 m .58039 .79669 L .58146 .79707 L .809 .541 .533 r
F
.57819 .78194 m .58319 .78167 L .58224 .78108 L .683 .77 .917 r
F
.58057 .74256 m .58167 .78403 L .58137 .78416 L .519 .305 .529 r
F
.57899 .74276 m .58064 .78449 L .58019 .78457 L .642 .403 .541 r
F
.57928 .78027 m .57821 .79665 L .5793 .79656 L .66 .418 .542 r
F
.57921 .73772 m .57849 .78038 L .57928 .78027 L F
.57819 .78194 m .57913 .78001 L .5783 .7798 L .683 .77 .917 r
F
.57899 .74276 m .58019 .78457 L .57906 .78477 L .642 .403 .541 r
F
.57819 .78194 m .57932 .78473 L .58064 .78449 L .683 .77 .917 r
F
.57849 .78038 m .57834 .78895 L .57928 .78027 L .66 .418 .542 r
F
.57834 .78895 m .57872 .7889 L .579 .78458 L F
.57881 .78461 m .579 .78458 L .57928 .78027 L F
.57868 .7865 m .57967 .78449 L .57878 .78461 L .683 .77 .917 r
F
.57834 .78895 m .579 .78458 L .57881 .78461 L .66 .418 .542 r
F
.58066 .78038 m .58037 .78459 L .58059 .78464 L .809 .541 .533 r
F
.58136 .73823 m .58046 .78033 L .58066 .78038 L F
.58046 .78033 m .58037 .78459 L .58066 .78038 L F
.58285 .74008 m .58256 .78138 L .58261 .78149 L .984 .727 .338 r
F
.58285 .74008 m .58248 .78123 L .58256 .78138 L F
.58285 .74008 m .58261 .78149 L .58293 .78213 L F
.57899 .74276 m .58057 .74256 L .58064 .78449 L .642 .403 .541 r
F
.58036 .78031 m .5793 .79656 L .58039 .79669 L .734 .478 .541 r
F
.58029 .73785 m .57958 .78028 L .58036 .78031 L F
.57819 .78194 m .58065 .78038 L .58036 .78031 L .683 .77 .917 r
F
.58173 .78076 m .58144 .78485 L .58166 .78499 L .909 .63 .501 r
F
.58319 .78167 m .58403 .7822 L .58482 .78158 L .683 .77 .917 r
F
.58126 .78 m .59465 .7755 L .5918 .77335 L F
.58136 .73823 m .58066 .78038 L .58143 .78057 L .809 .541 .533 r
F
.58029 .73785 m .57921 .73772 L .57928 .78027 L .734 .478 .541 r
F
.57819 .78194 m .58036 .78031 L .57978 .78029 L .683 .77 .917 r
F
.57958 .78028 m .57928 .78027 L .57929 .78882 L .734 .478 .541 r
F
.57868 .7865 m .58165 .78464 L .58054 .78459 L .683 .77 .917 r
F
.57958 .78028 m .57929 .78882 L .57943 .78883 L .734 .478 .541 r
F
.58074 .78033 m .58417 .7796 L .58126 .78 L .683 .77 .917 r
F
.58217 .78038 m .58417 .7796 L .58074 .78033 L F
.58417 .7796 m .59465 .7755 L .58126 .78 L F
.58065 .78038 m .5918 .77335 L .57988 .78019 L F
.58143 .78057 m .58059 .78464 L .58144 .78485 L .809 .541 .533 r
F
.58173 .78076 m .58143 .78057 L .58144 .78485 L .909 .63 .501 r
F
.57868 .7865 m .58858 .77629 L .58411 .77541 L .683 .77 .917 r
F
.5793 .78882 m .57977 .77986 L .57835 .78878 L .683 .771 .917 r
F
.57929 .78882 m .57835 .78878 L .57832 .78895 L F
.5793 .78882 m .57835 .78878 L .57929 .78882 L F
.57943 .78883 m .57929 .78882 L .5793 .79656 L .734 .478 .541 r
F
.58029 .73785 m .57928 .78027 L .57958 .78028 L F
.57819 .78194 m .58217 .78038 L .58074 .78033 L .683 .77 .917 r
F
.57849 .78038 m .5782 .78897 L .57834 .78895 L .66 .418 .542 r
F
.57921 .73772 m .57837 .78039 L .57849 .78038 L F
.57837 .78039 m .5782 .78897 L .57849 .78038 L F
.57819 .78194 m .59637 .77809 L .59465 .7755 L .683 .77 .917 r
F
.58054 .78459 m .59237 .77787 L .58858 .77629 L F
.58289 .78234 m .58293 .78213 L .58294 .7864 L 0 0 .148 r
F
.58165 .78464 m .59237 .77787 L .58054 .78459 L .683 .77 .917 r
F
.57958 .78028 m .57951 .78455 L .58036 .78031 L .734 .478 .541 r
F
.57868 .7865 m .58201 .7852 L .58144 .78485 L .683 .77 .917 r
F
.57951 .78455 m .57943 .78883 L .58008 .78457 L .734 .478 .541 r
F
.57868 .7865 m .5808 .7887 L .5818 .78825 L .683 .77 .917 r
F
.57943 .78883 m .57981 .78884 L .58008 .78457 L .734 .478 .541 r
F
.57951 .78455 m .58008 .78457 L .58036 .78031 L F
.57978 .78029 m .58036 .78031 L .57988 .78019 L .683 .77 .917 r
F
.58046 .78033 m .58036 .78031 L .58037 .78459 L .809 .541 .533 r
F
.57899 .78425 m .58411 .77541 L .5788 .7842 L .683 .77 .917 r
F
.58066 .78038 m .58059 .78464 L .58143 .78057 L .809 .541 .533 r
F
.57967 .78449 m .58411 .77541 L .57878 .78461 L .683 .77 .917 r
F
.58134 .78483 m .58144 .78485 L .58137 .78481 L F
.57868 .7865 m .58144 .78485 L .58134 .78483 L F
.5793 .78882 m .58461 .77998 L .57977 .77986 L .683 .771 .917 r
F
.57918 .79107 m .58026 .78886 L .5793 .78882 L F
.58289 .78234 m .58294 .7864 L .58291 .78656 L 0 0 .148 r
F
.58321 .78473 m .59696 .78264 L .59523 .78003 L .683 .77 .917 r
F
.58291 .78656 m .58287 .78682 L .58281 .78285 L 0 0 .148 r
F
.58289 .78234 m .58291 .78656 L .58281 .78285 L F
.58293 .78213 m .58282 .78617 L .58294 .7864 L .984 .727 .338 r
F
.58229 .7851 m .58307 .78558 L .58321 .78473 L .683 .77 .917 r
F
.57868 .7865 m .58258 .78568 L .58229 .7851 L F
.58201 .7852 m .58229 .7851 L .58137 .78481 L F
.58258 .7857 m .58274 .78602 L .58293 .78213 L .984 .727 .338 r
F
.58229 .7851 m .59523 .78003 L .58203 .78458 L .683 .77 .917 r
F
.58229 .7851 m .58203 .78458 L .58137 .78481 L F
.58261 .78149 m .58258 .7857 L .58293 .78213 L .984 .727 .338 r
F
.58258 .7857 m .58256 .78991 L .58274 .78602 L F
.58256 .78991 m .58251 .79788 L .58271 .79022 L F
.58256 .78991 m .58271 .79022 L .58293 .78213 L F
.58276 .79031 m .59794 .79007 L .59746 .78721 L .683 .771 .917 r
F
.57918 .79107 m .58304 .79087 L .58276 .79031 L F
.58304 .79087 m .59794 .79007 L .58276 .79031 L F
.58258 .78568 m .58307 .78558 L .58229 .7851 L .683 .77 .917 r
F
.58307 .78558 m .59696 .78264 L .58321 .78473 L F
.58291 .78656 m .58293 .79078 L .58287 .78682 L 0 0 .148 r
F
.58026 .78886 m .58461 .77998 L .5793 .78882 L .683 .771 .917 r
F
.57918 .79107 m .58095 .79291 L .58179 .79254 L F
.57943 .78883 m .5793 .79656 L .57981 .78884 L .734 .478 .541 r
F
.57988 .78019 m .5918 .77335 L .58803 .77178 L .683 .77 .917 r
F
.57913 .78001 m .58803 .77178 L .58358 .7709 L F
.57819 .78194 m .57988 .78019 L .57913 .78001 L F
.57988 .78019 m .58803 .77178 L .57913 .78001 L F
.58136 .73823 m .58029 .73785 L .58036 .78031 L .809 .541 .533 r
F
.58136 .73823 m .58036 .78031 L .58046 .78033 L F
.58166 .78499 m .58159 .78921 L .58222 .78534 L .909 .63 .501 r
F
.58027 .78884 m .58908 .78086 L .58461 .77998 L .683 .771 .917 r
F
.57918 .79107 m .58114 .78905 L .58027 .78884 L F
.58059 .78464 m .58052 .7889 L .58144 .78485 L .809 .541 .533 r
F
.57918 .79107 m .58186 .78938 L .58145 .78913 L .683 .771 .917 r
F
.57918 .79107 m .58145 .78913 L .58114 .78905 L F
.58052 .7889 m .58039 .79669 L .58107 .78903 L .809 .541 .533 r
F
.58052 .7889 m .58107 .78903 L .58144 .78485 L F
.58114 .78905 m .58145 .78913 L .58121 .78898 L .683 .771 .917 r
F
.58159 .78921 m .58195 .78944 L .58222 .78534 L .909 .63 .501 r
F
.58255 .78563 m .5825 .78978 L .58258 .7857 L .984 .727 .338 r
F
.58114 .78905 m .58908 .78086 L .58027 .78884 L .683 .771 .917 r
F
.58059 .78464 m .58037 .78459 L .58037 .78886 L .809 .541 .533 r
F
.58052 .7889 m .58037 .78886 L .58039 .79669 L F
.58059 .78464 m .58037 .78886 L .58052 .7889 L F
.57913 .78001 m .58141 .77534 L .57903 .77998 L .683 .77 .917 r
F
.58141 .77534 m .58358 .7709 L .57903 .77998 L F
.57903 .77998 m .58358 .7709 L .5783 .7798 L F
.5788 .7842 m .58411 .77541 L .57927 .77529 L F
.57878 .78461 m .57899 .78425 L .5788 .7842 L F
.57819 .78194 m .57877 .77078 L .57392 .77142 L F
.57796 .78473 m .57927 .77529 L .57439 .77593 L F
.57878 .78461 m .57927 .77529 L .57796 .78473 L F
.57828 .78468 m .57819 .78469 L .5782 .78897 L .66 .418 .542 r
F
.57731 .78499 m .57724 .78929 L .57819 .78469 L .569 .345 .536 r
F
.57739 .78069 m .57709 .78506 L .57731 .78499 L F
.57627 .78135 m .57619 .78568 L .57708 .78079 L .404 .216 .509 r
F
.57788 .78452 m .57439 .77593 L .57721 .78498 L .683 .77 .917 r
F
.57832 .78895 m .57977 .77986 L .57489 .7805 L .683 .771 .917 r
F
.57918 .79107 m .5793 .78882 L .57832 .78895 L F
.57834 .78895 m .57821 .79665 L .57872 .7889 L .66 .418 .542 r
F
.5783 .7798 m .58358 .7709 L .57877 .77078 L .683 .77 .917 r
F
.58166 .78499 m .58144 .78485 L .58146 .79707 L .909 .63 .501 r
F
.58241 .73904 m .58143 .78057 L .58173 .78076 L F
.58121 .78898 m .59287 .78244 L .58908 .78086 L .683 .771 .917 r
F
.58258 .7857 m .5825 .78978 L .58256 .78991 L .984 .727 .338 r
F
.58186 .78938 m .59287 .78244 L .58121 .78898 L .683 .771 .917 r
F
.58159 .78921 m .58146 .79707 L .58195 .78944 L .909 .63 .501 r
F
.58373 .788 m .59464 .79124 L .58323 .78699 L .683 .77 .917 r
F
.58402 .78537 m .59745 .78551 L .59696 .78264 L F
.58342 .78625 m .59745 .78551 L .58402 .78537 L F
.58256 .78991 m .5825 .78978 L .58251 .79788 L .984 .727 .338 r
F
.58467 .79415 m .59203 .79829 L .58419 .79319 L .683 .771 .917 r
F
.58467 .79415 m .58419 .79319 L .5824 .79203 L F
.58249 .78978 m .59746 .78721 L .59573 .7846 L F
.57918 .79107 m .58276 .79031 L .58249 .78978 L F
.58276 .79031 m .59746 .78721 L .58249 .78978 L F
.58282 .78617 m .58271 .79022 L .58294 .7864 L .984 .727 .338 r
F
.58271 .79022 m .58251 .79788 L .58279 .79037 L F
.58271 .79022 m .58279 .79037 L .58294 .7864 L F
.58168 .79258 m .5824 .8004 L .5817 .80096 L .361 .183 .5 r
F
.57921 .73772 m .57811 .73781 L .57819 .78469 L .66 .418 .542 r
F
.57921 .73772 m .57819 .78469 L .57828 .78468 L F
.57918 .79107 m .57832 .78895 L .57741 .78923 L .683 .771 .917 r
F
.57834 .78895 m .5782 .78897 L .57821 .79665 L .66 .418 .542 r
F
.57832 .78895 m .57831 .78893 L .5782 .78897 L .683 .771 .917 r
F
.57832 .78895 m .5782 .78897 L .57741 .78923 L F
.57724 .78929 m .5778 .7891 L .57819 .78469 L .569 .345 .536 r
F
.57731 .78499 m .57709 .78506 L .5771 .78934 L F
.57731 .78499 m .5771 .78934 L .57724 .78929 L F
.57831 .78893 m .57489 .7805 L .57741 .78923 L .683 .771 .917 r
F
.57724 .78929 m .57711 .79699 L .5778 .7891 L .569 .345 .536 r
F
.57529 .78889 m .5703 .78186 L .56632 .78385 L .683 .771 .917 r
F
.57647 .78955 m .57523 .788 L .57529 .78889 L F
.57523 .788 m .5703 .78186 L .57529 .78889 L F
.57741 .78923 m .5703 .78186 L .57647 .78955 L F
.57724 .78929 m .5771 .78934 L .57711 .79699 L .569 .345 .536 r
F
.57721 .78498 m .57439 .77593 L .56981 .77729 L .683 .77 .917 r
F
.57643 .79277 m .5762 .79261 L .57603 .78821 L .928 .648 .489 r
F
.57677 .78865 m .57703 .79302 L .57652 .78856 L .844 .571 .525 r
F
.57612 .79001 m .57599 .79776 L .5771 .78934 L .404 .216 .509 r
F
.57587 .79237 m .56838 .7953 L .57646 .79279 L .683 .771 .917 r
F
.56501 .79513 m .55892 .8069 L .5688 .79671 L .683 .77 .917 r
F
.56838 .7953 m .56264 .79754 L .56758 .79584 L .683 .771 .917 r
F
.56838 .7953 m .56758 .79584 L .57646 .79279 L F
.57701 .73815 m .57596 .78156 L .57615 .78143 L .404 .216 .509 r
F
.57612 .79001 m .57597 .79011 L .57599 .79776 L F
.56758 .79584 m .56264 .79754 L .56381 .79842 L .683 .771 .917 r
F
.56758 .79584 m .56381 .79842 L .5655 .7997 L F
.57543 .78677 m .5755 .79959 L .57545 .79878 L .779 .622 .059 r
F
.57545 .78696 m .57547 .79143 L .57543 .78677 L F
.57547 .79143 m .5755 .79959 L .57546 .7913 L F
.57547 .79143 m .57546 .7913 L .57543 .78677 L F
.57546 .79127 m .56121 .78913 L .56042 .79207 L .683 .771 .917 r
F
.57554 .78658 m .57543 .78677 L .57544 .79105 L 0 0 .381 r
F
.57551 .79093 m .57544 .79105 L .57545 .79878 L F
.57554 .78658 m .57544 .79105 L .57551 .79093 L F
.57918 .79107 m .57564 .79069 L .57546 .79127 L .683 .771 .917 r
F
.57564 .79069 m .57541 .79067 L .57544 .79105 L F
.57564 .79069 m .57544 .79105 L .57546 .79127 L F
.57541 .79067 m .56121 .78913 L .57546 .79127 L F
.40759 .92827 m .40044 .9348 L .40952 .92995 L .644 .733 .913 r
F
.40759 .92827 m .39659 .93142 L .40044 .9348 L F
.536 .69489 m .51477 .68774 L .50676 .6988 L .673 .758 .914 r
F
.42724 .931 m .43587 .93688 L .43999 .93397 L .644 .733 .913 r
F
.42459 .93205 m .43587 .93688 L .42724 .931 L F
.53817 .81694 m .54905 .81709 L .54954 .82166 L .859 .591 .531 r
F
.53817 .81694 m .53767 .81238 L .54905 .81709 L F
.55134 .80376 m .54905 .81709 L .55892 .8069 L .683 .77 .917 r
F
.55134 .80376 m .53767 .81238 L .54905 .81709 L F
0 g
.54905 .81709 m
.55318 .8179 L
s
.40492 .822 m .39072 .82151 L .3912 .82607 L .607 .406 .583 r
F
.40492 .822 m .40444 .81743 L .39072 .82151 L F
0 g
.37883 .82746 m
.39072 .82151 L
s
.51477 .69331 m .5064 .69875 L .50672 .70441 L .171 .075 .496 r
F
.51477 .69331 m .51445 .68764 L .5064 .69875 L F
0 g
.50327 .71056 m
.5064 .69875 L
s
.6172 .80814 m .6167 .80358 L .62601 .79615 L .407 .263 .571 r
F
.127 .923 .03 r
.66906 .84622 m
.671 .78846 L
s
0 g
.60985 .807 m
.6167 .80358 L
s
.7015 .58394 m .66448 .58027 L .69113 .59175 L .654 .726 .902 r
F
.58562 .69449 m .57996 .67901 L .57919 .6941 L .673 .758 .914 r
F
.58562 .69449 m .59283 .6798 L .57996 .67901 L F
.39749 .69165 m .39718 .68598 L .40027 .67415 L 0 0 .319 r
F
0 g
.39264 .6923 m
.39718 .68598 L
s
.60374 .7963 m .61651 .80347 L .62577 .79608 L .683 .77 .917 r
F
.59583 .80025 m .61651 .80347 L .60374 .7963 L F
.70251 .56955 m .68115 .55424 L .66569 .5659 L .654 .726 .902 r
F
.71574 .56386 m .68115 .55424 L .70251 .56955 L F
.7454 .59459 m .74641 .57447 L .73011 .575 L F
.3729 .68246 m .39682 .68593 L .39989 .67416 L .673 .757 .914 r
F
.65228 .70741 m .64504 .69091 L .64537 .69658 L .986 .711 .379 r
F
0 g
.65228 .70741 m
.65421 .71913 L
s
.26136 .56311 m .24647 .56756 L .24601 .57483 L .338 .16 .486 r
F
.25124 .55971 m .2517 .55244 L .27611 .55165 L .667 .432 .555 r
F
.25237 .53208 m .25171 .55214 L .276 .55135 L .654 .726 .902 r
F
.25609 .56468 m .26182 .55584 L .24647 .56756 L .338 .16 .486 r
F
.26424 .56186 m .26182 .55584 L .26136 .56311 L .492 .285 .526 r
F
.29685 .56569 m .28708 .55387 L .26215 .55607 L .654 .726 .902 r
F
.2644 .55928 m .26731 .5545 L .27565 .55892 L .667 .432 .555 r
F
.26465 .55536 m .26731 .5545 L .2644 .55928 L F
.28708 .55387 m .26563 .55456 L .26215 .55607 L .654 .726 .902 r
F
.26731 .5545 m .27595 .55422 L .27565 .55892 L .667 .432 .555 r
F
.27431 .55499 m .26464 .55565 L .2644 .55928 L .492 .285 .526 r
F
.26984 .55418 m .2631 .55933 L .2644 .55928 L .654 .726 .902 r
F
.27203 .55598 m .2644 .55928 L .27565 .55892 L F
.26984 .55418 m .2644 .55928 L .27203 .55598 L F
.26731 .5545 m .27611 .55165 L .27595 .55422 L .667 .432 .555 r
F
.27595 .55422 m .28184 .54753 L .26563 .55456 L .654 .726 .902 r
F
.28708 .55387 m .28567 .55216 L .27595 .55422 L F
.29073 .55109 m .27611 .55165 L .29899 .5468 L .592 .368 .545 r
F
.27595 .55422 m .27611 .55165 L .29073 .55109 L F
.28567 .55216 m .28184 .54753 L .27595 .55422 L .654 .726 .902 r
F
.26857 .53156 m .276 .55135 L .29877 .54653 L F
.31203 .56248 m .28955 .55134 L .29685 .56569 L F
.28955 .55134 m .28184 .54753 L .28567 .55216 L F
.28955 .55134 m .28567 .55216 L .29685 .56569 L F
.29073 .55109 m .29899 .5468 L .29883 .54937 L .592 .368 .545 r
F
.26857 .53156 m .29877 .54653 L .28376 .52834 L .654 .726 .902 r
F
.28376 .52834 m .29877 .54653 L .31848 .53798 L F
.29176 .55244 m .30462 .5427 L .28184 .54753 L F
.31203 .56248 m .30597 .54628 L .29176 .55244 L F
.29883 .54937 m .29899 .5468 L .31164 .54383 L .492 .285 .526 r
F
.30597 .54628 m .30462 .5427 L .29176 .55244 L .654 .726 .902 r
F
.31164 .54383 m .29899 .5468 L .31592 .53946 L .492 .285 .526 r
F
.32821 .56196 m .30796 .54542 L .31203 .56248 L .654 .726 .902 r
F
.30796 .54542 m .30462 .5427 L .30597 .54628 L F
.30796 .54542 m .30597 .54628 L .31203 .56248 L F
.32821 .56196 m .32892 .54192 L .31665 .54231 L F
.31019 .54724 m .31665 .54231 L .30462 .5427 L F
.32821 .56196 m .31665 .54231 L .31019 .54724 L F
.3286 .5332 m .31881 .53821 L .33421 .52646 L .339 .161 .487 r
F
.32848 .54889 m .32893 .54161 L .31576 .54204 L .667 .432 .555 r
F
.31164 .54383 m .31576 .54204 L .31559 .5448 L .492 .285 .526 r
F
.31555 .54539 m .31576 .54204 L .30451 .5424 L .667 .432 .555 r
F
.32848 .54889 m .31576 .54204 L .31555 .54539 L F
.31559 .5448 m .31865 .54079 L .31835 .54549 L .492 .285 .526 r
F
.31576 .54204 m .31865 .54079 L .31559 .5448 L F
.31835 .54549 m .31865 .54079 L .3286 .5332 L .339 .161 .487 r
F
.31865 .54079 m .31881 .53821 L .3286 .5332 L F
.29854 .55407 m .31559 .5448 L .31547 .54674 L .492 .285 .526 r
F
.27565 .55892 m .29073 .55109 L .29854 .55407 L .592 .368 .545 r
F
.29073 .55109 m .29883 .54937 L .29854 .55407 L F
.27565 .55892 m .27595 .55422 L .29073 .55109 L F
.29397 .55181 m .28573 .55679 L .29854 .55407 L .654 .726 .902 r
F
.25237 .53208 m .276 .55135 L .26857 .53156 L F
.27431 .55499 m .28162 .54725 L .26182 .55584 L .492 .285 .526 r
F
.28132 .55195 m .28162 .54725 L .27431 .55499 L F
.28101 .55202 m .27565 .55892 L .28573 .55679 L .654 .726 .902 r
F
.26818 .53903 m .27364 .55358 L .28101 .55202 L F
.27364 .55358 m .27565 .55892 L .28101 .55202 L F
.28822 .54896 m .28573 .55679 L .29397 .55181 L F
.29854 .55407 m .31164 .54383 L .31559 .5448 L .492 .285 .526 r
F
.32848 .54889 m .31555 .54539 L .31531 .54931 L .667 .432 .555 r
F
.31547 .54674 m .31559 .5448 L .31835 .54549 L .492 .285 .526 r
F
.31149 .54686 m .30451 .5424 L .30422 .5471 L .667 .432 .555 r
F
.31555 .54539 m .30451 .5424 L .31531 .54931 L F
.29611 .54882 m .30451 .5424 L .28162 .54725 L .592 .368 .545 r
F
.29854 .55407 m .29883 .54937 L .31164 .54383 L .492 .285 .526 r
F
.29308 .54746 m .29854 .55407 L .31547 .54674 L .654 .726 .902 r
F
.30406 .54967 m .30422 .5471 L .29611 .54882 L .592 .368 .545 r
F
.30422 .5471 m .30451 .5424 L .29611 .54882 L F
.28345 .5358 m .29308 .54746 L .30803 .54629 L .654 .726 .902 r
F
.31553 .5447 m .30803 .54629 L .31835 .54549 L F
.28345 .5358 m .30803 .54629 L .31553 .5447 L F
.29308 .54746 m .31547 .54674 L .31835 .54549 L F
.31531 .54931 m .31149 .54686 L .30406 .54967 L .667 .432 .555 r
F
.31149 .54686 m .30422 .5471 L .30406 .54967 L F
.29611 .54882 m .28162 .54725 L .28132 .55195 L .592 .368 .545 r
F
.26818 .53903 m .29854 .55407 L .28345 .5358 L .654 .726 .902 r
F
.30406 .54967 m .29611 .54882 L .28116 .55452 L .592 .368 .545 r
F
.28106 .55206 m .28573 .55679 L .28822 .54896 L .654 .726 .902 r
F
.29611 .54882 m .28132 .55195 L .28116 .55452 L .592 .368 .545 r
F
.28116 .55452 m .28132 .55195 L .27431 .55499 L .492 .285 .526 r
F
.26818 .53903 m .28106 .55206 L .28822 .54896 L .654 .726 .902 r
F
.29027 .55836 m .27565 .55892 L .29854 .55407 L .592 .368 .545 r
F
.27549 .5615 m .27565 .55892 L .29027 .55836 L F
.29624 .57278 m .28662 .56114 L .26136 .56311 L .654 .726 .902 r
F
.26685 .56177 m .27565 .55892 L .27549 .5615 L .667 .432 .555 r
F
.2519 .53956 m .27565 .55892 L .26818 .53903 L .654 .726 .902 r
F
.28662 .56114 m .28116 .55452 L .26424 .56186 L F
.28662 .56114 m .26424 .56186 L .26136 .56311 L F
.28304 .5785 m .26136 .56311 L .24601 .57483 L F
.29624 .57278 m .26136 .56311 L .28304 .5785 L F
.25563 .57196 m .26136 .56311 L .24601 .57483 L .338 .16 .486 r
F
.2609 .57038 m .26106 .56781 L .25563 .57196 L F
.26106 .56781 m .26136 .56311 L .25563 .57196 L F
.26394 .56656 m .26685 .56177 L .27519 .5662 L .667 .432 .555 r
F
.26417 .56292 m .26136 .56311 L .26378 .56913 L .492 .285 .526 r
F
.25078 .56698 m .26419 .56263 L .26394 .56656 L .667 .432 .555 r
F
.26419 .56263 m .26685 .56177 L .26394 .56656 L F
.26378 .56913 m .26136 .56311 L .2609 .57038 L .492 .285 .526 r
F
.27385 .56226 m .26417 .56292 L .26394 .56656 L F
.26937 .56146 m .26264 .5666 L .26394 .56656 L .654 .726 .902 r
F
.27157 .56325 m .26394 .56656 L .27519 .5662 L F
.26937 .56146 m .26394 .56656 L .27157 .56325 L F
.26685 .56177 m .27549 .5615 L .27519 .5662 L .667 .432 .555 r
F
.3115 .56955 m .28932 .55857 L .29624 .57278 L .654 .726 .902 r
F
.28932 .55857 m .28116 .55452 L .28521 .55944 L F
.28932 .55857 m .28521 .55944 L .29624 .57278 L F
.3115 .56955 m .30606 .55502 L .28932 .55857 L F
.27519 .5662 m .29027 .55836 L .29808 .56135 L .592 .368 .545 r
F
.29027 .55836 m .29854 .55407 L .29838 .55665 L F
.29027 .55836 m .29838 .55665 L .29808 .56135 L F
.27519 .5662 m .27549 .5615 L .29027 .55836 L F
.28932 .55857 m .30406 .54967 L .28116 .55452 L .654 .726 .902 r
F
.29838 .55665 m .30406 .54967 L .28932 .55857 L F
.30606 .55502 m .30551 .55356 L .29838 .55665 L F
.29838 .55665 m .29854 .55407 L .31118 .5511 L .492 .285 .526 r
F
.30551 .55356 m .30406 .54967 L .29838 .55665 L .654 .726 .902 r
F
.31118 .5511 m .29854 .55407 L .31547 .54674 L .492 .285 .526 r
F
.32777 .56903 m .32848 .54889 L .31531 .54931 L .654 .726 .902 r
F
.30767 .55262 m .31531 .54931 L .30406 .54967 L F
.32777 .56903 m .31531 .54931 L .30767 .55262 L F
.32777 .56903 m .30406 .54967 L .3115 .56955 L F
.29808 .56135 m .31118 .5511 L .3179 .55276 L .492 .285 .526 r
F
.31118 .5511 m .31835 .54549 L .31819 .54806 L F
.32803 .55616 m .31531 .54931 L .3151 .55266 L .667 .432 .555 r
F
.31118 .5511 m .31819 .54806 L .3179 .55276 L .492 .285 .526 r
F
.32803 .55616 m .32848 .54889 L .31531 .54931 L .667 .432 .555 r
F
.3151 .55266 m .31531 .54931 L .30406 .54967 L F
.3154 .5478 m .31547 .54674 L .31835 .54549 L .492 .285 .526 r
F
.31118 .5511 m .31547 .54674 L .3154 .5478 L F
.29808 .56135 m .29838 .55665 L .31118 .5511 L F
.28116 .55452 m .27431 .55499 L .26424 .56186 L F
.27431 .55499 m .2644 .55928 L .26424 .56186 L F
.26136 .56311 m .26152 .56053 L .25609 .56468 L .338 .16 .486 r
F
.26152 .56053 m .26182 .55584 L .25609 .56468 L F
.25078 .56698 m .25124 .55971 L .27565 .55892 L .667 .432 .555 r
F
.31103 .55414 m .30406 .54967 L .30376 .55437 L F
.3151 .55266 m .30406 .54967 L .31485 .55659 L F
.29566 .55609 m .30406 .54967 L .28116 .55452 L .592 .368 .545 r
F
.29262 .55473 m .29808 .56135 L .31501 .55401 L .654 .726 .902 r
F
.3036 .55695 m .30376 .55437 L .29566 .55609 L .592 .368 .545 r
F
.30376 .55437 m .30406 .54967 L .29566 .55609 L F
.28299 .54307 m .29262 .55473 L .30757 .55357 L .654 .726 .902 r
F
.31507 .55198 m .30757 .55357 L .3179 .55276 L F
.28299 .54307 m .30757 .55357 L .31507 .55198 L F
.29262 .55473 m .31501 .55401 L .3179 .55276 L F
.31485 .55659 m .31103 .55414 L .3036 .55695 L .667 .432 .555 r
F
.31103 .55414 m .30376 .55437 L .3036 .55695 L F
.29566 .55609 m .28116 .55452 L .28086 .55922 L .592 .368 .545 r
F
.26772 .54631 m .29808 .56135 L .28299 .54307 L .654 .726 .902 r
F
.3036 .55695 m .29566 .55609 L .2807 .5618 L .592 .368 .545 r
F
.28513 .55832 m .27519 .5662 L .28992 .55731 L .654 .726 .902 r
F
.29566 .55609 m .28086 .55922 L .2807 .5618 L .592 .368 .545 r
F
.28992 .55731 m .27519 .5662 L .29808 .56135 L .654 .726 .902 r
F
.28776 .55624 m .28513 .55832 L .28992 .55731 L F
.27385 .56226 m .28116 .55452 L .26136 .56311 L .492 .285 .526 r
F
.28086 .55922 m .28116 .55452 L .27385 .56226 L F
.26772 .54631 m .27373 .56232 L .28776 .55624 L .654 .726 .902 r
F
.27373 .56232 m .27519 .5662 L .28776 .55624 L F
.2807 .5618 m .28086 .55922 L .27385 .56226 L .492 .285 .526 r
F
.26464 .55565 m .26182 .55584 L .26424 .56186 L F
.25124 .55971 m .26465 .55536 L .2644 .55928 L .667 .432 .555 r
F
.2519 .53956 m .25124 .55971 L .2631 .55933 L .654 .726 .902 r
F
.2519 .53956 m .2631 .55933 L .26984 .55418 L F
.25143 .54683 m .27519 .5662 L .26772 .54631 L F
.2807 .5618 m .27385 .56226 L .26378 .56913 L .492 .285 .526 r
F
.27385 .56226 m .26394 .56656 L .26378 .56913 L F
.25143 .54683 m .25078 .56698 L .26264 .5666 L .654 .726 .902 r
F
.25143 .54683 m .26264 .5666 L .26937 .56146 L F
.32803 .55616 m .3151 .55266 L .31485 .55659 L .667 .432 .555 r
F
.31164 .54383 m .31881 .53821 L .31865 .54079 L .492 .285 .526 r
F
.31586 .54052 m .31592 .53946 L .31881 .53821 L F
.31164 .54383 m .31592 .53946 L .31586 .54052 L F
0 g
.23661 .58162 m
.24647 .56756 L
s
.24647 .56756 m
.25087 .5642 L
s
.79966 .59743 m .81305 .57551 L .79014 .58858 L .654 .726 .902 r
F
.79966 .59743 m .82733 .58879 L .81305 .57551 L F
.36812 .69557 m .39749 .69165 L .37344 .68817 L .673 .757 .914 r
F
.34673 .68839 m .36812 .69557 L .37344 .68817 L F
.34261 .6916 m .36812 .69557 L .34673 .68839 L F
0 g
.74788 .64488 m
.74795 .65878 L
s
.79068 .57417 m .79459 .55059 L .7781 .56713 L .654 .726 .902 r
F
.79068 .57417 m .81347 .56116 L .79459 .55059 L F
.53642 .70616 m .50704 .71008 L .53105 .71356 L .673 .758 .915 r
F
0 g
.74136 .64476 m
.7415 .67214 L
s
.57271 .69473 m .567 .68027 L .55481 .68351 L .673 .758 .914 r
F
.57919 .6941 m .567 .68027 L .57271 .69473 L F
.69588 .69379 m .67835 .70899 L .70048 .70102 L .673 .758 .915 r
F
.69588 .69379 m .67145 .69816 L .67835 .70899 L F
0 g
.67835 .70899 m
.68978 .71818 L
s
.40882 .58335 m .40926 .57608 L .3948 .56279 L .927 .669 .528 r
F
0 g
.40926 .57608 m
.41809 .59111 L
s
.30076 .67988 m .2812 .69142 L .30311 .68348 L .673 .757 .914 r
F
.30076 .67988 m .2765 .68423 L .2812 .69142 L F
.57919 .6941 m .57996 .67901 L .567 .68027 L .673 .758 .914 r
F
.39397 .93138 m .38533 .93834 L .39633 .93519 L .644 .733 .913 r
F
.39397 .93138 m .38179 .93263 L .38533 .93834 L F
0 g
.38533 .93834 m
.39111 .9434 L
s
.38243 1.3573 m
.38332 1.00698 L
s
.38332 1.00698 m
.3835 .93811 L
s
.72261 .69303 m .70809 .70715 L .72642 .6961 L .673 .758 .915 r
F
.72261 .69303 m .70048 .70102 L .70809 .70715 L F
.59194 .70149 m .59322 .68532 L .58598 .70009 L .673 .758 .914 r
F
.59194 .70149 m .60516 .68813 L .59322 .68532 L F
.59733 .70947 m .60549 .6938 L .59227 .70716 L .673 .758 .915 r
F
.59733 .70947 m .61562 .69843 L .60549 .6938 L F
.45042 .94216 m .45466 .93313 L .45441 .9369 L .084 0 .407 r
F
.43973 .93774 m .45042 .94216 L .45441 .9369 L .644 .733 .913 r
F
.127 .923 .03 r
.45138 .90228 m
.4514 .90578 L
s
.43562 .94064 m .45042 .94216 L .43973 .93774 L .644 .733 .913 r
F
0 g
.44425 .94652 m
.45042 .94216 L
s
.40673 .92259 m .39695 .92763 L .4079 .92449 L .644 .733 .913 r
F
.40673 .92259 m .39461 .92384 L .39695 .92763 L F
.44793 .82764 m .43404 .82045 L .43452 .82501 L .793 .542 .558 r
F
0 g
.44793 .82764 m
.45933 .83235 L
s
.127 .923 .03 r
.43852 .84601 m
.43885 .78249 L
s
.43404 .82045 m .43355 .81588 L .41905 .81551 L .733 .498 .572 r
F
0 g
.43355 .81588 m
.44696 .81851 L
s
.60586 .59329 m .60627 .58602 L .58204 .58269 L .732 .488 .559 r
F
0 g
.60627 .58602 m
.62866 .59323 L
s
.44013 .93016 m .45473 .92933 L .44278 .92667 L .644 .733 .913 r
F
.42949 .92575 m .44013 .93016 L .44278 .92667 L F
.42745 .9272 m .44013 .93016 L .42949 .92575 L F
.40734 .93203 m .40019 .93856 L .40926 .93372 L F
.40734 .93203 m .39633 .93519 L .40019 .93856 L F
.81635 .68983 m .81601 .68416 L .81928 .67233 L 0 0 .339 r
F
0 g
.81135 .69049 m
.81601 .68416 L
s
.42698 .93476 m .43562 .94064 L .43973 .93774 L .644 .733 .913 r
F
.42434 .93581 m .43562 .94064 L .42698 .93476 L F
.7918 .68064 m .81565 .68411 L .8189 .67234 L .673 .758 .914 r
F
.68042 .56128 m .66529 .56573 L .66488 .573 L .345 .167 .491 r
F
.68042 .56128 m .68082 .55401 L .66529 .56573 L F
0 g
.65521 .57979 m
.66529 .56573 L
s
.50688 .55594 m .50604 .57607 L .52231 .57555 L .654 .726 .902 r
F
.49879 .55483 m .50604 .57607 L .50688 .55594 L F
.49879 .55483 m .48988 .57385 L .50604 .57607 L F
.78694 .69375 m .81635 .68983 L .79238 .68635 L .673 .758 .914 r
F
.76569 .68657 m .78694 .69375 L .79238 .68635 L F
.76152 .68978 m .78694 .69375 L .76569 .68657 L F
.56688 .70195 m .55501 .68905 L .54439 .69406 L F
.573 .70033 m .55501 .68905 L .56688 .70195 L F
.55183 .80833 m .54954 .82166 L .55942 .81147 L .683 .771 .917 r
F
.55183 .80833 m .53817 .81694 L .54954 .82166 L F
0 g
.54954 .82166 m
.56293 .82429 L
s
.4054 .82656 m .3912 .82607 L .39168 .83064 L .607 .406 .583 r
F
0 g
.3798 .83659 m
.39168 .83064 L
s
.4054 .82656 m .40492 .822 L .3912 .82607 L .607 .406 .583 r
F
0 g
.37932 .83202 m
.3912 .82607 L
s
.62293 .69889 m .63359 .68171 L .61529 .69276 L .673 .758 .914 r
F
.62293 .69889 m .64504 .69091 L .63359 .68171 L F
.6172 .80814 m .62601 .79615 L .62651 .80071 L .407 .263 .571 r
F
.6177 .81271 m .6172 .80814 L .62651 .80071 L F
.60437 .80094 m .6172 .80814 L .62651 .80071 L .683 .77 .917 r
F
.127 .923 .03 r
.63134 .73773 m
.63141 .73347 L
s
.59642 .80491 m .6172 .80814 L .60437 .80094 L .683 .77 .917 r
F
0 g
.61035 .81156 m
.6172 .80814 L
s
.58238 .71931 m
.58241 .73904 L
s
.82771 .58152 m .82809 .57425 L .81381 .56096 L .929 .67 .524 r
F
0 g
.82809 .57425 m
.83671 .58929 L
s
.57586 .71942 m
.57589 .73892 L
s
.56189 .71012 m .54471 .69973 L .53642 .70616 L .673 .758 .915 r
F
.5672 .70762 m .54471 .69973 L .56189 .71012 L F
.54424 .6885 m .51477 .68774 L .536 .69489 L .673 .758 .914 r
F
.71976 .67806 m .69545 .68241 L .70003 .6896 L F
.5361 .70049 m .51477 .69331 L .50672 .70441 L F
.51508 .69898 m .50672 .70441 L .50704 .71008 L .171 .075 .496 r
F
.51508 .69898 m .51477 .69331 L .50672 .70441 L F
0 g
.50359 .71622 m
.50672 .70441 L
s
.37166 .58313 m .37523 .55945 L .35892 .57606 L .654 .726 .902 r
F
.37166 .58313 m .39435 .57007 L .37523 .55945 L F
.41953 .82008 m .40444 .81743 L .40492 .822 L .673 .454 .58 r
F
.41953 .82008 m .41905 .81551 L .40444 .81743 L F
0 g
.39072 .82151 m
.40444 .81743 L
s
.39749 .69165 m .40027 .67415 L .40057 .67982 L 0 0 .319 r
F
.39779 .69732 m .39749 .69165 L .40057 .67982 L F
.37344 .68817 m .39749 .69165 L .40057 .67982 L .673 .757 .914 r
F
0 g
.39294 .69796 m
.39749 .69165 L
s
.58598 .70009 m .5803 .68452 L .57952 .69969 L .673 .758 .914 r
F
.58598 .70009 m .59322 .68532 L .5803 .68452 L F
.381 .9229 m .38231 .9251 L .38205 .92887 L .931 .755 .276 r
F
.381 .9229 m .38126 .91914 L .38231 .9251 L F
0 g
.38231 .9251 m
.38448 .92862 L
s
.39392 .91988 m .38249 .92509 L .39461 .92384 L .644 .733 .913 r
F
.39392 .91988 m .38145 .91915 L .38249 .92509 L F
.127 .923 .03 r
.38987 .86277 m
.39063 .91969 L
s
.38987 .86277 m
.38992 .91965 L
s
.36842 .70124 m .39779 .69732 L .37375 .69384 L .673 .758 .914 r
F
.34703 .69406 m .36842 .70124 L .37375 .69384 L F
.34291 .69727 m .36842 .70124 L .34703 .69406 L F
.40641 .92636 m .39659 .93142 L .40759 .92827 L .644 .733 .913 r
F
.40641 .92636 m .39423 .92762 L .39659 .93142 L F
0 g
.58241 .73904 m
.58247 .77087 L
s
.45466 .93313 m .45491 .92937 L .45645 .92355 L 0 0 .143 r
F
.127 .923 .03 r
.45877 1.31689 m
.46283 .81698 L
s
.41816 6.3128 m
.45877 1.31689 L
s
0 g
.45195 .93329 m
.45491 .92937 L
s
.127 .923 .03 r
.45254 1.10188 m
.45876 2.17053 L
s
0 g
.57589 .73892 m
.57594 .77115 L
s
.43999 .93397 m .45466 .93313 L .44264 .93046 L .644 .733 .913 r
F
.42929 .92954 m .43999 .93397 L .44264 .93046 L F
.42724 .931 m .43999 .93397 L .42929 .92954 L F
.49131 .55243 m .48988 .57385 L .49879 .55483 L .654 .726 .902 r
F
.49131 .55243 m .47493 .56904 L .48988 .57385 L F
.44278 .92667 m .45473 .92933 L .45626 .92354 L .644 .733 .913 r
F
.60586 .59329 m .58204 .58269 L .58162 .58996 L .732 .488 .559 r
F
0 g
.58204 .58269 m
.60627 .58602 L
s
.60586 .59329 m
.62825 .6005 L
s
.58061 .58274 m
.58204 .58269 L
s
.51502 .55568 m .52231 .57555 L .5376 .57232 L .654 .726 .902 r
F
.50688 .55594 m .52231 .57555 L .51502 .55568 L F
.43404 .82045 m .41905 .81551 L .41953 .82008 L .733 .498 .572 r
F
0 g
.40444 .81743 m
.41905 .81551 L
s
.41905 .81551 m
.43355 .81588 L
s
.48549 .54155 m .47552 .56161 L .49182 .54507 L .654 .726 .902 r
F
.48549 .54155 m .46286 .55457 L .47552 .56161 L F
.45214 .56038 m .43904 .58231 L .46177 .56924 L F
.45214 .56038 m .42459 .56902 L .43904 .58231 L F
0 g
.43904 .58231 m
.45813 .59291 L
s
.573 .70033 m .56726 .6858 L .55501 .68905 L .673 .758 .914 r
F
.57952 .69969 m .56726 .6858 L .573 .70033 L F
.42202 .92587 m .42929 .92954 L .43062 .92778 L .644 .733 .913 r
F
.4186 .92511 m .42192 .92649 L .42202 .92587 L F
.42192 .92649 m .42929 .92954 L .42202 .92587 L F
.42199 .92574 m .42211 .92494 L .42211 .92532 L 0 0 .138 r
F
.42156 .92641 m .42157 .92664 L .42156 .92664 L .077 0 .416 r
F
.42283 .92686 m .42724 .931 L .42929 .92954 L .644 .733 .913 r
F
.42156 .92641 m .42199 .92574 L .42199 .92605 L .077 0 .416 r
F
.42158 .93016 m .42199 .9296 L .42189 .98483 L F
.42062 .9315 m .42434 .93581 L .42114 .93078 L .644 .733 .913 r
F
.42301 .93081 m .42698 .93476 L .42904 .93331 L F
.42082 .92768 m .42154 .93263 L .42459 .93205 L F
.41834 .92887 m .42386 .93263 L .42301 .93081 L F
.42386 .93263 m .42698 .93476 L .42301 .93081 L F
.42173 .92641 m .42361 .92852 L .42283 .92686 L F
.422 .92599 m .42211 .92532 L .4221 .92888 L 0 0 .138 r
F
.42211 .92531 m .42207 .92881 L .42211 .92532 L .985 .728 .345 r
F
.42207 .92881 m .42156 .983 L .42207 .92882 L F
.4218 .92729 m .42459 .93205 L .42724 .931 L .644 .733 .913 r
F
.4186 .92511 m .4216 .92858 L .4218 .92729 L F
.4216 .92858 m .42459 .93205 L .4218 .92729 L F
.42199 .92604 m .4221 .92888 L .422 .92956 L 0 0 .138 r
F
.42199 .92574 m .422 .92599 L .42199 .92604 L F
.42133 .92697 m .42361 .92852 L .42173 .92641 L .644 .733 .913 r
F
.422 .92599 m .4221 .92888 L .42199 .92604 L 0 0 .138 r
F
.42207 .92881 m .42207 .92882 L .42211 .92532 L .985 .728 .345 r
F
.422 .92956 m .4221 .92888 L .42201 .98403 L 0 0 .138 r
F
.42199 .9296 m .42201 .98403 L .42189 .98483 L F
.42199 .92574 m .422 .92956 L .42199 .9296 L F
.422 .92956 m .42201 .98403 L .42199 .9296 L F
.42198 .92968 m .42904 .93331 L .43037 .93155 L .644 .733 .913 r
F
.42003 .92877 m .42154 .93263 L .42082 .92768 L F
.41984 .9274 m .42086 .92697 L .42085 .93068 L .519 .305 .529 r
F
.41981 .93262 m .42128 .93639 L .42062 .9315 L .644 .733 .913 r
F
.4199 .93102 m .42085 .93068 L .42076 .98606 L .519 .305 .529 r
F
.41984 .9274 m .42085 .93068 L .4199 .93102 L F
.41834 .92887 m .42187 .93033 L .42198 .92968 L .644 .733 .913 r
F
.42187 .93034 m .42904 .93331 L .42198 .92968 L F
.4221 .92888 m .42156 .983 L .42201 .98403 L .985 .728 .345 r
F
.42211 .92532 m .42207 .92882 L .4221 .92888 L F
.42207 .92882 m .42156 .983 L .4221 .92888 L F
.42114 .93078 m .42434 .93581 L .42519 .93547 L .644 .733 .913 r
F
.42386 .93263 m .42519 .93547 L .42698 .93476 L F
.42114 .93078 m .42519 .93547 L .42386 .93263 L F
.41834 .92887 m .42062 .9315 L .42114 .93078 L F
.42157 .92664 m .42199 .92605 L .42199 .9296 L .077 0 .416 r
F
.42157 .92664 m .42199 .9296 L .42158 .93016 L F
.42156 .92641 m .42199 .92605 L .42157 .92664 L F
.4186 .92511 m .42133 .92697 L .42173 .92641 L .644 .733 .913 r
F
.42361 .92852 m .42724 .931 L .42283 .92686 L F
.42211 .92494 m .42211 .92531 L .42211 .92532 L .985 .728 .345 r
F
.42199 .92574 m .42211 .92532 L .422 .92599 L 0 0 .138 r
F
.42152 .93255 m .42128 .93639 L .42434 .93581 L .644 .733 .913 r
F
.42062 .9315 m .42111 .93515 L .42152 .93255 L F
.42111 .93515 m .42128 .93639 L .42152 .93255 L F
.41826 .9276 m .41984 .9274 L .41983 .93104 L .642 .403 .542 r
F
.41921 .93108 m .41981 .93262 L .42019 .93101 L .644 .733 .913 r
F
.41834 .92887 m .41803 .93646 L .42128 .93639 L F
.41762 .984 m .41752 .98678 L .41978 .98646 L .692 .759 .903 r
F
.41762 .984 m .41978 .98646 L .41876 .98384 L F
.41889 .98572 m .41788 .98621 L .41902 .98605 L .692 .759 .904 r
F
.41815 .98372 m .41926 .98565 L .41815 .98586 L .642 .403 .542 r
F
.41799 .98341 m .41789 .98591 L .41889 .98572 L .692 .759 .904 r
F
.41789 .98591 m .41788 .98621 L .41889 .98572 L F
.41752 .98678 m .4208 .98909 L .41978 .98646 L .692 .759 .903 r
F
.41788 .98621 m .42005 .98868 L .41902 .98605 L .692 .759 .904 r
F
.41815 .98586 m .41974 .98649 L .41815 .98669 L .642 .403 .542 r
F
.4188 .98387 m .41978 .98646 L .4219 .98579 L .692 .759 .903 r
F
.41876 .98384 m .41877 .98388 L .4188 .98387 L F
.41877 .98388 m .41978 .98646 L .4188 .98387 L F
.42077 .98508 m .41991 .98553 L .42101 .98522 L .692 .759 .904 r
F
.41974 .98342 m .42044 .98523 L .41974 .98556 L .519 .305 .529 r
F
.41974 .98342 m .41876 .98384 L .41982 .98351 L .692 .759 .903 r
F
.41867 .98363 m .41876 .98384 L .41974 .98342 L F
.41966 .98344 m .41971 .98557 L .41815 .98372 L .642 .403 .542 r
F
.41799 .98341 m .41988 .98549 L .42077 .98508 L .692 .759 .904 r
F
.41988 .98549 m .41991 .98553 L .42077 .98508 L F
.41978 .98646 m .42399 .98808 L .4219 .98579 L .692 .759 .903 r
F
.41902 .98605 m .42218 .98801 L .42008 .98571 L .692 .759 .904 r
F
.41974 .98556 m .42076 .98606 L .41974 .98649 L .519 .305 .529 r
F
.41991 .98553 m .42008 .98571 L .42071 .98538 L .692 .759 .904 r
F
.42008 .98571 m .42403 .98702 L .42101 .98522 L F
.42044 .98523 m .42076 .98606 L .41974 .98556 L .519 .305 .529 r
F
.42496 .92926 m .43037 .93155 L .43088 .92961 L .644 .733 .913 r
F
.42211 .92532 m .43062 .92778 L .43113 .92585 L F
.4186 .92511 m .42241 .92596 L .42211 .92532 L F
.42241 .92596 m .43062 .92778 L .42211 .92532 L F
.42211 .92494 m .42166 .9239 L .42166 .92436 L .985 .728 .345 r
F
.42206 .92523 m .42166 .92436 L .42165 .92792 L F
.42211 .92494 m .42166 .92436 L .42206 .92523 L F
.42057 .98376 m .4219 .98579 L .42374 .98481 L .692 .759 .903 r
F
.42055 .98312 m .42374 .98481 L .42074 .98302 L F
.41982 .98351 m .42 .98357 L .42055 .98312 L F
.42 .98357 m .42374 .98481 L .42055 .98312 L F
.42035 .98409 m .4219 .98579 L .42057 .98376 L F
.41876 .98384 m .4219 .98579 L .41982 .98351 L F
.42144 .98451 m .42101 .98522 L .42173 .9846 L .692 .759 .904 r
F
.41799 .98341 m .42076 .98507 L .42144 .98451 L F
.42076 .98507 m .42101 .98522 L .42144 .98451 L F
.42076 .98508 m .42146 .9855 L .42076 .98606 L .359 .182 .499 r
F
.42076 .98294 m .42124 .98468 L .42076 .98508 L F
.42124 .98468 m .42146 .9855 L .42076 .98508 L F
.42717 .92634 m .43053 .92762 L .42936 .92572 L .644 .733 .913 r
F
.42085 .93068 m .42143 .98239 L .42076 .98294 L .359 .182 .499 r
F
.4209 .93065 m .42143 .98239 L .42085 .93068 L F
.42086 .92697 m .42156 .92641 L .42156 .9302 L F
.4209 .93065 m .42156 .9302 L .42146 .9855 L F
.42086 .92697 m .42156 .9302 L .4209 .93065 L F
.42086 .92697 m .4209 .93065 L .42085 .93068 L F
.41834 .92887 m .42223 .92974 L .42221 .9291 L .644 .733 .913 r
F
.42223 .92974 m .42254 .92981 L .42244 .92959 L F
.42223 .92974 m .42244 .92959 L .42221 .9291 L F
.41983 .93104 m .42071 .98296 L .41974 .98342 L .519 .305 .529 r
F
.41773 .98122 m .42191 .98171 L .42209 .98098 L .692 .759 .903 r
F
.41773 .98122 m .42209 .98098 L .42197 .98027 L F
.42165 .92792 m .4205 .98218 L .42156 .983 L .908 .63 .503 r
F
.42166 .9239 m .42158 .92786 L .42165 .92792 L F
.42156 .92664 m .42158 .93016 L .42156 .9302 L .077 0 .416 r
F
.42285 .92841 m .43088 .92961 L .43053 .92762 L .644 .733 .913 r
F
.42158 .93016 m .42158 .93016 L .42156 .92664 L .077 0 .416 r
F
.42153 .92427 m .43079 .92386 L .42961 .92195 L .644 .733 .913 r
F
.4186 .92511 m .42217 .92474 L .42153 .92427 L F
.42217 .92474 m .43079 .92386 L .42153 .92427 L F
.42166 .9239 m .4206 .92309 L .4206 .92358 L .908 .63 .503 r
F
.42349 .92461 m .43113 .92585 L .43079 .92386 L .644 .733 .913 r
F
.4186 .92511 m .42614 .92555 L .42349 .92461 L F
.42614 .92555 m .43113 .92585 L .42349 .92461 L F
.4199 .93102 m .42071 .98296 L .41983 .93104 L .519 .305 .529 r
F
.42157 .92664 m .42158 .93016 L .42156 .92664 L .077 0 .416 r
F
.42166 .9239 m .4206 .92713 L .42158 .92786 L .908 .63 .503 r
F
.42029 .92702 m .42743 .92403 L .42488 .92267 L .644 .733 .913 r
F
.4186 .92511 m .42003 .92877 L .42082 .92768 L F
.41834 .92887 m .4212 .92735 L .42029 .92702 L F
.4212 .92735 m .42743 .92403 L .42029 .92702 L F
.41773 .98122 m .42145 .9824 L .42191 .98171 L .692 .759 .903 r
F
.4206 .92713 m .41949 .97899 L .4205 .97926 L .809 .541 .534 r
F
.41969 .97905 m .42089 .97909 L .42 .97869 L .692 .759 .903 r
F
.41826 .9276 m .41966 .98344 L .41815 .98372 L .642 .403 .542 r
F
.41773 .98122 m .4206 .97928 L .41969 .97905 L .692 .759 .903 r
F
.4206 .97928 m .42089 .97909 L .41969 .97905 L F
.41773 .98122 m .42197 .98027 L .42156 .97962 L F
.4205 .97926 m .41969 .98119 L .4205 .9814 L .809 .541 .534 r
F
.41993 .98125 m .42116 .98127 L .42027 .98088 L .692 .759 .904 r
F
.41773 .98122 m .41867 .98363 L .41974 .98342 L .692 .759 .903 r
F
.41773 .98122 m .42074 .98302 L .42145 .9824 L F
.41799 .98341 m .42084 .98149 L .41993 .98125 L .692 .759 .904 r
F
.42084 .98149 m .42116 .98127 L .41993 .98125 L F
.4205 .9814 m .41942 .98181 L .4205 .98218 L .809 .541 .534 r
F
.41969 .98119 m .41942 .98181 L .4205 .9814 L F
.41773 .98122 m .42156 .97962 L .42089 .97909 L .692 .759 .903 r
F
.41949 .97899 m .41942 .98181 L .4205 .97926 L .809 .541 .534 r
F
.4206 .92358 m .42053 .92711 L .4206 .92713 L F
.42053 .92711 m .41942 .98181 L .4206 .92713 L F
.4206 .92309 m .42059 .92357 L .4206 .92358 L F
.4212 .92735 m .42936 .92572 L .42743 .92403 L .644 .733 .913 r
F
.41834 .92887 m .4223 .92774 L .4212 .92735 L F
.42211 .92494 m .42165 .92792 L .42207 .92881 L .985 .728 .345 r
F
.4223 .92774 m .42936 .92572 L .4212 .92735 L .644 .733 .913 r
F
.42059 .92357 m .42052 .92711 L .4206 .92358 L .809 .541 .534 r
F
.42052 .92711 m .41942 .98181 L .42053 .92711 L F
.42052 .92711 m .42053 .92711 L .4206 .92358 L F
.42154 .92427 m .4206 .92358 L .4206 .92713 L .908 .63 .503 r
F
.42166 .9239 m .4206 .92358 L .42154 .92427 L F
.41834 .92887 m .42234 .92911 L .42266 .92867 L .644 .733 .913 r
F
.41834 .92887 m .42266 .92867 L .42238 .92846 L F
.41834 .92887 m .42238 .92846 L .42166 .92792 L F
.42158 .92786 m .4206 .92713 L .4205 .98218 L .908 .63 .503 r
F
.42238 .92846 m .42266 .92867 L .42285 .92841 L .644 .733 .913 r
F
.42234 .92911 m .43088 .92961 L .42285 .92841 L F
.42158 .93016 m .42189 .98483 L .42158 .93016 L .077 0 .416 r
F
.42158 .92786 m .4205 .98218 L .42165 .92792 L .908 .63 .503 r
F
.42166 .92792 m .42439 .92825 L .42717 .92634 L .644 .733 .913 r
F
.42238 .92846 m .42439 .92825 L .42166 .92792 L F
.42439 .92825 m .43053 .92762 L .42717 .92634 L F
.42074 .98302 m .42374 .98481 L .42517 .98359 L .692 .759 .903 r
F
.42143 .98239 m .42145 .98451 L .42076 .98294 L .359 .182 .499 r
F
.42147 .98236 m .42176 .98404 L .42146 .9845 L .077 0 .416 r
F
.41799 .98341 m .42218 .9839 L .42237 .98317 L .692 .759 .904 r
F
.42218 .9839 m .42219 .98391 L .42219 .98389 L F
.42218 .9839 m .42219 .98389 L .42237 .98317 L F
.42145 .98451 m .42146 .9855 L .42124 .98468 L .359 .182 .499 r
F
.42145 .98451 m .42124 .98468 L .42076 .98294 L F
.42187 .98387 m .42173 .9846 L .42219 .98391 L .692 .759 .904 r
F
.41982 .98351 m .42035 .98409 L .42057 .98376 L .692 .759 .903 r
F
.41991 .98553 m .42071 .98538 L .42101 .98522 L .692 .759 .904 r
F
.42071 .98296 m .42076 .98606 L .41974 .98342 L .519 .305 .529 r
F
.41799 .98341 m .42145 .98452 L .42187 .98387 L .692 .759 .904 r
F
.42145 .98452 m .42173 .9846 L .42187 .98387 L F
.42101 .98522 m .42546 .98579 L .42173 .9846 L F
.42146 .9845 m .42189 .98483 L .42146 .9855 L .077 0 .416 r
F
.42176 .98404 m .42189 .98483 L .42146 .9845 L F
.42156 .9302 m .42187 .98172 L .42147 .98236 L F
.42074 .98302 m .42517 .98359 L .42145 .9824 L .692 .759 .903 r
F
.42187 .98172 m .42189 .98384 L .42147 .98236 L .077 0 .416 r
F
.41799 .98341 m .42231 .98318 L .42225 .98246 L .692 .759 .904 r
F
.42231 .98318 m .42237 .98317 L .42236 .98311 L F
.42231 .98318 m .42236 .98311 L .42225 .98246 L F
.42189 .98384 m .42189 .98483 L .42176 .98404 L .077 0 .416 r
F
.42189 .98384 m .42176 .98404 L .42147 .98236 L F
.42158 .93016 m .42189 .98483 L .42156 .9302 L F
.42207 .92881 m .42165 .92792 L .42156 .983 L .985 .728 .345 r
F
.42221 .9291 m .42305 .92992 L .42496 .92926 L .644 .733 .913 r
F
.42254 .92981 m .42305 .92992 L .42221 .9291 L F
.42305 .92992 m .43037 .93155 L .42496 .92926 L F
.41984 .9274 m .4199 .93102 L .41983 .93104 L .519 .305 .529 r
F
.41991 .98553 m .41902 .98605 L .42008 .98571 L .692 .759 .904 r
F
.41971 .98557 m .41926 .98565 L .41815 .98372 L .642 .403 .542 r
F
.41799 .98341 m .41889 .98572 L .41991 .98553 L .692 .759 .904 r
F
.41889 .98572 m .41902 .98605 L .41991 .98553 L F
.41971 .98557 m .41974 .98649 L .41926 .98565 L .642 .403 .542 r
F
.41926 .98565 m .41974 .98649 L .41815 .98586 L F
.41834 .93115 m .41983 .93104 L .41974 .98556 L F
.41971 .98557 m .41974 .98556 L .41974 .98649 L F
.41834 .93115 m .41974 .98556 L .41971 .98557 L F
.41826 .9276 m .41983 .93104 L .41834 .93115 L F
.42019 .93101 m .41981 .93262 L .42062 .9315 L .644 .733 .913 r
F
.41834 .92887 m .41921 .93108 L .42019 .93101 L F
.30094 .68557 m .28127 .69717 L .3033 .68919 L .673 .757 .914 r
F
.30094 .68557 m .27655 .68994 L .28127 .69717 L F
.43452 .82501 m .43404 .82045 L .41953 .82008 L .733 .498 .572 r
F
0 g
.43404 .82045 m
.44745 .82307 L
s
.52302 .5467 m .53787 .56487 L .55106 .55918 L .654 .726 .902 r
F
.51541 .54831 m .53787 .56487 L .52302 .5467 L F
.57952 .69969 m .5803 .68452 L .56726 .6858 L .673 .758 .914 r
F
0 g
.57398 .58775 m
.57545 .58663 L
s
.59227 .70716 m .59355 .69099 L .5863 .70576 L .673 .758 .915 r
F
.59227 .70716 m .60549 .6938 L .59355 .69099 L F
0 0 0 r
2.5 Mabswid
.56369 .70858 Mdot
.52909 .8059 m .53718 .80782 L .53767 .81238 L .932 .647 .477 r
F
.52909 .8059 m .52859 .80134 L .53718 .80782 L F
0 g
.5 Mabswid
.53718 .80782 m
.54185 .80975 L
s
.2609 .57038 m .24601 .57483 L .24554 .5821 L .338 .16 .486 r
F
0 g
.23615 .58889 m
.24601 .57483 L
s
.7019 .57667 m .68042 .56128 L .66488 .573 L .654 .726 .902 r
F
.71519 .57095 m .68042 .56128 L .7019 .57667 L F
.54528 .79481 m .53739 .80769 L .55098 .79911 L .683 .77 .917 r
F
.54528 .79481 m .52884 .80124 L .53739 .80769 L F
.6177 .81271 m .62651 .80071 L .62701 .80528 L .407 .263 .571 r
F
.60487 .8055 m .6177 .81271 L .62701 .80528 L .683 .771 .917 r
F
.127 .923 .03 r
.63126 .74198 m
.63134 .73773 L
s
.59691 .80947 m .6177 .81271 L .60487 .8055 L .683 .771 .917 r
F
0 g
.60577 .81866 m
.6177 .81271 L
s
.79052 .58131 m .79445 .55762 L .77787 .57423 L .654 .726 .902 r
F
.79052 .58131 m .81343 .56824 L .79445 .55762 L F
.127 .923 .03 r
.81029 .55938 m
.81121 .5405 L
s
.81635 .68983 m .81928 .67233 L .81963 .678 L 0 0 .339 r
F
.8167 .69549 m .81635 .68983 L .81963 .678 L F
.79238 .68635 m .81635 .68983 L .81963 .678 L .673 .758 .914 r
F
0 g
.81169 .69616 m
.81635 .68983 L
s
.40882 .58335 m .3948 .56279 L .39435 .57007 L .927 .669 .528 r
F
.40838 .59062 m .40882 .58335 L .39435 .57007 L F
0 g
.40882 .58335 m
.41765 .59838 L
s
.78729 .69942 m .8167 .69549 L .79273 .69201 L .673 .758 .915 r
F
.76603 .69224 m .78729 .69942 L .79273 .69201 L F
.76186 .69545 m .78729 .69942 L .76603 .69224 L F
.5672 .70762 m .55533 .69472 L .54471 .69973 L F
.57333 .706 m .55533 .69472 L .5672 .70762 L F
.38075 .92667 m .38205 .92887 L .38179 .93263 L .931 .755 .276 r
F
.38075 .92667 m .381 .9229 L .38205 .92887 L F
.39354 .92364 m .38205 .92887 L .39423 .92762 L .644 .733 .913 r
F
.39354 .92364 m .381 .9229 L .38205 .92887 L F
0 g
.38205 .92887 m
.38423 .93238 L
s
.62325 .70456 m .63392 .68738 L .61562 .69843 L .673 .758 .915 r
F
.62325 .70456 m .64537 .69658 L .63392 .68738 L F
.3592 .56896 m .35308 .54523 L .34431 .56417 L .654 .726 .902 r
F
.3592 .56896 m .37543 .55242 L .35308 .54523 L F
.40616 .93013 m .39633 .93519 L .40734 .93203 L .644 .733 .913 r
F
.40616 .93013 m .39397 .93138 L .39633 .93519 L F
.42002 .82464 m .40492 .822 L .4054 .82656 L .673 .454 .58 r
F
0 g
.39168 .83064 m
.4054 .82656 L
s
.42002 .82464 m .41953 .82008 L .40492 .822 L .673 .454 .58 r
F
0 g
.3912 .82607 m
.40492 .822 L
s
.41669 .92734 m .41826 .9276 L .41825 .93116 L .751 .492 .541 r
F
.41825 .93116 m .4148 .93601 L .41803 .93646 L .644 .733 .913 r
F
.41678 .93088 m .41825 .93116 L .41815 .98669 L .751 .492 .541 r
F
.41669 .92734 m .41825 .93116 L .41678 .93088 L F
.41834 .92887 m .4173 .93098 L .41825 .93116 L .644 .733 .913 r
F
.4173 .93098 m .4148 .93601 L .41825 .93116 L F
.45466 .93313 m .45645 .92355 L .45619 .92732 L 0 0 .143 r
F
.45441 .9369 m .45466 .93313 L .45619 .92732 L F
.44264 .93046 m .45466 .93313 L .45619 .92732 L .644 .733 .913 r
F
0 g
.45169 .93705 m
.45466 .93313 L
s
.40639 .92061 m .39461 .92384 L .40673 .92259 L .644 .733 .913 r
F
.40639 .92061 m .39392 .91988 L .39461 .92384 L F
.43973 .93774 m .45441 .9369 L .44239 .93422 L F
.42904 .93331 m .43973 .93774 L .44239 .93422 L F
.42698 .93476 m .43973 .93774 L .42904 .93331 L F
.71998 .68375 m .70014 .69535 L .72228 .68736 L .673 .758 .914 r
F
.71998 .68375 m .69554 .68812 L .70014 .69535 L F
0 g
.5572 .59075 m
.58162 .58996 L
s
.3729 .68246 m .39989 .67416 L .37494 .67462 L .673 .757 .914 r
F
.34897 .679 m .3729 .68246 L .37494 .67462 L F
.34632 .68269 m .3729 .68246 L .34897 .679 L F
.54439 .69406 m .51477 .69331 L .5361 .70049 L .673 .758 .914 r
F
.44278 .92667 m .45626 .92354 L .44379 .92281 L .644 .733 .913 r
F
.43082 .92401 m .44278 .92667 L .44379 .92281 L F
.42949 .92575 m .44278 .92667 L .43082 .92401 L F
0 g
.41826 .92509 m
.41826 .92405 L
s
.4157 .92688 m .41669 .92734 L .41668 .93086 L .844 .572 .527 r
F
.41666 .98361 m .41546 .98375 L .4165 .98397 L .692 .759 .903 r
F
.4165 .98397 m .41752 .98678 L .41762 .984 L F
.41789 .98584 m .41675 .98617 L .41788 .98621 L .692 .759 .904 r
F
.41667 .98359 m .41659 .98359 L .41666 .98361 L .692 .759 .903 r
F
.41808 .98372 m .41815 .98669 L .41659 .98359 L .751 .492 .541 r
F
.41799 .98341 m .41694 .98576 L .41789 .98584 L .692 .759 .904 r
F
.4165 .98397 m .41527 .98671 L .41752 .98678 L .692 .759 .903 r
F
.41694 .98576 m .41675 .98617 L .41789 .98584 L .692 .759 .904 r
F
.41527 .98671 m .41741 .98955 L .41752 .98678 L .692 .759 .903 r
F
.41675 .98617 m .41777 .989 L .41788 .98621 L .692 .759 .904 r
F
.41658 .98573 m .41815 .98669 L .41658 .98643 L .751 .492 .541 r
F
.41659 .98359 m .41771 .98583 L .41658 .98573 L F
.41771 .98583 m .41815 .98669 L .41658 .98573 L F
.41504 .92629 m .4157 .92688 L .4157 .93039 L .927 .648 .492 r
F
.4164 .93072 m .41625 .93086 L .41723 .93112 L .644 .733 .913 r
F
.41466 .9256 m .41504 .92629 L .41504 .92983 L .989 .721 .392 r
F
.41468 .92923 m .41504 .92983 L .41493 .98538 L F
.41466 .9256 m .41504 .92983 L .41468 .92923 L F
.41625 .93086 m .41586 .93123 L .41687 .93138 L .644 .733 .913 r
F
.41461 .9248 m .41466 .9256 L .41466 .92919 L .789 .63 .07 r
F
.41657 .93244 m .41181 .93508 L .4148 .93601 L .644 .733 .913 r
F
.41723 .93112 m .41623 .93185 L .41657 .93244 L F
.41623 .93185 m .41181 .93508 L .41657 .93244 L F
.41449 .98195 m .41337 .98146 L .41349 .98217 L .692 .759 .903 r
F
.41546 .98375 m .41319 .98627 L .41527 .98671 L F
.41538 .98518 m .41414 .98502 L .41481 .98556 L .692 .759 .904 r
F
.41625 .93086 m .40926 .93372 L .41181 .93508 L .644 .733 .913 r
F
.41622 .93084 m .40926 .93372 L .41625 .93086 L F
.41517 .93057 m .40926 .93372 L .41632 .93079 L F
.41586 .98331 m .41546 .98375 L .41666 .98361 L .692 .759 .903 r
F
.41546 .98375 m .41527 .98671 L .4165 .98397 L F
.41586 .98331 m .41457 .98335 L .41546 .98375 L F
.4157 .93039 m .41654 .98357 L .4156 .98321 L .844 .572 .527 r
F
.41773 .98122 m .41508 .98301 L .41586 .98331 L .692 .759 .903 r
F
.41508 .98301 m .41457 .98335 L .41586 .98331 L F
.41608 .98553 m .41481 .98556 L .4157 .98595 L .692 .759 .904 r
F
.41654 .98357 m .41658 .98643 L .4156 .98321 L .844 .572 .527 r
F
.41654 .98357 m .41659 .98359 L .41658 .98643 L F
.41799 .98341 m .41529 .98523 L .41608 .98553 L .692 .759 .904 r
F
.41529 .98523 m .41481 .98556 L .41608 .98553 L F
.41799 .98341 m .4157 .98595 L .41675 .98617 L F
.4156 .98535 m .41658 .98643 L .41559 .98597 L .844 .572 .527 r
F
.4156 .98321 m .41634 .98563 L .4156 .98535 L F
.41634 .98563 m .41658 .98643 L .4156 .98535 L F
.4157 .92688 m .41576 .93042 L .4157 .93039 L F
.41576 .93042 m .41658 .98643 L .4157 .93039 L F
.4146 .92845 m .41455 .9847 L .4145 .98389 L .789 .63 .07 r
F
.41461 .9248 m .41461 .9285 L .4146 .92845 L F
.41461 .9285 m .41455 .9847 L .4146 .92845 L F
.41477 .93078 m .40734 .93203 L .40926 .93372 L .644 .733 .913 r
F
.41559 .93034 m .41475 .93051 L .41477 .93078 L F
.41475 .93051 m .40734 .93203 L .41477 .93078 L F
.41669 .92734 m .41678 .93088 L .41668 .93086 L .751 .492 .541 r
F
.4157 .92688 m .41668 .93086 L .41576 .93042 L .844 .572 .527 r
F
.41834 .92887 m .4147 .92992 L .41559 .93034 L .644 .733 .913 r
F
.41461 .9248 m .41466 .92919 L .41461 .9285 L .789 .63 .07 r
F
.41366 .92653 m .40641 .92636 L .40759 .92827 L .644 .733 .913 r
F
.4186 .92511 m .41422 .92556 L .41366 .92653 L F
.41422 .92556 m .40641 .92636 L .41366 .92653 L F
.41514 .92379 m .41461 .9248 L .41461 .9249 L 0 0 .377 r
F
.41511 .92404 m .41461 .9249 L .4146 .92845 L F
.41514 .92379 m .41461 .9249 L .41511 .92404 L F
.4147 .92992 m .41356 .93025 L .41559 .93034 L .644 .733 .913 r
F
.41466 .92919 m .41492 .98267 L .41456 .98207 L .989 .721 .392 r
F
.41468 .92923 m .41493 .98538 L .41466 .92919 L F
.41461 .9285 m .41466 .92919 L .41455 .9847 L .789 .63 .07 r
F
.41504 .92629 m .41508 .92987 L .41504 .92983 L .927 .648 .492 r
F
.40777 .93191 m .40616 .93013 L .40734 .93203 L .644 .733 .913 r
F
.41522 .98292 m .4139 .98282 L .41457 .98335 L .692 .759 .903 r
F
.41468 .98249 m .4139 .98282 L .41522 .98292 L F
.41504 .92629 m .4157 .93039 L .41508 .92987 L .927 .648 .492 r
F
.41175 .92955 m .40581 .92814 L .40616 .93013 L .644 .733 .913 r
F
.41834 .92887 m .41338 .92858 L .41175 .92955 L F
.41338 .92858 m .40581 .92814 L .41175 .92955 L F
.41773 .98122 m .41468 .98249 L .41522 .98292 L .692 .759 .903 r
F
.41504 .92983 m .41557 .98318 L .41494 .9827 L .927 .648 .492 r
F
.41773 .98122 m .41416 .98142 L .41449 .98195 L .692 .759 .903 r
F
.40994 .92838 m .40632 .9262 L .40581 .92814 L .644 .733 .913 r
F
.41834 .92887 m .41294 .92767 L .40994 .92838 L F
.41294 .92767 m .40632 .9262 L .40994 .92838 L F
.41501 .92362 m .40996 .91922 L .4079 .92068 L F
.4186 .92511 m .41606 .92338 L .41501 .92362 L F
.41606 .92338 m .40996 .91922 L .41501 .92362 L F
.41736 .92268 m .41626 .92301 L .41625 .92333 L .57 .345 .536 r
F
.41352 .92398 m .4079 .92068 L .40657 .92243 L .644 .733 .913 r
F
.41626 .92301 m .41514 .92379 L .41514 .92399 L .403 .215 .509 r
F
.41616 .92338 m .41514 .92399 L .41513 .92755 L F
.41626 .92301 m .41514 .92399 L .41616 .92338 L F
.41471 .92424 m .41501 .92362 L .41352 .92398 L .644 .733 .913 r
F
.4186 .92511 m .41545 .92381 L .41471 .92424 L F
.41545 .92381 m .41501 .92362 L .41471 .92424 L F
.41501 .92362 m .4079 .92068 L .41352 .92398 L F
.41668 .93086 m .41808 .98372 L .41659 .98359 L .751 .492 .541 r
F
.41625 .93086 m .41687 .93138 L .41723 .93112 L .644 .733 .913 r
F
.41678 .93088 m .41808 .98372 L .41668 .93086 L .751 .492 .541 r
F
.41834 .92887 m .4164 .93072 L .41723 .93112 L .644 .733 .913 r
F
.4186 .92511 m .41045 .9233 L .40607 .92437 L F
.41045 .9233 m .40657 .92243 L .40631 .92343 L F
.41045 .9233 m .40631 .92343 L .40607 .92437 L F
.41845 .92259 m .41736 .92268 L .41735 .92307 L .661 .418 .542 r
F
.40941 .92689 m .40765 .92444 L .40632 .9262 L .644 .733 .913 r
F
.41453 .92729 m .4097 .92299 L .40765 .92444 L F
.41834 .92887 m .41564 .92703 L .41453 .92729 L F
.41466 .9256 m .41468 .92923 L .41466 .92919 L .989 .721 .392 r
F
.41514 .92379 m .4146 .92845 L .4151 .92761 L 0 0 .377 r
F
.41564 .92703 m .4097 .92299 L .41453 .92729 L .644 .733 .913 r
F
.41735 .92307 m .41727 .92664 L .41735 .92307 L .57 .345 .536 r
F
.41727 .92664 m .41615 .98211 L .41728 .92664 L F
.41727 .92664 m .41728 .92664 L .41735 .92307 L F
.41586 .93123 m .41623 .93185 L .41687 .93138 L .644 .733 .913 r
F
.41632 .93079 m .41622 .93084 L .41625 .93086 L F
.41834 .92887 m .41517 .93057 L .41632 .93079 L F
.41576 .93042 m .41668 .93086 L .41659 .98359 L .844 .572 .527 r
F
.41576 .93042 m .41659 .98359 L .41654 .98357 L F
.41727 .92664 m .41625 .92689 L .41615 .98211 L .57 .345 .536 r
F
.41615 .97949 m .41671 .9786 L .41565 .97893 L .692 .759 .903 r
F
.41773 .98122 m .41694 .9792 L .41615 .97949 L F
.41735 .92663 m .4162 .97947 L .41725 .97909 L .57 .345 .536 r
F
.41694 .9792 m .41671 .9786 L .41615 .97949 L .692 .759 .903 r
F
.41432 .98082 m .41401 .98004 L .41355 .98073 L F
.41773 .98122 m .41497 .98034 L .41432 .98082 L F
.41497 .98034 m .41401 .98004 L .41432 .98082 L F
.41773 .98122 m .41565 .97893 L .41473 .97942 L F
.41445 .9814 m .41355 .98073 L .41337 .98146 L F
.41773 .98122 m .41473 .98087 L .41445 .9814 L F
.41473 .98087 m .41355 .98073 L .41445 .9814 L F
.41773 .98122 m .41349 .98217 L .4139 .98282 L F
.41503 .9803 m .41459 .98327 L .41503 .98244 L 0 0 .377 r
F
.41453 .98126 m .4145 .98389 L .41503 .9803 L F
.41501 .98247 m .41497 .98161 L .41425 .98223 L .692 .759 .904 r
F
.41773 .98122 m .41586 .98331 L .41659 .98359 L .692 .759 .903 r
F
.41773 .98122 m .4165 .98397 L .41762 .984 L F
.41799 .98341 m .41535 .98184 L .41501 .98247 L .692 .759 .904 r
F
.41773 .98122 m .41473 .97942 L .41401 .98004 L .692 .759 .903 r
F
.41508 .98026 m .41504 .98243 L .41615 .97949 L .403 .215 .509 r
F
.41799 .98341 m .41425 .98223 L .41378 .98292 L .692 .759 .904 r
F
.41504 .98243 m .41503 .98288 L .41522 .9823 L .403 .215 .509 r
F
.41504 .98243 m .41522 .9823 L .41615 .97949 L F
.41535 .98184 m .41497 .98161 L .41501 .98245 L .692 .759 .904 r
F
.41503 .98244 m .41501 .98245 L .41501 .98247 L F
.41535 .98184 m .41501 .98245 L .41503 .98244 L F
.41492 .98267 m .41493 .98538 L .41456 .98207 L .989 .721 .392 r
F
.41557 .98318 m .41559 .98597 L .41494 .9827 L .927 .648 .492 r
F
.41799 .98341 m .41378 .98292 L .41361 .98365 L .692 .759 .904 r
F
.41503 .98244 m .4145 .98389 L .41503 .98288 L 0 0 .377 r
F
.41459 .98327 m .4145 .98389 L .41503 .98244 L F
.41513 .92755 m .41453 .98126 L .41503 .9803 L F
.41615 .97949 m .41522 .9823 L .41615 .98163 L .403 .215 .509 r
F
.41563 .982 m .41589 .98112 L .41497 .98161 L .692 .759 .904 r
F
.41773 .98122 m .41659 .98359 L .41667 .98359 L .692 .759 .903 r
F
.41799 .98341 m .41627 .98153 L .41563 .982 L .692 .759 .904 r
F
.41627 .98153 m .41589 .98112 L .41563 .982 L F
.41615 .98163 m .41503 .98288 L .41615 .98211 L .403 .215 .509 r
F
.41522 .9823 m .41503 .98288 L .41615 .98163 L F
.41625 .92689 m .41508 .98026 L .41615 .97949 L F
.4162 .97947 m .41615 .98211 L .41725 .97909 L .57 .345 .536 r
F
.4163 .98157 m .41696 .98078 L .41589 .98112 L .692 .759 .904 r
F
.41799 .98341 m .41715 .98127 L .4163 .98157 L F
.41725 .97909 m .41635 .98155 L .41725 .98123 L .57 .345 .536 r
F
.41715 .98127 m .41696 .98078 L .4163 .98157 L .692 .759 .904 r
F
.41725 .98123 m .41615 .98211 L .41725 .98177 L .57 .345 .536 r
F
.41635 .98155 m .41615 .98211 L .41725 .98123 L F
.41735 .92307 m .41728 .92664 L .41735 .92663 L F
.41728 .92664 m .41615 .98211 L .41735 .92663 L F
.41294 .92767 m .41324 .92676 L .40941 .92689 L .644 .733 .913 r
F
.41834 .92887 m .41453 .92729 L .41294 .92767 L F
.41453 .92729 m .41324 .92676 L .41294 .92767 L F
.41324 .92676 m .40765 .92444 L .40941 .92689 L F
.4186 .92511 m .4126 .91817 L .40996 .91922 L F
.41844 .92303 m .41735 .92307 L .41735 .92663 L .661 .418 .542 r
F
.41837 .92659 m .41735 .92663 L .41725 .98177 L F
.41844 .92303 m .41735 .92663 L .41837 .92659 L F
.41845 .92259 m .41735 .92307 L .41844 .92303 L F
.41736 .92268 m .41735 .92307 L .41735 .92307 L .57 .345 .536 r
F
.41725 .9231 m .41625 .92333 L .41625 .92689 L F
.41736 .92268 m .41625 .92333 L .41725 .9231 L F
.41736 .92268 m .41625 .92689 L .41727 .92664 L F
.41626 .92301 m .41617 .92693 L .41625 .92689 L .403 .215 .509 r
F
.41617 .92693 m .41503 .98288 L .41625 .92689 L F
.41514 .92379 m .4151 .92761 L .41513 .92755 L 0 0 .377 r
F
.4151 .92761 m .4145 .98389 L .41513 .92755 L F
.41356 .93025 m .41175 .92955 L .40777 .93191 L .644 .733 .913 r
F
.41834 .92887 m .4141 .92931 L .41356 .93025 L F
.4141 .92931 m .41175 .92955 L .41356 .93025 L F
.41175 .92955 m .40616 .93013 L .40777 .93191 L F
.41586 .93123 m .41487 .93217 L .41623 .93185 L F
.41487 .93217 m .41492 .9328 L .41623 .93185 L F
.41508 .92987 m .41559 .98597 L .41504 .92983 L .927 .648 .492 r
F
.41508 .92987 m .4157 .93039 L .41559 .98597 L F
.41617 .92693 m .41513 .92755 L .41503 .98288 L .403 .215 .509 r
F
.41626 .92301 m .41513 .92755 L .41617 .92693 L F
.4151 .92761 m .4146 .92845 L .4145 .98389 L 0 0 .377 r
F
.41356 .93025 m .40734 .93203 L .41322 .93083 L .644 .733 .913 r
F
.41356 .93025 m .41322 .93083 L .41559 .93034 L F
.41799 .98341 m .41481 .98474 L .41538 .98518 L .692 .759 .904 r
F
.41494 .9827 m .41545 .98523 L .41493 .98484 L .927 .648 .492 r
F
.41457 .98335 m .41319 .98627 L .41546 .98375 L .692 .759 .903 r
F
.41799 .98341 m .41373 .98437 L .41414 .98502 L .692 .759 .904 r
F
.41455 .98421 m .41493 .98538 L .41455 .9847 L .989 .721 .392 r
F
.41456 .98207 m .41486 .98471 L .41455 .98421 L F
.41481 .98474 m .41414 .98502 L .41512 .98515 L .692 .759 .904 r
F
.41486 .98471 m .41493 .98538 L .41455 .98421 L .989 .721 .392 r
F
.41493 .98484 m .41512 .98515 L .41538 .98518 L .692 .759 .904 r
F
.41481 .98474 m .41512 .98515 L .41493 .98484 L F
.41493 .98484 m .41559 .98597 L .41493 .98538 L .927 .648 .492 r
F
.41545 .98523 m .41559 .98597 L .41493 .98484 L F
.41416 .98142 m .41337 .98146 L .41449 .98195 L .692 .759 .903 r
F
.41487 .93217 m .41181 .93508 L .41492 .9328 L .644 .733 .913 r
F
0 g
.58162 .58996 m
.60586 .59329 L
s
.25007 .68258 m .25189 .68865 L .25218 .69431 L .843 .637 .093 r
F
.127 .923 .03 r
.25537 .85585 m
.29908 2.30623 L
s
.24896 .67452 m
.24974 .71847 L
s
.25007 .68258 m .24978 .67691 L .25189 .68865 L .843 .637 .093 r
F
0 g
.25189 .68865 m
.25524 .69377 L
s
.27511 .67645 m .25225 .68858 L .2765 .68423 L .673 .757 .914 r
F
.27511 .67645 m .25015 .67691 L .25225 .68858 L F
.53642 .70616 m .51508 .69898 L .50704 .71008 L .673 .758 .915 r
F
0 g
.5039 .72189 m
.50704 .71008 L
s
.43452 .82501 m .41953 .82008 L .42002 .82464 L .733 .498 .572 r
F
0 g
.40492 .822 m
.41953 .82008 L
s
.41953 .82008 m
.43404 .82045 L
s
.43452 .82501 m
.44793 .82764 L
s
.39779 .69732 m .40057 .67982 L .40088 .68549 L 0 0 .319 r
F
.37375 .69384 m .39779 .69732 L .40088 .68549 L .673 .758 .914 r
F
0 g
.3898 .70842 m
.39779 .69732 L
s
.42002 .82464 m
.43452 .82501 L
s
.5863 .70576 m .58062 .69019 L .57984 .70536 L .673 .758 .915 r
F
.5863 .70576 m .59355 .69099 L .58062 .69019 L F
.68002 .56855 m .66488 .573 L .66448 .58027 L .345 .167 .491 r
F
.68002 .56855 m .68042 .56128 L .66488 .573 L F
0 g
.65481 .58706 m
.66488 .573 L
s
.50645 .56322 m .50561 .58334 L .52189 .58282 L .654 .726 .902 r
F
.49836 .56211 m .50561 .58334 L .50645 .56322 L F
.49836 .56211 m .48945 .58112 L .50561 .58334 L F
.57333 .706 m .56758 .69147 L .55533 .69472 L .673 .758 .915 r
F
.57984 .70536 m .56758 .69147 L .57333 .706 L F
.82771 .58152 m .81381 .56096 L .81343 .56824 L .929 .67 .524 r
F
.82733 .58879 m .82771 .58152 L .81343 .56824 L F
0 g
.82771 .58152 m
.83633 .59656 L
s
.61478 .6872 m .61786 .66928 L .6047 .68259 L .673 .758 .914 r
F
.61478 .6872 m .63298 .6762 L .61786 .66928 L F
.30123 .69124 m .28157 .70284 L .30359 .69486 L F
.30123 .69124 m .27685 .69561 L .28157 .70284 L F
.52958 .81047 m .53767 .81238 L .53817 .81694 L .932 .647 .477 r
F
.52958 .81047 m .52909 .8059 L .53767 .81238 L F
.54561 .79944 m .53767 .81238 L .55134 .80376 L .683 .77 .917 r
F
.54561 .79944 m .52909 .8059 L .53767 .81238 L F
0 g
.53767 .81238 m
.54234 .81431 L
s
.71574 .56386 m .70099 .5457 L .68115 .55424 L .654 .726 .902 r
F
.73097 .56065 m .70099 .5457 L .71574 .56386 L F
.127 .923 .03 r
.38992 .92232 m
.38992 .92342 L
s
.57984 .70536 m .58062 .69019 L .56758 .69147 L .673 .758 .915 r
F
.7781 .56713 m .77232 .5434 L .76326 .56234 L .654 .726 .902 r
F
.7781 .56713 m .79459 .55059 L .77232 .5434 L F
.28258 .58577 m .2609 .57038 L .24554 .5821 L F
0 g
.24601 .57483 m
.25653 .5668 L
s
.23568 .59616 m
.24554 .5821 L
s
.29578 .58005 m .2609 .57038 L .28258 .58577 L .654 .726 .902 r
F
.64504 .69091 m .64471 .68525 L .63326 .67604 L .932 .657 .495 r
F
0 g
.64471 .68525 m
.65162 .69608 L
s
.127 .923 .03 r
.39067 .92209 m
.39068 .92347 L
s
.39328 .9274 m .38179 .93263 L .39397 .93138 L .644 .733 .913 r
F
.39328 .9274 m .38075 .92667 L .38179 .93263 L F
0 g
.38179 .93263 m
.38533 .93834 L
s
.37122 .59041 m .37479 .56672 L .35847 .58333 L .654 .726 .902 r
F
.37122 .59041 m .39391 .57734 L .37479 .56672 L F
.7918 .68064 m .8189 .67234 L .79396 .6728 L .673 .758 .914 r
F
.76794 .67718 m .7918 .68064 L .79396 .6728 L F
.76524 .68086 m .7918 .68064 L .76794 .67718 L F
.40607 .92437 m .39423 .92762 L .40641 .92636 L .644 .733 .913 r
F
.40607 .92437 m .39354 .92364 L .39423 .92762 L F
.45441 .9369 m .45619 .92732 L .45594 .93108 L 0 0 .143 r
F
.44239 .93422 m .45441 .9369 L .45594 .93108 L .644 .733 .913 r
F
0 g
.45042 .94216 m
.45441 .9369 L
s
.6692 .68076 m .67078 .68683 L .67111 .69249 L .82 .618 .065 r
F
.6692 .68076 m .66886 .67509 L .67078 .68683 L F
0 g
.67078 .68683 m
.67406 .69197 L
s
.62651 .80071 m .62601 .79615 L .63207 .78775 L .208 .121 .532 r
F
0 g
.62021 .80078 m
.62601 .79615 L
s
.69419 .67463 m .67115 .68676 L .69545 .68241 L .673 .758 .914 r
F
.69419 .67463 m .66924 .67508 L .67115 .68676 L F
.44264 .93046 m .45619 .92732 L .44366 .92658 L .644 .733 .913 r
F
.43062 .92778 m .44264 .93046 L .44366 .92658 L F
.42929 .92954 m .44264 .93046 L .43062 .92778 L F
.48495 .54888 m .47493 .56904 L .49131 .55243 L .654 .726 .902 r
F
.48495 .54888 m .4622 .56197 L .47493 .56904 L F
.60992 .79137 m .62577 .79608 L .6318 .78772 L .683 .77 .917 r
F
.60374 .7963 m .62577 .79608 L .60992 .79137 L F
0 g
.4054 .82656 m
.42002 .82464 L
s
.49088 .5597 m .48945 .58112 L .49836 .56211 L .654 .726 .902 r
F
.49088 .5597 m .47449 .57631 L .48945 .58112 L F
.8167 .69549 m .81963 .678 L .81998 .68367 L 0 0 .339 r
F
.79273 .69201 m .8167 .69549 L .81998 .68367 L .673 .758 .915 r
F
0 g
.80853 .7066 m
.8167 .69549 L
s
.51459 .56296 m .52189 .58282 L .53718 .57959 L .654 .726 .902 r
F
.50645 .56322 m .52189 .58282 L .51459 .56296 L F
.52267 .55407 m .5376 .57232 L .55086 .56661 L F
.51502 .55568 m .5376 .57232 L .52267 .55407 L F
.43082 .92401 m .44379 .92281 L .43132 .92208 L .644 .733 .913 r
F
.4162 .54669 m .42547 .55448 L .42503 .56175 L .99 .743 .461 r
F
.4162 .54669 m .41664 .53942 L .42547 .55448 L F
0 g
.42547 .55448 m
.43125 .5598 L
s
.127 .923 .03 r
.57107 .65094 m
.57168 .58518 L
s
.44743 .53575 m .42588 .55435 L .45328 .54575 L .654 .726 .902 r
F
.44743 .53575 m .41709 .53936 L .42588 .55435 L F
.127 .923 .03 r
.42302 .53866 m
.42305 .52917 L
s
.57859 .80228 m .57801 .81347 L .58775 .81219 L .683 .771 .917 r
F
.57376 .80215 m .57801 .81347 L .57859 .80228 L F
.57376 .80215 m .56834 .81322 L .57801 .81347 L F
.127 .923 .03 r
.56859 .73357 m
.56877 .725 L
s
.57031 .73289 m
.57039 .72437 L
s
.72032 .68942 m .70048 .70102 L .72261 .69303 L .673 .758 .915 r
F
.72032 .68942 m .69588 .69379 L .70048 .70102 L F
.37344 .68817 m .40057 .67982 L .37549 .68028 L .673 .757 .914 r
F
.34939 .68468 m .37344 .68817 L .37549 .68028 L F
.34673 .68839 m .37344 .68817 L .34939 .68468 L F
.58755 .79571 m .59642 .80491 L .60437 .80094 L .683 .77 .917 r
F
.58789 .57027 m .5883 .563 L .59835 .54892 L .075 0 .398 r
F
0 g
.57976 .56947 m
.5883 .563 L
s
.54471 .69973 m .51508 .69898 L .53642 .70616 L .673 .758 .915 r
F
.25036 .68825 m .25218 .69431 L .25247 .69998 L .843 .637 .093 r
F
.25036 .68825 m .25007 .68258 L .25218 .69431 L F
.27516 .68212 m .25218 .69431 L .27655 .68994 L .673 .757 .914 r
F
.27516 .68212 m .25007 .68258 L .25218 .69431 L F
0 g
.25218 .69431 m
.25553 .69943 L
s
.56134 .5514 m .5879 .56283 L .5979 .54882 L .654 .726 .902 r
F
.55106 .55918 m .5879 .56283 L .56134 .5514 L F
.7015 .58394 m .68002 .56855 L .66448 .58027 L F
0 g
.6544 .59433 m
.66448 .58027 L
s
.71479 .57823 m .68002 .56855 L .7015 .58394 L .654 .726 .902 r
F
.58347 .80163 m .58775 .81219 L .59691 .80947 L .683 .771 .917 r
F
.57859 .80228 m .58775 .81219 L .58347 .80163 L F
.127 .923 .03 r
.6823 .85221 m
.6876 .7013 L
s
.79014 .58858 m .79406 .56489 L .77749 .58151 L .654 .726 .902 r
F
.79014 .58858 m .81305 .57551 L .79406 .56489 L F
.54611 .804 m .53817 .81694 L .55183 .80833 L .683 .771 .917 r
F
.54611 .804 m .52958 .81047 L .53817 .81694 L F
0 g
.53817 .81694 m
.54954 .82166 L
s
.40838 .59062 m .39435 .57007 L .39391 .57734 L .927 .669 .528 r
F
0 g
.40838 .59062 m
.41721 .60566 L
s
.41816 .98323 m
.41816 .98231 L
s
.127 .923 .03 r
.39696 8.82837 m
.42031 1.65189 L
s
.42031 1.65189 m
.42047 1.60242 L
s
.42047 1.60242 m
.42244 .99703 L
s
.42244 .99703 m
.42247 .9875 L
s
.42247 .9861 m
.42248 .98549 L
s
.42249 .98273 m
.42261 .94543 L
s
.38993 .92581 m
.38993 .92721 L
s
.30007 .67599 m .2765 .68423 L .30076 .67988 L .673 .757 .914 r
F
.30007 .67599 m .27511 .67645 L .2765 .68423 L F
.34431 .56417 m .32892 .54192 L .32821 .56196 L .654 .726 .902 r
F
.34431 .56417 m .35308 .54523 L .32892 .54192 L F
.54424 .6885 m .52712 .67814 L .51477 .68774 L .673 .758 .914 r
F
.55481 .68351 m .52712 .67814 L .54424 .6885 L F
.40581 .92814 m .39397 .93138 L .40616 .93013 L .644 .733 .913 r
F
.127 .923 .03 r
.68205 .85927 m
.6823 .85221 L
s
.40581 .92814 m .39328 .9274 L .39397 .93138 L .644 .733 .913 r
F
.127 .923 .03 r
.39071 .92557 m
.39073 .92725 L
s
.44239 .93422 m .45594 .93108 L .44341 .93035 L .644 .733 .913 r
F
.43037 .93155 m .44239 .93422 L .44341 .93035 L F
.42904 .93331 m .44239 .93422 L .43037 .93155 L F
.35892 .57606 m .35276 .55222 L .34394 .57125 L .654 .726 .902 r
F
.35892 .57606 m .37523 .55945 L .35276 .55222 L F
.61529 .69276 m .61839 .67475 L .60516 .68813 L .673 .758 .914 r
F
.61529 .69276 m .63359 .68171 L .61839 .67475 L F
.43062 .92778 m .44366 .92658 L .43113 .92585 L .644 .733 .913 r
F
.38252 .91708 m .38126 .91914 L .381 .9229 L 0 0 .139 r
F
.127 .923 .03 r
.3746 .86433 m
.37565 1.25262 L
s
.37565 1.25262 m
.39604 8.8271 L
s
0 g
.38155 .9208 m
.38193 .92296 L
s
.39492 .91602 m .38296 .91336 L .38145 .91915 L .644 .733 .913 r
F
.38252 .91708 m .38278 .91332 L .38126 .91914 L 0 0 .139 r
F
.39492 .91602 m .38145 .91915 L .39392 .91988 L .644 .733 .913 r
F
.5693 .80127 m .56834 .81322 L .57376 .80215 L .683 .771 .917 r
F
.5693 .80127 m .55942 .81147 L .56834 .81322 L F
.62651 .80071 m .63207 .78775 L .63257 .79231 L .208 .121 .532 r
F
.62701 .80528 m .62651 .80071 L .63257 .79231 L F
.61058 .79598 m .62651 .80071 L .63257 .79231 L .683 .77 .917 r
F
.60437 .80094 m .62651 .80071 L .61058 .79598 L F
0 g
.62071 .80534 m
.62651 .80071 L
s
.40689 .91868 m .39392 .91988 L .40639 .92061 L .644 .733 .913 r
F
.40689 .91868 m .39492 .91602 L .39392 .91988 L F
.41885 .92134 m .41916 .91379 L .41593 .91386 L F
.41885 .92134 m .42238 .91424 L .41916 .91379 L F
.59097 .78912 m .60374 .7963 L .60992 .79137 L .683 .77 .917 r
F
.43132 .92208 m .44311 .91885 L .43098 .9201 L .644 .733 .913 r
F
.43132 .92208 m .44379 .92281 L .44311 .91885 L F
.64504 .69091 m .63326 .67604 L .63359 .68171 L .932 .657 .495 r
F
.64537 .69658 m .64504 .69091 L .63359 .68171 L F
0 g
.64504 .69091 m
.65195 .70175 L
s
.44379 .92281 m .45523 .9176 L .44311 .91885 L .644 .733 .913 r
F
.44379 .92281 m .45626 .92354 L .45523 .9176 L F
.45619 .92732 m .45645 .92355 L .45542 .91758 L .928 .753 .272 r
F
0 g
.45547 .92727 m
.45602 .92516 L
s
.4807 .53713 m .46286 .55457 L .48549 .54155 L .654 .726 .902 r
F
.4807 .53713 m .45328 .54575 L .46286 .55457 L F
.79238 .68635 m .81963 .678 L .79456 .67846 L .673 .758 .914 r
F
.76841 .68286 m .79238 .68635 L .79456 .67846 L F
.76569 .68657 m .79238 .68635 L .76841 .68286 L F
.52961 .54385 m .55106 .55918 L .56134 .5514 L .654 .726 .902 r
F
.52302 .5467 m .55106 .55918 L .52961 .54385 L F
.127 .923 .03 r
.80995 .56629 m
.80998 .56553 L
s
.66953 .68643 m .67111 .69249 L .67145 .69816 L .82 .618 .065 r
F
.66953 .68643 m .6692 .68076 L .67111 .69249 L F
.69427 .6803 m .67111 .69249 L .69554 .68812 L .673 .758 .914 r
F
.69427 .6803 m .6692 .68076 L .67111 .69249 L F
0 g
.67111 .69249 m
.67439 .69764 L
s
.56501 .79513 m .55134 .80376 L .55892 .8069 L .683 .77 .917 r
F
.58805 .80028 m .59691 .80947 L .60487 .8055 L .683 .771 .917 r
F
.58347 .80163 m .59691 .80947 L .58805 .80028 L F
.82733 .58879 m .81343 .56824 L .81305 .57551 L .929 .67 .524 r
F
0 g
.82733 .58879 m
.83595 .60383 L
s
.34897 .679 m .37494 .67462 L .34999 .67508 L .673 .757 .914 r
F
.73097 .56065 m .72386 .54087 L .70099 .5457 L .654 .726 .902 r
F
.74719 .56013 m .72386 .54087 L .73097 .56065 L F
.71913 .67417 m .69545 .68241 L .71976 .67806 L .673 .758 .914 r
F
.71913 .67417 m .69419 .67463 L .69545 .68241 L F
.76326 .56234 m .74819 .54008 L .74719 .56013 L .654 .726 .902 r
F
.76326 .56234 m .77232 .5434 L .74819 .54008 L F
.71519 .57095 m .70037 .55269 L .68042 .56128 L F
.73051 .56772 m .70037 .55269 L .71519 .57095 L F
.77787 .57423 m .77207 .55039 L .76296 .56942 L F
.77787 .57423 m .79445 .55762 L .77207 .55039 L F
.37375 .69384 m .40088 .68549 L .3758 .68595 L .673 .758 .914 r
F
.34969 .69035 m .37375 .69384 L .3758 .68595 L F
.34703 .69406 m .37375 .69384 L .34969 .69035 L F
0 0 0 r
2.5 Mabswid
.38993 .9293 Mdot
.127 .923 .03 r
.5 Mabswid
.38993 .9293 m
.39633 8.82813 L
s
.27545 .68779 m .25247 .69998 L .27685 .69561 L .673 .758 .914 r
F
.27545 .68779 m .25036 .68825 L .25247 .69998 L F
0 g
.25247 .69998 m
.25956 .71081 L
s
.43037 .93155 m .44341 .93035 L .43088 .92961 L .644 .733 .913 r
F
.38226 .92085 m .381 .9229 L .38075 .92667 L 0 0 .139 r
F
0 g
.38129 .92456 m
.38167 .92672 L
s
.39455 .91976 m .38252 .91708 L .381 .9229 L .644 .733 .913 r
F
.38226 .92085 m .38252 .91708 L .381 .9229 L 0 0 .139 r
F
.39455 .91976 m .381 .9229 L .39354 .92364 L .644 .733 .913 r
F
.127 .923 .03 r
.40715 2.15881 m
.49566 8.80052 L
s
0 0 0 r
2.5 Mabswid
.39076 .92905 Mdot
.48452 .55616 m .47449 .57631 L .49088 .5597 L .654 .726 .902 r
F
.48452 .55616 m .46177 .56924 L .47449 .57631 L F
0 g
.5 Mabswid
.41514 .92111 m
.41514 .92044 L
s
.40657 .92243 m .39354 .92364 L .40607 .92437 L .644 .733 .913 r
F
.40657 .92243 m .39455 .91976 L .39354 .92364 L F
.4186 .92511 m .41566 .91759 L .4126 .91817 L F
.4186 .92511 m .41891 .91752 L .41566 .91759 L F
.4186 .92511 m .42215 .91797 L .41891 .91752 L F
.4186 .92511 m .42514 .9189 L .42215 .91797 L F
.4186 .92511 m .42768 .92026 L .42514 .9189 L F
.4206 .92309 m .41953 .92272 L .41953 .92319 L .809 .541 .534 r
F
.4206 .92309 m .41953 .92319 L .42059 .92357 L F
.41845 .92637 m .42189 .92173 L .41866 .92128 L .644 .733 .913 r
F
.41953 .92272 m .41845 .92259 L .41844 .92659 L .734 .478 .542 r
F
.41834 .92887 m .41941 .92673 L .41844 .92659 L .644 .733 .913 r
F
.41945 .92674 m .41844 .92659 L .41834 .98169 L .734 .478 .542 r
F
.41953 .92272 m .41844 .92659 L .41945 .92674 L F
.41844 .92659 m .41942 .92671 L .41845 .92637 L .644 .733 .913 r
F
.41941 .92673 m .41942 .92671 L .41844 .92659 L F
.4186 .92511 m .42209 .92411 L .42112 .92376 L F
.42059 .92357 m .41953 .92319 L .41952 .92675 L .809 .541 .534 r
F
.41942 .92671 m .42189 .92173 L .41845 .92637 L .644 .733 .913 r
F
.42052 .92711 m .41952 .92675 L .41942 .98181 L .809 .541 .534 r
F
.42059 .92357 m .41952 .92675 L .42052 .92711 L F
.42112 .92376 m .42961 .92195 L .42768 .92026 L .644 .733 .913 r
F
.42209 .92411 m .42961 .92195 L .42112 .92376 L F
.43113 .92585 m .44297 .9226 L .43079 .92386 L F
.43113 .92585 m .44366 .92658 L .44297 .9226 L F
.52224 .56134 m .53718 .57959 L .55044 .57388 L .654 .726 .902 r
F
.51459 .56296 m .53718 .57959 L .52224 .56134 L F
.44366 .92658 m .45516 .92135 L .44297 .9226 L .644 .733 .913 r
F
.44366 .92658 m .45619 .92732 L .45516 .92135 L F
.22697 .55638 m .2517 .55244 L .25124 .55971 L .732 .488 .559 r
F
.22697 .55638 m .22743 .54911 L .2517 .55244 L F
.45619 .92732 m .45542 .91758 L .45516 .92135 L .928 .753 .272 r
F
.45594 .93108 m .45619 .92732 L .45516 .92135 L F
0 g
.45521 .93104 m
.45577 .92893 L
s
.40821 .91693 m .39492 .91602 L .40689 .91868 L .644 .733 .913 r
F
.52719 .68366 m .51445 .68764 L .51477 .69331 L .39 .237 .55 r
F
.52719 .68366 m .52687 .67799 L .51445 .68764 L F
0 g
.5064 .69875 m
.51445 .68764 L
s
.62701 .80528 m .63257 .79231 L .63307 .79688 L .208 .121 .532 r
F
.61108 .80055 m .62701 .80528 L .63307 .79688 L .683 .771 .917 r
F
.60487 .8055 m .62701 .80528 L .61108 .80055 L F
0 g
.6177 .81271 m
.62701 .80528 L
s
.30024 .68166 m .27655 .68994 L .30094 .68557 L .673 .757 .914 r
F
.30024 .68166 m .27516 .68212 L .27655 .68994 L F
.59153 .79372 m .60437 .80094 L .61058 .79598 L .683 .77 .917 r
F
.43098 .9201 m .44077 .91506 L .42981 .9182 L .644 .733 .913 r
F
.43098 .9201 m .44311 .91885 L .44077 .91506 L F
.41576 .55396 m .42503 .56175 L .42459 .56902 L .99 .743 .461 r
F
.41576 .55396 m .4162 .54669 L .42503 .56175 L F
.44669 .54306 m .42503 .56175 L .45257 .5531 L .654 .726 .902 r
F
.44669 .54306 m .4162 .54669 L .42503 .56175 L F
0 g
.42503 .56175 m
.43081 .56707 L
s
.23626 .52987 m .25171 .55214 L .25237 .53208 L .654 .726 .902 r
F
.23626 .52987 m .22757 .54882 L .25171 .55214 L F
.54439 .69406 m .52719 .68366 L .51477 .69331 L .673 .758 .914 r
F
.55501 .68905 m .52719 .68366 L .54439 .69406 L F
.74719 .56013 m .74819 .54008 L .72386 .54087 L .654 .726 .902 r
F
.6047 .68259 m .60004 .66509 L .59283 .6798 L .673 .758 .914 r
F
.6047 .68259 m .61786 .66928 L .60004 .66509 L F
.61562 .69843 m .61872 .68043 L .60549 .6938 L .673 .758 .915 r
F
.61562 .69843 m .63392 .68738 L .61872 .68043 L F
.76794 .67718 m .79396 .6728 L .76902 .67325 L .673 .758 .914 r
F
0 g
.42166 .92573 m
.42166 .92436 L
s
.58789 .57027 m .59835 .54892 L .59794 .5562 L .075 0 .398 r
F
.58747 .57755 m .58789 .57027 L .59794 .5562 L F
.56118 .55879 m .58789 .57027 L .59794 .5562 L .654 .726 .902 r
F
.55086 .56661 m .58789 .57027 L .56118 .55879 L F
0 g
.57934 .57674 m
.58789 .57027 L
s
.41503 .98288 m
.41503 .98244 L
s
.41503 .98157 m
.41503 .9803 L
s
.5655 .7997 m .55942 .81147 L .5693 .80127 L .683 .771 .917 r
F
.127 .923 .03 r
.56691 .81393 m
.56706 .80681 L
s
.5655 .7997 m .55183 .80833 L .55942 .81147 L .683 .771 .917 r
F
.64537 .69658 m .63359 .68171 L .63392 .68738 L .932 .657 .495 r
F
0 g
.64537 .69658 m
.65228 .70741 L
s
.56173 .78837 m .55098 .79911 L .56458 .79053 L .683 .77 .917 r
F
.56173 .78837 m .54528 .79481 L .55098 .79911 L F
.52387 .7981 m .52859 .80134 L .52909 .8059 L .981 .69 .339 r
F
.127 .923 .03 r
.49499 8.80062 m
.55894 1.95052 L
s
.52387 .7981 m .52338 .79353 L .52859 .80134 L .981 .69 .339 r
F
0 g
.52859 .80134 m
.53275 .80447 L
s
.54183 .78963 m .52884 .80124 L .54528 .79481 L .683 .77 .917 r
F
.54183 .78963 m .52365 .79347 L .52884 .80124 L F
.79273 .69201 m .81998 .68367 L .79491 .68413 L .673 .758 .915 r
F
.76875 .68853 m .79273 .69201 L .79491 .68413 L F
.76603 .69224 m .79273 .69201 L .76875 .68853 L F
.127 .923 .03 r
.281 .52088 m
.28111 .5289 L
s
.40057 .67982 m .40027 .67415 L .39823 .66241 L .835 .63 .083 r
F
0 g
.39878 .67985 m
.39997 .67531 L
s
.69461 .68597 m .67145 .69816 L .69588 .69379 L .673 .758 .915 r
F
.69461 .68597 m .66953 .68643 L .67145 .69816 L F
0 g
.67145 .69816 m
.67835 .70899 L
s
.37494 .67462 m .39989 .67416 L .39786 .66248 L .673 .757 .914 r
F
.39435 .57007 m .3948 .56279 L .37568 .55217 L .857 .601 .55 r
F
0 g
.3948 .56279 m
.40926 .57608 L
s
.29578 .58005 m .2807 .5618 L .2609 .57038 L .654 .726 .902 r
F
0 g
.24554 .5821 m
.2609 .57038 L
s
.31104 .57682 m .2807 .5618 L .29578 .58005 L .654 .726 .902 r
F
.34394 .57125 m .32848 .54889 L .32777 .56903 L F
.34394 .57125 m .35276 .55222 L .32848 .54889 L F
.39429 .92352 m .38075 .92667 L .39328 .9274 L .644 .733 .913 r
F
.39429 .92352 m .38226 .92085 L .38075 .92667 L F
0 g
.38075 .92667 m
.38179 .93263 L
s
.35847 .58333 m .35231 .5595 L .34349 .57852 L .654 .726 .902 r
F
.35847 .58333 m .37479 .56672 L .35231 .5595 L F
.40632 .9262 m .39328 .9274 L .40581 .92814 L .644 .733 .913 r
F
.40632 .9262 m .39429 .92352 L .39328 .9274 L F
.34939 .68468 m .37549 .68028 L .35041 .68074 L .673 .757 .914 r
F
.41941 .92673 m .42488 .92267 L .42189 .92173 L .644 .733 .913 r
F
.41834 .92887 m .42044 .92688 L .41941 .92673 L F
.42044 .92688 m .42488 .92267 L .41941 .92673 L F
.41952 .92675 m .4184 .97893 L .41943 .97898 L .734 .478 .542 r
F
.41875 .97895 m .42 .97869 L .41896 .97847 L .692 .759 .903 r
F
.41773 .98122 m .41974 .97899 L .41875 .97895 L F
.41974 .97899 m .42 .97869 L .41875 .97895 L F
.4184 .97893 m .41834 .98169 L .41943 .97898 L .734 .478 .542 r
F
.41808 .98106 m .41923 .98065 L .4181 .98062 L .692 .759 .904 r
F
.41773 .98122 m .41762 .984 L .41876 .98384 L .692 .759 .903 r
F
.41773 .98122 m .41982 .98351 L .42074 .98302 L F
.41799 .98341 m .41902 .9811 L .41808 .98106 L .692 .759 .904 r
F
.41943 .97898 m .41858 .98108 L .41943 .98112 L .734 .478 .542 r
F
.41902 .9811 m .41923 .98065 L .41808 .98106 L .692 .759 .904 r
F
.41799 .98341 m .42027 .98088 L .41923 .98065 L F
.41943 .98112 m .41834 .98169 L .41942 .98181 L .734 .478 .542 r
F
.41858 .98108 m .41834 .98169 L .41943 .98112 L F
.41953 .92272 m .41945 .92674 L .41952 .92675 L F
.41945 .92674 m .41834 .98169 L .41952 .92675 L F
.41834 .92887 m .41235 .92193 L .4097 .92299 L .644 .733 .913 r
F
0 g
.41514 .92516 m
.41514 .92399 L
s
.41834 .92887 m .4154 .92135 L .41235 .92193 L .644 .733 .913 r
F
0 g
.41503 .97926 m
.41513 .92755 L
s
.41834 .92887 m .41866 .92128 L .4154 .92135 L .644 .733 .913 r
F
.71935 .67984 m .69554 .68812 L .71998 .68375 L .673 .758 .914 r
F
.71935 .67984 m .69427 .6803 L .69554 .68812 L F
.43088 .92961 m .44272 .92637 L .43053 .92762 L .644 .733 .913 r
F
.43088 .92961 m .44341 .93035 L .44272 .92637 L F
.41692 .97914 m .41784 .97844 L .41671 .9786 L .692 .759 .903 r
F
.41773 .98122 m .41782 .97901 L .41692 .97914 L F
.41845 .92259 m .4173 .97908 L .41835 .97893 L .661 .418 .542 r
F
.41782 .97901 m .41784 .97844 L .41692 .97914 L .692 .759 .903 r
F
.41773 .98122 m .41896 .97847 L .41784 .97844 L F
.4173 .97908 m .41725 .98177 L .41835 .97893 L .661 .418 .542 r
F
.41714 .98125 m .4181 .98062 L .41696 .98078 L .692 .759 .904 r
F
.41799 .98341 m .41808 .98111 L .41714 .98125 L F
.41835 .97893 m .41747 .9812 L .41834 .98107 L .661 .418 .542 r
F
.41808 .98111 m .4181 .98062 L .41714 .98125 L .692 .759 .904 r
F
.41834 .98107 m .41725 .98177 L .41834 .98169 L .661 .418 .542 r
F
.41747 .9812 m .41725 .98177 L .41834 .98107 L F
.44341 .93035 m .45491 .92511 L .44272 .92637 L .644 .733 .913 r
F
.44341 .93035 m .45594 .93108 L .45491 .92511 L F
.45594 .93108 m .45516 .92135 L .45491 .92511 L .928 .753 .272 r
F
0 g
.45441 .9369 m
.45594 .93108 L
s
.4079 .92068 m .39455 .91976 L .40657 .92243 L .644 .733 .913 r
F
.20447 .54915 m .22743 .54911 L .22697 .55638 L .793 .543 .559 r
F
0 g
.20454 .54917 m
.22479 .57406 L
s
.20447 .54915 m .20494 .54188 L .22743 .54911 L .793 .543 .559 r
F
0 g
.22743 .54911 m
.25125 .55238 L
s
.40821 .91693 m .39756 .91252 L .39492 .91602 L .644 .733 .913 r
F
.41026 .91549 m .39756 .91252 L .40821 .91693 L F
.43079 .92386 m .44062 .91879 L .42961 .92195 L F
.43079 .92386 m .44297 .9226 L .44062 .91879 L F
.48013 .54445 m .4622 .56197 L .48495 .54888 L .654 .726 .902 r
F
.48013 .54445 m .45257 .5531 L .4622 .56197 L F
.42981 .9182 m .43693 .9117 L .42789 .91652 L .644 .733 .913 r
F
.42981 .9182 m .44077 .91506 L .43693 .9117 L F
.39756 .91252 m .38296 .91336 L .39492 .91602 L F
.37494 .67462 m .39786 .66248 L .37358 .66683 L .673 .757 .914 r
F
.34999 .67508 m .37494 .67462 L .37358 .66683 L F
.55481 .68351 m .54299 .67066 L .52712 .67814 L .673 .758 .914 r
F
.567 .68027 m .54299 .67066 L .55481 .68351 L F
.22133 .52507 m .22757 .54882 L .23626 .52987 L .654 .726 .902 r
F
.22133 .52507 m .20519 .54163 L .22757 .54882 L F
.44311 .91885 m .45173 .91192 L .44077 .91506 L .644 .733 .913 r
F
.44311 .91885 m .45523 .9176 L .45173 .91192 L F
.5293 .5512 m .55086 .56661 L .56118 .55879 L .654 .726 .902 r
F
.52267 .55407 m .55086 .56661 L .5293 .5512 L F
.59203 .79829 m .60487 .8055 L .61108 .80055 L .683 .771 .917 r
F
.58805 .80028 m .60487 .8055 L .59203 .79829 L F
.127 .923 .03 r
.80959 .57358 m
.80964 .57256 L
s
.60992 .79137 m .6318 .78772 L .61394 .78579 L .683 .77 .917 r
F
.59406 .78665 m .60992 .79137 L .61394 .78579 L F
.70037 .55269 m .68082 .55401 L .68042 .56128 L .494 .288 .528 r
F
.70037 .55269 m .70077 .54542 L .68082 .55401 L F
0 g
.66529 .56573 m
.68082 .55401 L
s
.5275 .68933 m .51477 .69331 L .51508 .69898 L .39 .237 .55 r
F
.5275 .68933 m .52719 .68366 L .51477 .69331 L F
0 g
.50672 .70441 m
.51477 .69331 L
s
.81963 .678 m .81928 .67233 L .81743 .66059 L .812 .611 .054 r
F
0 g
.8177 .67803 m
.81903 .67324 L
s
.30054 .68733 m .27685 .69561 L .30123 .69124 L .673 .758 .914 r
F
.30054 .68733 m .27545 .68779 L .27685 .69561 L F
.79396 .6728 m .8189 .67234 L .81706 .66065 L F
.56215 .79297 m .55134 .80376 L .56501 .79513 L .683 .77 .917 r
F
.56215 .79297 m .54561 .79944 L .55134 .80376 L F
.52437 .80267 m .52909 .8059 L .52958 .81047 L .981 .69 .339 r
F
.52437 .80267 m .52387 .7981 L .52909 .8059 L F
.54214 .79423 m .52909 .8059 L .54561 .79944 L .683 .77 .917 r
F
.54214 .79423 m .52387 .7981 L .52909 .8059 L F
0 g
.52909 .8059 m
.53324 .80904 L
s
.34999 .67508 m .37358 .66683 L .3493 .67118 L .673 .757 .914 r
F
.54471 .69973 m .5275 .68933 L .51508 .69898 L .673 .758 .915 r
F
0 g
.50704 .71008 m
.51508 .69898 L
s
.55533 .69472 m .5275 .68933 L .54471 .69973 L .673 .758 .915 r
F
.81343 .56824 m .81381 .56096 L .79484 .55034 L .858 .601 .548 r
F
0 g
.85025 .55394 m
.86069 .56712 L
s
.81381 .56096 m
.82809 .57425 L
s
.71479 .57823 m .69997 .55997 L .68002 .56855 L .654 .726 .902 r
F
.73011 .575 m .69997 .55997 L .71479 .57823 L F
.73051 .56772 m .72336 .54784 L .70037 .55269 L F
.7468 .5672 m .72336 .54784 L .73051 .56772 L F
.76296 .56942 m .74781 .54706 L .7468 .5672 L F
.76296 .56942 m .77207 .55039 L .74781 .54706 L F
.60516 .68813 m .60048 .67053 L .59322 .68532 L .673 .758 .914 r
F
.60516 .68813 m .61839 .67475 L .60048 .67053 L F
.77749 .58151 m .77168 .55767 L .76257 .57669 L .654 .726 .902 r
F
.77749 .58151 m .79406 .56489 L .77168 .55767 L F
.76841 .68286 m .79456 .67846 L .76949 .67892 L .673 .758 .914 r
F
.41026 .91549 m .40165 .90962 L .39756 .91252 L .644 .733 .913 r
F
.41289 .91444 m .40165 .90962 L .41026 .91549 L F
.42789 .91652 m .43187 .90899 L .42536 .91517 L F
.42789 .91652 m .43693 .9117 L .43187 .90899 L F
.40765 .92444 m .39429 .92352 L .40632 .9262 L F
.79396 .6728 m .81706 .66065 L .79273 .66501 L .673 .758 .914 r
F
.76902 .67325 m .79396 .6728 L .79273 .66501 L F
.4079 .92068 m .3972 .91624 L .39455 .91976 L .644 .733 .913 r
F
.40996 .91922 m .3972 .91624 L .4079 .92068 L F
.43053 .92762 m .44037 .92256 L .42936 .92572 L F
.43053 .92762 m .44272 .92637 L .44037 .92256 L F
.42961 .92195 m .43677 .91541 L .42768 .92026 L F
.127 .923 .03 r
.42941 .91934 m
.42942 .91711 L
s
.42913 .91949 m
.42942 .91711 L
s
.42961 .92195 m .44062 .91879 L .43677 .91541 L .644 .733 .913 r
F
.2265 .56365 m .25124 .55971 L .25078 .56698 L .732 .488 .559 r
F
.2265 .56365 m .22697 .55638 L .25124 .55971 L F
.2357 .53733 m .25124 .55971 L .2519 .53956 L .654 .726 .902 r
F
.2357 .53733 m .22697 .55638 L .25124 .55971 L F
.3972 .91624 m .38252 .91708 L .39455 .91976 L .644 .733 .913 r
F
.40057 .67982 m .39823 .66241 L .39853 .66808 L .835 .63 .083 r
F
.37549 .68028 m .40057 .67982 L .39853 .66808 L .673 .757 .914 r
F
.40088 .68549 m .40057 .67982 L .39853 .66808 L .835 .63 .083 r
F
0 g
.39909 .68552 m
.40027 .68098 L
s
.59283 .6798 m .58074 .6639 L .57996 .67901 L .673 .758 .914 r
F
.59283 .6798 m .60004 .66509 L .58074 .6639 L F
.127 .923 .03 r
.59989 .66508 m
.60122 .61067 L
s
.39756 .91252 m .38691 .90811 L .38296 .91336 L .644 .733 .913 r
F
.3865 .91181 m .38278 .91332 L .38252 .91708 L .081 0 .405 r
F
.127 .923 .03 r
.38771 2.04339 m
.39626 8.82741 L
s
.3865 .91181 m .38675 .90804 L .38278 .91332 L .081 0 .405 r
F
0 g
.38126 .91914 m
.38278 .91332 L
s
.44297 .9226 m .45164 .91563 L .44062 .91879 L .644 .733 .913 r
F
.44297 .9226 m .45516 .92135 L .45164 .91563 L F
.44626 .55033 m .42459 .56902 L .45214 .56038 L .654 .726 .902 r
F
.44626 .55033 m .41576 .55396 L .42459 .56902 L F
0 g
.42459 .56902 m
.43904 .58231 L
s
.63257 .79231 m .63207 .78775 L .63446 .77894 L 0 0 .395 r
F
.127 .923 .03 r
.63629 .78998 m
.63638 .78671 L
s
.63705 .79434 m
.63719 .78638 L
s
0 g
.62826 .79303 m
.63207 .78775 L
s
.61394 .78579 m .6318 .78772 L .63418 .77896 L .683 .77 .917 r
F
.45516 .92135 m .45542 .91758 L .45189 .91187 L .989 .751 .48 r
F
0 g
.45542 .91758 m
.45645 .92355 L
s
.34969 .69035 m .3758 .68595 L .35071 .68641 L .673 .758 .914 r
F
.7468 .5672 m .74781 .54706 L .72336 .54784 L .654 .726 .902 r
F
.71969 .68551 m .69588 .69379 L .72032 .68942 L .673 .758 .915 r
F
.71969 .68551 m .69461 .68597 L .69588 .69379 L F
.58747 .57755 m .59794 .5562 L .59752 .56347 L .075 0 .398 r
F
.56076 .56606 m .58747 .57755 L .59752 .56347 L .654 .726 .902 r
F
.55044 .57388 m .58747 .57755 L .56076 .56606 L F
0 g
.57545 .58663 m
.58747 .57755 L
s
.76902 .67325 m .79273 .66501 L .7684 .66936 L .673 .758 .914 r
F
.61058 .79598 m .63257 .79231 L .61461 .79038 L .683 .77 .917 r
F
.59464 .79124 m .61058 .79598 L .61461 .79038 L F
.30108 .67207 m .27511 .67645 L .30007 .67599 L .673 .757 .914 r
F
.37549 .68028 m .39853 .66808 L .37412 .67245 L F
.35041 .68074 m .37549 .68028 L .37412 .67245 L F
.41289 .91444 m .40692 .90752 L .40165 .90962 L .644 .733 .913 r
F
.41593 .91386 m .40692 .90752 L .41289 .91444 L F
.42536 .91517 m .42591 .90713 L .42238 .91424 L F
.42536 .91517 m .43187 .90899 L .42591 .90713 L F
.567 .68027 m .56128 .6658 L .54299 .67066 L .673 .758 .914 r
F
.57996 .67901 m .56128 .6658 L .567 .68027 L F
.56264 .79754 m .55183 .80833 L .5655 .7997 L .683 .771 .917 r
F
.56264 .79754 m .54611 .804 L .55183 .80833 L F
.55501 .68905 m .54313 .67613 L .52719 .68366 L .673 .758 .914 r
F
.56726 .6858 m .54313 .67613 L .55501 .68905 L F
.54264 .7988 m .52958 .81047 L .54611 .804 L .683 .771 .917 r
F
.54264 .7988 m .52437 .80267 L .52958 .81047 L F
0 g
.52958 .81047 m
.53817 .81694 L
s
.39435 .57007 m .37568 .55217 L .37523 .55945 L .857 .601 .55 r
F
.39391 .57734 m .39435 .57007 L .37523 .55945 L F
0 g
.39435 .57007 m
.40882 .58335 L
s
.31104 .57682 m .3036 .55695 L .2807 .5618 L .654 .726 .902 r
F
.32732 .5763 m .3036 .55695 L .31104 .57682 L F
.34349 .57852 m .32803 .55616 L .32732 .5763 L F
.34349 .57852 m .35231 .5595 L .32803 .55616 L F
.40996 .91922 m .40131 .91333 L .3972 .91624 L .644 .733 .913 r
F
.4126 .91817 m .40131 .91333 L .40996 .91922 L F
.57996 .67901 m .58074 .6639 L .56128 .6658 L .673 .758 .914 r
F
.42768 .92026 m .43168 .91269 L .42514 .9189 L .644 .733 .913 r
F
.42768 .92026 m .43677 .91541 L .43168 .91269 L F
.74408 .67371 m .73236 .66085 L .72705 .66335 L .673 .758 .914 r
F
.74408 .67371 m .73846 .65923 L .73236 .66085 L F
.74408 .67371 m .74495 .6586 L .73846 .65923 L F
0 g
.74151 .67334 m
.74152 .6762 L
s
.81963 .678 m .81743 .66059 L .81778 .66626 L .812 .611 .054 r
F
.79456 .67846 m .81963 .678 L .81778 .66626 L .673 .758 .914 r
F
.81998 .68367 m .81963 .678 L .81778 .66626 L .812 .611 .054 r
F
0 g
.81805 .6837 m
.81938 .67891 L
s
.41593 .91386 m .413 .90637 L .40692 .90752 L .644 .733 .913 r
F
.41916 .91379 m .413 .90637 L .41593 .91386 L F
.40765 .92444 m .39694 .92001 L .39429 .92352 L F
.4097 .92299 m .39694 .92001 L .40765 .92444 L F
.42238 .91424 m .41948 .90623 L .41916 .91379 L F
.42238 .91424 m .42591 .90713 L .41948 .90623 L F
.27712 .6686 m .25015 .67691 L .27511 .67645 L .673 .757 .914 r
F
.30108 .67207 m .27712 .6686 L .27511 .67645 L F
.63359 .68171 m .63326 .67604 L .61806 .66908 L .859 .596 .539 r
F
0 g
.63326 .67604 m
.64471 .68525 L
s
.42936 .92572 m .43652 .91918 L .42743 .92403 L .644 .733 .913 r
F
.127 .923 .03 r
.42865 .92338 m
.42892 .92114 L
s
.42936 .92572 m .44037 .92256 L .43652 .91918 L .644 .733 .913 r
F
.127 .923 .03 r
.42939 .92298 m
.4294 .9206 L
s
.35041 .68074 m .37412 .67245 L .34972 .67683 L .673 .757 .914 r
F
.39694 .92001 m .38226 .92085 L .39429 .92352 L .644 .733 .913 r
F
.204 .55642 m .22697 .55638 L .2265 .56365 L .793 .543 .559 r
F
.204 .55642 m .20447 .54915 L .22697 .55638 L F
.2207 .53251 m .22697 .55638 L .2357 .53733 L .654 .726 .902 r
F
.2207 .53251 m .20447 .54915 L .22697 .55638 L F
0 g
.22697 .55638 m
.25101 .55968 L
s
.17722 .5156 m
.20448 .54909 L
s
.40165 .90962 m .38691 .90811 L .39756 .91252 L .644 .733 .913 r
F
.38624 .91557 m .38252 .91708 L .38226 .92085 L .081 0 .405 r
F
.3972 .91624 m .3865 .91181 L .38252 .91708 L .644 .733 .913 r
F
.38624 .91557 m .3865 .91181 L .38252 .91708 L .081 0 .405 r
F
0 g
.381 .9229 m
.38252 .91708 L
s
.4797 .55172 m .46177 .56924 L .48452 .55616 L .654 .726 .902 r
F
.4797 .55172 m .45214 .56038 L .46177 .56924 L F
.44272 .92637 m .45139 .9194 L .44037 .92256 L .644 .733 .913 r
F
.44272 .92637 m .45491 .92511 L .45139 .9194 L F
.41916 .91379 m .41948 .90623 L .413 .90637 L F
.60549 .6938 m .6008 .67621 L .59355 .69099 L .673 .758 .915 r
F
.60549 .6938 m .61872 .68043 L .6008 .67621 L F
.76875 .68853 m .79491 .68413 L .76983 .68459 L F
.44077 .91506 m .44598 .90687 L .43693 .9117 L .644 .733 .913 r
F
.44077 .91506 m .45173 .91192 L .44598 .90687 L F
.56001 .78578 m .54528 .79481 L .56173 .78837 L .683 .77 .917 r
F
.56001 .78578 m .54183 .78963 L .54528 .79481 L F
.52887 .55848 m .55044 .57388 L .56076 .56606 L .654 .726 .902 r
F
.52224 .56134 m .55044 .57388 L .52887 .55848 L F
.45516 .92135 m .45189 .91187 L .45164 .91563 L .989 .751 .48 r
F
.45491 .92511 m .45516 .92135 L .45164 .91563 L F
0 g
.45516 .92135 m
.45619 .92732 L
s
.47778 .53213 m .45328 .54575 L .4807 .53713 L .654 .726 .902 r
F
.47778 .53213 m .44743 .53575 L .45328 .54575 L F
.127 .923 .03 r
.45029 .53541 m
.45041 .51734 L
s
.43086 1.20301 m
.49738 8.7991 L
s
0 0 0 r
2.5 Mabswid
.42843 .92518 Mdot
.50941 .53196 m .50731 .54857 L .50808 .54855 L .654 .726 .902 r
F
.51025 .53424 m .50808 .54855 L .51541 .54831 L F
.50941 .53196 m .50808 .54855 L .51025 .53424 L F
.50671 .5457 m .50665 .54286 L .51154 .54246 L .666 .425 .547 r
F
.5083 .54807 m .50688 .55594 L .50803 .55591 L .654 .726 .902 r
F
.50671 .5457 m .51154 .54246 L .5116 .5453 L .666 .425 .547 r
F
.50688 .54153 m .50671 .5457 L .5116 .5453 L .675 .735 .895 r
F
.50905 .53248 m .50731 .54857 L .50941 .53196 L .654 .726 .902 r
F
.50682 .53865 m .51152 .5424 L .51007 .53838 L .675 .735 .895 r
F
.50706 .53736 m .51015 .54127 L .50869 .53723 L F
.50864 .53831 m .50766 .54809 L .5083 .54807 L .654 .726 .902 r
F
.50766 .54809 m .50688 .55594 L .5083 .54807 L F
.50688 .54153 m .5116 .5453 L .51015 .54127 L .675 .735 .895 r
F
.50866 .53834 m .50803 .55591 L .5101 .54227 L .654 .726 .902 r
F
.50913 .53137 m .50731 .54857 L .50918 .53133 L F
.50877 .53126 m .50731 .54857 L .50914 .53123 L F
.50803 .53132 m .50802 .53154 L .50877 .53126 L F
.50802 .53154 m .50731 .54857 L .50877 .53126 L F
.50699 .53449 m .51007 .53838 L .50862 .53436 L .675 .735 .895 r
F
.50904 .53539 m .50869 .53723 L .51022 .53682 L F
.50907 .53265 m .50862 .53436 L .51014 .53396 L F
.50463 .51769 m .50562 .51817 L .50562 .5311 L .845 .571 .524 r
F
.5036 .5164 m .50397 .5171 L .50397 .53002 L .989 .72 .386 r
F
.5078 .53689 m .50437 .54114 L .50731 .54857 L .654 .726 .902 r
F
.50437 .54114 m .49926 .54747 L .50483 .54823 L F
.50437 .54114 m .50483 .54823 L .50731 .54857 L F
.50355 .51559 m .5036 .5164 L .5036 .52934 L .783 .625 .063 r
F
.50688 .53525 m .50426 .53946 L .5078 .53689 L .654 .726 .902 r
F
.50426 .53946 m .49926 .54747 L .50437 .54114 L F
.50426 .53946 m .50437 .54114 L .5078 .53689 L F
.50748 .53315 m .50658 .53471 L .50793 .53356 L F
.50658 .53471 m .49926 .54747 L .50688 .53525 L F
.50658 .53471 m .50688 .53525 L .50793 .53356 L F
.50771 .53213 m .50725 .53295 L .50799 .53227 L F
.50725 .53295 m .49926 .54747 L .50748 .53315 L F
.50725 .53295 m .50748 .53315 L .50799 .53227 L F
.50791 .53154 m .50762 .53208 L .50802 .53156 L F
.50762 .53208 m .49926 .54747 L .50771 .53213 L F
.50762 .53208 m .50771 .53213 L .50802 .53156 L F
.50678 .53144 m .49926 .54747 L .50791 .53154 L F
.50719 .5314 m .50791 .53154 L .50803 .53132 L F
.50678 .53144 m .50791 .53154 L .50719 .5314 L F
.50815 .52851 m .49778 .53902 L .49926 .54747 L F
.49778 .53902 m .49182 .54507 L .49406 .54579 L F
.49778 .53902 m .49406 .54579 L .49926 .54747 L F
.5036 .5164 m .50368 .52949 L .5036 .52934 L .989 .72 .386 r
F
.50355 .51559 m .50356 .52873 L .50355 .52856 L .783 .625 .063 r
F
.50355 .51559 m .5036 .52934 L .50356 .52873 L F
.50408 .51456 m .50355 .51559 L .50355 .52856 L 0 0 .377 r
F
.49778 .53902 m .48549 .54155 L .49182 .54507 L .654 .726 .902 r
F
.50815 .52851 m .50145 .53237 L .49778 .53902 L F
.50145 .53237 m .48549 .54155 L .49778 .53902 L F
.50405 .54775 m .49879 .55483 L .5072 .54818 L F
.50192 .54809 m .50292 .54759 L .50677 .54855 L .731 .477 .545 r
F
.50292 .54759 m .50671 .5457 L .50677 .54812 L F
.50292 .54759 m .50677 .54812 L .50677 .54855 L F
.5072 .54818 m .49879 .55483 L .50688 .55594 L .654 .726 .902 r
F
.50741 .54323 m .50405 .54775 L .5072 .54818 L F
.50706 .53289 m .50538 .53434 L .50699 .53449 L .675 .735 .895 r
F
.50596 .53116 m .50719 .5314 L .50719 .53291 L .751 .491 .539 r
F
.50596 .53116 m .50719 .53291 L .50623 .53277 L F
.50716 .53034 m .50609 .53275 L .50706 .53289 L .675 .735 .895 r
F
.50609 .53275 m .50538 .53434 L .50706 .53289 L F
.50538 .53434 m .50682 .53865 L .50699 .53449 L F
.50712 .53571 m .50544 .53721 L .50706 .53736 L F
.50623 .53277 m .50719 .53572 L .50672 .53565 L .751 .491 .539 r
F
.50723 .53319 m .50617 .53557 L .50712 .53571 L .675 .735 .895 r
F
.50617 .53557 m .50544 .53721 L .50712 .53571 L F
.50623 .53277 m .50719 .53291 L .50719 .53572 L .751 .491 .539 r
F
.50793 .53356 m .50688 .53525 L .5078 .53689 L .654 .726 .902 r
F
.50699 .53449 m .50682 .53865 L .51007 .53838 L .675 .735 .895 r
F
.50672 .53565 m .50695 .53569 L .5069 .53674 L .751 .491 .539 r
F
.50695 .53569 m .50719 .53572 L .5069 .53674 L F
.5081 .5356 m .50706 .53736 L .50869 .53723 L .675 .735 .895 r
F
.50805 .53279 m .50699 .53449 L .50862 .53436 L F
.50719 .5314 m .50734 .5357 L .50719 .53572 L .641 .402 .54 r
F
.50712 .53573 m .50706 .53736 L .5081 .5356 L .675 .735 .895 r
F
.50799 .53227 m .50748 .53315 L .50793 .53356 L .654 .726 .902 r
F
.50706 .53293 m .50699 .53449 L .50805 .53279 L .675 .735 .895 r
F
.50682 .53865 m .50665 .5428 L .51152 .5424 L F
.50706 .53736 m .50688 .54153 L .51015 .54127 L F
.50761 .5384 m .50688 .55594 L .50864 .53831 L .654 .726 .902 r
F
.50754 .53137 m .50773 .53839 L .50719 .5314 L .641 .402 .54 r
F
.50677 .54855 m .50744 .5481 L .51167 .54815 L .666 .425 .547 r
F
.50922 .54804 m .50803 .55591 L .51218 .54794 L .654 .726 .902 r
F
.50821 .54556 m .50645 .56322 L .508 .56317 L F
.50995 .55031 m .508 .56317 L .51459 .56296 L F
.50744 .5481 m .50671 .5457 L .5116 .5453 L .666 .425 .547 r
F
.50677 .54855 m .50677 .54812 L .50744 .5481 L F
.50677 .54812 m .50671 .5457 L .50744 .5481 L F
.50864 .53835 m .5083 .54807 L .50866 .53834 L .654 .726 .902 r
F
.5083 .54807 m .50803 .55591 L .50831 .54807 L F
.5083 .54807 m .50831 .54807 L .50866 .53834 L F
.50744 .5481 m .5116 .5453 L .51166 .54796 L .666 .425 .547 r
F
.50744 .5481 m .51166 .54796 L .51167 .54815 L F
.50695 .54438 m .50677 .54855 L .51167 .54815 L .675 .735 .895 r
F
.50821 .54556 m .508 .56317 L .50995 .55031 L .654 .726 .902 r
F
.51218 .54794 m .50803 .55591 L .51502 .55568 L F
.51019 .54873 m .51459 .56296 L .51046 .54694 L F
.50877 .51822 m .50979 .51779 L .50979 .53087 L .517 .303 .528 r
F
.50995 .55031 m .51019 .54873 L .50913 .54531 L .654 .726 .902 r
F
.5105 .51722 m .51093 .51654 L .51093 .52972 L .076 0 .415 r
F
.5105 .53256 m .51541 .54831 L .51923 .5475 L .654 .726 .902 r
F
.50981 .53137 m .51041 .53318 L .5105 .53256 L F
.51041 .53318 m .51541 .54831 L .5105 .53256 L F
.51093 .51654 m .51105 .51572 L .51105 .52895 L 0 0 .142 r
F
.5105 .51722 m .51093 .52972 L .5106 .53021 L .076 0 .415 r
F
.50975 .53146 m .51541 .54831 L .50981 .53137 L .654 .726 .902 r
F
.50959 .53102 m .51541 .54831 L .5096 .53101 L F
.50986 .5322 m .51014 .53396 L .51146 .5333 L .675 .735 .895 r
F
.50718 .51843 m .50877 .51822 L .50877 .53269 L .641 .402 .54 r
F
.50918 .53133 m .50905 .53248 L .50941 .53196 L .654 .726 .902 r
F
.50716 .53034 m .50916 .53276 L .50986 .5322 L .675 .735 .895 r
F
.5096 .53101 m .50975 .53146 L .50981 .53137 L .654 .726 .902 r
F
.50957 .53096 m .50959 .53102 L .5096 .53101 L F
.50911 .53113 m .51541 .54831 L .50957 .53096 L F
.50914 .53123 m .50913 .53137 L .50918 .53133 L F
.509 .53117 m .50979 .53087 L .50979 .53225 L .517 .303 .528 r
F
.50916 .53276 m .51014 .53396 L .50986 .53222 L .675 .735 .895 r
F
.50916 .53276 m .50986 .53222 L .50979 .53225 L F
.50862 .53436 m .51312 .53757 L .51014 .53396 L F
.51194 .5479 m .5116 .5453 L .5162 .54408 L .592 .367 .544 r
F
.51167 .54815 m .51166 .54796 L .51194 .5479 L F
.51166 .54796 m .5116 .5453 L .51194 .5479 L F
.51498 .54726 m .51502 .55568 L .51933 .55477 L .654 .726 .902 r
F
.5116 .5453 m .51614 .54124 L .5162 .54408 L .592 .367 .544 r
F
.5116 .5453 m .51154 .54246 L .51614 .54124 L F
.51015 .54127 m .5116 .5453 L .5162 .54408 L .675 .735 .895 r
F
.51508 .54724 m .5162 .54408 L .51626 .54692 L .592 .367 .544 r
F
.5128 .54772 m .51502 .55568 L .51498 .54726 L .654 .726 .902 r
F
.51167 .54815 m .51194 .5479 L .51508 .54724 L .592 .367 .544 r
F
.51194 .5479 m .5162 .54408 L .51508 .54724 L F
.51257 .54348 m .51626 .54692 L .51327 .54329 L .675 .735 .895 r
F
.51093 .54104 m .5128 .54772 L .51423 .54597 L .654 .726 .902 r
F
.50908 .53949 m .51502 .55568 L .51039 .54024 L F
.51007 .53838 m .51152 .5424 L .51609 .54118 L .675 .735 .895 r
F
.50869 .53723 m .51015 .54127 L .51321 .54045 L F
.50815 .52851 m .52302 .5467 L .52961 .54385 L .654 .726 .902 r
F
.51091 .53104 m .51249 .53245 L .51316 .53145 L .675 .735 .895 r
F
.50995 .53076 m .5105 .53036 L .5105 .53168 L .358 .18 .498 r
F
.50815 .52851 m .51923 .5475 L .51403 .53571 L .654 .726 .902 r
F
.50995 .53076 m .5105 .53168 L .51006 .53203 L .358 .18 .498 r
F
.50716 .53034 m .51051 .53167 L .51091 .53104 L .675 .735 .895 r
F
.51051 .53167 m .51249 .53245 L .51091 .53104 L F
.50815 .52851 m .52961 .54385 L .53033 .54331 L .654 .726 .902 r
F
.50815 .52851 m .53033 .54331 L .51529 .53159 L F
.50862 .53436 m .51007 .53838 L .51312 .53757 L .675 .735 .895 r
F
.50873 .53726 m .51321 .54045 L .50876 .53721 L F
.51008 .53796 m .51028 .53966 L .51161 .53901 L F
.50876 .53721 m .51321 .54045 L .51022 .53682 L F
.5099 .53783 m .50996 .53815 L .51008 .53796 L F
.50996 .53815 m .51028 .53966 L .51008 .53796 L F
.51096 .52955 m .51096 .5308 L .51093 .52972 L 0 0 .142 r
F
.51007 .53235 m .51146 .5333 L .51051 .53167 L .675 .735 .895 r
F
.51082 .53179 m .51146 .5333 L .51249 .53245 L F
.51146 .5333 m .51782 .53456 L .51249 .53245 L F
.51112 .53252 m .51351 .53322 L .51334 .53214 L F
.51097 .53358 m .51096 .53365 L .51094 .53095 L 0 0 .142 r
F
.51051 .53167 m .51077 .53212 L .51082 .53179 L .675 .735 .895 r
F
.5106 .53021 m .51093 .53381 L .51063 .53429 L .076 0 .415 r
F
.5105 .53036 m .51054 .53443 L .5105 .53449 L F
.50916 .53252 m .50979 .53225 L .50979 .53506 L .517 .303 .528 r
F
.50723 .53319 m .51102 .53321 L .51112 .53252 L .675 .735 .895 r
F
.51102 .53321 m .51351 .53322 L .51112 .53252 L F
.51096 .5308 m .51097 .53358 L .51094 .53095 L 0 0 .142 r
F
.51014 .53396 m .51312 .53757 L .51576 .53626 L .675 .735 .895 r
F
.51014 .53396 m .51576 .53626 L .51146 .5333 L F
.51093 .53387 m .51258 .5353 L .51325 .5343 L F
.50805 .53279 m .50862 .53436 L .50907 .53265 L F
.50851 .53273 m .50877 .53269 L .50877 .5355 L .641 .402 .54 r
F
.509 .53117 m .50912 .53817 L .50877 .53126 L .517 .303 .528 r
F
.50723 .53319 m .51082 .53461 L .51093 .53387 L .675 .735 .895 r
F
.51082 .53461 m .51258 .5353 L .51093 .53387 L F
.51051 .53448 m .51155 .53616 L .51258 .5353 L F
.50916 .53252 m .50979 .53506 L .50947 .5352 L .517 .303 .528 r
F
.51007 .53838 m .51577 .54103 L .51312 .53757 L .675 .735 .895 r
F
.51022 .53682 m .51321 .54045 L .51586 .53914 L F
.51082 .53743 m .51161 .53901 L .51264 .53815 L F
.50907 .53537 m .50978 .53788 L .50912 .53816 L .517 .303 .528 r
F
.50729 .53603 m .5099 .53783 L .51082 .53743 L .675 .735 .895 r
F
.51063 .53429 m .51093 .53381 L .51093 .53663 L .076 0 .415 r
F
.51027 .53767 m .51161 .53901 L .51082 .53743 L .675 .735 .895 r
F
.51577 .54103 m .51609 .54118 L .51555 .54053 L F
.51577 .54103 m .51555 .54053 L .51312 .53757 L F
.51403 .53571 m .51923 .5475 L .52302 .5467 L .654 .726 .902 r
F
.5162 .54408 m .51614 .54124 L .52012 .53927 L .497 .294 .534 r
F
.5162 .54408 m .52012 .53927 L .52018 .54211 L F
.52024 .54496 m .52018 .54211 L .52328 .53954 L .358 .188 .509 r
F
.51312 .53757 m .51609 .54118 L .52005 .53922 L .675 .735 .895 r
F
.51321 .54045 m .52018 .54211 L .51586 .53914 L F
.52024 .54496 m .52328 .53954 L .52335 .54238 L .358 .188 .509 r
F
.51321 .54045 m .5162 .54408 L .52018 .54211 L .675 .735 .895 r
F
.51626 .54692 m .52018 .54211 L .52024 .54496 L .497 .294 .534 r
F
.51593 .54198 m .52024 .54496 L .52335 .54238 L .675 .735 .895 r
F
.51593 .54198 m .52335 .54238 L .51799 .54027 L F
.51161 .53901 m .51593 .54198 L .51799 .54027 L F
.51161 .53901 m .51799 .54027 L .51264 .53815 L F
.51072 .53708 m .5293 .5512 L .53446 .54729 L .654 .726 .902 r
F
.50947 .5352 m .5098 .53792 L .50907 .53537 L .517 .303 .528 r
F
.50898 .53541 m .50912 .53816 L .50877 .5355 L F
.51022 .53682 m .51586 .53914 L .51155 .53616 L .675 .735 .895 r
F
.51202 .53691 m .51264 .53815 L .51331 .53715 L F
.51004 .53768 m .5105 .5374 L .51004 .53774 L .358 .18 .498 r
F
.50989 .53502 m .51008 .53515 L .51027 .53485 L .675 .735 .895 r
F
.50989 .53502 m .51027 .53485 L .5105 .53449 L F
.50989 .53502 m .5105 .53449 L .51045 .53453 L F
.51006 .53203 m .5105 .53168 L .5105 .53449 L .358 .18 .498 r
F
.51008 .53515 m .51022 .53682 L .51155 .53616 L .675 .735 .895 r
F
.51028 .53467 m .5105 .53449 L .5105 .5374 L .358 .18 .498 r
F
.51006 .53203 m .5105 .53449 L .51028 .53467 L F
.51209 .53321 m .51325 .5343 L .51351 .53322 L .675 .735 .895 r
F
.50995 .53076 m .51028 .53467 L .51 .53489 L .358 .18 .498 r
F
.51061 .53151 m .51063 .53429 L .51053 .53163 L .076 0 .415 r
F
.51008 .53515 m .51155 .53616 L .51051 .53448 L .675 .735 .895 r
F
.51063 .53429 m .51065 .53707 L .51059 .53435 L .076 0 .415 r
F
.51063 .53429 m .51059 .53435 L .51053 .53163 L F
.51132 .53321 m .51121 .53392 L .51209 .53321 L .675 .735 .895 r
F
.5109 .53387 m .51121 .53392 L .51132 .53321 L F
.51121 .53392 m .51325 .5343 L .51209 .53321 L F
.5103 .5341 m .51282 .53398 L .51185 .53311 L F
.509 .53117 m .50947 .5352 L .50907 .53537 L .517 .303 .528 r
F
.50723 .53319 m .50904 .53539 L .50989 .53502 L .675 .735 .895 r
F
.5081 .5356 m .50816 .53577 L .50877 .5355 L F
.50758 .53286 m .50877 .5355 L .50765 .53566 L .641 .402 .54 r
F
.5081 .5356 m .50877 .5355 L .50904 .53539 L .675 .735 .895 r
F
.50877 .54534 m .5098 .57639 L .50878 .57683 L .517 .303 .528 r
F
.50896 .54527 m .5098 .57639 L .50877 .54534 L F
.50875 .54007 m .51021 .54411 L .51257 .54348 L .675 .735 .895 r
F
.50912 .53817 m .50925 .54517 L .50877 .5383 L .517 .303 .528 r
F
.50925 .54517 m .5098 .57639 L .50896 .54527 L F
.50712 .5402 m .50695 .54438 L .51021 .54411 L .675 .735 .895 r
F
.50925 .54517 m .50896 .54527 L .50877 .5383 L .517 .303 .528 r
F
.50877 .54534 m .50995 .55031 L .50913 .54531 L .654 .726 .902 r
F
.5101 .54227 m .50922 .54804 L .51218 .54794 L F
.50695 .54438 m .51167 .54815 L .51021 .54411 L .675 .735 .895 r
F
.50815 .5454 m .50821 .54556 L .50877 .54534 L .654 .726 .902 r
F
.50821 .54556 m .50995 .55031 L .50877 .54534 L F
.51008 .53796 m .51161 .53901 L .51027 .53767 L .675 .735 .895 r
F
.51015 .54127 m .5162 .54408 L .51321 .54045 L F
.51626 .54692 m .5162 .54408 L .52018 .54211 L .497 .294 .534 r
F
.51327 .54329 m .51626 .54692 L .52024 .54496 L .675 .735 .895 r
F
.51028 .53966 m .51327 .54329 L .51593 .54198 L F
.51105 .53986 m .52267 .55407 L .51105 .53836 L .654 .726 .902 r
F
.51105 .53986 m .51105 .53836 L .51075 .53796 L F
.51056 .53926 m .51105 .53986 L .51075 .53796 L F
.51098 .53649 m .51105 .53599 L .51105 .54303 L 0 0 .142 r
F
.51423 .54597 m .51384 .54644 L .5149 .54712 L .654 .726 .902 r
F
.51384 .54644 m .5128 .54772 L .5149 .54712 L F
.5149 .54712 m .5128 .54772 L .51498 .54726 L F
.5104 .54027 m .51502 .55568 L .51093 .54104 L F
.51005 .53973 m .51327 .54329 L .51028 .53966 L .675 .735 .895 r
F
.5104 .54026 m .51093 .54104 L .51051 .53955 L .654 .726 .902 r
F
.5104 .54027 m .51093 .54104 L .5104 .54026 L F
.51039 .54024 m .5104 .54027 L .5104 .54026 L F
.50875 .54007 m .51168 .54216 L .51005 .53973 L .675 .735 .895 r
F
.51168 .54216 m .51327 .54329 L .51005 .53973 L F
.51021 .54411 m .51167 .54815 L .51508 .54724 L F
.50956 .54583 m .51548 .55307 L .51008 .54506 L .654 .726 .902 r
F
.51548 .55307 m .52224 .56134 L .51463 .55114 L F
.51548 .55307 m .51463 .55114 L .51008 .54506 L F
.5105 .5373 m .51082 .53743 L .51119 .53675 L .675 .735 .895 r
F
.51065 .53718 m .51094 .53676 L .51094 .54381 L .076 0 .415 r
F
.51033 .53765 m .5293 .5512 L .51072 .53708 L .654 .726 .902 r
F
.50995 .53535 m .51022 .53682 L .51008 .53515 L .675 .735 .895 r
F
.50904 .53539 m .51022 .53682 L .50989 .53502 L F
.51 .53489 m .51049 .53731 L .51004 .53768 L .358 .18 .498 r
F
.50947 .5352 m .50979 .53506 L .5098 .53792 L .517 .303 .528 r
F
.50773 .53839 m .50743 .53842 L .50719 .5314 L .641 .402 .54 r
F
.50729 .53603 m .5105 .5373 L .51119 .53675 L .675 .735 .895 r
F
.51065 .53707 m .51093 .53663 L .51094 .53676 L .076 0 .415 r
F
.51065 .53707 m .51094 .53676 L .51065 .53718 L F
.51063 .53429 m .51093 .53663 L .51065 .53707 L F
.5109 .53564 m .51061 .53498 L .51061 .54202 L .984 .727 .339 r
F
.51168 .54216 m .51257 .54348 L .51327 .54329 L .675 .735 .895 r
F
.51424 .54599 m .51626 .54692 L .51257 .54348 L F
.50984 .53838 m .51423 .54597 L .51475 .54439 L .654 .726 .902 r
F
.51065 .53707 m .5107 .54415 L .51057 .5372 L .076 0 .415 r
F
.51498 .54726 m .51933 .55477 L .51593 .54706 L .654 .726 .902 r
F
.51475 .54439 m .51933 .55477 L .52267 .55407 L F
.51008 .54506 m .5128 .547 L .5105 .54444 L F
.5128 .547 m .52887 .55848 L .51227 .5458 L F
.5128 .547 m .51227 .5458 L .5105 .54444 L F
.51423 .54597 m .51498 .54726 L .51496 .54706 L F
.51424 .54599 m .51508 .54724 L .51626 .54692 L .675 .735 .895 r
F
.51021 .54411 m .51508 .54724 L .51424 .54599 L F
.51327 .54329 m .52024 .54496 L .51593 .54198 L F
.51245 .53917 m .52267 .55407 L .5293 .5512 L .654 .726 .902 r
F
.51364 .54185 m .52267 .55407 L .51245 .53917 L F
.51195 .54507 m .52887 .55848 L .53404 .55457 L F
.5105 .54444 m .51227 .5458 L .51195 .54507 L F
.51227 .5458 m .52887 .55848 L .51195 .54507 L F
.51095 .53664 m .51097 .54357 L .51094 .53676 L 0 0 .142 r
F
.5109 .53564 m .51085 .54256 L .51105 .53599 L .984 .727 .339 r
F
.5107 .54415 m .51094 .57514 L .51064 .54425 L .076 0 .415 r
F
.51385 .54455 m .53646 .55116 L .52606 .54731 L .654 .726 .902 r
F
.51021 .54411 m .51424 .54599 L .51257 .54348 L .675 .735 .895 r
F
.5105 .54444 m .51094 .57514 L .51051 .57583 L .076 0 .415 r
F
.5105 .5374 m .51058 .54433 L .5105 .54444 L F
.51058 .54433 m .51094 .57514 L .5105 .54444 L F
.51089 .54388 m .51452 .54507 L .51385 .54455 L .654 .726 .902 r
F
.50914 .53815 m .51028 .53966 L .5099 .53783 L .675 .735 .895 r
F
.50908 .53949 m .51039 .54024 L .50949 .53889 L .654 .726 .902 r
F
.50954 .53801 m .50959 .53807 L .5098 .53792 L F
.50912 .53817 m .5098 .53792 L .5098 .54496 L .517 .303 .528 r
F
.50925 .54517 m .5098 .54496 L .5098 .57639 L F
.50712 .5402 m .51021 .54411 L .50875 .54007 L .675 .735 .895 r
F
.50912 .53817 m .5098 .54496 L .50925 .54517 L .517 .303 .528 r
F
.51423 .54597 m .51496 .54706 L .51475 .54439 L .654 .726 .902 r
F
.51164 .54427 m .51767 .54753 L .51452 .54507 L F
.5098 .54496 m .51051 .57583 L .5098 .57639 L .358 .18 .498 r
F
.50877 .5355 m .50912 .53816 L .50877 .5383 L .517 .303 .528 r
F
.50882 .53789 m .51028 .53966 L .50782 .5364 L .675 .735 .895 r
F
.50949 .53889 m .51039 .54024 L .50984 .53838 L .654 .726 .902 r
F
.52018 .54211 m .52012 .53927 L .52322 .53669 L .358 .188 .509 r
F
.52018 .54211 m .52322 .53669 L .52328 .53954 L F
.51586 .53914 m .52018 .54211 L .52328 .53954 L .675 .735 .895 r
F
.52335 .54238 m .52328 .53954 L .52529 .53653 L .119 .01 .444 r
F
.51312 .53757 m .52005 .53922 L .51576 .53626 L .675 .735 .895 r
F
.51586 .53914 m .52328 .53954 L .51793 .53742 L F
.51155 .53616 m .51586 .53914 L .51793 .53742 L F
.51799 .54027 m .52335 .54238 L .52535 .53937 L F
.52335 .54238 m .52529 .53653 L .52535 .53937 L .119 .01 .444 r
F
.51799 .54027 m .52535 .53937 L .51933 .53826 L .675 .735 .895 r
F
.51264 .53815 m .51799 .54027 L .51933 .53826 L F
.51264 .53815 m .51933 .53826 L .51331 .53715 L F
.51152 .53665 m .53446 .54729 L .5378 .54259 L .654 .726 .902 r
F
.50816 .53577 m .50869 .53723 L .50904 .53539 L .675 .735 .895 r
F
.51065 .53707 m .51057 .5372 L .51054 .53443 L .076 0 .415 r
F
.5113 .53605 m .51331 .53715 L .51357 .53607 L .675 .735 .895 r
F
.5105 .53449 m .51053 .53726 L .5105 .5373 L .076 0 .415 r
F
.50979 .53087 m .5099 .53784 L .5098 .53792 L .358 .18 .498 r
F
.50729 .53603 m .51089 .5367 L .5113 .53605 L .675 .735 .895 r
F
.51089 .5367 m .51331 .53715 L .5113 .53605 L F
.5105 .5373 m .51053 .53735 L .5105 .5374 L .076 0 .415 r
F
.51053 .53726 m .51053 .53735 L .5105 .5373 L F
.50772 .53579 m .51086 .53714 L .51152 .53665 L .654 .726 .902 r
F
.51119 .53675 m .51082 .53743 L .51202 .53691 L .675 .735 .895 r
F
.51082 .53743 m .51264 .53815 L .51202 .53691 L F
.51086 .53714 m .53446 .54729 L .51152 .53665 L .654 .726 .902 r
F
.5098 .53792 m .51002 .5448 L .5098 .54496 L .358 .18 .498 r
F
.5099 .53784 m .51002 .5448 L .5098 .53792 L F
.50913 .54531 m .51019 .54873 L .51046 .54694 L .654 .726 .902 r
F
.51002 .5448 m .51051 .57583 L .5098 .54496 L .358 .18 .498 r
F
.51099 .54409 m .51082 .54458 L .51164 .54427 L .654 .726 .902 r
F
.50729 .54306 m .5105 .54444 L .51099 .54409 L F
.5105 .54444 m .51082 .54458 L .51099 .54409 L F
.51498 .54726 m .51593 .54706 L .51475 .54439 L F
.51082 .54458 m .51767 .54753 L .51164 .54427 L F
.50729 .54306 m .51078 .54403 L .51089 .54388 L F
.51078 .54403 m .51452 .54507 L .51089 .54388 L F
.51452 .54507 m .53646 .55116 L .51385 .54455 L F
.51028 .53467 m .51049 .53731 L .51 .53489 L .358 .18 .498 r
F
.50979 .51779 m .5105 .51722 L .5105 .53036 L F
.5105 .51722 m .5106 .53021 L .5105 .53036 L .076 0 .415 r
F
.5106 .51468 m .50955 .51385 L .50955 .52711 L .909 .63 .5 r
F
.50815 .52851 m .53673 .53718 L .5215 .53153 L .654 .726 .902 r
F
.50723 .53319 m .5109 .53387 L .51121 .53338 L .675 .735 .895 r
F
.50989 .53502 m .50995 .53535 L .51008 .53515 L F
.50979 .53225 m .50986 .53222 L .50986 .5322 L F
.50959 .53807 m .51056 .53926 L .5098 .53792 L .654 .726 .902 r
F
.50995 .53076 m .51004 .53774 L .50979 .53087 L .358 .18 .498 r
F
.50995 .55031 m .51459 .56296 L .51019 .54873 L .654 .726 .902 r
F
.51204 .54331 m .53738 .54987 L .53867 .54471 L F
.51008 .54506 m .51063 .5458 L .51068 .54549 L F
.5099 .53783 m .51008 .53796 L .51027 .53767 L .675 .735 .895 r
F
.50984 .53838 m .51039 .54024 L .51051 .53955 L .654 .726 .902 r
F
.51039 .54024 m .5104 .54026 L .51051 .53955 L F
.5098 .53792 m .51056 .53926 L .51039 .53769 L F
.51004 .53774 m .5105 .5374 L .5105 .54444 L .358 .18 .498 r
F
.51012 .54472 m .5105 .54444 L .51051 .57583 L F
.51004 .53774 m .5105 .54444 L .51012 .54472 L F
.51338 .5301 m .53475 .53996 L .53673 .53718 L .654 .726 .902 r
F
.51529 .53159 m .53475 .53996 L .51338 .5301 L F
.51529 .53159 m .53033 .54331 L .53475 .53996 L F
.51576 .53626 m .52005 .53922 L .52314 .53666 L .675 .735 .895 r
F
.52328 .53954 m .52322 .53669 L .52523 .53369 L .119 .01 .444 r
F
.51793 .53742 m .52328 .53954 L .52529 .53653 L .675 .735 .895 r
F
.51155 .53616 m .51793 .53742 L .51258 .5353 L F
.52535 .53937 m .52529 .53653 L .52607 .53329 L 0 0 .256 r
F
.52535 .53937 m .52607 .53329 L .52613 .53614 L F
.51933 .53826 m .52535 .53937 L .52613 .53614 L .675 .735 .895 r
F
.52328 .53954 m .52523 .53369 L .52529 .53653 L .119 .01 .444 r
F
.51576 .53626 m .52314 .53666 L .51782 .53456 L .675 .735 .895 r
F
.51793 .53742 m .52529 .53653 L .51927 .53542 L F
.51933 .53826 m .52613 .53614 L .51985 .5361 L F
.51258 .5353 m .51793 .53742 L .51927 .53542 L F
.51331 .53715 m .51933 .53826 L .51985 .5361 L F
.51331 .53715 m .51985 .5361 L .51357 .53607 L F
.51236 .53603 m .5378 .54259 L .53909 .53743 L .654 .726 .902 r
F
.51152 .53665 m .5378 .54259 L .51236 .53603 L F
.51004 .53774 m .5099 .53784 L .50979 .53087 L .358 .18 .498 r
F
.50723 .53319 m .51121 .53338 L .51114 .53321 L .675 .735 .895 r
F
.50979 .51779 m .50995 .53076 L .50979 .53087 L .358 .18 .498 r
F
.51092 .52866 m .53807 .53529 L .53936 .53015 L .654 .726 .902 r
F
.50979 .51779 m .5105 .53036 L .50995 .53076 L .358 .18 .498 r
F
.50815 .52851 m .51116 .5292 L .51092 .52866 L .654 .726 .902 r
F
.51116 .5292 m .53807 .53529 L .51092 .52866 L F
.51095 .52872 m .5106 .52917 L .51094 .52995 L .984 .727 .339 r
F
.51093 .51654 m .51096 .52955 L .51093 .52972 L 0 0 .142 r
F
.51105 .51572 m .51064 .52802 L .51095 .52872 L .984 .727 .339 r
F
.51093 .51654 m .51105 .52895 L .51096 .52955 L 0 0 .142 r
F
.51207 .52805 m .53936 .53015 L .53852 .5249 L .654 .726 .902 r
F
.50815 .52851 m .51419 .52883 L .51207 .52805 L F
.51419 .52883 m .53936 .53015 L .51207 .52805 L F
.50955 .51385 m .50847 .51347 L .50848 .52671 L .809 .541 .532 r
F
.50792 .54542 m .50768 .54544 L .50743 .53842 L .641 .402 .54 r
F
.50729 .54306 m .51118 .54394 L .51204 .54331 L .654 .726 .902 r
F
.50729 .54306 m .50956 .54583 L .51008 .54506 L F
.50869 .53723 m .50873 .53726 L .50876 .53721 L .675 .735 .895 r
F
.50912 .53816 m .50912 .53817 L .50903 .5382 L .517 .303 .528 r
F
.50912 .53816 m .50903 .5382 L .50877 .5383 L F
.50782 .5364 m .50914 .53815 L .5099 .53783 L .675 .735 .895 r
F
.50912 .53816 m .5098 .53792 L .50912 .53817 L .517 .303 .528 r
F
.50765 .53566 m .50877 .5355 L .50877 .5383 L .641 .402 .54 r
F
.50897 .53829 m .50875 .54007 L .51005 .53973 L .675 .735 .895 r
F
.50797 .53837 m .50877 .5383 L .50877 .53832 L .641 .402 .54 r
F
.50797 .53837 m .50877 .53832 L .50797 .53843 L F
.50765 .53566 m .50877 .5383 L .50797 .53837 L F
.50772 .53579 m .50761 .5384 L .50864 .53831 L .654 .726 .902 r
F
.50729 .53603 m .50815 .5384 L .50897 .53829 L .675 .735 .895 r
F
.50809 .5368 m .50908 .53949 L .50949 .53889 L .654 .726 .902 r
F
.50864 .53831 m .50864 .53835 L .50866 .53834 L F
.50815 .5384 m .50875 .54007 L .50897 .53829 L .675 .735 .895 r
F
.50797 .53843 m .50877 .53832 L .50877 .54534 L .641 .402 .54 r
F
.50772 .53579 m .50809 .5368 L .50966 .53822 L .654 .726 .902 r
F
.50971 .53822 m .50966 .53822 L .50984 .53838 L F
.50772 .53579 m .50966 .53822 L .50971 .53822 L F
.50809 .5368 m .50949 .53889 L .50984 .53838 L F
.50882 .53789 m .51005 .53973 L .51028 .53966 L .675 .735 .895 r
F
.50729 .53603 m .51005 .53973 L .50882 .53789 L F
.50877 .51822 m .509 .53117 L .50877 .53126 L .517 .303 .528 r
F
.50815 .52851 m .50911 .53113 L .50957 .53096 L .654 .726 .902 r
F
.50815 .5454 m .50813 .54559 L .50821 .54556 L F
.50792 .54542 m .50877 .54534 L .50878 .57683 L .641 .402 .54 r
F
.50877 .5383 m .50896 .54527 L .50877 .54534 L .517 .303 .528 r
F
.50877 .53126 m .50898 .53541 L .50877 .5355 L F
.5106 .51468 m .51036 .52775 L .5106 .52793 L .909 .63 .5 r
F
.51105 .51572 m .5106 .52793 L .51064 .52802 L .984 .727 .339 r
F
.50877 .51822 m .50979 .53087 L .509 .53117 L .517 .303 .528 r
F
.51105 .51572 m .51095 .52872 L .51105 .52895 L .984 .727 .339 r
F
.50896 .52678 m .52449 .51194 L .51704 .50953 L .654 .726 .902 r
F
.50815 .52851 m .50974 .5269 L .50896 .52678 L F
.50974 .5269 m .52449 .51194 L .50896 .52678 L F
.50765 .53566 m .50877 .54534 L .50792 .54542 L .641 .402 .54 r
F
.50729 .54306 m .50815 .5454 L .50913 .54531 L .654 .726 .902 r
F
.50792 .54542 m .50878 .57683 L .50768 .54544 L .641 .402 .54 r
F
.50813 .54559 m .50645 .56322 L .50821 .54556 L .654 .726 .902 r
F
.50719 .54549 m .50645 .56322 L .50815 .5454 L F
.50719 .53844 m .50878 .57683 L .50719 .57704 L .641 .402 .54 r
F
.50718 .51843 m .50877 .53269 L .50851 .53273 L F
.50815 .52851 m .50803 .53132 L .50914 .53123 L .654 .726 .902 r
F
.50815 .52851 m .53082 .51547 L .52449 .51194 L F
.50815 .52851 m .53561 .51989 L .53082 .51547 L F
.50815 .52851 m .53852 .5249 L .53561 .51989 L F
.50729 .53603 m .51357 .53607 L .51345 .53531 L .675 .735 .895 r
F
.51146 .5333 m .51576 .53626 L .51782 .53456 L F
.51258 .5353 m .51927 .53542 L .51325 .5343 L F
.5128 .53509 m .51345 .53531 L .5134 .53499 L F
.50729 .53603 m .51345 .53531 L .5128 .53509 L F
.50931 .52702 m .50848 .52671 L .50848 .52802 L .809 .541 .532 r
F
.50824 .52794 m .51044 .52676 L .50895 .52634 L .675 .735 .895 r
F
.50847 .51347 m .50739 .51335 L .50739 .52655 L .734 .477 .54 r
F
.50847 .51347 m .50739 .52655 L .50749 .52657 L F
.50562 .51817 m .50718 .51843 L .50719 .5314 L .751 .491 .539 r
F
.50397 .5171 m .50463 .51769 L .50463 .53061 L .929 .648 .488 r
F
.5052 .51377 m .50408 .51456 L .50408 .5276 L .401 .213 .507 r
F
.50428 .53219 m .50167 .53239 L .50263 .53325 L .675 .735 .895 r
F
.50485 .53072 m .50562 .5311 L .50562 .53267 L .845 .571 .524 r
F
.49844 .54634 m .49733 .54689 L .5022 .54755 L .654 .726 .902 r
F
.49743 .54682 m .49861 .5464 L .50192 .54809 L .794 .529 .537 r
F
.49861 .5464 m .50186 .54525 L .5019 .54746 L F
.49861 .5464 m .5019 .54746 L .50192 .54809 L F
.5022 .54755 m .49733 .54689 L .49879 .55483 L .654 .726 .902 r
F
.50407 .54358 m .49844 .54634 L .5022 .54755 L F
.5036 .53834 m .50182 .54234 L .50665 .5428 L .675 .735 .895 r
F
.50186 .54525 m .50179 .5424 L .50665 .54286 L .731 .477 .545 r
F
.50365 .54123 m .50671 .5457 L .50688 .54153 L .675 .735 .895 r
F
.50568 .54013 m .50394 .54155 L .50407 .54358 L .654 .726 .902 r
F
.49736 .54397 m .50179 .5424 L .50186 .54525 L .794 .529 .537 r
F
.50065 .54038 m .50186 .54525 L .50365 .54123 L .675 .735 .895 r
F
.50394 .54155 m .49733 .54689 L .50407 .54358 L .654 .726 .902 r
F
.50562 .51817 m .50596 .53116 L .50562 .5311 L .751 .491 .539 r
F
.50463 .51769 m .50485 .53072 L .50463 .53061 L .845 .571 .524 r
F
.50463 .51769 m .50562 .5311 L .50485 .53072 L F
.50815 .52851 m .49723 .53194 L .48549 .54155 L .654 .726 .902 r
F
.49723 .53194 m .4807 .53713 L .48411 .54027 L F
.49723 .53194 m .48411 .54027 L .48549 .54155 L F
.50485 .53072 m .50562 .53267 L .50488 .53233 L .845 .571 .524 r
F
.5036 .53834 m .50665 .5428 L .50682 .53865 L .675 .735 .895 r
F
.50544 .53721 m .50365 .54123 L .50688 .54153 L F
.50544 .53971 m .5039 .54107 L .50568 .54013 L .654 .726 .902 r
F
.5039 .54107 m .49733 .54689 L .50394 .54155 L F
.5039 .54107 m .50394 .54155 L .50568 .54013 L F
.50603 .5389 m .50389 .54087 L .50619 .53904 L F
.50389 .54087 m .49733 .54689 L .5039 .54107 L F
.50389 .54087 m .5039 .54107 L .50619 .53904 L F
.50364 .53165 m .50109 .53138 L .50167 .53239 L .675 .735 .895 r
F
.50544 .53721 m .50688 .54153 L .50706 .53736 L F
.50642 .53853 m .50602 .53889 L .50643 .53854 L .654 .726 .902 r
F
.50392 .53155 m .50167 .53239 L .50428 .53219 L .675 .735 .895 r
F
.50282 .53237 m .50187 .53107 L .50121 .53207 L F
.50412 .53015 m .50414 .53178 L .50397 .53002 L .929 .648 .488 r
F
.50509 .53261 m .50263 .53325 L .50389 .53392 L .675 .735 .895 r
F
.50447 .53207 m .50428 .53219 L .50509 .53261 L F
.50428 .53219 m .50263 .53325 L .50459 .53274 L F
.50428 .53219 m .50459 .53274 L .50509 .53261 L F
.50375 .53123 m .50397 .53445 L .50387 .53426 L .989 .72 .386 r
F
.50368 .52949 m .50379 .5313 L .50375 .53123 L F
.50379 .5313 m .50397 .53445 L .50375 .53123 L F
.50167 .53239 m .49809 .53616 L .50263 .53325 L .675 .735 .895 r
F
.5033 .53386 m .50095 .53315 L .50112 .53423 L F
.50417 .53462 m .50412 .53458 L .50403 .53169 L .929 .648 .488 r
F
.50389 .53392 m .50062 .5375 L .5036 .53834 L .675 .735 .895 r
F
.50431 .53506 m .5017 .53524 L .50267 .53611 L F
.50716 .53034 m .50389 .53392 L .50538 .53434 L F
.50488 .53233 m .50562 .53267 L .50562 .53548 L .845 .571 .524 r
F
.50534 .53952 m .50535 .53953 L .50603 .5389 L .654 .726 .902 r
F
.50389 .53392 m .5036 .53834 L .50538 .53434 L .675 .735 .895 r
F
.50527 .53532 m .50267 .53611 L .50394 .53678 L F
.5049 .53864 m .49804 .54561 L .50601 .53888 L .654 .726 .902 r
F
.50568 .53859 m .50601 .53888 L .50642 .53853 L F
.5049 .53864 m .50601 .53888 L .50568 .53859 L F
.50441 .53211 m .50418 .53201 L .50428 .53219 L .675 .735 .895 r
F
.50412 .53015 m .50463 .53061 L .50463 .53765 L .929 .648 .488 r
F
.50186 .54525 m .50665 .54286 L .50671 .5457 L .731 .477 .545 r
F
.50365 .54123 m .50186 .54525 L .50671 .5457 L .675 .735 .895 r
F
.50568 .54013 m .50223 .5475 L .50741 .54323 L .654 .726 .902 r
F
.50223 .5475 m .49879 .55483 L .50405 .54775 L F
.50292 .54759 m .50186 .54525 L .50671 .5457 L .731 .477 .545 r
F
.50223 .5475 m .50405 .54775 L .50741 .54323 L .654 .726 .902 r
F
.50192 .54809 m .5019 .54746 L .50292 .54759 L .731 .477 .545 r
F
.5019 .54746 m .50186 .54525 L .50292 .54759 L F
.50538 .53434 m .5036 .53834 L .50682 .53865 L .675 .735 .895 r
F
.50394 .53678 m .50365 .54123 L .50544 .53721 L F
.504 .53963 m .50371 .54407 L .5055 .54005 L F
.5042 .53726 m .50463 .53765 L .50463 .5447 L .929 .648 .488 r
F
.50702 .54958 m .49836 .56211 L .50645 .56322 L .654 .726 .902 r
F
.50713 .54692 m .50632 .54832 L .50702 .54958 L F
.50632 .54832 m .49836 .56211 L .50702 .54958 L F
.49804 .54561 m .48495 .54888 L .49131 .55243 L F
.50062 .5375 m .49735 .54107 L .50182 .54234 L .675 .735 .895 r
F
.49736 .54397 m .4973 .54113 L .50179 .5424 L .794 .529 .537 r
F
.50065 .54038 m .49736 .54397 L .50186 .54525 L .675 .735 .895 r
F
.50544 .5381 m .50084 .54052 L .49804 .54561 L .654 .726 .902 r
F
.494 .54412 m .48495 .54888 L .4971 .54584 L F
.49361 .54481 m .49478 .54455 L .49743 .54682 L .861 .586 .52 r
F
.49478 .54455 m .49736 .54397 L .49741 .54601 L F
.49478 .54455 m .49741 .54601 L .49743 .54682 L F
.4981 .53904 m .49736 .54397 L .50065 .54038 L .675 .735 .895 r
F
.50084 .54052 m .494 .54412 L .49804 .54561 L .654 .726 .902 r
F
.494 .54412 m .4971 .54584 L .49804 .54561 L F
.50356 .52873 m .50358 .53354 L .50356 .53321 L .783 .625 .063 r
F
.50263 .53325 m .50062 .5375 L .50389 .53392 L .675 .735 .895 r
F
.50395 .53441 m .50112 .53423 L .5017 .53524 L F
.50488 .53233 m .50562 .53548 L .50493 .53516 L .845 .571 .524 r
F
.50723 .53319 m .50362 .53381 L .50395 .53441 L .675 .735 .895 r
F
.50362 .53381 m .50112 .53423 L .50395 .53441 L F
.50447 .53495 m .50267 .53611 L .50527 .53532 L F
.50373 .53662 m .50366 .53649 L .50363 .53384 L .989 .72 .386 r
F
.50368 .53392 m .50363 .53384 L .5036 .52934 L F
.50397 .53445 m .5017 .53524 L .50431 .53506 L .675 .735 .895 r
F
.50373 .53662 m .50363 .53384 L .50368 .53392 L .989 .72 .386 r
F
.50358 .53354 m .5036 .53638 L .50356 .53321 L .783 .625 .063 r
F
.50397 .5171 m .50412 .53015 L .50397 .53002 L .929 .648 .488 r
F
.5036 .5164 m .50397 .53002 L .50368 .52949 L .989 .72 .386 r
F
.50397 .5171 m .50463 .53061 L .50412 .53015 L .929 .648 .488 r
F
.50562 .51817 m .50719 .5314 L .50596 .53116 L .751 .491 .539 r
F
.50815 .52851 m .49105 .53055 L .4807 .53713 L .654 .726 .902 r
F
.49105 .53055 m .47778 .53213 L .47872 .53374 L F
.49105 .53055 m .47872 .53374 L .4807 .53713 L F
.5063 .51343 m .5052 .51377 L .5052 .52689 L .568 .343 .534 r
F
.50371 .54407 m .50192 .54809 L .50677 .54855 L .675 .735 .895 r
F
.50665 .5465 m .50411 .55128 L .50713 .54692 L .654 .726 .902 r
F
.50411 .55128 m .49836 .56211 L .50416 .55206 L F
.50411 .55128 m .50416 .55206 L .50713 .54692 L F
.50062 .5375 m .50182 .54234 L .5036 .53834 L .675 .735 .895 r
F
.50394 .53678 m .50065 .54038 L .50365 .54123 L F
.50413 .53785 m .49361 .5439 L .50544 .5381 L .654 .726 .902 r
F
.49361 .5439 m .48495 .54888 L .494 .54412 L F
.49361 .5439 m .494 .54412 L .50544 .5381 L F
.49478 .54455 m .49354 .54196 L .49736 .54397 L .861 .586 .52 r
F
.49361 .54481 m .49359 .54389 L .49478 .54455 L F
.49359 .54389 m .49354 .54196 L .49478 .54455 L F
.50562 .53548 m .50586 .53818 L .50562 .53814 L .751 .491 .539 r
F
.50562 .5311 m .50577 .53551 L .50562 .53548 L F
.50617 .53557 m .50394 .53678 L .50544 .53721 L .675 .735 .895 r
F
.50577 .53551 m .50586 .53818 L .50562 .53548 L .751 .491 .539 r
F
.50596 .53116 m .50719 .53844 L .50615 .53824 L F
.50723 .53319 m .50519 .53542 L .50617 .53557 L .675 .735 .895 r
F
.50519 .53542 m .50394 .53678 L .50617 .53557 L F
.50772 .53579 m .50413 .53785 L .50544 .5381 L .654 .726 .902 r
F
.50497 .53782 m .50562 .53814 L .50562 .5383 L .845 .571 .524 r
F
.50371 .54407 m .50677 .54855 L .50695 .54438 L .675 .735 .895 r
F
.50624 .5453 m .50617 .54545 L .50719 .54549 L .654 .726 .902 r
F
.50602 .53889 m .50534 .53952 L .50603 .5389 L F
.50596 .53901 m .504 .53963 L .5055 .54005 L .675 .735 .895 r
F
.5049 .53864 m .50642 .53853 L .50638 .53851 L .654 .726 .902 r
F
.50734 .5357 m .50743 .53842 L .50719 .53572 L .641 .402 .54 r
F
.5069 .53674 m .50719 .53572 L .50719 .53844 L .751 .491 .539 r
F
.50772 .53579 m .5049 .53864 L .50644 .53851 L .654 .726 .902 r
F
.50729 .53603 m .50519 .53833 L .50596 .53901 L .675 .735 .895 r
F
.50519 .53833 m .504 .53963 L .50596 .53901 L F
.50463 .53503 m .50479 .53773 L .50463 .53765 L .845 .571 .524 r
F
.50493 .53516 m .50562 .53814 L .50497 .53782 L F
.50485 .53072 m .50497 .53782 L .50463 .53061 L F
.50597 .54589 m .50403 .55002 L .50665 .5465 L .654 .726 .902 r
F
.50403 .55002 m .49836 .56211 L .50411 .55128 L F
.50403 .55002 m .50411 .55128 L .50665 .5465 L F
.50534 .53952 m .49733 .54689 L .50535 .53953 L F
.504 .53963 m .50071 .54322 L .50371 .54407 L .675 .735 .895 r
F
.50355 .5356 m .50356 .54279 L .50355 .54265 L .783 .625 .063 r
F
.50267 .53611 m .50065 .54038 L .50394 .53678 L .675 .735 .895 r
F
.50267 .53611 m .4981 .53904 L .50065 .54038 L F
.50353 .5371 m .49692 .53918 L .50455 .53761 L .654 .726 .902 r
F
.49167 .54212 m .49066 .53935 L .49354 .54196 L .933 .65 .482 r
F
.49354 .54196 m .4973 .54113 L .49736 .54397 L .861 .586 .52 r
F
.49354 .54196 m .49348 .53912 L .4973 .54113 L F
.4981 .53904 m .49354 .54196 L .49736 .54397 L .675 .735 .895 r
F
.49361 .5439 m .48013 .54445 L .48495 .54888 L .654 .726 .902 r
F
.49167 .54212 m .49354 .54196 L .49359 .54389 L .933 .65 .482 r
F
.50455 .53761 m .49092 .54143 L .49361 .5439 L .654 .726 .902 r
F
.49092 .54143 m .48013 .54445 L .49361 .5439 L F
.49072 .5422 m .49167 .54212 L .49361 .54481 L .933 .65 .482 r
F
.49167 .54212 m .49359 .54389 L .49361 .54481 L F
.49072 .5422 m .4907 .54122 L .49167 .54212 L F
.4907 .54122 m .49066 .53935 L .49167 .54212 L F
.49066 .53935 m .49348 .53912 L .49354 .54196 L F
.49618 .5373 m .49066 .53935 L .49354 .54196 L .675 .735 .895 r
F
.49692 .53918 m .49062 .54116 L .49532 .5402 L .654 .726 .902 r
F
.49062 .54116 m .48013 .54445 L .49092 .54143 L F
.49062 .54116 m .49092 .54143 L .49532 .5402 L F
.49809 .53616 m .49735 .54107 L .50062 .5375 L .675 .735 .895 r
F
.49692 .53918 m .49532 .5402 L .50455 .53761 L .654 .726 .902 r
F
.50414 .53178 m .50417 .53462 L .50403 .53169 L .929 .648 .488 r
F
.49105 .53055 m .47693 .52688 L .47778 .53213 L .654 .726 .902 r
F
.50815 .52851 m .50046 .52811 L .49105 .53055 L F
.50046 .52811 m .47693 .52688 L .49105 .53055 L F
.5076 .53852 m .50568 .54013 L .50741 .54323 L F
.5055 .54005 m .50371 .54407 L .50695 .54438 L .675 .735 .895 r
F
.50634 .54532 m .5061 .54528 L .50586 .53818 L .751 .491 .539 r
F
.50598 .53821 m .50586 .53818 L .50562 .5311 L F
.5055 .54005 m .50695 .54438 L .50712 .5402 L .675 .735 .895 r
F
.50634 .54532 m .50586 .53818 L .50598 .53821 L .751 .491 .539 r
F
.49809 .53616 m .49355 .53907 L .49735 .54107 L .675 .735 .895 r
F
.49066 .53935 m .49059 .53651 L .49348 .53912 L .933 .65 .482 r
F
.49618 .5373 m .49354 .54196 L .4981 .53904 L .675 .735 .895 r
F
.48911 .53851 m .4772 .53942 L .49065 .54115 L .654 .726 .902 r
F
.48896 .53917 m .48953 .53923 L .49072 .5422 L .987 .712 .383 r
F
.48953 .53923 m .49066 .53935 L .4907 .54122 L F
.48953 .53923 m .4907 .54122 L .49072 .5422 L F
.49065 .54115 m .4772 .53942 L .48013 .54445 L .654 .726 .902 r
F
.50229 .53749 m .48911 .53851 L .49065 .54115 L F
.5042 .53726 m .50408 .53715 L .50404 .53451 L .929 .648 .488 r
F
.50493 .53516 m .50562 .53548 L .50562 .53814 L .845 .571 .524 r
F
.50403 .55002 m .4976 .55344 L .49836 .56211 L .654 .726 .902 r
F
.50617 .54545 m .50387 .5476 L .50403 .55002 L F
.50387 .5476 m .4976 .55344 L .50403 .55002 L F
.50772 .53579 m .50353 .5371 L .50455 .53761 L F
.5042 .53726 m .5042 .53746 L .50408 .53715 L .929 .648 .488 r
F
.5042 .53746 m .50408 .53736 L .50408 .53715 L F
.50434 .53792 m .50176 .53809 L .50273 .53896 L .675 .735 .895 r
F
.50729 .53603 m .50397 .53727 L .50434 .53792 L F
.50397 .53727 m .50176 .53809 L .50434 .53792 L F
.50772 .53579 m .50101 .53659 L .50229 .53749 L .654 .726 .902 r
F
.50373 .53662 m .50397 .53706 L .50397 .53727 L .989 .72 .386 r
F
.50371 .53833 m .50378 .53951 L .504 .53963 L .675 .735 .895 r
F
.50373 .53683 m .50397 .53727 L .50397 .54411 L .989 .72 .386 r
F
.50373 .53662 m .50397 .53727 L .50373 .53683 L F
.50355 .53572 m .50356 .54289 L .50355 .5356 L .783 .625 .063 r
F
.50356 .53587 m .50357 .54301 L .50355 .53572 L F
.50371 .53833 m .50273 .53896 L .50378 .53951 L .675 .735 .895 r
F
.50373 .53662 m .50377 .54374 L .50366 .53649 L .989 .72 .386 r
F
.49733 .54689 m .49383 .55324 L .49879 .55483 L .654 .726 .902 r
F
.49829 .55219 m .48452 .55616 L .49088 .5597 L F
.5048 .54559 m .50077 .54769 L .49829 .55219 L F
.50077 .54769 m .48452 .55616 L .49829 .55219 L F
.5047 .54541 m .50091 .54743 L .5048 .54559 L F
.50091 .54743 m .48452 .55616 L .50077 .54769 L F
.50071 .54322 m .50192 .54809 L .50371 .54407 L .675 .735 .895 r
F
.50091 .54743 m .50077 .54769 L .5048 .54559 L .654 .726 .902 r
F
.50534 .53817 m .50371 .53833 L .504 .53963 L .675 .735 .895 r
F
.50408 .53715 m .50418 .54429 L .50397 .53706 L .929 .648 .488 r
F
.49733 .54689 m .49131 .55243 L .49383 .55324 L .654 .726 .902 r
F
.50411 .54489 m .48452 .55616 L .5047 .54541 L F
.50446 .54498 m .5047 .54541 L .50516 .54517 L F
.50411 .54489 m .5047 .54541 L .50446 .54498 L F
.49804 .54561 m .49131 .55243 L .49733 .54689 L F
.49804 .54561 m .49775 .54612 L .50642 .53853 L F
.49775 .54612 m .49733 .54689 L .49806 .54622 L F
.49775 .54612 m .49806 .54622 L .50642 .53853 L F
.49861 .5464 m .49736 .54397 L .50186 .54525 L .794 .529 .537 r
F
.49743 .54682 m .49741 .54601 L .49861 .5464 L F
.49741 .54601 m .49736 .54397 L .49861 .5464 L F
.50071 .54322 m .49743 .54682 L .50192 .54809 L .675 .735 .895 r
F
.50456 .54463 m .49662 .54641 L .48452 .55616 L .654 .726 .902 r
F
.50397 .54411 m .50464 .5763 L .50398 .57571 L .929 .648 .488 r
F
.50397 .53706 m .50409 .54421 L .50397 .54411 L F
.50409 .54421 m .50464 .5763 L .50397 .54411 L F
.50497 .538 m .50562 .54518 L .50509 .54492 L .845 .571 .524 r
F
.50729 .54306 m .50397 .5441 L .50456 .54463 L .654 .726 .902 r
F
.50397 .5441 m .49662 .54641 L .50456 .54463 L F
.49662 .54641 m .4797 .55172 L .48319 .55493 L F
.49662 .54641 m .48319 .55493 L .48452 .55616 L F
.50506 .54507 m .50516 .54517 L .50527 .54511 L F
.50534 .54504 m .5038 .5466 L .50617 .54545 L F
.50411 .54489 m .50516 .54517 L .50506 .54507 L F
.49829 .55219 m .4976 .55344 L .50617 .54545 L F
.50463 .5447 m .50562 .57677 L .50464 .5763 L .845 .571 .524 r
F
.50463 .53765 m .50481 .54478 L .50463 .5447 L F
.50481 .54478 m .50562 .57677 L .50463 .5447 L F
.50365 .54421 m .47677 .5467 L .4797 .55172 L .654 .726 .902 r
F
.5042 .53726 m .50463 .5447 L .50428 .54438 L .929 .648 .488 r
F
.50729 .54306 m .50249 .54364 L .50365 .54421 L .654 .726 .902 r
F
.49817 .54188 m .49361 .54481 L .49743 .54682 L .675 .735 .895 r
F
.50249 .54364 m .47677 .5467 L .50365 .54421 L .654 .726 .902 r
F
.50527 .54511 m .5047 .54541 L .5048 .54559 L F
.50479 .53773 m .50494 .54485 L .50463 .53765 L .845 .571 .524 r
F
.50494 .54485 m .50562 .57677 L .50481 .54478 L F
.50494 .54485 m .50481 .54478 L .50463 .53765 L F
.49817 .54188 m .49743 .54682 L .50071 .54322 L .675 .735 .895 r
F
.50249 .54364 m .47591 .54142 L .47677 .5467 L .654 .726 .902 r
F
.50723 .53319 m .50395 .53441 L .50418 .53482 L .675 .735 .895 r
F
.49617 .53443 m .49355 .53907 L .49809 .53616 L F
.49617 .53443 m .49068 .53648 L .49355 .53907 L F
.4889 .53632 m .49059 .53651 L .49066 .53935 L .987 .712 .383 r
F
.49501 .53528 m .49066 .53935 L .49618 .5373 L .675 .735 .895 r
F
.49501 .53528 m .4889 .53632 L .49066 .53935 L F
.48852 .5356 m .47634 .53415 L .48891 .53803 L .654 .726 .902 r
F
.48845 .53593 m .48859 .53605 L .48896 .53917 L .855 .657 .12 r
F
.48859 .53605 m .4889 .53632 L .48894 .53821 L F
.48859 .53605 m .48894 .53821 L .48896 .53917 L F
.48891 .53803 m .47634 .53415 L .4772 .53942 L .654 .726 .902 r
F
.4989 .53684 m .48852 .5356 L .48891 .53803 L F
.50615 .53824 m .50598 .53821 L .50562 .5311 L .751 .491 .539 r
F
.50602 .53889 m .50603 .5389 L .50643 .53854 L .654 .726 .902 r
F
.50615 .53824 m .50634 .54532 L .50598 .53821 L .751 .491 .539 r
F
.50729 .54306 m .50534 .54504 L .50562 .54518 L .654 .726 .902 r
F
.50624 .5453 m .50562 .54518 L .50617 .54545 L F
.50562 .54518 m .50719 .57704 L .50562 .57677 L .751 .491 .539 r
F
.50591 .54524 m .50719 .57704 L .50562 .54518 L F
.50643 .53854 m .50603 .5389 L .50619 .53904 L .654 .726 .902 r
F
.49501 .53242 m .49068 .53648 L .49617 .53443 L .675 .735 .895 r
F
.49501 .53242 m .48893 .53346 L .49068 .53648 L F
.48839 .53308 m .48884 .53348 L .4889 .53632 L .855 .657 .12 r
F
.48839 .53308 m .48832 .53024 L .48884 .53348 L F
.49467 .53312 m .4889 .53632 L .49501 .53528 L .675 .735 .895 r
F
.4889 .53632 m .48884 .53348 L .49059 .53651 L .987 .712 .383 r
F
.49467 .53312 m .48839 .53308 L .4889 .53632 L .675 .735 .895 r
F
.49965 .53537 m .48911 .53231 L .48849 .53478 L .654 .726 .902 r
F
.48922 .53269 m .48899 .5328 L .48845 .53593 L 0 0 .254 r
F
.48899 .5328 m .48839 .53308 L .48843 .53504 L F
.48859 .53605 m .48839 .53308 L .4889 .53632 L .855 .657 .12 r
F
.48845 .53593 m .48843 .53504 L .48859 .53605 L F
.48843 .53504 m .48839 .53308 L .48859 .53605 L F
.4882 .53477 m .47634 .53415 L .48852 .5356 L .654 .726 .902 r
F
.48839 .5348 m .48852 .5356 L .4989 .53684 L F
.4882 .53477 m .48852 .5356 L .48839 .5348 L F
.48899 .5328 m .48843 .53504 L .48845 .53593 L 0 0 .254 r
F
.48849 .53478 m .47762 .52898 L .47634 .53415 L .654 .726 .902 r
F
.48911 .53231 m .47762 .52898 L .48849 .53478 L F
.50497 .53782 m .50479 .53773 L .50463 .53061 L .845 .571 .524 r
F
.50447 .53495 m .50418 .53482 L .50431 .53506 L .675 .735 .895 r
F
.50412 .53015 m .50463 .53765 L .5042 .53726 L .929 .648 .488 r
F
.5042 .53726 m .50404 .53451 L .50412 .53458 L F
.50387 .53426 m .50397 .53706 L .50371 .53397 L .989 .72 .386 r
F
.50356 .53321 m .5036 .53638 L .50356 .53587 L .783 .625 .063 r
F
.50417 .53462 m .5042 .53726 L .50412 .53458 L .929 .648 .488 r
F
.50395 .53441 m .50393 .53441 L .50397 .53445 L .675 .735 .895 r
F
.50387 .53426 m .50397 .53445 L .50397 .53706 L .989 .72 .386 r
F
.50409 .52913 m .50287 .52738 L .50184 .52824 L .675 .735 .895 r
F
.50716 .53034 m .50474 .52867 L .50409 .52913 L F
.50358 .52997 m .5036 .52987 L .5036 .53096 L .783 .625 .063 r
F
.50356 .52873 m .5036 .52987 L .50358 .52997 L F
.50356 .52873 m .5036 .52934 L .5036 .52987 L F
.50396 .52781 m .50355 .52856 L .50355 .53016 L 0 0 .377 r
F
.50357 .53048 m .5036 .53096 L .5036 .53377 L .783 .625 .063 r
F
.50393 .53441 m .5017 .53524 L .50397 .53445 L .675 .735 .895 r
F
.50358 .53354 m .5036 .53377 L .5036 .53638 L .783 .625 .063 r
F
.50357 .53048 m .5036 .53377 L .50358 .53354 L F
.50356 .53317 m .50121 .53207 L .50095 .53315 L .675 .735 .895 r
F
.50392 .53225 m .50355 .5356 L .5039 .53497 L 0 0 .377 r
F
.50368 .52949 m .50397 .53002 L .50397 .53164 L .989 .72 .386 r
F
.50379 .5313 m .50397 .53164 L .50397 .53445 L F
.50368 .52949 m .50397 .53164 L .50379 .5313 L F
.50716 .53034 m .5036 .53095 L .5036 .53096 L .675 .735 .895 r
F
.50392 .53155 m .5036 .53096 L .50364 .53165 L F
.50414 .53178 m .50403 .53169 L .50397 .53002 L .929 .648 .488 r
F
.50716 .53034 m .5036 .53096 L .50392 .53155 L .675 .735 .895 r
F
.50396 .52781 m .5037 .53267 L .50392 .53225 L 0 0 .377 r
F
.50368 .52949 m .50387 .53426 L .50371 .53397 L .989 .72 .386 r
F
.50463 .53061 m .50473 .53507 L .50463 .53503 L .845 .571 .524 r
F
.50723 .53319 m .50356 .53317 L .5036 .53381 L .675 .735 .895 r
F
.5037 .53267 m .50355 .5356 L .50392 .53225 L 0 0 .377 r
F
.50412 .53458 m .50404 .53451 L .50397 .53002 L .929 .648 .488 r
F
.50369 .53113 m .50373 .53662 L .50363 .53101 L .989 .72 .386 r
F
.50723 .53319 m .50377 .53255 L .50356 .53317 L .675 .735 .895 r
F
.5036 .52934 m .50366 .53649 L .5036 .53638 L .989 .72 .386 r
F
.50377 .53255 m .50355 .53297 L .50356 .53317 L .675 .735 .895 r
F
.50356 .53317 m .5025 .53316 L .5036 .53381 L F
.50355 .52856 m .50355 .53572 L .50355 .5356 L .783 .625 .063 r
F
.5036 .53095 m .50109 .53138 L .50364 .53165 L .675 .735 .895 r
F
.50356 .53032 m .50117 .52923 L .50092 .53031 L F
.50356 .53036 m .50355 .53024 L .50355 .52856 L .783 .625 .063 r
F
.50408 .51456 m .50355 .52856 L .50396 .52781 L 0 0 .377 r
F
.48728 .52742 m .47821 .52174 L .47693 .52688 L .654 .726 .902 r
F
.50815 .52851 m .50075 .52684 L .48728 .52742 L F
.50075 .52684 m .47821 .52174 L .48728 .52742 L F
.50739 .51335 m .5063 .51343 L .5063 .5266 L .66 .417 .541 r
F
.50473 .53507 m .50479 .53773 L .50463 .53503 L .845 .571 .524 r
F
.50371 .53397 m .50397 .53706 L .50373 .53662 L .989 .72 .386 r
F
.50263 .53325 m .49809 .53616 L .50062 .5375 L .675 .735 .895 r
F
.5017 .53524 m .4981 .53904 L .50267 .53611 L F
.50112 .53423 m .49618 .5373 L .5017 .53524 L F
.50772 .53579 m .49965 .53537 L .4989 .53684 L .654 .726 .902 r
F
.50356 .53587 m .5036 .53638 L .5036 .53658 L .783 .625 .063 r
F
.5036 .53666 m .50101 .536 L .50118 .53708 L .675 .735 .895 r
F
.50356 .53587 m .5036 .53658 L .50356 .53607 L .783 .625 .063 r
F
.50729 .53603 m .50356 .53601 L .5036 .53666 L .675 .735 .895 r
F
.50356 .53601 m .50101 .536 L .5036 .53666 L F
.50075 .52684 m .48152 .51706 L .47821 .52174 L .654 .726 .902 r
F
.5052 .51377 m .50408 .5276 L .50495 .52705 L .401 .213 .507 r
F
.50815 .52851 m .50394 .5267 L .50075 .52684 L .654 .726 .902 r
F
.50394 .5267 m .48152 .51706 L .50075 .52684 L F
.50719 .54549 m .50665 .5465 L .50713 .54692 L F
.50719 .53572 m .50743 .53842 L .50719 .53844 L .641 .402 .54 r
F
.50617 .54545 m .50597 .54589 L .50699 .54586 L .654 .726 .902 r
F
.50597 .54589 m .50665 .5465 L .50699 .54586 L F
.50617 .54545 m .50699 .54586 L .50719 .54549 L F
.50638 .53851 m .50642 .53853 L .50644 .53851 L F
.50644 .53851 m .50642 .53853 L .50643 .53854 L F
.50653 .53831 m .50568 .54013 L .5076 .53852 L F
.50615 .53824 m .50719 .53844 L .50719 .53854 L .751 .491 .539 r
F
.50719 .53854 m .5055 .54005 L .50712 .5402 L .675 .735 .895 r
F
.50619 .53904 m .50544 .53971 L .50568 .54013 L .654 .726 .902 r
F
.50624 .53839 m .5055 .54005 L .50719 .53854 L .675 .735 .895 r
F
.50634 .54532 m .50719 .54549 L .50719 .57704 L .751 .491 .539 r
F
.50739 .54064 m .5063 .57205 L .5074 .57196 L .66 .417 .541 r
F
.50772 .53579 m .50653 .53831 L .5076 .53852 L .654 .726 .902 r
F
.50723 .53319 m .50733 .53072 L .50637 .53081 L .675 .735 .895 r
F
.50716 .53034 m .50378 .52971 L .50356 .53032 L F
.50492 .52855 m .50486 .5314 L .50512 .52841 L .401 .213 .507 r
F
.50369 .53113 m .50363 .53101 L .5036 .52934 L .989 .72 .386 r
F
.50716 .53034 m .50092 .53031 L .50109 .53138 L .675 .735 .895 r
F
.50486 .5314 m .50496 .53133 L .50512 .52841 L .401 .213 .507 r
F
.50716 .53034 m .50418 .53201 L .50441 .53211 L .675 .735 .895 r
F
.5052 .53116 m .50502 .53404 L .5052 .53393 L .401 .213 .507 r
F
.50716 .53034 m .50409 .52913 L .50336 .52964 L .675 .735 .895 r
F
.5052 .52689 m .50509 .53124 L .5052 .53116 L .401 .213 .507 r
F
.50356 .53036 m .50356 .53321 L .50355 .53024 L .783 .625 .063 r
F
.50356 .53321 m .50356 .53314 L .50355 .52856 L F
.50368 .52949 m .50369 .53113 L .5036 .52934 L .989 .72 .386 r
F
.50378 .52971 m .50355 .53016 L .50356 .53032 L .675 .735 .895 r
F
.50387 .52954 m .50355 .53016 L .50355 .53297 L 0 0 .377 r
F
.50356 .53321 m .50356 .53587 L .50356 .53314 L .783 .625 .063 r
F
.50356 .53587 m .50355 .53572 L .50355 .52856 L F
.5037 .53267 m .50355 .53297 L .50355 .5356 L 0 0 .377 r
F
.50387 .52954 m .50355 .53297 L .5037 .53267 L F
.50408 .53194 m .50339 .53054 L .50347 .5317 L .675 .735 .895 r
F
.50716 .53034 m .50392 .53155 L .50418 .53201 L F
.50481 .53417 m .50502 .53404 L .50509 .53124 L .401 .213 .507 r
F
.50496 .53133 m .50509 .53124 L .5052 .52689 L F
.50716 .53034 m .50447 .53207 L .50509 .53261 L .675 .735 .895 r
F
.50723 .53319 m .50475 .53148 L .50408 .53194 L F
.50481 .53417 m .50509 .53124 L .50496 .53133 L .401 .213 .507 r
F
.50476 .52865 m .50408 .52914 L .50408 .53464 L F
.50408 .53194 m .50443 .53126 L .50408 .53194 L .675 .735 .895 r
F
.50475 .53148 m .50443 .53126 L .50408 .53194 L F
.50392 .53225 m .50396 .53216 L .50404 .52921 L 0 0 .377 r
F
.50443 .53126 m .50339 .53054 L .50408 .53194 L .675 .735 .895 r
F
.50394 .52939 m .50392 .53225 L .50404 .52921 L 0 0 .377 r
F
.50392 .53225 m .5039 .53497 L .50396 .53216 L F
.50509 .53124 m .50502 .53404 L .5052 .53116 L .401 .213 .507 r
F
.50356 .52873 m .5036 .53096 L .50357 .53048 L .783 .625 .063 r
F
.50475 .53148 m .50424 .52955 L .50291 .53021 L .675 .735 .895 r
F
.50596 .53116 m .50615 .53824 L .50562 .5311 L .751 .491 .539 r
F
.50716 .53034 m .50632 .528 L .5063 .528 L .675 .735 .895 r
F
.50605 .52666 m .5052 .52835 L .50577 .52817 L .568 .343 .534 r
F
.50546 .52827 m .5063 .528 L .50531 .52809 L .675 .735 .895 r
F
.50716 .53034 m .5063 .528 L .50546 .52827 L F
.50408 .51456 m .50396 .52781 L .50408 .5276 L 0 0 .377 r
F
.50815 .52851 m .48665 .51316 L .48152 .51706 L .654 .726 .902 r
F
.50605 .52666 m .5052 .52689 L .5052 .52835 L .568 .343 .534 r
F
.50577 .52817 m .5052 .52835 L .5052 .53116 L F
.50723 .53319 m .50548 .53107 L .50475 .53148 L .675 .735 .895 r
F
.49624 .54014 m .49361 .54481 L .49817 .54188 L F
.50024 .54226 m .49831 .54103 L .49195 .54131 L .654 .726 .902 r
F
.50729 .53603 m .50118 .53708 L .50176 .53809 L .675 .735 .895 r
F
.50481 .53417 m .50468 .5413 L .50502 .53404 L .401 .213 .507 r
F
.50592 .53374 m .50579 .54082 L .50613 .53369 L .568 .343 .534 r
F
.5061 .54528 m .50591 .54524 L .50562 .53814 L .751 .491 .539 r
F
.5017 .53524 m .49618 .5373 L .4981 .53904 L .675 .735 .895 r
F
.4989 .53684 m .48884 .53804 L .50229 .53749 L .654 .726 .902 r
F
.48884 .53804 m .4772 .53942 L .48911 .53851 L F
.48953 .53923 m .4889 .53632 L .49066 .53935 L .987 .712 .383 r
F
.48884 .53804 m .48911 .53851 L .50229 .53749 L .654 .726 .902 r
F
.48896 .53917 m .48894 .53821 L .48953 .53923 L .987 .712 .383 r
F
.48894 .53821 m .4889 .53632 L .48953 .53923 L F
.49473 .53596 m .48845 .53593 L .48896 .53917 L .675 .735 .895 r
F
.49831 .54103 m .48053 .53155 L .47719 .53626 L .654 .726 .902 r
F
.50167 .53239 m .49617 .53443 L .49809 .53616 L .675 .735 .895 r
F
.50095 .53315 m .49501 .53528 L .50112 .53423 L F
.50109 .53138 m .49501 .53242 L .49617 .53443 L F
.50095 .53315 m .49467 .53312 L .49501 .53528 L F
.49467 .53027 m .48893 .53346 L .49501 .53242 L F
.49518 .53096 m .48839 .53308 L .49467 .53312 L F
.50109 .53138 m .49617 .53443 L .50167 .53239 L F
.50254 .53462 m .48929 .53162 L .49965 .53537 L .654 .726 .902 r
F
.49467 .53027 m .48842 .53024 L .48893 .53346 L .675 .735 .895 r
F
.49518 .53096 m .48916 .52984 L .48839 .53308 L F
.48899 .5328 m .48916 .52984 L .48839 .53308 L 0 0 .254 r
F
.48929 .53162 m .47762 .52898 L .48911 .53231 L .654 .726 .902 r
F
.48929 .53162 m .48911 .53231 L .49965 .53537 L F
.48922 .53269 m .4892 .53194 L .48899 .5328 L 0 0 .254 r
F
.4892 .53194 m .48916 .52984 L .48899 .5328 L F
.50112 .53423 m .49501 .53528 L .49618 .5373 L .675 .735 .895 r
F
.49965 .53537 m .4882 .53477 L .49608 .53629 L .654 .726 .902 r
F
.50176 .53809 m .49817 .54188 L .50273 .53896 L .675 .735 .895 r
F
.50118 .53708 m .49507 .53812 L .49624 .54014 L F
.48916 .52984 m .48832 .53024 L .48839 .53308 L 0 0 .254 r
F
.49965 .53537 m .49608 .53629 L .4989 .53684 L .654 .726 .902 r
F
.50101 .536 m .49473 .53596 L .49507 .53812 L .675 .735 .895 r
F
.50397 .53002 m .50408 .53715 L .50397 .53706 L .929 .648 .488 r
F
.48071 .52968 m .48096 .52428 L .47762 .52898 L .654 .726 .902 r
F
.50121 .53207 m .49467 .53312 L .50095 .53315 L .675 .735 .895 r
F
.50092 .53031 m .49501 .53242 L .50109 .53138 L F
.50121 .53207 m .49518 .53096 L .49467 .53312 L F
.50772 .53579 m .50015 .53253 L .48071 .52968 L .654 .726 .902 r
F
.49518 .52812 m .48842 .53024 L .49467 .53027 L .675 .735 .895 r
F
.49518 .52812 m .48919 .52702 L .48842 .53024 L F
.48916 .52984 m .4891 .527 L .48832 .53024 L 0 0 .254 r
F
.49652 .52895 m .48916 .52984 L .49518 .53096 L .675 .735 .895 r
F
.50015 .53253 m .49145 .52879 L .48986 .53102 L .654 .726 .902 r
F
.49123 .52968 m .49079 .52971 L .48922 .53269 L .117 .009 .443 r
F
.49079 .52971 m .48916 .52984 L .4892 .53194 L F
.49079 .52971 m .4892 .53194 L .48922 .53269 L F
.48986 .53102 m .48096 .52428 L .48071 .52968 L .654 .726 .902 r
F
.49652 .52895 m .49116 .52683 L .48916 .52984 L .675 .735 .895 r
F
.49123 .52968 m .49116 .52683 L .48916 .52984 L .117 .009 .443 r
F
.49145 .52879 m .48096 .52428 L .48986 .53102 L .654 .726 .902 r
F
.50718 .51843 m .50838 .53129 L .50754 .53137 L .641 .402 .54 r
F
.50716 .53034 m .50848 .52802 L .50821 .52799 L .675 .735 .895 r
F
.50754 .53137 m .50797 .5328 L .50758 .53286 L .641 .402 .54 r
F
.50716 .53034 m .50706 .53293 L .50805 .53279 L .675 .735 .895 r
F
.50815 .52851 m .50678 .53144 L .50803 .53132 L .654 .726 .902 r
F
.51036 .52775 m .50955 .52711 L .50955 .52837 L .909 .63 .5 r
F
.5092 .52811 m .5117 .52743 L .51044 .52676 L .675 .735 .895 r
F
.50716 .53034 m .50986 .52861 L .5092 .52811 L F
.51036 .52775 m .50955 .52837 L .51011 .5288 L .909 .63 .5 r
F
.50986 .52861 m .5117 .52743 L .5092 .52811 L .675 .735 .895 r
F
.50815 .52851 m .51529 .53159 L .51338 .5301 L .654 .726 .902 r
F
.51096 .52955 m .51105 .52895 L .51105 .5302 L 0 0 .142 r
F
.51056 .52908 m .51324 .5293 L .51266 .5283 L .675 .735 .895 r
F
.50716 .53034 m .51084 .52971 L .51056 .52908 L F
.51095 .52872 m .51094 .52995 L .51105 .52895 L .984 .727 .339 r
F
.51094 .52995 m .51102 .53014 L .51105 .52895 L F
.51084 .52971 m .51324 .5293 L .51056 .52908 L .675 .735 .895 r
F
.51096 .5308 m .51094 .53095 L .51093 .52972 L 0 0 .142 r
F
.51096 .52955 m .51105 .5302 L .51096 .5308 L F
.51096 .5308 m .51101 .53332 L .51097 .53358 L F
.51092 .53271 m .51096 .53281 L .51102 .53014 L .984 .727 .339 r
F
.51058 .53194 m .51334 .53214 L .51275 .53113 L .675 .735 .895 r
F
.51064 .52802 m .5106 .52793 L .5106 .52917 L .984 .727 .339 r
F
.50986 .52861 m .51266 .5283 L .5117 .52743 L .675 .735 .895 r
F
.50716 .53034 m .51051 .5291 L .50986 .52861 L F
.51034 .52898 m .51051 .5291 L .5106 .52793 L .909 .63 .5 r
F
.51064 .52802 m .5106 .52917 L .51095 .52872 L .984 .727 .339 r
F
.51051 .5291 m .51266 .5283 L .50986 .52861 L .675 .735 .895 r
F
.51036 .52775 m .51034 .52898 L .5106 .52793 L .909 .63 .5 r
F
.51123 .52965 m .51341 .53038 L .51324 .5293 L .675 .735 .895 r
F
.5106 .53021 m .51093 .52972 L .51093 .531 L .076 0 .415 r
F
.50716 .53034 m .51218 .53037 L .51123 .52965 L .675 .735 .895 r
F
.51218 .53037 m .51341 .53038 L .51123 .52965 L F
.5106 .53021 m .51061 .53151 L .5105 .53036 L .076 0 .415 r
F
.5106 .53021 m .51093 .531 L .5107 .53136 L F
.50716 .53034 m .51316 .53145 L .51341 .53038 L .675 .735 .895 r
F
.51029 .52894 m .50955 .53119 L .51013 .53163 L .909 .63 .5 r
F
.51036 .52775 m .51011 .5288 L .51029 .52894 L F
.51011 .5288 m .50955 .53119 L .51029 .52894 L F
.51034 .52898 m .51029 .53175 L .51051 .5291 L F
.5106 .5348 m .5134 .53499 L .51282 .53398 L .675 .735 .895 r
F
.51065 .53707 m .51054 .53443 L .51059 .53435 L .076 0 .415 r
F
.51098 .53635 m .51105 .53599 L .51098 .53649 L 0 0 .142 r
F
.51097 .53358 m .51105 .53586 L .51098 .53635 L F
.51105 .53586 m .51105 .53599 L .51098 .53635 L F
.50729 .53603 m .51112 .53538 L .5106 .5348 L .675 .735 .895 r
F
.51112 .53538 m .51132 .53534 L .51114 .53521 L F
.51105 .53582 m .5109 .53564 L .51105 .53599 L .984 .727 .339 r
F
.51101 .53332 m .51105 .53599 L .51097 .53358 L 0 0 .142 r
F
.51097 .53358 m .51098 .53649 L .51096 .53365 L F
.51077 .53212 m .51146 .5333 L .51082 .53179 L .675 .735 .895 r
F
.51096 .5308 m .51105 .5302 L .51105 .53301 L 0 0 .142 r
F
.51101 .53332 m .51105 .53301 L .51105 .53599 L F
.51096 .5308 m .51105 .53301 L .51101 .53332 L F
.5107 .53136 m .51093 .531 L .51093 .53381 L .076 0 .415 r
F
.51094 .52995 m .51078 .53238 L .51092 .53271 L .984 .727 .339 r
F
.51086 .53257 m .51112 .53252 L .51058 .53194 L .675 .735 .895 r
F
.51112 .53252 m .51334 .53214 L .5112 .53198 L F
.51112 .53252 m .5112 .53198 L .51058 .53194 L F
.51098 .53649 m .51095 .53664 L .51093 .52972 L 0 0 .142 r
F
.51093 .52972 m .51095 .53664 L .51094 .53676 L F
.51105 .52895 m .5109 .53548 L .51105 .53582 L .984 .727 .339 r
F
.5109 .53548 m .5109 .53564 L .51105 .53582 L F
.51112 .53538 m .51114 .53521 L .51061 .5348 L .675 .735 .895 r
F
.51132 .53534 m .5134 .53499 L .5106 .5348 L F
.51029 .53175 m .51024 .53452 L .51046 .53188 L .909 .63 .5 r
F
.51049 .53731 m .5105 .5374 L .51004 .53768 L .358 .18 .498 r
F
.50772 .53579 m .51033 .53765 L .51072 .53708 L .654 .726 .902 r
F
.51024 .53452 m .51011 .54164 L .51036 .53462 L .909 .63 .5 r
F
.51024 .53452 m .51036 .53462 L .51046 .53188 L F
.51029 .53175 m .51046 .53188 L .5106 .52793 L F
.50723 .53319 m .51086 .53257 L .5106 .53199 L .675 .735 .895 r
F
.50772 .53579 m .51216 .53618 L .51193 .53601 L .654 .726 .902 r
F
.51039 .53769 m .51056 .53926 L .51075 .53796 L F
.51028 .53966 m .51593 .54198 L .51161 .53901 L .675 .735 .895 r
F
.51061 .53498 m .51028 .54176 L .51061 .54202 L .909 .63 .5 r
F
.51045 .53453 m .5105 .53449 L .51051 .53448 L .675 .735 .895 r
F
.51059 .53435 m .51054 .53443 L .5105 .53036 L .076 0 .415 r
F
.51061 .53151 m .51053 .53163 L .5105 .53036 L F
.51094 .52995 m .51092 .53271 L .51102 .53014 L .984 .727 .339 r
F
.51094 .52995 m .5106 .52917 L .5106 .53199 L F
.51078 .53238 m .5106 .53199 L .51061 .5348 L F
.51051 .53191 m .51044 .53485 L .5106 .53199 L .909 .63 .5 r
F
.51078 .53238 m .51061 .53498 L .51092 .53271 L .984 .727 .339 r
F
.5099 .53318 m .51185 .53311 L .51058 .53244 L .675 .735 .895 r
F
.50797 .5328 m .50877 .5355 L .50758 .53286 L .641 .402 .54 r
F
.50723 .53319 m .50989 .53502 L .51051 .53448 L .675 .735 .895 r
F
.50729 .53603 m .5103 .5341 L .5099 .53318 L F
.5106 .53199 m .51044 .53485 L .51061 .53498 L .909 .63 .5 r
F
.51114 .53321 m .51121 .53338 L .51132 .53321 L .675 .735 .895 r
F
.5103 .5341 m .51185 .53311 L .5099 .53318 L F
.51062 .53482 m .51061 .5348 L .51061 .53498 L .984 .727 .339 r
F
.51078 .53238 m .51061 .5348 L .51062 .53482 L F
.51094 .52995 m .5106 .53199 L .51078 .53238 L F
.51028 .53123 m .51275 .53113 L .51179 .53026 L .675 .735 .895 r
F
.51004 .53774 m .51012 .54472 L .5099 .53784 L .358 .18 .498 r
F
.51024 .53469 m .50955 .5412 L .51011 .54164 L .909 .63 .5 r
F
.51036 .52775 m .50996 .53447 L .51024 .53469 L F
.50996 .53447 m .50955 .5412 L .51024 .53469 L F
.51316 .53145 m .51915 .53256 L .51966 .53041 L .675 .735 .895 r
F
.51249 .53245 m .51915 .53256 L .51316 .53145 L F
.51966 .53041 m .52591 .53045 L .52541 .52722 L F
.51966 .53041 m .52541 .52722 L .51933 .52826 L F
.51351 .53322 m .51945 .5311 L .51334 .53214 L F
.51316 .53145 m .51966 .53041 L .51341 .53038 L F
.51341 .53038 m .51966 .53041 L .51933 .52826 L F
.51334 .53214 m .51945 .5311 L .51828 .52907 L F
.51933 .52826 m .52541 .52722 L .52366 .5242 L F
.52556 .53005 m .5255 .5272 L .52374 .52417 L .987 .711 .381 r
F
.51945 .5311 m .5238 .52702 L .51828 .52907 L .675 .735 .895 r
F
.51945 .5311 m .52556 .53005 L .5238 .52702 L F
.52556 .53005 m .52374 .52417 L .5238 .52702 L .987 .711 .381 r
F
.52562 .53289 m .52556 .53005 L .5238 .52702 L F
.51282 .53398 m .51642 .53018 L .51185 .53311 L .675 .735 .895 r
F
.51282 .53398 m .51834 .53192 L .51642 .53018 L F
.52562 .53289 m .5238 .52702 L .52387 .52986 L .987 .711 .381 r
F
.51834 .53192 m .52098 .52725 L .51642 .53018 L .675 .735 .895 r
F
.51834 .53192 m .52387 .52986 L .52098 .52725 L F
.51933 .52826 m .52366 .5242 L .51816 .52625 L F
.51828 .52907 m .5238 .52702 L .52092 .52441 L F
.52387 .52986 m .5238 .52702 L .52092 .52441 L .933 .65 .481 r
F
.50998 .53449 m .53532 .52712 L .53051 .52268 L .654 .726 .902 r
F
.51011 .53443 m .5106 .5348 L .51038 .53428 L .675 .735 .895 r
F
.50729 .53603 m .5106 .5348 L .51011 .53443 L F
.51011 .54164 m .51028 .54176 L .51044 .53485 L .909 .63 .5 r
F
.51036 .53462 m .51045 .53468 L .5106 .52793 L F
.509 .53117 m .50979 .53225 L .50916 .53252 L .517 .303 .528 r
F
.50723 .53319 m .5106 .53199 L .51056 .53195 L .675 .735 .895 r
F
.51013 .53163 m .50955 .53119 L .50955 .534 L .909 .63 .5 r
F
.50802 .53156 m .50771 .53213 L .50799 .53227 L .654 .726 .902 r
F
.50803 .53132 m .50791 .53154 L .50802 .53156 L F
.50838 .53129 m .50877 .5355 L .50754 .53137 L .641 .402 .54 r
F
.50723 .53319 m .51056 .53195 L .50991 .53146 L .675 .735 .895 r
F
.50716 .53034 m .51007 .53235 L .51051 .53167 L F
.50955 .53119 m .50918 .53388 L .50955 .534 L .809 .541 .532 r
F
.50955 .52711 m .50933 .53111 L .50955 .53119 L F
.50933 .53111 m .50918 .53388 L .50955 .53119 L F
.5106 .52793 m .51051 .53191 L .5106 .53199 L .909 .63 .5 r
F
.50917 .53106 m .51179 .53026 L .51052 .52959 L .675 .735 .895 r
F
.50723 .53319 m .51007 .53136 L .50917 .53106 L F
.51007 .53136 m .51179 .53026 L .50917 .53106 L F
.50854 .53323 m .51058 .53244 L .50908 .53201 L F
.50743 .53842 m .50768 .54544 L .50719 .53844 L .641 .402 .54 r
F
.50768 .54544 m .50878 .57683 L .50748 .54546 L F
.50768 .54544 m .50748 .54546 L .50719 .53844 L F
.51495 .54319 m .52438 .54396 L .52608 .54338 L .654 .726 .902 r
F
.51053 .53735 m .51061 .54429 L .5105 .5374 L .076 0 .415 r
F
.51061 .54429 m .51094 .57514 L .51058 .54433 L F
.51061 .54429 m .51058 .54433 L .5105 .5374 L F
.51139 .54313 m .51579 .54351 L .51495 .54319 L .654 .726 .902 r
F
.51012 .54472 m .51002 .5448 L .5099 .53784 L .358 .18 .498 r
F
.50729 .54306 m .5113 .54327 L .51139 .54313 L .654 .726 .902 r
F
.5113 .54327 m .51579 .54351 L .51139 .54313 L F
.51579 .54351 m .52438 .54396 L .51495 .54319 L F
.50729 .53603 m .50931 .53382 L .50917 .53371 L .675 .735 .895 r
F
.50729 .53603 m .51038 .53428 L .51015 .5342 L F
.50772 .53579 m .50998 .53449 L .50955 .53415 L .654 .726 .902 r
F
.50772 .53579 m .51052 .53491 L .50998 .53449 L F
.50978 .53788 m .5098 .53792 L .50912 .53816 L .517 .303 .528 r
F
.50772 .53579 m .50954 .53801 L .51039 .53769 L .654 .726 .902 r
F
.50918 .53388 m .50905 .54101 L .50955 .534 L .809 .541 .532 r
F
.50729 .54306 m .51061 .54202 L .50997 .54152 L .654 .726 .902 r
F
.51036 .53478 m .51044 .53485 L .51045 .53468 L .909 .63 .5 r
F
.51036 .53478 m .51045 .53468 L .51036 .53462 L F
.5106 .5348 m .5106 .5348 L .51011 .53443 L .675 .735 .895 r
F
.51092 .53271 m .51062 .53484 L .5109 .53547 L .984 .727 .339 r
F
.5106 .5348 m .51282 .53398 L .5103 .5341 L .675 .735 .895 r
F
.51915 .53256 m .52591 .53045 L .51966 .53041 L F
.51249 .53245 m .51782 .53456 L .51915 .53256 L F
.51351 .53322 m .51979 .53326 L .51945 .5311 L F
.51979 .53326 m .52556 .53005 L .51945 .5311 L F
.51951 .53394 m .52387 .52986 L .51834 .53192 L F
.51052 .53491 m .53532 .52712 L .50998 .53449 L .654 .726 .902 r
F
.5215 .53153 m .53673 .53718 L .53807 .53529 L F
.5107 .54415 m .51064 .54425 L .51057 .5372 L .076 0 .415 r
F
.50875 .54007 m .51257 .54348 L .51168 .54216 L .675 .735 .895 r
F
.51065 .53718 m .51094 .54381 L .5107 .54415 L .076 0 .415 r
F
.51051 .53955 m .51093 .54104 L .51423 .54597 L .654 .726 .902 r
F
.5109 .53564 m .51061 .54202 L .51085 .54256 L .984 .727 .339 r
F
.51054 .53443 m .51064 .54425 L .5105 .53449 L .076 0 .415 r
F
.51064 .54425 m .51094 .57514 L .51061 .54429 L F
.51064 .54425 m .51061 .54429 L .5105 .53449 L F
.52069 .52948 m .53009 .52996 L .52372 .52641 L .654 .726 .902 r
F
.51325 .5343 m .51927 .53542 L .51979 .53326 L .675 .735 .895 r
F
.51357 .53607 m .51951 .53394 L .5134 .53499 L F
.51782 .53456 m .52514 .53367 L .51915 .53256 L F
.51915 .53256 m .52514 .53367 L .52591 .53045 L F
.52607 .53329 m .526 .53045 L .5255 .5272 L .853 .655 .117 r
F
.51325 .5343 m .51979 .53326 L .51351 .53322 L .675 .735 .895 r
F
.52607 .53329 m .5255 .5272 L .52556 .53005 L .853 .655 .117 r
F
.52529 .53653 m .526 .53045 L .52607 .53329 L 0 0 .256 r
F
.51979 .53326 m .52607 .53329 L .52556 .53005 L .675 .735 .895 r
F
.52613 .53614 m .52607 .53329 L .52556 .53005 L .853 .655 .117 r
F
.52613 .53614 m .52556 .53005 L .52562 .53289 L F
.5134 .53499 m .51834 .53192 L .51282 .53398 L .675 .735 .895 r
F
.5134 .53499 m .51951 .53394 L .51834 .53192 L F
.51951 .53394 m .52562 .53289 L .52387 .52986 L F
.51237 .53433 m .53825 .53215 L .53532 .52712 L .654 .726 .902 r
F
.5109 .53547 m .51061 .53498 L .5109 .53564 L .984 .727 .339 r
F
.51062 .53484 m .51061 .53498 L .5109 .53547 L F
.50772 .53579 m .51578 .53483 L .51237 .53433 L .654 .726 .902 r
F
.52529 .53653 m .52523 .53369 L .526 .53045 L 0 0 .256 r
F
.51927 .53542 m .52607 .53329 L .51979 .53326 L .675 .735 .895 r
F
.51782 .53456 m .52314 .53666 L .52514 .53367 L F
.51985 .5361 m .52562 .53289 L .51951 .53394 L F
.51578 .53483 m .53825 .53215 L .51237 .53433 L .654 .726 .902 r
F
.50716 .53034 m .5091 .52822 L .50848 .52802 L .675 .735 .895 r
F
.50823 .52668 m .5081 .5337 L .50848 .52671 L .734 .477 .54 r
F
.50723 .53319 m .5081 .5356 L .50904 .53539 L .675 .735 .895 r
F
.50729 .53603 m .50917 .53371 L .50836 .53363 L F
.50918 .53388 m .50848 .53364 L .50848 .53376 L .809 .541 .532 r
F
.50918 .53388 m .50848 .53376 L .50917 .53401 L F
.50931 .53382 m .51058 .53244 L .50854 .53323 L .675 .735 .895 r
F
.51013 .53163 m .50955 .534 L .50997 .53432 L .909 .63 .5 r
F
.50991 .53146 m .51035 .53141 L .51028 .53123 L .675 .735 .895 r
F
.51035 .53141 m .51275 .53113 L .51028 .53123 L F
.51056 .53195 m .51275 .53113 L .50991 .53146 L F
.51056 .53195 m .5106 .53199 L .51058 .53194 L F
.51324 .5293 m .51816 .52625 L .51266 .5283 L F
.51266 .5283 m .51624 .52452 L .5117 .52743 L F
.51266 .5283 m .51816 .52625 L .51624 .52452 L F
.5117 .52743 m .51624 .52452 L .51371 .52318 L F
.51341 .53038 m .51933 .52826 L .51324 .5293 L F
.51275 .53113 m .51635 .52733 L .51179 .53026 L F
.51816 .52625 m .52079 .52161 L .51624 .52452 L F
.51179 .53026 m .51381 .52599 L .51052 .52959 L F
.51179 .53026 m .51635 .52733 L .51381 .52599 L F
.51624 .52452 m .51698 .5196 L .51371 .52318 L F
.51624 .52452 m .52079 .52161 L .51698 .5196 L F
.51058 .53244 m .51087 .52799 L .50908 .53201 L F
.51058 .53244 m .51387 .52884 L .51087 .52799 L F
.51635 .52733 m .5171 .52239 L .51381 .52599 L F
.51635 .52733 m .52092 .52441 L .5171 .52239 L F
.51816 .52625 m .52366 .5242 L .52079 .52161 L F
.52092 .52441 m .52085 .52156 L .51703 .51955 L .861 .586 .52 r
F
.51381 .52599 m .5171 .52239 L .5126 .52112 L .675 .735 .895 r
F
.52092 .52441 m .51703 .51955 L .5171 .52239 L .861 .586 .52 r
F
.51371 .52318 m .51698 .5196 L .51251 .51833 L .675 .735 .895 r
F
.5171 .52239 m .51703 .51955 L .51254 .51827 L .794 .529 .537 r
F
.5117 .52743 m .51371 .52318 L .51044 .52676 L .675 .735 .895 r
F
.51052 .52959 m .51381 .52599 L .51081 .52514 L F
.51387 .52884 m .51267 .52396 L .51087 .52799 L F
.51387 .52884 m .51716 .52524 L .51267 .52396 L F
.51716 .52524 m .5171 .52239 L .5126 .52112 L .794 .529 .537 r
F
.51716 .52524 m .5126 .52112 L .51267 .52396 L F
.50772 .53579 m .52414 .51913 L .51666 .51672 L .654 .726 .902 r
F
.51927 .53542 m .52529 .53653 L .52607 .53329 L .675 .735 .895 r
F
.51985 .5361 m .52613 .53614 L .52562 .53289 L F
.51357 .53607 m .51985 .5361 L .51951 .53394 L F
.50772 .53579 m .53909 .53743 L .53825 .53215 L .654 .726 .902 r
F
.51011 .54164 m .51044 .53485 L .51036 .53478 L .909 .63 .5 r
F
.51324 .5293 m .51933 .52826 L .51816 .52625 L .675 .735 .895 r
F
.51334 .53214 m .51828 .52907 L .51275 .53113 L F
.51275 .53113 m .51828 .52907 L .51635 .52733 L F
.51828 .52907 m .52092 .52441 L .51635 .52733 L F
.5238 .52702 m .52374 .52417 L .52085 .52156 L .933 .65 .481 r
F
.51185 .53311 m .51387 .52884 L .51058 .53244 L .675 .735 .895 r
F
.51185 .53311 m .51642 .53018 L .51387 .52884 L F
.5238 .52702 m .52085 .52156 L .52092 .52441 L .933 .65 .481 r
F
.51642 .53018 m .51716 .52524 L .51387 .52884 L .675 .735 .895 r
F
.51642 .53018 m .52098 .52725 L .51716 .52524 L F
.52387 .52986 m .52092 .52441 L .52098 .52725 L .933 .65 .481 r
F
.52098 .52725 m .52092 .52441 L .5171 .52239 L .861 .586 .52 r
F
.52098 .52725 m .5171 .52239 L .51716 .52524 L F
.50943 .53406 m .53051 .52268 L .52414 .51913 L .654 .726 .902 r
F
.51092 .53271 m .5109 .53564 L .51096 .53281 L .984 .727 .339 r
F
.51015 .5342 m .51038 .53428 L .5103 .5341 L .675 .735 .895 r
F
.50998 .53449 m .53051 .52268 L .50943 .53406 L .654 .726 .902 r
F
.50772 .53579 m .51152 .53665 L .51216 .53618 L F
.51044 .53485 m .51028 .54176 L .51061 .53498 L .909 .63 .5 r
F
.51193 .53601 m .51216 .53618 L .51236 .53603 L .654 .726 .902 r
F
.50955 .534 m .50935 .54112 L .50955 .5412 L .809 .541 .532 r
F
.50836 .54078 m .52372 .52641 L .51623 .52399 L .654 .726 .902 r
F
.50729 .54306 m .50939 .54093 L .50836 .54078 L F
.51098 .53649 m .51099 .54345 L .51095 .53664 L 0 0 .142 r
F
.50939 .54093 m .52372 .52641 L .50836 .54078 L .654 .726 .902 r
F
.5081 .5337 m .50797 .54073 L .50831 .53373 L .734 .477 .54 r
F
.51258 .5414 m .53783 .53943 L .5349 .5344 L .654 .726 .902 r
F
.50729 .54306 m .51646 .54197 L .51258 .5414 L F
.51646 .54197 m .53783 .53943 L .51258 .5414 L F
.50723 .53319 m .50712 .53573 L .5081 .5356 L .675 .735 .895 r
F
.5081 .5337 m .50739 .5336 L .50739 .54064 L .734 .477 .54 r
F
.50729 .54306 m .50719 .54549 L .50815 .5454 L .654 .726 .902 r
F
.50773 .53839 m .50773 .53846 L .50743 .53842 L .641 .402 .54 r
F
.50719 .53854 m .50712 .5402 L .50815 .5384 L .675 .735 .895 r
F
.50773 .53846 m .50792 .54542 L .50744 .5385 L .641 .402 .54 r
F
.50773 .53846 m .50744 .5385 L .50743 .53842 L F
.50815 .5384 m .50712 .5402 L .50875 .54007 L .675 .735 .895 r
F
.50729 .53603 m .50719 .53854 L .50815 .5384 L F
.50797 .54073 m .50739 .54064 L .5074 .57196 L .734 .477 .54 r
F
.50729 .53603 m .50882 .53789 L .50782 .5364 L .675 .735 .895 r
F
.5081 .5337 m .50739 .54064 L .50797 .54073 L .734 .477 .54 r
F
.50797 .54073 m .5074 .57196 L .50814 .54075 L F
.50797 .54073 m .50814 .54075 L .50831 .53373 L F
.51011 .5288 m .50955 .52837 L .50955 .53119 L .909 .63 .5 r
F
.50915 .52824 m .50848 .52802 L .50848 .53083 L .809 .541 .532 r
F
.50881 .53094 m .50848 .53083 L .50848 .53364 L F
.50915 .52824 m .50848 .53083 L .50881 .53094 L F
.50931 .52702 m .50918 .53388 L .50955 .52711 L F
.5083 .53077 m .51052 .52959 L .50902 .52916 L .675 .735 .895 r
F
.50826 .5308 m .50838 .53082 L .50848 .52671 L .734 .477 .54 r
F
.50829 .53081 m .50834 .53078 L .5083 .53077 L .675 .735 .895 r
F
.50931 .52702 m .50848 .53364 L .50918 .53388 L .809 .541 .532 r
F
.50834 .53078 m .51052 .52959 L .5083 .53077 L .675 .735 .895 r
F
.50716 .53034 m .50805 .53279 L .50907 .53265 L F
.50723 .53319 m .50931 .53091 L .50829 .53081 L F
.50931 .53091 m .51052 .52959 L .50829 .53081 L F
.50811 .5336 m .50831 .53362 L .50838 .53082 L .734 .477 .54 r
F
.50815 .53079 m .50739 .5336 L .5081 .5337 L F
.50821 .52799 m .5078 .53076 L .50815 .53079 L F
.50723 .53319 m .50829 .53081 L .50739 .53071 L .675 .735 .895 r
F
.50718 .51843 m .50754 .53137 L .50719 .5314 L .641 .402 .54 r
F
.50716 .53034 m .50829 .52782 L .50726 .52791 L .675 .735 .895 r
F
.50739 .5279 m .50729 .53072 L .50739 .53071 L .66 .417 .541 r
F
.5063 .51343 m .5052 .52689 L .50605 .52666 L .568 .343 .534 r
F
.5052 .51377 m .50495 .52705 L .5052 .52689 L .401 .213 .507 r
F
.50815 .52851 m .50087 .50869 L .49325 .5103 L .654 .726 .902 r
F
.50739 .52655 m .50736 .52791 L .50739 .5279 L .66 .417 .541 r
F
.50736 .52791 m .50729 .53072 L .50739 .5279 L F
.50815 .52851 m .50822 .52668 L .50743 .52656 L .654 .726 .902 r
F
.50749 .52657 m .50739 .52655 L .50739 .5279 L .734 .477 .54 r
F
.50847 .51347 m .50739 .5279 L .50821 .52799 L F
.50726 .52791 m .50895 .52634 L .50734 .52619 L .675 .735 .895 r
F
.50829 .52782 m .50895 .52634 L .50726 .52791 L F
.50733 .53072 m .50739 .53071 L .50733 .53071 L F
.50723 .53319 m .50739 .53071 L .50733 .53072 L F
.50739 .53071 m .50722 .53354 L .50739 .53353 L .66 .417 .541 r
F
.50729 .53072 m .50722 .53354 L .50739 .53071 L F
.5078 .53076 m .50739 .5336 L .50815 .53079 L .734 .477 .54 r
F
.50821 .52799 m .50739 .5279 L .50739 .5336 L F
.50733 .53071 m .50902 .52916 L .5074 .52901 L .675 .735 .895 r
F
.50829 .53081 m .50902 .52916 L .50733 .53071 L F
.50739 .53353 m .50908 .53201 L .50746 .53186 L F
.50729 .53603 m .50836 .53363 L .50739 .53353 L F
.50836 .53363 m .50908 .53201 L .50739 .53353 L F
.5081 .5337 m .50831 .53373 L .50831 .53362 L .734 .477 .54 r
F
.5081 .5337 m .50831 .53362 L .50811 .5336 L F
.5081 .5337 m .50838 .53082 L .50826 .5308 L F
.50939 .54093 m .51487 .53803 L .52069 .52948 L .654 .726 .902 r
F
.51487 .53803 m .53009 .52996 L .52069 .52948 L F
.50729 .54306 m .51067 .54112 L .50939 .54093 L F
.51099 .54345 m .51097 .54357 L .51095 .53664 L 0 0 .142 r
F
.51097 .54357 m .51096 .54366 L .51094 .53676 L F
.51094 .53676 m .51096 .54366 L .51094 .54381 L F
.51085 .54256 m .51097 .54285 L .51105 .53599 L .984 .727 .339 r
F
.51098 .53649 m .51105 .54303 L .51099 .54345 L 0 0 .142 r
F
.51105 .53599 m .51097 .54285 L .51105 .54303 L .984 .727 .339 r
F
.51075 .53796 m .51364 .54185 L .51245 .53917 L .654 .726 .902 r
F
.51067 .54112 m .53009 .52996 L .50939 .54093 L F
.50831 .53362 m .50814 .54075 L .50848 .53364 L .734 .477 .54 r
F
.50814 .54075 m .5074 .57196 L .50828 .54077 L F
.50814 .54075 m .50828 .54077 L .50848 .53364 L F
.50905 .54101 m .50848 .57209 L .50935 .54112 L .809 .541 .532 r
F
.50905 .54101 m .50935 .54112 L .50955 .534 L F
.51282 .54241 m .52608 .54338 L .51646 .54197 L .654 .726 .902 r
F
.50729 .54306 m .51495 .54319 L .51282 .54241 L F
.51495 .54319 m .52608 .54338 L .51282 .54241 L F
.50939 .53409 m .50955 .53415 L .50943 .53406 L F
.50772 .53579 m .50955 .53415 L .50939 .53409 L F
.50917 .53401 m .50848 .53376 L .50848 .5408 L .809 .541 .532 r
F
.50905 .54101 m .50848 .5408 L .50848 .57209 L F
.50918 .53388 m .50848 .5408 L .50905 .54101 L F
.50848 .5408 m .5074 .57196 L .50848 .57209 L .734 .477 .54 r
F
.50848 .53364 m .50828 .54077 L .50848 .5408 L F
.50828 .54077 m .5074 .57196 L .50848 .5408 L F
.51646 .54197 m .52608 .54338 L .53783 .53943 L .654 .726 .902 r
F
.52961 .54385 m .56134 .5514 L .53475 .53996 L F
.52438 .54396 m .53867 .54471 L .53835 .54271 L F
.52438 .54396 m .53835 .54271 L .53783 .53943 L F
.50848 .52671 m .50831 .53362 L .50848 .53364 L .734 .477 .54 r
F
.50836 .53363 m .50917 .53371 L .50854 .53323 L .675 .735 .895 r
F
.50997 .53432 m .50955 .534 L .50955 .5412 L .909 .63 .5 r
F
.49524 .5338 m .48845 .53593 L .49473 .53596 L .675 .735 .895 r
F
.49524 .5338 m .48922 .53269 L .48845 .53593 L F
.50347 .54142 m .48568 .52763 L .48053 .53155 L .654 .726 .902 r
F
.50373 .53662 m .50397 .54411 L .50377 .54374 L .989 .72 .386 r
F
.50729 .54306 m .50459 .54113 L .50347 .54142 L .654 .726 .902 r
F
.5036 .53638 m .50368 .54358 L .5036 .54343 L .989 .72 .386 r
F
.50377 .54374 m .50371 .54364 L .50366 .53649 L F
.50357 .54301 m .50356 .54289 L .50355 .53572 L .783 .625 .063 r
F
.50356 .54289 m .50356 .54279 L .50355 .5356 L F
.5042 .53746 m .50428 .54438 L .50408 .53736 L .929 .648 .488 r
F
.50481 .53417 m .50408 .53464 L .50408 .54168 L .401 .213 .507 r
F
.50562 .53814 m .50591 .54524 L .50562 .54518 L .751 .491 .539 r
F
.50729 .54306 m .50332 .54217 L .50273 .54254 L .654 .726 .902 r
F
.50418 .54429 m .50464 .5763 L .50409 .54421 L .929 .648 .488 r
F
.50418 .54429 m .50409 .54421 L .50397 .53706 L F
.50428 .54438 m .50464 .5763 L .50418 .54429 L F
.50428 .54438 m .50418 .54429 L .50408 .53715 L F
.50468 .5413 m .50408 .54168 L .50408 .57317 L .401 .213 .507 r
F
.50772 .53579 m .5037 .53488 L .50268 .53552 L .654 .726 .902 r
F
.50454 .5378 m .50371 .53833 L .50534 .53817 L .675 .735 .895 r
F
.50481 .53417 m .50408 .54168 L .50468 .5413 L .401 .213 .507 r
F
.50332 .54217 m .50347 .54142 L .50186 .54184 L .654 .726 .902 r
F
.50509 .54492 m .50494 .54485 L .50479 .53773 L .845 .571 .524 r
F
.50729 .54306 m .50408 .54168 L .50332 .54217 L .654 .726 .902 r
F
.50366 .53649 m .50371 .54364 L .5036 .53638 L .989 .72 .386 r
F
.5038 .5466 m .49829 .55219 L .50386 .54743 L .654 .726 .902 r
F
.50371 .54364 m .50379 .55289 L .50368 .54358 L .989 .72 .386 r
F
.50371 .54364 m .50368 .54358 L .5036 .53638 L F
.50101 .53659 m .4989 .53684 L .50021 .53709 L .654 .726 .902 r
F
.50101 .53659 m .50021 .53709 L .50229 .53749 L F
.50101 .536 m .49507 .53812 L .50118 .53708 L .675 .735 .895 r
F
.49651 .52613 m .48919 .52702 L .49518 .52812 L F
.49651 .52613 m .49118 .52402 L .48919 .52702 L F
.49116 .52683 m .4891 .527 L .48916 .52984 L .117 .009 .443 r
F
.49116 .52683 m .4911 .52399 L .4891 .527 L F
.50127 .53492 m .49473 .53596 L .50101 .536 L .675 .735 .895 r
F
.5036 .53381 m .5025 .53316 L .5033 .53386 L F
.5025 .53316 m .50095 .53315 L .5033 .53386 L F
.50092 .53031 m .49467 .53027 L .49501 .53242 L F
.50117 .52923 m .49518 .52812 L .49467 .53027 L F
.50187 .53107 m .49518 .53096 L .50121 .53207 L F
.50117 .52923 m .49467 .53027 L .50092 .53031 L F
.50187 .53107 m .49652 .52895 L .49518 .53096 L F
.50184 .52824 m .49651 .52613 L .49518 .52812 L F
.49859 .52723 m .49116 .52683 L .49652 .52895 L F
.50407 .53422 m .49437 .52673 L .49157 .52884 L .654 .726 .902 r
F
.49433 .5271 m .49392 .52707 L .49123 .52968 L .357 .187 .509 r
F
.49392 .52707 m .49116 .52683 L .49121 .52912 L F
.49392 .52707 m .49121 .52912 L .49123 .52968 L F
.49157 .52884 m .48612 .52036 L .48096 .52428 L .654 .726 .902 r
F
.49859 .52723 m .49426 .52426 L .49116 .52683 L .675 .735 .895 r
F
.49433 .5271 m .49426 .52426 L .49116 .52683 L .357 .187 .509 r
F
.49437 .52673 m .48612 .52036 L .49157 .52884 L .654 .726 .902 r
F
.50723 .53319 m .50447 .53495 L .50527 .53532 L .675 .735 .895 r
F
.50723 .53319 m .50418 .53482 L .50447 .53495 L F
.50772 .53579 m .50514 .53394 L .50407 .53422 L .654 .726 .902 r
F
.50352 .5325 m .50121 .53207 L .50356 .53317 L .675 .735 .895 r
F
.50291 .53021 m .49652 .52895 L .50187 .53107 L F
.49426 .52426 m .4911 .52399 L .49116 .52683 L .357 .187 .509 r
F
.50514 .53394 m .48612 .52036 L .50407 .53422 L .654 .726 .902 r
F
.50597 .53092 m .5052 .53116 L .5052 .53393 L .568 .343 .534 r
F
.50575 .53379 m .5052 .53393 L .5052 .54097 L F
.50377 .53255 m .50217 .53119 L .50282 .53237 L .675 .735 .895 r
F
.50723 .53319 m .50408 .53194 L .50377 .53255 L F
.50408 .53194 m .50217 .53119 L .50377 .53255 L F
.5039 .53497 m .50399 .53479 L .50403 .53205 L 0 0 .377 r
F
.50396 .53216 m .50403 .53205 L .50408 .5276 L F
.5039 .53497 m .50403 .53205 L .50396 .53216 L F
.50597 .53092 m .5052 .53393 L .50575 .53379 L .568 .343 .534 r
F
.50127 .53492 m .49524 .5338 L .49473 .53596 L .675 .735 .895 r
F
.49658 .5318 m .48922 .53269 L .49524 .5338 L F
.49658 .5318 m .49123 .52968 L .48922 .53269 L F
.49865 .53008 m .49123 .52968 L .49658 .5318 L F
.49865 .53008 m .49433 .5271 L .49123 .52968 L F
.50082 .53845 m .49232 .52476 L .48568 .52763 L .654 .726 .902 r
F
.5039 .53497 m .50355 .54265 L .50383 .54213 L 0 0 .377 r
F
.50194 .53391 m .49524 .5338 L .50127 .53492 L .675 .735 .895 r
F
.50194 .53391 m .49658 .5318 L .49524 .5338 L F
.50444 .54103 m .49511 .52817 L .50082 .53845 L .654 .726 .902 r
F
.50497 .538 m .50562 .5383 L .50562 .54518 L .845 .571 .524 r
F
.50729 .54306 m .50492 .54016 L .50444 .54103 L .654 .726 .902 r
F
.50391 .54198 m .50398 .54186 L .50408 .53464 L 0 0 .377 r
F
.50408 .53464 m .50398 .54186 L .50408 .54168 L F
.50273 .53896 m .50071 .54322 L .504 .53963 L .675 .735 .895 r
F
.50383 .54213 m .50391 .54198 L .50399 .53479 L 0 0 .377 r
F
.50356 .53607 m .5036 .53658 L .5036 .54343 L .783 .625 .063 r
F
.50492 .54016 m .49511 .52817 L .50444 .54103 L .654 .726 .902 r
F
.49511 .52817 m .49232 .52476 L .50082 .53845 L F
.50408 .54168 m .50347 .54142 L .50332 .54217 L F
.50356 .53587 m .5036 .54343 L .50357 .54301 L .783 .625 .063 r
F
.50118 .53708 m .49624 .54014 L .50176 .53809 L .675 .735 .895 r
F
.50459 .54113 m .48568 .52763 L .50347 .54142 L .654 .726 .902 r
F
.50613 .53369 m .50596 .54078 L .5063 .53364 L .568 .343 .534 r
F
.50596 .54078 m .5052 .57238 L .5061 .54074 L F
.50596 .54078 m .5061 .54074 L .5063 .53364 L F
.5063 .54069 m .5052 .57238 L .5063 .57205 L F
.50615 .53824 m .50719 .53854 L .50616 .53838 L .751 .491 .539 r
F
.5063 .53364 m .5061 .54074 L .5063 .54069 L .568 .343 .534 r
F
.5061 .54074 m .5052 .57238 L .5063 .54069 L F
.50273 .53896 m .49817 .54188 L .50071 .54322 L .675 .735 .895 r
F
.50186 .54184 m .50218 .54087 L .49831 .54103 L .654 .726 .902 r
F
.50347 .54142 m .50218 .54087 L .50186 .54184 L F
.50176 .53809 m .49624 .54014 L .49817 .54188 L .675 .735 .895 r
F
.49473 .53596 m .48896 .53917 L .49507 .53812 L F
.50218 .54087 m .48053 .53155 L .49831 .54103 L .654 .726 .902 r
F
.50268 .53552 m .50254 .53462 L .49965 .53537 L F
.50729 .53603 m .50127 .53492 L .50101 .536 L .675 .735 .895 r
F
.50702 .53356 m .5063 .53363 L .5063 .54069 L .66 .417 .541 r
F
.50616 .53838 m .50719 .53854 L .50719 .54549 L .751 .491 .539 r
F
.50616 .53838 m .50719 .54549 L .50634 .54532 L F
.5061 .54528 m .50719 .57704 L .50591 .54524 L F
.50729 .54306 m .50562 .54518 L .50624 .5453 L .654 .726 .902 r
F
.50634 .54532 m .50719 .57704 L .5061 .54528 L .751 .491 .539 r
F
.50688 .54066 m .5063 .54069 L .5063 .57205 L .66 .417 .541 r
F
.50729 .53603 m .50624 .53839 L .50719 .53854 L .675 .735 .895 r
F
.50702 .53356 m .5063 .54069 L .50688 .54066 L .66 .417 .541 r
F
.50579 .54082 m .5052 .57238 L .50596 .54078 L .568 .343 .534 r
F
.50586 .53818 m .5061 .54528 L .50562 .53814 L .751 .491 .539 r
F
.50579 .54082 m .50596 .54078 L .50613 .53369 L .568 .343 .534 r
F
.49624 .54014 m .49072 .5422 L .49361 .54481 L .675 .735 .895 r
F
.49883 .54262 m .49195 .54131 L .48999 .54216 L .654 .726 .902 r
F
.50729 .54306 m .50024 .54226 L .49883 .54262 L F
.50024 .54226 m .49195 .54131 L .49883 .54262 L F
.49195 .54131 m .47638 .53952 L .48675 .54153 L F
.49195 .54131 m .48675 .54153 L .48999 .54216 L F
.50696 .53511 m .50739 .53353 L .50642 .53362 L .675 .735 .895 r
F
.50729 .53603 m .50731 .53563 L .50696 .53511 L F
.50731 .53563 m .50739 .53353 L .50696 .53511 L F
.50605 .52666 m .5052 .53116 L .50597 .53092 L .568 .343 .534 r
F
.50548 .53107 m .50543 .531 L .5052 .53116 L .675 .735 .895 r
F
.50548 .53107 m .5052 .53116 L .50475 .53148 L F
.50495 .52705 m .50408 .53464 L .50481 .53417 L .401 .213 .507 r
F
.50543 .531 m .50424 .52955 L .50475 .53148 L .675 .735 .895 r
F
.50543 .531 m .50577 .52915 L .50424 .52955 L F
.50396 .52781 m .50394 .52939 L .50408 .5276 L 0 0 .377 r
F
.50394 .52939 m .50404 .52921 L .50408 .5276 L F
.50356 .52873 m .50356 .53036 L .50355 .52856 L .783 .625 .063 r
F
.50396 .52781 m .50355 .53016 L .50387 .52954 L 0 0 .377 r
F
.50495 .52705 m .50408 .52914 L .50476 .52865 L .401 .213 .507 r
F
.50474 .52867 m .50443 .52846 L .50409 .52913 L .675 .735 .895 r
F
.50443 .52846 m .50287 .52738 L .50409 .52912 L F
.50443 .52846 m .50409 .52912 L .50409 .52913 L F
.50409 .52913 m .50184 .52824 L .50336 .52964 L F
.50495 .52705 m .50408 .5276 L .50408 .52914 L .401 .213 .507 r
F
.50815 .52851 m .49325 .5103 L .48665 .51316 L .654 .726 .902 r
F
.50492 .52855 m .50512 .52841 L .5052 .52689 L .401 .213 .507 r
F
.50716 .53034 m .50419 .52673 L .50287 .52738 L .675 .735 .895 r
F
.50419 .52673 m .49857 .52442 L .50287 .52738 L F
.50419 .52673 m .50121 .52311 L .49857 .52442 L F
.50571 .52632 m .50121 .52311 L .50419 .52673 L F
.50577 .52915 m .50124 .52592 L .50424 .52955 L F
.50495 .52705 m .50492 .52854 L .505 .52701 L .401 .213 .507 r
F
.50492 .52854 m .50492 .52855 L .505 .52701 L F
.505 .52701 m .50492 .52855 L .5052 .52689 L F
.50577 .52915 m .50431 .5251 L .50124 .52592 L .675 .735 .895 r
F
.50121 .52311 m .49823 .5195 L .49427 .52146 L F
.50426 .5223 m .49823 .5195 L .50121 .52311 L F
.50378 .52971 m .50351 .52967 L .50355 .53016 L F
.50351 .52967 m .50117 .52923 L .50356 .53032 L F
.50336 .52964 m .50184 .52824 L .50117 .52923 L F
.50424 .52955 m .49859 .52723 L .50291 .53021 L F
.50583 .53199 m .50437 .52795 L .5013 .52877 L F
.50426 .5223 m .50281 .51828 L .49823 .5195 L F
.50431 .5251 m .49825 .52229 L .50124 .52592 L F
.50571 .52632 m .50426 .5223 L .50121 .52311 L F
.50431 .5251 m .50285 .52106 L .49825 .52229 L F
.50285 .52106 m .49819 .51944 L .49825 .52229 L .592 .367 .544 r
F
.50285 .52106 m .50278 .51822 L .49819 .51944 L F
.50437 .52795 m .50291 .52391 L .49831 .52513 L .675 .735 .895 r
F
.50121 .52311 m .49427 .52146 L .49857 .52442 L F
.50291 .52391 m .49825 .52229 L .49831 .52504 L .592 .367 .544 r
F
.50486 .5314 m .50481 .53417 L .50496 .53133 L .401 .213 .507 r
F
.50287 .52738 m .49651 .52613 L .50184 .52824 L .675 .735 .895 r
F
.50424 .52955 m .50124 .52592 L .49859 .52723 L F
.49857 .52442 m .49427 .52146 L .49118 .52402 L F
.50124 .52592 m .49825 .52229 L .49426 .52426 L F
.49825 .52229 m .49819 .51944 L .4942 .52141 L .497 .293 .534 r
F
.49831 .52504 m .49825 .52229 L .49817 .5251 L F
.49877 .52484 m .49485 .51704 L .49275 .51749 L .654 .726 .902 r
F
.50602 .53371 m .49978 .5244 L .49877 .52484 L F
.49978 .5244 m .49485 .51704 L .49877 .52484 L F
.49817 .5251 m .49825 .52229 L .49426 .52426 L .497 .293 .534 r
F
.50287 .52738 m .49857 .52442 L .49651 .52613 L .675 .735 .895 r
F
.50347 .5317 m .50291 .53021 L .50187 .53107 L F
.50339 .53054 m .50291 .53021 L .50347 .5317 L F
.50377 .53255 m .50352 .5325 L .50355 .53297 L F
.50217 .53119 m .50187 .53107 L .50282 .53237 L F
.50408 .5276 m .50399 .53479 L .50408 .53464 L 0 0 .377 r
F
.50184 .52824 m .49518 .52812 L .50117 .52923 L .675 .735 .895 r
F
.49857 .52442 m .49118 .52402 L .49651 .52613 L F
.50291 .53021 m .49859 .52723 L .49652 .52895 L F
.49426 .52426 m .4942 .52141 L .4911 .52399 L .357 .187 .509 r
F
.50124 .52592 m .49426 .52426 L .49859 .52723 L .675 .735 .895 r
F
.49825 .52229 m .4942 .52141 L .49426 .52426 L .497 .293 .534 r
F
.50713 .53537 m .49869 .52488 L .4948 .52656 L .654 .726 .902 r
F
.49831 .52513 m .49817 .5251 L .49433 .5271 L .497 .293 .534 r
F
.49817 .5251 m .49426 .52426 L .49432 .52676 L F
.49817 .5251 m .49432 .52676 L .49433 .5271 L F
.4948 .52656 m .49275 .51749 L .48612 .52036 L .654 .726 .902 r
F
.49869 .52488 m .49275 .51749 L .4948 .52656 L F
.50772 .53579 m .50602 .53371 L .50713 .53537 L F
.50602 .53371 m .49275 .51749 L .50713 .53537 L F
.50729 .53603 m .50696 .53511 L .5043 .5324 L .675 .735 .895 r
F
.50605 .52666 m .50592 .53374 L .5063 .5266 L .568 .343 .534 r
F
.50696 .53511 m .50583 .53199 L .50501 .53221 L .675 .735 .895 r
F
.50696 .53511 m .50501 .53221 L .5043 .5324 L F
.49831 .52513 m .49831 .52504 L .49817 .5251 L .497 .293 .534 r
F
.49998 .52469 m .49831 .52504 L .49831 .52513 L .592 .367 .544 r
F
.50291 .52391 m .49831 .52504 L .49998 .52469 L F
.50008 .52467 m .5004 .51586 L .49485 .51704 L .654 .726 .902 r
F
.50772 .53579 m .50338 .52397 L .50008 .52467 L F
.50291 .52391 m .50285 .52106 L .49825 .52229 L .592 .367 .544 r
F
.50338 .52397 m .5004 .51586 L .50008 .52467 L .654 .726 .902 r
F
.50772 .53579 m .49485 .51704 L .50602 .53371 L F
.50715 .52656 m .50712 .52793 L .50739 .52655 L .66 .417 .541 r
F
.50716 .53034 m .50726 .52791 L .50632 .528 L .675 .735 .895 r
F
.50712 .52793 m .50702 .53361 L .50732 .52791 L .66 .417 .541 r
F
.50712 .52793 m .50732 .52791 L .50739 .52655 L F
.50715 .52656 m .5063 .5266 L .5063 .528 L F
.50632 .528 m .50734 .52619 L .50571 .52632 L .675 .735 .895 r
F
.50715 .52656 m .5063 .528 L .50698 .52794 L .66 .417 .541 r
F
.50726 .52791 m .50734 .52619 L .50632 .528 L .675 .735 .895 r
F
.50548 .53107 m .50623 .53044 L .50543 .531 L F
.50698 .52794 m .5063 .528 L .5063 .53082 L .66 .417 .541 r
F
.50723 .53319 m .50637 .53081 L .50548 .53107 L .675 .735 .895 r
F
.50664 .53078 m .5063 .53082 L .5063 .53363 L .66 .417 .541 r
F
.50698 .52794 m .5063 .53082 L .50664 .53078 L F
.50637 .53081 m .50636 .5308 L .5063 .53082 L .675 .735 .895 r
F
.50637 .53081 m .5063 .53082 L .50548 .53107 L F
.50636 .5308 m .50623 .53044 L .50548 .53107 L F
.50592 .53374 m .50613 .53369 L .5062 .53085 L .568 .343 .534 r
F
.50607 .53089 m .5062 .53085 L .5063 .5266 L F
.50592 .53374 m .5062 .53085 L .50607 .53089 L F
.50623 .53044 m .50577 .52915 L .50543 .531 L .675 .735 .895 r
F
.50707 .53074 m .5063 .53363 L .50702 .53356 L .66 .417 .541 r
F
.50715 .52656 m .50664 .53078 L .50707 .53074 L F
.50664 .53078 m .5063 .53363 L .50707 .53074 L F
.50637 .53081 m .5074 .52901 L .50577 .52915 L .675 .735 .895 r
F
.50733 .53072 m .5074 .52901 L .50637 .53081 L F
.50642 .53362 m .50746 .53186 L .50583 .53199 L F
.50739 .51335 m .50715 .52656 L .50739 .52655 L .66 .417 .541 r
F
.50531 .52809 m .50571 .52632 L .50419 .52673 L .675 .735 .895 r
F
.50632 .528 m .50571 .52632 L .50531 .52809 L F
.50739 .51335 m .5063 .5266 L .50715 .52656 L .66 .417 .541 r
F
.5063 .5266 m .50613 .53369 L .5063 .53364 L .568 .343 .534 r
F
.5063 .51343 m .50605 .52666 L .5063 .5266 L F
.50743 .52656 m .50753 .52541 L .5071 .52568 L .654 .726 .902 r
F
.50753 .52541 m .50898 .50843 L .5071 .52568 L F
.50734 .52619 m .50426 .5223 L .50571 .52632 L .675 .735 .895 r
F
.5071 .52568 m .50898 .50843 L .50087 .50869 L .654 .726 .902 r
F
.50734 .52619 m .50751 .52203 L .50426 .5223 L .675 .735 .895 r
F
.5074 .52901 m .50431 .5251 L .50577 .52915 L F
.5074 .52901 m .50757 .52484 L .50431 .5251 L F
.50746 .53186 m .50437 .52795 L .50583 .53199 L F
.50702 .53361 m .50714 .53361 L .50739 .52655 L .66 .417 .541 r
F
.50746 .53186 m .50763 .52768 L .50437 .52795 L .675 .735 .895 r
F
.50751 .52203 m .50281 .51828 L .50426 .5223 L F
.50751 .52203 m .50768 .51788 L .50281 .51828 L F
.50757 .52484 m .50285 .52106 L .50431 .5251 L F
.50757 .52484 m .50774 .52066 L .50285 .52106 L F
.50763 .52768 m .50291 .52391 L .50437 .52795 L F
.50763 .52768 m .5078 .52351 L .50291 .52391 L F
.50774 .52066 m .50278 .51822 L .50285 .52106 L .666 .425 .547 r
F
.50774 .52066 m .50768 .51782 L .50278 .51822 L F
.5078 .52351 m .50285 .52106 L .50291 .52391 L F
.5078 .52351 m .50774 .52066 L .50285 .52106 L F
.50692 .53362 m .50856 .5156 L .5004 .51586 L .654 .726 .902 r
F
.50772 .53579 m .50781 .53358 L .50692 .53362 L F
.50739 .53353 m .50746 .53186 L .50642 .53362 L .675 .735 .895 r
F
.50847 .51347 m .50823 .52668 L .50848 .52671 L .734 .477 .54 r
F
.50822 .52668 m .50898 .50843 L .50743 .52656 L .654 .726 .902 r
F
.50955 .51385 m .50848 .52671 L .50931 .52702 L .809 .541 .532 r
F
.50815 .52851 m .50954 .52553 L .50838 .52289 L .654 .726 .902 r
F
.50895 .52634 m .50751 .52203 L .50734 .52619 L .675 .735 .895 r
F
.50821 .52799 m .50848 .52802 L .50824 .52794 L F
.50902 .52916 m .50757 .52484 L .5074 .52901 L F
.50931 .52702 m .50848 .52802 L .50915 .52824 L .809 .541 .532 r
F
.5091 .52822 m .51044 .52676 L .50824 .52794 L .675 .735 .895 r
F
.5106 .51468 m .50955 .52711 L .51036 .52775 L .909 .63 .5 r
F
.51044 .52676 m .51073 .52234 L .50895 .52634 L .675 .735 .895 r
F
.50902 .52916 m .51081 .52514 L .50757 .52484 L F
.51087 .52799 m .5078 .52351 L .50763 .52768 L F
.50781 .53358 m .50856 .5156 L .50692 .53362 L .654 .726 .902 r
F
.5037 .53488 m .50254 .53462 L .50268 .53552 L F
.50729 .53603 m .50194 .53391 L .50127 .53492 L .675 .735 .895 r
F
.50702 .53361 m .50688 .54066 L .50714 .53361 L .66 .417 .541 r
F
.50729 .54306 m .50624 .5453 L .50719 .54549 L .654 .726 .902 r
F
.50688 .54066 m .5063 .57205 L .50705 .54066 L .66 .417 .541 r
F
.50217 .53401 m .50297 .53306 L .50194 .53391 L .675 .735 .895 r
F
.50729 .53603 m .50409 .53383 L .50217 .53401 L F
.50409 .53383 m .50297 .53306 L .50217 .53401 L F
.50688 .54066 m .50705 .54066 L .50722 .53354 L .66 .417 .541 r
F
.50714 .53355 m .50722 .53354 L .50739 .52655 L F
.50688 .54066 m .50722 .53354 L .50714 .53355 L F
.5038 .5466 m .50386 .54743 L .50617 .54545 L .654 .726 .902 r
F
.50428 .54438 m .50463 .5447 L .50464 .5763 L .929 .648 .488 r
F
.50468 .5413 m .50408 .57317 L .50485 .54119 L .401 .213 .507 r
F
.50497 .53782 m .50509 .54492 L .50479 .53773 L .845 .571 .524 r
F
.50468 .5413 m .50485 .54119 L .50502 .53404 L .401 .213 .507 r
F
.50273 .54254 m .50186 .54184 L .50024 .54226 L .654 .726 .902 r
F
.50332 .54217 m .50186 .54184 L .50273 .54254 L F
.50186 .54184 m .49831 .54103 L .50024 .54226 L F
.50729 .54306 m .50411 .54489 L .50527 .54511 L F
.50509 .54492 m .50562 .57677 L .50494 .54485 L .845 .571 .524 r
F
.50509 .54492 m .50562 .54518 L .50562 .57677 L F
.50579 .54082 m .5052 .54097 L .5052 .57238 L .568 .343 .534 r
F
.50497 .53782 m .50562 .5383 L .50497 .538 L .845 .571 .524 r
F
.50729 .53603 m .50454 .5378 L .50534 .53817 L .675 .735 .895 r
F
.50597 .53092 m .5052 .54097 L .50579 .54082 L .568 .343 .534 r
F
.50739 .53353 m .50705 .54066 L .50739 .54064 L .66 .417 .541 r
F
.50722 .53354 m .50705 .54066 L .50739 .53353 L F
.50705 .54066 m .5063 .57205 L .50739 .54064 L F
.49195 .54131 m .47719 .53626 L .47638 .53952 L .654 .726 .902 r
F
.49507 .53812 m .49072 .5422 L .49624 .54014 L .675 .735 .895 r
F
.49507 .53812 m .48896 .53917 L .49072 .5422 L F
.49831 .54103 m .47719 .53626 L .49195 .54131 L .654 .726 .902 r
F
.48999 .54216 m .47638 .53952 L .47591 .54142 L F
.50502 .53404 m .50485 .54119 L .5052 .53393 L .401 .213 .507 r
F
.50485 .54119 m .50408 .57317 L .50499 .5411 L F
.50485 .54119 m .50499 .5411 L .5052 .53393 L F
.50729 .54306 m .50231 .5428 L .50249 .54364 L .654 .726 .902 r
F
.50231 .5428 m .50062 .54271 L .50165 .54322 L F
.50231 .5428 m .50165 .54322 L .50249 .54364 L F
.50062 .54271 m .47591 .54142 L .50249 .54364 L F
.5052 .54097 m .50408 .57317 L .5052 .57238 L .401 .213 .507 r
F
.5052 .53393 m .50499 .5411 L .5052 .54097 L F
.50499 .5411 m .50408 .57317 L .5052 .54097 L F
.5036 .54343 m .50379 .55289 L .5036 .56971 L .989 .72 .386 r
F
.50368 .54358 m .50379 .55289 L .5036 .54343 L F
.50399 .53479 m .50391 .54198 L .50408 .53464 L 0 0 .377 r
F
.50377 .54374 m .50398 .57571 L .50371 .54364 L .989 .72 .386 r
F
.50391 .54198 m .50355 .5742 L .50398 .54186 L 0 0 .377 r
F
.50377 .54374 m .50397 .54411 L .50398 .57571 L .989 .72 .386 r
F
.50379 .55289 m .50398 .57571 L .5036 .56971 L F
.5036 .56971 m .50398 .57571 L .5036 .57501 L F
.50408 .54168 m .50355 .5742 L .50408 .57317 L 0 0 .377 r
F
.50398 .54186 m .50355 .5742 L .50408 .54168 L F
.50357 .54301 m .5036 .57501 L .50356 .54289 L .783 .625 .063 r
F
.49829 .55219 m .49088 .5597 L .4976 .55344 L .654 .726 .902 r
F
.5039 .53497 m .50383 .54213 L .50399 .53479 L 0 0 .377 r
F
.50383 .54213 m .50355 .5742 L .50391 .54198 L F
.50356 .54289 m .5036 .57501 L .50356 .54279 L .783 .625 .063 r
F
.5039 .53497 m .50355 .5356 L .50355 .54265 L 0 0 .377 r
F
.50355 .54265 m .5036 .57501 L .50355 .5742 L .783 .625 .063 r
F
.50356 .54279 m .5036 .57501 L .50355 .54265 L F
.50357 .54301 m .5036 .54343 L .5036 .57501 L F
.50383 .54213 m .50355 .54265 L .50355 .5742 L 0 0 .377 r
F
.4976 .55344 m .49088 .5597 L .49366 .56059 L .654 .726 .902 r
F
.4976 .55344 m .49366 .56059 L .49836 .56211 L F
.51011 .54164 m .50955 .5412 L .50956 .57246 L .909 .63 .5 r
F
.50997 .54152 m .51618 .54027 L .53009 .52996 L .654 .726 .902 r
F
.51061 .54202 m .51618 .54027 L .50997 .54152 L F
.51618 .54027 m .5349 .5344 L .53015 .53002 L F
.51618 .54027 m .53015 .53002 L .53009 .52996 L F
.51118 .54394 m .53738 .54987 L .51204 .54331 L F
.51012 .54472 m .51051 .57583 L .51002 .5448 L .358 .18 .498 r
F
.50955 .51385 m .50931 .52702 L .50955 .52711 L .809 .541 .532 r
F
.51011 .54164 m .50956 .57246 L .51028 .54176 L .909 .63 .5 r
F
.51061 .54202 m .50956 .57246 L .51061 .57329 L F
.51028 .54176 m .50956 .57246 L .51061 .54202 L F
.51452 .54507 m .53404 .55457 L .53646 .55116 L .654 .726 .902 r
F
.51767 .54753 m .53404 .55457 L .51452 .54507 L F
.5293 .5512 m .56118 .55879 L .53446 .54729 L F
.52606 .54731 m .53646 .55116 L .53738 .54987 L F
.50955 .5412 m .50848 .57209 L .50956 .57246 L .809 .541 .532 r
F
.50729 .54306 m .51008 .54506 L .5105 .54444 L .654 .726 .902 r
F
.50935 .54112 m .50848 .57209 L .50955 .5412 L .809 .541 .532 r
F
.5107 .54415 m .51094 .54381 L .51094 .57514 L .076 0 .415 r
F
.51085 .54256 m .51061 .57329 L .51097 .54285 L .984 .727 .339 r
F
.51099 .54345 m .51105 .54303 L .51106 .57433 L 0 0 .142 r
F
.51099 .54345 m .51106 .57433 L .51097 .54357 L F
.51097 .54357 m .51106 .57433 L .51096 .54366 L F
.51094 .54381 m .51106 .57433 L .51094 .57514 L F
.51096 .54366 m .51106 .57433 L .51094 .54381 L F
.51105 .54303 m .51061 .57329 L .51106 .57433 L .984 .727 .339 r
F
.51097 .54285 m .51061 .57329 L .51105 .54303 L F
.51085 .54256 m .51061 .54202 L .51061 .57329 L F
.51068 .54549 m .52224 .56134 L .52887 .55848 L .654 .726 .902 r
F
.51063 .5458 m .52224 .56134 L .51068 .54549 L F
.50838 .52289 m .51704 .50953 L .50898 .50843 L F
.51105 .51572 m .5106 .51468 L .5106 .52793 L .984 .727 .339 r
F
.50954 .52553 m .51704 .50953 L .50838 .52289 L .654 .726 .902 r
F
.51046 .54694 m .51459 .56296 L .52224 .56134 L F
.63257 .79231 m .63446 .77894 L .63496 .78351 L 0 0 .395 r
F
.63307 .79688 m .63257 .79231 L .63496 .78351 L F
.61461 .79038 m .63257 .79231 L .63496 .78351 L .683 .77 .917 r
F
0 g
.5 Mabswid
.62876 .7976 m
.63257 .79231 L
s
.127 .923 .03 r
.34487 .51504 m
.34502 .53983 L
s
.72021 .67024 m .69419 .67463 L .71913 .67417 L .673 .758 .914 r
F
.56134 .5514 m .5979 .54882 L .56799 .54205 L .654 .726 .902 r
F
.53475 .53996 m .56134 .5514 L .56799 .54205 L F
.79456 .67846 m .81778 .66626 L .79332 .67063 L .673 .758 .914 r
F
.76949 .67892 m .79456 .67846 L .79332 .67063 L F
.27712 .6686 m .25316 .66513 L .25015 .67691 L .673 .757 .914 r
F
.25309 .67074 m .24978 .67691 L .25007 .68258 L 0 0 .312 r
F
0 g
.25049 .68091 m
.25079 .68257 L
s
.25309 .67074 m .2528 .66507 L .24978 .67691 L 0 0 .312 r
F
.127 .923 .03 r
.2476 .59826 m
.24989 .67419 L
s
.32533 .6812 m .31944 .66665 L .31332 .66828 L .673 .757 .914 r
F
.32533 .6812 m .32596 .66602 L .31944 .66665 L F
0 g
.32242 .68342 m
.32243 .68047 L
s
.32533 .6812 m .33243 .66641 L .32596 .66602 L .673 .757 .914 r
F
.69997 .55997 m .68042 .56128 L .68002 .56855 L .494 .288 .528 r
F
0 g
.66448 .58027 m
.68002 .56855 L
s
.69997 .55997 m .70037 .55269 L .68042 .56128 L .494 .288 .528 r
F
0 g
.66488 .573 m
.68042 .56128 L
s
.40088 .68549 m .39853 .66808 L .39884 .67375 L .835 .63 .083 r
F
.3758 .68595 m .40088 .68549 L .39884 .67375 L .673 .758 .914 r
F
0 g
.39779 .69732 m
.40088 .68549 L
s
.127 .923 .03 r
.34552 .6214 m
.34555 .62674 L
s
.4126 .91817 m .4066 .91122 L .40131 .91333 L .644 .733 .913 r
F
.41566 .91759 m .4066 .91122 L .4126 .91817 L F
.32732 .5763 m .32803 .55616 L .3036 .55695 L .654 .726 .902 r
F
0 0 0 r
2.5 Mabswid
.80929 .57959 Mdot
.127 .923 .03 r
.5 Mabswid
.40415 8.8262 m
.75955 1.59204 L
s
.42514 .9189 m .42569 .91082 L .42215 .91797 L .644 .733 .913 r
F
.42514 .9189 m .43168 .91269 L .42569 .91082 L F
.59322 .68532 m .58108 .66934 L .5803 .68452 L .673 .758 .914 r
F
.59322 .68532 m .60048 .67053 L .58108 .66934 L F
.61108 .80055 m .63307 .79688 L .61511 .79494 L .683 .771 .917 r
F
.59513 .79581 m .61108 .80055 L .61511 .79494 L F
.59203 .79829 m .61108 .80055 L .59513 .79581 L F
.81343 .56824 m .79484 .55034 L .79445 .55762 L .858 .601 .548 r
F
.81305 .57551 m .81343 .56824 L .79445 .55762 L F
0 g
.81343 .56824 m
.82771 .58152 L
s
.73011 .575 m .72296 .55512 L .69997 .55997 L .654 .726 .902 r
F
.74641 .57447 m .72296 .55512 L .73011 .575 L F
.76257 .57669 m .74742 .55433 L .74641 .57447 L F
.76257 .57669 m .77168 .55767 L .74742 .55433 L F
.3493 .67118 m .3689 .65963 L .34696 .66758 L .673 .757 .914 r
F
.3493 .67118 m .37358 .66683 L .3689 .65963 L F
.4097 .92299 m .40106 .9171 L .39694 .92001 L .644 .733 .913 r
F
.41235 .92193 m .40106 .9171 L .4097 .92299 L F
.69632 .66677 m .66924 .67508 L .69419 .67463 L .673 .758 .914 r
F
.72021 .67024 m .69632 .66677 L .69419 .67463 L F
.76949 .67892 m .79332 .67063 L .76887 .67501 L F
.42743 .92403 m .43143 .91646 L .42488 .92267 L .644 .733 .913 r
F
.42743 .92403 m .43652 .91918 L .43143 .91646 L F
0 0 0 r
2.5 Mabswid
.42939 .9241 Mdot
.127 .923 .03 r
.5 Mabswid
.39709 8.82802 m
.42847 1.14945 L
s
.41566 .91759 m .41271 .91006 L .4066 .91122 L .644 .733 .913 r
F
.41891 .91752 m .41271 .91006 L .41566 .91759 L F
.30126 .67772 m .27516 .68212 L .30024 .68166 L .673 .757 .914 r
F
.42215 .91797 m .41922 .90992 L .41891 .91752 L .644 .733 .913 r
F
.42215 .91797 m .42569 .91082 L .41922 .90992 L F
.3758 .68595 m .39884 .67375 L .37443 .67812 L .673 .758 .914 r
F
.35071 .68641 m .3758 .68595 L .37443 .67812 L F
.18528 .53852 m .20494 .54188 L .20447 .54915 L .857 .601 .551 r
F
.18528 .53852 m .18576 .53125 L .20494 .54188 L F
0 g
.20494 .54188 m
.20998 .5435 L
s
.40131 .91333 m .3865 .91181 L .3972 .91624 L .644 .733 .913 r
F
.39694 .92001 m .38624 .91557 L .38226 .92085 L F
0 g
.38075 .92667 m
.38226 .92085 L
s
.55533 .69472 m .54345 .68181 L .5275 .68933 L .673 .758 .915 r
F
.56758 .69147 m .54345 .68181 L .55533 .69472 L F
.56726 .6858 m .56151 .67125 L .54313 .67613 L .673 .758 .914 r
F
.5803 .68452 m .56151 .67125 L .56726 .6858 L F
.127 .923 .03 r
.5702 .65653 m
.57031 .65122 L
s
.57102 .65623 m
.57107 .65094 L
s
0 g
.26264 .5666 m
.26394 .56656 L
s
.23524 .54461 m .25078 .56698 L .25143 .54683 L .654 .726 .902 r
F
.23524 .54461 m .2265 .56365 L .25078 .56698 L F
0 g
.25078 .56698 m
.26264 .5666 L
s
.41891 .91752 m .41922 .90992 L .41271 .91006 L .644 .733 .913 r
F
0 g
.31592 .53946 m
.31881 .53821 L
s
.30952 .54224 m
.31592 .53946 L
s
.44062 .91879 m .44586 .91056 L .43677 .91541 L .644 .733 .913 r
F
.44062 .91879 m .45164 .91563 L .44586 .91056 L F
.2086 .51801 m .20519 .54163 L .22133 .52507 L .654 .726 .902 r
F
.2086 .51801 m .1861 .53105 L .20519 .54163 L F
.45491 .92511 m .45164 .91563 L .45139 .9194 L .989 .751 .48 r
F
0 g
.45491 .92511 m
.45594 .93108 L
s
.56041 .79037 m .54561 .79944 L .56215 .79297 L .683 .77 .917 r
F
.56041 .79037 m .54214 .79423 L .54561 .79944 L F
.69632 .66677 m .67243 .6633 L .66924 .67508 L .673 .758 .914 r
F
.67241 .66892 m .66886 .67509 L .6692 .68076 L 0 0 .332 r
F
0 g
.66957 .67939 m
.66979 .68075 L
s
.67241 .66892 m .67207 .66325 L .66886 .67509 L 0 0 .332 r
F
.74442 .67938 m .73877 .66483 L .73264 .66646 L .673 .758 .914 r
F
.74442 .67938 m .7453 .66419 L .73877 .66483 L F
.74442 .67938 m .75176 .66459 L .7453 .66419 L F
.81998 .68367 m .81778 .66626 L .81813 .67193 L .812 .611 .054 r
F
.79491 .68413 m .81998 .68367 L .81813 .67193 L .673 .758 .915 r
F
0 g
.8167 .69549 m
.81998 .68367 L
s
.61394 .78579 m .63418 .77896 L .61552 .77995 L .683 .77 .917 r
F
.59606 .78387 m .61394 .78579 L .61552 .77995 L F
.59406 .78665 m .61394 .78579 L .59606 .78387 L F
.74641 .57447 m .74742 .55433 L .72296 .55512 L .654 .726 .902 r
F
.5803 .68452 m .58108 .66934 L .56151 .67125 L .673 .758 .914 r
F
.63359 .68171 m .61806 .66908 L .61839 .67475 L .859 .596 .539 r
F
.127 .923 .03 r
.63243 .67286 m
.63251 .66758 L
s
.63162 .67315 m
.63177 .66785 L
s
.63392 .68738 m .63359 .68171 L .61839 .67475 L .859 .596 .539 r
F
0 g
.63359 .68171 m
.64504 .69091 L
s
.27718 .67423 m .25007 .68258 L .27516 .68212 L .673 .757 .914 r
F
.30126 .67772 m .27718 .67423 L .27516 .68212 L F
.35071 .68641 m .37443 .67812 L .35002 .6825 L .673 .758 .914 r
F
.63307 .79688 m .63496 .78351 L .63547 .78808 L 0 0 .395 r
F
.61511 .79494 m .63307 .79688 L .63547 .78808 L .683 .771 .917 r
F
0 g
.62701 .80528 m
.63307 .79688 L
s
.41235 .92193 m .40635 .91499 L .40106 .9171 L .644 .733 .913 r
F
.4154 .92135 m .40635 .91499 L .41235 .92193 L F
.42488 .92267 m .42544 .91459 L .42189 .92173 L F
.42488 .92267 m .43143 .91646 L .42544 .91459 L F
.7684 .66936 m .78818 .6578 L .76612 .66576 L .673 .758 .914 r
F
.7684 .66936 m .79273 .66501 L .78818 .6578 L F
.30372 .66838 m .27712 .6686 L .30108 .67207 L .673 .757 .914 r
F
0 g
.26378 .56913 m
.2807 .5618 L
s
.2609 .57038 m
.26378 .56913 L
s
.40165 .90962 m .39305 .90376 L .38691 .90811 L .644 .733 .913 r
F
.40692 .90752 m .39305 .90376 L .40165 .90962 L F
.72042 .67589 m .69427 .6803 L .71935 .67984 L .673 .758 .914 r
F
.79491 .68413 m .81813 .67193 L .79367 .6763 L .673 .758 .915 r
F
.76983 .68459 m .79491 .68413 L .79367 .6763 L F
.39391 .57734 m .37523 .55945 L .37479 .56672 L .857 .601 .55 r
F
0 g
.39391 .57734 m
.40838 .59062 L
s
.43693 .9117 m .43838 .90281 L .43187 .90899 L .644 .733 .913 r
F
.43693 .9117 m .44598 .90687 L .43838 .90281 L F
.25338 .67642 m .25007 .68258 L .25036 .68825 L 0 0 .312 r
F
0 g
.25079 .68658 m
.25108 .68824 L
s
.27718 .67423 m .25309 .67074 L .25007 .68258 L .673 .757 .914 r
F
.25338 .67642 m .25309 .67074 L .25007 .68258 L 0 0 .312 r
F
.32563 .68687 m .31974 .67232 L .31362 .67395 L .673 .758 .914 r
F
.32563 .68687 m .32626 .67169 L .31974 .67232 L F
.32563 .68687 m .33273 .67209 L .32626 .67169 L F
.4154 .92135 m .41246 .91382 L .40635 .91499 L .644 .733 .913 r
F
.41866 .92128 m .41246 .91382 L .4154 .92135 L F
.42189 .92173 m .41897 .91369 L .41866 .92128 L F
.42189 .92173 m .42544 .91459 L .41897 .91369 L F
.54313 .67613 m .52687 .67799 L .52719 .68366 L .517 .331 .568 r
F
.54313 .67613 m .54281 .67046 L .52687 .67799 L F
0 g
.51445 .68764 m
.52687 .67799 L
s
.59355 .69099 m .5814 .67501 L .58062 .69019 L .673 .758 .915 r
F
.59355 .69099 m .6008 .67621 L .5814 .67501 L F
.40106 .9171 m .38624 .91557 L .39694 .92001 L .644 .733 .913 r
F
.41866 .92128 m .41897 .91369 L .41246 .91382 L F
.22023 .53979 m .2265 .56365 L .23524 .54461 L .654 .726 .902 r
F
.22023 .53979 m .204 .55642 L .2265 .56365 L F
0 g
.2265 .56365 m
.25078 .56698 L
s
.44037 .92256 m .44561 .91433 L .43652 .91918 L .644 .733 .913 r
F
.44037 .92256 m .45139 .9194 L .44561 .91433 L F
.39266 .90744 m .38675 .90804 L .3865 .91181 L .353 .179 .501 r
F
.39266 .90744 m .39292 .90367 L .38675 .90804 L F
0 g
.38278 .91332 m
.38675 .90804 L
s
.52239 .7895 m .52338 .79353 L .52387 .7981 L .775 .561 0 r
F
.52239 .7895 m .5219 .78493 L .52338 .79353 L F
0 g
.52338 .79353 m
.52611 .79762 L
s
.54085 .78392 m .52365 .79347 L .54183 .78963 L .683 .77 .917 r
F
.54085 .78392 m .52218 .78492 L .52365 .79347 L F
.34972 .67683 m .36943 .66522 L .34737 .67321 L .673 .757 .914 r
F
.34972 .67683 m .37412 .67245 L .36943 .66522 L F
.4772 .53942 m .45257 .5531 L .48013 .54445 L .654 .726 .902 r
F
.4772 .53942 m .44669 .54306 L .45257 .5531 L F
.45164 .91563 m .45189 .91187 L .44612 .9068 L .925 .676 .544 r
F
0 g
.45189 .91187 m
.45542 .91758 L
s
.69642 .67241 m .6692 .68076 L .69427 .6803 L .673 .758 .914 r
F
.72042 .67589 m .69642 .67241 L .69427 .6803 L F
.76983 .68459 m .79367 .6763 L .76921 .68068 L .673 .758 .915 r
F
.30155 .68339 m .27545 .68779 L .30054 .68733 L .673 .758 .914 r
F
.56118 .55879 m .59794 .5562 L .56787 .5494 L .654 .726 .902 r
F
.53446 .54729 m .56118 .55879 L .56787 .5494 L F
.56091 .79494 m .54611 .804 L .56264 .79754 L .683 .771 .917 r
F
.56091 .79494 m .54264 .7988 L .54611 .804 L F
.41359 .53086 m .41664 .53942 L .4162 .54669 L .923 .743 .256 r
F
.41359 .53086 m .41403 .52359 L .41664 .53942 L F
0 g
.41664 .53942 m
.42059 .54616 L
s
.61461 .79038 m .63496 .78351 L .61621 .78451 L .683 .77 .917 r
F
.59665 .78844 m .61461 .79038 L .61621 .78451 L F
.59464 .79124 m .61461 .79038 L .59665 .78844 L F
.37358 .66683 m .39086 .65167 L .3689 .65963 L .673 .757 .914 r
F
.37358 .66683 m .39786 .66248 L .39086 .65167 L F
.32346 .78656 m .32298 .78199 L .3376 .78007 L .673 .454 .579 r
F
.30893 .78619 m .32298 .78199 L .32346 .78656 L .733 .498 .572 r
F
.30893 .78619 m .30846 .78162 L .32298 .78199 L F
.44572 .52525 m .41709 .53936 L .44743 .53575 L .654 .726 .902 r
F
.44572 .52525 m .4145 .52361 L .41709 .53936 L F
.56758 .69147 m .56184 .67692 L .54345 .68181 L .673 .758 .915 r
F
.58062 .69019 m .56184 .67692 L .56758 .69147 L F
.127 .923 .03 r
.57009 .66185 m
.5702 .65653 L
s
.57097 .66153 m
.57102 .65623 L
s
.72291 .66655 m .69632 .66677 L .72021 .67024 L .673 .758 .914 r
F
.32346 .77067 m .32299 .78183 L .33753 .77991 L .683 .77 .917 r
F
.31382 .77042 m .32299 .78183 L .32346 .77067 L F
.127 .923 .03 r
.24974 .71847 m
.2501 .73895 L
s
.31382 .77042 m .30854 .78146 L .32299 .78183 L .683 .77 .917 r
F
.127 .923 .03 r
.31997 .71433 m
.32119 .77061 L
s
.31997 .71433 m
.32049 .77059 L
s
.37523 .55945 m .37568 .55217 L .35321 .54495 L .793 .542 .558 r
F
0 g
.37568 .55217 m
.3948 .56279 L
s
.127 .923 .03 r
.3641 .52377 m
.36419 .54848 L
s
.59794 .5562 m .59835 .54892 L .60226 .53344 L 0 0 .15 r
F
0 g
.59382 .55527 m
.59835 .54892 L
s
.56799 .54205 m .5979 .54882 L .60179 .53341 L .654 .726 .902 r
F
.81305 .57551 m .79445 .55762 L .79406 .56489 L .858 .601 .548 r
F
0 g
.81305 .57551 m
.82733 .58879 L
s
.33808 .78464 m .3376 .78007 L .35132 .77599 L .607 .405 .583 r
F
.32346 .78656 m .3376 .78007 L .33808 .78464 L .673 .454 .579 r
F
0 g
.32298 .78199 m
.3376 .78007 L
s
.67274 .67459 m .6692 .68076 L .66953 .68643 L 0 0 .332 r
F
0 g
.6699 .68506 m
.67012 .68642 L
s
.69642 .67241 m .67241 .66892 L .6692 .68076 L .673 .758 .914 r
F
.67274 .67459 m .67241 .66892 L .6692 .68076 L 0 0 .332 r
F
.74476 .68505 m .74564 .66986 L .73911 .6705 L .673 .758 .915 r
F
.74476 .68505 m .7521 .67026 L .74564 .66986 L F
.40131 .91333 m .39266 .90744 L .3865 .91181 L .644 .733 .913 r
F
.4066 .91122 m .39266 .90744 L .40131 .91333 L F
.33316 .76939 m .33753 .77991 L .35119 .77585 L .683 .77 .917 r
F
.32346 .77067 m .33753 .77991 L .33316 .76939 L F
.34696 .66758 m .36124 .65351 L .34313 .66453 L .673 .757 .914 r
F
.34696 .66758 m .3689 .65963 L .36124 .65351 L F
.58062 .69019 m .5814 .67501 L .56184 .67692 L .673 .758 .915 r
F
.63392 .68738 m .61839 .67475 L .61872 .68043 L .859 .596 .539 r
F
0 g
.63392 .68738 m
.64537 .69658 L
s
.127 .923 .03 r
.63141 .73347 m
.63243 .67286 L
s
.62966 .74262 m
.63162 .67315 L
s
.27747 .6799 m .25036 .68825 L .27545 .68779 L .673 .758 .914 r
F
.30155 .68339 m .27747 .6799 L .27545 .68779 L F
.43677 .91541 m .43822 .90648 L .43168 .91269 L .644 .733 .913 r
F
.43677 .91541 m .44586 .91056 L .43822 .90648 L F
.76887 .67501 m .78875 .66339 L .76658 .67139 L .673 .758 .914 r
F
.76887 .67501 m .79332 .67063 L .78875 .66339 L F
.18481 .5458 m .20447 .54915 L .204 .55642 L .857 .601 .551 r
F
.18481 .5458 m .18528 .53852 L .20447 .54915 L F
.2079 .52542 m .20447 .54915 L .2207 .53251 L .654 .726 .902 r
F
.2079 .52542 m .18528 .53852 L .20447 .54915 L F
0 g
.20447 .54915 m
.20952 .55077 L
s
.30391 .67401 m .27718 .67423 L .30126 .67772 L .673 .757 .914 r
F
.39241 .9112 m .3865 .91181 L .38624 .91557 L .353 .179 .501 r
F
.39241 .9112 m .39266 .90744 L .3865 .91181 L F
0 g
.38252 .91708 m
.3865 .91181 L
s
.40692 .90752 m .40095 .90061 L .39305 .90376 L .644 .733 .913 r
F
.413 .90637 m .40095 .90061 L .40692 .90752 L F
.43187 .90899 m .42945 .90001 L .42591 .90713 L F
.43187 .90899 m .43838 .90281 L .42945 .90001 L F
.72076 .68156 m .69461 .68597 L .71969 .68551 L .673 .758 .915 r
F
.45164 .91563 m .44612 .9068 L .44586 .91056 L .925 .676 .544 r
F
.45139 .9194 m .45164 .91563 L .44586 .91056 L F
0 g
.45164 .91563 m
.45516 .92135 L
s
.127 .923 .03 r
.4514 .90578 m
.45254 1.10188 L
s
.52289 .79407 m .52387 .7981 L .52437 .80267 L .775 .561 0 r
F
.52289 .79407 m .52239 .7895 L .52387 .7981 L F
.54116 .7885 m .52387 .7981 L .54214 .79423 L .683 .77 .917 r
F
.54116 .7885 m .52239 .7895 L .52387 .7981 L F
0 g
.52387 .7981 m
.52661 .80219 L
s
.79273 .66501 m .81025 .64985 L .78818 .6578 L .673 .758 .914 r
F
.79273 .66501 m .81706 .66065 L .81025 .64985 L F
.72336 .54784 m .70077 .54542 L .70037 .55269 L .593 .369 .546 r
F
.72336 .54784 m .72375 .54057 L .70077 .54542 L F
0 g
.68082 .55401 m
.70077 .54542 L
s
.74264 .78474 m .74213 .78018 L .75676 .77826 L .673 .454 .58 r
F
.72815 .78437 m .74213 .78018 L .74264 .78474 L .733 .498 .571 r
F
.72815 .78437 m .72764 .77981 L .74213 .78018 L F
.55952 .78293 m .54183 .78963 L .56001 .78578 L .683 .77 .917 r
F
.55952 .78293 m .54085 .78392 L .54183 .78963 L F
.27747 .6799 m .25338 .67642 L .25036 .68825 L .673 .758 .914 r
F
0 g
.25036 .68825 m
.25247 .69998 L
s
.127 .923 .03 r
.42208 .83602 m
.42295 .56054 L
s
.7428 .76885 m .74214 .78001 L .75669 .7781 L .683 .771 .917 r
F
.73318 .7686 m .74214 .78001 L .7428 .76885 L F
.73318 .7686 m .72772 .77964 L .74214 .78001 L F
.54345 .68181 m .52719 .68366 L .5275 .68933 L .517 .331 .568 r
F
0 g
.51508 .69898 m
.5275 .68933 L
s
.54345 .68181 m .54313 .67613 L .52719 .68366 L .517 .331 .568 r
F
0 g
.51477 .69331 m
.52719 .68366 L
s
.79445 .55762 m .79484 .55034 L .77246 .54312 L .794 .542 .557 r
F
0 g
.79484 .55034 m
.81381 .56096 L
s
.83626 .5363 m
.85025 .55394 L
s
.59606 .78387 m .61552 .77995 L .59685 .78094 L .683 .77 .917 r
F
.29549 .78355 m .30846 .78162 L .30893 .78619 L .793 .542 .558 r
F
.29549 .78355 m .29502 .77899 L .30846 .78162 L F
0 g
.30846 .78162 m
.32298 .78199 L
s
.75727 .78282 m .75676 .77826 L .77053 .77417 L .607 .406 .584 r
F
.74264 .78474 m .75676 .77826 L .75727 .78282 L .673 .454 .58 r
F
0 g
.74213 .78018 m
.75676 .77826 L
s
.61511 .79494 m .63547 .78808 L .61671 .78907 L .683 .771 .917 r
F
.59715 .79301 m .61511 .79494 L .61671 .78907 L F
.59513 .79581 m .61511 .79494 L .59715 .79301 L F
.32393 .79113 m .32346 .78656 L .33808 .78464 L .673 .454 .579 r
F
.30941 .79075 m .32346 .78656 L .32393 .79113 L .733 .498 .572 r
F
.30941 .79075 m .30893 .78619 L .32346 .78656 L F
.32393 .77535 m .32346 .78656 L .33808 .78464 L .683 .77 .917 r
F
.31424 .7751 m .32346 .78656 L .32393 .77535 L F
.127 .923 .03 r
.2501 .73895 m
.25018 .74321 L
s
.31424 .7751 m .30893 .78619 L .32346 .78656 L .683 .77 .917 r
F
.3049 .76867 m .30854 .78146 L .31382 .77042 L F
.3049 .76867 m .29516 .77883 L .30854 .78146 L F
.35002 .6825 m .36973 .67089 L .34767 .67888 L .673 .758 .914 r
F
.35002 .6825 m .37443 .67812 L .36973 .67089 L F
.30372 .66838 m .2824 .66121 L .27712 .6686 L .673 .757 .914 r
F
.30782 .66517 m .2824 .66121 L .30372 .66838 L F
.127 .923 .03 r
.52609 .75516 m
.52628 .70202 L
s
.49806 8.79983 m
.52579 .84274 L
s
.52628 .70202 m
.52631 .69158 L
s
.3989 8.82664 m
.49347 2.78836 L
s
.52531 .75547 m
.52615 .70167 L
s
.49347 2.78836 m
.52419 .82684 L
s
.52615 .70167 m
.52631 .69158 L
s
.7525 .76758 m .75669 .7781 L .77039 .77404 L .683 .771 .917 r
F
.7428 .76885 m .75669 .7781 L .7525 .76758 L F
.76612 .66576 m .78062 .65168 L .76234 .6627 L .673 .758 .914 r
F
.76612 .66576 m .78818 .6578 L .78062 .65168 L F
.69676 .67808 m .66953 .68643 L .69461 .68597 L .673 .758 .915 r
F
.72076 .68156 m .69676 .67808 L .69461 .68597 L F
.40106 .9171 m .39241 .9112 L .38624 .91557 L .644 .733 .913 r
F
.127 .923 .03 r
.38625 .88462 m
.38771 2.04339 L
s
0 g
.38226 .92085 m
.38624 .91557 L
s
.40635 .91499 m .39241 .9112 L .40106 .9171 L .644 .733 .913 r
F
.43652 .91918 m .43797 .91025 L .43143 .91646 L F
.43652 .91918 m .44561 .91433 L .43797 .91025 L F
.33808 .78464 m .35132 .77599 L .3518 .78056 L .607 .405 .583 r
F
.33856 .7892 m .33808 .78464 L .3518 .78056 L F
.32393 .79113 m .33808 .78464 L .33856 .7892 L .673 .454 .579 r
F
.33368 .77407 m .33808 .78464 L .3518 .78056 L .683 .77 .917 r
F
.32393 .77535 m .33808 .78464 L .33368 .77407 L F
0 g
.32346 .78656 m
.33808 .78464 L
s
.37412 .67245 m .3915 .65722 L .36943 .66522 L .673 .757 .914 r
F
.37412 .67245 m .39853 .66808 L .3915 .65722 L F
.25313 .42333 m .2544 .48161 L .25282 .48181 L .641 .401 .539 r
F
.25313 .42333 m .25472 .42312 L .2544 .48161 L F
.25156 .42306 m .25313 .42333 L .25282 .48181 L .751 .491 .539 r
F
0 g
.25313 .42333 m
.25313 .42333 L
s
.72314 .67219 m .69642 .67241 L .72042 .67589 L .673 .758 .914 r
F
.413 .90637 m .41007 .89887 L .40095 .90061 L .644 .733 .913 r
F
.41948 .90623 m .41007 .89887 L .413 .90637 L F
.42591 .90713 m .41979 .89867 L .41948 .90623 L F
.42591 .90713 m .42945 .90001 L .41979 .89867 L F
.25472 .42312 m .25542 .48117 L .2544 .48161 L .515 .301 .526 r
F
.25472 .42312 m .25574 .42268 L .25542 .48117 L F
0 g
.25313 .42333 m
.25472 .42312 L
s
.25156 .42306 m .25282 .48181 L .25125 .48155 L .751 .491 .539 r
F
.25058 .42259 m .25156 .42306 L .25125 .48155 L .844 .571 .525 r
F
0 g
.25156 .42306 m
.25313 .42333 L
s
.63496 .78351 m .63446 .77894 L .63302 .77034 L .768 .555 0 r
F
0 g
.6332 .7836 m
.63435 .77936 L
s
.61552 .77995 m .63418 .77896 L .63274 .7704 L .683 .77 .917 r
F
.4066 .91122 m .4006 .90427 L .39266 .90744 L .644 .733 .913 r
F
.41271 .91006 m .4006 .90427 L .4066 .91122 L F
.43168 .91269 m .42925 .90367 L .42569 .91082 L F
.43168 .91269 m .43822 .90648 L .42925 .90367 L F
.39853 .66808 m .39823 .66241 L .39119 .65155 L .987 .712 .386 r
F
0 g
.39823 .66241 m
.40027 .67415 L
s
.69676 .67808 m .67274 .67459 L .66953 .68643 L .673 .758 .915 r
F
0 g
.66953 .68643 m
.67145 .69816 L
s
.45139 .9194 m .44586 .91056 L .44561 .91433 L .925 .676 .544 r
F
0 g
.45139 .9194 m
.45491 .92511 L
s
.25574 .42268 m .25612 .4806 L .25542 .48117 L .353 .175 .495 r
F
.25574 .42268 m .25644 .42211 L .25612 .4806 L F
0 g
.25472 .42312 m
.25574 .42268 L
s
.3518 .78056 m .35132 .77599 L .36322 .77002 L .523 .345 .581 r
F
0 g
.34462 .77798 m
.35132 .77599 L
s
.34737 .67321 m .36172 .65907 L .34352 .67014 L .673 .757 .914 r
F
.34737 .67321 m .36943 .66522 L .36172 .65907 L F
.41948 .90623 m .41979 .89867 L .41007 .89887 L .644 .733 .913 r
F
.25058 .42259 m .25125 .48155 L .25026 .48107 L .844 .571 .525 r
F
.24991 .42199 m .25058 .42259 L .25026 .48107 L .927 .648 .491 r
F
0 g
.25058 .42259 m
.25156 .42306 L
s
.2824 .66121 m .25316 .66513 L .27712 .6686 L .673 .757 .914 r
F
.61839 .67475 m .61806 .66908 L .60015 .66486 L .794 .544 .56 r
F
0 g
.61806 .66908 m
.63326 .67604 L
s
.47677 .5467 m .45214 .56038 L .4797 .55172 L .654 .726 .902 r
F
.47677 .5467 m .44626 .55033 L .45214 .56038 L F
.34227 .76668 m .35119 .77585 L .36302 .76992 L .683 .77 .917 r
F
.33316 .76939 m .35119 .77585 L .34227 .76668 L F
.71477 .78173 m .72764 .77981 L .72815 .78437 L .794 .542 .557 r
F
.71477 .78173 m .71426 .77717 L .72764 .77981 L F
.127 .923 .03 r
.72475 .77924 m
.7272 .71811 L
s
0 g
.72764 .77981 m
.74213 .78018 L
s
.54165 .79307 m .52437 .80267 L .54264 .7988 L .683 .771 .917 r
F
.127 .923 .03 r
.52518 .764 m
.52531 .75547 L
s
.52606 .76365 m
.52609 .75516 L
s
.54165 .79307 m .52289 .79407 L .52437 .80267 L .683 .771 .917 r
F
0 g
.52437 .80267 m
.52958 .81047 L
s
.55992 .7875 m .54214 .79423 L .56041 .79037 L .683 .77 .917 r
F
.55992 .7875 m .54116 .7885 L .54214 .79423 L F
0 0 0 r
2.5 Mabswid
.3743 .67975 Mdot
.56076 .56606 m .59752 .56347 L .56746 .55667 L .654 .726 .902 r
F
.53404 .55457 m .56076 .56606 L .56746 .55667 L F
.52887 .55848 m .56076 .56606 L .53404 .55457 L F
.74315 .78931 m .74264 .78474 L .75727 .78282 L .673 .454 .58 r
F
.72866 .78894 m .74264 .78474 L .74315 .78931 L .733 .498 .571 r
F
.72866 .78894 m .72815 .78437 L .74264 .78474 L F
.7433 .77353 m .74264 .78474 L .75727 .78282 L .683 .771 .917 r
F
.73363 .77328 m .74264 .78474 L .7433 .77353 L F
.73363 .77328 m .72815 .78437 L .74264 .78474 L F
.7243 .76685 m .72772 .77964 L .73318 .7686 L F
.127 .923 .03 r
.5 Mabswid
.72579 .76715 m
.7272 .71811 L
s
.7243 .76685 m .71441 .77701 L .72772 .77964 L .683 .771 .917 r
F
.127 .923 .03 r
.72544 .77937 m
.72545 .77919 L
s
.76921 .68068 m .78909 .66907 L .76692 .67706 L .673 .758 .915 r
F
.76921 .68068 m .79367 .6763 L .78909 .66907 L F
.72291 .66655 m .70172 .65939 L .69632 .66677 L .673 .758 .914 r
F
.72705 .66335 m .70172 .65939 L .72291 .66655 L F
.41315 .53814 m .4162 .54669 L .41576 .55396 L .923 .743 .256 r
F
.41315 .53814 m .41359 .53086 L .4162 .54669 L F
.44497 .5325 m .4162 .54669 L .44669 .54306 L .654 .726 .902 r
F
.44497 .5325 m .41359 .53086 L .4162 .54669 L F
0 g
.4162 .54669 m
.42015 .55344 L
s
.25644 .42211 m .25655 .47991 L .25612 .4806 L .065 0 .408 r
F
.25644 .42211 m .25686 .42143 L .25655 .47991 L F
0 g
.25574 .42268 m
.25644 .42211 L
s
.30421 .67968 m .27747 .6799 L .30155 .68339 L .673 .758 .914 r
F
.24991 .42199 m .25026 .48107 L .24959 .48048 L .927 .648 .491 r
F
.24953 .42129 m .24991 .42199 L .24959 .48048 L .989 .721 .393 r
F
0 g
.24991 .42199 m
.25058 .42259 L
s
.61552 .77995 m .63274 .7704 L .61456 .77424 L .683 .77 .917 r
F
.59685 .78094 m .61552 .77995 L .61456 .77424 L F
.59665 .78844 m .61621 .78451 L .59745 .78551 L F
.34313 .66453 m .3511 .64889 L .33806 .66222 L .673 .757 .914 r
F
.34313 .66453 m .36124 .65351 L .3511 .64889 L F
.37523 .55945 m .35321 .54495 L .35276 .55222 L .793 .542 .558 r
F
.37479 .56672 m .37523 .55945 L .35276 .55222 L F
0 g
.37523 .55945 m
.39435 .57007 L
s
.127 .923 .03 r
.36421 .55479 m
.36422 .55585 L
s
.29597 .78812 m .30893 .78619 L .30941 .79075 L .793 .542 .558 r
F
.29597 .78812 m .29549 .78355 L .30893 .78619 L F
.30528 .77334 m .30893 .78619 L .31424 .7751 L .683 .77 .917 r
F
.30528 .77334 m .29549 .78355 L .30893 .78619 L F
0 g
.30893 .78619 m
.32346 .78656 L
s
.75727 .78282 m .77053 .77417 L .77104 .77874 L .607 .406 .584 r
F
.75778 .78739 m .75727 .78282 L .77104 .77874 L F
.74315 .78931 m .75727 .78282 L .75778 .78739 L .673 .454 .58 r
F
.75306 .77225 m .75727 .78282 L .77104 .77874 L .683 .771 .917 r
F
.127 .923 .03 r
.80274 .71291 m
.80295 .70861 L
s
.7433 .77353 m .75727 .78282 L .75306 .77225 L .683 .771 .917 r
F
0 g
.74264 .78474 m
.75727 .78282 L
s
.59794 .5562 m .60226 .53344 L .60185 .54071 L 0 0 .15 r
F
.59752 .56347 m .59794 .5562 L .60185 .54071 L F
.56787 .5494 m .59794 .5562 L .60185 .54071 L .654 .726 .902 r
F
0 g
.59341 .56254 m
.59794 .5562 L
s
.32441 .77991 m .32393 .79113 L .33856 .7892 L .683 .77 .917 r
F
.31472 .77967 m .32393 .79113 L .32441 .77991 L F
.127 .923 .03 r
.25018 .74321 m
.25025 .74747 L
s
.31472 .77967 m .30941 .79075 L .32393 .79113 L .683 .77 .917 r
F
.4006 .90427 m .39292 .90367 L .39266 .90744 L .501 .301 .54 r
F
.4006 .90427 m .40086 .90051 L .39292 .90367 L F
0 g
.38675 .90804 m
.39292 .90367 L
s
.79332 .67063 m .81093 .6554 L .78875 .66339 L .673 .758 .914 r
F
.79332 .67063 m .81778 .66626 L .81093 .6554 L F
.25686 .42143 m .25666 .4791 L .25655 .47991 L 0 0 .125 r
F
.25686 .42143 m .25697 .42061 L .25666 .4791 L F
0 g
.25644 .42211 m
.25686 .42143 L
s
.44586 .91056 m .44612 .9068 L .43848 .90272 L .855 .609 .565 r
F
0 g
.44612 .9068 m
.45189 .91187 L
s
.24953 .42129 m .24959 .48048 L .24921 .47978 L .989 .721 .393 r
F
.24947 .42048 m .24953 .42129 L .24921 .47978 L .798 .638 .081 r
F
0 g
.24953 .42129 m
.24991 .42199 L
s
.33856 .7892 m .3518 .78056 L .35228 .78512 L .607 .405 .583 r
F
.33416 .77863 m .33856 .7892 L .35228 .78512 L .683 .77 .917 r
F
.32441 .77991 m .33856 .7892 L .33416 .77863 L F
0 g
.32393 .79113 m
.33856 .7892 L
s
.41271 .91006 m .40977 .90253 L .4006 .90427 L .644 .733 .913 r
F
.41922 .90992 m .40977 .90253 L .41271 .91006 L F
.42569 .91082 m .41954 .90232 L .41922 .90992 L F
.42569 .91082 m .42925 .90367 L .41954 .90232 L F
.127 .923 .03 r
.45025 .54263 m
.45029 .5361 L
s
.81778 .66626 m .81743 .66059 L .81058 .64973 L .986 .71 .373 r
F
0 g
.81743 .66059 m
.81928 .67233 L
s
.30391 .67401 m .28248 .66681 L .27718 .67423 L .673 .757 .914 r
F
.30803 .67079 m .28248 .66681 L .30391 .67401 L F
.59685 .78094 m .61456 .77424 L .59637 .77809 L .683 .77 .917 r
F
.77104 .77874 m .77053 .77417 L .7825 .76821 L .525 .347 .582 r
F
0 g
.76386 .77615 m
.77053 .77417 L
s
.40635 .91499 m .40034 .90804 L .39241 .9112 L .644 .733 .913 r
F
.41246 .91382 m .40034 .90804 L .40635 .91499 L F
.76658 .67139 m .78114 .65724 L .76277 .66832 L .673 .758 .914 r
F
.76658 .67139 m .78875 .66339 L .78114 .65724 L F
.20743 .53269 m .204 .55642 L .22023 .53979 L .654 .726 .902 r
F
.20743 .53269 m .18481 .5458 L .204 .55642 L F
0 g
.204 .55642 m
.2265 .56365 L
s
.70172 .65939 m .67243 .6633 L .69632 .66677 L .673 .758 .914 r
F
.47693 .52688 m .44743 .53575 L .47778 .53213 L .654 .726 .902 r
F
.47693 .52688 m .44572 .52525 L .44743 .53575 L F
.43143 .91646 m .42899 .90744 L .42544 .91459 L .644 .733 .913 r
F
.43143 .91646 m .43797 .91025 L .42899 .90744 L F
.63496 .78351 m .63302 .77034 L .63352 .7749 L .768 .555 0 r
F
.61621 .78451 m .63496 .78351 L .63352 .7749 L .683 .77 .917 r
F
.63547 .78808 m .63496 .78351 L .63352 .7749 L .768 .555 0 r
F
0 g
.6337 .78817 m
.63485 .78392 L
s
.76164 .76487 m .77039 .77404 L .78231 .7681 L .683 .771 .917 r
F
.7525 .76758 m .77039 .77404 L .76164 .76487 L F
.25697 .42061 m .25621 .47805 L .25666 .4791 L .986 .729 .348 r
F
.25697 .42061 m .25652 .41956 L .25621 .47805 L F
.24947 .42048 m .24921 .47978 L .24915 .47896 L .798 .638 .081 r
F
.24999 .41944 m .24947 .42048 L .24915 .47896 L 0 0 .368 r
F
.41922 .90992 m .41954 .90232 L .40977 .90253 L .644 .733 .913 r
F
.30782 .66517 m .29059 .6548 L .2824 .66121 L .673 .757 .914 r
F
.31309 .66268 m .29059 .6548 L .30782 .66517 L F
.56799 .54205 m .60179 .53341 L .57058 .53178 L .654 .726 .902 r
F
.53807 .53529 m .56799 .54205 L .57058 .53178 L F
.53475 .53996 m .56799 .54205 L .53807 .53529 L F
.37443 .67812 m .3918 .66289 L .36973 .67089 L .673 .758 .914 r
F
.37443 .67812 m .39884 .67375 L .3918 .66289 L F
.3518 .78056 m .36322 .77002 L .3637 .77459 L .523 .345 .581 r
F
.35228 .78512 m .3518 .78056 L .3637 .77459 L F
.34283 .77134 m .3518 .78056 L .3637 .77459 L .683 .77 .917 r
F
.33368 .77407 m .3518 .78056 L .34283 .77134 L F
0 g
.3451 .78255 m
.3518 .78056 L
s
.72296 .55512 m .70037 .55269 L .69997 .55997 L .593 .369 .546 r
F
0 g
.68002 .56855 m
.69997 .55997 L
s
.72296 .55512 m .72336 .54784 L .70037 .55269 L .593 .369 .546 r
F
0 g
.68042 .56128 m
.70037 .55269 L
s
.72348 .67786 m .69676 .67808 L .72076 .68156 L .673 .758 .915 r
F
.76234 .6627 m .77056 .64706 L .75731 .66039 L .673 .758 .914 r
F
.76234 .6627 m .78062 .65168 L .77056 .64706 L F
.79445 .55762 m .77246 .54312 L .77207 .55039 L .794 .542 .557 r
F
.79406 .56489 m .79445 .55762 L .77207 .55039 L F
0 g
.79445 .55762 m
.81343 .56824 L
s
.71528 .7863 m .72815 .78437 L .72866 .78894 L .794 .542 .557 r
F
.71528 .7863 m .71477 .78173 L .72815 .78437 L F
.72471 .77152 m .72815 .78437 L .73363 .77328 L .683 .771 .917 r
F
.72471 .77152 m .71477 .78173 L .72815 .78437 L F
0 g
.72815 .78437 m
.74264 .78474 L
s
.30695 .54232 m
.31576 .54204 L
s
.56042 .79207 m .54264 .7988 L .56091 .79494 L .683 .771 .917 r
F
.56042 .79207 m .54165 .79307 L .54264 .7988 L F
.74381 .7781 m .74315 .78931 L .75778 .78739 L F
.73414 .77785 m .74315 .78931 L .74381 .7781 L F
.73414 .77785 m .72866 .78894 L .74315 .78931 L F
.57819 .78194 m .57392 .77142 L .56936 .77277 L .683 .77 .917 r
F
.35276 .55222 m .35321 .54495 L .32893 .54161 L .732 .488 .559 r
F
0 g
.35321 .54495 m
.37568 .55217 L
s
.39853 .66808 m .39119 .65155 L .3915 .65722 L .987 .712 .386 r
F
.39884 .67375 m .39853 .66808 L .3915 .65722 L F
0 g
.39853 .66808 m
.40057 .67982 L
s
.25652 .41956 m .25514 .47722 L .25621 .47805 L .908 .63 .502 r
F
.25652 .41956 m .25546 .41874 L .25514 .47722 L F
0 g
.25652 .41956 m
.25697 .42061 L
s
.25652 .41956 m
.25652 .41956 L
s
.61621 .78451 m .63352 .7749 L .61524 .77877 L .683 .77 .917 r
F
.59745 .78551 m .61621 .78451 L .61524 .77877 L F
.34767 .67888 m .36202 .66474 L .34382 .67581 L .673 .758 .914 r
F
.34767 .67888 m .36973 .67089 L .36202 .66474 L F
.56151 .67125 m .54281 .67046 L .54313 .67613 L .603 .397 .575 r
F
.56151 .67125 m .56119 .66558 L .54281 .67046 L F
0 g
.52687 .67799 m
.54281 .67046 L
s
.59715 .79301 m .61671 .78907 L .59794 .79007 L .683 .771 .917 r
F
.61839 .67475 m .60015 .66486 L .60048 .67053 L .794 .544 .56 r
F
.61872 .68043 m .61839 .67475 L .60048 .67053 L F
0 g
.61839 .67475 m
.63359 .68171 L
s
.40034 .90804 m .39266 .90744 L .39241 .9112 L .501 .301 .54 r
F
0 g
.38624 .91557 m
.39241 .9112 L
s
.40034 .90804 m .4006 .90427 L .39266 .90744 L .501 .301 .54 r
F
0 g
.3865 .91181 m
.39266 .90744 L
s
.28248 .66681 m .25309 .67074 L .27718 .67423 L .673 .757 .914 r
F
.25111 .41866 m .24999 .41944 L .24967 .47793 L .398 .209 .505 r
F
.24999 .41944 m .24915 .47896 L .24967 .47793 L 0 0 .368 r
F
0 g
.24947 .42048 m
.24999 .41944 L
s
.24999 .41944 m
.24999 .41944 L
s
.30576 .77791 m .30941 .79075 L .31472 .77967 L .683 .77 .917 r
F
.30576 .77791 m .29597 .78812 L .30941 .79075 L F
0 g
.30941 .79075 m
.32393 .79113 L
s
.28404 .77883 m .29502 .77899 L .29549 .78355 L .859 .591 .533 r
F
.28404 .77883 m .28357 .77426 L .29502 .77899 L F
0 g
.29502 .77899 m
.2991 .77979 L
s
.75778 .78739 m .77104 .77874 L .77155 .78331 L .607 .406 .584 r
F
.75357 .77681 m .75778 .78739 L .77155 .78331 L .683 .771 .917 r
F
.127 .923 .03 r
.80253 .71721 m
.80274 .71291 L
s
.74381 .7781 m .75778 .78739 L .75357 .77681 L .683 .771 .917 r
F
0 g
.74315 .78931 m
.75778 .78739 L
s
.44586 .91056 m .43848 .90272 L .43822 .90648 L .855 .609 .565 r
F
.44561 .91433 m .44586 .91056 L .43822 .90648 L F
0 g
.44586 .91056 m
.45164 .91563 L
s
.29731 .76553 m .29516 .77883 L .3049 .76867 L .683 .77 .917 r
F
.29731 .76553 m .28377 .77413 L .29516 .77883 L F
.1707 .52521 m .18576 .53125 L .18528 .53852 L .926 .669 .529 r
F
.1707 .52521 m .17118 .51793 L .18576 .53125 L F
0 g
.18576 .53125 m
.19193 .53467 L
s
.72314 .67219 m .70184 .66499 L .69642 .67241 L .673 .758 .914 r
F
.7273 .66897 m .70184 .66499 L .72314 .67219 L F
.41246 .91382 m .40951 .90629 L .40034 .90804 L .644 .733 .913 r
F
.41897 .91369 m .40951 .90629 L .41246 .91382 L F
.19893 .50917 m .1861 .53105 L .2086 .51801 L .654 .726 .902 r
F
.19893 .50917 m .17159 .5178 L .1861 .53105 L F
.42544 .91459 m .41928 .90609 L .41897 .91369 L .644 .733 .913 r
F
.42544 .91459 m .42899 .90744 L .41928 .90609 L F
.33806 .66222 m .33917 .64609 L .3321 .66082 L .673 .757 .914 r
F
.33806 .66222 m .3511 .64889 L .33917 .64609 L F
.25546 .41874 m .25407 .47685 L .25514 .47722 L .809 .541 .533 r
F
.25546 .41874 m .25438 .41836 L .25407 .47685 L F
0 g
.25546 .41874 m
.25652 .41956 L
s
.34352 .67014 m .35153 .65443 L .33842 .66782 L .673 .757 .914 r
F
.34352 .67014 m .36172 .65907 L .35153 .65443 L F
.25111 .41866 m .24967 .47793 L .25079 .47714 L .398 .209 .505 r
F
.25221 .41832 m .25111 .41866 L .25079 .47714 L .567 .342 .533 r
F
0 g
.24999 .41944 m
.25111 .41866 L
s
.5603 .78001 m .54085 .78392 L .55952 .78293 L .683 .77 .917 r
F
.2969 .52263 m .31848 .53798 L .3338 .52629 L .654 .726 .902 r
F
.28376 .52834 m .31848 .53798 L .2969 .52263 L F
.72705 .66335 m .71 .65298 L .70172 .65939 L .673 .758 .914 r
F
.73236 .66085 m .71 .65298 L .72705 .66335 L F
.79367 .6763 m .81127 .66107 L .78909 .66907 L .673 .758 .915 r
F
.79367 .6763 m .81813 .67193 L .81127 .66107 L F
.59745 .78551 m .61524 .77877 L .59696 .78264 L .683 .77 .917 r
F
.77104 .77874 m .7825 .76821 L .78301 .77277 L .525 .347 .582 r
F
.77155 .78331 m .77104 .77874 L .78301 .77277 L F
.76224 .76952 m .77104 .77874 L .78301 .77277 L .683 .771 .917 r
F
.75306 .77225 m .77104 .77874 L .76224 .76952 L F
0 g
.76437 .78072 m
.77104 .77874 L
s
.51059 .45621 m
.5106 .50865 L
s
.25438 .41836 m .25298 .47672 L .25407 .47685 L .734 .477 .54 r
F
.25438 .41836 m .2533 .41823 L .25298 .47672 L F
0 g
.25438 .41836 m
.25546 .41874 L
s
.41897 .91369 m .41928 .90609 L .40951 .90629 L .644 .733 .913 r
F
.25221 .41832 m .25079 .47714 L .25189 .47681 L .567 .342 .533 r
F
.2533 .41823 m .25221 .41832 L .25189 .47681 L .66 .416 .54 r
F
0 g
.25111 .41866 m
.25221 .41832 L
s
.50407 .45609 m
.50408 .50858 L
s
.2533 .41823 m .25189 .47681 L .25298 .47672 L .66 .416 .54 r
F
0 g
.2533 .41823 m
.25438 .41836 L
s
.25221 .41832 m
.2533 .41823 L
s
.63547 .78808 m .63352 .7749 L .63402 .77947 L .768 .555 0 r
F
.61671 .78907 m .63547 .78808 L .63402 .77947 L .683 .771 .917 r
F
0 g
.63307 .79688 m
.63547 .78808 L
s
.74781 .54706 m .72375 .54057 L .72336 .54784 L .667 .432 .555 r
F
.74781 .54706 m .74821 .53978 L .72375 .54057 L F
0 g
.70077 .54542 m
.72375 .54057 L
s
.77207 .55039 m .77246 .54312 L .74821 .53978 L .732 .488 .558 r
F
0 g
.77246 .54312 m
.79484 .55034 L
s
.81778 .66626 m .81058 .64973 L .81093 .6554 L .986 .71 .373 r
F
.81813 .67193 m .81778 .66626 L .81093 .6554 L F
0 g
.81778 .66626 m
.81963 .678 L
s
.35228 .78512 m .3637 .77459 L .36418 .77916 L .523 .345 .581 r
F
.34331 .77591 m .35228 .78512 L .36418 .77916 L .683 .77 .917 r
F
.33416 .77863 m .35228 .78512 L .34331 .77591 L F
0 g
.33856 .7892 m
.35228 .78512 L
s
.31309 .66268 m .30113 .6498 L .29059 .6548 L .673 .757 .914 r
F
.31917 .66105 m .30113 .6498 L .31309 .66268 L F
.30421 .67968 m .28278 .67248 L .27747 .6799 L .673 .758 .914 r
F
.30832 .67646 m .28278 .67248 L .30421 .67968 L F
.44453 .53978 m .41576 .55396 L .44626 .55033 L .654 .726 .902 r
F
.44453 .53978 m .41315 .53814 L .41576 .55396 L F
0 g
.41576 .55396 m
.42459 .56902 L
s
.76692 .67706 m .78149 .66292 L .76312 .67399 L .673 .758 .915 r
F
.76692 .67706 m .78909 .66907 L .78149 .66292 L F
0 g
.2807 .5618 m
.3036 .55695 L
s
.3689 .65963 m .37936 .64248 L .36124 .65351 L .673 .757 .914 r
F
.3689 .65963 m .39086 .65167 L .37936 .64248 L F
.70184 .66499 m .67241 .66892 L .69642 .67241 L .673 .758 .914 r
F
.54242 .77808 m .52218 .78492 L .54085 .78392 L .683 .77 .917 r
F
.5603 .78001 m .54242 .77808 L .54085 .78392 L F
.72522 .77609 m .72866 .78894 L .73414 .77785 L .683 .771 .917 r
F
.72522 .77609 m .71528 .7863 L .72866 .78894 L F
0 g
.72866 .78894 m
.74315 .78931 L
s
.127 .923 .03 r
.72411 .79519 m
.72438 .78839 L
s
.72438 .78839 m
.7244 .7881 L
s
.35276 .55222 m .32893 .54161 L .32848 .54889 L .732 .488 .559 r
F
0 g
.32893 .54161 m
.35321 .54495 L
s
.127 .923 .03 r
.34502 .53983 m
.34507 .5469 L
s
0 g
.32138 .54186 m
.32893 .54161 L
s
.70342 .77701 m .71426 .77717 L .71477 .78173 L .86 .591 .53 r
F
.70342 .77701 m .70291 .77244 L .71426 .77717 L F
0 g
.71426 .77717 m
.71842 .77799 L
s
.37479 .56672 m .35276 .55222 L .35231 .5595 L .793 .542 .558 r
F
.127 .923 .03 r
.36422 .55585 m
.36425 .56292 L
s
0 g
.37479 .56672 m
.39391 .57734 L
s
.71677 .76371 m .71441 .77701 L .7243 .76685 L .683 .771 .917 r
F
.71677 .76371 m .70312 .77231 L .71441 .77701 L F
.59637 .77809 m .61111 .76906 L .59465 .7755 L .683 .77 .917 r
F
.59637 .77809 m .61456 .77424 L .61111 .76906 L F
.30803 .67079 m .29071 .66037 L .28248 .66681 L .673 .757 .914 r
F
.31332 .66828 m .29071 .66037 L .30803 .67079 L F
.40977 .90253 m .40086 .90051 L .4006 .90427 L .597 .381 .559 r
F
.127 .923 .03 r
.67927 .93843 m
.68205 .85927 L
s
.40977 .90253 m .41002 .89876 L .40086 .90051 L .597 .381 .559 r
F
0 g
.39292 .90367 m
.40086 .90051 L
s
.59752 .56347 m .60185 .54071 L .60143 .54799 L 0 0 .15 r
F
.56746 .55667 m .59752 .56347 L .60143 .54799 L .654 .726 .902 r
F
0 g
.58747 .57755 m
.59752 .56347 L
s
.44561 .91433 m .43822 .90648 L .43797 .91025 L .855 .609 .565 r
F
0 g
.44561 .91433 m
.45139 .9194 L
s
.61671 .78907 m .63402 .77947 L .61574 .78334 L .683 .771 .917 r
F
.59794 .79007 m .61671 .78907 L .61574 .78334 L F
.32393 .7595 m .32346 .77067 L .33316 .76939 L .683 .77 .917 r
F
.32393 .7595 m .33316 .76939 L .32878 .75886 L F
.3244 .76412 m .32393 .77535 L .33368 .77407 L F
.3244 .76412 m .33368 .77407 L .32928 .76348 L F
.32389 .70888 m .32546 .70914 L .3253 .75116 L .751 .492 .54 r
F
.32569 .75142 m .32393 .7595 L .32878 .75886 L .683 .77 .917 r
F
.32559 .75119 m .32553 .75148 L .32569 .75142 L F
.32553 .75148 m .32393 .7595 L .32569 .75142 L F
.32598 .75555 m .3244 .76412 L .32928 .76348 L F
.32427 .75135 m .32393 .7595 L .32555 .75118 L F
.3253 .75116 m .32555 .75118 L .32556 .75112 L F
.32427 .75135 m .32555 .75118 L .3253 .75116 L F
.32224 .70782 m .32291 .70841 L .32274 .75068 L .927 .648 .492 r
F
.3232 .75084 m .3229 .75147 L .32428 .75123 L .683 .77 .917 r
F
.32181 .70632 m .32186 .70713 L .3217 .74961 L .794 .634 .076 r
F
.32199 .75336 m .31911 .75938 L .32209 .75467 L .683 .77 .917 r
F
.31465 .7585 m .31382 .77042 L .31911 .75938 L F
.32185 .75605 m .31126 .76154 L .31508 .76312 L F
.3223 .75052 m .32229 .75053 L .3232 .75084 L F
.32426 .75178 m .31911 .75938 L .32393 .7595 L F
.32359 .75558 m .31956 .764 L .32433 .75612 L F
.31911 .75938 m .32346 .77067 L .32393 .7595 L F
.32314 .75097 m .31791 .7556 L .31911 .75938 L F
.31791 .7556 m .31465 .7585 L .31614 .75879 L F
.31791 .7556 m .31614 .75879 L .31911 .75938 L F
.32181 .70632 m .32168 .74941 L .32164 .74889 L .794 .634 .076 r
F
.32186 .70713 m .32197 .75003 L .3217 .74961 L .989 .721 .393 r
F
.32181 .70632 m .3217 .74961 L .32168 .74941 L .794 .634 .076 r
F
.32186 .70713 m .32224 .70782 L .32208 .7502 L .989 .721 .393 r
F
.32186 .70713 m .32208 .7502 L .32197 .75003 L F
.32233 .70529 m .32181 .70632 L .32164 .74889 L 0 0 .373 r
F
.3217 .75414 m .32091 .75445 L .32176 .75487 L .683 .77 .917 r
F
.32291 .70841 m .32345 .75093 L .32274 .75068 L .844 .572 .526 r
F
.32291 .70841 m .32389 .70888 L .32373 .75104 L F
.32291 .70841 m .32373 .75104 L .32364 .751 L F
.32181 .75103 m .32189 .75202 L .32275 .75124 L .683 .77 .917 r
F
.32464 .75847 m .31956 .764 L .3244 .76412 L F
.31911 .75938 m .31382 .77042 L .32346 .77067 L F
.31956 .764 m .31424 .7751 L .32393 .77535 L F
.31508 .76312 m .31424 .7751 L .31956 .764 L F
.32359 .76115 m .31555 .76769 L .32004 .76857 L F
.32351 .75524 m .32372 .75531 L .3237 .75959 L .844 .572 .526 r
F
.31956 .764 m .32393 .77535 L .3244 .76412 L .683 .77 .917 r
F
.32524 .76014 m .32004 .76857 L .32488 .76869 L F
.32476 .75569 m .32382 .7572 L .32464 .75847 L F
.32372 .75531 m .32359 .75558 L .32477 .7554 L F
.32412 .75534 m .3245 .75966 L .32372 .75531 L .751 .492 .54 r
F
.32474 .75611 m .3244 .76412 L .32598 .75555 L .683 .77 .917 r
F
.3245 .75966 m .32524 .768 L .32423 .75963 L .751 .492 .54 r
F
.32382 .7572 m .31956 .764 L .32464 .75847 L .683 .77 .917 r
F
.3245 .75966 m .32423 .75963 L .32372 .75531 L .751 .492 .54 r
F
.32526 .75972 m .32424 .75979 L .32524 .76014 L .683 .77 .917 r
F
.32431 .75964 m .32424 .75979 L .32526 .75972 L F
.32428 .75123 m .32403 .75162 L .32426 .75178 L F
.32359 .75558 m .32433 .75612 L .32477 .7554 L F
.32477 .7554 m .32463 .75564 L .32476 .75569 L F
.32486 .75113 m .32524 .768 L .32373 .75104 L .751 .492 .54 r
F
.32477 .7554 m .32474 .75611 L .32596 .7555 L .683 .77 .917 r
F
.32495 .75541 m .32529 .75544 L .32524 .768 L .751 .492 .54 r
F
.32536 .75746 m .32431 .75964 L .32526 .75972 L .683 .77 .917 r
F
.32424 .75979 m .32004 .76857 L .32524 .76014 L F
.32271 .75923 m .32367 .76774 L .32268 .76727 L .844 .572 .526 r
F
.32229 .75053 m .32275 .75124 L .3232 .75084 L .683 .77 .917 r
F
.3229 .75147 m .32199 .75336 L .32352 .75243 L F
.32403 .75162 m .31911 .75938 L .32426 .75178 L F
.32274 .75068 m .32298 .75505 L .32273 .75496 L .844 .572 .526 r
F
.32488 .75289 m .3217 .75414 L .32174 .7546 L .683 .77 .917 r
F
.32203 .7547 m .32174 .7546 L .32176 .75487 L F
.32488 .75289 m .32174 .7546 L .32203 .7547 L F
.32463 .75564 m .31956 .764 L .32476 .75569 L F
.32273 .75496 m .32322 .75942 L .32271 .75923 L .844 .572 .526 r
F
.32359 .75558 m .31508 .76312 L .31956 .764 L .683 .77 .917 r
F
.32373 .75104 m .32412 .75534 L .32372 .75531 L .751 .492 .54 r
F
.32488 .75289 m .32283 .75503 L .32359 .75558 L .683 .77 .917 r
F
.32283 .75503 m .31508 .76312 L .32359 .75558 L F
.32229 .75053 m .32181 .75103 L .32275 .75124 L F
.32199 .75336 m .32209 .75467 L .32352 .75243 L F
.32256 .75054 m .32259 .75486 L .32208 .7502 L .927 .648 .492 r
F
.32216 .75462 m .32176 .75487 L .32259 .75529 L .683 .77 .917 r
F
.32224 .70782 m .32256 .75054 L .32208 .7502 L .927 .648 .492 r
F
.32224 .70782 m .32274 .75068 L .32256 .75054 L F
.32309 .75093 m .31465 .7585 L .32314 .75097 L .683 .77 .917 r
F
.32291 .70841 m .32364 .751 L .32345 .75093 L .844 .572 .526 r
F
.32389 .70888 m .32486 .75113 L .32373 .75104 L .751 .492 .54 r
F
.3244 .74832 m .3179 .75088 L .31085 .75693 L .683 .77 .917 r
F
.3179 .75088 m .30798 .75477 L .31001 .7563 L F
.3179 .75088 m .31001 .7563 L .31085 .75693 L F
.32345 .70451 m .32233 .70529 L .32217 .74794 L .4 .212 .507 r
F
.32259 .75486 m .32223 .7546 L .32208 .7502 L .927 .648 .492 r
F
.31859 .75439 m .31085 .75693 L .31465 .7585 L .683 .77 .917 r
F
.31085 .75693 m .29731 .76553 L .3049 .76867 L F
.31623 .75629 m .30661 .75676 L .30837 .75937 L F
.32179 .74863 m .32173 .75297 L .32217 .74794 L 0 0 .373 r
F
.32168 .75388 m .3218 .75837 L .32166 .75816 L .989 .721 .393 r
F
.32176 .75487 m .31126 .76154 L .32185 .75605 L .683 .77 .917 r
F
.32178 .75404 m .32186 .75847 L .32168 .75388 L .989 .721 .393 r
F
.32288 .76005 m .31555 .76769 L .32359 .76115 L .683 .77 .917 r
F
.32186 .75847 m .32202 .76668 L .3218 .75837 L .989 .721 .393 r
F
.32186 .75847 m .3218 .75837 L .32168 .75388 L F
.31085 .75693 m .3049 .76867 L .31465 .7585 L .683 .77 .917 r
F
.32176 .75487 m .30837 .75937 L .31126 .76154 L F
.32171 .75823 m .30656 .75846 L .30708 .76133 L F
.32167 .75373 m .32168 .75388 L .32166 .75816 L .794 .634 .076 r
F
.31508 .76312 m .30528 .77334 L .31424 .7751 L .683 .77 .917 r
F
.31642 .76678 m .31174 .76611 L .31555 .76769 L F
.32536 .75746 m .31955 .76115 L .31642 .76678 L F
.31955 .76115 m .31174 .76611 L .31642 .76678 L F
.32166 .75816 m .32202 .76668 L .32163 .76599 L .989 .721 .393 r
F
.32259 .75529 m .32176 .75487 L .32185 .75605 L .683 .77 .917 r
F
.3179 .75088 m .30622 .75218 L .30798 .75477 L F
.32117 .75309 m .30685 .75095 L .30609 .75389 L F
.32198 .75435 m .32185 .75414 L .3217 .74961 L .989 .721 .393 r
F
.32235 .74781 m .32224 .75215 L .32247 .74773 L .4 .212 .507 r
F
.32256 .75054 m .32273 .75496 L .32259 .75486 L .927 .648 .492 r
F
.32488 .75289 m .32136 .75364 L .32091 .75445 L .683 .77 .917 r
F
.32224 .75215 m .32213 .7565 L .3223 .75211 L .4 .212 .507 r
F
.32224 .75215 m .3223 .75211 L .32247 .74773 L F
.32197 .75003 m .32206 .75447 L .32198 .75435 L .989 .721 .393 r
F
.32488 .75289 m .32167 .75255 L .32117 .75309 L .683 .77 .917 r
F
.32181 .75103 m .31465 .7585 L .32189 .75202 L F
.32167 .75255 m .32076 .75245 L .32108 .75295 L F
.32167 .75255 m .32108 .75295 L .32117 .75309 L F
.32143 .75021 m .31085 .75693 L .3223 .75052 L F
.32076 .75245 m .30685 .75095 L .32117 .75309 L F
.32197 .75003 m .32198 .75435 L .3217 .74961 L .989 .721 .393 r
F
.32198 .75435 m .32199 .75867 L .32185 .75414 L F
.32199 .75867 m .32202 .76668 L .32186 .75847 L F
.32199 .75867 m .32186 .75847 L .3217 .74961 L F
.31465 .7585 m .3049 .76867 L .31382 .77042 L .683 .77 .917 r
F
.32205 .75876 m .30708 .76133 L .30885 .76394 L F
.32351 .75524 m .3237 .75959 L .32356 .75954 L .844 .572 .526 r
F
.32198 .75435 m .32206 .75447 L .32202 .76668 L .989 .721 .393 r
F
.32536 .75746 m .32171 .75823 L .32205 .75876 L .683 .77 .917 r
F
.32171 .75823 m .30708 .76133 L .32205 .75876 L F
.32213 .7565 m .32158 .76518 L .3221 .76415 L 0 0 .373 r
F
.32197 .75003 m .32208 .7502 L .32206 .75447 L .989 .721 .393 r
F
.32217 .74794 m .32186 .75699 L .32213 .7565 L 0 0 .373 r
F
.32264 .75919 m .31378 .76224 L .31174 .76611 L .683 .77 .917 r
F
.3218 .75837 m .32202 .76668 L .32166 .75816 L .989 .721 .393 r
F
.32186 .75699 m .32158 .76518 L .32213 .7565 L 0 0 .373 r
F
.32166 .75806 m .32166 .75816 L .32163 .76599 L .794 .634 .076 r
F
.32167 .75373 m .32166 .75816 L .32166 .75806 L F
.32536 .75746 m .32162 .75766 L .32171 .75823 L .683 .77 .917 r
F
.32162 .75766 m .32135 .75767 L .32166 .75816 L F
.32162 .75766 m .32166 .75816 L .32171 .75823 L F
.32135 .75767 m .30656 .75846 L .32171 .75823 L F
.32003 .75179 m .31085 .75693 L .31859 .75439 L F
.31952 .75403 m .30661 .75676 L .31623 .75629 L F
.32091 .75445 m .30837 .75937 L .32043 .75532 L F
.32166 .75358 m .30609 .75389 L .30661 .75676 L F
.32256 .75054 m .32274 .75068 L .32273 .75496 L .927 .648 .492 r
F
.32488 .75289 m .32162 .75307 L .32166 .75358 L .683 .77 .917 r
F
.32162 .75307 m .30609 .75389 L .32166 .75358 L F
.32168 .74941 m .32167 .75373 L .32164 .74889 L .794 .634 .076 r
F
.32167 .75373 m .32163 .76599 L .32164 .75335 L F
.32167 .75373 m .32164 .75335 L .32164 .74889 L F
.32181 .75708 m .30932 .75271 L .30732 .75552 L .683 .77 .917 r
F
.32424 .75979 m .32288 .76005 L .32359 .76115 L F
.32342 .75949 m .32288 .76005 L .32424 .75979 L F
.3232 .75084 m .32309 .75093 L .32314 .75097 L F
.32345 .75093 m .32351 .75524 L .32274 .75068 L .844 .572 .526 r
F
.32351 .75524 m .32367 .76774 L .32298 .75505 L F
.32351 .75524 m .32298 .75505 L .32274 .75068 L F
.32345 .75093 m .32372 .75531 L .32351 .75524 L F
.32488 .75289 m .32216 .75462 L .32227 .75479 L .683 .77 .917 r
F
.32286 .755 m .32227 .75479 L .32259 .75529 L F
.32488 .75289 m .32227 .75479 L .32286 .755 L F
.32536 .75746 m .32213 .7565 L .32181 .75708 L F
.32091 .75445 m .31952 .75403 L .31623 .75629 L F
.32213 .7565 m .30932 .75271 L .32181 .75708 L F
.32173 .75297 m .32168 .75732 L .32201 .75247 L 0 0 .373 r
F
.32168 .75732 m .32158 .76518 L .32186 .75699 L F
.32168 .75732 m .32186 .75699 L .32201 .75247 L F
.32173 .75297 m .32201 .75247 L .32217 .74794 L F
.32136 .75364 m .31952 .75403 L .32091 .75445 L .683 .77 .917 r
F
.32262 .75917 m .32239 .759 L .32223 .7546 L .927 .648 .492 r
F
.32238 .75206 m .32213 .7565 L .32228 .7564 L .4 .212 .507 r
F
.32247 .74773 m .3223 .75211 L .32238 .75206 L F
.3223 .75211 m .32213 .7565 L .32238 .75206 L F
.32345 .70451 m .32235 .74781 L .32247 .74773 L F
.3244 .74832 m .32037 .74918 L .3179 .75088 L .683 .77 .917 r
F
.32037 .74918 m .30622 .75218 L .3179 .75088 L F
.3223 .75052 m .32003 .75179 L .31859 .75439 L F
.32168 .74941 m .3217 .74961 L .32168 .75388 L .794 .634 .076 r
F
.32262 .75917 m .32268 .76727 L .32239 .759 L .927 .648 .492 r
F
.32322 .75942 m .32367 .76774 L .32271 .75923 L .844 .572 .526 r
F
.32325 .75573 m .3221 .76415 L .32322 .76338 L .4 .212 .507 r
F
.32259 .75486 m .32262 .75917 L .32223 .7546 L .927 .648 .492 r
F
.3244 .74832 m .32143 .75021 L .3223 .75052 L .683 .77 .917 r
F
.32037 .74918 m .3057 .74932 L .30622 .75218 L F
.3244 .74832 m .32138 .74848 L .32037 .74918 L F
.32138 .74848 m .3057 .74932 L .32037 .74918 L F
.32328 .74717 m .32228 .7564 L .32325 .75573 L .4 .212 .507 r
F
.32345 .70451 m .32247 .74773 L .32328 .74717 L F
.3244 .74832 m .3223 .75052 L .3232 .75084 L .683 .77 .917 r
F
.32238 .75206 m .32278 .75178 L .32328 .74717 L .4 .212 .507 r
F
.32235 .74781 m .32217 .74794 L .32215 .75222 L F
.32233 .70529 m .32179 .74863 L .32217 .74794 L 0 0 .373 r
F
.32233 .70529 m .32164 .74889 L .32179 .74863 L F
.3227 .74737 m .31546 .73913 L .31151 .74112 L .683 .77 .917 r
F
.3244 .74832 m .32328 .74717 L .3227 .74737 L F
.32328 .74717 m .31546 .73913 L .3227 .74737 L F
.32455 .70418 m .32345 .70451 L .32328 .74717 L .568 .344 .535 r
F
.32042 .75241 m .30884 .74814 L .30685 .75095 L .683 .77 .917 r
F
.3217 .74961 m .32178 .75404 L .32168 .75388 L .989 .721 .393 r
F
.32168 .74941 m .32168 .75388 L .32167 .75373 L .794 .634 .076 r
F
.32488 .75289 m .32174 .75196 L .32042 .75241 L .683 .77 .917 r
F
.32174 .75196 m .30884 .74814 L .32042 .75241 L F
.32359 .74707 m .32328 .74717 L .32327 .75145 L .568 .344 .535 r
F
.32091 .75445 m .32043 .75532 L .32176 .75487 L .683 .77 .917 r
F
.3229 .75147 m .32352 .75243 L .32428 .75123 L F
.32364 .751 m .32372 .75531 L .32345 .75093 L .844 .572 .526 r
F
.32179 .74863 m .32162 .75316 L .32173 .75297 L 0 0 .373 r
F
.32164 .74889 m .32164 .75335 L .32162 .75316 L .794 .634 .076 r
F
.32364 .751 m .32373 .75104 L .32372 .75531 L .844 .572 .526 r
F
.31903 .74861 m .30646 .74639 L .3057 .74932 L .683 .77 .917 r
F
.3244 .74832 m .32097 .74795 L .31903 .74861 L F
.32097 .74795 m .30646 .74639 L .31903 .74861 L F
.3244 .74832 m .3232 .75084 L .32428 .75123 L F
.32438 .7468 m .32349 .75137 L .32437 .75108 L .568 .344 .535 r
F
.32455 .70418 m .32359 .74707 L .32438 .7468 L F
.32359 .74707 m .32349 .75137 L .32438 .7468 L F
.32174 .75196 m .31192 .74565 L .30884 .74814 L .683 .77 .917 r
F
.32488 .75289 m .32266 .75165 L .32174 .75196 L F
.32266 .75165 m .31192 .74565 L .32174 .75196 L F
.32356 .75954 m .3237 .75959 L .32367 .76774 L .844 .572 .526 r
F
.32536 .75746 m .32342 .75949 L .32424 .75979 L .683 .77 .917 r
F
.32372 .75531 m .32524 .768 L .32367 .76774 L .751 .492 .54 r
F
.32437 .75108 m .32322 .76338 L .32432 .76304 L .568 .344 .535 r
F
.32536 .75746 m .32356 .75562 L .32263 .75594 L .683 .77 .917 r
F
.32488 .75289 m .32405 .75091 L .32339 .75136 L F
.32488 .75289 m .32339 .75136 L .32283 .75175 L F
.32259 .75486 m .32273 .75496 L .32268 .76727 L .927 .648 .492 r
F
.32536 .75746 m .32206 .75876 L .32264 .75919 L .683 .77 .917 r
F
.32238 .75206 m .32228 .7564 L .32278 .75178 L .4 .212 .507 r
F
.3244 .74832 m .30844 .74359 L .30646 .74639 L .683 .77 .917 r
F
.3244 .74832 m .31151 .74112 L .30844 .74359 L F
.32283 .75175 m .31589 .74366 L .31192 .74565 L F
.32235 .74781 m .32215 .75222 L .32224 .75215 L .4 .212 .507 r
F
.32179 .74863 m .32164 .74889 L .32162 .75316 L 0 0 .373 r
F
.32339 .75136 m .31589 .74366 L .32283 .75175 L .683 .77 .917 r
F
.32205 .75875 m .32268 .76727 L .32202 .76668 L .927 .648 .492 r
F
.32208 .7502 m .32239 .759 L .32205 .75875 L F
.32239 .759 m .32268 .76727 L .32205 .75875 L F
.32062 .75771 m .30732 .75552 L .30656 .75846 L .683 .77 .917 r
F
.32173 .75297 m .32162 .75316 L .32161 .75744 L 0 0 .373 r
F
.32162 .75316 m .32163 .76599 L .32158 .76518 L .794 .634 .076 r
F
.32164 .75335 m .32164 .75782 L .32162 .75316 L F
.32164 .75782 m .32163 .76599 L .32163 .75769 L F
.32164 .75782 m .32163 .75769 L .32162 .75316 L F
.32536 .75746 m .32181 .75708 L .32161 .75744 L .683 .77 .917 r
F
.32162 .75766 m .32161 .75744 L .32148 .75767 L F
.32536 .75746 m .32161 .75744 L .32162 .75766 L F
.32168 .75732 m .32161 .75744 L .32158 .76518 L 0 0 .373 r
F
.32173 .75297 m .32161 .75744 L .32168 .75732 L F
.32148 .75767 m .31938 .75682 L .32062 .75771 L .683 .77 .917 r
F
.32181 .75708 m .31938 .75682 L .32148 .75767 L F
.31938 .75682 m .30732 .75552 L .32062 .75771 L F
.32224 .75215 m .32215 .75222 L .32213 .7565 L .4 .212 .507 r
F
.32356 .75562 m .32095 .74686 L .31637 .74823 L .683 .77 .917 r
F
.32389 .70888 m .3253 .75116 L .32486 .75113 L .751 .492 .54 r
F
.32564 .70409 m .32455 .70418 L .32435 .75535 L .66 .417 .541 r
F
.32536 .75746 m .32447 .75534 L .32356 .75562 L .683 .77 .917 r
F
.32449 .75534 m .32435 .75535 L .32432 .76304 L .66 .417 .541 r
F
.32488 .75289 m .32372 .75531 L .32477 .7554 L .683 .77 .917 r
F
.32705 .70894 m .32762 .75056 L .32689 .75088 L .517 .303 .528 r
F
.32546 .70914 m .32643 .75096 L .3253 .75116 L .641 .402 .541 r
F
.33071 .75019 m .33728 .75553 L .34035 .75305 L .683 .77 .917 r
F
.32705 .70894 m .32807 .7085 L .32791 .75042 L .517 .303 .528 r
F
.32805 .75036 m .32847 .7506 L .32934 .74979 L .683 .77 .917 r
F
.32823 .75868 m .32928 .76348 L .32854 .75666 L F
.32928 .76348 m .33368 .77407 L .34283 .77134 L F
.32856 .76075 m .32976 .76805 L .33434 .76669 L F
.32728 .75944 m .32806 .76396 L .32856 .76075 L F
.32628 .75969 m .32488 .76869 L .32976 .76805 L F
.32524 .76015 m .32488 .76869 L .32628 .75969 L F
.32527 .75972 m .32683 .7678 L .32524 .768 L .641 .402 .541 r
F
.32596 .7555 m .32474 .75611 L .32598 .75555 L .683 .77 .917 r
F
.3253 .75116 m .32607 .75957 L .32527 .75972 L .641 .402 .541 r
F
.32622 .75955 m .32524 .76015 L .32628 .75969 L .683 .77 .917 r
F
.32526 .75972 m .32524 .76015 L .32622 .75955 L F
.32607 .75957 m .32683 .7678 L .32527 .75972 L .641 .402 .541 r
F
.32536 .75746 m .32526 .75972 L .32622 .75955 L .683 .77 .917 r
F
.32686 .75943 m .32785 .76736 L .32683 .7678 L .517 .303 .528 r
F
.32687 .75516 m .3272 .75928 L .32686 .75943 L F
.32645 .76009 m .32806 .76396 L .32728 .75944 L .683 .77 .917 r
F
.3272 .75928 m .32785 .76736 L .32686 .75943 L .517 .303 .528 r
F
.32788 .75898 m .32855 .7668 L .32785 .76736 L .356 .178 .497 r
F
.32592 .75198 m .32878 .75886 L .32708 .75107 L .683 .77 .917 r
F
.32757 .75566 m .32823 .75868 L .32854 .75666 L F
.3288 .75079 m .33334 .75751 L .33728 .75553 L F
.3244 .74832 m .32853 .75257 L .3288 .75079 L F
.32853 .75257 m .33334 .75751 L .3288 .75079 L F
.32904 .74924 m .32911 .75295 L .32903 .75352 L 0 0 .131 r
F
.3292 .70726 m .32912 .74872 L .32904 .74924 L F
.32934 .74979 m .32847 .7506 L .33071 .75019 L .683 .77 .917 r
F
.32912 .74872 m .32911 .75295 L .32904 .74924 L 0 0 .131 r
F
.32892 .74942 m .32893 .75365 L .32861 .74987 L .071 0 .412 r
F
.32878 .75886 m .33316 .76939 L .33886 .7677 L .683 .77 .917 r
F
.33672 .76347 m .33886 .7677 L .34227 .76668 L F
.32878 .75886 m .33886 .7677 L .33672 .76347 L F
.32854 .75666 m .32928 .76348 L .33386 .76212 L F
.32853 .75257 m .32878 .75886 L .33334 .75751 L F
.3275 .75151 m .32813 .75514 L .32853 .75257 L F
.32813 .75514 m .32878 .75886 L .32853 .75257 L F
.3292 .70726 m .32931 .70645 L .32915 .74851 L 0 0 .131 r
F
.33334 .75751 m .35016 .76272 L .33728 .75553 L .683 .77 .917 r
F
.32894 .7541 m .33783 .76013 L .34091 .75765 L F
.32725 .75188 m .32878 .75886 L .3275 .75151 L F
.32689 .75088 m .32713 .75504 L .32687 .75516 L .517 .303 .528 r
F
.32708 .75107 m .32725 .75188 L .3275 .75151 L .683 .77 .917 r
F
.32762 .75056 m .32767 .7548 L .32689 .75088 L .517 .303 .528 r
F
.32662 .75707 m .32928 .76348 L .32757 .75566 L .683 .77 .917 r
F
.32878 .75886 m .34227 .76668 L .33334 .75751 L F
.33089 .75625 m .33386 .76212 L .33783 .76013 L F
.32819 .75475 m .33386 .76212 L .33089 .75625 L F
.33386 .76212 m .33386 .76212 L .33089 .75625 L F
.32847 .7506 m .33728 .75553 L .33071 .75019 L F
.32877 .70794 m .3292 .70726 L .32904 .74924 L .071 0 .412 r
F
.32931 .74885 m .34035 .75305 L .34234 .75026 L .683 .77 .917 r
F
.33022 .75176 m .34367 .75189 L .34316 .74902 L F
.32897 .74935 m .32903 .75352 L .32899 .75357 L .071 0 .412 r
F
.32893 .75365 m .32871 .75399 L .32861 .74987 L F
.32861 .74987 m .32871 .75399 L .3286 .75415 L F
.32799 .75463 m .32814 .75483 L .32819 .75475 L .683 .77 .917 r
F
.32718 .75526 m .33386 .76212 L .32799 .75463 L F
.3306 .75259 m .34291 .75484 L .34367 .75189 L F
.32841 .75003 m .32845 .75427 L .32791 .75042 L .356 .178 .497 r
F
.32845 .75427 m .3282 .75447 L .32791 .75042 L F
.32796 .75892 m .33831 .7647 L .32859 .75842 L .683 .77 .917 r
F
.32928 .76348 m .34283 .77134 L .33386 .76212 L F
.32817 .75903 m .33434 .76669 L .33831 .7647 L F
.32802 .75465 m .32879 .75508 L .32891 .75425 L F
.33728 .75553 m .3563 .75778 L .34035 .75305 L F
.32956 .7534 m .34091 .75765 L .34291 .75484 L F
.32767 .7548 m .32713 .75504 L .32689 .75088 L .517 .303 .528 r
F
.32878 .74962 m .34035 .75305 L .32931 .74885 L .683 .77 .917 r
F
.32879 .75508 m .33783 .76013 L .32894 .7541 L F
.32892 .74942 m .32901 .7578 L .32895 .75789 L .071 0 .412 r
F
.32877 .70794 m .32897 .74935 L .32892 .74942 L F
.32897 .74935 m .32901 .7578 L .32892 .74942 L F
.32986 .74803 m .34234 .75026 L .3431 .74733 L .683 .77 .917 r
F
.32841 .75003 m .32858 .75843 L .32848 .75851 L .356 .178 .497 r
F
.32807 .7085 m .32849 .74997 L .32841 .75003 L F
.32849 .74997 m .32858 .75843 L .32841 .75003 L F
.3329 .74652 m .3431 .74733 L .34258 .74447 L .683 .77 .917 r
F
.32807 .7085 m .32877 .70794 L .32861 .74987 L .356 .178 .497 r
F
.32855 .74993 m .32861 .74987 L .3286 .75415 L F
.32807 .7085 m .32861 .74987 L .32855 .74993 L F
.32849 .74997 m .3286 .75415 L .32854 .7542 L F
.32807 .7085 m .32855 .74993 L .32849 .74997 L F
.32855 .74993 m .3286 .75415 L .32849 .74997 L F
.33685 .74344 m .34258 .74447 L .34083 .74187 L .683 .77 .917 r
F
.32877 .70794 m .32904 .74924 L .32897 .74935 L .071 0 .412 r
F
.32877 .70794 m .32892 .74942 L .32861 .74987 L F
.32931 .70645 m .32886 .70541 L .3287 .74762 L .986 .729 .347 r
F
.3244 .74832 m .32878 .74962 L .32931 .74885 L .683 .77 .917 r
F
.32874 .7477 m .3287 .74762 L .32868 .75189 L .986 .729 .347 r
F
.32931 .70645 m .3287 .74762 L .32874 .7477 L F
.32854 .7542 m .3286 .75415 L .32858 .75843 L .356 .178 .497 r
F
.32806 .76396 m .32976 .76805 L .32856 .76075 L .683 .77 .917 r
F
.32848 .75851 m .32858 .75843 L .32855 .7668 L .356 .178 .497 r
F
.32488 .75289 m .32956 .7534 L .33024 .75286 L .683 .77 .917 r
F
.32986 .75263 m .33024 .75286 L .3306 .75259 L F
.32488 .75289 m .33024 .75286 L .32986 .75263 L F
.32728 .75944 m .33362 .76595 L .32788 .75898 L F
.33362 .76595 m .33434 .76669 L .33346 .76564 L F
.33362 .76595 m .33346 .76564 L .32788 .75898 L F
.32895 .75789 m .32901 .7578 L .32898 .76612 L .071 0 .412 r
F
.32898 .76505 m .32898 .76612 L .32895 .765 L F
.32898 .76505 m .32895 .765 L .32871 .75399 L F
.32814 .75483 m .33386 .76212 L .32819 .75475 L .683 .77 .917 r
F
.32938 .75725 m .34338 .75941 L .34415 .75646 L F
.32789 .7547 m .32823 .7587 L .32788 .75898 L .356 .178 .497 r
F
.32536 .75746 m .32897 .75785 L .32938 .75725 L .683 .77 .917 r
F
.32897 .75785 m .34338 .75941 L .32938 .75725 L F
.32893 .75365 m .32895 .75789 L .32871 .75399 L .071 0 .412 r
F
.32895 .75789 m .32898 .76505 L .32881 .7581 L F
.32895 .75789 m .32881 .7581 L .32871 .75399 L F
.32901 .7578 m .32909 .76531 L .32898 .76612 L 0 0 .131 r
F
.32812 .7591 m .33434 .76669 L .32817 .75903 L .683 .77 .917 r
F
.32905 .75755 m .32909 .76531 L .32901 .7578 L 0 0 .131 r
F
.32912 .75707 m .32864 .76427 L .32909 .76531 L .986 .729 .347 r
F
.32911 .75295 m .32914 .75279 L .32912 .75707 L 0 0 .131 r
F
.32911 .75717 m .32912 .75707 L .32909 .76531 L F
.32911 .75295 m .32912 .75707 L .32911 .75717 L F
.32919 .75665 m .34415 .75646 L .34363 .75359 L .683 .77 .917 r
F
.32911 .75295 m .32909 .76531 L .32903 .75352 L 0 0 .131 r
F
.32762 .75056 m .32791 .75042 L .32788 .75898 L .517 .303 .528 r
F
.32773 .75904 m .32788 .75898 L .32785 .76736 L F
.32762 .75056 m .32788 .75898 L .32773 .75904 L F
.33334 .75751 m .34227 .76668 L .35016 .76272 L .683 .77 .917 r
F
.33783 .76013 m .35694 .7624 L .34091 .75765 L F
.33013 .75798 m .34139 .76221 L .34338 .75941 L F
.32773 .75904 m .32737 .7592 L .32713 .75504 L .517 .303 .528 r
F
.32802 .75465 m .32891 .75425 L .32894 .7541 L .683 .77 .917 r
F
.32871 .75399 m .3288 .75811 L .3286 .75415 L .071 0 .412 r
F
.3288 .75811 m .32898 .76612 L .32873 .75821 L F
.3288 .75811 m .32873 .75821 L .3286 .75415 L F
.32897 .75785 m .32891 .75852 L .33013 .75798 L .683 .77 .917 r
F
.32767 .7548 m .32773 .75904 L .32713 .75504 L .517 .303 .528 r
F
.32536 .75746 m .32859 .75842 L .32897 .75785 L .683 .77 .917 r
F
.32859 .75842 m .32891 .75852 L .32897 .75785 L F
.32891 .75852 m .34139 .76221 L .33013 .75798 L F
.32536 .75746 m .32909 .75726 L .32919 .75665 L F
.32909 .75726 m .34415 .75646 L .32919 .75665 L F
.32903 .75352 m .32905 .75755 L .32901 .7578 L 0 0 .131 r
F
.32914 .75279 m .32897 .75676 L .32912 .75707 L .986 .729 .347 r
F
.32897 .75676 m .32864 .76427 L .32912 .75707 L F
.32845 .75427 m .32848 .75851 L .3282 .75447 L .356 .178 .497 r
F
.32848 .75851 m .32855 .7668 L .32823 .7587 L F
.32799 .75893 m .32812 .7591 L .32817 .75903 L .683 .77 .917 r
F
.32823 .7587 m .32855 .7668 L .32788 .75898 L .356 .178 .497 r
F
.32868 .75189 m .32758 .76345 L .32864 .76427 L .908 .63 .503 r
F
.3287 .74762 m .32841 .75172 L .32868 .75189 L F
.32848 .75851 m .32823 .7587 L .32791 .75042 L .356 .178 .497 r
F
.32962 .75264 m .34367 .75189 L .33022 .75176 L .683 .77 .917 r
F
.32802 .75577 m .34187 .75098 L .33899 .74881 L F
.32807 .75456 m .32823 .7587 L .32789 .7547 L .356 .178 .497 r
F
.32536 .75746 m .32866 .75617 L .32802 .75577 L .683 .77 .917 r
F
.32956 .7534 m .34291 .75484 L .3306 .75259 L F
.32488 .75289 m .32874 .75404 L .32948 .75346 L F
.32878 .75208 m .32868 .75189 L .32867 .75617 L .986 .729 .347 r
F
.3286 .75415 m .32898 .76612 L .32855 .7668 L .071 0 .412 r
F
.32873 .7563 m .32867 .75617 L .32864 .76427 L .986 .729 .347 r
F
.32878 .75208 m .32867 .75617 L .32873 .7563 L F
.32866 .75617 m .32866 .75616 L .32802 .75577 L .683 .77 .917 r
F
.32866 .75616 m .34187 .75098 L .3284 .75564 L F
.32866 .75616 m .3284 .75564 L .32802 .75577 L F
.32841 .75172 m .32812 .75583 L .32868 .75189 L .908 .63 .503 r
F
.32713 .75504 m .32785 .76736 L .32687 .75516 L .517 .303 .528 r
F
.32536 .75746 m .32796 .75892 L .32859 .75842 L .683 .77 .917 r
F
.32812 .75583 m .32758 .76345 L .3283 .75594 L .908 .63 .503 r
F
.32812 .75583 m .3283 .75594 L .32868 .75189 L F
.32886 .70541 m .32794 .74714 L .3287 .74762 L F
.32791 .75042 m .32807 .75456 L .32789 .7547 L .356 .178 .497 r
F
.32488 .75289 m .32948 .75346 L .32944 .75338 L .683 .77 .917 r
F
.32488 .75289 m .32962 .75264 L .3297 .75253 L F
.32891 .75204 m .3297 .75253 L .33022 .75176 L F
.32488 .75289 m .3297 .75253 L .32891 .75204 L F
.32705 .70894 m .32791 .75042 L .32762 .75056 L .517 .303 .528 r
F
.3244 .74832 m .32931 .74885 L .32972 .74825 L .683 .77 .917 r
F
.32941 .74806 m .32972 .74825 L .32986 .74803 L F
.3244 .74832 m .32972 .74825 L .32941 .74806 L F
.32807 .7085 m .32841 .75003 L .32791 .75042 L .356 .178 .497 r
F
.32886 .70541 m .3278 .70459 L .32764 .74696 L .908 .63 .503 r
F
.33105 .74797 m .3431 .74733 L .3329 .74652 L .683 .77 .917 r
F
.32883 .74787 m .32868 .75189 L .32878 .75208 L .986 .729 .347 r
F
.32931 .70645 m .32874 .7477 L .32883 .74787 L F
.32874 .7477 m .32868 .75189 L .32883 .74787 L F
.3292 .70726 m .32915 .74851 L .32912 .74872 L 0 0 .131 r
F
.32931 .70645 m .32883 .74787 L .32915 .74851 L .986 .729 .347 r
F
.32793 .74609 m .33685 .74344 L .33796 .73971 L .683 .77 .917 r
F
.32886 .70541 m .32764 .74696 L .32794 .74714 L .908 .63 .503 r
F
.32709 .74662 m .32804 .74631 L .32793 .74609 L .683 .77 .917 r
F
.32804 .74631 m .33685 .74344 L .32793 .74609 L F
.32756 .75119 m .34139 .74641 L .33851 .74424 L F
.32643 .75096 m .32689 .75088 L .32687 .75516 L .641 .402 .541 r
F
.32721 .75937 m .32645 .76009 L .32728 .75944 L .683 .77 .917 r
F
.32622 .75955 m .32645 .76009 L .32721 .75937 L F
.32556 .75112 m .32555 .75118 L .32559 .75119 L F
.32643 .75096 m .32653 .75522 L .3253 .75116 L .641 .402 .541 r
F
.32589 .75533 m .32662 .75707 L .32705 .75512 L .683 .77 .917 r
F
.32653 .75522 m .32683 .7678 L .32569 .75537 L .641 .402 .541 r
F
.32653 .75522 m .32569 .75537 L .3253 .75116 L F
.32705 .75512 m .32662 .75707 L .32757 .75566 L .683 .77 .917 r
F
.32488 .75289 m .32589 .75533 L .32705 .75512 L F
.32536 .75746 m .32622 .75955 L .32721 .75937 L F
.32653 .75522 m .32687 .75516 L .32686 .75943 L .641 .402 .541 r
F
.32663 .75947 m .32686 .75943 L .32683 .7678 L F
.32653 .75522 m .32686 .75943 L .32663 .75947 L F
.32643 .75096 m .32687 .75516 L .32653 .75522 L F
.32488 .75289 m .32705 .75512 L .32799 .75463 L .683 .77 .917 r
F
.32705 .75512 m .32718 .75526 L .32744 .75505 L F
.32705 .75512 m .32744 .75505 L .32799 .75463 L F
.32715 .7593 m .32728 .75944 L .32788 .75898 L F
.32536 .75746 m .32715 .7593 L .32799 .75893 L F
.32762 .75123 m .3265 .76308 L .32758 .76345 L .809 .541 .534 r
F
.32764 .74696 m .33685 .74344 L .32709 .74662 L .683 .77 .917 r
F
.32773 .74702 m .32779 .74699 L .32764 .74696 L F
.32779 .74699 m .33685 .74344 L .32764 .74696 L F
.3244 .74832 m .32805 .75036 L .32934 .74979 L F
.32764 .74696 m .32677 .75102 L .32762 .75123 L .809 .541 .534 r
F
.3278 .70459 m .32686 .74677 L .32764 .74696 L F
.3244 .74832 m .32861 .74743 L .32847 .74716 L .683 .77 .917 r
F
.32779 .74699 m .32847 .74716 L .32829 .7468 L F
.32546 .70914 m .32705 .70894 L .32689 .75088 L .641 .402 .541 r
F
.3244 .74832 m .32847 .74716 L .32779 .74699 L .683 .77 .917 r
F
.3278 .70459 m .32672 .70422 L .32656 .74669 L .809 .541 .534 r
F
.32488 .75289 m .3282 .75159 L .32762 .75123 L .683 .77 .917 r
F
.32488 .75289 m .32762 .75123 L .32753 .75121 L F
.32546 .70914 m .32689 .75088 L .32643 .75096 L .641 .402 .541 r
F
.3244 .74832 m .33105 .74797 L .33239 .74692 L .683 .77 .917 r
F
.33124 .74687 m .33239 .74692 L .3329 .74652 L F
.3244 .74832 m .33239 .74692 L .33124 .74687 L F
.32656 .74669 m .32541 .76295 L .3265 .76308 L .734 .478 .541 r
F
.32672 .70422 m .32578 .74666 L .32656 .74669 L F
.3244 .74832 m .32592 .75198 L .32708 .75107 L .683 .77 .917 r
F
.32488 .75289 m .32669 .751 L .32655 .75097 L F
.32568 .75094 m .32626 .75096 L .32656 .74669 L .734 .478 .541 r
F
.32581 .75094 m .32655 .75097 L .32588 .75081 L .683 .77 .917 r
F
.32486 .75113 m .3253 .75116 L .32529 .75544 L .751 .492 .54 r
F
.32488 .75289 m .32655 .75097 L .32581 .75094 L .683 .77 .917 r
F
.3244 .74832 m .32773 .74702 L .32709 .74662 L F
.32578 .74666 m .32568 .75094 L .32656 .74669 L .734 .478 .541 r
F
.32559 .75521 m .32596 .75523 L .32626 .75096 L F
.32555 .75118 m .32393 .7595 L .32559 .75119 L .683 .77 .917 r
F
.32486 .75113 m .32529 .75544 L .32495 .75541 L .751 .492 .54 r
F
.32488 .75289 m .32477 .7554 L .32596 .7555 L .683 .77 .917 r
F
.32545 .75521 m .32643 .75522 L .32546 .75499 L F
.32536 .75746 m .32642 .75524 L .32545 .75521 L F
.32642 .75524 m .32643 .75522 L .32545 .75521 L F
.32568 .75094 m .32559 .75521 L .32626 .75096 L .734 .478 .541 r
F
.32559 .75521 m .32541 .76295 L .32596 .75523 L F
.32686 .74677 m .32656 .74669 L .32655 .75097 L .809 .541 .534 r
F
.32912 .74872 m .32915 .74851 L .32914 .75279 L 0 0 .131 r
F
.32912 .74872 m .32914 .75279 L .32911 .75295 L F
.32915 .74851 m .32902 .75256 L .32914 .75279 L .986 .729 .347 r
F
.32853 .75146 m .34316 .74902 L .34139 .74641 L .683 .77 .917 r
F
.32488 .75289 m .32998 .75181 L .32853 .75146 L F
.32998 .75181 m .34316 .74902 L .32853 .75146 L F
.32488 .75289 m .32802 .75465 L .32894 .7541 L F
.32677 .75102 m .32653 .75525 L .32667 .75528 L .809 .541 .534 r
F
.32686 .74677 m .3267 .75101 L .32677 .75102 L F
.3267 .75101 m .32653 .75525 L .32677 .75102 L F
.3267 .75101 m .32655 .75097 L .32653 .75525 L F
.32686 .74677 m .32655 .75097 L .3267 .75101 L F
.32794 .74714 m .32764 .74696 L .32762 .75123 L .908 .63 .503 r
F
.32861 .74743 m .3329 .74652 L .32829 .7468 L .683 .77 .917 r
F
.32588 .75081 m .33469 .74266 L .3302 .74178 L F
.32794 .74714 m .32784 .75137 L .3287 .74762 L .908 .63 .503 r
F
.32669 .751 m .33469 .74266 L .32588 .75081 L .683 .77 .917 r
F
.32686 .74677 m .32677 .75102 L .32764 .74696 L .809 .541 .534 r
F
.32753 .75121 m .32762 .75123 L .32756 .75119 L .683 .77 .917 r
F
.32794 .74714 m .32762 .75123 L .32784 .75137 L .908 .63 .503 r
F
.32784 .75137 m .32841 .75172 L .3287 .74762 L F
.32546 .75499 m .33068 .74635 L .32583 .74622 L .683 .77 .917 r
F
.32677 .75102 m .32667 .75528 L .32762 .75123 L .809 .541 .534 r
F
.32667 .75528 m .3265 .76308 L .32723 .75542 L F
.32667 .75528 m .32723 .75542 L .32762 .75123 L F
.32931 .74885 m .34234 .75026 L .32986 .74803 L .683 .77 .917 r
F
.32897 .74935 m .32904 .74924 L .32903 .75352 L .071 0 .412 r
F
.32878 .75208 m .32902 .75256 L .32915 .74851 L .986 .729 .347 r
F
.3282 .75159 m .34139 .74641 L .32756 .75119 L .683 .77 .917 r
F
.32643 .75522 m .33517 .74723 L .33068 .74635 L F
.32536 .75746 m .3273 .75544 L .32643 .75522 L F
.3273 .75544 m .33517 .74723 L .32643 .75522 L F
.32883 .74787 m .32878 .75208 L .32915 .74851 L .986 .729 .347 r
F
.32643 .75522 m .33068 .74635 L .32546 .75499 L .683 .77 .917 r
F
.32667 .75528 m .32653 .75525 L .3265 .76308 L .809 .541 .534 r
F
.3278 .70459 m .32656 .74669 L .32686 .74677 L F
.32944 .75338 m .32948 .75346 L .32956 .7534 L .683 .77 .917 r
F
.32737 .75536 m .33899 .74881 L .33517 .74723 L F
.32536 .75746 m .32802 .75577 L .32737 .75536 L F
.32773 .75904 m .32785 .76736 L .32737 .7592 L .517 .303 .528 r
F
.32784 .75137 m .32758 .76345 L .32841 .75172 L .908 .63 .503 r
F
.32899 .75357 m .32903 .75352 L .32901 .7578 L .071 0 .412 r
F
.32802 .75577 m .33899 .74881 L .32737 .75536 L .683 .77 .917 r
F
.32784 .75137 m .32762 .75123 L .32761 .75551 L .908 .63 .503 r
F
.32775 .7556 m .32761 .75551 L .32758 .76345 L F
.32784 .75137 m .32761 .75551 L .32775 .7556 L F
.32829 .7468 m .3329 .74652 L .33685 .74344 L .683 .77 .917 r
F
.3329 .74652 m .34258 .74447 L .33685 .74344 L F
.33685 .74344 m .34083 .74187 L .33982 .74111 L F
.33685 .74344 m .33982 .74111 L .33796 .73971 L F
.32874 .75404 m .34091 .75765 L .32956 .7534 L F
.32866 .75616 m .34363 .75359 L .34187 .75098 L F
.32536 .75746 m .32894 .7567 L .32866 .75616 L F
.32902 .75256 m .32864 .76427 L .32914 .75279 L .986 .729 .347 r
F
.32894 .7567 m .34363 .75359 L .32866 .75616 L .683 .77 .917 r
F
.32878 .75208 m .32873 .7563 L .32902 .75256 L .986 .729 .347 r
F
.32873 .7563 m .32864 .76427 L .32889 .75661 L F
.32873 .7563 m .32889 .75661 L .32902 .75256 L F
.32788 .75898 m .33434 .76669 L .32799 .75893 L .683 .77 .917 r
F
.33386 .76212 m .35077 .76736 L .33783 .76013 L F
.32859 .75842 m .33831 .7647 L .34139 .76221 L F
.32672 .70422 m .32564 .70409 L .32548 .74665 L .734 .478 .541 r
F
.32447 .74679 m .32456 .74661 L .32447 .74661 L .683 .77 .917 r
F
.3244 .74832 m .32518 .74669 L .32447 .74679 L F
.32469 .74676 m .32435 .75535 L .32449 .75534 L .66 .417 .541 r
F
.3244 .74832 m .32427 .75135 L .32556 .75112 L .683 .77 .917 r
F
.32609 .74657 m .33796 .73971 L .33416 .73814 L F
.3244 .74832 m .32747 .74638 L .32609 .74657 L F
.32747 .74638 m .33796 .73971 L .32609 .74657 L F
.32536 .75746 m .32545 .75521 L .32544 .75521 L F
.32488 .75289 m .32496 .751 L .32414 .75111 L F
.32469 .74676 m .32432 .76304 L .32548 .74665 L .66 .417 .541 r
F
.32447 .75534 m .32544 .75521 L .3244 .75516 L .683 .77 .917 r
F
.32536 .75746 m .32544 .75521 L .32447 .75534 L F
.32544 .75521 m .32432 .76304 L .32541 .76295 L .66 .417 .541 r
F
.32548 .74665 m .32487 .75528 L .32544 .75521 L F
.32487 .75528 m .32432 .76304 L .32544 .75521 L F
.32564 .70409 m .32469 .74676 L .32548 .74665 L F
.32457 .74678 m .32446 .75106 L .32469 .74676 L F
.32446 .75106 m .32435 .75535 L .32452 .75106 L F
.32446 .75106 m .32452 .75106 L .32469 .74676 L F
.3244 .74832 m .32487 .73714 L .32002 .73778 L .683 .77 .917 r
F
.32414 .75111 m .32535 .74165 L .32047 .74229 L F
.32496 .751 m .32535 .74165 L .32414 .75111 L F
.32349 .75137 m .32339 .75568 L .32437 .75108 L .568 .344 .535 r
F
.32359 .74707 m .32327 .75145 L .32349 .75137 L F
.32247 .74773 m .32238 .75206 L .32328 .74717 L .4 .212 .507 r
F
.32405 .75091 m .32047 .74229 L .32339 .75136 L .683 .77 .917 r
F
.3244 .75516 m .32583 .74622 L .32095 .74686 L F
.32578 .74666 m .32548 .74665 L .32546 .75093 L .734 .478 .541 r
F
.32672 .75098 m .33851 .74424 L .33469 .74266 L .683 .77 .917 r
F
.32488 .75289 m .32783 .75102 L .32672 .75098 L F
.32783 .75102 m .33851 .74424 L .32672 .75098 L F
.32568 .75094 m .32544 .75521 L .32559 .75521 L .734 .478 .541 r
F
.32578 .74666 m .32561 .75093 L .32568 .75094 L F
.32561 .75093 m .32544 .75521 L .32568 .75094 L F
.32561 .75093 m .32546 .75093 L .32544 .75521 L F
.32578 .74666 m .32546 .75093 L .32561 .75093 L F
.32456 .74661 m .3297 .73726 L .32447 .74661 L .683 .77 .917 r
F
.32518 .74669 m .3297 .73726 L .32447 .74679 L F
.3244 .74832 m .33416 .73814 L .3297 .73726 L F
.32496 .75091 m .3302 .74178 L .32535 .74165 L F
.32488 .75289 m .32581 .75094 L .32496 .75091 L F
.32581 .75094 m .3302 .74178 L .32496 .75091 L F
.32545 .75521 m .32583 .74622 L .3244 .75516 L F
.32559 .75521 m .32544 .75521 L .32541 .76295 L .734 .478 .541 r
F
.32672 .70422 m .32548 .74665 L .32578 .74666 L F
.32447 .74661 m .3297 .73726 L .32487 .73714 L .683 .77 .917 r
F
.32564 .70409 m .32457 .74678 L .32469 .74676 L .66 .417 .541 r
F
.32447 .75534 m .32447 .75532 L .32435 .75535 L .683 .77 .917 r
F
.32447 .75534 m .32435 .75535 L .32356 .75562 L F
.32339 .75568 m .32396 .75549 L .32437 .75108 L .568 .344 .535 r
F
.32349 .75137 m .32327 .75145 L .32325 .75573 L F
.32349 .75137 m .32325 .75573 L .32339 .75568 L F
.32447 .75532 m .32095 .74686 L .32356 .75562 L .683 .77 .917 r
F
.32339 .75568 m .32322 .76338 L .32396 .75549 L .568 .344 .535 r
F
.32263 .75594 m .31637 .74823 L .3124 .75022 L .683 .77 .917 r
F
.32356 .75562 m .31637 .74823 L .32263 .75594 L F
.32339 .75568 m .32325 .75573 L .32322 .76338 L .568 .344 .535 r
F
.32455 .70418 m .32328 .74717 L .32359 .74707 L F
.32339 .75136 m .32047 .74229 L .31589 .74366 L .683 .77 .917 r
F
.32298 .75505 m .32322 .75942 L .32273 .75496 L .844 .572 .526 r
F
.32228 .7564 m .3221 .76415 L .32325 .75573 L .4 .212 .507 r
F
.32206 .75876 m .31457 .7617 L .32264 .75919 L .683 .77 .917 r
F
.31126 .76154 m .30528 .77334 L .31508 .76312 L F
.31457 .7617 m .30885 .76394 L .31378 .76224 L F
.31457 .7617 m .31378 .76224 L .32264 .75919 L F
.32345 .70451 m .32217 .74794 L .32235 .74781 L .4 .212 .507 r
F
.32228 .7564 m .32213 .7565 L .3221 .76415 L F
.31378 .76224 m .30885 .76394 L .31002 .76483 L .683 .77 .917 r
F
.31378 .76224 m .31002 .76483 L .31174 .76611 L F
.43822 .90648 m .43848 .90272 L .4295 .8999 L .793 .551 .572 r
F
0 g
.43848 .90272 m
.44612 .9068 L
s
.2824 .66121 m .26107 .65405 L .25316 .66513 L .673 .757 .914 r
F
.75731 .66039 m .75869 .64426 L .75138 .65899 L .673 .758 .914 r
F
.75731 .66039 m .77056 .64706 L .75869 .64426 L F
.28452 .78339 m .29549 .78355 L .29597 .78812 L .859 .591 .533 r
F
.28452 .78339 m .28404 .77883 L .29549 .78355 L F
.29765 .77019 m .29549 .78355 L .30528 .77334 L .683 .77 .917 r
F
.29765 .77019 m .28404 .77883 L .29549 .78355 L F
0 g
.29549 .78355 m
.29958 .78435 L
s
.26104 .65961 m .2528 .66507 L .25309 .67074 L .162 .067 .491 r
F
.26104 .65961 m .26075 .65394 L .2528 .66507 L F
0 g
.24978 .67691 m
.2528 .66507 L
s
.76277 .66832 m .77103 .6526 L .75772 .666 L .673 .758 .914 r
F
.76277 .66832 m .78114 .65724 L .77103 .6526 L F
.3637 .77459 m .36322 .77002 L .37247 .76258 L .403 .259 .569 r
F
0 g
.35638 .77345 m
.36322 .77002 L
s
.3321 .66082 m .32628 .64529 L .32566 .66042 L .673 .757 .914 r
F
.3321 .66082 m .33917 .64609 L .32628 .64529 L F
.35016 .76272 m .36302 .76992 L .37223 .76251 L .683 .77 .917 r
F
.34227 .76668 m .36302 .76992 L .35016 .76272 L F
.127 .923 .03 r
.34455 .70828 m
.34483 .75438 L
s
.34485 .75642 m
.34486 .75882 L
s
.34455 .70828 m
.34542 .75456 L
s
.34545 .7565 m
.3455 .75901 L
s
.39884 .67375 m .3915 .65722 L .3918 .66289 L .987 .712 .386 r
F
0 g
.39884 .67375 m
.40088 .68549 L
s
0 0 0 r
2.5 Mabswid
.59948 .68153 Mdot
.54242 .77808 m .52452 .77615 L .52218 .78492 L .683 .77 .917 r
F
.52475 .78069 m .5219 .78493 L .52239 .7895 L 0 0 .39 r
F
.127 .923 .03 r
.5 Mabswid
.40028 8.82654 m
.58799 1.1516 L
s
0 g
.52257 .78883 m
.52268 .78948 L
s
.52475 .78069 m .52425 .77612 L .5219 .78493 L 0 0 .39 r
F
.56184 .67692 m .54313 .67613 L .54345 .68181 L .603 .397 .575 r
F
0 g
.5275 .68933 m
.54345 .68181 L
s
.56184 .67692 m .56151 .67125 L .54313 .67613 L .603 .397 .575 r
F
0 g
.52719 .68366 m
.54313 .67613 L
s
.60048 .67053 m .60015 .66486 L .58075 .66367 L .733 .497 .57 r
F
0 g
.60015 .66486 m
.61806 .66908 L
s
.61872 .68043 m .60048 .67053 L .6008 .67621 L .794 .544 .56 r
F
0 g
.61872 .68043 m
.63392 .68738 L
s
.47634 .53415 m .44669 .54306 L .4772 .53942 L .654 .726 .902 r
F
.47634 .53415 m .44497 .5325 L .44669 .54306 L F
.28278 .67248 m .25338 .67642 L .27747 .6799 L .673 .758 .914 r
F
.31917 .66105 m .31331 .64656 L .30113 .6498 L .673 .757 .914 r
F
.32566 .66042 m .31331 .64656 L .31917 .66105 L F
.56071 .78457 m .54116 .7885 L .55992 .7875 L .683 .77 .917 r
F
.25302 .512 m .25237 .53208 L .26857 .53156 L .654 .726 .902 r
F
.24496 .5109 m .25237 .53208 L .25302 .512 L F
.24496 .5109 m .23626 .52987 L .25237 .53208 L F
.56787 .5494 m .60185 .54071 L .57047 .53907 L F
.5378 .54259 m .56787 .5494 L .57047 .53907 L F
.53446 .54729 m .56787 .5494 L .5378 .54259 L F
.127 .923 .03 r
.57913 5.88938 m
.60022 5.1526 L
s
.60022 5.1526 m
.70591 1.46137 L
s
.532 7.53522 m
.57913 5.88938 L
s
.49577 8.80062 m
.532 7.53522 L
s
0 0 0 r
2.5 Mabswid
.72519 .78806 Mdot
.59794 .79007 m .61574 .78334 L .59746 .78721 L .683 .771 .917 r
F
.77155 .78331 m .78301 .77277 L .78353 .77734 L .525 .347 .582 r
F
.76275 .77409 m .77155 .78331 L .78353 .77734 L .683 .771 .917 r
F
.75357 .77681 m .77155 .78331 L .76275 .77409 L F
0 g
.5 Mabswid
.75778 .78739 m
.77155 .78331 L
s
.73236 .66085 m .72062 .64798 L .71 .65298 L .673 .758 .914 r
F
.73846 .65923 m .72062 .64798 L .73236 .66085 L F
.72348 .67786 m .70218 .67066 L .69676 .67808 L .673 .758 .915 r
F
.72764 .67464 m .70218 .67066 L .72348 .67786 L F
.32566 .66042 m .32628 .64529 L .31331 .64656 L .673 .757 .914 r
F
.78818 .6578 m .79891 .64066 L .78062 .65168 L .673 .758 .914 r
F
.78818 .6578 m .81025 .64985 L .79891 .64066 L F
.127 .923 .03 r
.80646 .63716 m
.80929 .57959 L
s
.77207 .55039 m .74821 .53978 L .74781 .54706 L .732 .488 .558 r
F
0 g
.74821 .53978 m
.77246 .54312 L
s
.72375 .54057 m
.74821 .53978 L
s
.33842 .66782 m .33954 .65161 L .33243 .66641 L .673 .757 .914 r
F
.33842 .66782 m .35153 .65443 L .33954 .65161 L F
.34382 .67581 m .35183 .6601 L .33872 .67349 L .673 .758 .914 r
F
.34382 .67581 m .36202 .66474 L .35183 .6601 L F
.79406 .56489 m .77207 .55039 L .77168 .55767 L .794 .542 .557 r
F
0 g
.79406 .56489 m
.81305 .57551 L
s
.30649 .54959 m
.31531 .54931 L
s
.7273 .66897 m .71017 .65854 L .70184 .66499 L .673 .758 .914 r
F
.73264 .66646 m .71017 .65854 L .7273 .66897 L F
.35231 .5595 m .35276 .55222 L .32848 .54889 L .732 .488 .559 r
F
0 g
.35276 .55222 m
.37523 .55945 L
s
.74345 .75768 m .7428 .76885 L .7525 .76758 L .683 .771 .917 r
F
.74345 .75768 m .7525 .76758 L .74831 .75704 L F
.74396 .76231 m .7433 .77353 L .75306 .77225 L F
.74396 .76231 m .75306 .77225 L .74884 .76166 L F
.74318 .70706 m .74474 .70732 L .74496 .74934 L .751 .492 .54 r
F
.74534 .74959 m .74345 .75768 L .74831 .75704 L .683 .771 .917 r
F
.74525 .74937 m .74519 .74966 L .74534 .74959 L F
.74519 .74966 m .74345 .75768 L .74534 .74959 L F
.74568 .75373 m .74396 .76231 L .74884 .76166 L F
.74393 .74953 m .74345 .75768 L .74521 .74936 L F
.74496 .74934 m .74521 .74936 L .74522 .7493 L F
.74393 .74953 m .74521 .74936 L .74496 .74934 L F
.74154 .706 m .7422 .70659 L .74242 .74886 L .929 .648 .486 r
F
.74112 .70449 m .74117 .7053 L .74139 .74778 L .769 .613 .047 r
F
.74286 .74902 m .74256 .74964 L .74394 .74941 L .683 .771 .917 r
F
.74381 .75164 m .74177 .75397 L .74345 .75768 L F
.74177 .75397 m .742 .75764 L .74345 .75768 L F
.74342 .75349 m .74329 .75376 L .74447 .75358 L F
.74329 .75376 m .73912 .76218 L .74402 .7543 L F
.74329 .75376 m .74402 .7543 L .74447 .75358 L F
.74162 .75154 m .7417 .75285 L .74316 .75061 L F
.7428 .74914 m .73751 .75378 L .73864 .75756 L F
.73751 .75378 m .7342 .75668 L .73569 .75697 L F
.73751 .75378 m .73569 .75697 L .73864 .75756 L F
.74112 .70449 m .74138 .74758 L .74135 .74707 L .769 .613 .047 r
F
.74117 .7053 m .74166 .74821 L .74139 .74778 L .988 .719 .38 r
F
.74112 .70449 m .74139 .74778 L .74138 .74758 L .769 .613 .047 r
F
.74117 .7053 m .74154 .706 L .74176 .74838 L .988 .719 .38 r
F
.74166 .70347 m .74112 .70449 L .74135 .74707 L 0 0 .386 r
F
.73864 .75756 m .7428 .76885 L .74345 .75768 L .683 .771 .917 r
F
.74429 .75665 m .73912 .76218 L .74396 .76231 L F
.74446 .75387 m .74349 .75537 L .74429 .75665 L F
.74349 .75537 m .73912 .76218 L .74429 .75665 L F
.73864 .75756 m .73318 .7686 L .7428 .76885 L F
.73912 .76218 m .73363 .77328 L .7433 .77353 L F
.73466 .7613 m .73363 .77328 L .73912 .76218 L F
.74331 .75933 m .73517 .76587 L .73964 .76675 L F
.74321 .75342 m .74342 .75349 L .74344 .75777 L .845 .571 .524 r
F
.73912 .76218 m .7433 .77353 L .74396 .76231 L .683 .771 .917 r
F
.74497 .75832 m .73964 .76675 L .74447 .76687 L F
.74391 .74996 m .7433 .75083 L .74381 .75164 L F
.74394 .74941 m .74369 .7498 L .74391 .74996 L F
.74447 .75358 m .74432 .75382 L .74446 .75387 L F
.74443 .75428 m .74396 .76231 L .74568 .75373 L F
.74452 .74931 m .74479 .75788 L .7434 .74921 L .751 .492 .54 r
F
.745 .7579 m .74398 .75796 L .74497 .75832 L .683 .771 .917 r
F
.74405 .75782 m .74398 .75796 L .745 .7579 L F
.74479 .75788 m .74505 .76618 L .74424 .75783 L .751 .492 .54 r
F
.74479 .75788 m .74424 .75783 L .7434 .74921 L F
.74447 .75358 m .74443 .75428 L .74566 .75368 L .683 .771 .917 r
F
.74465 .75359 m .74499 .75362 L .74505 .76618 L .751 .492 .54 r
F
.74513 .75564 m .74405 .75782 L .745 .7579 L .683 .771 .917 r
F
.74398 .75796 m .73964 .76675 L .74497 .75832 L F
.74246 .75741 m .74348 .76592 L .7425 .76545 L .845 .571 .524 r
F
.74197 .7487 m .7382 .75257 L .74286 .74902 L .683 .771 .917 r
F
.7382 .75257 m .7342 .75668 L .73754 .75373 L F
.7382 .75257 m .73754 .75373 L .74286 .74902 L F
.74177 .75397 m .73864 .75756 L .742 .75764 L F
.7342 .75668 m .73318 .7686 L .73864 .75756 L F
.74329 .75376 m .73466 .7613 L .73912 .76218 L F
.7434 .74921 m .74382 .75352 L .74342 .75349 L .751 .492 .54 r
F
.74462 .75107 m .74254 .75321 L .74329 .75376 L .683 .771 .917 r
F
.74254 .75321 m .73466 .7613 L .74329 .75376 L F
.74256 .74964 m .74162 .75154 L .74316 .75061 L F
.74223 .74872 m .74242 .74886 L .74244 .75314 L .929 .648 .486 r
F
.7433 .75083 m .73864 .75756 L .74381 .75164 L .683 .771 .917 r
F
.74257 .75318 m .74208 .75313 L .74229 .75346 L F
.74208 .75313 m .74147 .75305 L .74229 .75346 L F
.74174 .75288 m .74147 .75305 L .74249 .75317 L F
.74244 .75314 m .74249 .75317 L .74257 .75318 L F
.74174 .75288 m .74249 .75317 L .74244 .75314 L F
.74178 .75265 m .7425 .76545 L .74185 .76486 L .929 .648 .486 r
F
.74176 .74838 m .74195 .75278 L .74178 .75265 L F
.74195 .75278 m .7425 .76545 L .74178 .75265 L F
.74154 .706 m .74223 .74872 L .74176 .74838 L F
.74154 .706 m .74242 .74886 L .74223 .74872 L F
.74276 .74911 m .7342 .75668 L .7428 .74914 L .683 .771 .917 r
F
.7422 .70659 m .74312 .74911 L .74242 .74886 L .845 .571 .524 r
F
.7422 .70659 m .74318 .70706 L .7434 .74921 L F
.7422 .70659 m .7434 .74921 L .74331 .74918 L F
.74197 .7487 m .73044 .75511 L .7342 .75668 L .683 .771 .917 r
F
.74411 .7465 m .74112 .74839 L .74197 .7487 L F
.74112 .74839 m .73044 .75511 L .74197 .7487 L F
.74312 .74911 m .74342 .75349 L .74321 .75342 L .845 .571 .524 r
F
.7422 .70659 m .74331 .74918 L .74312 .74911 L F
.74256 .74964 m .74316 .75061 L .74394 .74941 L .683 .771 .917 r
F
.74369 .7498 m .73864 .75756 L .74391 .74996 L F
.74331 .74918 m .74342 .75349 L .74312 .74911 L .845 .571 .524 r
F
.74318 .70706 m .74452 .74931 L .7434 .74921 L .751 .492 .54 r
F
.74411 .7465 m .73757 .74906 L .73044 .75511 L .683 .771 .917 r
F
.73757 .74906 m .72761 .75295 L .72961 .75448 L F
.73757 .74906 m .72961 .75448 L .73044 .75511 L F
.74279 .70269 m .74166 .70347 L .74188 .74612 L .405 .218 .51 r
F
.74223 .74872 m .7423 .75304 L .74176 .74838 L .929 .648 .486 r
F
.7423 .75304 m .74195 .75278 L .74176 .74838 L F
.7423 .75304 m .7425 .76545 L .74195 .75278 L F
.74214 .75024 m .74193 .75467 L .74208 .75457 L .405 .218 .51 r
F
.73757 .74906 m .7259 .75036 L .72761 .75295 L .683 .771 .917 r
F
.74411 .7465 m .74007 .74736 L .73757 .74906 L F
.74007 .74736 m .7259 .75036 L .73757 .74906 L F
.7422 .74591 m .742 .75033 L .74214 .75024 L .405 .218 .51 r
F
.74279 .70269 m .74207 .74599 L .7422 .74591 L F
.74207 .74599 m .742 .75033 L .7422 .74591 L F
.74223 .74872 m .74244 .75314 L .7423 .75304 L .929 .648 .486 r
F
.74063 .75263 m .72631 .75494 L .72803 .75755 L .683 .771 .917 r
F
.74242 .74886 m .74269 .75323 L .74244 .75314 L .845 .571 .524 r
F
.74462 .75107 m .7411 .75182 L .74063 .75263 L .683 .771 .917 r
F
.7411 .75182 m .72631 .75494 L .74063 .75263 L F
.74182 .76261 m .74185 .76486 L .74179 .76268 L .988 .719 .38 r
F
.74262 .75822 m .73517 .76587 L .74331 .75933 L .683 .771 .917 r
F
.74182 .76261 m .74179 .76268 L .74151 .75222 L .988 .719 .38 r
F
.74162 .75154 m .73864 .75756 L .7417 .75285 L .683 .771 .917 r
F
.74147 .75305 m .73088 .75972 L .74155 .75423 L F
.74113 .75585 m .72716 .7537 L .72635 .75664 L F
.73978 .75412 m .73593 .75447 L .73088 .75972 L F
.74138 .74758 m .7414 .75191 L .74135 .74707 L .769 .613 .047 r
F
.73044 .75511 m .7243 .76685 L .7342 .75668 L .683 .771 .917 r
F
.73593 .75447 m .72803 .75755 L .72962 .75877 L F
.73593 .75447 m .72962 .75877 L .73088 .75972 L F
.74144 .75642 m .72635 .75664 L .72682 .75951 L F
.7423 .75304 m .74246 .75741 L .74237 .75735 L .929 .648 .486 r
F
.74432 .75382 m .73912 .76218 L .74446 .75387 L .683 .771 .917 r
F
.74244 .75314 m .74296 .7576 L .74246 .75741 L .845 .571 .524 r
F
.74229 .75346 m .74147 .75305 L .74155 .75423 L .683 .771 .917 r
F
.74151 .75222 m .74163 .75665 L .74141 .75206 L .988 .719 .38 r
F
.74163 .75665 m .74185 .76486 L .74156 .75655 L F
.74163 .75665 m .74156 .75655 L .74141 .75206 L F
.74513 .75564 m .7414 .75584 L .74143 .75634 L .683 .771 .917 r
F
.74148 .75641 m .74143 .75634 L .74144 .75642 L F
.74513 .75564 m .74143 .75634 L .74148 .75641 L F
.7414 .75584 m .72635 .75664 L .74144 .75642 L F
.7414 .75191 m .74143 .75624 L .74138 .75153 L .769 .613 .047 r
F
.73466 .7613 m .72471 .77152 L .73363 .77328 L .683 .771 .917 r
F
.73606 .76496 m .73139 .76429 L .73517 .76587 L F
.74513 .75564 m .73927 .75933 L .73606 .76496 L F
.73927 .75933 m .73139 .76429 L .73606 .76496 L F
.74176 .75685 m .74182 .76261 L .74164 .75667 L .988 .719 .38 r
F
.74143 .75634 m .74185 .76486 L .74147 .76417 L F
.74193 .75467 m .74143 .76336 L .74197 .76233 L 0 0 .386 r
F
.74191 .7504 m .74174 .75501 L .74193 .75467 L F
.74239 .75736 m .73349 .76042 L .73139 .76429 L .683 .771 .917 r
F
.74156 .75655 m .74185 .76486 L .74143 .75634 L .988 .719 .38 r
F
.74174 .75501 m .74143 .76336 L .74193 .75467 L 0 0 .386 r
F
.74143 .75624 m .74147 .76417 L .74141 .756 L .769 .613 .047 r
F
.74143 .75624 m .74141 .756 L .74138 .75153 L F
.7414 .75191 m .74138 .75153 L .74135 .74707 L F
.74147 .75305 m .74063 .75263 L .73978 .75412 L .683 .771 .917 r
F
.74462 .75107 m .74143 .75232 L .74147 .75305 L F
.74143 .75232 m .74063 .75263 L .74147 .75305 L F
.74063 .75263 m .73593 .75447 L .73978 .75412 L F
.74139 .74778 m .74151 .75222 L .74141 .75206 L .988 .719 .38 r
F
.74135 .74707 m .74138 .75153 L .74137 .75134 L .769 .613 .047 r
F
.74149 .7468 m .74135 .74707 L .74137 .75134 L 0 0 .386 r
F
.74138 .75153 m .74141 .756 L .74137 .75134 L .769 .613 .047 r
F
.74141 .756 m .74147 .76417 L .74141 .75587 L F
.74141 .756 m .74141 .75587 L .74137 .75134 L F
.74513 .75564 m .7416 .75526 L .7414 .75584 L .683 .771 .917 r
F
.74141 .75206 m .74156 .75655 L .74143 .75634 L .988 .719 .38 r
F
.74148 .75115 m .74139 .75562 L .74146 .7555 L 0 0 .386 r
F
.7416 .75526 m .74137 .75523 L .74139 .75562 L .683 .771 .917 r
F
.7416 .75526 m .74139 .75562 L .7414 .75584 L F
.74117 .7053 m .74176 .74838 L .74166 .74821 L .988 .719 .38 r
F
.74007 .74736 m .72543 .7475 L .7259 .75036 L .683 .771 .917 r
F
.74411 .7465 m .74109 .74666 L .74007 .74736 L F
.74109 .74666 m .72543 .7475 L .74007 .74736 L F
.74321 .75342 m .74344 .75777 L .74331 .75772 L .845 .571 .524 r
F
.74513 .75564 m .74144 .75642 L .74148 .75707 L .683 .771 .917 r
F
.74237 .75735 m .74246 .75741 L .7425 .76545 L .929 .648 .486 r
F
.74398 .75796 m .74262 .75822 L .74331 .75933 L .683 .771 .917 r
F
.74316 .75767 m .74262 .75822 L .74398 .75796 L F
.74286 .74902 m .74276 .74911 L .7428 .74914 L F
.74312 .74911 m .74321 .75342 L .74242 .74886 L .845 .571 .524 r
F
.74321 .75342 m .74348 .76592 L .74269 .75323 L F
.74321 .75342 m .74269 .75323 L .74242 .74886 L F
.73964 .75212 m .72584 .75207 L .72631 .75494 L .683 .771 .917 r
F
.7422 .74591 m .74214 .75024 L .74301 .74535 L .405 .218 .51 r
F
.74138 .74758 m .74141 .75206 L .74141 .75196 L .769 .613 .047 r
F
.74462 .75107 m .74129 .75008 L .74133 .75072 L .683 .771 .917 r
F
.7423 .75304 m .74244 .75314 L .74246 .75741 L .929 .648 .486 r
F
.73775 .75144 m .72584 .75207 L .73964 .75212 L .683 .771 .917 r
F
.74133 .75072 m .72869 .74632 L .72665 .74913 L F
.74142 .75124 m .72665 .74913 L .72584 .75207 L F
.74462 .75107 m .7417 .75076 L .74142 .75124 L F
.74171 .75253 m .74151 .75222 L .74139 .74778 L .988 .719 .38 r
F
.7417 .75076 m .72665 .74913 L .74142 .75124 L .683 .771 .917 r
F
.74166 .74821 m .74171 .75253 L .74139 .74778 L .988 .719 .38 r
F
.74149 .7468 m .74148 .75115 L .74188 .74612 L 0 0 .386 r
F
.74462 .75107 m .7406 .75129 L .73964 .75212 L .683 .771 .917 r
F
.74171 .75253 m .74176 .75685 L .74151 .75222 L .988 .719 .38 r
F
.74176 .75685 m .74164 .75667 L .74151 .75222 L F
.7416 .75526 m .7292 .75089 L .72716 .7537 L .683 .771 .917 r
F
.74513 .75564 m .74192 .75468 L .7416 .75526 L F
.74166 .74821 m .74176 .74838 L .74181 .75693 L .988 .719 .38 r
F
.74176 .75685 m .74181 .75693 L .74185 .76486 L F
.74166 .74821 m .74181 .75693 L .74176 .75685 L F
.74146 .7555 m .74165 .75517 L .74177 .75064 L 0 0 .386 r
F
.74261 .75421 m .73872 .75202 L .74192 .75468 L .683 .771 .917 r
F
.73872 .75202 m .73232 .7484 L .73933 .75299 L F
.73872 .75202 m .73933 .75299 L .74192 .75468 L F
.74177 .75064 m .74143 .76336 L .74191 .7504 L 0 0 .386 r
F
.74192 .75468 m .7292 .75089 L .7416 .75526 L .683 .771 .917 r
F
.74148 .75115 m .74146 .7555 L .74177 .75064 L 0 0 .386 r
F
.74146 .7555 m .74143 .76336 L .74165 .75517 L F
.74148 .75115 m .74177 .75064 L .74188 .74612 L F
.74192 .75468 m .73232 .7484 L .7292 .75089 L .683 .771 .917 r
F
.74269 .75323 m .74296 .7576 L .74244 .75314 L .845 .571 .524 r
F
.74513 .75564 m .74261 .75421 L .74192 .75468 L .683 .771 .917 r
F
.74214 .75024 m .74208 .75457 L .74274 .74983 L .405 .218 .51 r
F
.74513 .75564 m .74181 .75694 L .74239 .75736 L .683 .771 .917 r
F
.74208 .75457 m .74197 .76233 L .74246 .75431 L .405 .218 .51 r
F
.74237 .75249 m .74174 .75288 L .74228 .75308 L .683 .771 .917 r
F
.74237 .75249 m .74228 .75308 L .74257 .75318 L F
.74462 .75107 m .74237 .75249 L .74257 .75318 L F
.74208 .75457 m .74246 .75431 L .74274 .74983 L .405 .218 .51 r
F
.74411 .7465 m .74197 .7487 L .74286 .74902 L .683 .771 .917 r
F
.74214 .75024 m .74274 .74983 L .74301 .74535 L .405 .218 .51 r
F
.7406 .75129 m .73775 .75144 L .73947 .75206 L .683 .771 .917 r
F
.7406 .75129 m .73947 .75206 L .73964 .75212 L F
.74296 .7576 m .74348 .76592 L .74246 .75741 L .845 .571 .524 r
F
.74301 .74535 m .74197 .76233 L .7431 .76155 L .405 .218 .51 r
F
.74279 .70269 m .7422 .74591 L .74301 .74535 L F
.74129 .75008 m .72869 .74632 L .74133 .75072 L .683 .771 .917 r
F
.74138 .74758 m .74139 .74778 L .74141 .75206 L .769 .613 .047 r
F
.74141 .75196 m .74141 .75206 L .74143 .75634 L F
.74143 .75624 m .74143 .75634 L .74147 .76417 L F
.74138 .74758 m .74143 .75634 L .74143 .75624 L F
.74155 .75423 m .73088 .75972 L .73466 .7613 L .683 .771 .917 r
F
.7342 .75668 m .7243 .76685 L .73318 .7686 L F
.74148 .75707 m .72682 .75951 L .72854 .76212 L F
.74144 .75642 m .72682 .75951 L .74148 .75707 L F
.74148 .75115 m .74137 .75134 L .74139 .75562 L 0 0 .386 r
F
.74137 .75134 m .74147 .76417 L .74143 .76336 L .769 .613 .047 r
F
.74146 .7555 m .74139 .75562 L .74143 .76336 L 0 0 .386 r
F
.74149 .7468 m .74137 .75134 L .74148 .75115 L F
.7414 .75584 m .74069 .75516 L .74113 .75585 L .683 .771 .917 r
F
.74137 .75523 m .74069 .75516 L .7414 .75584 L F
.74069 .75516 m .72716 .7537 L .74113 .75585 L F
.74188 .74612 m .74177 .75064 L .74191 .7504 L 0 0 .386 r
F
.742 .75033 m .74193 .75467 L .74214 .75024 L .405 .218 .51 r
F
.74166 .70347 m .74149 .7468 L .74188 .74612 L 0 0 .386 r
F
.74166 .70347 m .74135 .74707 L .74149 .7468 L F
.74069 .74613 m .72826 .74177 L .72623 .74457 L .683 .771 .917 r
F
.74411 .7465 m .74171 .74579 L .74069 .74613 L F
.74171 .74579 m .72826 .74177 L .74069 .74613 L F
.74389 .70236 m .74279 .70269 L .74301 .74535 L .57 .345 .536 r
F
.74171 .74579 m .73136 .73929 L .72826 .74177 L .683 .771 .917 r
F
.74411 .7465 m .74242 .74555 L .74171 .74579 L F
.74242 .74555 m .73136 .73929 L .74171 .74579 L F
.74331 .75772 m .74344 .75777 L .74348 .76592 L .845 .571 .524 r
F
.74424 .75783 m .74398 .75781 L .74342 .75349 L .751 .492 .54 r
F
.74513 .75564 m .74316 .75767 L .74344 .75777 L .683 .771 .917 r
F
.74405 .75782 m .74344 .75777 L .74398 .75796 L F
.74513 .75564 m .74344 .75777 L .74405 .75782 L F
.74382 .75352 m .74424 .75783 L .74342 .75349 L .751 .492 .54 r
F
.74424 .75783 m .74505 .76618 L .74398 .75781 L F
.74414 .74926 m .74358 .75373 L .74416 .75353 L .57 .345 .536 r
F
.74411 .7465 m .74393 .74953 L .74522 .7493 L .683 .771 .917 r
F
.74412 .74498 m .74385 .74935 L .74414 .74926 L .57 .345 .536 r
F
.74331 .74918 m .7434 .74921 L .74342 .75349 L .845 .571 .524 r
F
.74462 .75107 m .74243 .74983 L .74151 .75014 L .683 .771 .917 r
F
.74385 .74935 m .74358 .75373 L .74414 .74926 L .57 .345 .536 r
F
.74411 .7465 m .72623 .74457 L .72543 .7475 L .683 .771 .917 r
F
.74151 .75014 m .73181 .74383 L .72869 .74632 L F
.74243 .74983 m .73181 .74383 L .74151 .75014 L F
.74332 .74525 m .74326 .74955 L .74412 .74498 L .57 .345 .536 r
F
.74462 .75107 m .74319 .74958 L .7426 .74993 L .683 .771 .917 r
F
.74326 .74955 m .7431 .76155 L .74385 .74935 L .57 .345 .536 r
F
.74411 .7465 m .74286 .74902 L .74394 .74941 L .683 .771 .917 r
F
.74326 .74955 m .74385 .74935 L .74412 .74498 L .57 .345 .536 r
F
.74332 .74525 m .74301 .74535 L .74303 .74963 L F
.74319 .74958 m .74303 .74963 L .74306 .75391 L F
.74332 .74525 m .74303 .74963 L .74319 .74958 L F
.74207 .74599 m .74188 .74612 L .74191 .7504 L .405 .218 .51 r
F
.74411 .7465 m .73533 .73731 L .73136 .73929 L .683 .771 .917 r
F
.74319 .74958 m .7404 .74047 L .7358 .74183 L F
.74462 .75107 m .74393 .74933 L .74319 .74958 L F
.74393 .74933 m .7404 .74047 L .74319 .74958 L F
.74319 .74958 m .74316 .74954 L .74303 .74963 L F
.74319 .74958 m .74303 .74963 L .7426 .74993 L F
.74462 .75107 m .74342 .75349 L .74447 .75358 L F
.74318 .70706 m .74496 .74934 L .74452 .74931 L .751 .492 .54 r
F
.74389 .70236 m .74301 .74535 L .74332 .74525 L .57 .345 .536 r
F
.74462 .75107 m .74473 .74917 L .74391 .74929 L .683 .771 .917 r
F
.74566 .75368 m .74443 .75428 L .74568 .75373 L F
.74526 .75338 m .7442 .76122 L .7453 .76113 L .66 .418 .542 r
F
.74452 .74931 m .74496 .74934 L .74499 .75362 L .751 .492 .54 r
F
.74521 .74936 m .74345 .75768 L .74525 .74937 L .683 .771 .917 r
F
.74452 .74931 m .74499 .75362 L .74465 .75359 L .751 .492 .54 r
F
.74462 .75107 m .74447 .75358 L .74566 .75368 L .683 .771 .917 r
F
.74522 .7493 m .74521 .74936 L .74525 .74937 L F
.74633 .70712 m .74736 .70668 L .74758 .7486 L .519 .306 .53 r
F
.74522 .7493 m .74831 .75704 L .74655 .74906 L .683 .771 .917 r
F
.74884 .76166 m .75306 .77225 L .76224 .76952 L F
.74827 .75893 m .74935 .76623 L .75395 .76487 L F
.74568 .75373 m .74884 .76166 L .74673 .75331 L F
.74657 .75334 m .74673 .75331 L .74672 .75327 L F
.74568 .75373 m .74673 .75331 L .74657 .75334 L F
.7461 .74914 m .74655 .74906 L .74657 .75334 L .642 .403 .541 r
F
.74695 .75755 m .74618 .75827 L .74702 .75762 L .683 .771 .917 r
F
.74596 .75773 m .74618 .75827 L .74695 .75755 L F
.7461 .74914 m .74623 .7534 L .74496 .74934 L .642 .403 .541 r
F
.74559 .75351 m .74568 .75373 L .74657 .75334 L .683 .771 .917 r
F
.74623 .7534 m .74664 .76598 L .74539 .75355 L .642 .403 .541 r
F
.74623 .7534 m .74539 .75355 L .74496 .74934 L F
.74462 .75107 m .74559 .75351 L .74672 .75327 L .683 .771 .917 r
F
.7461 .74914 m .74657 .75334 L .74623 .7534 L .642 .403 .541 r
F
.74559 .75351 m .74657 .75334 L .74672 .75327 L .683 .771 .917 r
F
.74513 .75564 m .74596 .75773 L .74695 .75755 L F
.74623 .7534 m .74657 .75334 L .7466 .75761 L .642 .403 .541 r
F
.74602 .75787 m .74447 .76687 L .74935 .76623 L .683 .771 .917 r
F
.74497 .75833 m .74447 .76687 L .74602 .75787 L F
.74501 .7579 m .74664 .76598 L .74505 .76618 L .642 .403 .541 r
F
.74496 .74934 m .74581 .75775 L .74501 .7579 L F
.74596 .75773 m .74497 .75833 L .74602 .75787 L .683 .771 .917 r
F
.745 .7579 m .74497 .75833 L .74596 .75773 L F
.74581 .75775 m .74664 .76598 L .74501 .7579 L .642 .403 .541 r
F
.74513 .75564 m .745 .7579 L .74596 .75773 L .683 .771 .917 r
F
.7466 .75761 m .74767 .76554 L .74664 .76598 L .519 .306 .53 r
F
.74657 .75334 m .74694 .75746 L .7466 .75761 L F
.74618 .75827 m .74935 .76623 L .74702 .75762 L .683 .771 .917 r
F
.74694 .75746 m .74767 .76554 L .7466 .75761 L .519 .306 .53 r
F
.74637 .75765 m .7466 .75761 L .74664 .76598 L .642 .403 .541 r
F
.74623 .7534 m .7466 .75761 L .74637 .75765 L F
.74738 .75799 m .74799 .76056 L .74827 .75893 L .683 .771 .917 r
F
.74799 .76056 m .74935 .76623 L .74827 .75893 L F
.74865 .74786 m .75685 .75371 L .75996 .75123 L F
.74633 .70712 m .74728 .74873 L .74655 .74906 L .519 .306 .53 r
F
.74411 .7465 m .74847 .74897 L .74865 .74786 L .683 .771 .917 r
F
.74847 .74897 m .75685 .75371 L .74865 .74786 L F
.74816 .75075 m .75288 .75569 L .74847 .74897 L F
.74882 .7469 m .74888 .75097 L .74885 .75113 L 0 0 .158 r
F
.7485 .70544 m .74884 .74676 L .74882 .7469 L F
.74884 .74676 m .74888 .75097 L .74882 .7469 L F
.74884 .74676 m .74885 .74669 L .74888 .75097 L F
.74715 .74969 m .74831 .75704 L .75288 .75569 L .683 .771 .917 r
F
.74655 .74906 m .7468 .7502 L .74715 .74969 L F
.7468 .7502 m .74831 .75704 L .74715 .74969 L F
.74726 .75384 m .75343 .7603 L .7479 .75292 L F
.74807 .70612 m .7485 .70544 L .74873 .74742 L .088 0 .422 r
F
.74869 .74748 m .74873 .74742 L .74875 .7517 L F
.74807 .70612 m .74873 .74742 L .74869 .74748 L F
.749 .74703 m .75996 .75123 L .76198 .74844 L .683 .771 .917 r
F
.7479 .75292 m .74842 .75362 L .74849 .75326 L F
.74787 .75686 m .74884 .76166 L .74822 .75484 L F
.75075 .74615 m .76198 .74844 L .76279 .74551 L F
.74809 .74821 m .74831 .75233 L .74816 .75245 L .362 .185 .501 r
F
.74736 .70668 m .74822 .7481 L .74809 .74821 L F
.74411 .7465 m .74816 .75075 L .74847 .74897 L .683 .771 .917 r
F
.74822 .7481 m .74831 .75233 L .74809 .74821 L .362 .185 .501 r
F
.75263 .7447 m .76279 .74551 L .76233 .74265 L .683 .771 .917 r
F
.74863 .70463 m .74819 .70359 L .74841 .7458 L .982 .725 .331 r
F
.74411 .7465 m .74846 .7478 L .749 .74703 L .683 .771 .917 r
F
.74807 .70612 m .7486 .7476 L .74829 .74805 L .088 0 .422 r
F
.74845 .74588 m .74841 .7458 L .74844 .75007 L .982 .725 .331 r
F
.7486 .7476 m .74875 .7517 L .74866 .75183 L .088 0 .422 r
F
.74807 .70612 m .74869 .74748 L .7486 .7476 L F
.74869 .74748 m .74875 .7517 L .7486 .7476 L F
.74863 .70463 m .74841 .7458 L .74845 .74588 L .982 .725 .331 r
F
.74736 .70668 m .74807 .70612 L .74829 .74805 L .362 .185 .501 r
F
.74736 .70668 m .74829 .74805 L .74822 .7481 L F
.7486 .7476 m .74866 .75183 L .74829 .74805 L .088 0 .422 r
F
.74769 .75281 m .75743 .75831 L .74846 .75222 L .683 .771 .917 r
F
.74866 .75183 m .74871 .75607 L .7485 .75206 L .088 0 .422 r
F
.74866 .75183 m .7485 .75206 L .74829 .74805 L F
.74997 .74994 m .7634 .75007 L .76293 .7472 L .683 .771 .917 r
F
.74829 .74805 m .7485 .75206 L .74831 .75233 L .088 0 .422 r
F
.74758 .7486 m .74816 .75245 L .7476 .75288 L .362 .185 .501 r
F
.74736 .70668 m .74809 .74821 L .74758 .7486 L F
.74809 .74821 m .74816 .75245 L .74758 .7486 L F
.74863 .70463 m .74845 .74588 L .74854 .74605 L .982 .725 .331 r
F
.74873 .74742 m .74885 .75113 L .74875 .7517 L 0 0 .158 r
F
.7485 .70544 m .74882 .7469 L .74873 .74742 L F
.74882 .7469 m .74885 .75113 L .74873 .74742 L F
.74946 .74314 m .75662 .74161 L .75779 .73789 L .683 .771 .917 r
F
.74822 .7481 m .74829 .74805 L .74831 .75233 L .362 .185 .501 r
F
.74816 .75245 m .74831 .75233 L .74834 .75661 L F
.74705 .75415 m .74884 .76166 L .74726 .75384 L .683 .771 .917 r
F
.74823 .75669 m .74834 .75661 L .74838 .76498 L .362 .185 .501 r
F
.74816 .75245 m .74834 .75661 L .74823 .75669 L F
.74831 .75704 m .76164 .76487 L .75288 .75569 L .683 .771 .917 r
F
.75288 .75569 m .76164 .76487 L .76958 .7609 L F
.75343 .7603 m .77022 .76554 L .75743 .75831 L F
.74835 .7566 m .75794 .76288 L .76106 .76039 L F
.74726 .75384 m .74787 .75686 L .74822 .75484 L F
.74816 .75245 m .74838 .76498 L .7476 .75288 L .362 .185 .501 r
F
.74688 .75344 m .74705 .75415 L .74726 .75384 L .683 .771 .917 r
F
.74702 .75762 m .74719 .75825 L .74738 .75799 L F
.74728 .74873 m .74738 .75298 L .74655 .74906 L .519 .306 .53 r
F
.74831 .75704 m .7525 .76758 L .76164 .76487 L .683 .771 .917 r
F
.74822 .75484 m .74884 .76166 L .75343 .7603 L F
.74884 .76166 m .76224 .76952 L .75343 .7603 L F
.74773 .75711 m .75395 .76487 L .75794 .76288 L F
.74678 .75351 m .74884 .76166 L .74688 .75344 L F
.74738 .75298 m .7476 .75288 L .74767 .76554 L .519 .306 .53 r
F
.74672 .75327 m .74678 .75351 L .74688 .75344 L .683 .771 .917 r
F
.74683 .75322 m .74767 .76554 L .74657 .75334 L .519 .306 .53 r
F
.74513 .75564 m .74689 .75748 L .74773 .75711 L .683 .771 .917 r
F
.74689 .75748 m .75395 .76487 L .74773 .75711 L F
.74738 .75298 m .74748 .75722 L .74683 .75322 L .519 .306 .53 r
F
.74748 .75722 m .74767 .76554 L .74712 .75738 L F
.74748 .75722 m .74712 .75738 L .74683 .75322 L F
.74738 .75298 m .74683 .75322 L .74655 .74906 L F
.75685 .75371 m .7758 .75596 L .75996 .75123 L .683 .771 .917 r
F
.7503 .75169 m .76055 .75583 L .76259 .75302 L F
.74846 .7478 m .75996 .75123 L .749 .74703 L F
.74854 .74605 m .74853 .75026 L .74885 .74669 L .982 .725 .331 r
F
.74842 .75362 m .75343 .7603 L .74849 .75326 L .683 .771 .917 r
F
.7485 .75206 m .74871 .75607 L .74831 .75233 L .088 0 .422 r
F
.74834 .75661 m .74882 .7643 L .74838 .76498 L F
.75053 .75013 m .75317 .75554 L .75685 .75371 L .683 .771 .917 r
F
.74884 .75233 m .76055 .75583 L .7503 .75169 L F
.74847 .74897 m .75288 .75569 L .75317 .75554 L F
.7496 .75081 m .76259 .75302 L .7634 .75007 L F
.74847 .74897 m .75317 .75554 L .75053 .75013 L F
.74462 .75107 m .75114 .75178 L .7496 .75081 L F
.75114 .75178 m .76259 .75302 L .7496 .75081 L F
.74831 .75233 m .74871 .75607 L .74834 .75661 L .088 0 .422 r
F
.74719 .75825 m .74935 .76623 L .74738 .75799 L .683 .771 .917 r
F
.74786 .75697 m .74838 .76498 L .74762 .75716 L .362 .185 .501 r
F
.74844 .75007 m .74745 .76163 L .7485 .76245 L .91 .629 .499 r
F
.74841 .7458 m .74816 .7499 L .74844 .75007 L F
.74936 .75082 m .7634 .75007 L .74997 .74994 L .683 .771 .917 r
F
.74782 .75395 m .76173 .74916 L .75888 .74699 L F
.74513 .75564 m .74845 .75434 L .74782 .75395 L F
.74728 .74873 m .7476 .75288 L .74738 .75298 L .519 .306 .53 r
F
.74462 .75107 m .74942 .75208 L .74916 .75156 L .683 .771 .917 r
F
.74853 .75026 m .74844 .75007 L .74846 .75435 L .982 .725 .331 r
F
.74771 .7571 m .7506 .75873 L .74835 .7566 L .683 .771 .917 r
F
.7506 .75873 m .75794 .76288 L .75013 .75777 L F
.7506 .75873 m .75013 .75777 L .74835 .7566 L F
.74866 .75183 m .74875 .7517 L .74877 .75598 L .088 0 .422 r
F
.74871 .75607 m .74877 .75598 L .74882 .7643 L F
.74866 .75183 m .74877 .75598 L .74871 .75607 L F
.75288 .75569 m .76958 .7609 L .75685 .75371 L .683 .771 .917 r
F
.74846 .75222 m .75743 .75831 L .76055 .75583 L F
.74915 .75543 m .7631 .75758 L .76391 .75464 L F
.7476 .75288 m .74786 .75697 L .74762 .75716 L .362 .185 .501 r
F
.74513 .75564 m .74874 .75603 L .74915 .75543 L .683 .771 .917 r
F
.74849 .75326 m .75343 .7603 L .75743 .75831 L F
.74874 .75603 m .7631 .75758 L .74915 .75543 L F
.74877 .75598 m .74894 .76349 L .74882 .7643 L 0 0 .158 r
F
.74888 .75535 m .74894 .76349 L .74877 .75598 L F
.7489 .75525 m .7485 .76245 L .74894 .76349 L .982 .725 .331 r
F
.74462 .75107 m .74884 .75233 L .74942 .75208 L .683 .771 .917 r
F
.74875 .7517 m .74888 .75535 L .74877 .75598 L 0 0 .158 r
F
.74885 .75113 m .74888 .75535 L .74875 .7517 L F
.74897 .75483 m .76391 .75464 L .76344 .75177 L .683 .771 .917 r
F
.74513 .75564 m .74887 .75544 L .74897 .75483 L F
.74887 .75544 m .76391 .75464 L .74897 .75483 L F
.74885 .75113 m .74888 .75097 L .7489 .75525 L 0 0 .158 r
F
.74888 .75535 m .7489 .75525 L .74894 .76349 L F
.74885 .75113 m .7489 .75525 L .74888 .75535 L F
.74885 .74669 m .74867 .75479 L .7489 .75525 L .982 .725 .331 r
F
.74871 .75607 m .74882 .7643 L .74834 .75661 L .088 0 .422 r
F
.74867 .75479 m .7485 .76245 L .7489 .75525 L .982 .725 .331 r
F
.74852 .75447 m .74846 .75435 L .7485 .76245 L F
.74853 .75026 m .74846 .75435 L .74852 .75447 L F
.74845 .75434 m .74846 .75434 L .74782 .75395 L .683 .771 .917 r
F
.74846 .75434 m .76173 .74916 L .7482 .75382 L F
.74846 .75434 m .7482 .75382 L .74782 .75395 L F
.74816 .7499 m .74792 .75401 L .74844 .75007 L .91 .629 .499 r
F
.74513 .75564 m .74771 .7571 L .74835 .7566 L .683 .771 .917 r
F
.74792 .75401 m .74745 .76163 L .74809 .75412 L .91 .629 .499 r
F
.74792 .75401 m .74809 .75412 L .74844 .75007 L F
.74846 .75434 m .76344 .75177 L .76173 .74916 L .683 .771 .917 r
F
.74411 .7465 m .74954 .74709 L .74995 .74677 L F
.74911 .74624 m .74995 .74677 L .75075 .74615 L F
.74411 .7465 m .74995 .74677 L .74911 .74624 L F
.74819 .70359 m .74714 .70277 L .74737 .74514 L .91 .629 .499 r
F
.74633 .70712 m .74758 .7486 L .74728 .74873 L .519 .306 .53 r
F
.74754 .74525 m .74737 .74514 L .74739 .74941 L .91 .629 .499 r
F
.74728 .74873 m .74758 .7486 L .7476 .75288 L .519 .306 .53 r
F
.74766 .74532 m .74741 .75369 L .74755 .75378 L .91 .629 .499 r
F
.74819 .70359 m .74754 .74525 L .74766 .74532 L F
.74748 .74947 m .74754 .74951 L .74766 .74532 L F
.74845 .74588 m .74844 .75007 L .74854 .74605 L .982 .725 .331 r
F
.74832 .74561 m .75075 .74615 L .75263 .7447 L .683 .771 .917 r
F
.74739 .74941 m .74638 .76126 L .74745 .76163 L .809 .541 .532 r
F
.74411 .7465 m .74864 .74626 L .74832 .74561 L .683 .771 .917 r
F
.74819 .70359 m .74766 .74532 L .74841 .7458 L .91 .629 .499 r
F
.7485 .70544 m .74863 .70463 L .74885 .74669 L 0 0 .158 r
F
.7485 .70544 m .74885 .74669 L .74884 .74676 L F
.74863 .70463 m .74854 .74605 L .74885 .74669 L .982 .725 .331 r
F
.74474 .70732 m .74633 .70712 L .74655 .74906 L .642 .403 .541 r
F
.74474 .70732 m .74655 .74906 L .7461 .74914 L F
.74474 .70732 m .7461 .74914 L .74496 .74934 L F
.74462 .75107 m .74936 .75082 L .74944 .75071 L .683 .771 .917 r
F
.74874 .75026 m .74944 .75071 L .74991 .75003 L F
.74462 .75107 m .74944 .75071 L .74874 .75026 L F
.74766 .74532 m .74761 .74955 L .74841 .7458 L .91 .629 .499 r
F
.74462 .75107 m .74991 .75003 L .74973 .74999 L .683 .771 .917 r
F
.74916 .75156 m .74942 .75208 L .7503 .75169 L F
.74954 .74709 m .76198 .74844 L .75075 .74615 L F
.74714 .70277 m .74659 .74495 L .74737 .74514 L .809 .541 .532 r
F
.74581 .74475 m .74767 .74426 L .74721 .74332 L .683 .771 .917 r
F
.74607 .70239 m .74499 .70227 L .74521 .74483 L .734 .478 .541 r
F
.74411 .7465 m .74629 .74487 L .74572 .74485 L .683 .771 .917 r
F
.74411 .7465 m .74522 .7493 L .74655 .74906 L F
.74462 .75107 m .74649 .74915 L .74559 .74912 L F
.74411 .7465 m .74659 .74494 L .74629 .74487 L F
.74462 .75107 m .74732 .74937 L .74701 .74918 L F
.74632 .74915 m .7453 .76113 L .74638 .76126 L .734 .478 .541 r
F
.74411 .7465 m .74746 .74519 L .74699 .7449 L .683 .771 .917 r
F
.74668 .74489 m .74699 .7449 L .74682 .74479 L F
.74411 .7465 m .74699 .7449 L .74668 .74489 L F
.74629 .74487 m .74546 .74911 L .74632 .74915 L .734 .478 .541 r
F
.74607 .70239 m .74551 .74484 L .74629 .74487 L F
.74551 .74484 m .74546 .74911 L .74629 .74487 L F
.74462 .75107 m .74701 .74918 L .74649 .74915 L .683 .771 .917 r
F
.74462 .75107 m .74829 .74964 L .74729 .74939 L F
.74546 .74911 m .7454 .75339 L .74632 .74915 L .734 .478 .541 r
F
.74655 .74906 m .74683 .75322 L .74657 .75334 L .519 .306 .53 r
F
.74462 .75107 m .74726 .75384 L .7479 .75292 L .683 .771 .917 r
F
.7454 .75339 m .74595 .75341 L .74632 .74915 L .734 .478 .541 r
F
.74737 .74514 m .74654 .7492 L .74739 .74941 L .809 .541 .532 r
F
.74649 .74915 m .74701 .74918 L .74667 .74896 L .683 .771 .917 r
F
.74559 .74912 m .74667 .74896 L .7459 .74848 L F
.74649 .74915 m .74667 .74896 L .74559 .74912 L F
.74546 .74911 m .74523 .74911 L .7453 .76113 L .734 .478 .541 r
F
.74572 .74485 m .74629 .74487 L .74581 .74475 L .683 .771 .917 r
F
.74659 .74494 m .74767 .74426 L .74581 .74475 L F
.74639 .7449 m .74629 .74487 L .74632 .74915 L .809 .541 .532 r
F
.74761 .74955 m .74816 .7499 L .74841 .7458 L .91 .629 .499 r
F
.74659 .74495 m .74654 .7492 L .74737 .74514 L .809 .541 .532 r
F
.74754 .74525 m .74748 .74947 L .74766 .74532 L .91 .629 .499 r
F
.74754 .74525 m .74739 .74941 L .74748 .74947 L F
.74864 .74626 m .75075 .74615 L .74832 .74561 L .683 .771 .917 r
F
.74667 .74896 m .75459 .74084 L .7459 .74848 L F
.74746 .74519 m .74923 .7445 L .74682 .74479 L F
.74527 .75338 m .75063 .74452 L .74579 .7444 L F
.74513 .75564 m .74623 .75342 L .74527 .75338 L F
.74748 .74947 m .74741 .75369 L .74754 .74951 L .91 .629 .499 r
F
.74748 .74947 m .74739 .74941 L .74741 .75369 L F
.74854 .74605 m .74844 .75007 L .74853 .75026 L .982 .725 .331 r
F
.74462 .75107 m .76293 .7472 L .76262 .74672 L .683 .771 .917 r
F
.75204 .74817 m .76262 .74672 L .76122 .74459 L F
.74462 .75107 m .76262 .74672 L .75204 .74817 L F
.74523 .74911 m .74431 .75351 L .74526 .75338 L .66 .418 .542 r
F
.74411 .7465 m .74581 .74475 L .7458 .74475 L .683 .771 .917 r
F
.74607 .70239 m .74521 .74483 L .74551 .74484 L .734 .478 .541 r
F
.74492 .74487 m .7458 .74475 L .74507 .74457 L .683 .771 .917 r
F
.74411 .7465 m .7458 .74475 L .74492 .74487 L F
.74521 .74483 m .74436 .74923 L .74523 .74911 L .66 .418 .542 r
F
.74499 .70227 m .74442 .74494 L .74521 .74483 L F
.74751 .74517 m .76233 .74265 L .76062 .74005 L .683 .771 .917 r
F
.74411 .7465 m .74885 .7455 L .74751 .74517 L F
.74885 .7455 m .76233 .74265 L .74751 .74517 L F
.74659 .74495 m .74632 .74915 L .74654 .7492 L .809 .541 .532 r
F
.74714 .70277 m .74639 .7449 L .74659 .74495 L F
.74639 .7449 m .74632 .74915 L .74659 .74495 L F
.74442 .74494 m .74436 .74923 L .74521 .74483 L .66 .418 .542 r
F
.74436 .74923 m .74431 .75351 L .74523 .74911 L F
.74623 .75342 m .75063 .74452 L .74527 .75338 L .683 .771 .917 r
F
.7454 .75339 m .7453 .76113 L .74595 .75341 L .734 .478 .541 r
F
.74551 .74484 m .74521 .74483 L .74523 .74911 L F
.74551 .74484 m .74523 .74911 L .74546 .74911 L F
.74714 .70277 m .74607 .70239 L .74629 .74487 L .809 .541 .532 r
F
.74714 .70277 m .74629 .74487 L .74639 .7449 L F
.75075 .74615 m .76279 .74551 L .75263 .7447 L .683 .771 .917 r
F
.74729 .74939 m .76122 .74459 L .75837 .74242 L F
.74853 .75026 m .74876 .75074 L .74885 .74669 L .982 .725 .331 r
F
.74829 .74964 m .76122 .74459 L .74729 .74939 L .683 .771 .917 r
F
.74761 .74955 m .74755 .75378 L .74816 .7499 L .91 .629 .499 r
F
.74973 .74999 m .74991 .75003 L .74997 .74994 L .683 .771 .917 r
F
.74732 .74937 m .75837 .74242 L .74667 .74896 L F
.74462 .75107 m .74769 .75281 L .74846 .75222 L F
.74624 .7534 m .7551 .74541 L .75063 .74452 L F
.74513 .75564 m .74711 .75362 L .74624 .7534 L F
.74755 .75378 m .74792 .75401 L .74816 .7499 L .91 .629 .499 r
F
.74654 .7492 m .74648 .75346 L .74739 .74941 L .809 .541 .532 r
F
.74513 .75564 m .74782 .75395 L .74741 .75369 L .683 .771 .917 r
F
.74513 .75564 m .74741 .75369 L .74711 .75362 L F
.74648 .75346 m .74638 .76126 L .74703 .7536 L .809 .541 .532 r
F
.74648 .75346 m .74703 .7536 L .74739 .74941 L F
.74711 .75362 m .74741 .75369 L .74718 .75354 L .683 .771 .917 r
F
.74853 .75026 m .74852 .75447 L .74876 .75074 L .982 .725 .331 r
F
.74711 .75362 m .7551 .74541 L .74624 .7534 L .683 .771 .917 r
F
.74654 .7492 m .74632 .74915 L .74634 .75343 L .809 .541 .532 r
F
.74648 .75346 m .74634 .75343 L .74638 .76126 L F
.74654 .7492 m .74634 .75343 L .74648 .75346 L F
.74718 .75354 m .75888 .74699 L .7551 .74541 L .683 .771 .917 r
F
.74852 .75447 m .74867 .75479 L .74876 .75074 L .982 .725 .331 r
F
.74782 .75395 m .75888 .74699 L .74718 .75354 L .683 .771 .917 r
F
.74755 .75378 m .74745 .76163 L .74792 .75401 L .91 .629 .499 r
F
.74507 .74457 m .75402 .73632 L .74958 .73544 L .683 .771 .917 r
F
.74581 .74475 m .75402 .73632 L .74507 .74457 L F
.74667 .74896 m .75837 .74242 L .75459 .74084 L F
.7443 .74321 m .74958 .73544 L .74477 .73531 L F
.74411 .7465 m .7454 .7439 L .7443 .74321 L F
.7454 .7439 m .74958 .73544 L .7443 .74321 L F
.74682 .74479 m .74923 .7445 L .74946 .74314 L F
.74923 .7445 m .75662 .74161 L .74946 .74314 L F
.74767 .74426 m .75344 .74063 L .74721 .74332 L F
.7459 .74848 m .75459 .74084 L .75012 .73995 L F
.74819 .70359 m .74737 .74514 L .74754 .74525 L .91 .629 .499 r
F
.74513 .75564 m .74872 .75488 L .74846 .75435 L .683 .771 .917 r
F
.74755 .75378 m .74741 .75369 L .74745 .76163 L .91 .629 .499 r
F
.74872 .75488 m .76344 .75177 L .74846 .75434 L .683 .771 .917 r
F
.74852 .75447 m .7485 .76245 L .74867 .75479 L .982 .725 .331 r
F
.75662 .74161 m .76062 .74005 L .75963 .73929 L .683 .771 .917 r
F
.75662 .74161 m .75963 .73929 L .75779 .73789 L F
.74721 .74332 m .75344 .74063 L .75402 .73632 L F
.75344 .74063 m .75779 .73789 L .75589 .7371 L F
.75344 .74063 m .75589 .7371 L .75402 .73632 L F
.74762 .75716 m .74838 .76498 L .74767 .76554 L .362 .185 .501 r
F
.74513 .75564 m .74527 .75338 L .74429 .75352 L .683 .771 .917 r
F
.74431 .75351 m .7442 .76122 L .74526 .75338 L .66 .418 .542 r
F
.74429 .75352 m .74528 .75316 L .74428 .7535 L .683 .771 .917 r
F
.74527 .75338 m .74528 .75316 L .74429 .75352 L F
.74354 .74506 m .74477 .73531 L .73991 .73595 L F
.74411 .7465 m .7442 .74497 L .74354 .74506 L F
.74499 .70227 m .74389 .70236 L .74414 .74926 L .66 .418 .542 r
F
.7442 .74497 m .74477 .73531 L .74354 .74506 L .683 .771 .917 r
F
.74442 .74494 m .74416 .75353 L .74431 .75351 L .66 .418 .542 r
F
.74499 .70227 m .7443 .74495 L .74442 .74494 L F
.7443 .74495 m .74416 .75353 L .74442 .74494 L F
.74391 .74929 m .74528 .73983 L .7404 .74047 L .683 .771 .917 r
F
.74473 .74917 m .74528 .73983 L .74391 .74929 L F
.74423 .74924 m .74414 .74926 L .74416 .75353 L .66 .418 .542 r
F
.74499 .70227 m .74414 .74926 L .74423 .74924 L F
.74513 .75564 m .74429 .75352 L .74337 .7538 L .683 .771 .917 r
F
.74431 .75351 m .74416 .75353 L .7442 .76122 L .66 .418 .542 r
F
.74429 .75352 m .74428 .7535 L .74416 .75353 L .683 .771 .917 r
F
.74429 .75352 m .74416 .75353 L .74337 .7538 L F
.74428 .7535 m .74579 .7444 L .74091 .74504 L F
.74528 .75316 m .74579 .7444 L .74428 .7535 L F
.74342 .75349 m .74505 .76618 L .74348 .76592 L .751 .492 .54 r
F
.74416 .75353 m .7431 .76155 L .7442 .76122 L .57 .345 .536 r
F
.74358 .75373 m .7431 .76155 L .74416 .75353 L F
.74389 .70236 m .74332 .74525 L .74412 .74498 L F
.7426 .74993 m .7358 .74183 L .73181 .74383 L .683 .771 .917 r
F
.74207 .74599 m .74191 .7504 L .742 .75033 L .405 .218 .51 r
F
.74316 .74954 m .7358 .74183 L .7426 .74993 L .683 .771 .917 r
F
.742 .75033 m .74191 .7504 L .74193 .75467 L .405 .218 .51 r
F
.74337 .7538 m .74091 .74504 L .73631 .7464 L .683 .771 .917 r
F
.74332 .74525 m .74306 .75391 L .7432 .75386 L .57 .345 .536 r
F
.74428 .7535 m .74091 .74504 L .74337 .7538 L .683 .771 .917 r
F
.7432 .75386 m .74306 .75391 L .7431 .76155 L .57 .345 .536 r
F
.74279 .70269 m .74188 .74612 L .74207 .74599 L .405 .218 .51 r
F
.74181 .75694 m .72854 .76212 L .74239 .75736 L .683 .771 .917 r
F
.74208 .75457 m .74193 .75467 L .74197 .76233 L .405 .218 .51 r
F
.73088 .75972 m .72471 .77152 L .73466 .7613 L .683 .771 .917 r
F
.73349 .76042 m .72854 .76212 L .7297 .76301 L F
.73349 .76042 m .7297 .76301 L .73139 .76429 L F
.127 .923 .03 r
.32139 .77953 m
.32139 .77984 L
s
.56231 .77722 m .54242 .77808 L .5603 .78001 L .683 .77 .917 r
F
.40951 .90629 m .4006 .90427 L .40034 .90804 L .597 .381 .559 r
F
0 g
.39241 .9112 m
.40034 .90804 L
s
.40951 .90629 m .40977 .90253 L .4006 .90427 L .597 .381 .559 r
F
0 g
.39266 .90744 m
.4006 .90427 L
s
.54273 .78263 m .52239 .7895 L .54116 .7885 L .683 .77 .917 r
F
.56071 .78457 m .54273 .78263 L .54116 .7885 L F
.70172 .65939 m .68052 .65222 L .67243 .6633 L .673 .758 .914 r
F
.70393 .78158 m .71477 .78173 L .71528 .7863 L .86 .591 .53 r
F
.70393 .78158 m .70342 .77701 L .71477 .78173 L F
.71715 .76837 m .71477 .78173 L .72471 .77152 L .683 .771 .917 r
F
.71715 .76837 m .70342 .77701 L .71477 .78173 L F
0 g
.71477 .78173 m
.71893 .78255 L
s
.68053 .65778 m .67207 .66325 L .67241 .66892 L .175 .079 .499 r
F
.68053 .65778 m .6802 .65211 L .67207 .66325 L F
0 g
.66886 .67509 m
.67207 .66325 L
s
.78301 .77277 m .7825 .76821 L .79187 .76076 L .408 .264 .572 r
F
0 g
.77565 .77162 m
.7825 .76821 L
s
.127 .923 .03 r
.78684 .76475 m
.78957 .70738 L
s
.78751 .76422 m
.78957 .70738 L
s
.43822 .90648 m .4295 .8999 L .42925 .90367 L .793 .551 .572 r
F
.43797 .91025 m .43822 .90648 L .42925 .90367 L F
0 g
.43822 .90648 m
.44586 .91056 L
s
.75138 .65899 m .74582 .64346 L .74495 .6586 L .673 .758 .914 r
F
.75138 .65899 m .75869 .64426 L .74582 .64346 L F
.57918 .79107 m .56632 .78385 L .56322 .78633 L .683 .771 .917 r
F
.57918 .79107 m .59573 .7846 L .59287 .78244 L F
.59696 .78264 m .61178 .77356 L .59523 .78003 L .683 .77 .917 r
F
.59696 .78264 m .61524 .77877 L .61178 .77356 L F
.76958 .7609 m .78231 .7681 L .79163 .76069 L .683 .771 .917 r
F
.127 .923 .03 r
.78741 .76709 m
.78742 .7668 L
s
.76164 .76487 m .78231 .7681 L .76958 .7609 L .683 .771 .917 r
F
.61456 .77424 m .62759 .76261 L .61111 .76906 L .683 .77 .917 r
F
.61456 .77424 m .63274 .7704 L .62759 .76261 L F
.58108 .66934 m .56119 .66558 L .56151 .67125 L .672 .45 .575 r
F
.58108 .66934 m .58075 .66367 L .56119 .66558 L F
0 g
.54281 .67046 m
.56119 .66558 L
s
.53807 .53529 m .57058 .53178 L .53936 .53015 L .654 .726 .902 r
F
.81813 .67193 m .81093 .6554 L .81127 .66107 L .986 .71 .373 r
F
0 g
.81813 .67193 m
.81998 .68367 L
s
.17023 .53248 m .18528 .53852 L .18481 .5458 L .926 .669 .529 r
F
.17023 .53248 m .1707 .52521 L .18528 .53852 L F
.19819 .51653 m .18528 .53852 L .2079 .52542 L .654 .726 .902 r
F
.19819 .51653 m .1707 .52521 L .18528 .53852 L F
0 g
.18528 .53852 m
.19146 .54194 L
s
.2375 .50849 m .23626 .52987 L .24496 .5109 L .654 .726 .902 r
F
.2375 .50849 m .22133 .52507 L .23626 .52987 L F
.31332 .66828 m .30131 .65535 L .29071 .66037 L .673 .757 .914 r
F
.31944 .66665 m .30131 .65535 L .31332 .66828 L F
.26113 .51174 m .26857 .53156 L .28376 .52834 L .654 .726 .902 r
F
.25302 .512 m .26857 .53156 L .26113 .51174 L F
.70218 .67066 m .67274 .67459 L .69676 .67808 L .673 .758 .915 r
F
.29812 .77475 m .29597 .78812 L .30576 .77791 L .683 .77 .917 r
F
.29812 .77475 m .28452 .78339 L .29597 .78812 L F
0 g
.29597 .78812 m
.30941 .79075 L
s
.41954 .90232 m .41002 .89876 L .40977 .90253 L .67 .444 .568 r
F
.41954 .90232 m .41979 .89855 L .41002 .89876 L F
0 g
.40086 .90051 m
.41002 .89876 L
s
.36943 .66522 m .37994 .64799 L .36172 .65907 L .673 .757 .914 r
F
.36943 .66522 m .3915 .65722 L .37994 .64799 L F
.3637 .77459 m .37247 .76258 L .37295 .76714 L .403 .259 .569 r
F
.36418 .77916 m .3637 .77459 L .37295 .76714 L F
.35077 .76736 m .3637 .77459 L .37295 .76714 L .683 .77 .917 r
F
.34283 .77134 m .3637 .77459 L .35077 .76736 L F
0 g
.35686 .77802 m
.3637 .77459 L
s
.127 .923 .03 r
.34593 .68911 m
.34596 .6934 L
s
.31014 2.65674 m
.39431 8.82582 L
s
.28147 .55486 m
.2815 .55736 L
s
.42925 .90367 m .4295 .8999 L .41979 .89855 L .733 .498 .573 r
F
0 g
.4295 .8999 m
.43848 .90272 L
s
.31835 .54549 m .33421 .52646 L .33375 .53374 L .339 .161 .487 r
F
.3179 .55276 m .31835 .54549 L .33375 .53374 L F
.29666 .53006 m .31835 .54549 L .33375 .53374 L .654 .726 .902 r
F
.28345 .5358 m .31835 .54549 L .29666 .53006 L F
0 g
.31547 .54674 m
.31835 .54549 L
s
.31835 .54549 m
.31901 .54499 L
s
.32886 .70541 m
.32893 .68567 L
s
.73846 .65923 m .73284 .64473 L .72062 .64798 L .673 .758 .914 r
F
.74495 .6586 m .73284 .64473 L .73846 .65923 L F
0 g
.32233 .70529 m
.32241 .68579 L
s
.30832 .67646 m .29101 .66604 L .28278 .67248 L .673 .758 .914 r
F
.31362 .67395 m .29101 .66604 L .30832 .67646 L F
.29059 .6548 m .26107 .65405 L .2824 .66121 L .673 .757 .914 r
F
.74495 .6586 m .74582 .64346 L .73284 .64473 L .673 .758 .914 r
F
.52524 .78526 m .52239 .7895 L .52289 .79407 L 0 0 .39 r
F
0 g
.52306 .7934 m
.52318 .79405 L
s
.54273 .78263 m .52475 .78069 L .52239 .7895 L .683 .77 .917 r
F
.52524 .78526 m .52475 .78069 L .52239 .7895 L 0 0 .39 r
F
.59465 .7755 m .60543 .76475 L .5918 .77335 L .683 .77 .917 r
F
.59465 .7755 m .61111 .76906 L .60543 .76475 L F
.127 .923 .03 r
.36425 .56292 m
.36448 .6232 L
s
.50477 .65351 m .50446 .64784 L .52402 .64593 L .672 .449 .575 r
F
.48536 .65231 m .50446 .64784 L .50477 .65351 L .733 .497 .57 r
F
.48536 .65231 m .48505 .64664 L .50446 .64784 L F
.56121 .78913 m .54165 .79307 L .56042 .79207 L .683 .771 .917 r
F
.28248 .66681 m .26104 .65961 L .25309 .67074 L .673 .757 .914 r
F
.26133 .66528 m .25309 .67074 L .25338 .67642 L .162 .067 .491 r
F
.26133 .66528 m .26104 .65961 L .25309 .67074 L F
0 g
.25007 .68258 m
.25309 .67074 L
s
.75772 .666 m .75911 .64978 L .75176 .66459 L .673 .758 .914 r
F
.75772 .666 m .77103 .6526 L .75911 .64978 L F
.76312 .67399 m .77138 .65827 L .75806 .67167 L .673 .758 .915 r
F
.76312 .67399 m .78149 .66292 L .77138 .65827 L F
.60048 .67053 m .58075 .66367 L .58108 .66934 L .733 .497 .57 r
F
0 g
.56119 .66558 m
.58075 .66367 L
s
.58075 .66367 m
.60015 .66486 L
s
.5052 .63248 m .50447 .64761 L .52393 .64571 L .673 .757 .914 r
F
.49232 .63168 m .50447 .64761 L .5052 .63248 L F
.49232 .63168 m .48515 .64642 L .50447 .64761 L F
.33243 .66641 m .32659 .65081 L .32596 .66602 L F
.33243 .66641 m .33954 .65161 L .32659 .65081 L F
.74742 .55433 m .72336 .54784 L .72296 .55512 L .667 .432 .555 r
F
0 g
.69997 .55997 m
.72296 .55512 L
s
.74742 .55433 m .74781 .54706 L .72336 .54784 L .667 .432 .555 r
F
0 g
.70037 .55269 m
.72336 .54784 L
s
.42925 .90367 m .41979 .89855 L .41954 .90232 L .733 .498 .573 r
F
0 g
.41979 .89855 m
.4295 .8999 L
s
.41002 .89876 m
.41979 .89855 L
s
.77168 .55767 m .77207 .55039 L .74781 .54706 L .732 .488 .558 r
F
0 g
.77207 .55039 m
.79445 .55762 L
s
.6008 .67621 m .60048 .67053 L .58108 .66934 L .733 .497 .57 r
F
0 g
.60048 .67053 m
.61839 .67475 L
s
.32874 .73724 m
.32886 .70541 L
s
.127 .923 .03 r
.34493 .76891 m
.34493 .77029 L
s
0 g
.32221 .73749 m
.32233 .70529 L
s
.35231 .5595 m .32848 .54889 L .32803 .55616 L .732 .488 .559 r
F
0 g
.32093 .54913 m
.32848 .54889 L
s
.32848 .54889 m
.35276 .55222 L
s
.127 .923 .03 r
.34511 .55398 m
.34552 .6214 L
s
.34507 .5469 m
.34511 .55398 L
s
0 g
.35231 .5595 m
.37479 .56672 L
s
.31944 .66665 m .31354 .65209 L .30131 .65535 L .673 .757 .914 r
F
.32596 .66602 m .31354 .65209 L .31944 .66665 L F
.127 .923 .03 r
.34568 .76861 m
.34571 .7699 L
s
.43797 .91025 m .42925 .90367 L .42899 .90744 L .793 .551 .572 r
F
0 g
.43797 .91025 m
.44561 .91433 L
s
.127 .923 .03 r
.43374 1.7712 m
.43848 .85308 L
s
.52433 .6516 m .52402 .64593 L .5424 .64104 L .603 .397 .574 r
F
.50477 .65351 m .52402 .64593 L .52433 .6516 L .672 .449 .575 r
F
0 g
.50446 .64784 m
.52402 .64593 L
s
.73264 .66646 m .72084 .65352 L .71017 .65854 L .673 .758 .914 r
F
.73877 .66483 m .72084 .65352 L .73264 .66646 L F
.56273 .78176 m .54273 .78263 L .56071 .78457 L .683 .77 .917 r
F
.32596 .66602 m .32659 .65081 L .31354 .65209 L .673 .757 .914 r
F
.54323 .7872 m .52289 .79407 L .54165 .79307 L .683 .771 .917 r
F
.56121 .78913 m .54323 .7872 L .54165 .79307 L F
.71765 .77294 m .71528 .7863 L .72522 .77609 L F
.71765 .77294 m .70393 .78158 L .71528 .7863 L F
0 g
.71528 .7863 m
.72866 .78894 L
s
0 0 0 r
2.5 Mabswid
.32062 .78408 Mdot
.78875 .66339 m .79953 .64616 L .78114 .65724 L .673 .758 .914 r
F
.78875 .66339 m .81093 .6554 L .79953 .64616 L F
.78301 .77277 m .79187 .76076 L .79238 .76533 L .408 .264 .572 r
F
.78353 .77734 m .78301 .77277 L .79238 .76533 L F
.77022 .76554 m .78301 .77277 L .79238 .76533 L .683 .771 .917 r
F
.76224 .76952 m .78301 .77277 L .77022 .76554 L F
0 g
.5 Mabswid
.77616 .77619 m
.78301 .77277 L
s
.51818 .63121 m .52393 .64571 L .54222 .64085 L .673 .757 .914 r
F
.5052 .63248 m .52393 .64571 L .51818 .63121 L F
.33872 .67349 m .33984 .65728 L .33273 .67209 L .673 .758 .914 r
F
.33872 .67349 m .35183 .6601 L .33984 .65728 L F
0 g
.74808 .68385 m
.74819 .70359 L
s
.59746 .78721 m .61228 .77813 L .59573 .7846 L .683 .771 .917 r
F
.59746 .78721 m .61574 .78334 L .61228 .77813 L F
.61524 .77877 m .62834 .76708 L .61178 .77356 L .683 .77 .917 r
F
.61524 .77877 m .63352 .7749 L .62834 .76708 L F
.41928 .90609 m .40977 .90253 L .40951 .90629 L .67 .444 .568 r
F
0 g
.40034 .90804 m
.40951 .90629 L
s
.41928 .90609 m .41954 .90232 L .40977 .90253 L .67 .444 .568 r
F
0 g
.4006 .90427 m
.40977 .90253 L
s
.74156 .68396 m
.74166 .70347 L
s
.63352 .7749 m .63302 .77034 L .62784 .76252 L .98 .689 .335 r
F
0 g
.63302 .77034 m
.63446 .77894 L
s
.127 .923 .03 r
.62067 1.37225 m
.62692 1.00035 L
s
.61765 1.16713 m
.62396 .94383 L
s
.72764 .67464 m .71051 .66422 L .70218 .67066 L .673 .758 .915 r
F
.73298 .67213 m .71051 .66422 L .72764 .67464 L F
.127 .923 .03 r
.3715 3.09034 m
.49533 8.8005 L
s
0 0 0 r
2.5 Mabswid
.32148 .78375 Mdot
.42899 .90744 m .42925 .90367 L .41954 .90232 L .733 .498 .573 r
F
0 g
.5 Mabswid
.42925 .90367 m
.43822 .90648 L
s
.71 .65298 m .68052 .65222 L .70172 .65939 L .673 .758 .914 r
F
.27537 .77233 m .28357 .77426 L .28404 .77883 L .931 .647 .48 r
F
.27537 .77233 m .2749 .76776 L .28357 .77426 L F
0 g
.28357 .77426 m
.28821 .77618 L
s
.58078 .8569 m .57943 .8619 L .58268 .86183 L .645 .732 .913 r
F
.57909 .8016 m .58067 .85691 L .57918 .85703 L .642 .403 .541 r
F
.57979 .85431 m .57966 .85699 L .58078 .8569 L .645 .732 .913 r
F
.57966 .85699 m .57943 .8619 L .58078 .8569 L F
.57943 .8619 m .57907 .86948 L .58556 .86934 L F
.58047 .86049 m .57918 .86571 L .58245 .86564 L .644 .733 .913 r
F
.57918 .85703 m .58077 .86038 L .5792 .86058 L .642 .403 .541 r
F
.57954 .85808 m .57943 .86057 L .58047 .86049 L .644 .733 .913 r
F
.57943 .86057 m .57918 .86571 L .58047 .86049 L F
.58067 .85691 m .58077 .86038 L .57918 .85703 L .642 .403 .541 r
F
.58329 .85671 m .58572 .86125 L .58837 .8602 L .645 .732 .913 r
F
.58077 .85691 m .5818 .85995 L .58077 .86038 L .519 .305 .529 r
F
.58067 .8014 m .58173 .85657 L .58077 .85691 L F
.57979 .85431 m .58268 .86183 L .58572 .86125 L .645 .732 .913 r
F
.58173 .85657 m .5818 .85995 L .58077 .85691 L .519 .305 .529 r
F
.5825 .85606 m .58294 .85871 L .58251 .85939 L .082 0 .419 r
F
.5824 .8004 m .58291 .8555 L .5825 .85606 L F
.58263 .85626 m .58199 .85677 L .58329 .85671 L .645 .732 .913 r
F
.58193 .85682 m .58572 .86125 L .58329 .85671 L F
.58291 .8555 m .58294 .85871 L .5825 .85606 L .082 0 .419 r
F
.58199 .85677 m .58193 .85682 L .58196 .85681 L .645 .732 .913 r
F
.58199 .85677 m .58196 .85681 L .58329 .85671 L F
.57979 .85431 m .58172 .85657 L .58263 .85626 L F
.58179 .85655 m .58251 .85939 L .5818 .85995 L .361 .183 .5 r
F
.5817 .80096 m .58246 .85609 L .58179 .85655 L F
.58179 .85655 m .58193 .85682 L .58263 .85626 L .645 .732 .913 r
F
.58174 .85659 m .58193 .85682 L .58179 .85655 L F
.58246 .85609 m .58251 .85939 L .58179 .85655 L .361 .183 .5 r
F
.58172 .85657 m .58174 .85659 L .58179 .85655 L .645 .732 .913 r
F
.57909 .8016 m .58067 .8014 L .58077 .85691 L .642 .403 .541 r
F
.58067 .85691 m .58077 .85691 L .58077 .86038 L F
.57909 .8016 m .58077 .85691 L .58067 .85691 L F
.57849 .8569 m .57323 .86052 L .57621 .86145 L .645 .732 .913 r
F
.57966 .85712 m .57621 .86145 L .57943 .8619 L F
.57849 .8569 m .57621 .86145 L .57966 .85712 L F
.57323 .86052 m .57263 .86858 L .57621 .86145 L F
.57728 .86022 m .57041 .86295 L .57295 .86432 L .644 .733 .913 r
F
.57761 .85673 m .57918 .86059 L .57762 .86029 L .751 .492 .54 r
F
.57654 .80087 m .57752 .80134 L .57761 .85673 L .844 .571 .525 r
F
.57755 .8567 m .57761 .85673 L .57762 .86033 L F
.57654 .80087 m .57761 .85673 L .57755 .8567 L F
.57736 .85661 m .5707 .85916 L .57323 .86052 L .645 .732 .913 r
F
.57752 .80134 m .57908 .85701 L .57761 .85673 L .751 .492 .54 r
F
.57979 .85431 m .57637 .85614 L .57736 .85661 L .645 .732 .913 r
F
.57637 .85614 m .5707 .85916 L .57736 .85661 L F
.57954 .85808 m .57599 .85998 L .57728 .86022 L .644 .733 .913 r
F
.57599 .85998 m .57041 .86295 L .57728 .86022 L F
.57621 .86145 m .57263 .86858 L .57907 .86948 L .645 .732 .913 r
F
.57954 .85808 m .57295 .86432 L .57595 .86525 L .644 .733 .913 r
F
.57762 .86029 m .57918 .86059 L .57762 .86033 L .751 .492 .54 r
F
.57621 .86145 m .57907 .86948 L .57943 .8619 L .645 .732 .913 r
F
.57954 .85808 m .57595 .86525 L .57918 .86571 L .644 .733 .913 r
F
.57918 .86059 m .57918 .86059 L .57762 .86029 L .751 .492 .54 r
F
.57908 .85701 m .57918 .86059 L .57761 .85673 L F
.57979 .85431 m .57849 .8569 L .57966 .85712 L .645 .732 .913 r
F
.57979 .85431 m .5773 .85667 L .57849 .8569 L F
.57721 .85676 m .57323 .86052 L .57787 .85732 L F
.56879 .85747 m .56162 .864 L .5707 .85916 L F
.57513 .85854 m .56698 .85734 L .56732 .85934 L .644 .733 .913 r
F
.57597 .8557 m .57662 .85981 L .57597 .85925 L .928 .648 .489 r
F
.57954 .85808 m .57424 .85777 L .57513 .85854 L .644 .733 .913 r
F
.57752 .80134 m .57909 .8016 L .57918 .85703 L .751 .492 .54 r
F
.57752 .80134 m .57918 .85703 L .57908 .85701 L F
.57637 .85614 m .56879 .85747 L .5707 .85916 L .645 .732 .913 r
F
.57654 .80087 m .57755 .8567 L .57662 .85626 L .844 .571 .525 r
F
.57979 .85431 m .57527 .85561 L .57637 .85614 L .645 .732 .913 r
F
.57527 .85561 m .56879 .85747 L .57637 .85614 L F
.5707 .85916 m .56668 .86672 L .57323 .86052 L F
.57545 .85926 m .56732 .85934 L .56849 .86126 L .644 .733 .913 r
F
.57662 .85626 m .5776 .86028 L .57663 .85982 L .844 .571 .525 r
F
.57954 .85808 m .57415 .85864 L .57545 .85926 L .644 .733 .913 r
F
.57415 .85864 m .56732 .85934 L .57545 .85926 L F
.57663 .85982 m .57762 .86033 L .57663 .85986 L .844 .571 .525 r
F
.5776 .86028 m .57762 .86033 L .57663 .85982 L F
.57755 .8567 m .57762 .86033 L .57662 .85626 L F
.57424 .85777 m .56698 .85734 L .57513 .85854 L .644 .733 .913 r
F
.57599 .85998 m .56849 .86126 L .57041 .86295 L F
.57908 .85701 m .57918 .85703 L .57918 .86059 L .751 .492 .54 r
F
.57658 .85622 m .57663 .85982 L .57597 .8557 L .928 .648 .489 r
F
.57663 .85982 m .57663 .85986 L .57662 .85981 L F
.57663 .85982 m .57662 .85981 L .57597 .8557 L F
.5765 .8597 m .57416 .85963 L .57599 .85998 L .644 .733 .913 r
F
.57954 .85808 m .57584 .85914 L .5765 .8597 L F
.57584 .85914 m .57416 .85963 L .5765 .8597 L F
.57416 .85963 m .56849 .86126 L .57599 .85998 L F
.57597 .85925 m .57663 .85986 L .57597 .85927 L .928 .648 .489 r
F
.57662 .85981 m .57663 .85986 L .57597 .85925 L F
.57588 .80028 m .57658 .85622 L .57597 .8557 L F
.5773 .85667 m .57721 .85676 L .57849 .8569 L .645 .732 .913 r
F
.57721 .85676 m .57787 .85732 L .57849 .8569 L F
0 g
.57908 .79658 m
.57909 .8016 L
s
.29156 .76122 m .28377 .77413 L .29731 .76553 L .683 .77 .917 r
F
.29156 .76122 m .27515 .76767 L .28377 .77413 L F
.56231 .77722 m .54642 .7725 L .54242 .77808 L F
.5654 .77475 m .54642 .7725 L .56231 .77722 L F
.36418 .77916 m .37295 .76714 L .37343 .77171 L .403 .259 .569 r
F
.35125 .77193 m .36418 .77916 L .37343 .77171 L .683 .77 .917 r
F
.34331 .77591 m .36418 .77916 L .35125 .77193 L F
0 g
.35228 .78512 m
.36418 .77916 L
s
.47591 .54142 m .44626 .55033 L .47677 .5467 L .654 .726 .902 r
F
.127 .923 .03 r
.45021 .54914 m
.45024 .54317 L
s
.47591 .54142 m .44453 .53978 L .44626 .55033 L .654 .726 .902 r
F
.70184 .66499 m .68053 .65778 L .67241 .66892 L .673 .758 .914 r
F
.68087 .66346 m .67241 .66892 L .67274 .67459 L .175 .079 .499 r
F
.68087 .66346 m .68053 .65778 L .67241 .66892 L F
0 g
.6692 .68076 m
.67241 .66892 L
s
.58363 .85591 m .58837 .8602 L .59043 .85874 L .645 .732 .913 r
F
.57979 .85431 m .58263 .85626 L .58363 .85591 L F
.58263 .85626 m .58837 .8602 L .58363 .85591 L F
.58067 .8014 m .5817 .80096 L .58179 .85655 L .519 .305 .529 r
F
.58173 .85657 m .58179 .85655 L .5818 .85995 L F
.58067 .8014 m .58179 .85655 L .58173 .85657 L F
.25256 .51938 m .2519 .53956 L .26818 .53903 L .654 .726 .902 r
F
.24445 .51827 m .2519 .53956 L .25256 .51938 L F
.24445 .51827 m .2357 .53733 L .2519 .53956 L F
.67355 .53345 m .67395 .52617 L .69841 .52539 L .667 .432 .555 r
F
.64928 .53011 m .67395 .52617 L .67355 .53345 L .732 .488 .558 r
F
.64928 .53011 m .64969 .52284 L .67395 .52617 L F
.5814 .67501 m .56151 .67125 L .56184 .67692 L .672 .45 .575 r
F
0 g
.54345 .68181 m
.56184 .67692 L
s
.5814 .67501 m .58108 .66934 L .56151 .67125 L .672 .45 .575 r
F
0 g
.54313 .67613 m
.56151 .67125 L
s
.127 .923 .03 r
.57039 .72437 m
.57097 .66153 L
s
.56877 .725 m
.57009 .66185 L
s
.75176 .66459 m .74617 .64898 L .7453 .66419 L .673 .758 .914 r
F
.75176 .66459 m .75911 .64978 L .74617 .64898 L F
.56746 .55667 m .60143 .54799 L .57005 .54635 L .654 .726 .902 r
F
.53738 .54987 m .56746 .55667 L .57005 .54635 L F
.53404 .55457 m .56746 .55667 L .53738 .54987 L F
0 0 0 r
2.5 Mabswid
.4502 .55023 Mdot
.54323 .7872 m .52524 .78526 L .52289 .79407 L .683 .771 .917 r
F
0 g
.5 Mabswid
.52289 .79407 m
.52437 .80267 L
s
.31362 .67395 m .3016 .66102 L .29101 .66604 L .673 .758 .914 r
F
.31974 .67232 m .3016 .66102 L .31362 .67395 L F
.58376 .8552 m .59043 .85874 L .59177 .85699 L .645 .732 .913 r
F
.57979 .85431 m .58307 .85568 L .58376 .8552 L F
.58307 .85568 m .59043 .85874 L .58376 .8552 L F
.5817 .80096 m .5824 .8004 L .5825 .85606 L .361 .183 .5 r
F
.58246 .85609 m .5825 .85606 L .58251 .85939 L F
.5817 .80096 m .5825 .85606 L .58246 .85609 L F
.67492 .50578 m .67396 .52587 L .6983 .52509 L .654 .726 .902 r
F
.65882 .50357 m .67396 .52587 L .67492 .50578 L F
.65882 .50357 m .64983 .52255 L .67396 .52587 L F
0 g
.74819 .70359 m
.74836 .73541 L
s
.59523 .78003 m .60606 .76923 L .59237 .77787 L .683 .77 .917 r
F
.59523 .78003 m .61178 .77356 L .60606 .76923 L F
.42899 .90744 m .41954 .90232 L .41928 .90609 L .733 .498 .573 r
F
0 g
.41954 .90232 m
.42925 .90367 L
s
.42899 .90744 m
.43797 .91025 L
s
.40977 .90253 m
.41954 .90232 L
s
.57572 .85548 m .56763 .85557 L .56879 .85747 L .645 .732 .913 r
F
.57979 .85431 m .57494 .85481 L .57572 .85548 L F
.57494 .85481 m .56763 .85557 L .57572 .85548 L F
.57588 .80028 m .57654 .80087 L .57662 .85626 L .928 .648 .489 r
F
.57658 .85622 m .57662 .85626 L .57663 .85986 L F
.57588 .80028 m .57662 .85626 L .57658 .85622 L F
.36973 .67089 m .38024 .65366 L .36202 .66474 L .673 .758 .914 r
F
.36973 .67089 m .3918 .66289 L .38024 .65366 L F
0 g
.74166 .70347 m
.74183 .7357 L
s
.77168 .55767 m .74781 .54706 L .74742 .55433 L .732 .488 .558 r
F
0 g
.74781 .54706 m
.77207 .55039 L
s
.77168 .55767 m
.79406 .56489 L
s
.72336 .54784 m
.74781 .54706 L
s
.46742 .64809 m .48505 .64664 L .48536 .65231 L .794 .544 .56 r
F
.46742 .64809 m .4671 .64242 L .48505 .64664 L F
0 g
.48505 .64664 m
.50446 .64784 L
s
.73877 .66483 m .73312 .65026 L .72084 .65352 L .673 .758 .914 r
F
.7453 .66419 m .73312 .65026 L .73877 .66483 L F
0 g
.3036 .55695 m
.31485 .55659 L
s
.31485 .55659 m
.32803 .55616 L
s
.48041 .62887 m .48515 .64642 L .49232 .63168 L .673 .757 .914 r
F
.48041 .62887 m .4673 .64222 L .48515 .64642 L F
.5918 .77335 m .59788 .76161 L .58803 .77178 L .683 .77 .917 r
F
.5918 .77335 m .60543 .76475 L .59788 .76161 L F
.29071 .66037 m .26104 .65961 L .28248 .66681 L .673 .757 .914 r
F
.58361 .85454 m .59177 .85699 L .59229 .85505 L .645 .732 .913 r
F
.57979 .85431 m .58322 .85508 L .58361 .85454 L F
.58322 .85508 m .59177 .85699 L .58361 .85454 L F
.5824 .8004 m .58284 .79972 L .58294 .85546 L .082 0 .419 r
F
.58291 .8555 m .58294 .85546 L .58294 .85871 L F
.5824 .8004 m .58294 .85546 L .58291 .8555 L F
0 g
.32803 .55616 m
.35231 .5595 L
s
.7453 .66419 m .74617 .64898 L .73312 .65026 L .673 .758 .914 r
F
.57542 .85476 m .56729 .85358 L .56763 .85557 L .645 .732 .913 r
F
.5772 .85274 m .57608 .85675 L .5772 .85598 L .404 .216 .509 r
F
.57711 .79699 m .57614 .85336 L .5772 .85274 L F
.57979 .85431 m .57501 .85403 L .57542 .85476 L .645 .732 .913 r
F
.57614 .85336 m .57608 .85675 L .5772 .85274 L .404 .216 .509 r
F
.575 .85403 m .56729 .85358 L .57542 .85476 L .645 .732 .913 r
F
.5755 .79959 m .57588 .80028 L .57597 .8557 L .988 .72 .386 r
F
.57594 .85566 m .57597 .8557 L .57597 .85927 L F
.5755 .79959 m .57597 .8557 L .57594 .85566 L F
.50509 .65918 m .50477 .65351 L .52433 .6516 L .672 .449 .575 r
F
.48568 .65799 m .50477 .65351 L .50509 .65918 L .733 .497 .57 r
F
.48568 .65799 m .48536 .65231 L .50477 .65351 L F
.50551 .6383 m .50477 .65351 L .52433 .6516 L .673 .757 .914 r
F
.49256 .6375 m .50477 .65351 L .50551 .6383 L F
.49256 .6375 m .48536 .65231 L .50477 .65351 L F
.28278 .67248 m .26133 .66528 L .25338 .67642 L .673 .758 .914 r
F
0 g
.25036 .68825 m
.25338 .67642 L
s
.75806 .67167 m .75945 .65546 L .7521 .67026 L .673 .758 .915 r
F
.75806 .67167 m .77138 .65827 L .75945 .65546 L F
.6008 .67621 m .58108 .66934 L .5814 .67501 L .733 .497 .57 r
F
0 g
.56151 .67125 m
.58108 .66934 L
s
.58108 .66934 m
.60048 .67053 L
s
.6008 .67621 m
.61872 .68043 L
s
.41766 .99179 m .41741 .9896 L .42082 .98912 L .669 .438 .561 r
F
.41427 .99169 m .41741 .9896 L .41766 .99179 L .731 .482 .552 r
F
.41427 .99169 m .41402 .9895 L .41741 .9896 L F
.41752 .98678 m .41741 .98955 L .4208 .98909 L .692 .759 .903 r
F
.41527 .98671 m .41404 .98946 L .41741 .98955 L F
.54642 .7725 m .52452 .77615 L .54242 .77808 L .683 .77 .917 r
F
.42107 .99132 m .42082 .98912 L .42402 .98811 L .6 .388 .566 r
F
.127 .923 .03 r
.42479 1.08947 m
.49519 8.80075 L
s
.42347 .94516 m
.42382 .98316 L
s
.42383 .98473 m
.42384 .98528 L
s
.42384 .98558 m
.42385 .98692 L
s
.42385 .98697 m
.42386 .98794 L
s
.42386 .98803 m
.42387 .98816 L
s
.41766 .99179 m .42082 .98912 L .42107 .99132 L .669 .438 .561 r
F
0 g
.41741 .9896 m
.42082 .98912 L
s
.41978 .98646 m .4208 .98909 L .42399 .98808 L .692 .759 .903 r
F
.127 .923 .03 r
.42394 .99639 m
.42479 1.08947 L
s
.42387 .98828 m
.42394 .99639 L
s
.33273 .67209 m .32689 .65648 L .32626 .67169 L .673 .758 .914 r
F
.33273 .67209 m .33984 .65728 L .32689 .65648 L F
.23695 .51585 m .2357 .53733 L .24445 .51827 L .654 .726 .902 r
F
.23695 .51585 m .2207 .53251 L .2357 .53733 L F
.5378 .54259 m .57047 .53907 L .53909 .53743 L F
.2607 .51912 m .26818 .53903 L .28345 .5358 L F
.25256 .51938 m .26818 .53903 L .2607 .51912 L F
.127 .923 .03 r
.34495 .77315 m
.34496 .77508 L
s
.23113 .50496 m .22133 .52507 L .2375 .50849 L .654 .726 .902 r
F
.23113 .50496 m .2086 .51801 L .22133 .52507 L F
.19771 .52381 m .18481 .5458 L .20743 .53269 L F
.19771 .52381 m .17023 .53248 L .18481 .5458 L F
0 g
.18481 .5458 m
.204 .55642 L
s
.69487 .77051 m .70291 .77244 L .70342 .77701 L .933 .647 .474 r
F
.69487 .77051 m .69436 .76594 L .70291 .77244 L F
0 g
.70291 .77244 m
.70758 .77439 L
s
.40951 .90629 m
.41928 .90609 L
s
.56322 .78633 m .54323 .7872 L .56121 .78913 L .683 .771 .917 r
F
0 g
.5814 .67501 m
.6008 .67621 L
s
.58261 .85377 m .58156 .85606 L .58262 .85687 L .909 .63 .501 r
F
.58251 .79788 m .58161 .85302 L .58261 .85377 L F
.58284 .79972 m .58305 .85477 L .58294 .85546 L 0 0 .148 r
F
.58318 .85396 m .59229 .85505 L .59195 .85306 L .645 .732 .913 r
F
.57979 .85431 m .58309 .85451 L .58318 .85396 L F
.58309 .85451 m .59229 .85505 L .58318 .85396 L F
.58284 .79972 m .58296 .79892 L .58306 .85473 L 0 0 .148 r
F
.58305 .85477 m .58306 .85473 L .58306 .85791 L F
.58284 .79972 m .58306 .85473 L .58305 .85477 L F
.58161 .85302 m .58156 .85606 L .58261 .85377 L .909 .63 .501 r
F
.58296 .79892 m .58251 .79788 L .58261 .85377 L .984 .727 .338 r
F
.58263 .85382 m .58261 .85377 L .58262 .85687 L F
.58296 .79892 m .58261 .85377 L .58263 .85382 L F
.58294 .85546 m .58306 .85791 L .58294 .85871 L 0 0 .148 r
F
.58305 .85477 m .58306 .85791 L .58294 .85546 L F
.58306 .85473 m .58262 .85687 L .58306 .85791 L .984 .727 .338 r
F
.58296 .79892 m .58263 .85382 L .58306 .85473 L F
.58263 .85382 m .58262 .85687 L .58306 .85473 L F
.58193 .85229 m .58888 .84947 L .58635 .84811 L .645 .732 .913 r
F
.58156 .85298 m .58049 .85568 L .58156 .85606 L .809 .541 .533 r
F
.58146 .79707 m .58054 .85262 L .58156 .85298 L F
.57979 .85431 m .58199 .85314 L .5813 .85289 L .645 .732 .913 r
F
.57979 .85431 m .58136 .85283 L .58076 .85238 L F
.58186 .85321 m .59079 .85115 L .58888 .84947 L F
.57979 .85431 m .58235 .85358 L .58186 .85321 L F
.58235 .85358 m .59079 .85115 L .58186 .85321 L F
.58251 .79788 m .58146 .79707 L .58156 .85298 L .909 .63 .501 r
F
.58283 .85344 m .59195 .85306 L .59079 .85115 L .645 .732 .913 r
F
.57979 .85431 m .58405 .85387 L .58283 .85344 L F
.58405 .85387 m .59195 .85306 L .58283 .85344 L F
.58146 .79707 m .58039 .79669 L .58048 .8526 L .809 .541 .533 r
F
.58054 .85262 m .58048 .8526 L .58049 .85568 L F
.58146 .79707 m .58048 .8526 L .58054 .85262 L F
.58161 .85302 m .58156 .85298 L .58156 .85606 L .909 .63 .501 r
F
.58251 .79788 m .58156 .85298 L .58161 .85302 L F
.58054 .85262 m .58049 .85568 L .58156 .85298 L .809 .541 .533 r
F
.5813 .85289 m .58225 .853 L .58193 .85229 L .645 .732 .913 r
F
.58199 .85314 m .58225 .853 L .5813 .85289 L F
.58225 .853 m .58888 .84947 L .58193 .85229 L F
.58139 .85112 m .58373 .85058 L .58337 .84717 L F
.58076 .85238 m .58171 .85181 L .58139 .85112 L F
.58171 .85181 m .58373 .85058 L .58139 .85112 L F
.58136 .85283 m .58373 .85058 L .58076 .85238 L F
.58373 .85058 m .58635 .84811 L .58425 .84745 L F
.58373 .85058 m .58425 .84745 L .58337 .84717 L F
0 g
.41928 .90609 m
.42899 .90744 L
s
.71111 .7594 m .70312 .77231 L .71677 .76371 L .683 .771 .917 r
F
.71111 .7594 m .69461 .76585 L .70312 .77231 L F
.26873 .51013 m .28376 .52834 L .2969 .52263 L .654 .726 .902 r
F
.26113 .51174 m .28376 .52834 L .26873 .51013 L F
.78353 .77734 m .79238 .76533 L .79289 .76989 L .408 .264 .572 r
F
.77074 .77011 m .78353 .77734 L .79289 .76989 L .683 .771 .917 r
F
.127 .923 .03 r
.78633 .77559 m
.78635 .77509 L
s
.78613 .77967 m
.78631 .7759 L
s
.78691 .78079 m
.7871 .77558 L
s
.78631 .7759 m
.78633 .77559 L
s
.7871 .77558 m
.7871 .77556 L
s
.7871 .77556 m
.78714 .77447 L
s
.76275 .77409 m .78353 .77734 L .77074 .77011 L .683 .771 .917 r
F
0 g
.77155 .78331 m
.78353 .77734 L
s
.41114 .99103 m .41402 .9895 L .41427 .99169 L .793 .528 .537 r
F
.41114 .99103 m .41088 .98883 L .41402 .9895 L F
0 g
.41402 .9895 m
.41741 .9896 L
s
.575 .85403 m .56781 .85164 L .56729 .85358 L .645 .732 .913 r
F
.57979 .85431 m .57447 .85313 L .575 .85403 L F
.57447 .85313 m .56781 .85164 L .575 .85403 L F
.57559 .85505 m .57597 .85927 L .5756 .85858 L .988 .72 .386 r
F
.5755 .79959 m .57594 .85566 L .57559 .85505 L F
.57594 .85566 m .57597 .85927 L .57559 .85505 L F
.57548 .85335 m .56914 .84988 L .56781 .85164 L .645 .732 .913 r
F
.57979 .85431 m .57542 .85249 L .57548 .85335 L F
.57542 .85249 m .56914 .84988 L .57548 .85335 L F
.57545 .79878 m .5755 .79959 L .57559 .85505 L .779 .622 .059 r
F
.57559 .85501 m .57559 .85505 L .5756 .85858 L F
.57545 .79878 m .57559 .85505 L .57559 .85501 L F
.41319 .98627 m .41404 .98946 L .41527 .98671 L .692 .759 .903 r
F
.41319 .98627 m .41092 .9888 L .41404 .98946 L F
.127 .923 .03 r
.34576 .77282 m
.3458 .77466 L
s
.61574 .78334 m .62884 .77165 L .61228 .77813 L .683 .771 .917 r
F
.61574 .78334 m .63402 .77947 L .62884 .77165 L F
.3179 .55276 m .33375 .53374 L .3333 .54101 L .339 .161 .487 r
F
.29621 .53734 m .3179 .55276 L .3333 .54101 L .654 .726 .902 r
F
.28299 .54307 m .3179 .55276 L .29621 .53734 L F
0 g
.31501 .55401 m
.3179 .55276 L
s
.3179 .55276 m
.31855 .55226 L
s
.31974 .67232 m .31384 .65776 L .3016 .66102 L .673 .758 .914 r
F
.32626 .67169 m .31384 .65776 L .31974 .67232 L F
.63352 .7749 m .62784 .76252 L .62834 .76708 L .98 .689 .335 r
F
.63402 .77947 m .63352 .7749 L .62834 .76708 L F
0 g
.63352 .7749 m
.63496 .78351 L
s
.36124 .65351 m .36415 .63555 L .3511 .64889 L .673 .757 .914 r
F
.36124 .65351 m .37936 .64248 L .36415 .63555 L F
.42427 .99031 m .42402 .98811 L .42679 .98663 L .515 .328 .565 r
F
.127 .923 .03 r
.40194 8.8269 m
.67261 1.12777 L
s
.67261 1.12777 m
.67927 .93843 L
s
.42107 .99132 m .42402 .98811 L .42427 .99031 L .6 .388 .566 r
F
0 g
.42082 .98912 m
.42402 .98811 L
s
.4219 .98579 m .42399 .98808 L .42675 .98661 L .692 .759 .903 r
F
.27585 .7769 m .28404 .77883 L .28452 .78339 L .931 .647 .48 r
F
.27585 .7769 m .27537 .77233 L .28404 .77883 L F
.29187 .76585 m .28404 .77883 L .29765 .77019 L .683 .77 .917 r
F
.127 .923 .03 r
.28342 .6983 m
.28348 .70258 L
s
.29187 .76585 m .27537 .77233 L .28404 .77883 L .683 .77 .917 r
F
0 g
.28404 .77883 m
.28869 .78074 L
s
.52433 .6516 m .5424 .64104 L .54272 .64671 L .603 .397 .574 r
F
.52465 .65727 m .52433 .6516 L .54272 .64671 L F
.50509 .65918 m .52433 .6516 L .52465 .65727 L .672 .449 .575 r
F
.51856 .63702 m .52433 .6516 L .54272 .64671 L .673 .757 .914 r
F
.50551 .6383 m .52433 .6516 L .51856 .63702 L F
0 g
.50477 .65351 m
.52433 .6516 L
s
.73298 .67213 m .72118 .65919 L .71051 .66422 L .673 .758 .915 r
F
.73911 .6705 m .72118 .65919 L .73298 .67213 L F
.62686 .52287 m .64969 .52284 L .64928 .53011 L .794 .542 .557 r
F
.62686 .52287 m .62727 .5156 L .64969 .52284 L F
0 g
.64969 .52284 m
.67395 .52617 L
s
.32626 .67169 m .32689 .65648 L .31384 .65776 L .673 .758 .914 r
F
.56273 .78176 m .54676 .77702 L .54273 .78263 L .683 .77 .917 r
F
.56583 .77928 m .54676 .77702 L .56273 .78176 L F
.78909 .66907 m .79987 .65184 L .78149 .66292 L .673 .758 .915 r
F
.78909 .66907 m .81127 .66107 L .79987 .65184 L F
.44826 .51496 m .41829 .50818 L .4145 .52361 L .654 .726 .902 r
F
.4174 .51536 m .41403 .52359 L .41359 .53086 L 0 0 .138 r
F
0 g
.41457 .52687 m
.41524 .53095 L
s
.4174 .51536 m .41784 .50808 L .41403 .52359 L 0 0 .138 r
F
.44826 .51496 m .4145 .52361 L .44572 .52525 L .654 .726 .902 r
F
.69801 .53266 m .69841 .52539 L .7214 .52053 L .592 .369 .546 r
F
.67355 .53345 m .69841 .52539 L .69801 .53266 L .667 .432 .555 r
F
0 g
.67395 .52617 m
.69841 .52539 L
s
.47821 .52174 m .44572 .52525 L .47693 .52688 L .654 .726 .902 r
F
.47821 .52174 m .44826 .51496 L .44572 .52525 L F
0 g
.5825 .78978 m
.58251 .79788 L
s
.3915 .65722 m .39119 .65155 L .37963 .64232 L .931 .657 .498 r
F
0 g
.39119 .65155 m
.39823 .66241 L
s
.5654 .77475 m .5526 .76756 L .54642 .7725 L .683 .77 .917 r
F
.56936 .77277 m .5526 .76756 L .5654 .77475 L F
.41792 .99399 m .41766 .99179 L .42107 .99132 L .669 .438 .561 r
F
.41453 .99389 m .41766 .99179 L .41792 .99399 L .731 .482 .552 r
F
.41453 .99389 m .41427 .99169 L .41766 .99179 L F
.41777 .989 m .41766 .99179 L .42107 .99132 L .692 .759 .904 r
F
.127 .923 .03 r
.42208 .83817 m
.42208 .83602 L
s
.41551 .98893 m .41766 .99179 L .41777 .989 L .692 .759 .904 r
F
.41551 .98893 m .41427 .99169 L .41766 .99179 L F
.64394 .49876 m .64983 .52255 L .65882 .50357 L .654 .726 .902 r
F
.64394 .49876 m .62752 .51535 L .64983 .52255 L F
.57542 .85249 m .5712 .84843 L .56914 .84988 L .645 .732 .913 r
F
.57979 .85431 m .57534 .85126 L .57542 .85249 L F
.57534 .85126 m .5712 .84843 L .57542 .85249 L F
.57554 .85431 m .5756 .85858 L .57555 .85777 L .779 .622 .059 r
F
.57545 .79878 m .57559 .85501 L .57554 .85431 L F
.57559 .85501 m .5756 .85858 L .57554 .85431 L F
.57608 .8534 m .57555 .85777 L .57608 .85675 L 0 0 .381 r
F
.57599 .79776 m .57557 .85426 L .57608 .8534 L F
.57557 .85426 m .57555 .85777 L .57608 .8534 L F
.57727 .85137 m .5769 .84679 L .57385 .84737 L .645 .732 .913 r
F
.5794 .85244 m .57831 .85564 L .5794 .85555 L .66 .418 .542 r
F
.5793 .79656 m .57836 .85247 L .5794 .85244 L F
.57979 .85431 m .57907 .85245 L .57822 .85248 L .645 .732 .913 r
F
.57741 .85268 m .57727 .85137 L .57676 .85224 L F
.57979 .85431 m .57823 .85249 L .57741 .85268 L F
.57821 .79665 m .57726 .85272 L .5783 .85247 L .569 .345 .536 r
F
.57823 .85249 m .57727 .85137 L .57741 .85268 L .645 .732 .913 r
F
.5783 .85247 m .5772 .85598 L .57831 .85564 L .569 .345 .536 r
F
.57726 .85272 m .5772 .85598 L .5783 .85247 L F
.57836 .85247 m .57831 .85564 L .5794 .85244 L .66 .418 .542 r
F
.57822 .85248 m .57811 .84994 L .57727 .85137 L .645 .732 .913 r
F
.57907 .85245 m .57811 .84994 L .57822 .85248 L F
.57811 .84994 m .5769 .84679 L .57727 .85137 L F
.57676 .85224 m .57385 .84737 L .5712 .84843 L F
.57727 .85137 m .57385 .84737 L .57676 .85224 L F
.57599 .79776 m .57545 .79878 L .57554 .85431 L 0 0 .381 r
F
.57557 .85426 m .57554 .85431 L .57555 .85777 L F
.57599 .79776 m .57554 .85431 L .57557 .85426 L F
.42133 .99351 m .42107 .99132 L .42427 .99031 L .6 .388 .566 r
F
.41792 .99399 m .42107 .99132 L .42133 .99351 L .669 .438 .561 r
F
.42005 .98868 m .42107 .99132 L .42427 .99031 L .692 .759 .904 r
F
.41777 .989 m .42107 .99132 L .42005 .98868 L F
0 g
.41766 .99179 m
.42107 .99132 L
s
.69116 .50526 m .6983 .52509 L .72118 .52025 L .654 .726 .902 r
F
.67492 .50578 m .6983 .52509 L .69116 .50526 L F
.53936 .53015 m .5689 .52128 L .53852 .5249 L F
.53936 .53015 m .57058 .53178 L .5689 .52128 L F
0 g
.72296 .55512 m
.74742 .55433 L
s
.71017 .65854 m .68053 .65778 L .70184 .66499 L .673 .758 .914 r
F
.57058 .53178 m .5993 .51765 L .5689 .52128 L .654 .726 .902 r
F
.57058 .53178 m .60179 .53341 L .5993 .51765 L F
.59573 .7846 m .60656 .7738 L .59287 .78244 L .683 .771 .917 r
F
.59573 .7846 m .61228 .77813 L .60656 .7738 L F
0 g
.74742 .55433 m
.77168 .55767 L
s
.40847 .98985 m .41088 .98883 L .41114 .99103 L .86 .578 .509 r
F
.127 .923 .03 r
.39972 8.82622 m
.43742 7.01981 L
s
.39695 8.82592 m
.40415 6.53805 L
s
.40847 .98985 m .40821 .98765 L .41088 .98883 L .86 .578 .509 r
F
0 g
.41088 .98883 m
.41402 .9895 L
s
.60185 .54071 m .60226 .53344 L .59976 .5176 L .917 .737 .245 r
F
0 g
.60044 .54064 m
.60147 .53656 L
s
.41142 .98549 m .41092 .9888 L .41319 .98627 L .692 .759 .903 r
F
.41142 .98549 m .40826 .98762 L .41092 .9888 L F
.37295 .76714 m .37247 .76258 L .37846 .75416 L .199 .114 .528 r
F
0 g
.36672 .76721 m
.37247 .76258 L
s
.70218 .67066 m .68087 .66346 L .67274 .67459 L .673 .758 .915 r
F
0 g
.66953 .68643 m
.67274 .67459 L
s
.41139 .99322 m .41427 .99169 L .41453 .99389 L .793 .528 .537 r
F
.41139 .99322 m .41114 .99103 L .41427 .99169 L F
.41342 .98849 m .41427 .99169 L .41551 .98893 L .692 .759 .904 r
F
.41342 .98849 m .41114 .99103 L .41427 .99169 L F
0 g
.41427 .99169 m
.41766 .99179 L
s
.3563 .75778 m .37223 .76251 L .37819 .75413 L .683 .77 .917 r
F
.35016 .76272 m .37223 .76251 L .3563 .75778 L F
0 g
.56184 .67692 m
.5814 .67501 L
s
.7521 .67026 m .74651 .65466 L .74564 .66986 L .673 .758 .915 r
F
.7521 .67026 m .75945 .65546 L .74651 .65466 L F
.58803 .77178 m .58899 .75986 L .58358 .7709 L .683 .77 .917 r
F
.58803 .77178 m .59788 .76161 L .58899 .75986 L F
.42705 .98883 m .42679 .98663 L .42895 .98479 L .393 .242 .554 r
F
.42427 .99031 m .42679 .98663 L .42705 .98883 L .515 .328 .565 r
F
0 g
.42402 .98811 m
.42679 .98663 L
s
.42453 .9925 m .42427 .99031 L .42705 .98883 L .515 .328 .565 r
F
.42133 .99351 m .42427 .99031 L .42453 .9925 L .6 .388 .566 r
F
.42218 .98801 m .42427 .99031 L .42705 .98883 L .692 .759 .904 r
F
.42005 .98868 m .42427 .99031 L .42218 .98801 L F
0 g
.42107 .99132 m
.42427 .99031 L
s
.42374 .98481 m .42675 .98661 L .42889 .98477 L .692 .759 .903 r
F
.127 .923 .03 r
.42918 .9742 m
.42939 .9241 L
s
.45018 .95322 m
.4505 .90606 L
s
.4219 .98579 m .42675 .98661 L .42374 .98481 L .692 .759 .903 r
F
.59237 .77787 m .59848 .76608 L .58858 .77629 L .683 .77 .917 r
F
.59237 .77787 m .60606 .76923 L .59848 .76608 L F
0 g
.58251 .79788 m
.5826 .8487 L
s
.57711 .79699 m .57599 .79776 L .57608 .85675 L .404 .216 .509 r
F
0 g
.57599 .79776 m
.57607 .84695 L
s
.57597 .79011 m
.57599 .79776 L
s
.46773 .65376 m .48536 .65231 L .48568 .65799 L .794 .544 .56 r
F
.46773 .65376 m .46742 .64809 L .48536 .65231 L F
.48059 .63468 m .48536 .65231 L .49256 .6375 L .673 .757 .914 r
F
.48059 .63468 m .46742 .64809 L .48536 .65231 L F
0 g
.48536 .65231 m
.50477 .65351 L
s
.54272 .64671 m .5424 .64104 L .55835 .6335 L .517 .331 .568 r
F
0 g
.53409 .64325 m
.5424 .64104 L
s
.54676 .77702 m .52475 .78069 L .54273 .78263 L .683 .77 .917 r
F
.73911 .6705 m .73346 .65593 L .72118 .65919 L .673 .758 .915 r
F
.74564 .66986 m .73346 .65593 L .73911 .6705 L F
.61111 .76906 m .61906 .75615 L .60543 .76475 L .683 .77 .917 r
F
.61111 .76906 m .62759 .76261 L .61906 .75615 L F
.78062 .65168 m .78382 .63372 L .77056 .64706 L .673 .758 .914 r
F
.78062 .65168 m .79891 .64066 L .78382 .63372 L F
.32488 .76869 m .32441 .77991 L .33416 .77863 L .683 .77 .917 r
F
.32004 .76857 m .32441 .77991 L .32488 .76869 L F
.32004 .76857 m .31472 .77967 L .32441 .77991 L F
.41803 .99119 m .41792 .99399 L .42133 .99351 L .692 .759 .904 r
F
.127 .923 .03 r
.42207 .84032 m
.42208 .83817 L
s
.41577 .99113 m .41792 .99399 L .41803 .99119 L .692 .759 .904 r
F
.41577 .99113 m .41453 .99389 L .41792 .99399 L F
.4203 .99088 m .42133 .99351 L .42453 .9925 L F
.41803 .99119 m .42133 .99351 L .4203 .99088 L F
0 g
.41792 .99399 m
.42133 .99351 L
s
.53038 .62796 m .54222 .64085 L .5581 .63334 L .673 .757 .914 r
F
.51818 .63121 m .54222 .64085 L .53038 .62796 L F
.69538 .77508 m .70342 .77701 L .70393 .78158 L .933 .647 .474 r
F
.69538 .77508 m .69487 .77051 L .70342 .77701 L F
.71145 .76403 m .70342 .77701 L .71715 .76837 L .683 .771 .917 r
F
.71145 .76403 m .69487 .77051 L .70342 .77701 L F
0 g
.70342 .77701 m
.70809 .77895 L
s
.33386 .76212 m .34283 .77134 L .35077 .76736 L .683 .77 .917 r
F
.29101 .66604 m .26133 .66528 L .28278 .67248 L .673 .758 .914 r
F
.74564 .66986 m .74651 .65466 L .73346 .65593 L .673 .758 .915 r
F
.50583 .64397 m .50509 .65918 L .52465 .65727 L .673 .758 .914 r
F
.49288 .64317 m .50509 .65918 L .50583 .64397 L F
.49288 .64317 m .48568 .65799 L .50509 .65918 L F
.40872 .99204 m .41114 .99103 L .41139 .99322 L .86 .578 .509 r
F
.40872 .99204 m .40847 .98985 L .41114 .99103 L F
.41164 .9877 m .41114 .99103 L .41342 .98849 L .692 .759 .904 r
F
.41164 .9877 m .40847 .98985 L .41114 .99103 L F
0 g
.41114 .99103 m
.41427 .99169 L
s
.32976 .76805 m .33416 .77863 L .34331 .77591 L .683 .77 .917 r
F
.32488 .76869 m .33416 .77863 L .32976 .76805 L F
.81093 .6554 m .81058 .64973 L .79918 .64049 L .933 .657 .493 r
F
0 g
.81058 .64973 m
.81743 .66059 L
s
.63402 .77947 m .62834 .76708 L .62884 .77165 L .98 .689 .335 r
F
0 g
.63402 .77947 m
.63547 .78808 L
s
.25209 .52666 m .25143 .54683 L .26772 .54631 L .654 .726 .902 r
F
.24399 .52554 m .25143 .54683 L .25209 .52666 L F
.24399 .52554 m .23524 .54461 L .25143 .54683 L F
.41368 .99069 m .41453 .99389 L .41577 .99113 L .692 .759 .904 r
F
.41368 .99069 m .41139 .99322 L .41453 .99389 L F
0 g
.41453 .99389 m
.41792 .99399 L
s
0 0 0 r
2.5 Mabswid
.34498 .77739 Mdot
.56936 .77277 m .56052 .7636 L .5526 .76756 L .683 .77 .917 r
F
.127 .923 .03 r
.5 Mabswid
.56254 .7657 m
.56369 .70858 L
s
.57392 .77142 m .56052 .7636 L .56936 .77277 L .683 .77 .917 r
F
.127 .923 .03 r
.56321 .76517 m
.56369 .70858 L
s
.57821 .79665 m .57711 .79699 L .5772 .85598 L .569 .345 .536 r
F
.67314 .54072 m .67355 .53345 L .69801 .53266 L .667 .432 .555 r
F
.64888 .53738 m .67355 .53345 L .67314 .54072 L .732 .488 .558 r
F
.64888 .53738 m .64928 .53011 L .67355 .53345 L F
.67451 .51326 m .67355 .53345 L .69801 .53266 L .654 .726 .902 r
F
.65832 .51103 m .67355 .53345 L .67451 .51326 L F
.65832 .51103 m .64928 .53011 L .67355 .53345 L F
.40645 .98823 m .40821 .98765 L .40847 .98985 L .933 .634 .452 r
F
.127 .923 .03 r
.40415 6.53805 m
.41493 3.10975 L
s
.38882 .88383 m
.40125 1.80641 L
s
.40125 1.80641 m
.40712 2.24185 L
s
.40645 .98823 m .40619 .98603 L .40821 .98765 L .933 .634 .452 r
F
0 g
.40821 .98765 m
.41033 .98859 L
s
.41008 .98441 m .40826 .98762 L .41142 .98549 L .692 .759 .903 r
F
.41008 .98441 m .40625 .98601 L .40826 .98762 L F
.127 .923 .03 r
.39076 .92905 m
.39148 .98321 L
s
.29234 .77042 m .28452 .78339 L .29812 .77475 L .683 .77 .917 r
F
.127 .923 .03 r
.28348 .70258 m
.28354 .70687 L
s
.29234 .77042 m .27585 .7769 L .28452 .78339 L .683 .77 .917 r
F
0 g
.28452 .78339 m
.29597 .78812 L
s
.42705 .98883 m .42895 .98479 L .4292 .98698 L .393 .242 .554 r
F
.4273 .99102 m .42705 .98883 L .4292 .98698 L F
.42453 .9925 m .42705 .98883 L .4273 .99102 L .515 .328 .565 r
F
.42403 .98702 m .42705 .98883 L .4292 .98698 L .692 .759 .904 r
F
.127 .923 .03 r
.45017 .95533 m
.45018 .95322 L
s
.42218 .98801 m .42705 .98883 L .42403 .98702 L .692 .759 .904 r
F
0 g
.42427 .99031 m
.42705 .98883 L
s
.42243 .99021 m .42453 .9925 L .4273 .99102 L .692 .759 .904 r
F
.4203 .99088 m .42453 .9925 L .42243 .99021 L F
0 g
.42133 .99351 m
.42453 .9925 L
s
.127 .923 .03 r
.37559 2.35367 m
.49723 8.79917 L
s
0 0 0 r
2.5 Mabswid
.34584 .77704 Mdot
.58039 .79669 m .5794 .85555 L .58049 .85568 L .734 .478 .541 r
F
.58039 .79669 m .5793 .79656 L .5794 .85555 L F
.56322 .78633 m .54725 .78159 L .54323 .7872 L .683 .771 .917 r
F
.56632 .78385 m .54725 .78159 L .56322 .78633 L F
.5793 .79656 m .57821 .79665 L .57831 .85564 L .66 .418 .542 r
F
.79238 .76533 m .79187 .76076 L .79798 .75234 L .212 .125 .534 r
F
0 g
.5 Mabswid
.78604 .76539 m
.79187 .76076 L
s
.29059 .6548 m .27335 .64442 L .26107 .65405 L .673 .757 .914 r
F
.30113 .6498 m .27335 .64442 L .29059 .6548 L F
.7758 .75596 m .79163 .76069 L .79771 .75231 L .683 .771 .917 r
F
.76958 .7609 m .79163 .76069 L .7758 .75596 L F
.58358 .7709 m .57936 .75961 L .57877 .77078 L .683 .77 .917 r
F
.58358 .7709 m .58899 .75986 L .57936 .75961 L F
.56583 .77928 m .55296 .77205 L .54676 .77702 L F
.56981 .77729 m .55296 .77205 L .56583 .77928 L F
.4292 .98698 m .42895 .98479 L .43034 .98269 L .19 .099 .515 r
F
0 g
.42679 .98663 m
.42895 .98479 L
s
.42517 .98359 m .42889 .98477 L .43028 .98269 L .692 .759 .903 r
F
.42374 .98481 m .42889 .98477 L .42517 .98359 L F
.36172 .65907 m .36465 .64102 L .35153 .65443 L .673 .757 .914 r
F
.36172 .65907 m .37994 .64799 L .36465 .64102 L F
.52465 .65727 m .54272 .64671 L .54304 .65238 L .603 .397 .574 r
F
.51887 .6427 m .52465 .65727 L .54304 .65238 L .673 .758 .914 r
F
.50583 .64397 m .52465 .65727 L .51887 .6427 L F
0 g
.50509 .65918 m
.52465 .65727 L
s
.31555 .76769 m .31472 .77967 L .32004 .76857 L .683 .77 .917 r
F
.31555 .76769 m .30576 .77791 L .31472 .77967 L F
.37295 .76714 m .37846 .75416 L .37894 .75872 L .199 .114 .528 r
F
.37343 .77171 m .37295 .76714 L .37894 .75872 L F
.35694 .7624 m .37295 .76714 L .37894 .75872 L .683 .77 .917 r
F
.35077 .76736 m .37295 .76714 L .35694 .7624 L F
0 g
.3672 .77177 m
.37295 .76714 L
s
.41457 .98335 m .41142 .98549 L .41319 .98627 L .692 .759 .903 r
F
.57392 .77142 m .56964 .76088 L .56052 .7636 L .683 .77 .917 r
F
.57877 .77078 m .56964 .76088 L .57392 .77142 L F
.4119 .9899 m .41139 .99322 L .41368 .99069 L .692 .759 .904 r
F
.4119 .9899 m .40872 .99204 L .41139 .99322 L F
0 g
.41139 .99322 m
.41453 .99389 L
s
.33728 .75553 m .35016 .76272 L .3563 .75778 L .683 .77 .917 r
F
.3915 .65722 m .37963 .64232 L .37994 .64799 L .931 .657 .498 r
F
.3918 .66289 m .3915 .65722 L .37994 .64799 L F
0 g
.3915 .65722 m
.39853 .66808 L
s
.41788 .98621 m .41777 .989 L .42005 .98868 L .692 .759 .904 r
F
0 g
.41815 .98669 m
.41815 .98586 L
s
.41675 .98617 m .41551 .98893 L .41777 .989 L .692 .759 .904 r
F
.41902 .98605 m .42005 .98868 L .42218 .98801 L F
.57877 .77078 m .57936 .75961 L .56964 .76088 L .683 .77 .917 r
F
.74447 .76687 m .74381 .7781 L .75357 .77681 L .683 .771 .917 r
F
.73964 .76675 m .74381 .7781 L .74447 .76687 L F
.73964 .76675 m .73414 .77785 L .74381 .7781 L F
.73044 .75511 m .71677 .76371 L .7243 .76685 L F
.23055 .5123 m .2207 .53251 L .23695 .51585 L .654 .726 .902 r
F
.23055 .5123 m .2079 .52542 L .2207 .53251 L F
.58858 .77629 m .58954 .76431 L .58411 .77541 L .683 .77 .917 r
F
.58858 .77629 m .59848 .76608 L .58954 .76431 L F
.4067 .99042 m .40847 .98985 L .40872 .99204 L .933 .634 .452 r
F
.4067 .99042 m .40645 .98823 L .40847 .98985 L F
.41029 .98662 m .40847 .98985 L .41164 .9877 L .692 .759 .904 r
F
.41029 .98662 m .40645 .98823 L .40847 .98985 L F
0 g
.40847 .98985 m
.41058 .99078 L
s
.127 .923 .03 r
.39148 .98321 m
.39151 .9853 L
s
.59287 .78244 m .59898 .77064 L .58908 .78086 L .683 .771 .917 r
F
.59287 .78244 m .60656 .7738 L .59898 .77064 L F
.75343 .7603 m .76224 .76952 L .77022 .76554 L F
.23648 .52313 m .23524 .54461 L .24399 .52554 L .654 .726 .902 r
F
.23648 .52313 m .22023 .53979 L .23524 .54461 L F
.54642 .7725 m .53053 .76778 L .52452 .77615 L .683 .77 .917 r
F
.53738 .54987 m .57005 .54635 L .53867 .54471 L .654 .726 .902 r
F
.71051 .66422 m .68087 .66346 L .70218 .67066 L .673 .758 .915 r
F
.53078 .77227 m .52425 .77612 L .52475 .78069 L .204 .118 .53 r
F
.53078 .77227 m .53029 .7677 L .52425 .77612 L F
0 g
.5219 .78493 m
.52425 .77612 L
s
.26024 .52639 m .26772 .54631 L .28299 .54307 L .654 .726 .902 r
F
.25209 .52666 m .26772 .54631 L .26024 .52639 L F
.26834 .51749 m .28345 .5358 L .29666 .53006 L F
.2607 .51912 m .28345 .5358 L .26834 .51749 L F
.4157 .98595 m .41551 .98893 L .41675 .98617 L .692 .759 .904 r
F
.4157 .98595 m .41342 .98849 L .41551 .98893 L F
.4273 .99102 m .4292 .98698 L .42946 .98918 L .393 .242 .554 r
F
.42428 .98922 m .4273 .99102 L .42946 .98918 L .692 .759 .904 r
F
.127 .923 .03 r
.45015 .95744 m
.45017 .95533 L
s
.42243 .99021 m .4273 .99102 L .42428 .98922 L .692 .759 .904 r
F
0 g
.42453 .9925 m
.4273 .99102 L
s
.74935 .76623 m .75357 .77681 L .76275 .77409 L .683 .771 .917 r
F
.74447 .76687 m .75357 .77681 L .74935 .76623 L F
.54725 .78159 m .52524 .78526 L .54323 .7872 L F
.42008 .98571 m .42218 .98801 L .42403 .98702 L .692 .759 .904 r
F
.31126 .76154 m .29765 .77019 L .30528 .77334 L .683 .77 .917 r
F
.61178 .77356 m .61976 .76058 L .60606 .76923 L F
.61178 .77356 m .62834 .76708 L .61976 .76058 L F
.16173 .5101 m .17118 .51793 L .1707 .52521 L .989 .743 .466 r
F
.16173 .5101 m .16221 .50283 L .17118 .51793 L F
0 g
.17118 .51793 m
.17697 .52323 L
s
.71196 .7686 m .70393 .78158 L .71765 .77294 L .683 .771 .917 r
F
.71196 .7686 m .69538 .77508 L .70393 .78158 L F
0 g
.70393 .78158 m
.71528 .7863 L
s
.33434 .76669 m .34331 .77591 L .35125 .77193 L .683 .77 .917 r
F
.127 .923 .03 r
.34596 .6934 m
.34599 .69769 L
s
.32976 .76805 m .34331 .77591 L .33434 .76669 L .683 .77 .917 r
F
.4292 .98698 m .43034 .98269 L .43059 .98489 L .19 .099 .515 r
F
.42946 .98918 m .4292 .98698 L .43059 .98489 L F
.42546 .98579 m .4292 .98698 L .43059 .98489 L .692 .759 .904 r
F
.42403 .98702 m .4292 .98698 L .42546 .98579 L F
0 g
.42705 .98883 m
.4292 .98698 L
s
.19299 .49915 m .17159 .5178 L .19893 .50917 L .654 .726 .902 r
F
.19299 .49915 m .16266 .50278 L .17159 .5178 L F
.4139 .98282 m .41142 .98549 L .41457 .98335 L .692 .759 .903 r
F
.4139 .98282 m .41008 .98441 L .41142 .98549 L F
.40521 .98628 m .40619 .98603 L .40645 .98823 L .976 .674 .311 r
F
.40521 .98628 m .40496 .98408 L .40619 .98603 L F
0 g
.40619 .98603 m
.40808 .98755 L
s
.40926 .98312 m .40625 .98601 L .41008 .98441 L .692 .759 .903 r
F
.40926 .98312 m .40502 .98407 L .40625 .98601 L F
.62645 .53015 m .64928 .53011 L .64888 .53738 L .794 .542 .557 r
F
.62645 .53015 m .62686 .52287 L .64928 .53011 L F
.64336 .5062 m .64928 .53011 L .65832 .51103 L .654 .726 .902 r
F
.64336 .5062 m .62686 .52287 L .64928 .53011 L F
0 g
.64928 .53011 m
.67355 .53345 L
s
.41481 .98556 m .41342 .98849 L .4157 .98595 L .692 .759 .904 r
F
.41481 .98556 m .41164 .9877 L .41342 .98849 L F
.51044 .52676 m .51371 .52318 L .51073 .52234 L .675 .735 .895 r
F
.71 .65298 m .69295 .6426 L .68052 .65222 L .673 .758 .914 r
F
.72062 .64798 m .69295 .6426 L .71 .65298 L F
.33375 .53374 m .33421 .52646 L .34413 .51235 L .063 0 .39 r
F
0 g
.32572 .53294 m
.33421 .52646 L
s
.50729 .53603 m .5043 .5324 L .50297 .53306 L .675 .735 .895 r
F
0 g
.50408 .53476 m
.50408 .53914 L
s
.44752 .52217 m .4174 .51536 L .41359 .53086 L .654 .726 .902 r
F
.41696 .52263 m .41359 .53086 L .41315 .53814 L 0 0 .138 r
F
0 g
.41413 .53414 m
.4148 .53822 L
s
.41696 .52263 m .4174 .51536 L .41359 .53086 L 0 0 .138 r
F
.44752 .52217 m .41359 .53086 L .44497 .5325 L .654 .726 .902 r
F
.45215 .64112 m .4671 .64242 L .46742 .64809 L .859 .596 .54 r
F
.127 .923 .03 r
.46425 .64217 m
.46468 .58934 L
s
.45215 .64112 m .45184 .63545 L .4671 .64242 L .859 .596 .54 r
F
0 g
.4671 .64242 m
.47188 .64354 L
s
.69801 .53266 m .7214 .52053 L .72101 .5278 L .592 .369 .546 r
F
.69761 .53993 m .69801 .53266 L .72101 .5278 L F
.67314 .54072 m .69801 .53266 L .69761 .53993 L .667 .432 .555 r
F
.69083 .51273 m .69801 .53266 L .72101 .5278 L .654 .726 .902 r
F
.67451 .51326 m .69801 .53266 L .69083 .51273 L F
0 g
.67355 .53345 m
.69801 .53266 L
s
.48091 .64035 m .48568 .65799 L .49288 .64317 L .673 .758 .914 r
F
.48091 .64035 m .46773 .65376 L .48568 .65799 L F
0 g
.48568 .65799 m
.50509 .65918 L
s
.54272 .64671 m .55835 .6335 L .55868 .63917 L .517 .331 .568 r
F
.54304 .65238 m .54272 .64671 L .55868 .63917 L F
.53082 .63376 m .54272 .64671 L .55868 .63917 L .673 .757 .914 r
F
.51856 .63702 m .54272 .64671 L .53082 .63376 L F
0 g
.53441 .64892 m
.54272 .64671 L
s
.47762 .52898 m .44497 .5325 L .47634 .53415 L .654 .726 .902 r
F
.47762 .52898 m .44752 .52217 L .44497 .5325 L F
.56981 .77729 m .56092 .76807 L .55296 .77205 L .683 .77 .917 r
F
.57439 .77593 m .56092 .76807 L .56981 .77729 L F
.42517 .98359 m .43028 .98269 L .42609 .9822 L .692 .759 .903 r
F
.42145 .9824 m .42517 .98359 L .42609 .9822 L F
.30712 .51483 m .3338 .52629 L .34368 .51225 L .654 .726 .902 r
F
.2969 .52263 m .3338 .52629 L .30712 .51483 L F
.41813 .9884 m .41803 .99119 L .4203 .99088 L .692 .759 .904 r
F
.417 .98837 m .41803 .99119 L .41813 .9884 L F
.417 .98837 m .41577 .99113 L .41803 .99119 L F
.41927 .98824 m .4203 .99088 L .42243 .99021 L F
.41813 .9884 m .4203 .99088 L .41927 .98824 L F
.47028 .62424 m .4673 .64222 L .48041 .62887 L .673 .757 .914 r
F
.47028 .62424 m .45212 .63528 L .4673 .64222 L F
.42101 .98522 m .42403 .98702 L .42546 .98579 L .692 .759 .904 r
F
.50895 .52634 m .51073 .52234 L .50751 .52203 L .675 .735 .895 r
F
.51052 .52959 m .51081 .52514 L .50902 .52916 L F
.51371 .52318 m .51251 .51833 L .51073 .52234 L F
.50908 .53201 m .50763 .52768 L .50746 .53186 L F
.50908 .53201 m .51087 .52799 L .50763 .52768 L F
.51073 .52234 m .50768 .51788 L .50751 .52203 L F
.51073 .52234 m .51251 .51833 L .50768 .51788 L F
.51381 .52599 m .5126 .52112 L .51081 .52514 L F
.51081 .52514 m .50774 .52066 L .50757 .52484 L F
.51081 .52514 m .5126 .52112 L .50774 .52066 L F
.51087 .52799 m .51267 .52396 L .5078 .52351 L F
.5126 .52112 m .51254 .51827 L .50768 .51782 L .731 .477 .545 r
F
.5171 .52239 m .51254 .51827 L .5126 .52112 L .794 .529 .537 r
F
.5126 .52112 m .50768 .51782 L .50774 .52066 L .731 .477 .545 r
F
.51267 .52396 m .5126 .52112 L .50774 .52066 L F
.51267 .52396 m .50774 .52066 L .5078 .52351 L F
.50772 .53579 m .51666 .51672 L .50856 .5156 L .654 .726 .902 r
F
0 g
.51061 .53498 m
.51061 .53599 L
s
.78114 .65724 m .78436 .63919 L .77103 .6526 L .673 .758 .914 r
F
.78114 .65724 m .79953 .64616 L .78436 .63919 L F
.53909 .53743 m .56879 .52851 L .53825 .53215 L .654 .726 .902 r
F
.53909 .53743 m .57047 .53907 L .56879 .52851 L F
.41055 .98882 m .40872 .99204 L .4119 .9899 L .692 .759 .904 r
F
.41055 .98882 m .4067 .99042 L .40872 .99204 L F
0 g
.40872 .99204 m
.41139 .99322 L
s
.127 .923 .03 r
.39151 .9853 m
.39154 .98739 L
s
.73517 .76587 m .73414 .77785 L .73964 .76675 L .683 .771 .917 r
F
.73517 .76587 m .72522 .77609 L .73414 .77785 L F
.57047 .53907 m .59934 .52488 L .56879 .52851 L .654 .726 .902 r
F
.57047 .53907 m .60185 .54071 L .59934 .52488 L F
.79238 .76533 m .79798 .75234 L .7985 .7569 L .212 .125 .534 r
F
.79289 .76989 m .79238 .76533 L .7985 .7569 L F
.77647 .76058 m .79238 .76533 L .7985 .7569 L .683 .771 .917 r
F
.77022 .76554 m .79238 .76533 L .77647 .76058 L F
0 g
.78656 .76995 m
.79238 .76533 L
s
.43059 .98489 m .43034 .98269 L .43087 .9805 L 0 0 .382 r
F
0 g
.42895 .98479 m
.43034 .98269 L
s
.127 .923 .03 r
.4286 4.17856 m
.44957 1.04503 L
s
.44957 1.04503 m
.45015 .95744 L
s
.42609 .9822 m .43028 .98269 L .43081 .9805 L .692 .759 .903 r
F
.41596 .98815 m .41577 .99113 L .417 .98837 L .692 .759 .904 r
F
.41596 .98815 m .41368 .99069 L .41577 .99113 L F
.60185 .54071 m .59976 .5176 L .59934 .52488 L .917 .737 .245 r
F
.60143 .54799 m .60185 .54071 L .59934 .52488 L F
0 g
.60003 .54792 m
.60106 .54384 L
s
.75685 .75371 m .76958 .7609 L .7758 .75596 L .683 .771 .917 r
F
.56632 .78385 m .55346 .77662 L .54725 .78159 L F
.5703 .78186 m .55346 .77662 L .56632 .78385 L F
.81093 .6554 m .79918 .64049 L .79953 .64616 L .933 .657 .493 r
F
.127 .923 .03 r
.8062 .64248 m
.80646 .63716 L
s
.81127 .66107 m .81093 .6554 L .79953 .64616 L .933 .657 .493 r
F
0 g
.81093 .6554 m
.81778 .66626 L
s
.58411 .77541 m .57986 .76406 L .57927 .77529 L .683 .77 .917 r
F
.58411 .77541 m .58954 .76431 L .57986 .76406 L F
.42034 .98791 m .42243 .99021 L .42428 .98922 L .692 .759 .904 r
F
.41927 .98824 m .42243 .99021 L .42034 .98791 L F
.5526 .76756 m .53053 .76778 L .54642 .7725 L .683 .77 .917 r
F
.42946 .98918 m .43059 .98489 L .43085 .98708 L .19 .099 .515 r
F
.42572 .98799 m .42946 .98918 L .43085 .98708 L .692 .759 .904 r
F
.42428 .98922 m .42946 .98918 L .42572 .98799 L F
0 g
.4273 .99102 m
.42946 .98918 L
s
.27338 .64994 m .26075 .65394 L .26104 .65961 L .386 .233 .548 r
F
.27338 .64994 m .27309 .64427 L .26075 .65394 L F
0 g
.2528 .66507 m
.26075 .65394 L
s
.41414 .98502 m .41164 .9877 L .41481 .98556 L .692 .759 .904 r
F
.41414 .98502 m .41029 .98662 L .41164 .9877 L F
.37343 .77171 m .37894 .75872 L .37942 .76329 L .199 .114 .528 r
F
.35742 .76696 m .37343 .77171 L .37942 .76329 L .683 .77 .917 r
F
.35125 .77193 m .37343 .77171 L .35742 .76696 L F
0 g
.36418 .77916 m
.37343 .77171 L
s
.41349 .98217 m .41008 .98441 L .4139 .98282 L .692 .759 .903 r
F
.41349 .98217 m .40926 .98312 L .41008 .98441 L F
.40547 .98847 m .40645 .98823 L .4067 .99042 L .976 .674 .311 r
F
.40547 .98847 m .40521 .98628 L .40645 .98823 L F
.40947 .98532 m .40645 .98823 L .41029 .98662 L .692 .759 .904 r
F
.40947 .98532 m .40521 .98628 L .40645 .98823 L F
0 g
.40645 .98823 m
.40833 .98974 L
s
.33783 .76013 m .35077 .76736 L .35694 .7624 L .683 .77 .917 r
F
.57439 .77593 m .5701 .76535 L .56092 .76807 L F
.57927 .77529 m .5701 .76535 L .57439 .77593 L F
.41507 .98775 m .41368 .99069 L .41596 .98815 L .692 .759 .904 r
F
.41507 .98775 m .4119 .9899 L .41368 .99069 L F
.73088 .75972 m .71715 .76837 L .72471 .77152 L .683 .771 .917 r
F
.29071 .66037 m .27338 .64994 L .26104 .65961 L .673 .757 .914 r
F
.30131 .65535 m .27338 .64994 L .29071 .66037 L F
.3511 .64889 m .34626 .63134 L .33917 .64609 L F
.3511 .64889 m .36415 .63555 L .34626 .63134 L F
.57927 .77529 m .57986 .76406 L .5701 .76535 L .683 .77 .917 r
F
.48152 .51706 m .44826 .51496 L .47821 .52174 L .654 .726 .902 r
F
.42546 .98579 m .43059 .98489 L .42639 .9844 L .692 .759 .904 r
F
.42173 .9846 m .42546 .98579 L .42639 .9844 L F
.58908 .78086 m .59004 .76888 L .58461 .77998 L .683 .771 .917 r
F
.58908 .78086 m .59898 .77064 L .59004 .76888 L F
.75395 .76487 m .76275 .77409 L .77074 .77011 L F
.74935 .76623 m .76275 .77409 L .75395 .76487 L F
.36202 .66474 m .36495 .64669 L .35183 .6601 L .673 .758 .914 r
F
.36202 .66474 m .38024 .65366 L .36495 .64669 L F
.42609 .9822 m .43081 .9805 L .42645 .98074 L .692 .759 .903 r
F
.42191 .98171 m .42609 .9822 L .42645 .98074 L F
.42145 .9824 m .42609 .9822 L .42191 .98171 L F
.53128 .77684 m .52475 .78069 L .52524 .78526 L .204 .118 .53 r
F
.54676 .77702 m .53078 .77227 L .52475 .78069 L .683 .77 .917 r
F
.53128 .77684 m .53078 .77227 L .52475 .78069 L .204 .118 .53 r
F
0 g
.52239 .7895 m
.52475 .78069 L
s
.127 .923 .03 r
.52419 .82684 m
.52518 .764 L
s
.42126 .98741 m .42428 .98922 L .42572 .98799 L .692 .759 .904 r
F
.42034 .98791 m .42428 .98922 L .42126 .98741 L F
.53852 .5249 m .56309 .51126 L .53561 .51989 L .654 .726 .902 r
F
.53852 .5249 m .5689 .52128 L .56309 .51126 L F
.2263 .50054 m .2086 .51801 L .23113 .50496 L F
.2263 .50054 m .19893 .50917 L .2086 .51801 L F
.43059 .98489 m .43087 .9805 L .43113 .9827 L 0 0 .382 r
F
.43085 .98708 m .43059 .98489 L .43113 .9827 L F
.42639 .9844 m .43059 .98489 L .43113 .9827 L .692 .759 .904 r
F
0 g
.4292 .98698 m
.43059 .98489 L
s
.31174 .76611 m .30576 .77791 L .31555 .76769 L .683 .77 .917 r
F
.31174 .76611 m .29812 .77475 L .30576 .77791 L F
.3918 .66289 m .37994 .64799 L .38024 .65366 L .931 .657 .498 r
F
0 g
.3918 .66289 m
.39884 .67375 L
s
.30798 .75477 m .29731 .76553 L .31085 .75693 L .683 .77 .917 r
F
.30798 .75477 m .29156 .76122 L .29731 .76553 L F
.61228 .77813 m .62027 .76515 L .60656 .7738 L .683 .771 .917 r
F
.61228 .77813 m .62884 .77165 L .62027 .76515 L F
.2753 .50727 m .2969 .52263 L .30712 .51483 L .654 .726 .902 r
F
.26873 .51013 m .2969 .52263 L .2753 .50727 L F
.27007 .76451 m .2749 .76776 L .27537 .77233 L .982 .691 .347 r
F
.27007 .76451 m .2696 .75994 L .2749 .76776 L F
0 g
.2749 .76776 m
.27906 .77088 L
s
.6078 .51223 m .62727 .5156 L .62686 .52287 L .858 .601 .549 r
F
.6078 .51223 m .60821 .50495 L .62727 .5156 L F
0 g
.62727 .5156 m
.63242 .51726 L
s
.28804 .75603 m .27515 .76767 L .29156 .76122 L .683 .77 .917 r
F
.28804 .75603 m .26987 .75988 L .27515 .76767 L F
.40485 .98413 m .40496 .98408 L .40521 .98628 L .765 .548 0 r
F
.40485 .98413 m .40459 .98194 L .40496 .98408 L F
0 g
.40496 .98408 m
.40619 .98603 L
s
.40902 .9817 m .40502 .98407 L .40926 .98312 L .692 .759 .903 r
F
.40902 .9817 m .40466 .98194 L .40502 .98407 L F
.6741 .52054 m .67314 .54072 L .69761 .53993 L .654 .726 .902 r
F
.65791 .51831 m .67314 .54072 L .6741 .52054 L F
.65791 .51831 m .64888 .53738 L .67314 .54072 L F
.72101 .5278 m .7214 .52053 L .74138 .51192 L .494 .288 .528 r
F
0 g
.71089 .52275 m
.7214 .52053 L
s
.63129 .49169 m .62752 .51535 L .64394 .49876 L .654 .726 .902 r
F
.63129 .49169 m .60855 .50476 L .62752 .51535 L F
.50297 .53306 m .49658 .5318 L .50194 .53391 L .675 .735 .895 r
F
.4144 .98721 m .4119 .9899 L .41507 .98775 L .692 .759 .904 r
F
.4144 .98721 m .41055 .98882 L .4119 .9899 L F
.41373 .98437 m .41029 .98662 L .41414 .98502 L F
.41373 .98437 m .40947 .98532 L .41029 .98662 L F
.40972 .98752 m .4067 .99042 L .41055 .98882 L F
.40972 .98752 m .40547 .98847 L .4067 .99042 L F
0 g
.4067 .99042 m
.40872 .99204 L
s
.70642 .50203 m .72118 .52025 L .74106 .51169 L .654 .726 .902 r
F
.69116 .50526 m .72118 .52025 L .70642 .50203 L F
.5703 .78186 m .56142 .77264 L .55346 .77662 L .683 .771 .917 r
F
.57489 .7805 m .56142 .77264 L .5703 .78186 L F
.41337 .98146 m .40926 .98312 L .41349 .98217 L .692 .759 .903 r
F
.41337 .98146 m .40902 .9817 L .40926 .98312 L F
.42191 .98171 m .42645 .98074 L .42209 .98098 L F
.42572 .98799 m .43085 .98708 L .42665 .98659 L .692 .759 .904 r
F
.42198 .9868 m .42572 .98799 L .42665 .98659 L F
.42126 .98741 m .42572 .98799 L .42198 .9868 L F
0 g
.41815 .98669 m
.41974 .98649 L
s
.41815 .98669 m
.41815 .98669 L
s
.41658 .98643 m
.41815 .98669 L
s
.43113 .9827 m .43087 .9805 L .43051 .97836 L .763 .546 0 r
F
0 g
.43034 .98269 m
.43084 .98065 L
s
.42645 .98074 m .43081 .9805 L .43044 .97837 L .692 .759 .903 r
F
.69302 .64811 m .6802 .65211 L .68053 .65778 L .392 .238 .551 r
F
.69302 .64811 m .69269 .64244 L .6802 .65211 L F
0 g
.67207 .66325 m
.6802 .65211 L
s
.42639 .9844 m .43113 .9827 L .42675 .98294 L .692 .759 .904 r
F
.42219 .98391 m .42639 .9844 L .42675 .98294 L F
.42173 .9846 m .42639 .9844 L .42219 .98391 L F
.79289 .76989 m .7985 .7569 L .79901 .76147 L .212 .125 .534 r
F
.77698 .76514 m .79289 .76989 L .79901 .76147 L .683 .771 .917 r
F
.77074 .77011 m .79289 .76989 L .77698 .76514 L F
0 g
.78353 .77734 m
.79289 .76989 L
s
.62834 .76708 m .62784 .76252 L .61926 .75602 L .933 .647 .475 r
F
0 g
.62784 .76252 m
.63302 .77034 L
s
.75743 .75831 m .77022 .76554 L .77647 .76058 L .683 .771 .917 r
F
.60543 .76475 m .60774 .75143 L .59788 .76161 L .683 .77 .917 r
F
.127 .923 .03 r
.59797 .74329 m
.59948 .68153 L
s
.60543 .76475 m .61906 .75615 L .60774 .75143 L .683 .77 .917 r
F
.58461 .77998 m .58036 .76863 L .57977 .77986 L .683 .771 .917 r
F
.58461 .77998 m .59004 .76888 L .58036 .76863 L F
.45247 .64679 m .46742 .64809 L .46773 .65376 L .859 .596 .54 r
F
.127 .923 .03 r
.46421 .64781 m
.46422 .64663 L
s
.45247 .64679 m .45215 .64112 L .46742 .64809 L .859 .596 .54 r
F
.47042 .63003 m .46742 .64809 L .48059 .63468 L .673 .757 .914 r
F
.47042 .63003 m .45215 .64112 L .46742 .64809 L F
0 g
.46742 .64809 m
.4722 .64921 L
s
.42645 .98074 m .43044 .97837 L .42621 .97932 L .692 .759 .903 r
F
.42209 .98098 m .42645 .98074 L .42621 .97932 L F
.43085 .98708 m .43113 .9827 L .43138 .98489 L 0 0 .382 r
F
.42665 .98659 m .43085 .98708 L .43138 .98489 L .692 .759 .904 r
F
0 g
.42946 .98918 m
.43085 .98708 L
s
.54304 .65238 m .55868 .63917 L .559 .64484 L .517 .331 .568 r
F
.53114 .63943 m .54304 .65238 L .559 .64484 L .673 .758 .914 r
F
.51887 .6427 m .54304 .65238 L .53114 .63943 L F
0 g
.52465 .65727 m
.54304 .65238 L
s
.50297 .53306 m .49865 .53008 L .49658 .5318 L .675 .735 .895 r
F
.5043 .5324 m .49865 .53008 L .50297 .53306 L F
.71017 .65854 m .69302 .64811 L .68053 .65778 L .673 .758 .914 r
F
.72084 .65352 m .69302 .64811 L .71017 .65854 L F
.77056 .64706 m .76601 .62951 L .75869 .64426 L F
.77056 .64706 m .78382 .63372 L .76601 .62951 L F
.41824 .98561 m .41813 .9884 L .41927 .98824 L .692 .759 .904 r
F
.41824 .98561 m .417 .98837 L .41813 .9884 L F
.41824 .98561 m .41927 .98824 L .42034 .98791 L F
0 g
.41974 .98649 m
.42076 .98606 L
s
.55296 .77205 m .53078 .77227 L .54676 .77702 L .683 .77 .917 r
F
.78149 .66292 m .78471 .64487 L .77138 .65827 L .673 .758 .915 r
F
.78149 .66292 m .79987 .65184 L .78471 .64487 L F
.4051 .98633 m .40521 .98628 L .40547 .98847 L .765 .548 0 r
F
.4051 .98633 m .40485 .98413 L .40521 .98628 L F
.40923 .98389 m .40521 .98628 L .40947 .98532 L .692 .759 .904 r
F
.40923 .98389 m .40485 .98413 L .40521 .98628 L F
0 g
.40521 .98628 m
.40645 .98823 L
s
.42209 .98098 m .42621 .97932 L .42197 .98027 L .692 .759 .903 r
F
.30113 .6498 m .28916 .63692 L .27335 .64442 L .673 .757 .914 r
F
.31331 .64656 m .28916 .63692 L .30113 .6498 L F
.41824 .98561 m .41596 .98815 L .417 .98837 L .692 .759 .904 r
F
0 g
.41559 .98597 m
.41658 .98643 L
s
.23008 .51958 m .22023 .53979 L .23648 .52313 L .654 .726 .902 r
F
.23008 .51958 m .20743 .53269 L .22023 .53979 L F
.33831 .7647 m .35125 .77193 L .35742 .76696 L .683 .77 .917 r
F
.33434 .76669 m .35125 .77193 L .33831 .7647 L F
.127 .923 .03 r
.34643 .77106 m
.34645 .77463 L
s
.41824 .98561 m .42034 .98791 L .42126 .98741 L .692 .759 .904 r
F
.26788 .52477 m .28299 .54307 L .29621 .53734 L .654 .726 .902 r
F
.26024 .52639 m .28299 .54307 L .26788 .52477 L F
.57489 .7805 m .5706 .76992 L .56142 .77264 L .683 .771 .917 r
F
.57977 .77986 m .5706 .76992 L .57489 .7805 L F
.73139 .76429 m .72522 .77609 L .73517 .76587 L F
.73139 .76429 m .71765 .77294 L .72522 .77609 L F
.41398 .98656 m .41055 .98882 L .4144 .98721 L .692 .759 .904 r
F
.41398 .98656 m .40972 .98752 L .41055 .98882 L F
.81127 .66107 m .79953 .64616 L .79987 .65184 L .933 .657 .493 r
F
0 g
.81127 .66107 m
.81813 .67193 L
s
.127 .923 .03 r
.80594 .64781 m
.8062 .64248 L
s
.80295 .70861 m
.80594 .64781 L
s
.72761 .75295 m .71677 .76371 L .73044 .75511 L .683 .771 .917 r
F
.72761 .75295 m .71111 .7594 L .71677 .76371 L F
.68971 .76269 m .69436 .76594 L .69487 .77051 L .98 .688 .333 r
F
.68971 .76269 m .6892 .75812 L .69436 .76594 L F
0 g
.69436 .76594 m
.69851 .76909 L
s
.41824 .98561 m .41507 .98775 L .41596 .98815 L .692 .759 .904 r
F
0 g
.41493 .98538 m
.41559 .98597 L
s
.5043 .5324 m .5013 .52877 L .49865 .53008 L .675 .735 .895 r
F
.50583 .53199 m .5013 .52877 L .5043 .5324 L F
.57977 .77986 m .58036 .76863 L .5706 .76992 L .683 .771 .917 r
F
.70768 .75421 m .69461 .76585 L .71111 .7594 L F
.70768 .75421 m .68947 .75806 L .69461 .76585 L F
.41361 .98365 m .40947 .98532 L .41373 .98437 L .692 .759 .904 r
F
.41361 .98365 m .40923 .98389 L .40947 .98532 L F
.42219 .98391 m .42675 .98294 L .42237 .98317 L F
.41355 .98073 m .40902 .9817 L .41337 .98146 L .692 .759 .903 r
F
.41824 .98561 m .42126 .98741 L .42198 .9868 L .692 .759 .904 r
F
0 g
.42076 .98606 m
.42146 .9855 L
s
.16125 .51738 m .1707 .52521 L .17023 .53248 L .989 .743 .466 r
F
.16125 .51738 m .16173 .5101 L .1707 .52521 L F
.19221 .50646 m .1707 .52521 L .19819 .51653 L .654 .726 .902 r
F
.19221 .50646 m .16173 .5101 L .1707 .52521 L F
0 g
.1707 .52521 m
.1765 .5305 L
s
.54725 .78159 m .53128 .77684 L .52524 .78526 L .683 .771 .917 r
F
.127 .923 .03 r
.52579 .84274 m
.52606 .76365 L
s
0 g
.52289 .79407 m
.52524 .78526 L
s
.42146 .9855 m
.42189 .98483 L
s
.3563 .75778 m .37819 .75413 L .36027 .75219 L .683 .77 .917 r
F
.34035 .75305 m .3563 .75778 L .36027 .75219 L F
.27368 .65561 m .26104 .65961 L .26133 .66528 L .386 .233 .548 r
F
.27368 .65561 m .27338 .64994 L .26104 .65961 L F
0 g
.25309 .67074 m
.26104 .65961 L
s
.41455 .9847 m
.41493 .98538 L
s
.43113 .9827 m .43051 .97836 L .43076 .98055 L .763 .546 0 r
F
.43138 .98489 m .43113 .9827 L .43076 .98055 L F
0 g
.43059 .98489 m
.43109 .98284 L
s
.42675 .98294 m .43113 .9827 L .43076 .98055 L .692 .759 .904 r
F
.42197 .98027 m .42539 .97803 L .42156 .97962 L .692 .759 .903 r
F
0 g
.42156 .97962 m
.42165 .92792 L
s
.42197 .98027 m .42621 .97932 L .42539 .97803 L .692 .759 .903 r
F
.42665 .98659 m .43138 .98489 L .427 .98513 L .692 .759 .904 r
F
.42245 .9861 m .42665 .98659 L .427 .98513 L F
.42198 .9868 m .42665 .98659 L .42245 .9861 L F
.40937 .98024 m .40466 .98194 L .40902 .9817 L .692 .759 .903 r
F
.41355 .98073 m .40937 .98024 L .40902 .9817 L F
.30837 .75937 m .29765 .77019 L .31126 .76154 L .683 .77 .917 r
F
.30837 .75937 m .29187 .76585 L .29765 .77019 L F
.64295 .51348 m .64888 .53738 L .65791 .51831 L .654 .726 .902 r
F
.64295 .51348 m .62645 .53015 L .64888 .53738 L F
0 g
.64888 .53738 m
.67314 .54072 L
s
.41824 .98561 m .4144 .98721 L .41507 .98775 L .692 .759 .904 r
F
.27054 .76908 m .27537 .77233 L .27585 .7769 L .982 .691 .347 r
F
.27054 .76908 m .27007 .76451 L .27537 .77233 L F
.28834 .76064 m .27537 .77233 L .29187 .76585 L .683 .77 .917 r
F
.28834 .76064 m .27007 .76451 L .27537 .77233 L F
0 g
.27537 .77233 m
.27954 .77545 L
s
.33375 .53374 m .34413 .51235 L .34368 .51962 L .063 0 .39 r
F
.3333 .54101 m .33375 .53374 L .34368 .51962 L F
.30693 .52222 m .33375 .53374 L .34368 .51962 L .654 .726 .902 r
F
.29666 .53006 m .33375 .53374 L .30693 .52222 L F
0 g
.32526 .54022 m
.33375 .53374 L
s
.29101 .66604 m .27368 .65561 L .26133 .66528 L .673 .758 .914 r
F
0 g
.25338 .67642 m
.26133 .66528 L
s
.3016 .66102 m .27368 .65561 L .29101 .66604 L .673 .758 .914 r
F
.42675 .98294 m .43076 .98055 L .42651 .98151 L .692 .759 .904 r
F
.42237 .98317 m .42675 .98294 L .42651 .98151 L F
.44708 .52945 m .41315 .53814 L .44453 .53978 L .654 .726 .902 r
F
.44708 .52945 m .41696 .52263 L .41315 .53814 L F
0 g
.41315 .53814 m
.41576 .55396 L
s
.41799 .98341 m .41361 .98365 L .41373 .98437 L .692 .759 .904 r
F
.69761 .53993 m .72101 .5278 L .72061 .53508 L .592 .369 .546 r
F
.69042 .52001 m .69761 .53993 L .72061 .53508 L .654 .726 .902 r
F
.6741 .52054 m .69761 .53993 L .69042 .52001 L F
0 g
.67314 .54072 m
.69761 .53993 L
s
.40937 .98024 m .40519 .97975 L .40466 .98194 L .692 .759 .903 r
F
.40538 .98194 m .40459 .98194 L .40485 .98413 L 0 0 .381 r
F
0 g
.40492 .98385 m
.40496 .98408 L
s
.40538 .98194 m .40512 .97975 L .40459 .98194 L 0 0 .381 r
F
.47719 .53626 m .44453 .53978 L .47591 .54142 L .654 .726 .902 r
F
.47719 .53626 m .44708 .52945 L .44453 .53978 L F
.41824 .98561 m .42198 .9868 L .42245 .9861 L .692 .759 .904 r
F
.35153 .65443 m .34666 .63679 L .33954 .65161 L .673 .757 .914 r
F
.35153 .65443 m .36465 .64102 L .34666 .63679 L F
.5013 .52877 m .49433 .5271 L .49865 .53008 L .675 .735 .895 r
F
.5013 .52877 m .49831 .52513 L .49433 .5271 L F
.50437 .52795 m .49831 .52513 L .5013 .52877 L F
.50729 .54306 m .49998 .52314 L .49232 .52476 L .654 .726 .902 r
F
.50729 .54306 m .50813 .52288 L .49998 .52314 L F
.50729 .54306 m .51623 .52399 L .50813 .52288 L F
.40948 .98609 m .40547 .98847 L .40972 .98752 L .692 .759 .904 r
F
.40948 .98609 m .4051 .98633 L .40547 .98847 L F
0 g
.40547 .98847 m
.4067 .99042 L
s
.127 .923 .03 r
.39154 .98739 m
.40715 2.15881 L
s
.41401 .98004 m .40937 .98024 L .41355 .98073 L .692 .759 .903 r
F
.42237 .98317 m .42651 .98151 L .42225 .98246 L .692 .759 .904 r
F
0 g
.42189 .98483 m
.42201 .98403 L
s
.42621 .97932 m .42922 .97643 L .42539 .97803 L .692 .759 .903 r
F
.42621 .97932 m .43044 .97837 L .42922 .97643 L F
.53867 .54471 m .56837 .53579 L .53783 .53943 L .654 .726 .902 r
F
.53867 .54471 m .57005 .54635 L .56837 .53579 L F
0 g
.4145 .98389 m
.41455 .9847 L
s
.57005 .54635 m .59893 .53215 L .56837 .53579 L .654 .726 .902 r
F
.57005 .54635 m .60143 .54799 L .59893 .53215 L F
.55868 .63917 m .55835 .6335 L .5708 .62382 L .39 .237 .55 r
F
0 g
.54994 .63748 m
.55835 .6335 L
s
.42156 .97962 m .42405 .97695 L .42089 .97909 L .692 .759 .903 r
F
.42156 .97962 m .42539 .97803 L .42405 .97695 L F
.60143 .54799 m .59934 .52488 L .59893 .53215 L .917 .737 .245 r
F
0 g
.59752 .56347 m
.60143 .54799 L
s
.41799 .98341 m .42183 .98181 L .42116 .98127 L .692 .759 .904 r
F
0 g
.42156 .98159 m
.42156 .97996 L
s
.41799 .98341 m .42225 .98246 L .42183 .98181 L .692 .759 .904 r
F
0 g
.42156 .983 m
.42156 .9821 L
s
.41824 .98561 m .41398 .98656 L .4144 .98721 L .692 .759 .904 r
F
.54097 .62295 m .5581 .63334 L .57048 .62371 L .673 .757 .914 r
F
.127 .923 .03 r
.57031 .65122 m
.57057 .63845 L
s
.57057 .63845 m
.57168 .58518 L
s
.53038 .62796 m .5581 .63334 L .54097 .62295 L .673 .757 .914 r
F
.41386 .98585 m .40972 .98752 L .41398 .98656 L .692 .759 .904 r
F
.41386 .98585 m .40948 .98609 L .40972 .98752 L F
.42245 .9861 m .427 .98513 L .42262 .98537 L F
.41824 .98561 m .42245 .9861 L .42262 .98537 L F
.41378 .98292 m .40923 .98389 L .41361 .98365 L F
.72062 .64798 m .70887 .63509 L .69295 .6426 L .673 .758 .914 r
F
.73284 .64473 m .70887 .63509 L .72062 .64798 L F
.43076 .98055 m .43051 .97836 L .42927 .97641 L .976 .674 .31 r
F
0 g
.43051 .97836 m
.43087 .9805 L
s
.62834 .76708 m .61926 .75602 L .61976 .76058 L .933 .647 .475 r
F
.62884 .77165 m .62834 .76708 L .61976 .76058 L F
0 g
.62834 .76708 m
.63352 .7749 L
s
.75794 .76288 m .77074 .77011 L .77698 .76514 L .683 .771 .917 r
F
.75395 .76487 m .77074 .77011 L .75794 .76288 L F
.41401 .98004 m .41029 .97885 L .40937 .98024 L .692 .759 .903 r
F
.41473 .97942 m .41029 .97885 L .41401 .98004 L F
.33917 .64609 m .32691 .63014 L .32628 .64529 L .673 .757 .914 r
F
.33917 .64609 m .34626 .63134 L .32691 .63014 L F
.60606 .76923 m .60838 .75585 L .59848 .76608 L .683 .77 .917 r
F
.60606 .76923 m .61976 .76058 L .60838 .75585 L F
.43138 .98489 m .43076 .98055 L .43102 .98275 L .763 .546 0 r
F
.427 .98513 m .43138 .98489 L .43102 .98275 L .692 .759 .904 r
F
0 g
.43085 .98708 m
.43138 .98489 L
s
.42225 .98246 m .42568 .98021 L .42183 .98181 L .692 .759 .904 r
F
.42225 .98246 m .42651 .98151 L .42568 .98021 L F
.40958 .98243 m .40485 .98413 L .40923 .98389 L F
.41378 .98292 m .40958 .98243 L .40923 .98389 L F
.42089 .97909 m .42228 .97617 L .42 .97869 L .692 .759 .903 r
F
.42089 .97909 m .42405 .97695 L .42228 .97617 L F
.37894 .75872 m .37846 .75416 L .38077 .74533 L 0 0 .384 r
F
0 g
.37471 .75943 m
.37846 .75416 L
s
.55346 .77662 m .53128 .77684 L .54725 .78159 L .683 .771 .917 r
F
.41029 .97885 m .40519 .97975 L .40937 .98024 L .692 .759 .903 r
F
.427 .98513 m .43102 .98275 L .42676 .9837 L .692 .759 .904 r
F
.42262 .98537 m .427 .98513 L .42676 .9837 L F
.41824 .98561 m .41386 .98585 L .41398 .98656 L F
.36027 .75219 m .37819 .75413 L .38048 .74534 L .683 .77 .917 r
F
.40563 .98414 m .40485 .98413 L .4051 .98633 L 0 0 .381 r
F
0 g
.40517 .98604 m
.40521 .98628 L
s
.40958 .98243 m .40538 .98194 L .40485 .98413 L .692 .759 .904 r
F
.40563 .98414 m .40538 .98194 L .40485 .98413 L 0 0 .381 r
F
.7758 .75596 m .79771 .75231 L .77985 .75037 L .683 .771 .917 r
F
.75996 .75123 m .7758 .75596 L .77985 .75037 L F
.48096 .52428 m .44752 .52217 L .47762 .52898 L .654 .726 .902 r
F
.69336 .65379 m .68053 .65778 L .68087 .66346 L .392 .238 .551 r
F
.69336 .65379 m .69302 .64811 L .68053 .65778 L F
0 g
.67241 .66892 m
.68053 .65778 L
s
.22569 .50786 m .2079 .52542 L .23055 .5123 L .654 .726 .902 r
F
.22569 .50786 m .19819 .51653 L .2079 .52542 L F
.57846 .88094 m .57871 .87717 L .58849 .87697 L .67 .444 .568 r
F
.127 .923 .03 r
.6503 .91921 m
.65303 .83253 L
s
.56876 .87959 m .57871 .87717 L .57846 .88094 L .733 .498 .572 r
F
.127 .923 .03 r
.56876 .87959 m
.5689 .86461 L
s
.56892 .8625 m
.56893 .86165 L
s
.56904 .85002 m
.56919 .83368 L
s
.56876 .87959 m .569 .87582 L .57871 .87717 L .733 .498 .572 r
F
.41473 .97942 m .41172 .97763 L .41029 .97885 L .692 .759 .903 r
F
.41565 .97893 m .41172 .97763 L .41473 .97942 L F
.42262 .98537 m .42676 .9837 L .4225 .98466 L .692 .759 .904 r
F
.41824 .98561 m .42262 .98537 L .4225 .98466 L F
.41425 .98223 m .40958 .98243 L .41378 .98292 L F
.42651 .98151 m .42953 .9786 L .42568 .98021 L F
.42651 .98151 m .43076 .98055 L .42953 .9786 L F
.53825 .53215 m .56294 .51845 L .53532 .52712 L .654 .726 .902 r
F
.53825 .53215 m .56879 .52851 L .56294 .51845 L F
.72803 .75755 m .71715 .76837 L .73088 .75972 L .683 .771 .917 r
F
.72803 .75755 m .71145 .76403 L .71715 .76837 L F
.5526 .76756 m .53979 .76036 L .53053 .76778 L .683 .77 .917 r
F
.56052 .7636 m .53979 .76036 L .5526 .76756 L F
.57907 .86948 m .57871 .87706 L .58844 .87685 L .645 .732 .913 r
F
.57263 .86858 m .57871 .87706 L .57907 .86948 L F
.57263 .86858 m .56905 .87571 L .57871 .87706 L F
.42 .97869 m .4202 .97573 L .41896 .97847 L .692 .759 .903 r
F
.42 .97869 m .42228 .97617 L .4202 .97573 L F
.27495 .51463 m .29666 .53006 L .30693 .52222 L .654 .726 .902 r
F
.26834 .51749 m .29666 .53006 L .27495 .51463 L F
.47073 .6357 m .46773 .65376 L .48091 .64035 L .673 .758 .914 r
F
.47073 .6357 m .45247 .64679 L .46773 .65376 L F
0 g
.46773 .65376 m
.48568 .65799 L
s
.127 .923 .03 r
.46411 .65993 m
.46417 .65214 L
s
.69021 .76726 m .69487 .77051 L .69538 .77508 L .98 .688 .333 r
F
.69021 .76726 m .68971 .76269 L .69487 .77051 L F
.70801 .75882 m .69487 .77051 L .71145 .76403 L .683 .771 .917 r
F
.70801 .75882 m .68971 .76269 L .69487 .77051 L F
0 g
.69487 .77051 m
.69901 .77366 L
s
.42539 .97803 m .42721 .97482 L .42405 .97695 L .692 .759 .903 r
F
.42539 .97803 m .42922 .97643 L .42721 .97482 L F
.71051 .66422 m .69336 .65379 L .68087 .66346 L .673 .758 .915 r
F
0 g
.67274 .67459 m
.68087 .66346 L
s
.72118 .65919 m .69336 .65379 L .71051 .66422 L .673 .758 .915 r
F
.42183 .98181 m .42434 .97913 L .42116 .98127 L .692 .759 .904 r
F
.42183 .98181 m .42568 .98021 L .42434 .97913 L F
.41824 .98561 m .41404 .98512 L .41386 .98585 L F
.41824 .98561 m .4145 .98442 L .41404 .98512 L F
.41824 .98561 m .41522 .9838 L .4145 .98442 L F
0 g
.4145 .98389 m
.41503 .98288 L
s
.41824 .98561 m .41615 .98331 L .41522 .9838 L .692 .759 .904 r
F
.41824 .98561 m .41721 .98297 L .41615 .98331 L F
.41824 .98561 m .41835 .98282 L .41721 .98297 L F
.41824 .98561 m .41948 .98285 L .41835 .98282 L F
.41824 .98561 m .42053 .98307 L .41948 .98285 L F
.41824 .98561 m .42142 .98347 L .42053 .98307 L F
.41824 .98561 m .42209 .98401 L .42142 .98347 L F
0 g
.42156 .983 m
.42195 .98389 L
s
.41824 .98561 m .4225 .98466 L .42209 .98401 L .692 .759 .904 r
F
.35694 .7624 m .37894 .75872 L .36093 .75678 L .683 .77 .917 r
F
.34091 .75765 m .35694 .7624 L .36093 .75678 L F
.60738 .5195 m .62686 .52287 L .62645 .53015 L .858 .601 .549 r
F
.60738 .5195 m .6078 .51223 L .62686 .52287 L F
.63065 .4991 m .62686 .52287 L .64336 .5062 L .654 .726 .902 r
F
.63065 .4991 m .6078 .51223 L .62686 .52287 L F
0 g
.62686 .52287 m
.63201 .52454 L
s
.41565 .97893 m .41356 .97664 L .41172 .97763 L .692 .759 .903 r
F
.41671 .9786 m .41356 .97664 L .41565 .97893 L F
.77103 .6526 m .76646 .63496 L .75911 .64978 L .673 .758 .914 r
F
.77103 .6526 m .78436 .63919 L .76646 .63496 L F
.31331 .64656 m .30743 .63205 L .28916 .63692 L .673 .757 .914 r
F
.32628 .64529 m .30743 .63205 L .31331 .64656 L F
.41896 .97847 m .41795 .97566 L .41784 .97844 L .692 .759 .903 r
F
.41896 .97847 m .4202 .97573 L .41795 .97566 L F
0 0 0 r
2.5 Mabswid
.56226 .77939 Mdot
.41404 .98512 m .40948 .98609 L .41386 .98585 L .692 .759 .904 r
F
.43076 .98055 m .42927 .97641 L .42953 .9786 L .976 .674 .31 r
F
.43102 .98275 m .43076 .98055 L .42953 .9786 L F
0 g
.5 Mabswid
.43076 .98055 m
.43113 .9827 L
s
.4205 .98218 m
.42156 .983 L
s
.42156 .983 m
.42156 .983 L
s
.30885 .76394 m .29812 .77475 L .31174 .76611 L .683 .77 .917 r
F
.30885 .76394 m .29234 .77042 L .29812 .77475 L F
.30131 .65535 m .28928 .6424 L .27338 .64994 L .673 .757 .914 r
F
.31354 .65209 m .28928 .6424 L .30131 .65535 L F
.41671 .9786 m .41568 .97597 L .41356 .97664 L .692 .759 .903 r
F
.41784 .97844 m .41568 .97597 L .41671 .9786 L F
.72101 .5278 m .74138 .51192 L .74099 .5192 L .494 .288 .528 r
F
.72061 .53508 m .72101 .5278 L .74099 .5192 L F
.70617 .50949 m .72101 .5278 L .74099 .5192 L .654 .726 .902 r
F
.69083 .51273 m .72101 .5278 L .70617 .50949 L F
0 g
.71048 .53002 m
.72101 .5278 L
s
.41503 .98288 m
.41503 .98288 L
s
.41503 .98288 m
.41615 .98211 L
s
.41784 .97844 m .41795 .97566 L .41568 .97597 L .692 .759 .903 r
F
.48152 .51706 m .45488 .5056 L .44826 .51496 L .654 .726 .902 r
F
.48665 .51316 m .45488 .5056 L .48152 .51706 L F
.41425 .98223 m .41051 .98104 L .40958 .98243 L .692 .759 .904 r
F
.41497 .98161 m .41051 .98104 L .41425 .98223 L F
.28881 .76521 m .27585 .7769 L .29234 .77042 L .683 .77 .917 r
F
.28881 .76521 m .27054 .76908 L .27585 .7769 L F
0 g
.27585 .7769 m
.28452 .78339 L
s
.41029 .97885 m .40657 .97767 L .40519 .97975 L .692 .759 .903 r
F
.40677 .97985 m .40512 .97975 L .40538 .98194 L .189 .098 .515 r
F
.40677 .97985 m .40651 .97765 L .40512 .97975 L F
0 g
.40459 .98194 m
.40512 .97975 L
s
.55978 .87677 m .569 .87582 L .56876 .87959 L .793 .551 .572 r
F
.127 .923 .03 r
.56068 1.19895 m
.56211 1.13079 L
s
.56749 .87598 m
.56771 .86574 L
s
.56773 .86474 m
.56781 .8607 L
s
.56788 .8574 m
.56791 .85603 L
s
.56801 .85138 m
.56844 .8308 L
s
.55978 .87677 m .56003 .87301 L .569 .87582 L .793 .551 .572 r
F
0 g
.569 .87582 m
.57871 .87717 L
s
.4225 .98466 m .42594 .9824 L .42209 .98401 L .692 .759 .904 r
F
.4225 .98466 m .42676 .9837 L .42594 .9824 L F
.40984 .98463 m .4051 .98633 L .40948 .98609 L F
.41404 .98512 m .40984 .98463 L .40948 .98609 L F
.53561 .51989 m .55352 .50241 L .53082 .51547 L .654 .726 .902 r
F
.53561 .51989 m .56309 .51126 L .55352 .50241 L F
0 0 0 r
2.5 Mabswid
.56309 .77905 Mdot
.58824 .88073 m .58849 .87697 L .59768 .87522 L .598 .382 .559 r
F
.57846 .88094 m .58849 .87697 L .58824 .88073 L .67 .444 .568 r
F
0 g
.5 Mabswid
.57871 .87717 m
.58849 .87697 L
s
.42116 .98127 m .42256 .97834 L .42027 .98088 L .692 .759 .904 r
F
.42116 .98127 m .42434 .97913 L .42256 .97834 L F
.56668 .86672 m .56905 .87571 L .57263 .86858 L .645 .732 .913 r
F
.56668 .86672 m .56013 .87291 L .56905 .87571 L F
.45488 .5056 m .41829 .50818 L .44826 .51496 L .654 .726 .902 r
F
.58556 .86934 m .58844 .87685 L .59759 .87511 L .645 .732 .913 r
F
.127 .923 .03 r
.63437 .85568 m
.63629 .78998 L
s
.57907 .86948 m .58844 .87685 L .58556 .86934 L .645 .732 .913 r
F
.41051 .98104 m .40538 .98194 L .40958 .98243 L .692 .759 .904 r
F
.40984 .98463 m .40563 .98414 L .4051 .98633 L F
0 g
.4051 .98633 m
.40547 .98847 L
s
.41172 .97763 m .40657 .97767 L .41029 .97885 L .692 .759 .903 r
F
.32628 .64529 m .32691 .63014 L .30743 .63205 L .673 .757 .914 r
F
.75869 .64426 m .7467 .62831 L .74582 .64346 L .673 .758 .914 r
F
.75869 .64426 m .76601 .62951 L .7467 .62831 L F
.5689 .52128 m .59059 .50262 L .56309 .51126 L .654 .726 .902 r
F
.5689 .52128 m .5993 .51765 L .59059 .50262 L F
.41497 .98161 m .41194 .9798 L .41051 .98104 L .692 .759 .904 r
F
.41589 .98112 m .41194 .9798 L .41497 .98161 L F
.4145 .98442 m .40984 .98463 L .41404 .98512 L F
.42676 .9837 m .42979 .9808 L .42594 .9824 L F
.42676 .9837 m .43102 .98275 L .42979 .9808 L F
0 g
.41942 .98181 m
.4205 .98218 L
s
.37994 .64799 m .37963 .64232 L .36434 .63535 L .859 .596 .54 r
F
0 g
.37963 .64232 m
.39119 .65155 L
s
.41615 .98211 m
.41725 .98177 L
s
.42027 .98088 m .42046 .97789 L .41923 .98065 L .692 .759 .904 r
F
.42027 .98088 m .42256 .97834 L .42046 .97789 L F
.42953 .9786 m .42927 .97641 L .42725 .97479 L .933 .634 .451 r
F
.127 .923 .03 r
.42847 1.14945 m
.42903 1.01172 L
s
0 g
.42927 .97641 m
.43051 .97836 L
s
.7985 .7569 m .79798 .75234 L .80043 .74351 L 0 0 .401 r
F
0 g
.79414 .75763 m
.79798 .75234 L
s
.42568 .98021 m .42751 .97698 L .42434 .97913 L .692 .759 .904 r
F
.42568 .98021 m .42953 .9786 L .42751 .97698 L F
.42405 .97695 m .42455 .97364 L .42228 .97617 L .692 .759 .903 r
F
.42405 .97695 m .42721 .97482 L .42455 .97364 L F
.42209 .98401 m .42459 .98132 L .42142 .98347 L .692 .759 .904 r
F
.42209 .98401 m .42594 .9824 L .42459 .98132 L F
.77985 .75037 m .79771 .75231 L .80015 .74352 L .683 .771 .917 r
F
.35183 .6601 m .34696 .64246 L .33984 .65728 L .673 .758 .914 r
F
.35183 .6601 m .36495 .64669 L .34696 .64246 L F
.59788 .76161 m .59439 .7488 L .58899 .75986 L .683 .77 .917 r
F
.59788 .76161 m .60774 .75143 L .59439 .7488 L F
.62884 .77165 m .61976 .76058 L .62027 .76515 L .933 .647 .475 r
F
0 g
.62884 .77165 m
.63402 .77947 L
s
.127 .923 .03 r
.62692 1.00035 m
.63126 .74198 L
s
.62396 .94383 m
.62966 .74262 L
s
.41589 .98112 m .41379 .97882 L .41194 .9798 L .692 .759 .904 r
F
.41696 .98078 m .41379 .97882 L .41589 .98112 L F
0 g
.41834 .98169 m
.41942 .98181 L
s
.41725 .98177 m
.41834 .98169 L
s
.30622 .75218 m .29156 .76122 L .30798 .75477 L .683 .77 .917 r
F
.30622 .75218 m .28804 .75603 L .29156 .76122 L F
.41923 .98065 m .4182 .97783 L .4181 .98062 L .692 .759 .904 r
F
.41923 .98065 m .42046 .97789 L .4182 .97783 L F
.43102 .98275 m .42953 .9786 L .42979 .9808 L .976 .674 .31 r
F
0 g
.43102 .98275 m
.43138 .98489 L
s
.60656 .7738 m .60888 .76042 L .59898 .77064 L .683 .771 .917 r
F
.60656 .7738 m .62027 .76515 L .60888 .76042 L F
.41696 .98078 m .41593 .97814 L .41379 .97882 L .692 .759 .904 r
F
.4181 .98062 m .41593 .97814 L .41696 .98078 L F
.55868 .63917 m .5708 .62382 L .57113 .62949 L .39 .237 .55 r
F
.559 .64484 m .55868 .63917 L .57113 .62949 L F
.54146 .62873 m .55868 .63917 L .57113 .62949 L .673 .757 .914 r
F
.53082 .63376 m .55868 .63917 L .54146 .62873 L F
0 g
.55026 .64315 m
.55868 .63917 L
s
.57822 .88471 m .57846 .88094 L .58824 .88073 L .67 .444 .568 r
F
.56851 .88336 m .57846 .88094 L .57822 .88471 L .733 .498 .572 r
F
.127 .923 .03 r
.56873 .8833 m
.56876 .87959 L
s
.56851 .88336 m .56876 .87959 L .57846 .88094 L .733 .498 .572 r
F
.57882 .87332 m .57846 .88094 L .58824 .88073 L .644 .733 .913 r
F
.127 .923 .03 r
.5961 .81977 m
.59619 .81622 L
s
.57235 .87242 m .57846 .88094 L .57882 .87332 L .644 .733 .913 r
F
.57235 .87242 m .56876 .87959 L .57846 .88094 L F
.127 .923 .03 r
.5697 .79741 m
.56974 .79387 L
s
.4181 .98062 m .4182 .97783 L .41593 .97814 L .692 .759 .904 r
F
.4145 .98442 m .41076 .98323 L .40984 .98463 L F
.41522 .9838 m .41076 .98323 L .4145 .98442 L F
.37894 .75872 m .38077 .74533 L .38125 .7499 L 0 0 .384 r
F
.37942 .76329 m .37894 .75872 L .38125 .7499 L F
.36093 .75678 m .37894 .75872 L .38125 .7499 L .683 .77 .917 r
F
0 g
.37519 .764 m
.37894 .75872 L
s
.127 .923 .03 r
.38122 .5961 m
.38136 .67276 L
s
.40702 .98204 m .40538 .98194 L .40563 .98414 L .189 .098 .515 r
F
.41051 .98104 m .40677 .97985 L .40538 .98194 L .692 .759 .904 r
F
.40702 .98204 m .40677 .97985 L .40538 .98194 L .189 .098 .515 r
F
0 g
.40485 .98413 m
.40538 .98194 L
s
.77647 .76058 m .7985 .7569 L .78054 .75496 L .683 .771 .917 r
F
.76055 .75583 m .77647 .76058 L .78054 .75496 L F
.75743 .75831 m .77647 .76058 L .76055 .75583 L F
.67559 .39694 m .6774 .45523 L .67581 .45544 L .641 .401 .54 r
F
.67559 .39694 m .67717 .39673 L .6774 .45523 L F
.67402 .39668 m .67559 .39694 L .67581 .45544 L .751 .491 .538 r
F
0 g
.67559 .39694 m
.67559 .39694 L
s
.42142 .98347 m .42281 .98053 L .42053 .98307 L .692 .759 .904 r
F
.42142 .98347 m .42459 .98132 L .42281 .98053 L F
.73284 .64473 m .72721 .63022 L .70887 .63509 L .673 .758 .914 r
F
.74582 .64346 m .72721 .63022 L .73284 .64473 L F
.41172 .97763 m .40871 .97583 L .40657 .97767 L .692 .759 .903 r
F
.41356 .97664 m .40871 .97583 L .41172 .97763 L F
.19174 .51374 m .17023 .53248 L .19771 .52381 L .654 .726 .902 r
F
.19174 .51374 m .16125 .51738 L .17023 .53248 L F
0 g
.17023 .53248 m
.18481 .5458 L
s
.41076 .98323 m .40563 .98414 L .40984 .98463 L .692 .759 .904 r
F
.67717 .39673 m .67842 .45479 L .6774 .45523 L .517 .303 .528 r
F
0 g
.7433 .41903 m
.74743 .42424 L
s
.67717 .39673 m .6782 .39629 L .67842 .45479 L .517 .303 .528 r
F
0 g
.67559 .39694 m
.67717 .39673 L
s
.72854 .76212 m .71765 .77294 L .73139 .76429 L .683 .771 .917 r
F
.72854 .76212 m .71196 .7686 L .71765 .77294 L F
.72084 .65352 m .70903 .64057 L .69302 .64811 L .673 .758 .914 r
F
.73312 .65026 m .70903 .64057 L .72084 .65352 L F
.67402 .39668 m .67581 .45544 L .67424 .45518 L .751 .491 .538 r
F
.67304 .3962 m .67402 .39668 L .67424 .45518 L .845 .571 .523 r
F
0 g
.67402 .39668 m
.67559 .39694 L
s
.41194 .9798 m .40677 .97985 L .41051 .98104 L .692 .759 .904 r
F
.55296 .77205 m .54009 .76482 L .53078 .77227 L .683 .77 .917 r
F
.56092 .76807 m .54009 .76482 L .55296 .77205 L F
.70852 .76339 m .69538 .77508 L .71196 .7686 L .683 .771 .917 r
F
.70852 .76339 m .69021 .76726 L .69538 .77508 L F
0 g
.69538 .77508 m
.70393 .78158 L
s
.41522 .9838 m .4122 .982 L .41076 .98323 L .692 .759 .904 r
F
.41615 .98331 m .4122 .982 L .41522 .9838 L F
.54009 .76482 m .53029 .7677 L .53078 .77227 L .405 .261 .57 r
F
.54009 .76482 m .53959 .76025 L .53029 .7677 L F
0 g
.52425 .77612 m
.53029 .7677 L
s
.42228 .97617 m .42143 .97298 L .4202 .97573 L .692 .759 .903 r
F
.42228 .97617 m .42455 .97364 L .42143 .97298 L F
.33954 .65161 m .32722 .63559 L .32659 .65081 L .673 .757 .914 r
F
.33954 .65161 m .34666 .63679 L .32722 .63559 L F
.35742 .76696 m .37942 .76329 L .36141 .76135 L .683 .77 .917 r
F
.34139 .76221 m .35742 .76696 L .36141 .76135 L F
.33831 .7647 m .35742 .76696 L .34139 .76221 L F
.42053 .98307 m .42072 .98009 L .41948 .98285 L .692 .759 .904 r
F
.42053 .98307 m .42281 .98053 L .42072 .98009 L F
.3333 .54101 m .34368 .51962 L .34323 .5269 L .063 0 .39 r
F
.30647 .5295 m .3333 .54101 L .34323 .5269 L .654 .726 .902 r
F
.29621 .53734 m .3333 .54101 L .30647 .5295 L F
0 g
.31855 .55226 m
.3333 .54101 L
s
.42953 .9786 m .42725 .97479 L .42751 .97698 L .933 .634 .451 r
F
.127 .923 .03 r
.42918 .9763 m
.42918 .9742 L
s
.42843 .92518 m
.42887 .97514 L
s
.42979 .9808 m .42953 .9786 L .42751 .97698 L .933 .634 .451 r
F
0 g
.42953 .9786 m
.43076 .98055 L
s
.127 .923 .03 r
.42907 .99796 m
.43086 1.20301 L
s
.6782 .39629 m .67914 .45422 L .67842 .45479 L .359 .181 .499 r
F
0 g
.73151 .40416 m
.7433 .41903 L
s
.6782 .39629 m .67891 .39572 L .67914 .45422 L .359 .181 .499 r
F
0 g
.67717 .39673 m
.6782 .39629 L
s
.42594 .9824 m .42777 .97918 L .42459 .98132 L .692 .759 .904 r
F
.42594 .9824 m .42979 .9808 L .42777 .97918 L F
.55954 .88054 m .56876 .87959 L .56851 .88336 L .793 .551 .572 r
F
.127 .923 .03 r
.56741 .87973 m
.56742 .87917 L
s
.55954 .88054 m .55978 .87677 L .56876 .87959 L .793 .551 .572 r
F
.56637 .87055 m .56876 .87959 L .57235 .87242 L .644 .733 .913 r
F
.56637 .87055 m .55978 .87677 L .56876 .87959 L F
0 g
.56876 .87959 m
.57846 .88094 L
s
.42434 .97913 m .42484 .9758 L .42256 .97834 L .692 .759 .904 r
F
.42434 .97913 m .42751 .97698 L .42484 .9758 L F
.40892 .978 m .40651 .97765 L .40677 .97985 L .393 .241 .554 r
F
.40892 .978 m .40867 .9758 L .40651 .97765 L F
0 g
.40512 .97975 m
.40651 .97765 L
s
.67304 .3962 m .67424 .45518 L .67326 .4547 L .845 .571 .523 r
F
.67238 .3956 m .67304 .3962 L .67326 .4547 L .93 .648 .486 r
F
0 g
.67304 .3962 m
.67402 .39668 L
s
.58824 .88073 m .59768 .87522 L .59743 .87898 L .598 .382 .559 r
F
.588 .8845 m .58824 .88073 L .59743 .87898 L F
.57822 .88471 m .58824 .88073 L .588 .8845 L .67 .444 .568 r
F
.58535 .87319 m .58824 .88073 L .59743 .87898 L .644 .733 .913 r
F
.127 .923 .03 r
.63426 .85921 m
.63437 .85568 L
s
.57882 .87332 m .58824 .88073 L .58535 .87319 L .644 .733 .913 r
F
0 g
.57846 .88094 m
.58824 .88073 L
s
.74582 .64346 m .7467 .62831 L .72721 .63022 L .673 .758 .914 r
F
.41615 .98331 m .41405 .98101 L .4122 .982 L .692 .759 .904 r
F
.41721 .98297 m .41405 .98101 L .41615 .98331 L F
.127 .923 .03 r
.66866 .51246 m
.66875 .51129 L
s
.66871 .51246 m
.66875 .51129 L
s
.41948 .98285 m .41846 .98002 L .41835 .98282 L .692 .759 .904 r
F
.41948 .98285 m .42072 .98009 L .41846 .98002 L F
.41356 .97664 m .41147 .97436 L .40871 .97583 L .692 .759 .903 r
F
.41568 .97597 m .41147 .97436 L .41356 .97664 L F
.79953 .64616 m .79918 .64049 L .78402 .63352 L .86 .596 .538 r
F
0 g
.79918 .64049 m
.81058 .64973 L
s
.44061 .63188 m .45184 .63545 L .45215 .64112 L .931 .657 .497 r
F
.44061 .63188 m .4403 .62621 L .45184 .63545 L F
0 g
.45184 .63545 m
.45735 .63796 L
s
0 0 0 r
2.5 Mabswid
.18968 .53269 Mdot
.41721 .98297 m .41618 .98034 L .41405 .98101 L .692 .759 .904 r
F
.41835 .98282 m .41618 .98034 L .41721 .98297 L F
.41835 .98282 m .41846 .98002 L .41618 .98034 L F
.4202 .97573 m .41805 .97288 L .41795 .97566 L .692 .759 .903 r
F
.4202 .97573 m .42143 .97298 L .41805 .97288 L F
.46263 .61811 m .45212 .63528 L .47028 .62424 L .673 .757 .914 r
F
.46263 .61811 m .44064 .62609 L .45212 .63528 L F
.41076 .98323 m .40702 .98204 L .40563 .98414 L .692 .759 .904 r
F
0 g
.5 Mabswid
.4051 .98633 m
.40563 .98414 L
s
.67891 .39572 m .67957 .45354 L .67914 .45422 L .082 0 .419 r
F
0 g
.71739 .38634 m
.73151 .40416 L
s
.67891 .39572 m .67935 .39504 L .67957 .45354 L .082 0 .419 r
F
0 g
.6782 .39629 m
.67891 .39572 L
s
.5083 .62 m .50633 .63236 L .51818 .63121 L .673 .757 .914 r
F
.50877 .61704 m .51818 .63121 L .51243 .61668 L F
.50593 .61732 m .5083 .62 L .50877 .61704 L F
.5083 .62 m .51818 .63121 L .50877 .61704 L F
.51094 .57514 m .51106 .57433 L .51107 .60259 L 0 0 .142 r
F
.50624 .62307 m .50551 .6383 L .51856 .63702 L .673 .757 .914 r
F
.50593 .61732 m .50633 .63236 L .5083 .62 L F
.50624 .62307 m .51856 .63702 L .51277 .62243 L F
.50656 .62874 m .50583 .64397 L .51887 .6427 L .673 .758 .914 r
F
.50656 .62874 m .51887 .6427 L .51309 .62811 L F
.5098 .57639 m .51015 .60424 L .50981 .6045 L .358 .18 .498 r
F
.50719 .57704 m .50796 .60505 L .50719 .60516 L .641 .402 .54 r
F
.51302 .60429 m .52382 .61255 L .52795 .60934 L .673 .757 .914 r
F
.50562 .57677 m .50719 .57704 L .50719 .60516 L .751 .491 .539 r
F
.5098 .57639 m .51051 .57583 L .51051 .60396 L .358 .18 .498 r
F
.50853 .60685 m .50593 .61732 L .51243 .61668 L .673 .757 .914 r
F
.50811 .60579 m .50767 .60809 L .50853 .60685 L F
.50767 .60809 m .50593 .61732 L .50853 .60685 L F
.50958 .60532 m .51243 .61668 L .51723 .6154 L F
.50957 .61064 m .51548 .61707 L .51018 .60976 L F
.51243 .61668 m .53038 .62796 L .51853 .61506 L F
.51548 .61707 m .51891 .6208 L .51473 .61552 L F
.51548 .61707 m .51473 .61552 L .51018 .60976 L F
.51095 .6328 m .51095 .63282 L .51095 .6339 L .076 0 .415 r
F
.50878 .57683 m .50927 .60472 L .50878 .60493 L .517 .303 .528 r
F
.50719 .57704 m .50878 .57683 L .50878 .60493 L .641 .402 .54 r
F
.50719 .57704 m .50878 .60493 L .50796 .60505 L F
.51051 .57583 m .51094 .57514 L .51095 .60333 L .076 0 .415 r
F
.51051 .57583 m .51095 .60333 L .51072 .60366 L F
.51106 .57433 m .51061 .57329 L .51062 .60166 L .984 .727 .339 r
F
.5091 .60479 m .51853 .61506 L .51024 .60432 L .673 .757 .914 r
F
.50593 .61732 m .5052 .63248 L .50633 .63236 L F
.49949 .61692 m .5052 .63248 L .50537 .62889 L F
.50456 .61723 m .50537 .62889 L .50593 .61732 L F
.49949 .61692 m .50537 .62889 L .50456 .61723 L F
.50355 .5742 m .5036 .57501 L .5036 .60346 L .783 .625 .063 r
F
.50652 .60509 m .50593 .61732 L .50789 .60525 L .673 .757 .914 r
F
.5036 .57501 m .50398 .57571 L .50398 .60407 L .989 .72 .386 r
F
.50355 .5742 m .50357 .60308 L .50355 .60272 L .783 .625 .063 r
F
.50355 .5742 m .5036 .60346 L .50357 .60308 L F
.50408 .57317 m .50355 .5742 L .50355 .60272 L 0 0 .377 r
F
.50482 .60544 m .4992 .61045 L .50495 .60567 L .673 .757 .914 r
F
.4992 .61045 m .49353 .61552 L .49902 .61078 L F
.4992 .61045 m .49902 .61078 L .50495 .60567 L F
.50442 .6048 m .49353 .61552 L .50482 .60544 L F
.50669 .61381 m .49977 .62267 L .50624 .62307 L F
.5068 .61158 m .50605 .61276 L .50669 .61381 L F
.50648 .60602 m .49949 .61692 L .50593 .61732 L F
.50562 .60498 m .50652 .6104 L .50563 .61029 L .751 .491 .539 r
F
.50562 .57677 m .50638 .60507 L .50562 .60498 L F
.50652 .60509 m .50525 .60506 L .50648 .60602 L .673 .757 .914 r
F
.50531 .60494 m .50525 .60506 L .50652 .60509 L F
.50638 .60507 m .50652 .6104 L .50562 .60498 L .751 .491 .539 r
F
.50666 .60215 m .50531 .60494 L .50652 .60509 L .673 .757 .914 r
F
.50525 .60506 m .49949 .61692 L .50648 .60602 L F
.50605 .61276 m .49977 .62267 L .50669 .61381 L F
.5065 .61135 m .50585 .61244 L .5068 .61158 L F
.50585 .61244 m .49977 .62267 L .50605 .61276 L F
.50585 .61244 m .50605 .61276 L .5068 .61158 L F
.49977 .62267 m .50551 .6383 L .50624 .62307 L F
.5041 .62125 m .50008 .62834 L .50461 .62862 L .673 .758 .914 r
F
.50378 .60375 m .50398 .60407 L .50398 .60939 L .989 .72 .386 r
F
.50624 .61568 m .50596 .61624 L .50719 .61579 L .673 .758 .914 r
F
.50596 .61624 m .50008 .62834 L .50664 .61677 L F
.50682 .61106 m .50624 .62307 L .50806 .61058 L .673 .757 .914 r
F
.50799 .61057 m .50806 .61058 L .50806 .61054 L F
.50682 .61106 m .50806 .61058 L .50799 .61057 L F
.50638 .60507 m .50719 .60516 L .5072 .61048 L .751 .491 .539 r
F
.50684 .61078 m .5065 .61135 L .5068 .61158 L .673 .757 .914 r
F
.50719 .61579 m .5041 .62125 L .50656 .62874 L .673 .758 .914 r
F
.50808 .61058 m .50624 .62307 L .51277 .62243 L .673 .757 .914 r
F
.49353 .61552 m .49232 .63168 L .49949 .61692 L F
.49353 .61552 m .48041 .62887 L .49232 .63168 L F
.48847 .6132 m .48041 .62887 L .49353 .61552 L F
.48847 .6132 m .47028 .62424 L .48041 .62887 L F
.5036 .57501 m .50398 .60407 L .50378 .60375 L .989 .72 .386 r
F
.50464 .5763 m .50511 .60478 L .50464 .60459 L .845 .571 .524 r
F
.50398 .57571 m .50464 .5763 L .50464 .60459 L .929 .648 .488 r
F
.50398 .57571 m .50464 .60459 L .50453 .6045 L F
.50443 .60442 m .48847 .6132 L .49353 .61552 L .673 .757 .914 r
F
.50666 .60215 m .50377 .60391 L .50443 .60442 L F
.50377 .60391 m .48847 .6132 L .50443 .60442 L F
.5043 .60432 m .50464 .6099 L .50436 .60968 L .929 .648 .488 r
F
.50398 .57571 m .50453 .6045 L .5043 .60432 L F
.50443 .60442 m .50437 .60448 L .50464 .60459 L .673 .757 .914 r
F
.50495 .60567 m .50382 .60664 L .5039 .60783 L F
.50453 .6045 m .50464 .6099 L .5043 .60432 L .929 .648 .488 r
F
.50382 .60224 m .50377 .60763 L .50408 .60177 L 0 0 .377 r
F
.5048 .61604 m .50381 .61705 L .5055 .61719 L .673 .758 .914 r
F
.49949 .61692 m .49232 .63168 L .5052 .63248 L .673 .757 .914 r
F
.50523 .61143 m .49378 .62126 L .49977 .62267 L F
.50381 .61705 m .4941 .62693 L .50391 .61855 L .673 .758 .914 r
F
.50381 .61705 m .50391 .61855 L .5055 .61719 L F
.49378 .62126 m .49256 .6375 L .49977 .62267 L .673 .757 .914 r
F
.50381 .61705 m .48901 .6246 L .4941 .62693 L .673 .758 .914 r
F
.50506 .61114 m .50384 .61223 L .50523 .61143 L .673 .757 .914 r
F
.50384 .61223 m .49378 .62126 L .50387 .6126 L F
.50384 .61223 m .50387 .6126 L .50523 .61143 L F
.50357 .60308 m .50358 .60846 L .50355 .60272 L .783 .625 .063 r
F
.50371 .61568 m .48901 .6246 L .50381 .61705 L .673 .758 .914 r
F
.50481 .61003 m .49924 .6157 L .50561 .61065 L .673 .757 .914 r
F
.49924 .6157 m .49378 .62126 L .49849 .61703 L F
.49924 .6157 m .49849 .61703 L .50561 .61065 L F
.50358 .60846 m .50356 .60816 L .50355 .60272 L .783 .625 .063 r
F
.50355 .60272 m .50356 .60816 L .50355 .60803 L F
.50437 .60448 m .49353 .61552 L .50464 .60459 L .673 .757 .914 r
F
.50378 .60375 m .50382 .60912 L .5036 .60346 L .989 .72 .386 r
F
.50382 .60664 m .49353 .61552 L .5039 .60783 L .673 .757 .914 r
F
.50357 .60308 m .5036 .60346 L .5036 .60877 L .783 .625 .063 r
F
.5039 .60783 m .49838 .61192 L .49949 .61692 L .673 .757 .914 r
F
.49838 .61192 m .49353 .61552 L .49603 .6161 L F
.50367 .60983 m .48869 .61893 L .50373 .61061 L F
.50359 .60858 m .5036 .60877 L .5036 .61408 L .783 .625 .063 r
F
.50357 .60308 m .5036 .60877 L .50359 .60858 L F
.50398 .57571 m .5043 .60432 L .50398 .60407 L .929 .648 .488 r
F
.50344 .60411 m .48464 .61013 L .48847 .6132 L .673 .757 .914 r
F
.50666 .60215 m .5024 .60369 L .50344 .60411 L F
.5024 .60369 m .48464 .61013 L .50344 .60411 L F
.50464 .5763 m .50562 .57677 L .50562 .60498 L .845 .571 .524 r
F
.50547 .60492 m .50562 .60498 L .50563 .61029 L F
.50464 .5763 m .50562 .60498 L .50547 .60492 L F
.5036 .57501 m .50378 .60375 L .5036 .60346 L .989 .72 .386 r
F
.5024 .60369 m .48232 .60651 L .48464 .61013 L .673 .757 .914 r
F
.5052 .57238 m .50408 .57317 L .50408 .60177 L .401 .213 .507 r
F
.50534 .61549 m .50371 .61568 L .50381 .61705 L .673 .758 .914 r
F
.50399 .60964 m .50367 .60983 L .50473 .60997 L .673 .757 .914 r
F
.50464 .6099 m .50473 .60997 L .50485 .60999 L F
.50399 .60964 m .50473 .60997 L .50464 .6099 L F
.50442 .61504 m .50421 .61488 L .50409 .60948 L .929 .648 .488 r
F
.5042 .60956 m .50409 .60948 L .50398 .60407 L F
.50442 .61504 m .50409 .60948 L .5042 .60956 L F
.50367 .60983 m .50373 .61061 L .50485 .60999 L .673 .757 .914 r
F
.50575 .61035 m .49977 .62267 L .50684 .61078 L F
.50563 .61029 m .50596 .61565 L .50563 .61561 L .751 .491 .539 r
F
.5073 .6135 m .50064 .61469 L .50248 .61524 L .673 .758 .914 r
F
.50064 .61469 m .49951 .61489 L .50021 .61498 L F
.50064 .61469 m .50021 .61498 L .50248 .61524 L F
.5043 .60432 m .50436 .60968 L .50398 .60407 L .929 .648 .488 r
F
.50436 .60968 m .50442 .61504 L .5042 .60956 L F
.50436 .60968 m .5042 .60956 L .50398 .60407 L F
.50208 .60791 m .48289 .60431 L .48184 .60828 L .673 .757 .914 r
F
.50378 .60375 m .50398 .60939 L .50382 .60912 L .989 .72 .386 r
F
.50398 .60407 m .50409 .60948 L .50398 .60939 L .929 .648 .488 r
F
.50498 .61535 m .50563 .63553 L .50485 .6153 L .845 .571 .524 r
F
.5041 .62125 m .50461 .62862 L .50656 .62874 L .673 .758 .914 r
F
.50464 .61521 m .50563 .63553 L .50464 .63506 L .845 .571 .524 r
F
.50464 .6099 m .50485 .6153 L .50464 .61521 L F
.50485 .6153 m .50563 .63553 L .50464 .61521 L F
.50356 .60816 m .50357 .61361 L .50355 .60803 L .783 .625 .063 r
F
.50357 .61361 m .50356 .61351 L .50355 .60803 L F
.50355 .60803 m .50356 .61351 L .50355 .61335 L F
.50485 .60999 m .50137 .61191 L .49924 .6157 L .673 .757 .914 r
F
.50367 .60888 m .50373 .6143 L .5036 .60877 L .989 .72 .386 r
F
.50373 .6143 m .50398 .63447 L .50368 .61422 L F
.50373 .6143 m .50368 .61422 L .5036 .60877 L F
.49924 .6157 m .48869 .61893 L .49378 .62126 L .673 .757 .914 r
F
.50365 .61482 m .48516 .62152 L .50431 .61525 L .673 .758 .914 r
F
.50418 .61503 m .50431 .61525 L .50454 .61517 L F
.50365 .61482 m .50431 .61525 L .50418 .61503 L F
.50357 .60308 m .5036 .61408 L .50358 .61384 L .783 .625 .063 r
F
.50195 .61087 m .48485 .61584 L .48869 .61893 L .673 .757 .914 r
F
.50698 .60782 m .50282 .60933 L .50195 .61087 L F
.50282 .60933 m .48485 .61584 L .50195 .61087 L F
.50409 .60948 m .50421 .61488 L .50398 .60939 L .929 .648 .488 r
F
.50421 .61488 m .50464 .63506 L .50412 .61481 L F
.50421 .61488 m .50412 .61481 L .50398 .60939 L F
.49838 .61192 m .49603 .6161 L .49949 .61692 L .673 .757 .914 r
F
.50334 .61421 m .48216 .61396 L .48283 .61789 L .673 .758 .914 r
F
.5073 .6135 m .50254 .61358 L .50334 .61421 L F
.50254 .61358 m .48216 .61396 L .50334 .61421 L F
.50408 .60709 m .50389 .61274 L .50408 .6124 L 0 0 .377 r
F
.50408 .60177 m .50399 .60726 L .50408 .60709 L F
.50382 .60912 m .50398 .60939 L .50398 .6147 L .989 .72 .386 r
F
.50399 .60726 m .50389 .61274 L .50408 .60709 L 0 0 .377 r
F
.50377 .60763 m .50355 .60803 L .50355 .61335 L F
.49817 .61101 m .48251 .61221 L .48485 .61584 L .673 .757 .914 r
F
.50511 .60478 m .50563 .61029 L .5052 .61012 L .845 .571 .524 r
F
.50698 .60782 m .5015 .6088 L .49817 .61101 L .673 .757 .914 r
F
.5015 .6088 m .48251 .61221 L .49817 .61101 L F
.50698 .60782 m .5037 .60734 L .50287 .6079 L F
.50455 .60677 m .50408 .6124 L .50445 .61216 L .401 .213 .507 r
F
.50466 .60139 m .50437 .6069 L .50455 .60677 L F
.50437 .6069 m .50408 .6124 L .50455 .60677 L F
.50358 .60846 m .50358 .61384 L .50356 .60816 L .783 .625 .063 r
F
.5055 .61719 m .49759 .62395 L .50008 .62834 L .673 .758 .914 r
F
.50358 .61384 m .5036 .63377 L .50357 .61361 L .783 .625 .063 r
F
.50358 .61384 m .50357 .61361 L .50356 .60816 L F
.50356 .61356 m .4832 .60999 L .48216 .61396 L .673 .758 .914 r
F
.50498 .61535 m .50485 .6153 L .50464 .6099 L .845 .571 .524 r
F
.5073 .6135 m .50352 .61295 L .50356 .61356 L .673 .758 .914 r
F
.50352 .61295 m .4832 .60999 L .50356 .61356 L F
.50357 .61361 m .5036 .63377 L .50356 .61351 L .783 .625 .063 r
F
.50355 .61335 m .5036 .63377 L .50355 .63296 L F
.50356 .61351 m .5036 .63377 L .50355 .61335 L F
.5036 .61408 m .50398 .63447 L .5036 .63377 L .989 .72 .386 r
F
.5036 .60877 m .50368 .61422 L .5036 .61408 L F
.50368 .61422 m .50398 .63447 L .5036 .61408 L F
.50464 .60459 m .50481 .60997 L .50464 .6099 L .845 .571 .524 r
F
.50178 .60875 m .48184 .60828 L .48251 .61221 L .673 .757 .914 r
F
.49465 .6043 m .48165 .6026 L .48232 .60651 L F
.50442 .6048 m .50482 .60544 L .50525 .60506 L F
.50525 .60506 m .50482 .60544 L .50495 .60567 L F
.50666 .60215 m .50443 .60442 L .50525 .60506 L F
.5052 .60103 m .50455 .60677 L .5052 .60634 L .401 .213 .507 r
F
.50464 .5763 m .50547 .60492 L .50511 .60478 L .845 .571 .524 r
F
.5052 .57238 m .50466 .60139 L .5052 .60103 L .401 .213 .507 r
F
.50464 .60459 m .50442 .6048 L .50525 .60506 L .673 .757 .914 r
F
.50453 .6045 m .50464 .60459 L .50464 .6099 L .929 .648 .488 r
F
.50466 .60139 m .50455 .60677 L .5052 .60103 L .401 .213 .507 r
F
.50236 .60292 m .50129 .60224 L .49465 .6043 L .673 .757 .914 r
F
.50666 .60215 m .50343 .6022 L .50236 .60292 L F
.50343 .6022 m .50129 .60224 L .50236 .60292 L F
.50129 .60224 m .48165 .6026 L .49465 .6043 L F
.5063 .57205 m .5052 .57238 L .5052 .60103 L .568 .343 .534 r
F
.50538 .60098 m .5052 .60103 L .5052 .60634 L F
.5063 .57205 m .5052 .60103 L .50538 .60098 L F
.5052 .61012 m .50563 .63553 L .50481 .60997 L .845 .571 .524 r
F
.5073 .6135 m .50365 .61482 L .50454 .61517 L .673 .758 .914 r
F
.50547 .60492 m .50563 .61029 L .50511 .60478 L .845 .571 .524 r
F
.50698 .60782 m .50399 .60964 L .50485 .60999 L .673 .757 .914 r
F
.50561 .61065 m .50506 .61114 L .50523 .61143 L F
.5052 .61012 m .50563 .61029 L .50563 .63553 L .845 .571 .524 r
F
.50666 .60215 m .50236 .60292 L .5024 .60369 L .673 .757 .914 r
F
.5036 .60346 m .50367 .60888 L .5036 .60877 L .989 .72 .386 r
F
.50382 .60912 m .50367 .60888 L .5036 .60346 L F
.50382 .60224 m .50355 .60803 L .50377 .60763 L 0 0 .377 r
F
.50129 .60224 m .48269 .59866 L .48165 .6026 L .673 .757 .914 r
F
.50408 .57317 m .50355 .60272 L .50382 .60224 L 0 0 .377 r
F
.50666 .60215 m .50322 .60164 L .50129 .60224 L .673 .757 .914 r
F
.50322 .60164 m .48269 .59866 L .50129 .60224 L F
.50631 .60069 m .50567 .6062 L .50631 .606 L .568 .343 .534 r
F
.50562 .57677 m .50719 .60516 L .50638 .60507 L .751 .491 .539 r
F
.5063 .57205 m .50577 .60085 L .50631 .60069 L .568 .343 .534 r
F
.50577 .60085 m .50567 .6062 L .50631 .60069 L F
.50385 .60676 m .48972 .59735 L .48557 .60059 L .673 .757 .914 r
F
.50698 .60782 m .50477 .60648 L .50385 .60676 L F
.50106 .60315 m .48232 .60651 L .5024 .60369 L F
.50322 .60164 m .48536 .59495 L .48269 .59866 L F
.50666 .60215 m .50424 .60133 L .50322 .60164 L F
.50424 .60133 m .48536 .59495 L .50322 .60164 L F
.50577 .60085 m .5052 .60634 L .50567 .6062 L .568 .343 .534 r
F
.5063 .57205 m .50538 .60098 L .50577 .60085 L F
.50538 .60098 m .5052 .60634 L .50577 .60085 L F
.50477 .60648 m .48972 .59735 L .50385 .60676 L .673 .757 .914 r
F
.50008 .62834 m .50583 .64397 L .50656 .62874 L .673 .758 .914 r
F
.50563 .61561 m .5072 .63579 L .50563 .63553 L .751 .491 .539 r
F
.50596 .61565 m .5072 .63579 L .50563 .61561 L F
.49977 .60795 m .48184 .60828 L .50178 .60875 L .673 .757 .914 r
F
.5035 .60731 m .48557 .60059 L .48289 .60431 L F
.50346 .6122 m .49004 .60303 L .48589 .60626 L .673 .758 .914 r
F
.5052 .61166 m .50408 .63193 L .50521 .63114 L .401 .213 .507 r
F
.5052 .61012 m .50481 .60997 L .50464 .60459 L .845 .571 .524 r
F
.50698 .60782 m .50481 .61003 L .50561 .61065 L .673 .757 .914 r
F
.5052 .60634 m .50496 .61182 L .5052 .61166 L .401 .213 .507 r
F
.50496 .61182 m .50408 .63193 L .5052 .61166 L F
.50398 .60939 m .50464 .63506 L .50398 .63447 L .929 .648 .488 r
F
.50408 .61241 m .50458 .61185 L .50346 .6122 L .673 .758 .914 r
F
.5073 .6135 m .50476 .61196 L .50408 .61241 L F
.50511 .60478 m .5052 .61012 L .50464 .60459 L .845 .571 .524 r
F
.50698 .60782 m .50345 .60663 L .5035 .60731 L .673 .757 .914 r
F
.50481 .60997 m .50498 .61535 L .50464 .6099 L .845 .571 .524 r
F
.50454 .61517 m .50371 .61568 L .50504 .61553 L .673 .758 .914 r
F
.50464 .61521 m .50504 .61553 L .50534 .61549 L F
.50454 .61517 m .50504 .61553 L .50464 .61521 L F
.50436 .60968 m .50464 .6099 L .50464 .61521 L .929 .648 .488 r
F
.50442 .61504 m .50464 .61521 L .50464 .63506 L F
.50436 .60968 m .50464 .61521 L .50442 .61504 L F
.50442 .61504 m .50464 .63506 L .50421 .61488 L F
.50455 .60677 m .50445 .61216 L .5052 .60634 L .401 .213 .507 r
F
.50445 .61216 m .50408 .63193 L .50496 .61182 L F
.50445 .61216 m .50496 .61182 L .5052 .60634 L F
.50003 .60795 m .49977 .60795 L .49988 .60799 L .673 .757 .914 r
F
.50003 .60795 m .49988 .60799 L .50178 .60875 L F
.50345 .60663 m .48557 .60059 L .5035 .60731 L F
.50476 .61196 m .49536 .60051 L .49004 .60303 L .673 .758 .914 r
F
.50698 .60782 m .50003 .60795 L .50178 .60875 L .673 .757 .914 r
F
.50567 .6062 m .50557 .61155 L .50631 .606 L .568 .343 .534 r
F
.50596 .61624 m .50664 .61677 L .50719 .61579 L .673 .758 .914 r
F
.50652 .6104 m .5072 .63579 L .50563 .61029 L .751 .491 .539 r
F
.5073 .6135 m .50552 .61156 L .50476 .61196 L .673 .758 .914 r
F
.50652 .6104 m .5072 .61579 L .50666 .61573 L .751 .491 .539 r
F
.5073 .6135 m .50454 .61517 L .50534 .61549 L .673 .758 .914 r
F
.5073 .6135 m .5048 .61604 L .5055 .61719 L F
.50557 .61155 m .50521 .63114 L .50607 .61139 L .568 .343 .534 r
F
.50557 .61155 m .50607 .61139 L .50631 .606 L F
.50567 .6062 m .5052 .60634 L .5052 .61166 L F
.50557 .61155 m .5052 .61166 L .50521 .63114 L F
.50567 .6062 m .5052 .61166 L .50557 .61155 L F
.50287 .6079 m .50081 .60692 L .50208 .60791 L .673 .757 .914 r
F
.5037 .60734 m .50081 .60692 L .50287 .6079 L F
.50236 .60292 m .50106 .60315 L .50165 .60339 L F
.50236 .60292 m .50165 .60339 L .5024 .60369 L F
.50377 .60763 m .50399 .60726 L .50408 .60177 L 0 0 .377 r
F
.5052 .57238 m .50408 .60177 L .50466 .60139 L .401 .213 .507 r
F
.50408 .57317 m .50382 .60224 L .50408 .60177 L 0 0 .377 r
F
.5033 .60101 m .48949 .59173 L .48536 .59495 L .673 .757 .914 r
F
.50666 .60215 m .50457 .60087 L .5033 .60101 L F
.50457 .60087 m .48949 .59173 L .5033 .60101 L F
.5074 .57196 m .5063 .57205 L .50631 .60069 L .66 .417 .541 r
F
.5073 .6135 m .50643 .6113 L .50552 .61156 L .673 .758 .914 r
F
.50638 .60507 m .5072 .61048 L .50652 .6104 L .751 .491 .539 r
F
.50698 .60782 m .50575 .61035 L .50684 .61078 L .673 .757 .914 r
F
.50687 .60063 m .50631 .61132 L .50667 .61128 L .66 .417 .541 r
F
.50643 .6113 m .50642 .61128 L .50631 .61132 L .673 .758 .914 r
F
.50643 .6113 m .50631 .61132 L .50552 .61156 L F
.50687 .60063 m .50631 .60069 L .50631 .606 L .66 .417 .541 r
F
.50698 .60782 m .50707 .60592 L .50626 .60601 L .673 .757 .914 r
F
.50382 .60912 m .50398 .6147 L .50385 .61449 L .989 .72 .386 r
F
.5073 .6135 m .50218 .61177 L .50284 .61285 L .673 .758 .914 r
F
.50652 .6104 m .5072 .61048 L .5072 .61579 L .751 .491 .539 r
F
.507 .6197 m .50656 .62874 L .50875 .61716 L .673 .758 .914 r
F
.50666 .61573 m .5072 .61579 L .5072 .63579 L .751 .491 .539 r
F
.5073 .6135 m .50624 .61568 L .50719 .61579 L .673 .758 .914 r
F
.50779 .60603 m .50593 .61732 L .50811 .60579 L .673 .757 .914 r
F
.50788 .6053 m .50593 .61732 L .50791 .60529 L F
.50799 .61036 m .50682 .61106 L .50806 .61054 L F
.50719 .60516 m .50747 .61044 L .5072 .61048 L .641 .402 .54 r
F
.50698 .60782 m .50685 .61053 L .50799 .61036 L .673 .757 .914 r
F
.50685 .61053 m .50682 .61106 L .50799 .61036 L F
.50806 .61058 m .50624 .62307 L .50808 .61058 L F
.50875 .61716 m .50656 .62874 L .50863 .62854 L .673 .758 .914 r
F
.5072 .61048 m .50879 .63559 L .5072 .63579 L .641 .402 .54 r
F
.50815 .61565 m .507 .6197 L .50875 .61716 L .673 .758 .914 r
F
.50775 .61571 m .50753 .61574 L .5072 .61048 L .641 .402 .54 r
F
.50806 .61054 m .50806 .61058 L .50808 .61058 L .673 .757 .914 r
F
.50791 .60529 m .50779 .60603 L .50811 .60579 L F
.50789 .60525 m .50788 .6053 L .50791 .60529 L F
.50796 .60505 m .5081 .61034 L .50719 .60516 L .641 .402 .54 r
F
.51853 .61506 m .53038 .62796 L .54097 .62295 L .673 .757 .914 r
F
.51891 .6208 m .54146 .62873 L .52423 .61828 L F
.51198 .61508 m .52455 .62395 L .5287 .62072 L .673 .758 .914 r
F
.50824 .611 m .51277 .62243 L .50922 .61026 L .673 .757 .914 r
F
.50996 .6202 m .50863 .62854 L .51309 .62811 L .673 .758 .914 r
F
.50981 .61513 m .51052 .63459 L .50981 .63515 L .358 .18 .498 r
F
.50981 .60981 m .50996 .61501 L .50981 .61513 L F
.50996 .61501 m .51052 .63459 L .50981 .61513 L F
.51095 .61396 m .51107 .63309 L .51095 .6339 L 0 0 .142 r
F
.50878 .57683 m .5098 .57639 L .50981 .6045 L .517 .303 .528 r
F
.50878 .57683 m .50981 .6045 L .50927 .60472 L F
.51051 .57583 m .51072 .60366 L .51051 .60396 L .076 0 .415 r
F
.5098 .57639 m .51051 .60396 L .51015 .60424 L .358 .18 .498 r
F
.51263 .60301 m .52795 .60934 L .53063 .60563 L .673 .757 .914 r
F
.50666 .60215 m .51609 .60533 L .51263 .60301 L F
.51609 .60533 m .52795 .60934 L .51263 .60301 L F
.50796 .60505 m .50878 .60493 L .50879 .61556 L .641 .402 .54 r
F
.50821 .6158 m .50838 .61621 L .509 .61552 L .673 .758 .914 r
F
.50821 .6158 m .509 .61552 L .50879 .61556 L F
.50824 .61564 m .50879 .61556 L .50879 .63559 L .641 .402 .54 r
F
.50915 .61019 m .50824 .611 L .50922 .61026 L .673 .757 .914 r
F
.5081 .61034 m .50747 .61044 L .50719 .60516 L .641 .402 .54 r
F
.50698 .60782 m .50799 .61036 L .50915 .61019 L .673 .757 .914 r
F
.50799 .61036 m .50824 .611 L .50915 .61019 L F
.5081 .61034 m .50879 .61556 L .50824 .61564 L .641 .402 .54 r
F
.50796 .60505 m .50837 .6103 L .5081 .61034 L F
.50837 .6103 m .50879 .61556 L .5081 .61034 L F
.50879 .61556 m .509 .61552 L .50908 .61543 L .673 .758 .914 r
F
.50838 .61621 m .51309 .62811 L .50914 .61563 L F
.50838 .61621 m .50914 .61563 L .50908 .61543 L F
.50922 .61026 m .51017 .61352 L .51048 .61162 L .673 .757 .914 r
F
.50993 .60972 m .51005 .61494 L .50981 .60981 L .358 .18 .498 r
F
.51005 .61494 m .51052 .63459 L .50996 .61501 L F
.51005 .61494 m .50996 .61501 L .50981 .60981 L F
.50989 .61507 m .51032 .61533 L .51052 .61459 L .673 .758 .914 r
F
.51017 .61352 m .51277 .62243 L .51048 .61162 L .673 .757 .914 r
F
.51052 .60927 m .51061 .61446 L .51052 .61459 L .076 0 .415 r
F
.5094 .60558 m .51243 .61668 L .50958 .60532 L .673 .757 .914 r
F
.51051 .60396 m .51059 .60916 L .51052 .60927 L .076 0 .415 r
F
.50919 .60496 m .51243 .61668 L .50923 .60494 L .673 .757 .914 r
F
.51015 .60424 m .51051 .60396 L .51052 .61459 L .358 .18 .498 r
F
.51028 .61477 m .51052 .61459 L .51052 .63459 L F
.50782 .60507 m .51243 .61668 L .50917 .60487 L .673 .757 .914 r
F
.51015 .60424 m .51052 .61459 L .51028 .61477 L .358 .18 .498 r
F
.5108 .61417 m .51095 .63282 L .51095 .6328 L .076 0 .415 r
F
.51072 .60366 m .51081 .61417 L .5108 .61417 L F
.51277 .62243 m .51856 .63702 L .53082 .63376 L .673 .757 .914 r
F
.50952 .61603 m .51309 .62811 L .51765 .62689 L .673 .758 .914 r
F
.51081 .61417 m .51095 .63282 L .5108 .61417 L .076 0 .415 r
F
.51075 .60909 m .51054 .60998 L .5125 .60968 L .673 .757 .914 r
F
.50917 .60487 m .50919 .60496 L .50923 .60494 L F
.5126 .60864 m .52838 .61505 L .53107 .61133 L F
.50937 .61 m .50912 .6101 L .50878 .60493 L .517 .303 .528 r
F
.51076 .60891 m .5108 .61417 L .51066 .60907 L .076 0 .415 r
F
.51081 .60737 m .51062 .61229 L .51077 .61261 L .984 .727 .339 r
F
.50958 .60532 m .51723 .6154 L .51546 .61172 L .673 .757 .914 r
F
.51094 .57514 m .51107 .60259 L .511 .60298 L 0 0 .142 r
F
.51094 .57514 m .511 .60298 L .51095 .60333 L F
.51121 .60206 m .53063 .60563 L .53167 .60169 L .673 .757 .914 r
F
.50666 .60215 m .51263 .60301 L .51121 .60206 L F
.51263 .60301 m .53063 .60563 L .51121 .60206 L F
.51061 .57329 m .50956 .57246 L .50956 .60095 L .909 .63 .5 r
F
.50957 .61597 m .51005 .61527 L .50989 .61507 L .673 .758 .914 r
F
.51021 .60951 m .50993 .60972 L .50981 .6045 L .358 .18 .498 r
F
.50698 .60782 m .51118 .60924 L .51162 .60905 L .673 .757 .914 r
F
.50698 .60782 m .51162 .60905 L .51133 .60845 L F
.50937 .61 m .50981 .61513 L .50946 .61527 L .517 .303 .528 r
F
.50908 .61543 m .50981 .61513 L .50989 .61507 L .673 .758 .914 r
F
.50937 .61 m .50981 .60981 L .50981 .61513 L .517 .303 .528 r
F
.50921 .61558 m .50957 .61597 L .50989 .61507 L .673 .758 .914 r
F
.50875 .61716 m .50863 .62854 L .50996 .6202 L F
.50946 .61527 m .50981 .61513 L .50981 .63515 L .517 .303 .528 r
F
.50923 .60494 m .5094 .60558 L .50958 .60532 L .673 .757 .914 r
F
.50927 .60472 m .50981 .6045 L .50981 .60981 L .517 .303 .528 r
F
.50981 .6045 m .50993 .60972 L .50981 .60981 L .358 .18 .498 r
F
.51853 .61506 m .54097 .62295 L .52382 .61255 L .673 .757 .914 r
F
.5125 .60968 m .52423 .61828 L .52838 .61505 L F
.51384 .61445 m .5287 .62072 L .53139 .617 L .673 .758 .914 r
F
.51021 .60951 m .51028 .61477 L .50993 .60972 L .358 .18 .498 r
F
.51028 .61477 m .51052 .63459 L .51005 .61494 L F
.51028 .61477 m .51005 .61494 L .50993 .60972 L F
.51121 .61407 m .51762 .61698 L .51384 .61445 L .673 .758 .914 r
F
.5073 .6135 m .51052 .61459 L .51121 .61407 L F
.51243 .61668 m .51818 .63121 L .53038 .62796 L .673 .757 .914 r
F
.51048 .61162 m .51277 .62243 L .51891 .6208 L F
.51052 .61459 m .51762 .61698 L .51121 .61407 L .673 .758 .914 r
F
.51546 .61172 m .51723 .6154 L .51853 .61506 L .673 .757 .914 r
F
.51072 .61009 m .51891 .6208 L .52423 .61828 L F
.51018 .60976 m .51067 .61038 L .51072 .61009 L F
.51067 .61038 m .51891 .6208 L .51072 .61009 L F
.51095 .60864 m .51099 .6137 L .51095 .61396 L 0 0 .142 r
F
.51095 .60333 m .51097 .60852 L .51095 .60864 L F
.51097 .60852 m .51099 .6137 L .51095 .60864 L F
.51762 .61698 m .5287 .62072 L .51384 .61445 L .673 .758 .914 r
F
.51011 .60132 m .50956 .60095 L .50956 .60627 L .909 .63 .5 r
F
.50908 .61543 m .50921 .61558 L .50981 .61513 L .673 .758 .914 r
F
.50908 .61543 m .50935 .61629 L .50952 .61603 L F
.50946 .61527 m .50981 .63515 L .50914 .61541 L .517 .303 .528 r
F
.50946 .61527 m .50914 .61541 L .50878 .60493 L F
.5073 .6135 m .50989 .61507 L .51052 .61459 L .673 .758 .914 r
F
.50927 .60472 m .50981 .60981 L .50937 .61 L .517 .303 .528 r
F
.51399 .61337 m .53139 .617 L .53244 .61304 L .673 .758 .914 r
F
.5073 .6135 m .51205 .61419 L .51399 .61337 L F
.51054 .60998 m .52423 .61828 L .5125 .60968 L .673 .757 .914 r
F
.51205 .61419 m .53139 .617 L .51399 .61337 L .673 .758 .914 r
F
.50879 .61556 m .50981 .63515 L .50879 .63559 L .517 .303 .528 r
F
.50878 .61024 m .509 .61547 L .50879 .61556 L F
.509 .61547 m .50981 .63515 L .50879 .61556 L F
.50878 .60493 m .50896 .61017 L .50878 .61024 L F
.52382 .61255 m .54922 .61653 L .52795 .60934 L .673 .757 .914 r
F
.51848 .61149 m .53244 .61304 L .53178 .6091 L .673 .758 .914 r
F
.50914 .61541 m .50981 .63515 L .509 .61547 L .517 .303 .528 r
F
.51258 .60573 m .51853 .61506 L .52382 .61255 L .673 .757 .914 r
F
.51464 .61002 m .51853 .61506 L .51258 .60573 L F
.51118 .60924 m .52838 .61505 L .5126 .60864 L F
.51076 .60463 m .52382 .61255 L .51302 .60429 L F
.51175 .60773 m .53107 .61133 L .53212 .60736 L F
.51076 .60891 m .51066 .60907 L .51051 .60396 L .076 0 .415 r
F
.51072 .60366 m .51076 .60891 L .51051 .60396 L F
.50666 .60215 m .51076 .60463 L .51302 .60429 L .673 .757 .914 r
F
.51085 .60214 m .51062 .60166 L .51062 .60698 L .984 .727 .339 r
F
.51074 .60722 m .51062 .60698 L .51062 .61229 L F
.51085 .60214 m .51062 .60698 L .51074 .60722 L F
.51099 .60775 m .51324 .60873 L .51175 .60773 L .673 .757 .914 r
F
.50698 .60782 m .51133 .60845 L .51099 .60775 L F
.51133 .60845 m .51324 .60873 L .51099 .60775 L F
.51324 .60873 m .53107 .61133 L .51175 .60773 L F
.51072 .60366 m .51095 .60333 L .51095 .60864 L .076 0 .415 r
F
.51072 .60366 m .51095 .60864 L .51084 .60881 L F
.51072 .60366 m .51095 .61396 L .51081 .61417 L F
.51085 .60214 m .51074 .60722 L .51081 .60737 L .984 .727 .339 r
F
.51024 .60432 m .51464 .61002 L .51258 .60573 L .673 .757 .914 r
F
.511 .60298 m .51102 .60822 L .51095 .60333 L 0 0 .142 r
F
.50957 .61597 m .51047 .61695 L .51005 .61527 L .673 .758 .914 r
F
.51047 .61695 m .51922 .62647 L .51063 .61597 L F
.51047 .61695 m .51063 .61597 L .51005 .61527 L F
.51102 .60822 m .51103 .61347 L .51097 .60852 L 0 0 .142 r
F
.51103 .61347 m .51107 .63309 L .51099 .6137 L F
.51103 .61347 m .51099 .6137 L .51097 .60852 L F
.51102 .60822 m .51097 .60852 L .51095 .60333 L F
.51101 .60137 m .53167 .60169 L .53102 .59777 L .673 .757 .914 r
F
.50666 .60215 m .51333 .60202 L .51101 .60137 L F
.51333 .60202 m .53167 .60169 L .51101 .60137 L F
.50666 .60215 m .5091 .60479 L .51024 .60432 L F
.50956 .60095 m .50894 .60609 L .50956 .60627 L .809 .541 .532 r
F
.50956 .57246 m .50904 .60081 L .50956 .60095 L F
.50904 .60081 m .50894 .60609 L .50956 .60095 L F
.51152 .60506 m .52913 .59979 L .52529 .5967 L .673 .757 .914 r
F
.511 .60298 m .51107 .60259 L .51107 .60791 L 0 0 .142 r
F
.511 .60298 m .51107 .60791 L .51102 .60822 L F
.51107 .60259 m .51099 .60774 L .51107 .60791 L .984 .727 .339 r
F
.51011 .60592 m .51145 .60549 L .51152 .60506 L .673 .757 .914 r
F
.51145 .60549 m .52913 .59979 L .51152 .60506 L F
.50927 .60472 m .50937 .61 L .50878 .60493 L .517 .303 .528 r
F
.51015 .60424 m .51021 .60951 L .50981 .6045 L .358 .18 .498 r
F
.50698 .60782 m .51042 .60657 L .51011 .60592 L .673 .757 .914 r
F
.51081 .60737 m .51092 .6076 L .51107 .60259 L .984 .727 .339 r
F
.51042 .60657 m .52913 .59979 L .51011 .60592 L .673 .757 .914 r
F
.51085 .60214 m .51081 .60737 L .51107 .60259 L .984 .727 .339 r
F
.51081 .60737 m .51077 .61261 L .51092 .6076 L F
.50935 .61629 m .51309 .62811 L .50952 .61603 L .673 .758 .914 r
F
.5108 .61417 m .51095 .6339 L .51067 .61437 L .076 0 .415 r
F
.51052 .61459 m .51095 .6339 L .51052 .63459 L F
.51077 .61261 m .51062 .63205 L .51091 .6129 L .984 .727 .339 r
F
.51084 .60881 m .51095 .60864 L .51095 .61396 L .076 0 .415 r
F
.51077 .61261 m .51091 .6129 L .51107 .60259 L .984 .727 .339 r
F
.51109 .61327 m .51399 .61337 L .51475 .61306 L .673 .758 .914 r
F
.5073 .6135 m .51117 .61343 L .51109 .61327 L F
.51117 .61343 m .51399 .61337 L .51109 .61327 L F
.51062 .61229 m .51282 .61251 L .51125 .61206 L F
.5073 .6135 m .51134 .61277 L .51062 .61229 L F
.51134 .61277 m .51282 .61251 L .51062 .61229 L F
.51062 .61229 m .50957 .63122 L .51062 .63205 L .909 .63 .5 r
F
.51059 .60916 m .51067 .61437 L .51052 .60927 L .076 0 .415 r
F
.51067 .61437 m .51095 .6339 L .51061 .61446 L F
.51067 .61437 m .51061 .61446 L .51052 .60927 L F
.50957 .61597 m .51765 .62689 L .5155 .62242 L .673 .758 .914 r
F
.50908 .61543 m .50952 .61603 L .50957 .61597 L F
.50952 .61603 m .51765 .62689 L .50957 .61597 L F
.51062 .60698 m .5104 .61214 L .51062 .61229 L .909 .63 .5 r
F
.5104 .61214 m .50957 .63122 L .51062 .61229 L F
.51062 .60166 m .51043 .60685 L .51062 .60698 L F
.51001 .60966 m .51054 .60998 L .51075 .60909 L .673 .757 .914 r
F
.51043 .60685 m .51025 .61204 L .51062 .60698 L .909 .63 .5 r
F
.50698 .60782 m .50909 .61011 L .51008 .6097 L .673 .757 .914 r
F
.50698 .60782 m .51001 .60966 L .51075 .60909 L F
.50885 .61138 m .50933 .61152 L .50956 .60627 L .809 .541 .532 r
F
.50956 .60627 m .50933 .61152 L .50956 .61158 L F
.51052 .60654 m .51216 .60689 L .51302 .60563 L .673 .757 .914 r
F
.51191 .60694 m .51216 .60689 L .51052 .60654 L F
.51008 .6097 m .50957 .61064 L .51018 .60976 L F
.50909 .61011 m .50957 .61064 L .51008 .6097 L F
.51001 .60657 m .50956 .61158 L .50992 .61182 L .909 .63 .5 r
F
.51011 .60132 m .50983 .60645 L .51001 .60657 L F
.50983 .60645 m .50956 .61158 L .51001 .60657 L F
.51016 .60667 m .51191 .60694 L .51052 .60654 L .673 .757 .914 r
F
.50698 .60782 m .51084 .60713 L .51016 .60667 L F
.51084 .60713 m .51191 .60694 L .51016 .60667 L F
.51001 .60657 m .51027 .60674 L .51062 .60166 L .909 .63 .5 r
F
.51061 .57329 m .50956 .60095 L .51011 .60132 L F
.51061 .57329 m .51011 .60132 L .51062 .60166 L F
.51106 .57433 m .51062 .60166 L .51085 .60214 L .984 .727 .339 r
F
.51106 .57433 m .51085 .60214 L .51107 .60259 L F
.50904 .60081 m .50849 .60065 L .50849 .60596 L .809 .541 .532 r
F
.50698 .60782 m .50954 .60626 L .50905 .60612 L .673 .757 .914 r
F
.50824 .61564 m .50775 .61571 L .50747 .61044 L .641 .402 .54 r
F
.5073 .6135 m .50908 .61543 L .50989 .61507 L .673 .758 .914 r
F
.51025 .61204 m .5104 .61214 L .51062 .60698 L .909 .63 .5 r
F
.51302 .60563 m .53146 .60343 L .52913 .59979 L .673 .757 .914 r
F
.51216 .60689 m .53146 .60343 L .51302 .60563 L F
.51102 .60822 m .51107 .60791 L .51107 .61322 L 0 0 .142 r
F
.51103 .61347 m .51107 .61322 L .51107 .63309 L F
.51102 .60822 m .51107 .61322 L .51103 .61347 L F
.51174 .60897 m .52561 .60238 L .52052 .60005 L .673 .758 .914 r
F
.50926 .6115 m .51154 .61023 L .51174 .60897 L F
.51157 .60774 m .53212 .60736 L .51216 .60689 L .673 .757 .914 r
F
.51154 .61023 m .52561 .60238 L .51174 .60897 L .673 .758 .914 r
F
.50896 .61017 m .50914 .61541 L .50878 .61024 L .517 .303 .528 r
F
.50914 .61541 m .509 .61547 L .50878 .61024 L F
.50937 .61 m .50946 .61527 L .50912 .6101 L F
.5073 .6135 m .51017 .61176 L .50926 .6115 L .673 .758 .914 r
F
.5108 .61417 m .51067 .61437 L .51051 .60396 L .076 0 .415 r
F
.51017 .61176 m .52561 .60238 L .50926 .6115 L .673 .758 .914 r
F
.50698 .60782 m .51157 .60774 L .51163 .60765 L .673 .757 .914 r
F
.51084 .60713 m .51163 .60765 L .51216 .60689 L F
.50698 .60782 m .51163 .60765 L .51084 .60713 L F
.50992 .61182 m .51025 .61204 L .51043 .60685 L .909 .63 .5 r
F
.51027 .60674 m .51043 .60685 L .51062 .60166 L F
.50992 .61182 m .51043 .60685 L .51027 .60674 L F
.50894 .60609 m .50849 .60596 L .50849 .61128 L .809 .541 .532 r
F
.51091 .6129 m .51097 .61302 L .51107 .60791 L .984 .727 .339 r
F
.51216 .60689 m .53212 .60736 L .53146 .60343 L .673 .757 .914 r
F
.51069 .61144 m .52945 .60547 L .52561 .60238 L .673 .758 .914 r
F
.5073 .6135 m .51259 .61158 L .51069 .61144 L F
.51107 .60791 m .51097 .61302 L .51107 .61322 L .984 .727 .339 r
F
.51259 .61158 m .52945 .60547 L .51069 .61144 L .673 .758 .914 r
F
.50824 .61564 m .50879 .63559 L .50775 .61571 L .641 .402 .54 r
F
.50775 .61571 m .50879 .63559 L .50753 .61574 L F
.50849 .61128 m .5074 .63072 L .50849 .63085 L .734 .477 .54 r
F
.50849 .60596 m .50826 .61126 L .50849 .61128 L F
.5073 .6135 m .50933 .61143 L .50856 .61091 L .673 .758 .914 r
F
.5081 .61034 m .50824 .61564 L .50747 .61044 L .641 .402 .54 r
F
.5073 .6135 m .50821 .6158 L .50908 .61543 L .673 .758 .914 r
F
.50826 .61126 m .5074 .63072 L .50849 .61128 L .734 .477 .54 r
F
.50885 .61138 m .50849 .61128 L .50849 .63085 L .809 .541 .532 r
F
.50894 .60609 m .50849 .61128 L .50885 .61138 L F
.50904 .60081 m .50849 .60596 L .50894 .60609 L F
.50905 .60612 m .50955 .60626 L .50918 .60601 L .673 .757 .914 r
F
.50954 .60626 m .50955 .60626 L .50905 .60612 L F
.50878 .60599 m .50918 .60601 L .50893 .60584 L F
.50698 .60782 m .50918 .60601 L .50878 .60599 L F
.50666 .60215 m .50782 .60507 L .50917 .60487 L F
.50849 .60065 m .5083 .60595 L .50849 .60596 L .734 .477 .54 r
F
.5083 .60595 m .5074 .63072 L .50849 .60596 L F
.50848 .57209 m .50796 .60061 L .50849 .60065 L F
.5079 .60592 m .50893 .60584 L .50818 .60535 L .673 .757 .914 r
F
.50698 .60782 m .50878 .60599 L .5079 .60592 L F
.50878 .60599 m .50893 .60584 L .5079 .60592 L F
.50796 .60061 m .50786 .60592 L .50849 .60065 L .734 .477 .54 r
F
.50786 .60592 m .5074 .63072 L .5083 .60595 L F
.50786 .60592 m .5083 .60595 L .50849 .60065 L F
.50849 .60065 m .52488 .59108 L .50821 .60057 L .673 .757 .914 r
F
.50956 .57246 m .50849 .60065 L .50904 .60081 L .809 .541 .532 r
F
.50892 .60077 m .50906 .60069 L .50849 .60065 L .673 .757 .914 r
F
.50906 .60069 m .52488 .59108 L .50849 .60065 L F
.50821 .60057 m .52488 .59108 L .51981 .58876 L F
.50848 .57209 m .5074 .57196 L .5074 .60057 L .734 .477 .54 r
F
.50666 .60215 m .50849 .60065 L .50816 .60063 L .673 .757 .914 r
F
.5073 .6135 m .50719 .61579 L .50815 .61565 L .673 .758 .914 r
F
.50719 .61579 m .507 .6197 L .50815 .61565 L F
.50747 .61044 m .50775 .61571 L .5072 .61048 L .641 .402 .54 r
F
.50666 .60215 m .53102 .59777 L .5287 .59416 L .673 .757 .914 r
F
.50796 .60061 m .5074 .6112 L .50776 .61123 L .734 .477 .54 r
F
.50666 .60215 m .50892 .60077 L .50849 .60065 L .673 .757 .914 r
F
.50816 .60063 m .50849 .60065 L .50821 .60057 L F
.50666 .60215 m .51251 .60003 L .50965 .60033 L F
.51011 .60132 m .51001 .60657 L .51062 .60166 L .909 .63 .5 r
F
.50894 .60609 m .50885 .61138 L .50956 .60627 L .809 .541 .532 r
F
.50818 .60535 m .5202 .59437 L .5142 .59296 L .673 .757 .914 r
F
.51011 .60132 m .50956 .60627 L .50983 .60645 L .909 .63 .5 r
F
.50893 .60584 m .5202 .59437 L .50818 .60535 L .673 .757 .914 r
F
.50741 .6112 m .51452 .59863 L .50804 .59823 L .673 .758 .914 r
F
.5073 .6135 m .50838 .61127 L .50741 .6112 L F
.51001 .60657 m .50992 .61182 L .51027 .60674 L .909 .63 .5 r
F
.50983 .60645 m .50956 .60627 L .50956 .61158 L F
.50838 .61127 m .51452 .59863 L .50741 .6112 L .673 .758 .914 r
F
.50796 .60061 m .5074 .60057 L .5074 .60588 L .734 .477 .54 r
F
.50796 .60061 m .5074 .60588 L .50768 .6059 L F
.50666 .60215 m .51981 .58876 L .51385 .58735 L .673 .757 .914 r
F
.50708 .60586 m .5142 .59296 L .50772 .59255 L F
.5074 .60588 m .50631 .63081 L .5074 .63072 L .66 .417 .541 r
F
.50666 .60215 m .50652 .60509 L .50789 .60525 L .673 .757 .914 r
F
.5074 .60057 m .50721 .60591 L .5074 .60588 L .66 .417 .541 r
F
.50721 .60591 m .50631 .63081 L .5074 .60588 L F
.50698 .60782 m .5079 .60592 L .5074 .60588 L .673 .757 .914 r
F
.50698 .60782 m .5074 .60588 L .50707 .60592 L F
.50687 .60063 m .50667 .61128 L .5074 .60057 L .66 .417 .541 r
F
.50667 .61128 m .50631 .63081 L .50702 .61124 L F
.50667 .61128 m .50702 .61124 L .5074 .60057 L F
.5074 .57196 m .50631 .60069 L .50687 .60063 L F
.50666 .60215 m .5074 .58695 L .5009 .58759 L .673 .757 .914 r
F
.50626 .60601 m .50772 .59255 L .50118 .59319 L F
.50687 .60063 m .50631 .606 L .50659 .60597 L .66 .417 .541 r
F
.50707 .60592 m .50772 .59255 L .50626 .60601 L .673 .757 .914 r
F
.50659 .60597 m .50631 .606 L .50631 .61132 L .66 .417 .541 r
F
.50698 .60782 m .50546 .60617 L .50489 .60655 L .673 .757 .914 r
F
.50466 .60139 m .50408 .60177 L .50408 .60709 L .401 .213 .507 r
F
.50466 .60139 m .50408 .60709 L .50437 .6069 L F
.50631 .606 m .50607 .61139 L .50631 .61132 L .568 .343 .534 r
F
.50643 .6113 m .50804 .59823 L .5015 .59887 L .673 .758 .914 r
F
.5073 .6135 m .50741 .6112 L .50643 .6113 L F
.50707 .60592 m .5074 .60588 L .50708 .60586 L .673 .757 .914 r
F
.50768 .6059 m .5074 .60588 L .5074 .6112 L .734 .477 .54 r
F
.50741 .6112 m .50804 .59823 L .50643 .6113 L .673 .758 .914 r
F
.5079 .60592 m .5142 .59296 L .50708 .60586 L .673 .757 .914 r
F
.50776 .61123 m .5074 .6112 L .5074 .63072 L .734 .477 .54 r
F
.50848 .57209 m .5074 .60057 L .50796 .60061 L F
.50956 .57246 m .50848 .57209 L .50849 .60065 L .809 .541 .532 r
F
.5074 .57196 m .50687 .60063 L .5074 .60057 L .66 .417 .541 r
F
.50965 .60033 m .5287 .59416 L .52488 .59108 L .673 .757 .914 r
F
.51251 .60003 m .5287 .59416 L .50965 .60033 L F
.50893 .60584 m .52529 .5967 L .5202 .59437 L F
.50955 .60626 m .52529 .5967 L .50893 .60584 L F
.50989 .61507 m .51005 .61527 L .5101 .61519 L .673 .758 .914 r
F
.50992 .61182 m .50957 .63122 L .51025 .61204 L .909 .63 .5 r
F
.51134 .61277 m .51475 .61306 L .51282 .61251 L .673 .758 .914 r
F
.5073 .6135 m .512 .61322 L .51134 .61277 L F
.512 .61322 m .51475 .61306 L .51134 .61277 L F
.50856 .61091 m .52052 .60005 L .51452 .59863 L F
.51074 .60722 m .51062 .61229 L .51081 .60737 L .984 .727 .339 r
F
.51133 .60845 m .51162 .60905 L .5126 .60864 L .673 .757 .914 r
F
.51099 .60774 m .51091 .6129 L .51107 .60791 L .984 .727 .339 r
F
.50933 .61143 m .52052 .60005 L .50856 .61091 L .673 .758 .914 r
F
.51025 .61204 m .50957 .63122 L .5104 .61214 L .909 .63 .5 r
F
.51125 .61206 m .53178 .6091 L .52945 .60547 L .673 .758 .914 r
F
.51282 .61251 m .53178 .6091 L .51125 .61206 L F
.50885 .61138 m .50849 .63085 L .50933 .61152 L .809 .541 .532 r
F
.50956 .61158 m .50849 .63085 L .50957 .63122 L F
.50933 .61152 m .50849 .63085 L .50956 .61158 L F
.51282 .61251 m .51475 .61306 L .51848 .61149 L .673 .758 .914 r
F
.51399 .61337 m .53244 .61304 L .51848 .61149 L F
.50992 .61182 m .50956 .61158 L .50957 .63122 L .909 .63 .5 r
F
.51052 .61459 m .51032 .61533 L .51196 .61508 L .673 .758 .914 r
F
.51081 .61417 m .51095 .61396 L .51095 .63282 L .076 0 .415 r
F
.51091 .6129 m .51062 .63205 L .51097 .61302 L .984 .727 .339 r
F
.51277 .62243 m .53082 .63376 L .51891 .6208 L .673 .757 .914 r
F
.51281 .61684 m .51922 .62647 L .52455 .62395 L .673 .758 .914 r
F
.5101 .61519 m .51484 .62105 L .51281 .61684 L F
.51484 .62105 m .51922 .62647 L .51281 .61684 L F
.51005 .61527 m .51922 .62647 L .5101 .61519 L F
.51061 .61446 m .51095 .6339 L .51052 .61459 L .076 0 .415 r
F
.51077 .61261 m .51062 .61229 L .51062 .63205 L .984 .727 .339 r
F
.5155 .62242 m .51765 .62689 L .51922 .62647 L .673 .758 .914 r
F
.51099 .6137 m .51107 .63309 L .51095 .61396 L 0 0 .142 r
F
.51107 .61322 m .51062 .63205 L .51107 .63309 L .984 .727 .339 r
F
.51097 .61302 m .51062 .63205 L .51107 .61322 L F
.51196 .61507 m .51196 .61508 L .51198 .61508 L .673 .758 .914 r
F
.51052 .61459 m .51196 .61508 L .51196 .61507 L F
.51032 .61533 m .52455 .62395 L .51198 .61508 L F
.50667 .61128 m .50631 .61132 L .50631 .63081 L .66 .417 .541 r
F
.50489 .60655 m .49504 .59483 L .48972 .59735 L .673 .757 .914 r
F
.50382 .60224 m .50355 .60272 L .50355 .60803 L 0 0 .377 r
F
.50546 .60617 m .49504 .59483 L .50489 .60655 L .673 .757 .914 r
F
.50437 .6069 m .50408 .60709 L .50408 .6124 L .401 .213 .507 r
F
.50552 .61156 m .5015 .59887 L .49536 .60051 L .673 .758 .914 r
F
.50642 .61128 m .5015 .59887 L .50552 .61156 L F
.50552 .61156 m .50546 .61149 L .5052 .61166 L F
.50552 .61156 m .5052 .61166 L .50476 .61196 L F
.50546 .61149 m .49536 .60051 L .50476 .61196 L F
.50476 .61196 m .50458 .61185 L .50408 .61241 L F
.50377 .60763 m .50355 .61335 L .50373 .61304 L 0 0 .377 r
F
.50081 .60692 m .48289 .60431 L .50208 .60791 L .673 .757 .914 r
F
.50458 .61185 m .49004 .60303 L .50346 .6122 L .673 .758 .914 r
F
.50631 .61132 m .50521 .63114 L .50631 .63081 L .568 .343 .534 r
F
.50607 .61139 m .50521 .63114 L .50631 .61132 L F
.50284 .61285 m .48589 .60626 L .4832 .60999 L .673 .758 .914 r
F
.50218 .61177 m .48589 .60626 L .50284 .61285 L F
.50358 .61384 m .5036 .61408 L .5036 .63377 L .783 .625 .063 r
F
.50373 .61304 m .50355 .61335 L .50355 .63296 L 0 0 .377 r
F
.48869 .61893 m .48059 .63468 L .49378 .62126 L .673 .757 .914 r
F
.50148 .61703 m .48516 .62152 L .48901 .6246 L .673 .758 .914 r
F
.50454 .61517 m .50207 .61598 L .50148 .61703 L F
.50207 .61598 m .48516 .62152 L .50148 .61703 L F
.50445 .61216 m .50408 .6124 L .50408 .63193 L .401 .213 .507 r
F
.50382 .60912 m .50398 .63447 L .50367 .60888 L .989 .72 .386 r
F
.50377 .60763 m .50355 .63296 L .50399 .60726 L 0 0 .377 r
F
.50137 .61191 m .48869 .61893 L .49924 .6157 L .673 .757 .914 r
F
.50248 .61524 m .48283 .61789 L .48516 .62152 L .673 .758 .914 r
F
.49951 .61489 m .48283 .61789 L .50248 .61524 L F
.50385 .61449 m .50398 .6147 L .50398 .63447 L .989 .72 .386 r
F
.50408 .6124 m .50355 .63296 L .50408 .63193 L 0 0 .377 r
F
.50389 .61274 m .50355 .63296 L .50408 .6124 L F
.49759 .62395 m .4941 .62693 L .4957 .62731 L .673 .758 .914 r
F
.49759 .62395 m .4957 .62731 L .50008 .62834 L F
.55215 .87268 m .56003 .87301 L .55978 .87677 L .856 .609 .565 r
F
.55215 .87268 m .5524 .86892 L .56003 .87301 L F
0 g
.56003 .87301 m
.56283 .87389 L
s
.77138 .65827 m .7668 .64064 L .75945 .65546 L .673 .758 .915 r
F
.77138 .65827 m .78471 .64487 L .7668 .64064 L F
.42751 .97698 m .42725 .97479 L .42458 .9736 L .86 .578 .509 r
F
0 g
.42725 .97479 m
.42927 .97641 L
s
.67238 .3956 m .67326 .4547 L .6726 .4541 L .93 .648 .486 r
F
.67201 .3949 m .67238 .3956 L .6726 .4541 L .988 .719 .38 r
F
0 g
.67238 .3956 m
.67304 .3962 L
s
.56162 .864 m .56013 .87291 L .56668 .86672 L .645 .732 .913 r
F
.56162 .864 m .55254 .86884 L .56013 .87291 L F
.59743 .87898 m .59768 .87522 L .60565 .87204 L .502 .302 .541 r
F
0 g
.59188 .87632 m
.59768 .87522 L
s
.7259 .75036 m .71111 .7594 L .72761 .75295 L .683 .771 .917 r
F
.7259 .75036 m .70768 .75421 L .71111 .7594 L F
.41568 .97597 m .41466 .97335 L .41147 .97436 L .692 .759 .903 r
F
.41795 .97566 m .41466 .97335 L .41568 .97597 L F
.41194 .9798 m .40892 .978 L .40677 .97985 L .692 .759 .904 r
F
.41379 .97882 m .40892 .978 L .41194 .9798 L F
.3016 .66102 m .28957 .64807 L .27368 .65561 L .673 .758 .914 r
F
.31384 .65776 m .28957 .64807 L .3016 .66102 L F
.41795 .97566 m .41805 .97288 L .41466 .97335 L .692 .759 .903 r
F
.59166 .86818 m .59759 .87511 L .60552 .87196 L .645 .732 .913 r
F
.127 .923 .03 r
.63598 .85517 m
.63705 .79434 L
s
.58556 .86934 m .59759 .87511 L .59166 .86818 L .645 .732 .913 r
F
.31354 .65209 m .30764 .6375 L .28928 .6424 L .673 .757 .914 r
F
.32659 .65081 m .30764 .6375 L .31354 .65209 L F
.127 .923 .03 r
.49674 8.79934 m
.50375 8.44913 L
s
.50375 8.44913 m
.50982 8.14633 L
s
.50982 8.14633 m
.51917 7.67953 L
s
.66212 .5416 m
.66226 .53455 L
s
.66226 .53455 m
.66229 .53305 L
s
.4014 8.82559 m
.43155 7.86728 L
s
.43155 7.86728 m
.49726 5.77887 L
s
.66202 .54164 m
.66225 .53456 L
s
.66225 .53456 m
.66229 .53305 L
s
.49726 5.77887 m
.52377 4.93612 L
s
.4122 .982 m .40702 .98204 L .41076 .98323 L .692 .759 .904 r
F
.56052 .7636 m .55167 .75441 L .53979 .76036 L .683 .77 .917 r
F
.56964 .76088 m .55167 .75441 L .56052 .7636 L F
.7985 .7569 m .80043 .74351 L .80095 .74808 L 0 0 .401 r
F
.79901 .76147 m .7985 .7569 L .80095 .74808 L F
.78054 .75496 m .7985 .7569 L .80095 .74808 L .683 .771 .917 r
F
0 g
.79465 .7622 m
.7985 .7569 L
s
0 0 0 r
2.5 Mabswid
.33269 .65916 Mdot
.42256 .97834 m .4217 .97513 L .42046 .97789 L .692 .759 .904 r
F
.42256 .97834 m .42484 .9758 L .4217 .97513 L F
.57858 .87709 m .57822 .88471 L .588 .8845 L .644 .733 .913 r
F
.127 .923 .03 r
.5 Mabswid
.65509 .76206 m
.65531 .7549 L
s
.65772 .76127 m
.65787 .75413 L
s
.59602 .82331 m
.5961 .81977 L
s
.57211 .87619 m .57822 .88471 L .57858 .87709 L .644 .733 .913 r
F
.57211 .87619 m .56851 .88336 L .57822 .88471 L F
.127 .923 .03 r
.56967 .80096 m
.5697 .79741 L
s
.56817 .94297 m
.56854 .90302 L
s
.56854 .90302 m
.56873 .88339 L
s
.67935 .39504 m .6797 .45272 L .67957 .45354 L 0 0 .152 r
F
.67935 .39504 m .67947 .39422 L .6797 .45272 L F
0 g
.67891 .39572 m
.67935 .39504 L
s
.42979 .9808 m .42751 .97698 L .42777 .97918 L .933 .634 .451 r
F
.127 .923 .03 r
.42889 .97723 m
.4289 .97932 L
s
.42903 1.01172 m
.42917 .9784 L
s
0 g
.42979 .9808 m
.43102 .98275 L
s
.127 .923 .03 r
.42891 .97995 m
.42907 .99796 L
s
.4289 .97932 m
.42891 .97995 L
s
.42887 .97514 m
.42889 .97723 L
s
.42917 .9784 m
.42918 .9763 L
s
.30661 .75676 m .29187 .76585 L .30837 .75937 L .683 .77 .917 r
F
.127 .923 .03 r
.19345 .68683 m
.19355 .69112 L
s
.30661 .75676 m .28834 .76064 L .29187 .76585 L .683 .77 .917 r
F
.42459 .98132 m .4251 .97799 L .42281 .98053 L .692 .759 .904 r
F
.42459 .98132 m .42777 .97918 L .4251 .97799 L F
.59848 .76608 m .59497 .7532 L .58954 .76431 L .683 .77 .917 r
F
.59848 .76608 m .60838 .75585 L .59497 .7532 L F
.40918 .98019 m .40677 .97985 L .40702 .98204 L .393 .241 .554 r
F
.40918 .98019 m .40892 .978 L .40677 .97985 L F
0 g
.40538 .98194 m
.40677 .97985 L
s
.67201 .3949 m .6726 .4541 L .67222 .4534 L .988 .719 .38 r
F
.67196 .39408 m .67201 .3949 L .67222 .4534 L .772 .616 .051 r
F
0 g
.67201 .3949 m
.67238 .3956 L
s
.48053 .53155 m .44708 .52945 L .47719 .53626 L .654 .726 .902 r
F
.36027 .75219 m .38048 .74534 L .36179 .74634 L .683 .77 .917 r
F
.34234 .75026 m .36027 .75219 L .36179 .74634 L F
.34035 .75305 m .36027 .75219 L .34234 .75026 L F
.22522 .51513 m .20743 .53269 L .23008 .51958 L .654 .726 .902 r
F
.22522 .51513 m .19771 .52381 L .20743 .53269 L F
.53783 .53943 m .56252 .52573 L .5349 .5344 L F
.53783 .53943 m .56837 .53579 L .56252 .52573 L F
.32659 .65081 m .32722 .63559 L .30764 .6375 L .673 .757 .914 r
F
.37994 .64799 m .36434 .63535 L .36465 .64102 L .859 .596 .54 r
F
.38024 .65366 m .37994 .64799 L .36465 .64102 L F
0 g
.37994 .64799 m
.3915 .65722 L
s
.37942 .76329 m .38125 .7499 L .38173 .75447 L 0 0 .384 r
F
.36141 .76135 m .37942 .76329 L .38173 .75447 L .683 .77 .917 r
F
.127 .923 .03 r
.38136 .67276 m
.38137 .67707 L
s
0 g
.37343 .77171 m
.37942 .76329 L
s
.127 .923 .03 r
.19355 .69112 m
.19366 .69542 L
s
.75911 .64978 m .74705 .63376 L .74617 .64898 L .673 .758 .914 r
F
.75911 .64978 m .76646 .63496 L .74705 .63376 L F
.41379 .97882 m .4117 .97652 L .40892 .978 L .692 .759 .904 r
F
.41593 .97814 m .4117 .97652 L .41379 .97882 L F
.27449 .5219 m .29621 .53734 L .30647 .5295 L .654 .726 .902 r
F
.26788 .52477 m .29621 .53734 L .27449 .5219 L F
.77698 .76514 m .79901 .76147 L .78106 .75953 L .683 .771 .917 r
F
.76106 .76039 m .77698 .76514 L .78106 .75953 L F
.75794 .76288 m .77698 .76514 L .76106 .76039 L F
.22333 .49552 m .19893 .50917 L .2263 .50054 L .654 .726 .902 r
F
.22333 .49552 m .19299 .49915 L .19893 .50917 L F
.4117 .97652 m .40867 .9758 L .40892 .978 L .515 .327 .565 r
F
.4117 .97652 m .41144 .97432 L .40867 .9758 L F
0 g
.40651 .97765 m
.40867 .9758 L
s
.42046 .97789 m .41831 .97503 L .4182 .97783 L .692 .759 .904 r
F
.42046 .97789 m .4217 .97513 L .41831 .97503 L F
.63024 .50638 m .62645 .53015 L .64295 .51348 L .654 .726 .902 r
F
.63024 .50638 m .60738 .5195 L .62645 .53015 L F
0 g
.62645 .53015 m
.64888 .53738 L
s
.25498 .49535 m .25302 .512 L .25379 .51198 L .654 .726 .902 r
F
.25584 .49764 m .25379 .51198 L .26113 .51174 L F
.25498 .49535 m .25379 .51198 L .25584 .49764 L F
.25233 .50912 m .25229 .50627 L .25718 .50587 L .665 .425 .546 r
F
.25391 .51149 m .25256 .51938 L .25371 .51934 L .654 .726 .902 r
F
.25242 .50205 m .25229 .50621 L .25716 .50581 L .675 .735 .895 r
F
.25233 .50912 m .25718 .50587 L .25723 .50872 L .665 .425 .546 r
F
.25359 .49471 m .25302 .512 L .2547 .49461 L .654 .726 .902 r
F
.25247 .50494 m .25233 .50912 L .25485 .50891 L .675 .735 .895 r
F
.25511 .50703 m .25485 .50891 L .25723 .50872 L F
.25247 .50494 m .25485 .50891 L .25511 .50703 L F
.25648 .4931 m .2753 .50727 L .28041 .50337 L .654 .726 .902 r
F
.25542 .48117 m .25612 .4806 L .25605 .49374 L .353 .175 .495 r
F
.25779 .51136 m .25371 .51934 L .2607 .51912 L .654 .726 .902 r
F
.25305 .51151 m .25723 .50872 L .25727 .51138 L .665 .425 .546 r
F
.25566 .50567 m .25483 .51146 L .25779 .51136 L .654 .726 .902 r
F
.25483 .51146 m .25371 .51934 L .25779 .51136 L F
.25305 .51151 m .25233 .50912 L .25723 .50872 L .665 .425 .546 r
F
.25125 .48155 m .25282 .48181 L .25275 .49479 L .751 .491 .539 r
F
.24959 .48048 m .25026 .48107 L .25019 .494 L .927 .648 .491 r
F
.24915 .47896 m .24921 .47978 L .24914 .49273 L .798 .638 .081 r
F
.25002 .50455 m .24496 .5109 L .25054 .51166 L .654 .726 .902 r
F
.25248 .49865 m .24989 .50286 L .25341 .50029 L F
.24989 .50286 m .24496 .5109 L .25002 .50455 L F
.24989 .50286 m .25002 .50455 L .25341 .50029 L F
.25306 .49655 m .25217 .49811 L .25352 .49695 L F
.25217 .49811 m .24496 .5109 L .25248 .49865 L F
.25217 .49811 m .25248 .49865 L .25352 .49695 L F
.25327 .49552 m .25283 .49634 L .25356 .49566 L F
.25283 .49634 m .24496 .5109 L .25306 .49655 L F
.25283 .49634 m .25306 .49655 L .25356 .49566 L F
.25347 .49493 m .25318 .49547 L .25358 .49495 L F
.25318 .49547 m .24496 .5109 L .25327 .49552 L F
.25318 .49547 m .25327 .49552 L .25358 .49495 L F
.25234 .49482 m .24496 .5109 L .25347 .49493 L F
.25275 .49479 m .25347 .49493 L .25359 .49471 L F
.25234 .49482 m .25347 .49493 L .25275 .49479 L F
.25002 .50455 m .25054 .51166 L .25302 .512 L F
.25368 .49189 m .24341 .50243 L .24496 .5109 L F
.24341 .50243 m .2375 .50849 L .23974 .50922 L F
.24341 .50243 m .23974 .50922 L .24496 .5109 L F
.24921 .47978 m .24922 .49288 L .24914 .49273 L .989 .721 .393 r
F
.24915 .47896 m .24909 .49212 L .24908 .49194 L .798 .638 .081 r
F
.24915 .47896 m .24914 .49273 L .24909 .49212 L F
.24921 .47978 m .24959 .48048 L .24952 .4934 L .989 .721 .393 r
F
.24967 .47793 m .24915 .47896 L .24908 .49194 L 0 0 .368 r
F
.24341 .50243 m .23113 .50496 L .2375 .50849 L .654 .726 .902 r
F
.25368 .49189 m .24702 .49576 L .24341 .50243 L F
.24702 .49576 m .23113 .50496 L .24341 .50243 L F
.25341 .50029 m .25002 .50455 L .25302 .512 L F
.25237 .51154 m .25233 .50912 L .25305 .51151 L .665 .425 .546 r
F
.24966 .51116 m .24445 .51827 L .25281 .5116 L .654 .726 .902 r
F
.24751 .51151 m .24852 .51101 L .25238 .51196 L .731 .477 .545 r
F
.24852 .51101 m .25233 .50912 L .25237 .51154 L F
.24852 .51101 m .25237 .51154 L .25238 .51196 L F
.25281 .5116 m .24445 .51827 L .25256 .51938 L .654 .726 .902 r
F
.25297 .50664 m .24966 .51116 L .25281 .5116 L F
.25261 .49628 m .25095 .49774 L .25256 .49789 L .675 .735 .895 r
F
.25152 .49455 m .25275 .49479 L .25274 .4963 L .751 .491 .539 r
F
.25152 .49455 m .25274 .4963 L .25178 .49615 L F
.2527 .49372 m .25164 .49613 L .25261 .49628 L .675 .735 .895 r
F
.25164 .49613 m .25095 .49774 L .25261 .49628 L F
.25095 .49774 m .25242 .50205 L .25256 .49789 L F
.25266 .4991 m .25098 .5006 L .25261 .50075 L F
.25178 .49615 m .25272 .49911 L .25225 .49904 L .751 .491 .539 r
F
.25274 .49657 m .2517 .49896 L .25266 .4991 L .675 .735 .895 r
F
.2517 .49896 m .25098 .5006 L .25266 .4991 L F
.25178 .49615 m .25274 .4963 L .25272 .49911 L .751 .491 .539 r
F
.25352 .49695 m .25248 .49865 L .25341 .50029 L .654 .726 .902 r
F
.25462 .49587 m .25302 .512 L .25498 .49535 L F
.25469 .49475 m .25302 .512 L .25474 .49472 L F
.25256 .49789 m .25242 .50205 L .25567 .50178 L .675 .735 .895 r
F
.25225 .49904 m .25272 .49911 L .25271 .50183 L .751 .491 .539 r
F
.2492 .50175 m .25229 .50621 L .25242 .50205 L .675 .735 .895 r
F
.25098 .5006 m .25247 .50494 L .25261 .50075 L F
.25313 .50191 m .25122 .50353 L .25297 .50664 L .654 .726 .902 r
F
.25205 .50171 m .25122 .50353 L .25313 .50191 L F
.2492 .50175 m .24745 .50576 L .25229 .50621 L .675 .735 .895 r
F
.24747 .50866 m .24742 .50582 L .25229 .50627 L .731 .477 .545 r
F
.24922 .50463 m .25233 .50912 L .25247 .50494 L .675 .735 .895 r
F
.25122 .50353 m .24963 .50698 L .25297 .50664 L .654 .726 .902 r
F
.24852 .51101 m .24747 .50866 L .25233 .50912 L .731 .477 .545 r
F
.24783 .51091 m .24445 .51827 L .24966 .51116 L .654 .726 .902 r
F
.24751 .51151 m .2475 .51087 L .24852 .51101 L .731 .477 .545 r
F
.2475 .51087 m .24747 .50866 L .24852 .51101 L F
.24963 .50698 m .24783 .51091 L .24992 .51081 L .654 .726 .902 r
F
.24783 .51091 m .24966 .51116 L .24992 .51081 L F
.24747 .50866 m .25229 .50627 L .25233 .50912 L .731 .477 .545 r
F
.24922 .50463 m .24747 .50866 L .25233 .50912 L .675 .735 .895 r
F
.24963 .50698 m .24992 .51081 L .25297 .50664 L .654 .726 .902 r
F
.25125 .48155 m .25152 .49455 L .25118 .49448 L .751 .491 .539 r
F
.25026 .48107 m .2504 .4941 L .25019 .494 L .844 .571 .525 r
F
.25026 .48107 m .25125 .48155 L .25118 .49448 L F
.25026 .48107 m .25118 .49448 L .2504 .4941 L F
.25368 .49189 m .24279 .49533 L .23113 .50496 L .654 .726 .902 r
F
.24279 .49533 m .2263 .50054 L .22973 .50368 L F
.24279 .49533 m .22973 .50368 L .23113 .50496 L F
.25079 .47714 m .24967 .47793 L .2496 .49098 L .398 .209 .505 r
F
.24982 .49558 m .24721 .49578 L .24818 .49664 L .675 .735 .895 r
F
.2504 .4941 m .25118 .49448 L .25117 .49606 L .844 .571 .525 r
F
.2442 .50981 m .24279 .51055 L .2478 .51097 L .654 .726 .902 r
F
.243 .51023 m .2442 .50981 L .24751 .51151 L .794 .529 .537 r
F
.2442 .50981 m .24747 .50866 L .2475 .51087 L F
.2442 .50981 m .2475 .51087 L .24751 .51151 L F
.2478 .51097 m .24279 .51055 L .24445 .51827 L .654 .726 .902 r
F
.24963 .50698 m .2442 .50981 L .2478 .51097 L F
.25122 .50353 m .24948 .50497 L .24963 .50698 L F
.24296 .50738 m .24742 .50582 L .24747 .50866 L .794 .529 .537 r
F
.24622 .50378 m .24747 .50866 L .24922 .50463 L .675 .735 .895 r
F
.24948 .50497 m .24279 .51055 L .24963 .50698 L .654 .726 .902 r
F
.24918 .49504 m .24662 .49477 L .24721 .49578 L .675 .735 .895 r
F
.25098 .5006 m .24922 .50463 L .25247 .50494 L F
.25098 .50311 m .24945 .5045 L .25122 .50353 L .654 .726 .902 r
F
.24945 .5045 m .24279 .51055 L .24948 .50497 L F
.24945 .5045 m .24948 .50497 L .25122 .50353 L F
.24946 .49493 m .24721 .49578 L .24982 .49558 L .675 .735 .895 r
F
.24833 .49575 m .24736 .49445 L .2467 .49545 L F
.25028 .49639 m .24818 .49664 L .24945 .49731 L F
.24928 .49462 m .2495 .49784 L .24939 .49764 L .989 .721 .393 r
F
.24922 .49288 m .24932 .49469 L .24928 .49462 L F
.24932 .49469 m .2495 .49784 L .24928 .49462 L F
.2504 .4941 m .25117 .49606 L .25042 .49572 L .844 .571 .525 r
F
.2527 .49372 m .24982 .49558 L .25028 .49639 L .675 .735 .895 r
F
.24982 .49558 m .24818 .49664 L .25028 .49639 L F
.24945 .49731 m .2492 .50175 L .25095 .49774 L F
.24945 .49731 m .2462 .5009 L .2492 .50175 L F
.24984 .49845 m .24723 .49863 L .2482 .4995 L F
.2527 .49372 m .24945 .49731 L .25095 .49774 L F
.25042 .49572 m .25117 .49606 L .25115 .49887 L .844 .571 .525 r
F
.25082 .50163 m .25039 .50207 L .25172 .50244 L .654 .726 .902 r
F
.25039 .50207 m .25095 .50306 L .25172 .50244 L F
.24296 .50738 m .24291 .50454 L .24742 .50582 L .794 .529 .537 r
F
.24622 .50378 m .24296 .50738 L .24747 .50866 L .675 .735 .895 r
F
.24362 .50902 m .24334 .50953 L .25172 .50244 L .654 .726 .902 r
F
.24334 .50953 m .24279 .51055 L .24376 .50967 L F
.2442 .50981 m .24296 .50738 L .24747 .50866 L .794 .529 .537 r
F
.24334 .50953 m .24376 .50967 L .25172 .50244 L .654 .726 .902 r
F
.243 .51023 m .24299 .50942 L .2442 .50981 L .794 .529 .537 r
F
.24299 .50942 m .24296 .50738 L .2442 .50981 L F
.2495 .49784 m .24723 .49863 L .24984 .49845 L .675 .735 .895 r
F
.24947 .49779 m .24945 .4978 L .2495 .49784 L F
.24818 .49664 m .2462 .5009 L .24945 .49731 L F
.24945 .4978 m .24723 .49863 L .2495 .49784 L F
.25067 .49886 m .2482 .4995 L .24948 .50018 L F
.25274 .49657 m .25004 .49831 L .25067 .49886 L F
.25004 .49831 m .2482 .4995 L .25067 .49886 L F
.25001 .49546 m .24972 .49539 L .24995 .4955 L F
.2527 .49372 m .24985 .49532 L .25001 .49546 L F
.24985 .49532 m .24972 .49539 L .25001 .49546 L F
.24967 .49354 m .25019 .494 L .25018 .4956 L .927 .648 .491 r
F
.24985 .49532 m .25018 .4956 L .25016 .49842 L F
.24967 .49354 m .25018 .4956 L .24985 .49532 L F
.2462 .5009 m .24745 .50576 L .2492 .50175 L .675 .735 .895 r
F
.2462 .5009 m .24296 .50448 L .24745 .50576 L F
.24034 .50795 m .23912 .50537 L .24296 .50738 L .86 .586 .521 r
F
.24034 .50795 m .24296 .50738 L .24299 .50942 L F
.24366 .50244 m .24296 .50738 L .24622 .50378 L .675 .735 .895 r
F
.24638 .5039 m .23956 .50752 L .24362 .50902 L .654 .726 .902 r
F
.23956 .50752 m .23055 .5123 L .24268 .50925 L F
.23956 .50752 m .24268 .50925 L .24362 .50902 L F
.23916 .50821 m .24034 .50795 L .243 .51023 L .86 .586 .521 r
F
.24034 .50795 m .24299 .50942 L .243 .51023 L F
.23916 .50821 m .23915 .50729 L .24034 .50795 L F
.23915 .50729 m .23912 .50537 L .24034 .50795 L F
.25095 .49774 m .2492 .50175 L .25242 .50205 L .675 .735 .895 r
F
.24948 .50018 m .24922 .50463 L .25098 .5006 L F
.24948 .50018 m .24622 .50378 L .24922 .50463 L F
.25006 .501 m .23917 .50731 L .25075 .50158 L .654 .726 .902 r
F
.23917 .50731 m .23055 .5123 L .23956 .50752 L F
.23912 .50537 m .24291 .50454 L .24296 .50738 L .86 .586 .521 r
F
.24366 .50244 m .23912 .50537 L .24296 .50738 L .675 .735 .895 r
F
.23917 .50731 m .23956 .50752 L .25075 .50158 L .654 .726 .902 r
F
.25015 .50104 m .25075 .50158 L .25099 .50146 L F
.25006 .501 m .25075 .50158 L .25015 .50104 L F
.25 .49834 m .2497 .49821 L .24984 .49845 L .675 .735 .895 r
F
.24969 .49801 m .25016 .49842 L .25015 .50104 L .927 .648 .491 r
F
.25082 .50163 m .24638 .5039 L .24362 .50902 L .654 .726 .902 r
F
.25099 .50146 m .25075 .50158 L .25082 .50163 L F
.25075 .50158 m .24638 .5039 L .25082 .50163 L F
.24967 .49354 m .24971 .50065 L .24952 .4934 L .927 .648 .491 r
F
.25254 .51298 m .24399 .52554 L .25209 .52666 L .654 .726 .902 r
F
.25183 .51172 m .24399 .52554 L .25254 .51298 L F
.24927 .50748 m .24751 .51151 L .25238 .51196 L .675 .735 .895 r
F
.25145 .50928 m .24955 .51343 L .25263 .51032 L .654 .726 .902 r
F
.24955 .51343 m .24399 .52554 L .2497 .51547 L F
.24955 .51343 m .2497 .51547 L .25263 .51032 L F
.25039 .50207 m .24362 .50902 L .25095 .50306 L F
.24953 .50302 m .24627 .50663 L .24927 .50748 L .675 .735 .895 r
F
.24904 .49899 m .24901 .50618 L .249 .50603 L .798 .638 .081 r
F
.24923 .49736 m .24948 .50045 L .24923 .5 L .989 .721 .393 r
F
.24939 .49764 m .24948 .50045 L .24923 .49736 L F
.25274 .49657 m .24948 .50018 L .25098 .5006 L .675 .735 .895 r
F
.25045 .49855 m .25114 .50153 L .25048 .50121 L .844 .571 .525 r
F
.2504 .4941 m .25048 .50121 L .25019 .494 L F
.24955 .51343 m .24303 .51707 L .24399 .52554 L .654 .726 .902 r
F
.25145 .50928 m .24938 .51119 L .24955 .51343 L F
.24938 .51119 m .24303 .51707 L .24955 .51343 L F
.23912 .50537 m .23907 .50252 L .24291 .50454 L .86 .586 .521 r
F
.23917 .50731 m .23786 .50612 L .23055 .5123 L .654 .726 .902 r
F
.23625 .5056 m .23721 .50552 L .23916 .50821 L .932 .65 .484 r
F
.23721 .50552 m .23912 .50537 L .23915 .50729 L F
.23721 .50552 m .23915 .50729 L .23916 .50821 L F
.24366 .49956 m .23914 .50248 L .24296 .50448 L .675 .735 .895 r
F
.25006 .501 m .24085 .50359 L .23786 .50612 L .654 .726 .902 r
F
.25006 .501 m .23786 .50612 L .23917 .50731 L F
.24085 .50359 m .22569 .50786 L .22918 .51105 L F
.24085 .50359 m .22918 .51105 L .23055 .5123 L F
.24995 .4955 m .24972 .49539 L .24982 .49558 L .675 .735 .895 r
F
.24959 .48048 m .25019 .494 L .24967 .49354 L .927 .648 .491 r
F
.24959 .48048 m .24967 .49354 L .24952 .4934 L F
.24921 .47978 m .24952 .4934 L .24922 .49288 L .989 .721 .393 r
F
.25125 .48155 m .25275 .49479 L .25152 .49455 L .751 .491 .539 r
F
.2469 .49271 m .22243 .49026 L .22333 .49552 L .654 .726 .902 r
F
.25368 .49189 m .24858 .49163 L .2469 .49271 L F
.24858 .49163 m .22243 .49026 L .2469 .49271 L F
.24366 .49956 m .24296 .50448 L .2462 .5009 L .675 .735 .895 r
F
.2362 .50275 m .23907 .50252 L .23912 .50537 L .932 .65 .484 r
F
.2362 .50275 m .23616 .49991 L .23907 .50252 L F
.24171 .50069 m .23912 .50537 L .24366 .50244 L .675 .735 .895 r
F
.24171 .50069 m .2362 .50275 L .23912 .50537 L F
.23462 .5019 m .22271 .50282 L .23619 .50455 L .654 .726 .902 r
F
.23446 .50256 m .23505 .50263 L .23625 .5056 L .987 .713 .39 r
F
.23505 .50263 m .2362 .50275 L .23623 .50462 L F
.23505 .50263 m .23623 .50462 L .23625 .5056 L F
.23619 .50455 m .22271 .50282 L .22569 .50786 L .654 .726 .902 r
F
.2478 .50088 m .23462 .5019 L .23619 .50455 L F
.25067 .50859 m .2493 .50999 L .25145 .50928 L F
.24922 .50172 m .24728 .50148 L .24825 .50235 L .675 .735 .895 r
F
.25048 .50121 m .2503 .50112 L .25019 .494 L .844 .571 .525 r
F
.25322 .49917 m .24903 .50049 L .25006 .501 L .654 .726 .902 r
F
.25279 .49942 m .24915 .50078 L .24922 .50172 L .675 .735 .895 r
F
.2482 .4995 m .24622 .50378 L .24948 .50018 L F
.2482 .4995 m .24366 .50244 L .24622 .50378 L F
.24903 .50049 m .23616 .50455 L .25006 .501 L .654 .726 .902 r
F
.23616 .50455 m .22569 .50786 L .23646 .50483 L F
.23616 .50455 m .23646 .50483 L .25006 .501 L F
.23721 .50552 m .2362 .50275 L .23912 .50537 L .932 .65 .484 r
F
.23625 .5056 m .23623 .50462 L .23721 .50552 L F
.23623 .50462 m .2362 .50275 L .23721 .50552 L F
.24915 .50078 m .24728 .50148 L .24922 .50172 L .675 .735 .895 r
F
.25167 .50163 m .2515 .5016 L .25118 .49448 L .751 .491 .539 r
F
.25368 .49189 m .23659 .49394 L .2263 .50054 L .654 .726 .902 r
F
.23659 .49394 m .22333 .49552 L .22429 .49714 L F
.23659 .49394 m .22429 .49714 L .2263 .50054 L F
.25189 .47681 m .25079 .47714 L .25072 .49026 L .567 .342 .533 r
F
.2515 .5016 m .25138 .50158 L .25118 .49448 L .751 .491 .539 r
F
.24961 .49251 m .24837 .49076 L .24734 .49161 L .675 .735 .895 r
F
.2527 .49372 m .25025 .49205 L .24961 .49251 L F
.24909 .49212 m .24914 .49273 L .24913 .49434 L .798 .638 .081 r
F
.24948 .49119 m .24908 .49194 L .24907 .49354 L 0 0 .368 r
F
.24905 .49635 m .24905 .49911 L .24904 .49899 L .798 .638 .081 r
F
.24913 .49434 m .24662 .49477 L .24918 .49504 L .675 .735 .895 r
F
.24908 .49194 m .24906 .49643 L .24905 .49635 L .798 .638 .081 r
F
.24923 .5 m .24916 .49988 L .24915 .49722 L .989 .721 .393 r
F
.24919 .4973 m .24915 .49722 L .24914 .49273 L F
.24923 .5 m .24915 .49722 L .24919 .4973 L F
.24934 .49756 m .24663 .49762 L .247 .49824 L .675 .735 .895 r
F
.25274 .49657 m .24913 .49719 L .24934 .49756 L F
.24913 .49719 m .24663 .49762 L .24934 .49756 L F
.2479 .49838 m .247 .49824 L .24723 .49863 L F
.25274 .49657 m .24828 .49787 L .24804 .49833 L F
.24942 .49563 m .24904 .49899 L .24938 .49835 L 0 0 .368 r
F
.24922 .49288 m .24952 .4934 L .24951 .49503 L .989 .721 .393 r
F
.24932 .49469 m .24951 .49503 L .2495 .49784 L F
.24922 .49288 m .24951 .49503 L .24932 .49469 L F
.2527 .49372 m .24913 .49434 L .24913 .49434 L .675 .735 .895 r
F
.24946 .49493 m .24913 .49434 L .24918 .49504 L F
.2527 .49372 m .24913 .49434 L .24946 .49493 L F
.24862 .49442 m .24644 .49369 L .24662 .49477 L F
.24922 .49451 m .24916 .4944 L .24914 .49273 L .989 .721 .393 r
F
.2527 .49372 m .24898 .4937 L .24862 .49442 L .675 .735 .895 r
F
.24898 .4937 m .24644 .49369 L .24862 .49442 L F
.24946 .49277 m .24921 .49605 L .24942 .49563 L 0 0 .368 r
F
.24948 .49119 m .24939 .49292 L .24946 .49277 L F
.24939 .49292 m .24921 .49605 L .24946 .49277 L F
.24967 .49354 m .25016 .49842 L .24969 .49801 L .927 .648 .491 r
F
.25274 .49657 m .24907 .49655 L .24911 .49719 L .675 .735 .895 r
F
.24922 .49288 m .24939 .49764 L .24923 .49736 L .989 .721 .393 r
F
.24922 .49451 m .24923 .49736 L .24916 .4944 L F
.24923 .49736 m .24923 .5 L .24919 .4973 L F
.24923 .49736 m .24919 .4973 L .24916 .4944 L F
.24721 .49578 m .24366 .49956 L .24818 .49664 L .675 .735 .895 r
F
.24877 .49655 m .2467 .49545 L .24645 .49653 L F
.24952 .4934 m .24956 .4979 L .2495 .49784 L .927 .648 .491 r
F
.24907 .49655 m .24884 .49585 L .24877 .49655 L .675 .735 .895 r
F
.24909 .49386 m .24911 .49716 L .2491 .49692 L .798 .638 .081 r
F
.25274 .49657 m .24902 .49588 L .24907 .49655 L .675 .735 .895 r
F
.24902 .49588 m .24884 .49585 L .24907 .49655 L F
.24909 .49386 m .24913 .49434 L .24911 .49716 L .798 .638 .081 r
F
.2491 .49692 m .24911 .49716 L .2491 .49977 L F
.25036 .49477 m .24956 .49802 L .25029 .49755 L .398 .209 .505 r
F
.2527 .49372 m .24961 .49251 L .24888 .49302 L .675 .735 .895 r
F
.24792 .4937 m .24669 .49261 L .24644 .49369 L F
.24967 .47793 m .24908 .49194 L .24948 .49119 L 0 0 .368 r
F
.25162 .49894 m .25167 .50163 L .25149 .49892 L .751 .491 .539 r
F
.2495 .49784 m .24958 .50054 L .24948 .50045 L .927 .648 .491 r
F
.25322 .49917 m .24818 .49891 L .24715 .49956 L .654 .726 .902 r
F
.24818 .49664 m .24366 .49956 L .2462 .5009 L .675 .735 .895 r
F
.24723 .49863 m .24366 .50244 L .2482 .4995 L F
.24769 .49983 m .24715 .49956 L .24651 .49997 L .654 .726 .902 r
F
.25322 .49917 m .24715 .49956 L .24769 .49983 L F
.24279 .51055 m .23948 .51667 L .24445 .51827 L F
.24279 .51055 m .23695 .51585 L .23948 .51667 L F
.25001 .50804 m .24696 .5098 L .25082 .50844 L F
.24696 .5098 m .23008 .51958 L .24643 .5108 L F
.24627 .50663 m .24751 .51151 L .24927 .50748 L .675 .735 .895 r
F
.24696 .5098 m .24643 .5108 L .25082 .50844 L .654 .726 .902 r
F
.24922 .50172 m .24931 .50291 L .24953 .50302 L .675 .735 .895 r
F
.24923 .5 m .24948 .50045 L .24944 .5075 L .989 .721 .393 r
F
.24969 .49801 m .25015 .50104 L .24971 .50065 L .927 .648 .491 r
F
.25045 .49855 m .25115 .49887 L .25114 .50153 L .844 .571 .525 r
F
.25152 .49455 m .25271 .50183 L .25167 .50163 L .751 .491 .539 r
F
.25322 .49917 m .24651 .49997 L .2478 .50088 L .654 .726 .902 r
F
.25279 .49942 m .24668 .50047 L .24728 .50148 L .675 .735 .895 r
F
.24948 .49817 m .24936 .50537 L .24956 .49802 L 0 0 .368 r
F
.24971 .50065 m .24971 .50085 L .24958 .50054 L .927 .648 .491 r
F
.24953 .50302 m .24927 .50748 L .25103 .50345 L .675 .735 .895 r
F
.24971 .50085 m .24975 .50777 L .24959 .50075 L .927 .648 .491 r
F
.24971 .50085 m .24959 .50075 L .24958 .50054 L F
.25149 .5024 m .24953 .50302 L .25103 .50345 L .675 .735 .895 r
F
.25322 .49917 m .25082 .50163 L .25172 .50244 L .654 .726 .902 r
F
.25279 .49942 m .25071 .50172 L .25149 .5024 L .675 .735 .895 r
F
.25071 .50172 m .24953 .50302 L .25149 .5024 L F
.24971 .50065 m .24958 .50054 L .24952 .4934 L .927 .648 .491 r
F
.25029 .49755 m .24956 .49802 L .24952 .50507 L .398 .209 .505 r
F
.24362 .50902 m .23055 .5123 L .23695 .51585 L .654 .726 .902 r
F
.24911 .5076 m .22522 .51513 L .24979 .5081 L F
.24927 .50748 m .25238 .51196 L .25252 .50778 L .675 .735 .895 r
F
.24965 .50786 m .24979 .5081 L .25001 .50804 L .654 .726 .902 r
F
.24911 .5076 m .24979 .5081 L .24965 .50786 L F
.24362 .50902 m .23695 .51585 L .24279 .51055 L F
.24627 .50663 m .243 .51023 L .24751 .51151 L .675 .735 .895 r
F
.25001 .50804 m .24071 .5107 L .23008 .51958 L .654 .726 .902 r
F
.25029 .49755 m .25012 .50469 L .2505 .49742 L .398 .209 .505 r
F
.25103 .50345 m .24927 .50748 L .25252 .50778 L .675 .735 .895 r
F
.25015 .50104 m .25029 .50818 L .25011 .50809 L .844 .571 .525 r
F
.2493 .50999 m .24937 .51101 L .25145 .50928 L .654 .726 .902 r
F
.24937 .51105 m .24938 .51119 L .25079 .50989 L F
.24975 .50777 m .25011 .50809 L .24994 .5397 L .927 .648 .491 r
F
.23393 .5087 m .22133 .50481 L .22224 .5101 L .654 .726 .902 r
F
.25041 .50824 m .25093 .54018 L .25029 .50818 L .844 .571 .525 r
F
.25011 .50809 m .25093 .54018 L .24994 .5397 L F
.25029 .50818 m .25093 .54018 L .25011 .50809 L F
.2506 .51142 m .25093 .54018 L .25057 .51771 L F
.24383 .5156 m .25079 .50989 L .25077 .50985 L .654 .726 .902 r
F
.24176 .50354 m .23916 .50821 L .2437 .50528 L .675 .735 .895 r
F
.24607 .5061 m .22257 .49963 L .22133 .50481 L .654 .726 .902 r
F
.25042 .49572 m .25115 .49887 L .25045 .49855 L .844 .571 .525 r
F
.25274 .49657 m .2497 .49821 L .25 .49834 L .675 .735 .895 r
F
.24906 .49925 m .2491 .49977 L .2491 .49997 L .798 .638 .081 r
F
.24906 .49925 m .2491 .49997 L .24906 .49945 L F
.25279 .49942 m .2465 .49938 L .24668 .50047 L .675 .735 .895 r
F
.2514 .49712 m .25068 .49731 L .25064 .50436 L .567 .342 .533 r
F
.25085 .50156 m .24922 .50172 L .24953 .50302 L .675 .735 .895 r
F
.25048 .50121 m .25114 .50153 L .25114 .50169 L .844 .571 .525 r
F
.25048 .50121 m .25114 .50169 L .2505 .50139 L F
.25304 .49936 m .25006 .501 L .25099 .50146 L .654 .726 .902 r
F
.25261 .50075 m .25247 .50494 L .25573 .50467 L .675 .735 .895 r
F
.25313 .50179 m .25256 .51938 L .25417 .5017 L .654 .726 .902 r
F
.25363 .49899 m .25261 .50075 L .25424 .50062 L .675 .735 .895 r
F
.25256 .49789 m .25567 .50178 L .25418 .49775 L F
.25319 .49905 m .25295 .49908 L .25282 .49629 L .641 .401 .539 r
F
.2529 .49628 m .25282 .49629 L .25275 .49479 L F
.25356 .49566 m .25306 .49655 L .25352 .49695 L .654 .726 .902 r
F
.25261 .49632 m .25256 .49789 L .2536 .49618 L .675 .735 .895 r
F
.25319 .49905 m .25282 .49629 L .2529 .49628 L .641 .401 .539 r
F
.2536 .49618 m .25256 .49789 L .25418 .49775 L .675 .735 .895 r
F
.2531 .49476 m .25319 .49905 L .25275 .49479 L .641 .401 .539 r
F
.2527 .49372 m .25261 .49632 L .2536 .49618 L .675 .735 .895 r
F
.25274 .49657 m .25266 .49912 L .25363 .49899 L F
.25266 .49912 m .25261 .50075 L .25363 .49899 L F
.25242 .50205 m .25716 .50581 L .25567 .50178 L F
.25367 .50179 m .25265 .5036 L .25429 .50347 L F
.25325 .50185 m .25308 .50188 L .25308 .5018 L .641 .401 .539 r
F
.25261 .50075 m .25573 .50467 L .25424 .50062 L .675 .735 .895 r
F
.25325 .50178 m .25308 .5018 L .25295 .49908 L .641 .401 .539 r
F
.25325 .50185 m .25308 .5018 L .25325 .50178 L F
.25322 .49917 m .25205 .50171 L .25271 .50183 L .654 .726 .902 r
F
.25313 .50179 m .25271 .50183 L .25313 .50191 L F
.25319 .49905 m .25325 .50185 L .25295 .49908 L .641 .401 .539 r
F
.25271 .50193 m .25265 .5036 L .25367 .50179 L .675 .735 .895 r
F
.25247 .50494 m .25723 .50872 L .25573 .50467 L F
.25418 .50173 m .25392 .51149 L .25566 .50567 L .654 .726 .902 r
F
.25265 .5036 m .25578 .50752 L .25429 .50347 L .675 .735 .895 r
F
.2534 .50881 m .25316 .50884 L .25275 .49479 L .641 .401 .539 r
F
.25322 .49917 m .25271 .50183 L .25313 .50179 L .654 .726 .902 r
F
.25275 .49479 m .25295 .50181 L .25271 .50183 L .641 .401 .539 r
F
.25279 .49942 m .25271 .50193 L .25367 .50179 L .675 .735 .895 r
F
.25325 .50185 m .2534 .50881 L .25308 .50188 L .641 .401 .539 r
F
.25392 .51149 m .25371 .51934 L .25483 .51146 L .654 .726 .902 r
F
.25238 .51196 m .25305 .51151 L .25728 .51156 L .665 .425 .546 r
F
.25612 .4806 m .25655 .47991 L .25648 .4931 L .065 0 .408 r
F
.25567 .49431 m .26113 .51174 L .26494 .51093 L .654 .726 .902 r
F
.25963 .49911 m .26494 .51093 L .26873 .51013 L F
.25567 .49431 m .26494 .51093 L .25963 .49911 L F
.25666 .4791 m .25621 .47805 L .25614 .49131 L .986 .729 .348 r
F
.25467 .49452 m .26113 .51174 L .25557 .49418 L .654 .726 .902 r
F
.25567 .50178 m .25591 .50244 L .25658 .5022 L .675 .735 .895 r
F
.25591 .50244 m .25716 .50581 L .25658 .5022 L F
.25658 .5022 m .25716 .50581 L .26173 .50459 L F
.25424 .50062 m .25573 .50467 L .25879 .50385 L F
.25582 .50306 m .26149 .50538 L .25714 .5024 L F
.25563 .49438 m .26113 .51174 L .25567 .49431 L .654 .726 .902 r
F
.25622 .49497 m .26873 .51013 L .25638 .49381 L F
.25606 .49505 m .25702 .49669 L .25805 .49584 L .675 .735 .895 r
F
.2547 .49461 m .25469 .49475 L .25474 .49472 L .654 .726 .902 r
F
.25456 .49456 m .25535 .49426 L .25534 .49563 L .515 .301 .526 r
F
.25418 .49775 m .25872 .50097 L .25571 .49735 L .675 .735 .895 r
F
.25474 .49472 m .25462 .49587 L .25498 .49535 L .654 .726 .902 r
F
.25456 .49456 m .25534 .49563 L .25471 .49591 L .515 .301 .526 r
F
.25418 .49775 m .25567 .50178 L .25872 .50097 L .675 .735 .895 r
F
.25638 .49381 m .2753 .50727 L .25648 .4931 L .654 .726 .902 r
F
.25767 .49473 m .26873 .51013 L .2753 .50727 L F
.25854 .49666 m .26873 .51013 L .25767 .49473 L F
.26579 .50552 m .26574 .50267 L .26883 .50009 L .354 .183 .506 r
F
.26579 .50552 m .26883 .50009 L .26887 .50294 L F
.25872 .50097 m .26173 .50459 L .26568 .50263 L .675 .735 .895 r
F
.26182 .50749 m .26574 .50267 L .26579 .50552 L .495 .291 .533 r
F
.26144 .50254 m .26579 .50552 L .26887 .50294 L .675 .735 .895 r
F
.26892 .50578 m .26887 .50294 L .27086 .49992 L .108 .001 .438 r
F
.25872 .50097 m .26568 .50263 L .26135 .49966 L .675 .735 .895 r
F
.26144 .50254 m .26887 .50294 L .2635 .50082 L F
.25709 .49955 m .26144 .50254 L .2635 .50082 L F
.26584 .50836 m .26579 .50552 L .26887 .50294 L .354 .183 .506 r
F
.26355 .50366 m .26892 .50578 L .27091 .50277 L .675 .735 .895 r
F
.26892 .50578 m .27086 .49992 L .27091 .50277 L .108 .001 .438 r
F
.26355 .50366 m .27091 .50277 L .26487 .50165 L .675 .735 .895 r
F
.25817 .50154 m .26355 .50366 L .26487 .50165 L F
.25817 .50154 m .26487 .50165 L .25883 .50053 L F
.25648 .49991 m .28008 .5107 L .28338 .50599 L .654 .726 .902 r
F
.25548 .51371 m .25364 .52661 L .26024 .52639 L F
.25638 .49381 m .25854 .49666 L .25767 .49473 L F
.25647 .49442 m .25805 .49584 L .2587 .49484 L .675 .735 .895 r
F
.25542 .48117 m .25551 .49414 L .25535 .49426 L .353 .175 .495 r
F
.25368 .49189 m .25622 .49497 L .25638 .49381 L .654 .726 .902 r
F
.25605 .49374 m .25606 .49504 L .25605 .49506 L .065 0 .408 r
F
.25557 .49418 m .25563 .49438 L .25567 .49431 L .654 .726 .902 r
F
.25551 .49414 m .25605 .49374 L .25605 .49506 L .353 .175 .495 r
F
.25551 .49414 m .25605 .49506 L .25561 .49542 L F
.25615 .4949 m .25608 .49502 L .25605 .49374 L .065 0 .408 r
F
.2527 .49372 m .25637 .49517 L .25647 .49442 L .675 .735 .895 r
F
.25637 .49517 m .25805 .49584 L .25647 .49442 L F
.25571 .49735 m .25872 .50097 L .26135 .49966 L F
.25635 .49799 m .25709 .49955 L .25812 .49869 L F
.25561 .49854 m .25577 .50021 L .25709 .49955 L F
.25616 .50046 m .25608 .50059 L .25607 .49782 L .065 0 .408 r
F
.25563 .49573 m .25571 .49735 L .25702 .49669 L .675 .735 .895 r
F
.25612 .49774 m .25607 .49782 L .25605 .49374 L .065 0 .408 r
F
.25561 .49854 m .25622 .49895 L .25604 .49787 L .675 .735 .895 r
F
.25543 .4956 m .25582 .49543 L .25606 .49505 L F
.25561 .49542 m .25605 .49506 L .25603 .49788 L .353 .175 .495 r
F
.25581 .49806 m .25603 .49788 L .25602 .50079 L F
.25543 .4956 m .25563 .49573 L .25582 .49543 L .675 .735 .895 r
F
.25561 .49542 m .25603 .49788 L .25581 .49806 L .353 .175 .495 r
F
.25616 .50046 m .25607 .49782 L .25612 .49774 L .065 0 .408 r
F
.2554 .49839 m .25547 .49876 L .25561 .49854 L .675 .735 .895 r
F
.25547 .49876 m .25577 .50021 L .25561 .49854 L F
.25359 .49471 m .25347 .49493 L .25358 .49495 L .654 .726 .902 r
F
.2531 .49476 m .25433 .49465 L .25433 .49608 L .641 .401 .539 r
F
.25458 .49878 m .25424 .50062 L .25577 .50021 L .675 .735 .895 r
F
.2531 .49476 m .25431 .49889 L .25319 .49905 L .641 .401 .539 r
F
.25274 .49657 m .2537 .49916 L .25458 .49878 L .675 .735 .895 r
F
.2537 .49916 m .25424 .50062 L .25458 .49878 L F
.25432 .5006 m .25879 .50385 L .25577 .50021 L F
.25424 .50062 m .25428 .50065 L .25432 .5006 L F
.25428 .50065 m .25879 .50385 L .25432 .5006 L F
.25616 .49366 m .25638 .49381 L .25643 .49346 L .654 .726 .902 r
F
.25616 .49366 m .25643 .49346 L .25648 .4931 L F
.25615 .4936 m .25648 .4931 L .25646 .4972 L .065 0 .408 r
F
.25604 .49787 m .25622 .49895 L .25635 .49799 L .675 .735 .895 r
F
.25567 .50178 m .26173 .50459 L .25872 .50097 L F
.25577 .50021 m .25879 .50385 L .26144 .50254 L F
.25577 .50021 m .26144 .50254 L .25709 .49955 L F
.25753 .50029 m .25817 .50154 L .25883 .50053 L F
.25448 .49882 m .25464 .50155 L .25431 .49889 L .515 .301 .526 r
F
.25533 .49845 m .25542 .50123 L .25531 .50131 L .353 .175 .495 r
F
.25622 .49895 m .25709 .49955 L .25635 .49799 L .675 .735 .895 r
F
.25616 .49768 m .25646 .4972 L .25644 .50015 L .065 0 .408 r
F
.25755 .51132 m .25723 .50872 L .26182 .50749 L .591 .366 .543 r
F
.25728 .51156 m .25727 .51138 L .25755 .51132 L F
.25727 .51138 m .25723 .50872 L .25755 .51132 L F
.26059 .51067 m .2607 .51912 L .26501 .5182 L .654 .726 .902 r
F
.25723 .50872 m .25718 .50587 L .26177 .50464 L .591 .366 .543 r
F
.25723 .50872 m .26177 .50464 L .26182 .50749 L F
.25573 .50467 m .25723 .50872 L .26182 .50749 L .675 .735 .895 r
F
.26069 .51065 m .26182 .50749 L .26187 .51034 L .591 .366 .543 r
F
.25825 .51117 m .2607 .51912 L .26059 .51067 L .654 .726 .902 r
F
.25728 .51156 m .25755 .51132 L .26069 .51065 L .591 .366 .543 r
F
.25755 .51132 m .26182 .50749 L .26069 .51065 L F
.25814 .50689 m .26187 .51034 L .25884 .5067 L .675 .735 .895 r
F
.25593 .50364 m .25825 .51117 L .25983 .50938 L .654 .726 .902 r
F
.25459 .50158 m .25582 .50306 L .25542 .50122 L .675 .735 .895 r
F
.25525 .50193 m .2607 .51912 L .25536 .50177 L .654 .726 .902 r
F
.2543 .50206 m .2607 .51912 L .25567 .50325 L F
.25468 .50178 m .25567 .50325 L .25511 .50146 L F
.2543 .50206 m .25567 .50325 L .25468 .50178 L F
.25429 .50347 m .25578 .50752 L .25814 .50689 L .675 .735 .895 r
F
.25724 .50556 m .25814 .50689 L .25884 .5067 L F
.25429 .50347 m .25814 .50689 L .25724 .50556 L F
.25578 .50752 m .25984 .5094 L .25814 .50689 L F
.25984 .5094 m .26187 .51034 L .25814 .50689 L F
.25429 .50347 m .25884 .5067 L .25582 .50306 L F
.25536 .50177 m .25983 .50938 L .26033 .50779 L .654 .726 .902 r
F
.25983 .50938 m .26059 .51067 L .26057 .51047 L F
.25983 .50938 m .26057 .51047 L .26033 .50779 L F
.26059 .51067 m .26501 .5182 L .26154 .51047 L F
.25984 .5094 m .26069 .51065 L .26187 .51034 L .675 .735 .895 r
F
.26059 .51067 m .26154 .51047 L .26033 .50779 L .654 .726 .902 r
F
.25983 .50938 m .25825 .51117 L .26059 .51067 L F
.25578 .50752 m .25728 .51156 L .26069 .51065 L .675 .735 .895 r
F
.25578 .50752 m .26069 .51065 L .25984 .5094 L F
.25573 .50467 m .26182 .50749 L .25879 .50385 L F
.25536 .50177 m .25593 .50364 L .25983 .50938 L .654 .726 .902 r
F
.26033 .50779 m .26501 .5182 L .26834 .51749 L F
.25563 .49573 m .25702 .49669 L .25606 .49505 L .675 .735 .895 r
F
.25615 .4949 m .25616 .49768 L .25608 .49502 L .065 0 .408 r
F
.25616 .49768 m .25616 .50046 L .25612 .49774 L F
.25616 .49768 m .25612 .49774 L .25608 .49502 L F
.25702 .49669 m .26135 .49966 L .2634 .49795 L .675 .735 .895 r
F
.25684 .49659 m .25878 .49769 L .25903 .49661 L F
.25534 .49563 m .25539 .49839 L .25533 .49845 L .353 .175 .495 r
F
.25535 .49426 m .25537 .49562 L .25534 .49563 L F
.25471 .49615 m .25571 .49735 L .25541 .49558 L .675 .735 .895 r
F
.25537 .49562 m .25539 .49839 L .25534 .49563 L .353 .175 .495 r
F
.25471 .49615 m .25418 .49775 L .25571 .49735 L .675 .735 .895 r
F
.25358 .49495 m .25327 .49552 L .25356 .49566 L .654 .726 .902 r
F
.2531 .49476 m .25433 .49608 L .25352 .49619 L .641 .401 .539 r
F
.2527 .49372 m .25385 .49685 L .25471 .49615 L .675 .735 .895 r
F
.25385 .49685 m .25418 .49775 L .25471 .49615 L F
.25606 .49783 m .25606 .49783 L .25605 .49506 L .065 0 .408 r
F
.25606 .49504 m .25608 .50069 L .25605 .49506 L F
.25457 .49597 m .25462 .49604 L .25524 .49568 L .675 .735 .895 r
F
.25462 .49604 m .25471 .49615 L .25489 .496 L F
.25462 .49604 m .25489 .496 L .25541 .49558 L F
.25471 .49591 m .25534 .49563 L .25533 .49845 L .515 .301 .526 r
F
.25472 .49895 m .25577 .50021 L .2554 .49842 L .675 .735 .895 r
F
.25472 .49895 m .2554 .49842 L .25533 .49845 L F
.25501 .49859 m .25533 .49845 L .25531 .50126 L .515 .301 .526 r
F
.25471 .49591 m .25533 .49845 L .25501 .49859 L F
.25533 .49845 m .2554 .49842 L .2554 .49839 L .675 .735 .895 r
F
.25648 .49988 m .25646 .50003 L .25647 .49713 L 0 0 .125 r
F
.25352 .49619 m .25433 .49608 L .25431 .49889 L .641 .401 .539 r
F
.25571 .49735 m .26135 .49966 L .25702 .49669 L .675 .735 .895 r
F
.257 .49736 m .25812 .49869 L .25878 .49769 L F
.25565 .49819 m .25602 .50079 L .25574 .50099 L .353 .175 .495 r
F
.25547 .49598 m .25571 .49735 L .25563 .49573 L .675 .735 .895 r
F
.25551 .49414 m .25581 .49806 L .25565 .49819 L .353 .175 .495 r
F
.25581 .49806 m .25602 .50079 L .25565 .49819 L F
.25673 .49731 m .25748 .49844 L .257 .49736 L .675 .735 .895 r
F
.25274 .49657 m .25604 .49787 L .25673 .49731 L F
.25646 .4972 m .25646 .50003 L .25644 .50015 L 0 0 .125 r
F
.25648 .4931 m .25647 .49713 L .25646 .4972 L F
.25647 .49713 m .25646 .50003 L .25646 .4972 L F
.25641 .49757 m .25748 .49844 L .25673 .49731 L .675 .735 .895 r
F
.25604 .49787 m .25635 .49799 L .25641 .49757 L F
.25635 .49799 m .25748 .49844 L .25641 .49757 L F
.25748 .49844 m .25812 .49869 L .257 .49736 L F
.25649 .49696 m .25657 .49639 L .25656 .49921 L 0 0 .125 r
F
.25539 .49839 m .25542 .50123 L .25533 .49845 L .353 .175 .495 r
F
.25463 .49885 m .25472 .49895 L .25488 .49881 L .675 .735 .895 r
F
.25461 .49876 m .25531 .50126 L .25464 .50155 L .515 .301 .526 r
F
.25456 .49456 m .25501 .49859 L .25461 .49876 L F
.25463 .49885 m .25488 .49881 L .25533 .49845 L .675 .735 .895 r
F
.25501 .49859 m .25531 .50126 L .25461 .49876 L .515 .301 .526 r
F
.25524 .49849 m .25533 .49845 L .2554 .49839 L .675 .735 .895 r
F
.25463 .49885 m .25533 .49845 L .25524 .49849 L F
.25709 .49955 m .2635 .50082 L .25812 .49869 L F
.25682 .49873 m .25908 .49945 L .2589 .49837 L F
.25279 .49942 m .25778 .49945 L .25682 .49873 L F
.25778 .49945 m .25908 .49945 L .25682 .49873 L F
.25602 .50069 m .25634 .50082 L .2567 .50014 L F
.25608 .50069 m .25608 .5007 L .25608 .5006 L .065 0 .408 r
F
.25608 .50059 m .25608 .5006 L .25606 .49783 L F
.25279 .49942 m .25602 .50069 L .2567 .50014 L .675 .735 .895 r
F
.25608 .50069 m .25608 .5006 L .25608 .50059 L .065 0 .408 r
F
.25681 .49944 m .25883 .50053 L .25908 .49945 L .675 .735 .895 r
F
.25616 .49768 m .25644 .50015 L .25616 .50057 L .065 0 .408 r
F
.25279 .49942 m .2564 .50008 L .25681 .49944 L .675 .735 .895 r
F
.2564 .50008 m .25883 .50053 L .25681 .49944 L F
.2556 .50135 m .25582 .50306 L .25714 .5024 L F
.25542 .50122 m .25548 .50154 L .2556 .50135 L F
.25548 .50154 m .25582 .50306 L .2556 .50135 L F
.25511 .50146 m .26033 .50779 L .25576 .50098 L .654 .726 .902 r
F
.25648 .49988 m .25646 .50684 L .25646 .50003 L 0 0 .125 r
F
.25596 .51034 m .26503 .52538 L .26103 .51648 L .654 .726 .902 r
F
.25392 .51149 m .25483 .51146 L .25566 .50567 L F
.25417 .5017 m .25327 .51151 L .25391 .51149 L F
.25252 .50778 m .25728 .51156 L .25578 .50752 L .675 .735 .895 r
F
.25504 .50923 m .25592 .51064 L .25596 .51034 L .654 .726 .902 r
F
.25592 .51064 m .26503 .52538 L .25596 .51034 L F
.25623 .50047 m .25638 .50058 L .25639 .50053 L F
.25637 .50053 m .25639 .50053 L .25639 .50051 L F
.25637 .50053 m .25639 .50051 L .25648 .49991 L F
.25616 .50057 m .25644 .50015 L .25641 .5072 L .065 0 .408 r
F
.26182 .50749 m .26177 .50464 L .26574 .50267 L .495 .291 .533 r
F
.25879 .50385 m .26182 .50749 L .26579 .50552 L .675 .735 .895 r
F
.25879 .50385 m .26579 .50552 L .26144 .50254 L F
.26584 .50836 m .26887 .50294 L .26892 .50578 L .354 .183 .506 r
F
.26149 .50538 m .26892 .50578 L .26355 .50366 L .675 .735 .895 r
F
.25602 .50069 m .25714 .5024 L .25817 .50154 L F
.25279 .49942 m .2556 .50135 L .25602 .50069 L F
.2556 .50135 m .25714 .5024 L .25602 .50069 L F
.25602 .50069 m .2561 .50765 L .25598 .50783 L .065 0 .408 r
F
.25605 .49506 m .25607 .5006 L .25602 .50069 L F
.25607 .5006 m .2561 .50765 L .25602 .50069 L F
.25585 .50104 m .27495 .51463 L .25623 .50047 L .654 .726 .902 r
F
.2564 .49902 m .2563 .50595 L .25648 .49922 L .986 .729 .348 r
F
.25305 .51151 m .25727 .51138 L .25728 .51156 L .665 .425 .546 r
F
.25504 .50923 m .26103 .51648 L .25557 .50845 L .654 .726 .902 r
F
.26103 .51648 m .26788 .52477 L .26017 .51455 L F
.26103 .51648 m .26017 .51455 L .25557 .50845 L F
.25238 .51196 m .25237 .51154 L .25305 .51151 L .665 .425 .546 r
F
.25252 .50778 m .25238 .51196 L .25728 .51156 L .675 .735 .895 r
F
.25386 .5094 m .25424 .51042 L .25468 .50879 L .654 .726 .902 r
F
.25646 .50003 m .25644 .50696 L .25644 .50015 L 0 0 .125 r
F
.25319 .49905 m .25431 .49889 L .25429 .50169 L .641 .401 .539 r
F
.25431 .49889 m .25464 .50156 L .25429 .50169 L .515 .301 .526 r
F
.25332 .49978 m .25459 .50158 L .25542 .50122 L .675 .735 .895 r
F
.25319 .49905 m .25429 .50169 L .25349 .50176 L .641 .401 .539 r
F
.2536 .50019 m .25313 .50179 L .25417 .5017 L .654 .726 .902 r
F
.25322 .49917 m .2532 .4996 L .2536 .50019 L F
.25417 .50174 m .25371 .51934 L .25418 .50173 L F
.25265 .5036 m .25252 .50778 L .25578 .50752 L .675 .735 .895 r
F
.25319 .49905 m .25426 .50874 L .2534 .50881 L .641 .401 .539 r
F
.2532 .4996 m .25313 .50179 L .2536 .50019 L .654 .726 .902 r
F
.2536 .50019 m .25417 .5017 L .25456 .5016 L F
.25417 .5017 m .2543 .50206 L .25486 .50164 L F
.25349 .50176 m .25429 .50169 L .25429 .50171 L .641 .401 .539 r
F
.25417 .5017 m .25417 .50174 L .25418 .50173 L .654 .726 .902 r
F
.25367 .50179 m .25429 .50347 L .2545 .50168 L .675 .735 .895 r
F
.2535 .50182 m .25429 .50171 L .25426 .50874 L .641 .401 .539 r
F
.25349 .50176 m .25429 .50171 L .2535 .50182 L F
.2545 .50168 m .25429 .50347 L .25558 .50312 L .675 .735 .895 r
F
.25279 .49942 m .25367 .50179 L .2545 .50168 L F
.25433 .50128 m .25558 .50312 L .25582 .50306 L F
.25279 .49942 m .25558 .50312 L .25433 .50128 L F
.25279 .49942 m .25433 .50128 L .25332 .49978 L F
.25433 .50128 m .25459 .50158 L .25332 .49978 L F
.25322 .49917 m .2536 .50019 L .25511 .50146 L .654 .726 .902 r
F
.2536 .50019 m .25456 .5016 L .25511 .50146 L F
.25464 .50155 m .25531 .50126 L .25531 .50131 L .515 .301 .526 r
F
.25447 .50162 m .25486 .50164 L .25511 .50146 L .654 .726 .902 r
F
.25562 .50823 m .25578 .5086 L .25617 .50857 L F
.25429 .50169 m .25486 .50164 L .25447 .50162 L F
.25464 .50156 m .25473 .50856 L .25429 .50169 L .515 .301 .526 r
F
.25424 .51042 m .25489 .50945 L .25468 .50879 L .654 .726 .902 r
F
.25473 .50856 m .25511 .5398 L .25444 .50867 L .515 .301 .526 r
F
.25473 .50856 m .25444 .50867 L .25429 .50169 L F
.26187 .51034 m .26182 .50749 L .26579 .50552 L .495 .291 .533 r
F
.26187 .51034 m .26579 .50552 L .26584 .50836 L F
.25884 .5067 m .26187 .51034 L .26584 .50836 L .675 .735 .895 r
F
.25945 .50583 m .26834 .51749 L .25799 .50256 L .654 .726 .902 r
F
.25629 .50797 m .27592 .52081 L .26318 .51093 L F
.25464 .50156 m .25528 .50835 L .25473 .50856 L .515 .301 .526 r
F
.25275 .50645 m .25562 .50823 L .25629 .50797 L .654 .726 .902 r
F
.25576 .50098 m .25945 .50583 L .25799 .50256 L F
.25648 .49922 m .25638 .50611 L .25655 .49937 L .986 .729 .348 r
F
.25578 .5086 m .27449 .5219 L .25617 .50857 L .654 .726 .902 r
F
.26149 .50538 m .26584 .50836 L .26892 .50578 L .675 .735 .895 r
F
.25714 .5024 m .26149 .50538 L .26355 .50366 L F
.25714 .5024 m .26355 .50366 L .25817 .50154 L F
.25639 .50053 m .27495 .51463 L .28008 .5107 L .654 .726 .902 r
F
.25638 .50058 m .27495 .51463 L .25639 .50053 L F
.25884 .5067 m .26584 .50836 L .26149 .50538 L .675 .735 .895 r
F
.25799 .50256 m .26834 .51749 L .27495 .51463 L .654 .726 .902 r
F
.25933 .50794 m .27962 .51798 L .28292 .51327 L F
.25542 .50123 m .25549 .50819 L .25531 .50131 L .353 .175 .495 r
F
.25549 .50819 m .25581 .53923 L .25541 .50826 L F
.25549 .50819 m .25541 .50826 L .25531 .50131 L F
.25665 .50733 m .26318 .51093 L .25933 .50794 L .654 .726 .902 r
F
.25275 .50645 m .25598 .50784 L .25665 .50733 L F
.25598 .50784 m .26318 .51093 L .25665 .50733 L F
.26033 .50779 m .26834 .51749 L .25945 .50583 L F
.26318 .51093 m .27962 .51798 L .25933 .50794 L F
.25322 .49917 m .25585 .50104 L .25623 .50047 L F
.25573 .49791 m .25556 .50502 L .2561 .49818 L .908 .63 .502 r
F
.25538 .50832 m .25578 .5086 L .25562 .50823 L .654 .726 .902 r
F
.25504 .50923 m .25577 .51164 L .25592 .51064 L F
.25556 .50113 m .25598 .50783 L .2556 .50811 L .353 .175 .495 r
F
.25548 .51371 m .25571 .51206 L .25489 .50945 L .654 .726 .902 r
F
.25541 .50826 m .25581 .53923 L .25528 .50835 L .353 .175 .495 r
F
.25541 .49558 m .25547 .49598 L .25563 .49573 L .675 .735 .895 r
F
.25644 .49609 m .25612 .49822 L .2564 .49886 L .986 .729 .348 r
F
.25653 .4963 m .25648 .49922 L .25657 .49639 L F
.25554 .49828 m .25547 .49833 L .25535 .49426 L .353 .175 .495 r
F
.25274 .49657 m .25643 .49725 L .25673 .49676 L .675 .735 .895 r
F
.2564 .49902 m .25653 .4963 L .25648 .49619 L .986 .729 .348 r
F
.25579 .49748 m .25673 .49794 L .25689 .49677 L .675 .735 .895 r
F
.25433 .49608 m .25448 .49882 L .25431 .49889 L .515 .301 .526 r
F
.25461 .49876 m .25448 .49882 L .25433 .49608 L F
.25274 .49657 m .25458 .49878 L .2554 .49839 L .675 .735 .895 r
F
.25458 .49878 m .25463 .49885 L .25524 .49849 L F
.25458 .49878 m .25524 .49849 L .2554 .49839 L F
.25458 .49597 m .25461 .49876 L .25433 .49608 L .515 .301 .526 r
F
.25461 .49876 m .25464 .50156 L .25448 .49882 L F
.25424 .51042 m .25548 .51371 L .25489 .50945 L .654 .726 .902 r
F
.25468 .50879 m .25489 .50945 L .25504 .50923 L F
.25424 .51042 m .25364 .52661 L .25548 .51371 L F
.25426 .50874 m .25511 .5398 L .25409 .54024 L .515 .301 .526 r
F
.25444 .50867 m .25511 .5398 L .25426 .50874 L F
.26127 .5069 m .28292 .51327 L .28417 .50809 L .654 .726 .902 r
F
.25556 .50113 m .2556 .50811 L .25542 .50123 L .353 .175 .495 r
F
.2556 .50811 m .25581 .53923 L .25549 .50819 L F
.2556 .50811 m .25549 .50819 L .25542 .50123 L F
.25751 .5067 m .27157 .51071 L .26127 .5069 L .654 .726 .902 r
F
.25275 .50645 m .25665 .50733 L .25751 .5067 L F
.25665 .50733 m .27157 .51071 L .25751 .5067 L F
.27157 .51071 m .28292 .51327 L .26127 .5069 L F
.25274 .49657 m .25664 .4959 L .25666 .49577 L .675 .735 .895 r
F
.25651 .49293 m .2565 .49419 L .25648 .4931 L 0 0 .125 r
F
.2565 .49419 m .25649 .49696 L .25649 .49431 L F
.2565 .49419 m .25649 .49431 L .25648 .4931 L F
.25656 .49375 m .2587 .49484 L .25895 .49376 L .675 .735 .895 r
F
.25648 .49433 m .25648 .49436 L .25648 .4931 L 0 0 .125 r
F
.25615 .4936 m .25615 .4949 L .25605 .49374 L .065 0 .408 r
F
.2544 .48161 m .25535 .49426 L .25456 .49456 L .515 .301 .526 r
F
.25368 .49189 m .25467 .49452 L .25557 .49418 L .654 .726 .902 r
F
.25282 .48181 m .25433 .49465 L .2531 .49476 L .641 .401 .539 r
F
.25368 .49189 m .25234 .49482 L .25359 .49471 L .654 .726 .902 r
F
.25368 .49189 m .25359 .49471 L .2547 .49461 L F
.2527 .49372 m .25647 .49442 L .25656 .49375 L .675 .735 .895 r
F
.25647 .49442 m .2587 .49484 L .25656 .49375 L F
.25651 .49293 m .25657 .49639 L .25649 .49696 L 0 0 .125 r
F
.25368 .49189 m .26086 .49498 L .25894 .49349 L .654 .726 .902 r
F
.25612 .4806 m .25615 .4936 L .25605 .49374 L .065 0 .408 r
F
.25821 .49292 m .28236 .50058 L .26707 .49492 L .654 .726 .902 r
F
.25368 .49189 m .25894 .49349 L .25821 .49292 L F
.25894 .49349 m .28236 .50058 L .25821 .49292 L F
.25621 .47805 m .25514 .47722 L .25507 .49049 L .908 .63 .502 r
F
.25657 .49251 m .25659 .49233 L .25659 .49358 L 0 0 .125 r
F
.25657 .49371 m .25659 .49358 L .25657 .49639 L F
.25657 .49251 m .25659 .49358 L .25657 .49371 L F
.2527 .49372 m .25656 .49375 L .25637 .49309 L .675 .735 .895 r
F
.25656 .49375 m .25666 .49375 L .25659 .49358 L F
.25656 .49375 m .25659 .49358 L .25637 .49309 L F
.25551 .49414 m .25552 .49549 L .25535 .49426 L .353 .175 .495 r
F
.25552 .49549 m .25554 .49828 L .25541 .49558 L F
.25552 .49549 m .25541 .49558 L .25535 .49426 L F
.2527 .49372 m .25541 .49558 L .25606 .49505 L .675 .735 .895 r
F
.25541 .49558 m .25543 .4956 L .25595 .49514 L F
.25541 .49558 m .25595 .49514 L .25606 .49505 L F
.25457 .49597 m .25524 .49568 L .25541 .49558 L F
.25649 .49696 m .25648 .49704 L .25648 .4931 L 0 0 .125 r
F
.25274 .49657 m .25666 .49577 L .25606 .49533 L .675 .735 .895 r
F
.2561 .49818 m .25586 .50525 L .25606 .50541 L .908 .63 .502 r
F
.25616 .50057 m .25641 .5072 L .25618 .50754 L .065 0 .408 r
F
.25574 .50099 m .25602 .50079 L .25598 .50783 L .353 .175 .495 r
F
.25542 .50491 m .25669 .50521 L .2556 .5048 L .654 .726 .902 r
F
.25275 .50645 m .25606 .50541 L .25542 .50491 L F
.25618 .50754 m .25611 .50764 L .25608 .50059 L .065 0 .408 r
F
.25606 .50541 m .25669 .50521 L .25542 .50491 L .654 .726 .902 r
F
.25615 .4936 m .25646 .4972 L .25616 .49768 L .065 0 .408 r
F
.25274 .49657 m .25666 .49659 L .25637 .49595 L .675 .735 .895 r
F
.25556 .50113 m .25542 .50123 L .25535 .49426 L .353 .175 .495 r
F
.25274 .49657 m .25673 .49676 L .25666 .49659 L .675 .735 .895 r
F
.25368 .49189 m .25616 .49366 L .25648 .4931 L .654 .726 .902 r
F
.25612 .4806 m .25648 .4931 L .25615 .4936 L .065 0 .408 r
F
.25542 .48117 m .25605 .49374 L .25551 .49414 L .353 .175 .495 r
F
.25655 .47991 m .25657 .49251 L .25651 .49293 L 0 0 .125 r
F
.25655 .47991 m .25651 .49293 L .25648 .4931 L F
.25974 .49221 m .28369 .49868 L .28493 .49353 L .654 .726 .902 r
F
.25368 .49189 m .26707 .49492 L .25974 .49221 L F
.26707 .49492 m .28369 .49868 L .25974 .49221 L F
.25514 .47722 m .25407 .47685 L .25399 .49009 L .809 .541 .533 r
F
.25417 .5017 m .25429 .50169 L .25447 .50162 L .654 .726 .902 r
F
.25386 .5094 m .25367 .51128 L .25424 .51042 L F
.25369 .50895 m .25363 .50957 L .25386 .5094 L F
.25363 .50879 m .25362 .50898 L .25369 .50895 L F
.2534 .50881 m .25426 .50874 L .25409 .54024 L .641 .401 .539 r
F
.2544 .48161 m .25458 .49597 L .25433 .49608 L .515 .301 .526 r
F
.2527 .49372 m .25457 .49597 L .25541 .49558 L .675 .735 .895 r
F
.25429 .50169 m .25444 .50867 L .25426 .50874 L .515 .301 .526 r
F
.25526 .49027 m .27626 .47881 L .26989 .47527 L .654 .726 .902 r
F
.25368 .49189 m .25623 .49042 L .25526 .49027 L F
.25623 .49042 m .27626 .47881 L .25526 .49027 L F
.25275 .50645 m .25386 .5094 L .25468 .50879 L F
.25424 .51042 m .25209 .52666 L .25364 .52661 L F
.25367 .51128 m .25209 .52666 L .25424 .51042 L F
.2534 .50881 m .25409 .54024 L .25316 .50884 L .641 .401 .539 r
F
.25327 .51151 m .25256 .51938 L .25391 .51149 L .654 .726 .902 r
F
.25362 .50898 m .25209 .52666 L .25369 .50895 L F
.25267 .50888 m .25209 .52666 L .25363 .50879 L F
.25271 .50183 m .25409 .54024 L .2525 .54044 L .641 .401 .539 r
F
.25363 .50957 m .25209 .52666 L .25386 .5094 L .654 .726 .902 r
F
.25295 .50181 m .25316 .50884 L .25271 .50183 L .641 .401 .539 r
F
.25316 .50884 m .25409 .54024 L .25296 .50885 L F
.25316 .50884 m .25296 .50885 L .25271 .50183 L F
.26041 .50658 m .26986 .50735 L .27156 .50677 L .654 .726 .902 r
F
.25275 .50645 m .26127 .5069 L .26041 .50658 L F
.26127 .5069 m .26986 .50735 L .26041 .50658 L F
.25282 .48181 m .2544 .48161 L .25433 .49465 L .641 .401 .539 r
F
.25621 .47805 m .2559 .49113 L .25614 .49131 L .908 .63 .502 r
F
.25666 .4791 m .25614 .49131 L .25649 .4921 L .986 .729 .348 r
F
.25655 .47991 m .25666 .4791 L .25659 .49233 L 0 0 .125 r
F
.25655 .47991 m .25659 .49233 L .25657 .49251 L F
.25666 .4791 m .25649 .4921 L .25659 .49233 L .986 .729 .348 r
F
.25368 .49189 m .26989 .47527 L .26241 .47287 L .654 .726 .902 r
F
.25483 .4904 m .25399 .49009 L .25399 .49139 L .809 .541 .533 r
F
.25375 .49131 m .25594 .49014 L .25445 .48971 L .675 .735 .895 r
F
.25189 .47681 m .25157 .49004 L .25182 .48998 L .567 .342 .533 r
F
.25407 .47685 m .25298 .47672 L .25291 .48993 L .734 .477 .54 r
F
.25407 .47685 m .25291 .48993 L .25375 .49005 L F
.25189 .47681 m .25072 .49026 L .25157 .49004 L .567 .342 .533 r
F
.25298 .47672 m .25189 .47681 L .25182 .48998 L .66 .416 .54 r
F
.25298 .47672 m .25182 .48998 L .25266 .48994 L F
.25294 .48993 m .25434 .47176 L .24622 .47202 L .654 .726 .902 r
F
.25368 .49189 m .25375 .48989 L .25294 .48993 L F
.25375 .48989 m .25434 .47176 L .25294 .48993 L F
.253 .4993 m .25006 .501 L .25304 .49936 L F
.25048 .50121 m .2511 .50858 L .25057 .50831 L .844 .571 .525 r
F
.25182 .50872 m .25158 .50867 L .25138 .50158 L .751 .491 .539 r
F
.24777 .50619 m .24731 .50522 L .24607 .5061 L .654 .726 .902 r
F
.24971 .50065 m .25011 .50809 L .24975 .50777 L .927 .648 .491 r
F
.25275 .50645 m .24877 .50555 L .24777 .50619 L .654 .726 .902 r
F
.24877 .50555 m .24731 .50522 L .24777 .50619 L F
.25274 .49657 m .24947 .49779 L .2497 .49821 L .675 .735 .895 r
F
.2505 .49742 m .25029 .50458 L .25068 .49731 L .398 .209 .505 r
F
.25041 .50824 m .25029 .50818 L .25015 .50104 L .844 .571 .525 r
F
.24172 .49783 m .23914 .50248 L .24366 .49956 L .675 .735 .895 r
F
.24172 .49783 m .23624 .49988 L .23914 .50248 L F
.23441 .49972 m .23616 .49991 L .2362 .50275 L .987 .713 .39 r
F
.24052 .49867 m .2362 .50275 L .24171 .50069 L .675 .735 .895 r
F
.24052 .49867 m .23441 .49972 L .2362 .50275 L F
.23441 .50142 m .2218 .49753 L .22271 .50282 L .654 .726 .902 r
F
.23408 .49944 m .23441 .49972 L .23444 .5016 L .866 .666 .136 r
F
.2444 .50023 m .234 .49898 L .23441 .50142 L .654 .726 .902 r
F
.234 .49898 m .2218 .49753 L .23441 .50142 L F
.23392 .49931 m .23408 .49944 L .23446 .50256 L .866 .666 .136 r
F
.23408 .49944 m .23444 .5016 L .23446 .50256 L F
.24723 .49863 m .24171 .50069 L .24366 .50244 L .675 .735 .895 r
F
.2444 .50023 m .23434 .50143 L .2478 .50088 L .654 .726 .902 r
F
.23434 .50143 m .22271 .50282 L .23462 .5019 L F
.23505 .50263 m .23441 .49972 L .2362 .50275 L .987 .713 .39 r
F
.23434 .50143 m .23462 .5019 L .2478 .50088 L .654 .726 .902 r
F
.23446 .50256 m .23444 .5016 L .23505 .50263 L .987 .713 .39 r
F
.23444 .5016 m .23441 .49972 L .23505 .50263 L F
.24021 .49935 m .23392 .49931 L .23446 .50256 L .675 .735 .895 r
F
.25152 .49455 m .25162 .49894 L .25118 .49448 L .751 .491 .539 r
F
.24627 .49022 m .22694 .48041 L .22366 .48511 L .654 .726 .902 r
F
.25079 .47714 m .2496 .49098 L .25047 .49042 L .398 .209 .505 r
F
.25368 .49189 m .24945 .49008 L .24627 .49022 L .654 .726 .902 r
F
.24945 .49008 m .22694 .48041 L .24627 .49022 L F
.25263 .51032 m .25183 .51172 L .25254 .51298 L F
.25103 .50345 m .25252 .50778 L .25265 .5036 L .675 .735 .895 r
F
.25271 .50193 m .25103 .50345 L .25265 .5036 L F
.25167 .50163 m .25271 .50183 L .25271 .50193 L .751 .491 .539 r
F
.25167 .50163 m .25271 .50193 L .25169 .50177 L F
.25279 .49942 m .25176 .50178 L .25271 .50193 L .675 .735 .895 r
F
.25172 .50244 m .25098 .50311 L .25122 .50353 L .654 .726 .902 r
F
.25176 .50178 m .25103 .50345 L .25271 .50193 L .675 .735 .895 r
F
.25169 .50177 m .25271 .50193 L .25267 .50888 L .751 .491 .539 r
F
.25267 .50888 m .25145 .50928 L .25263 .51032 L .654 .726 .902 r
F
.25172 .5087 m .25145 .50928 L .25267 .50888 L F
.25182 .50872 m .25267 .50888 L .2525 .54044 L .751 .491 .539 r
F
.25167 .50163 m .25267 .50888 L .25182 .50872 L F
.25275 .50645 m .25172 .5087 L .25267 .50888 L .654 .726 .902 r
F
.24967 .47793 m .24948 .49119 L .2496 .49098 L 0 0 .368 r
F
.25368 .49189 m .23204 .4765 L .22694 .48041 L .654 .726 .902 r
F
.25368 .49189 m .23862 .47364 L .23204 .4765 L F
.25079 .47714 m .25047 .49042 L .25072 .49026 L .398 .209 .505 r
F
.25282 .48181 m .2531 .49476 L .25275 .49479 L .641 .401 .539 r
F
.25368 .49189 m .24622 .47202 L .23862 .47364 L .654 .726 .902 r
F
.24018 .49365 m .23446 .49685 L .24054 .49581 L .675 .735 .895 r
F
.24018 .49365 m .23392 .49362 L .23446 .49685 L F
.23387 .49646 m .23383 .49362 L .23437 .49687 L .866 .666 .136 r
F
.23462 .49322 m .23383 .49362 L .23387 .49646 L 0 0 .24 r
F
.24068 .4915 m .23467 .49039 L .23392 .49362 L .675 .735 .895 r
F
.23462 .49322 m .23458 .49037 L .23383 .49362 L 0 0 .24 r
F
.24066 .49434 m .23387 .49646 L .24016 .4965 L .675 .735 .895 r
F
.24066 .49434 m .23462 .49322 L .23387 .49646 L F
.24501 .49732 m .23639 .49285 L .23486 .49502 L .654 .726 .902 r
F
.23665 .49305 m .23622 .49308 L .23467 .49606 L .107 0 .437 r
F
.23622 .49308 m .23462 .49322 L .23466 .49532 L F
.23622 .49308 m .23466 .49532 L .23467 .49606 L F
.23486 .49502 m .22633 .48763 L .22304 .49235 L .654 .726 .902 r
F
.23639 .49285 m .22633 .48763 L .23486 .49502 L F
.24914 .49273 m .24916 .49988 L .2491 .49977 L .989 .721 .393 r
F
.25172 .5087 m .25067 .50859 L .25145 .50928 L .654 .726 .902 r
F
.25118 .49448 m .2525 .54044 L .25093 .54018 L .751 .491 .539 r
F
.25322 .49917 m .24854 .49716 L .24501 .49732 L .654 .726 .902 r
F
.24911 .49719 m .24645 .49653 L .24663 .49762 L .675 .735 .895 r
F
.24662 .49477 m .24172 .49783 L .24721 .49578 L F
.24662 .49477 m .24054 .49581 L .24172 .49783 L F
.24068 .4915 m .23392 .49362 L .24018 .49365 L F
.2467 .49545 m .24016 .4965 L .24645 .49653 L F
.24644 .49369 m .24054 .49581 L .24662 .49477 L F
.2467 .49545 m .24066 .49434 L .24016 .4965 L F
.24198 .49232 m .23462 .49322 L .24066 .49434 L F
.24198 .49232 m .2366 .4902 L .23462 .49322 L F
.23622 .49308 m .2366 .4902 L .23462 .49322 L .107 0 .437 r
F
.23687 .49216 m .23639 .49285 L .24501 .49732 L .654 .726 .902 r
F
.23665 .49305 m .23664 .49249 L .23622 .49308 L .107 0 .437 r
F
.23664 .49249 m .2366 .4902 L .23622 .49308 L F
.24854 .49716 m .23687 .49216 L .24501 .49732 L .654 .726 .902 r
F
.23687 .49216 m .22633 .48763 L .23639 .49285 L F
.24599 .49149 m .23032 .48661 L .22243 .49026 L F
.24644 .49369 m .24018 .49365 L .24054 .49581 L .675 .735 .895 r
F
.24669 .49261 m .24068 .4915 L .24018 .49365 L F
.24874 .49078 m .23032 .48661 L .24599 .49149 L .654 .726 .902 r
F
.24199 .4895 m .23467 .49039 L .24068 .4915 L .675 .735 .895 r
F
.24736 .49445 m .24066 .49434 L .2467 .49545 L F
.24199 .4895 m .23664 .48739 L .23467 .49039 L F
.2366 .4902 m .23458 .49037 L .23462 .49322 L .107 0 .437 r
F
.2366 .4902 m .23656 .48735 L .23458 .49037 L F
.24669 .49261 m .24018 .49365 L .24644 .49369 L .675 .735 .895 r
F
.24736 .49445 m .24198 .49232 L .24066 .49434 L F
.24854 .49716 m .23967 .49017 L .237 .49221 L .654 .726 .902 r
F
.23973 .49046 m .23933 .49043 L .23665 .49305 L .353 .183 .506 r
F
.23933 .49043 m .2366 .4902 L .23664 .49249 L F
.23933 .49043 m .23664 .49249 L .23665 .49305 L F
.237 .49221 m .23146 .4837 L .22633 .48763 L .654 .726 .902 r
F
.24404 .4906 m .23969 .48762 L .2366 .4902 L .675 .735 .895 r
F
.23973 .49046 m .23969 .48762 L .2366 .4902 L .353 .183 .506 r
F
.23967 .49017 m .23146 .4837 L .237 .49221 L .654 .726 .902 r
F
.24906 .49643 m .24905 .49911 L .24905 .49635 L .798 .638 .081 r
F
.24938 .49835 m .24948 .49817 L .24953 .49543 L 0 0 .368 r
F
.25322 .49917 m .25028 .49709 L .2489 .49715 L .654 .726 .902 r
F
.24892 .49733 m .2489 .49715 L .24854 .49716 L F
.25322 .49917 m .2489 .49715 L .24892 .49733 L F
.24884 .49585 m .24833 .49575 L .24851 .49608 L .675 .735 .895 r
F
.24884 .49585 m .24851 .49608 L .24877 .49655 L F
.24833 .49575 m .2467 .49545 L .24877 .49655 L F
.24921 .49605 m .24904 .49899 L .24942 .49563 L 0 0 .368 r
F
.24907 .49655 m .24645 .49653 L .24911 .49719 L .675 .735 .895 r
F
.24909 .49212 m .2491 .49977 L .24906 .49925 L .798 .638 .081 r
F
.24906 .49925 m .24905 .49911 L .24908 .49194 L F
.24839 .49359 m .24198 .49232 L .24736 .49445 L .675 .735 .895 r
F
.24734 .49161 m .24199 .4895 L .24068 .4915 L F
.24404 .4906 m .2366 .4902 L .24198 .49232 L F
.23969 .48762 m .23656 .48735 L .2366 .4902 L .353 .183 .506 r
F
.25028 .49709 m .23146 .4837 L .24854 .49716 L .654 .726 .902 r
F
.25157 .49004 m .25153 .49147 L .25182 .48998 L .567 .342 .533 r
F
.25153 .49147 m .25173 .4914 L .25182 .48998 L F
.2527 .49372 m .25277 .49129 L .25183 .49138 L .675 .735 .895 r
F
.25266 .48994 m .25182 .48998 L .25181 .49138 L .66 .416 .54 r
F
.2527 .49372 m .25183 .49138 L .25097 .49165 L .675 .735 .895 r
F
.24922 .49288 m .24922 .49451 L .24914 .49273 L .989 .721 .393 r
F
.2527 .49372 m .2493 .4931 L .24898 .4937 L .675 .735 .895 r
F
.25027 .49203 m .24991 .49509 L .25043 .49192 L .398 .209 .505 r
F
.25043 .49192 m .25029 .49755 L .25063 .49178 L F
.25274 .49657 m .24958 .49532 L .24927 .49593 L .675 .735 .895 r
F
.25029 .49755 m .2505 .49742 L .25059 .49461 L .398 .209 .505 r
F
.25046 .49471 m .25059 .49461 L .25072 .49026 L F
.24909 .49212 m .24907 .49659 L .24908 .49194 L .798 .638 .081 r
F
.24907 .49659 m .24906 .49925 L .24907 .49652 L F
.24907 .49659 m .24907 .49652 L .24908 .49194 L F
.24946 .49277 m .24942 .49563 L .24955 .49259 L 0 0 .368 r
F
.24942 .49563 m .24947 .49555 L .24955 .49259 L F
.24993 .49464 m .24888 .49392 L .24958 .49532 L .675 .735 .895 r
F
.24888 .49392 m .24839 .49359 L .24891 .49434 L F
.24939 .49292 m .24907 .49354 L .24905 .49635 L 0 0 .368 r
F
.24921 .49605 m .24905 .49635 L .24904 .49899 L F
.24939 .49292 m .24905 .49635 L .24921 .49605 L F
.24888 .49392 m .24891 .49434 L .24958 .49532 L .675 .735 .895 r
F
.24958 .49532 m .24839 .49359 L .24736 .49445 L F
.25368 .49189 m .24874 .49078 L .24599 .49149 L .654 .726 .902 r
F
.25157 .49004 m .25072 .49026 L .25069 .49454 L .567 .342 .533 r
F
.25274 .49657 m .25007 .49474 L .24958 .49532 L .675 .735 .895 r
F
.25103 .49443 m .25069 .49454 L .25068 .49731 L .567 .342 .533 r
F
.25157 .49004 m .25069 .49454 L .25103 .49443 L F
.25027 .49203 m .24959 .49252 L .24958 .49533 L .398 .209 .505 r
F
.24991 .49509 m .24958 .49533 L .24956 .49802 L F
.25027 .49203 m .24958 .49533 L .24991 .49509 L F
.24909 .49212 m .24913 .49434 L .24909 .49386 L .798 .638 .081 r
F
.2493 .4931 m .24888 .49302 L .24898 .4937 L .675 .735 .895 r
F
.24947 .49555 m .24953 .49543 L .2496 .49098 L 0 0 .368 r
F
.25024 .49486 m .24972 .49293 L .24839 .49359 L .675 .735 .895 r
F
.2527 .49372 m .24946 .49493 L .24972 .49539 L F
.25274 .49657 m .25098 .49445 L .25024 .49486 L F
.25147 .4943 m .25068 .49731 L .2514 .49712 L .567 .342 .533 r
F
.25157 .49004 m .25103 .49443 L .25147 .4943 L F
.25103 .49443 m .25068 .49731 L .25147 .4943 L F
.25098 .49445 m .25092 .49438 L .25069 .49454 L .675 .735 .895 r
F
.25098 .49445 m .25069 .49454 L .25024 .49486 L F
.25043 .49192 m .24991 .49509 L .25036 .49477 L .398 .209 .505 r
F
.25092 .49438 m .24972 .49293 L .25024 .49486 L .675 .735 .895 r
F
.25007 .49474 m .24993 .49464 L .24984 .49481 L F
.25007 .49474 m .24984 .49481 L .24958 .49532 L F
.24942 .49563 m .24938 .49835 L .24947 .49555 L 0 0 .368 r
F
.25029 .49755 m .25059 .49461 L .25046 .49471 L .398 .209 .505 r
F
.25084 .49428 m .25125 .49252 L .24972 .49293 L .675 .735 .895 r
F
.24991 .49509 m .24956 .49802 L .25036 .49477 L .398 .209 .505 r
F
.25072 .49026 m .2505 .49742 L .25068 .49731 L F
.24888 .49302 m .24669 .49261 L .24792 .4937 L .675 .735 .895 r
F
.25162 .49894 m .25149 .49892 L .25118 .49448 L .751 .491 .539 r
F
.24938 .49835 m .24953 .49543 L .24947 .49555 L 0 0 .368 r
F
.24927 .49593 m .24766 .49456 L .24833 .49575 L .675 .735 .895 r
F
.24958 .49532 m .24766 .49456 L .24927 .49593 L F
.24766 .49456 m .24736 .49445 L .24833 .49575 L F
.2496 .49098 m .24948 .49817 L .24956 .49802 L 0 0 .368 r
F
.24734 .49161 m .24068 .4915 L .24669 .49261 L .675 .735 .895 r
F
.24837 .49076 m .24199 .4895 L .24734 .49161 L F
.24837 .49076 m .24404 .48779 L .24199 .4895 L F
.24404 .48779 m .23664 .48739 L .24199 .4895 L F
.24839 .49359 m .24404 .4906 L .24198 .49232 L F
.24898 .4937 m .24888 .49302 L .24792 .4937 L F
.24888 .49302 m .24734 .49161 L .24669 .49261 L F
.24972 .49293 m .24404 .4906 L .24839 .49359 L F
.24404 .48779 m .2397 .48482 L .23664 .48739 L F
.23969 .48762 m .23964 .48477 L .23656 .48735 L .353 .183 .506 r
F
.24669 .48929 m .23969 .48762 L .24404 .4906 L .675 .735 .895 r
F
.24667 .48648 m .2397 .48482 L .24404 .48779 L F
.24669 .48929 m .24366 .48564 L .23969 .48762 L F
.24366 .48564 m .23964 .48477 L .23969 .48762 L .495 .291 .532 r
F
.25262 .49875 m .24409 .48823 L .2402 .48992 L .654 .726 .902 r
F
.24371 .48849 m .24356 .48846 L .23973 .49046 L .495 .291 .532 r
F
.24356 .48846 m .23969 .48762 L .23973 .49013 L F
.24356 .48846 m .23973 .49013 L .23973 .49046 L F
.2402 .48992 m .23807 .48083 L .23146 .4837 L .654 .726 .902 r
F
.24371 .48849 m .24366 .48564 L .23969 .48762 L .495 .291 .532 r
F
.24409 .48823 m .23807 .48083 L .2402 .48992 L .654 .726 .902 r
F
.25274 .49657 m .25186 .49419 L .25179 .49419 L .675 .735 .895 r
F
.25274 .49657 m .25179 .49419 L .25098 .49445 L F
.25239 .49414 m .25179 .49419 L .25178 .49701 L .66 .416 .54 r
F
.25279 .49942 m .2519 .497 L .25099 .49725 L .675 .735 .895 r
F
.24906 .49925 m .24906 .49944 L .24905 .49911 L .798 .638 .081 r
F
.24906 .49944 m .24905 .4993 L .24905 .49911 L F
.25279 .49942 m .24734 .49841 L .2465 .49938 L .675 .735 .895 r
F
.25019 .494 m .2503 .50112 L .25015 .50104 L .844 .571 .525 r
F
.24804 .49833 m .247 .49824 L .2479 .49838 L .675 .735 .895 r
F
.24828 .49787 m .247 .49824 L .24804 .49833 L F
.24956 .4979 m .24958 .50054 L .2495 .49784 L .927 .648 .491 r
F
.24939 .49764 m .2495 .49784 L .24948 .50045 L .989 .721 .393 r
F
.25322 .49917 m .24803 .498 L .24514 .49875 L .654 .726 .902 r
F
.24663 .49762 m .24171 .50069 L .24723 .49863 L .675 .735 .895 r
F
.24734 .49841 m .24675 .4983 L .24668 .49862 L F
.24818 .49891 m .24514 .49875 L .24651 .49997 L .654 .726 .902 r
F
.24734 .49841 m .24668 .49862 L .2465 .49938 L .675 .735 .895 r
F
.25182 .50872 m .25138 .50158 L .2515 .5016 L .751 .491 .539 r
F
.25167 .50163 m .25182 .50872 L .2515 .5016 L F
.25178 .49701 m .2514 .50416 L .25174 .50407 L .567 .342 .533 r
F
.25182 .48998 m .25161 .49706 L .25178 .49701 L F
.25161 .49706 m .2514 .50416 L .25178 .49701 L F
.2522 .49697 m .25178 .49701 L .25174 .50407 L .66 .416 .54 r
F
.25239 .49414 m .25178 .49701 L .2522 .49697 L F
.2519 .497 m .25189 .49697 L .25178 .49701 L .675 .735 .895 r
F
.25279 .49942 m .25287 .49691 L .2519 .497 L F
.25111 .49652 m .25129 .49537 L .25048 .49558 L F
.2514 .49712 m .2515 .49709 L .25164 .49424 L .567 .342 .533 r
F
.25189 .49697 m .25129 .49537 L .25099 .49725 L .675 .735 .895 r
F
.2514 .49712 m .25164 .49424 L .25157 .49426 L .567 .342 .533 r
F
.25098 .49445 m .25179 .49419 L .25084 .49428 L .675 .735 .895 r
F
.24948 .49119 m .24946 .49277 L .2496 .49098 L 0 0 .368 r
F
.24946 .49277 m .24955 .49259 L .2496 .49098 L F
.24948 .49119 m .24907 .49354 L .24939 .49292 L F
.25047 .49042 m .24959 .49252 L .25027 .49203 L .398 .209 .505 r
F
.25025 .49205 m .24994 .49184 L .24961 .49251 L .675 .735 .895 r
F
.24994 .49184 m .24837 .49076 L .2496 .4925 L F
.24994 .49184 m .2496 .4925 L .24961 .49251 L F
.24961 .49251 m .24734 .49161 L .24888 .49302 L F
.25047 .49042 m .2496 .49098 L .24959 .49252 L .398 .209 .505 r
F
.25007 .49193 m .24968 .4901 L .24837 .49076 L .675 .735 .895 r
F
.2527 .49372 m .25097 .49165 L .25007 .49193 L F
.25047 .49042 m .25027 .49203 L .25043 .49192 L .398 .209 .505 r
F
.25043 .49192 m .25063 .49178 L .25072 .49026 L F
.25097 .49165 m .24968 .4901 L .25007 .49193 L .675 .735 .895 r
F
.25157 .49426 m .25164 .49424 L .25176 .4914 L .567 .342 .533 r
F
.25173 .4914 m .25176 .4914 L .25182 .48998 L F
.25157 .49426 m .25176 .4914 L .25173 .4914 L F
.24968 .4901 m .24404 .48779 L .24837 .49076 L .675 .735 .895 r
F
.24968 .4901 m .24667 .48648 L .24404 .48779 L F
.25121 .48969 m .24667 .48648 L .24968 .4901 L F
.25125 .49252 m .24669 .48929 L .24972 .49293 L F
.25047 .49042 m .25062 .49082 L .25072 .49026 L .398 .209 .505 r
F
.25047 .49042 m .25062 .49082 L .25047 .49042 L F
.25047 .49042 m .25043 .49192 L .25062 .49082 L F
.25125 .49252 m .24975 .48847 L .24669 .48929 L .675 .735 .895 r
F
.24667 .48648 m .24366 .48285 L .2397 .48482 L F
.24972 .48566 m .24366 .48285 L .24667 .48648 L F
.2515 .49709 m .23807 .48083 L .25262 .49875 L .654 .726 .902 r
F
.25129 .49537 m .2498 .49131 L .24673 .49213 L .675 .735 .895 r
F
.24972 .48566 m .24823 .48163 L .24366 .48285 L F
.24975 .48847 m .24366 .48564 L .24669 .48929 L F
.25121 .48969 m .24972 .48566 L .24667 .48648 L F
.24975 .48847 m .24825 .48441 L .24366 .48564 L F
.24825 .48441 m .24361 .4828 L .24366 .48564 L .591 .366 .543 r
F
.24825 .48441 m .24821 .48157 L .24361 .4828 L F
.2498 .49131 m .2483 .48726 L .24371 .48849 L .675 .735 .895 r
F
.2483 .48726 m .24366 .48564 L .2437 .4884 L .591 .366 .543 r
F
.24972 .49293 m .24669 .48929 L .24404 .4906 L .675 .735 .895 r
F
.24366 .48564 m .24361 .4828 L .23964 .48477 L .495 .291 .532 r
F
.2515 .49709 m .24017 .48038 L .23807 .48083 L .654 .726 .902 r
F
.24537 .48805 m .2437 .4884 L .24371 .48849 L .591 .366 .543 r
F
.2483 .48726 m .2437 .4884 L .24537 .48805 L F
.24548 .48802 m .24572 .4792 L .24017 .48038 L .654 .726 .902 r
F
.25322 .49917 m .24877 .48732 L .24548 .48802 L F
.2483 .48726 m .24825 .48441 L .24366 .48564 L .591 .366 .543 r
F
.24877 .48732 m .24572 .4792 L .24548 .48802 L .654 .726 .902 r
F
.2519 .497 m .25178 .49701 L .2515 .49709 L .675 .735 .895 r
F
.2519 .497 m .2515 .49709 L .25151 .49711 L F
.25322 .49917 m .24017 .48038 L .2515 .49709 L .654 .726 .902 r
F
.25151 .49711 m .2515 .49709 L .25099 .49725 L .675 .735 .895 r
F
.2519 .497 m .25293 .49523 L .25129 .49537 L F
.25274 .49657 m .25282 .4941 L .25186 .49419 L F
.25249 .49699 m .2527 .49698 L .25279 .4941 L .66 .416 .54 r
F
.25283 .49129 m .25287 .49128 L .25291 .48993 L F
.25263 .4913 m .25283 .49129 L .25291 .48993 L F
.25375 .49005 m .25291 .48993 L .2529 .49128 L .734 .477 .54 r
F
.25277 .49129 m .25445 .48971 L .25283 .48956 L .675 .735 .895 r
F
.2527 .49372 m .2538 .4912 L .25277 .49129 L F
.25375 .49005 m .2529 .49128 L .25372 .49136 L .734 .477 .54 r
F
.2538 .4912 m .25445 .48971 L .25277 .49129 L .675 .735 .895 r
F
.25266 .49411 m .25279 .4941 L .25287 .49128 L .66 .416 .54 r
F
.25266 .49411 m .25287 .49128 L .25283 .49129 L F
.25249 .49699 m .25279 .4941 L .25266 .49411 L F
.25257 .49131 m .25181 .49138 L .25179 .49419 L F
.25257 .49131 m .25179 .49419 L .25239 .49414 L F
.25153 .49147 m .25147 .4943 L .25173 .4914 L .567 .342 .533 r
F
.25147 .4943 m .2514 .49712 L .25157 .49426 L F
.25147 .4943 m .25157 .49426 L .25173 .4914 L F
.25186 .49417 m .25288 .49239 L .25125 .49252 L .675 .735 .895 r
F
.25186 .49419 m .25187 .49417 L .25186 .49417 L F
.25187 .49417 m .25288 .49239 L .25186 .49417 L F
.25266 .48994 m .2522 .49697 L .25249 .49694 L .66 .416 .54 r
F
.25263 .4913 m .25249 .49699 L .25283 .49129 L F
.25282 .4941 m .25288 .49239 L .25186 .49419 L .675 .735 .895 r
F
.25287 .49691 m .25293 .49523 L .2519 .497 L F
.25322 .49917 m .2515 .49709 L .25262 .49875 L .654 .726 .902 r
F
.25249 .49694 m .25174 .50407 L .25232 .50404 L .66 .416 .54 r
F
.2522 .49697 m .25174 .50407 L .25249 .49694 L F
.25099 .49725 m .25111 .49652 L .24976 .49578 L .675 .735 .895 r
F
.25111 .49652 m .25048 .49558 L .24976 .49578 L F
.25186 .49419 m .25125 .49252 L .25084 .49428 L F
.25266 .48994 m .25181 .49138 L .25257 .49131 L .66 .416 .54 r
F
.25183 .49138 m .25283 .48956 L .25121 .48969 L .675 .735 .895 r
F
.25266 .48994 m .25263 .4913 L .25291 .48993 L .66 .416 .54 r
F
.25277 .49129 m .25283 .48956 L .25183 .49138 L .675 .735 .895 r
F
.25182 .50872 m .2525 .54044 L .25158 .50867 L .751 .491 .539 r
F
.24054 .49581 m .23624 .49988 L .24172 .49783 L .675 .735 .895 r
F
.24054 .49581 m .23446 .49685 L .23624 .49988 L F
.23387 .49646 m .23437 .49687 L .23441 .49972 L .866 .666 .136 r
F
.24016 .4965 m .23441 .49972 L .24052 .49867 L .675 .735 .895 r
F
.23441 .49972 m .23437 .49687 L .23616 .49991 L .987 .713 .39 r
F
.24016 .4965 m .23387 .49646 L .23441 .49972 L .675 .735 .895 r
F
.23397 .49816 m .22613 .49305 L .2218 .49753 L .654 .726 .902 r
F
.24514 .49875 m .23459 .49559 L .23397 .49816 L F
.23445 .49617 m .23387 .49646 L .23391 .49842 L 0 0 .24 r
F
.23459 .49559 m .22613 .49305 L .23397 .49816 L .654 .726 .902 r
F
.23408 .49944 m .23387 .49646 L .23441 .49972 L .866 .666 .136 r
F
.23392 .49931 m .23391 .49842 L .23408 .49944 L F
.23391 .49842 m .23387 .49646 L .23408 .49944 L F
.23367 .49815 m .2218 .49753 L .234 .49898 L .654 .726 .902 r
F
.23387 .49819 m .234 .49898 L .2444 .50023 L F
.23367 .49815 m .234 .49898 L .23387 .49819 L F
.23467 .49606 m .23445 .49617 L .23392 .49931 L 0 0 .24 r
F
.23445 .49617 m .23391 .49842 L .23392 .49931 L F
.24663 .49762 m .24052 .49867 L .24171 .50069 L .675 .735 .895 r
F
.24514 .49875 m .23367 .49815 L .24157 .49968 L .654 .726 .902 r
F
.24668 .50047 m .24057 .50151 L .24176 .50354 L .675 .735 .895 r
F
.23445 .49617 m .23462 .49322 L .23387 .49646 L 0 0 .24 r
F
.23467 .49606 m .23466 .49532 L .23445 .49617 L F
.23466 .49532 m .23462 .49322 L .23445 .49617 L F
.24721 .49578 m .24172 .49783 L .24366 .49956 L .675 .735 .895 r
F
.24645 .49653 m .24052 .49867 L .24663 .49762 L F
.24645 .49653 m .24016 .4965 L .24052 .49867 L F
.24803 .498 m .23473 .49499 L .24514 .49875 L .654 .726 .902 r
F
.23473 .49499 m .22613 .49305 L .23459 .49559 L F
.23473 .49499 m .23459 .49559 L .24514 .49875 L F
.24071 .49718 m .23392 .49931 L .24021 .49935 L .675 .735 .895 r
F
.24071 .49718 m .23467 .49606 L .23392 .49931 L F
.24762 .50425 m .23099 .49098 L .22586 .49491 L .654 .726 .902 r
F
.2491 .49977 m .24915 .50697 L .24906 .50682 L .989 .721 .393 r
F
.24924 .50713 m .24918 .50703 L .24916 .49988 L F
.24923 .5 m .24944 .5075 L .24924 .50713 L F
.24971 .50065 m .25015 .50104 L .25015 .50123 L .927 .648 .491 r
F
.25005 .50119 m .24922 .50172 L .25055 .50159 L .675 .735 .895 r
F
.24972 .50086 m .25015 .50123 L .25011 .50809 L .927 .648 .491 r
F
.24971 .50065 m .25015 .50123 L .24972 .50086 L F
.25015 .50123 m .25055 .50159 L .25085 .50156 L .675 .735 .895 r
F
.25005 .50119 m .25055 .50159 L .25015 .50123 L F
.25275 .50645 m .24954 .50417 L .24762 .50425 L .654 .726 .902 r
F
.24514 .49875 m .24157 .49968 L .2444 .50023 L F
.24903 .5064 m .24902 .50628 L .24905 .49911 L .798 .638 .081 r
F
.24906 .49925 m .24906 .50682 L .24903 .5064 L F
.24902 .50628 m .24901 .50618 L .24904 .49899 L F
.24825 .50235 m .24627 .50663 L .24953 .50302 L .675 .735 .895 r
F
.24728 .50148 m .2437 .50528 L .24825 .50235 L F
.24668 .50047 m .24176 .50354 L .24728 .50148 L F
.24651 .49997 m .24514 .49875 L .2444 .50023 L .654 .726 .902 r
F
.2465 .49938 m .24021 .49935 L .24057 .50151 L .675 .735 .895 r
F
.24954 .50417 m .23099 .49098 L .24762 .50425 L .654 .726 .902 r
F
.25279 .49942 m .24741 .49729 L .24675 .4983 L .675 .735 .895 r
F
.25249 .49699 m .25232 .50404 L .2527 .49698 L .66 .416 .54 r
F
.24651 .49997 m .2444 .50023 L .24572 .50048 L .654 .726 .902 r
F
.24651 .49997 m .24572 .50048 L .2478 .50088 L F
.2465 .49938 m .24057 .50151 L .24668 .50047 L .675 .735 .895 r
F
.24675 .4983 m .24021 .49935 L .2465 .49938 L F
.24675 .4983 m .24071 .49718 L .24021 .49935 L F
.24741 .49729 m .24203 .49517 L .24071 .49718 L F
.24203 .49517 m .23467 .49606 L .24071 .49718 L F
.24203 .49517 m .23665 .49305 L .23467 .49606 L F
.24409 .49345 m .23665 .49305 L .24203 .49517 L F
.24409 .49345 m .23973 .49046 L .23665 .49305 L F
.24954 .50417 m .2376 .48811 L .23099 .49098 L .654 .726 .902 r
F
.2505 .50139 m .25114 .50169 L .2511 .50858 L .844 .571 .525 r
F
.25048 .50121 m .2506 .51142 L .2503 .50112 L F
.25275 .50645 m .25082 .50411 L .24954 .50417 L .654 .726 .902 r
F
.24936 .50537 m .24943 .50525 L .24956 .49802 L 0 0 .368 r
F
.24944 .5075 m .24994 .5397 L .24927 .53911 L .927 .648 .491 r
F
.24948 .50045 m .24956 .5076 L .24944 .5075 L F
.24956 .5076 m .24994 .5397 L .24944 .5075 L F
.24922 .50172 m .24825 .50235 L .24931 .50291 L .675 .735 .895 r
F
.24916 .49988 m .24918 .50703 L .2491 .49977 L .989 .721 .393 r
F
.25067 .50859 m .24643 .5108 L .24383 .5156 L .654 .726 .902 r
F
.25082 .50844 m .25062 .50854 L .25067 .50859 L F
.25062 .50854 m .24643 .5108 L .25067 .50859 L F
.24958 .50054 m .24965 .50768 L .24948 .50045 L .927 .648 .491 r
F
.24965 .50768 m .24994 .5397 L .24956 .5076 L F
.24965 .50768 m .24956 .5076 L .24948 .50045 L F
.24918 .50703 m .2492 .51511 L .24915 .50697 L .989 .721 .393 r
F
.24918 .50703 m .24915 .50697 L .2491 .49977 L F
.24928 .50552 m .24936 .50537 L .24948 .49817 L 0 0 .368 r
F
.25275 .50645 m .24762 .50425 L .24761 .50425 L .654 .726 .902 r
F
.24825 .50235 m .2437 .50528 L .24627 .50663 L .675 .735 .895 r
F
.24803 .50499 m .24761 .50425 L .24587 .50432 L .654 .726 .902 r
F
.24975 .50777 m .24965 .50768 L .24958 .50054 L .927 .648 .491 r
F
.25275 .50645 m .24761 .50425 L .24803 .50499 L .654 .726 .902 r
F
.24673 .50509 m .24587 .50432 L .24375 .50442 L F
.25051 .50828 m .25041 .50824 L .2503 .50112 L .844 .571 .525 r
F
.25275 .50645 m .24587 .50432 L .24673 .50509 L .654 .726 .902 r
F
.24956 .49802 m .24943 .50525 L .24952 .50507 L 0 0 .368 r
F
.24923 .5 m .24924 .50713 L .24916 .49988 L .989 .721 .393 r
F
.24906 .49945 m .2491 .49997 L .24906 .50682 L .798 .638 .081 r
F
.24938 .49835 m .249 .50603 L .24928 .50552 L 0 0 .368 r
F
.24741 .49729 m .24071 .49718 L .24675 .4983 L .675 .735 .895 r
F
.25082 .50411 m .2376 .48811 L .24954 .50417 L .654 .726 .902 r
F
.25279 .49942 m .24976 .49578 L .24844 .49643 L .675 .735 .895 r
F
.2527 .49698 m .25249 .50404 L .25287 .49697 L .66 .416 .54 r
F
.25249 .50404 m .25157 .53544 L .25263 .50403 L F
.25249 .50404 m .25263 .50403 L .25287 .49697 L F
.25232 .50404 m .25157 .53544 L .25249 .50404 L F
.25232 .50404 m .25249 .50404 L .2527 .49698 L F
.25287 .49697 m .25157 .53544 L .25266 .53535 L F
.2527 .49372 m .25399 .49139 L .25373 .49136 L .675 .735 .895 r
F
.25372 .49136 m .2529 .49128 L .25289 .49409 L .734 .477 .54 r
F
.25274 .49657 m .25386 .494 L .25282 .4941 L .675 .735 .895 r
F
.2533 .49414 m .25289 .49409 L .25287 .49697 L .734 .477 .54 r
F
.2544 .48161 m .25542 .48117 L .25535 .49426 L .515 .301 .526 r
F
.25368 .49189 m .28108 .48325 L .27626 .47881 L .654 .726 .902 r
F
.2559 .49113 m .25507 .49049 L .25507 .49175 L .908 .63 .502 r
F
.25472 .49149 m .25722 .49081 L .25594 .49014 L .675 .735 .895 r
F
.2527 .49372 m .25538 .49199 L .25472 .49149 L F
.25368 .49189 m .28493 .49353 L .28404 .48826 L .654 .726 .902 r
F
.2559 .49113 m .25507 .49175 L .25582 .49232 L .908 .63 .502 r
F
.25368 .49189 m .28404 .48826 L .28108 .48325 L .654 .726 .902 r
F
.25538 .49199 m .25722 .49081 L .25472 .49149 L .675 .735 .895 r
F
.25582 .49232 m .25505 .49457 L .25564 .49501 L .908 .63 .502 r
F
.25614 .49131 m .2559 .4952 L .25611 .49537 L F
.2559 .49113 m .25587 .49235 L .25614 .49131 L F
.25587 .49235 m .25573 .49791 L .25606 .4925 L F
.25587 .49235 m .25606 .4925 L .25614 .49131 L F
.25538 .49199 m .25818 .49167 L .25722 .49081 L .675 .735 .895 r
F
.2527 .49372 m .25603 .49248 L .25538 .49199 L F
.25603 .49248 m .25818 .49167 L .25538 .49199 L F
.25609 .49246 m .25877 .49268 L .25818 .49167 L F
.2527 .49372 m .25637 .49309 L .25609 .49246 L F
.25649 .4921 m .25613 .49255 L .25637 .4931 L .986 .729 .348 r
F
.25649 .4921 m .25647 .49333 L .25659 .49233 L F
.25657 .49251 m .25657 .49639 L .25651 .49293 L 0 0 .125 r
F
.25647 .49333 m .25654 .49349 L .25659 .49233 L .986 .729 .348 r
F
.25637 .49309 m .25877 .49268 L .25609 .49246 L .675 .735 .895 r
F
.25649 .4921 m .25614 .49131 L .25613 .49255 L .986 .729 .348 r
F
.25637 .4931 m .25613 .49255 L .25611 .49537 L F
.25626 .4957 m .25611 .49537 L .2561 .49818 L F
.2559 .4952 m .25573 .49791 L .25611 .49537 L .908 .63 .502 r
F
.25626 .4957 m .2561 .49836 L .25644 .49609 L .986 .729 .348 r
F
.25648 .49705 m .25647 .49713 L .25648 .49436 L 0 0 .125 r
F
.25666 .49659 m .25761 .4966 L .25637 .49595 L .675 .735 .895 r
F
.25648 .49988 m .25648 .49436 L .25648 .49433 L 0 0 .125 r
F
.25538 .49656 m .25733 .49648 L .25605 .49581 L .675 .735 .895 r
F
.25274 .49657 m .25561 .49854 L .25604 .49787 L F
.25279 .49942 m .25579 .49748 L .25538 .49656 L F
.25611 .49537 m .25573 .49791 L .2561 .49818 L .908 .63 .502 r
F
.25666 .49659 m .25673 .49676 L .25684 .49659 L .675 .735 .895 r
F
.25579 .49748 m .25733 .49648 L .25538 .49656 L F
.25649 .49696 m .25656 .49921 L .25655 .49924 L 0 0 .125 r
F
.25648 .49988 m .25648 .49921 L .25648 .49921 L F
.25648 .49921 m .25647 .49713 L .25648 .49921 L F
.25648 .49921 m .25647 .49713 L .25648 .49705 L F
.25649 .49696 m .25648 .49988 L .25648 .49704 L F
.2564 .49902 m .25648 .49922 L .25653 .4963 L .986 .729 .348 r
F
.2561 .49818 m .2589 .49837 L .25831 .49736 L .675 .735 .895 r
F
.25564 .49501 m .25505 .49457 L .25504 .49738 L .908 .63 .502 r
F
.25551 .49414 m .25574 .50091 L .25556 .50107 L .353 .175 .495 r
F
.25608 .50069 m .25606 .49783 L .25606 .49783 L .065 0 .408 r
F
.25279 .49942 m .25638 .4988 L .2561 .49818 L .675 .735 .895 r
F
.25322 .49917 m .25637 .50053 L .25648 .49991 L .654 .726 .902 r
F
.25546 .4977 m .25504 .49738 L .255 .50458 L .908 .63 .502 r
F
.25564 .49501 m .25504 .49738 L .25546 .4977 L F
.25649 .49696 m .25655 .49937 L .2565 .49976 L 0 0 .125 r
F
.25657 .49639 m .25649 .49906 L .25656 .49921 L .986 .729 .348 r
F
.25638 .4988 m .2589 .49837 L .2561 .49818 L .675 .735 .895 r
F
.25655 .49924 m .25656 .49921 L .25655 .49937 L 0 0 .125 r
F
.25656 .49921 m .25648 .49922 L .25655 .49937 L .986 .729 .348 r
F
.25649 .49906 m .25648 .49922 L .25656 .49921 L F
.25611 .4982 m .2561 .49818 L .2561 .49836 L F
.25626 .4957 m .2561 .49818 L .25611 .4982 L F
.25649 .4921 m .25611 .49537 L .25626 .4957 L F
.25536 .49367 m .25729 .49364 L .25601 .49296 L .675 .735 .895 r
F
.25582 .49232 m .25507 .49175 L .25505 .49457 L .908 .63 .502 r
F
.25476 .49434 m .25556 .49412 L .25536 .49367 L .675 .735 .895 r
F
.25556 .49412 m .25729 .49364 L .25536 .49367 L F
.25475 .49165 m .25399 .49139 L .25397 .49421 L .809 .541 .533 r
F
.25274 .49657 m .25542 .49484 L .25505 .49457 L .675 .735 .895 r
F
.25274 .49657 m .25505 .49457 L .25467 .49444 L F
.25456 .4944 m .25396 .49702 L .25438 .49716 L .809 .541 .533 r
F
.25507 .49049 m .25466 .49726 L .25504 .49738 L F
.25385 .49698 m .25605 .49581 L .25455 .49538 L .675 .735 .895 r
F
.25396 .49702 m .25358 .50413 L .25392 .50418 L .734 .477 .54 r
F
.25475 .49165 m .25397 .49421 L .25456 .4944 L .809 .541 .533 r
F
.25483 .4904 m .25473 .49446 L .25507 .49049 L F
.25647 .49333 m .25644 .49609 L .25654 .49349 L .986 .729 .348 r
F
.25644 .49609 m .25648 .49619 L .25659 .49233 L F
.25649 .4921 m .25626 .4957 L .25644 .49609 L F
.25659 .49233 m .25653 .4963 L .25657 .49639 L F
.25648 .49619 m .25653 .4963 L .25659 .49233 L F
.25274 .49657 m .25826 .49451 L .25729 .49364 L .675 .735 .895 r
F
.25473 .49446 m .25466 .49726 L .25483 .49449 L .809 .541 .533 r
F
.25473 .49446 m .25483 .49449 L .25507 .49049 L F
.2538 .49415 m .25601 .49296 L .2545 .49254 L .675 .735 .895 r
F
.25274 .49657 m .2548 .49429 L .25378 .49419 L F
.2527 .49372 m .25462 .4916 L .25399 .49139 L F
.25407 .47685 m .25375 .49005 L .25399 .49009 L .734 .477 .54 r
F
.25514 .47722 m .25399 .49009 L .25483 .4904 L .809 .541 .533 r
F
.25621 .47805 m .25507 .49049 L .2559 .49113 L .908 .63 .502 r
F
.25514 .47722 m .25483 .4904 L .25507 .49049 L .809 .541 .533 r
F
.25368 .49189 m .26241 .47287 L .25434 .47176 L .654 .726 .902 r
F
.25375 .49005 m .25365 .49417 L .25399 .49009 L .734 .477 .54 r
F
.25275 .50645 m .27156 .50677 L .26192 .50536 L .654 .726 .902 r
F
.25542 .49484 m .25729 .49364 L .25476 .49434 L .675 .735 .895 r
F
.25637 .49309 m .25895 .49376 L .25877 .49268 L F
.25666 .49375 m .25895 .49376 L .25637 .49309 L F
.25877 .49268 m .26367 .48962 L .25818 .49167 L F
.25818 .49167 m .26174 .48789 L .25722 .49081 L F
.25818 .49167 m .26367 .48962 L .26174 .48789 L F
.25722 .49081 m .26174 .48789 L .25919 .48655 L F
.26367 .48962 m .26626 .48497 L .26174 .48789 L F
.25729 .49364 m .25927 .48936 L .25601 .49296 L F
.25729 .49364 m .26183 .4907 L .25927 .48936 L F
.26174 .48789 m .26244 .48296 L .25919 .48655 L F
.26174 .48789 m .26626 .48497 L .26244 .48296 L F
.25605 .49581 m .25631 .49135 L .25455 .49538 L F
.25606 .49533 m .25611 .49537 L .25609 .49532 L F
.25611 .49537 m .25666 .49577 L .25609 .49532 L F
.25605 .49581 m .25932 .4922 L .25631 .49135 L F
.26183 .4907 m .26253 .48575 L .25927 .48936 L F
.26183 .4907 m .26638 .48777 L .26253 .48575 L F
.26367 .48962 m .26916 .48757 L .26626 .48497 L F
.26638 .48777 m .26633 .48492 L .26249 .4829 L .861 .586 .521 r
F
.25927 .48936 m .26253 .48575 L .25802 .48447 L .675 .735 .895 r
F
.26638 .48777 m .26249 .4829 L .26253 .48575 L .861 .586 .521 r
F
.25919 .48655 m .26244 .48296 L .25795 .48168 L .675 .735 .895 r
F
.26253 .48575 m .26249 .4829 L .25798 .48162 L .794 .529 .537 r
F
.25722 .49081 m .25919 .48655 L .25594 .49014 L .675 .735 .895 r
F
.25601 .49296 m .25927 .48936 L .25626 .4885 L F
.25932 .4922 m .25807 .48732 L .25631 .49135 L F
.25932 .4922 m .26258 .4886 L .25807 .48732 L F
.26258 .4886 m .26253 .48575 L .25802 .48447 L .794 .529 .537 r
F
.26258 .4886 m .25802 .48447 L .25807 .48732 L F
.25414 .49716 m .2695 .48247 L .26199 .48005 L .654 .726 .902 r
F
.25279 .49942 m .25473 .49728 L .25396 .49702 L .675 .735 .895 r
F
.25438 .49716 m .25396 .49702 L .25396 .49713 L .809 .541 .533 r
F
.25322 .49917 m .25487 .49747 L .25412 .4972 L .654 .726 .902 r
F
.25437 .49729 m .25396 .49713 L .25392 .50418 L .809 .541 .533 r
F
.25438 .49716 m .25396 .49713 L .25437 .49729 L F
.25483 .4904 m .25392 .50418 L .25449 .50439 L F
.25412 .4972 m .25505 .49729 L .25414 .49716 L .654 .726 .902 r
F
.25279 .49942 m .2561 .49818 L .25587 .49766 L .675 .735 .895 r
F
.25279 .49942 m .25587 .49766 L .25564 .49758 L F
.25556 .50107 m .25556 .50112 L .25556 .50113 L .353 .175 .495 r
F
.25322 .49917 m .25511 .50146 L .25576 .50098 L .654 .726 .902 r
F
.25466 .49726 m .25449 .50439 L .25504 .49738 L .809 .541 .533 r
F
.25487 .49747 m .25505 .49729 L .25412 .4972 L .654 .726 .902 r
F
.25473 .49728 m .25605 .49581 L .25385 .49698 L .675 .735 .895 r
F
.25609 .49532 m .25666 .49577 L .25675 .49507 L F
.25877 .49268 m .26485 .49164 L .26367 .48962 L F
.25895 .49376 m .26485 .49164 L .25877 .49268 L F
.25826 .49451 m .26183 .4907 L .25729 .49364 L F
.25826 .49451 m .26377 .49245 L .26183 .4907 L F
.26188 .49355 m .26258 .4886 L .25932 .4922 L F
.25505 .49729 m .2695 .48247 L .25414 .49716 L .654 .726 .902 r
F
.25365 .49417 m .25358 .49708 L .25387 .4942 L .734 .477 .54 r
F
.25644 .49609 m .2564 .49902 L .25648 .49619 L .986 .729 .348 r
F
.25894 .49349 m .28041 .50337 L .28236 .50058 L .654 .726 .902 r
F
.26086 .49498 m .28041 .50337 L .25894 .49349 L F
.25564 .49758 m .25587 .49766 L .25579 .49748 L .675 .735 .895 r
F
.25637 .49595 m .25761 .4966 L .25885 .49552 L F
.25805 .49584 m .2634 .49795 L .26471 .49595 L F
.25761 .4966 m .25886 .49558 L .25885 .49552 L F
.25675 .49507 m .25885 .49552 L .25826 .49451 L F
.25664 .4959 m .25885 .49552 L .25675 .49507 L F
.2587 .49484 m .26521 .4938 L .25895 .49376 L F
.25895 .49376 m .26521 .4938 L .26485 .49164 L F
.26485 .49164 m .26916 .48757 L .26367 .48962 L F
.26485 .49164 m .27093 .4906 L .26916 .48757 L F
.25885 .49552 m .26377 .49245 L .25826 .49451 L F
.26377 .49245 m .26638 .48777 L .26183 .4907 L F
.26377 .49245 m .26929 .49039 L .26638 .48777 L F
.26929 .49039 m .26924 .48754 L .26633 .48492 L .932 .65 .484 r
F
.25733 .49648 m .25932 .4922 L .25605 .49581 L .675 .735 .895 r
F
.25733 .49648 m .26188 .49355 L .25932 .4922 L F
.26929 .49039 m .26633 .48492 L .26638 .48777 L .932 .65 .484 r
F
.26188 .49355 m .26642 .49062 L .26258 .4886 L .675 .735 .895 r
F
.26934 .49323 m .26638 .48777 L .26642 .49062 L .932 .65 .484 r
F
.26642 .49062 m .26638 .48777 L .26253 .48575 L .861 .586 .521 r
F
.26642 .49062 m .26253 .48575 L .26258 .4886 L F
.25322 .49917 m .27591 .48603 L .2695 .48247 L .654 .726 .902 r
F
.25702 .49669 m .2634 .49795 L .25805 .49584 L .675 .735 .895 r
F
.25761 .4966 m .25903 .49661 L .25886 .49558 L F
.25689 .49677 m .25831 .49736 L .25733 .49648 L F
.25643 .49725 m .25878 .49769 L .25684 .49659 L F
.2587 .49484 m .26471 .49595 L .26521 .4938 L F
.25805 .49584 m .26471 .49595 L .2587 .49484 L F
.26521 .4938 m .27147 .49383 L .27093 .4906 L F
.26521 .4938 m .27093 .4906 L .26485 .49164 L F
.25903 .49661 m .26496 .49447 L .25885 .49552 L F
.25885 .49552 m .26496 .49447 L .26377 .49245 L F
.27107 .49343 m .27103 .49058 L .26924 .48754 L .987 .713 .388 r
F
.26496 .49447 m .26929 .49039 L .26377 .49245 L .675 .735 .895 r
F
.26496 .49447 m .27107 .49343 L .26929 .49039 L F
.27107 .49343 m .26924 .48754 L .26929 .49039 L .987 .713 .388 r
F
.27112 .49627 m .27107 .49343 L .26929 .49039 L F
.25831 .49736 m .26188 .49355 L .25733 .49648 L .675 .735 .895 r
F
.25831 .49736 m .26382 .49529 L .26188 .49355 L F
.27112 .49627 m .26929 .49039 L .26934 .49323 L .987 .713 .388 r
F
.26382 .49529 m .26642 .49062 L .26188 .49355 L .675 .735 .895 r
F
.26382 .49529 m .26934 .49323 L .26642 .49062 L F
.26934 .49323 m .26929 .49039 L .26638 .48777 L .932 .65 .484 r
F
.25547 .49787 m .28076 .49048 L .27591 .48603 L .654 .726 .902 r
F
.25322 .49917 m .25601 .49829 L .25547 .49787 L F
.2561 .49818 m .25673 .49794 L .25579 .49748 L .675 .735 .895 r
F
.25673 .49794 m .25831 .49736 L .25689 .49677 L F
.26471 .49595 m .27147 .49383 L .26521 .4938 L F
.25903 .49661 m .26532 .49664 L .26496 .49447 L F
.26532 .49664 m .27107 .49343 L .26496 .49447 L F
.26501 .49732 m .26934 .49323 L .26382 .49529 L F
.25601 .49829 m .28076 .49048 L .25547 .49787 L .654 .726 .902 r
F
.25573 .49807 m .255 .50458 L .25556 .50502 L .908 .63 .502 r
F
.2559 .49113 m .25545 .49785 L .25573 .49807 L F
.25554 .49828 m .25556 .50113 L .25547 .49833 L .353 .175 .495 r
F
.25511 .50146 m .25525 .50193 L .25536 .50177 L .654 .726 .902 r
F
.25464 .50156 m .25531 .50131 L .25528 .50835 L .515 .301 .526 r
F
.25545 .49785 m .255 .50458 L .25573 .49807 L .908 .63 .502 r
F
.26707 .49492 m .28236 .50058 L .28369 .49868 L .654 .726 .902 r
F
.2564 .49886 m .2561 .49836 L .2564 .49902 L .986 .729 .348 r
F
.25612 .49822 m .2561 .49836 L .2564 .49886 L F
.26471 .49595 m .27072 .49706 L .27147 .49383 L .675 .735 .895 r
F
.27161 .49668 m .27156 .49383 L .27103 .49058 L .865 .665 .134 r
F
.25878 .49769 m .26532 .49664 L .25903 .49661 L .675 .735 .895 r
F
.27161 .49668 m .27103 .49058 L .27107 .49343 L .865 .665 .134 r
F
.26532 .49664 m .27161 .49668 L .27107 .49343 L .675 .735 .895 r
F
.27086 .49992 m .27156 .49383 L .27161 .49668 L 0 0 .242 r
F
.27166 .49952 m .27107 .49343 L .27112 .49627 L .865 .665 .134 r
F
.2589 .49837 m .26382 .49529 L .25831 .49736 L .675 .735 .895 r
F
.2589 .49837 m .26501 .49732 L .26382 .49529 L F
.2634 .49795 m .27072 .49706 L .26471 .49595 L F
.26501 .49732 m .27112 .49627 L .26934 .49323 L F
.25814 .49762 m .28374 .49552 L .28076 .49048 L .654 .726 .902 r
F
.25608 .5007 m .25607 .5007 L .25605 .49506 L .065 0 .408 r
F
.25322 .49917 m .25744 .49867 L .25814 .49762 L .654 .726 .902 r
F
.27086 .49992 m .27081 .49708 L .27156 .49383 L 0 0 .242 r
F
.26482 .49881 m .27161 .49668 L .26532 .49664 L .675 .735 .895 r
F
.25878 .49769 m .26482 .49881 L .26532 .49664 L F
.27166 .49952 m .27161 .49668 L .27107 .49343 L .865 .665 .134 r
F
.2634 .49795 m .26875 .50006 L .27072 .49706 L .675 .735 .895 r
F
.26537 .49949 m .27112 .49627 L .26501 .49732 L F
.25744 .49867 m .28374 .49552 L .25814 .49762 L .654 .726 .902 r
F
.25611 .50764 m .2561 .50765 L .25607 .5007 L .065 0 .408 r
F
.25611 .50764 m .25607 .5007 L .25608 .5007 L F
.26135 .49966 m .26875 .50006 L .2634 .49795 L .675 .735 .895 r
F
.26887 .50294 m .27081 .49708 L .27086 .49992 L .108 .001 .438 r
F
.26887 .50294 m .26883 .50009 L .27081 .49708 L F
.2635 .50082 m .27086 .49992 L .26482 .49881 L .675 .735 .895 r
F
.25812 .49869 m .2635 .50082 L .26482 .49881 L F
.27091 .50277 m .27086 .49992 L .27161 .49668 L 0 0 .242 r
F
.26482 .49881 m .27086 .49992 L .27161 .49668 L .675 .735 .895 r
F
.25812 .49869 m .26482 .49881 L .25878 .49769 L F
.27091 .50277 m .27161 .49668 L .27166 .49952 L 0 0 .242 r
F
.26537 .49949 m .27166 .49952 L .27112 .49627 L .675 .735 .895 r
F
.25908 .49945 m .26537 .49949 L .26501 .49732 L F
.25908 .49945 m .26501 .49732 L .2589 .49837 L F
.25322 .49917 m .28463 .50082 L .28374 .49552 L .654 .726 .902 r
F
.25464 .50155 m .25531 .50131 L .25464 .50156 L .515 .301 .526 r
F
.25449 .50439 m .2548 .50451 L .25504 .49738 L .809 .541 .533 r
F
.25504 .49738 m .2548 .50451 L .255 .50458 L F
.25322 .49917 m .25703 .50003 L .25787 .49942 L .654 .726 .902 r
F
.25616 .50046 m .25618 .50754 L .25608 .50059 L .065 0 .408 r
F
.25608 .50069 m .25611 .50764 L .25608 .5007 L F
.2564 .49902 m .2561 .49836 L .25606 .50541 L .986 .729 .348 r
F
.2567 .50014 m .25634 .50082 L .25753 .50029 L .675 .735 .895 r
F
.25634 .50082 m .25817 .50154 L .25753 .50029 L F
.25639 .50053 m .28008 .5107 L .25648 .49991 L .654 .726 .902 r
F
.2538 .50416 m .26904 .48975 L .26153 .48733 L F
.25275 .50645 m .25483 .50432 L .2538 .50416 L F
.25787 .49942 m .25862 .49961 L .25877 .49946 L F
.26135 .49966 m .26568 .50263 L .26875 .50006 L .675 .735 .895 r
F
.2635 .50082 m .26887 .50294 L .27086 .49992 L F
.26487 .50165 m .27091 .50277 L .27166 .49952 L F
.25862 .49961 m .28338 .50599 L .25877 .49946 L .654 .726 .902 r
F
.26487 .50165 m .27166 .49952 L .26537 .49949 L .675 .735 .895 r
F
.25883 .50053 m .26487 .50165 L .26537 .49949 L F
.25883 .50053 m .26537 .49949 L .25908 .49945 L F
.25877 .49946 m .28338 .50599 L .28463 .50082 L .654 .726 .902 r
F
.25703 .50003 m .28338 .50599 L .25787 .49942 L F
.25556 .50112 m .25598 .50783 L .25556 .50113 L .353 .175 .495 r
F
.25574 .50091 m .25598 .50783 L .25556 .50107 L F
.25556 .50502 m .25586 .50525 L .2561 .49818 L .908 .63 .502 r
F
.2565 .49976 m .25655 .49937 L .25652 .50642 L 0 0 .125 r
F
.25483 .50432 m .26904 .48975 L .2538 .50416 L .654 .726 .902 r
F
.25358 .49708 m .25341 .50411 L .25379 .49711 L .734 .477 .54 r
F
.25582 .50306 m .25884 .5067 L .26149 .50538 L .675 .735 .895 r
F
.2564 .49902 m .25606 .50541 L .2563 .50595 L .986 .729 .348 r
F
.25649 .49696 m .25652 .50642 L .25646 .50684 L 0 0 .125 r
F
.25483 .50432 m .27545 .49331 L .26904 .48975 L .654 .726 .902 r
F
.25275 .50645 m .25611 .5045 L .25483 .50432 L F
.25644 .50696 m .25643 .50705 L .25644 .50015 L 0 0 .125 r
F
.25644 .50015 m .25643 .50705 L .25641 .5072 L F
.25646 .50684 m .25644 .50696 L .25646 .50003 L F
.25638 .50611 m .25643 .50623 L .25655 .49937 L .986 .729 .348 r
F
.25655 .49937 m .25643 .50623 L .25652 .50642 L F
.2563 .50595 m .25638 .50611 L .25648 .49922 L F
.25611 .5045 m .27545 .49331 L .25483 .50432 L .654 .726 .902 r
F
.25322 .49917 m .253 .4993 L .25304 .49936 L F
.25358 .49708 m .25287 .49697 L .25283 .50402 L .734 .477 .54 r
F
.25275 .50645 m .25267 .50888 L .25363 .50879 L .654 .726 .902 r
F
.25531 .50131 m .25541 .50826 L .25528 .50835 L .353 .175 .495 r
F
.26033 .50779 m .25945 .50583 L .25576 .50098 L .654 .726 .902 r
F
.25275 .50645 m .28328 .50281 L .2803 .49776 L F
.25341 .50411 m .25283 .50402 L .25266 .53535 L .734 .477 .54 r
F
.25279 .49942 m .25396 .49702 L .25384 .49701 L .675 .735 .895 r
F
.25358 .49708 m .25283 .50402 L .25341 .50411 L .734 .477 .54 r
F
.25341 .50411 m .25266 .53535 L .25358 .50413 L F
.25341 .50411 m .25358 .50413 L .25379 .49711 L F
.25359 .49698 m .25379 .497 L .25387 .4942 L F
.25372 .49136 m .25287 .49697 L .25358 .49708 L F
.25287 .49691 m .25455 .49538 L .25293 .49523 L .675 .735 .895 r
F
.25279 .49942 m .25384 .49701 L .25287 .49691 L F
.25397 .49421 m .25379 .497 L .25396 .49702 L .734 .477 .54 r
F
.25384 .49701 m .25455 .49538 L .25287 .49691 L .675 .735 .895 r
F
.25358 .49708 m .25379 .49711 L .25379 .497 L .734 .477 .54 r
F
.25358 .49708 m .25379 .497 L .25359 .49698 L F
.25365 .49417 m .25387 .4942 L .25399 .49009 L F
.25386 .494 m .2545 .49254 L .25284 .49409 L .675 .735 .895 r
F
.25291 .48993 m .25279 .4941 L .25289 .49409 L .66 .416 .54 r
F
.25289 .49409 m .25284 .49409 L .25282 .4941 L .675 .735 .895 r
F
.25372 .49136 m .25289 .49409 L .2533 .49414 L .734 .477 .54 r
F
.25386 .494 m .25284 .49409 L .25289 .49409 L .675 .735 .895 r
F
.25378 .49419 m .25383 .49416 L .2538 .49415 L F
.25383 .49416 m .25601 .49296 L .2538 .49415 L F
.2548 .49429 m .25601 .49296 L .25378 .49419 L F
.25399 .49009 m .25387 .4942 L .25397 .49421 L .734 .477 .54 r
F
.25387 .4942 m .25379 .497 L .25397 .49421 L F
.25379 .497 m .25358 .50413 L .25396 .49702 L F
.25384 .49701 m .25396 .49702 L .25385 .49698 L .675 .735 .895 r
F
.25456 .4944 m .25397 .49421 L .25396 .49702 L .809 .541 .533 r
F
.25467 .49444 m .25505 .49457 L .25476 .49434 L .675 .735 .895 r
F
.25282 .49409 m .2545 .49254 L .25288 .49239 L F
.25282 .4941 m .25284 .49409 L .25282 .49409 L F
.25284 .49409 m .2545 .49254 L .25282 .49409 L F
.25289 .49409 m .2527 .49698 L .25287 .49697 L .66 .416 .54 r
F
.25279 .4941 m .2527 .49698 L .25289 .49409 L F
.25298 .47672 m .25266 .48994 L .25291 .48993 L F
.25097 .49165 m .25121 .48969 L .24968 .4901 L .675 .735 .895 r
F
.25183 .49137 m .25121 .48969 L .25097 .49165 L F
.2514 .49712 m .25123 .5042 L .25152 .49709 L .567 .342 .533 r
F
.22613 .49305 m .22304 .49235 L .22298 .49259 L .654 .726 .902 r
F
.22613 .49305 m .22298 .49259 L .2218 .49753 L F
.24375 .50442 m .22586 .49491 L .22257 .49963 L F
.24728 .50148 m .24176 .50354 L .2437 .50528 L .675 .735 .895 r
F
.24021 .49935 m .23446 .50256 L .24057 .50151 L F
.24762 .50425 m .22586 .49491 L .24375 .50442 L .654 .726 .902 r
F
.25275 .50645 m .25075 .50851 L .25172 .5087 L F
.25232 .50404 m .25174 .50407 L .25157 .53544 L .66 .416 .54 r
F
.25029 .50458 m .24935 .53656 L .25043 .50449 L .398 .209 .505 r
F
.25029 .50458 m .25043 .50449 L .25068 .49731 L F
.25373 .49136 m .25399 .49139 L .25375 .49131 L .675 .735 .895 r
F
.25483 .4904 m .25399 .49139 L .25475 .49165 L .809 .541 .533 r
F
.25462 .4916 m .25594 .49014 L .25375 .49131 L .675 .735 .895 r
F
.25449 .50439 m .25392 .50418 L .25375 .53548 L .809 .541 .533 r
F
.25392 .50418 m .25266 .53535 L .25375 .53548 L .734 .477 .54 r
F
.25358 .50413 m .25266 .53535 L .25392 .50418 L F
.26192 .50536 m .27156 .50677 L .28328 .50281 L .654 .726 .902 r
F
.2753 .50727 m .30712 .51483 L .28041 .50337 L F
.26986 .50735 m .28417 .50809 L .28383 .5061 L F
.26986 .50735 m .28383 .5061 L .28328 .50281 L F
.25473 .50856 m .25528 .50835 L .25511 .5398 L .515 .301 .526 r
F
.25556 .50502 m .255 .50458 L .25483 .53586 L .908 .63 .502 r
F
.2556 .5048 m .2803 .49776 L .27545 .49331 L .654 .726 .902 r
F
.25669 .50521 m .2803 .49776 L .2556 .5048 L F
.25275 .50645 m .25538 .50832 L .25562 .50823 L F
.25275 .50645 m .25504 .50923 L .25557 .50845 L F
.25449 .50439 m .25375 .53548 L .2548 .50451 L .809 .541 .533 r
F
.255 .50458 m .25375 .53548 L .25483 .53586 L F
.2548 .50451 m .25375 .53548 L .255 .50458 L F
.25556 .50502 m .25483 .53586 L .25586 .50525 L .908 .63 .502 r
F
.25636 .50727 m .25641 .5072 L .2564 .50794 L .065 0 .408 r
F
.25636 .50727 m .2564 .50794 L .25624 .53855 L F
.25618 .50754 m .25636 .50727 L .25624 .53855 L F
.25638 .50611 m .25589 .53668 L .25643 .50623 L .986 .729 .348 r
F
.25562 .50823 m .25799 .50969 L .25629 .50797 L .654 .726 .902 r
F
.25799 .50969 m .27592 .52081 L .25759 .50882 L F
.25799 .50969 m .25759 .50882 L .25629 .50797 L F
.25617 .50857 m .27449 .5219 L .27592 .52081 L F
.26318 .51093 m .27592 .52081 L .27962 .51798 L F
.25528 .50835 m .25581 .53923 L .25511 .5398 L .353 .175 .495 r
F
.2556 .50811 m .25598 .50783 L .25581 .53923 L F
.25606 .50541 m .25483 .53586 L .25589 .53668 L .908 .63 .502 r
F
.25586 .50525 m .25483 .53586 L .25606 .50541 L F
.25644 .50696 m .25635 .53773 L .25643 .50705 L 0 0 .125 r
F
.25548 .51371 m .26024 .52639 L .25571 .51206 L .654 .726 .902 r
F
.25618 .50754 m .25624 .53855 L .25611 .50764 L .065 0 .408 r
F
.25641 .5072 m .25635 .53773 L .25624 .53855 L 0 0 .125 r
F
.25643 .50705 m .25635 .53773 L .25641 .5072 L F
.25646 .50684 m .25635 .53773 L .25644 .50696 L F
.25646 .50684 m .25652 .50642 L .25635 .53773 L F
.25652 .50642 m .25589 .53668 L .25635 .53773 L .986 .729 .348 r
F
.25643 .50623 m .25589 .53668 L .25652 .50642 L F
.25611 .50764 m .25624 .53855 L .2561 .50765 L .065 0 .408 r
F
.25598 .50783 m .25624 .53855 L .25581 .53923 L F
.2563 .50595 m .25589 .53668 L .25638 .50611 L .986 .729 .348 r
F
.2583 .5104 m .26788 .52477 L .27449 .5219 L .654 .726 .902 r
F
.25557 .50845 m .26017 .51455 L .2583 .5104 L F
.26017 .51455 m .26788 .52477 L .2583 .5104 L F
.25592 .51064 m .26024 .52639 L .26503 .52538 L F
.25577 .51164 m .26024 .52639 L .25592 .51064 L F
.26103 .51648 m .26503 .52538 L .26788 .52477 L F
.2561 .50765 m .25624 .53855 L .25598 .50783 L .065 0 .408 r
F
.2563 .50595 m .25606 .50541 L .25589 .53668 L .986 .729 .348 r
F
.25489 .50945 m .26024 .52639 L .25504 .50923 L .654 .726 .902 r
F
.25279 .49942 m .25005 .50119 L .25085 .50156 L .675 .735 .895 r
F
.25077 .50985 m .25079 .50989 L .25145 .50928 L .654 .726 .902 r
F
.25075 .50851 m .25067 .50859 L .25172 .5087 L F
.25057 .50831 m .2511 .50858 L .25093 .54018 L .844 .571 .525 r
F
.24911 .5076 m .24612 .50724 L .24211 .50981 L .654 .726 .902 r
F
.25275 .50645 m .24795 .50702 L .24911 .5076 L F
.24795 .50702 m .24612 .50724 L .24911 .5076 L F
.25275 .50645 m .24911 .5076 L .25001 .50804 L F
.25123 .5042 m .25064 .50436 L .25047 .53578 L .567 .342 .533 r
F
.2514 .49712 m .25064 .50436 L .25123 .5042 L F
.24731 .50522 m .24172 .50396 L .24533 .50574 L .654 .726 .902 r
F
.24731 .50522 m .24533 .50574 L .24607 .5061 L F
.24057 .50151 m .23625 .5056 L .24176 .50354 L .675 .735 .895 r
F
.24057 .50151 m .23446 .50256 L .23625 .5056 L F
.24172 .50396 m .22257 .49963 L .24607 .5061 L .654 .726 .902 r
F
.2506 .51142 m .25057 .51771 L .25041 .50824 L .844 .571 .525 r
F
.2506 .51142 m .25041 .50824 L .25051 .50828 L F
.25064 .50436 m .24935 .53656 L .25047 .53578 L .398 .209 .505 r
F
.25068 .49731 m .25043 .50449 L .25064 .50436 L F
.25043 .50449 m .24935 .53656 L .25064 .50436 L F
.2437 .50528 m .243 .51023 L .24627 .50663 L .675 .735 .895 r
F
.2437 .50528 m .23916 .50821 L .243 .51023 L F
.24612 .50724 m .24428 .50601 L .23393 .5087 L .654 .726 .902 r
F
.25275 .50645 m .24777 .50619 L .24612 .50724 L F
.24777 .50619 m .24428 .50601 L .24612 .50724 L F
.24176 .50354 m .23625 .5056 L .23916 .50821 L .675 .735 .895 r
F
.24428 .50601 m .22133 .50481 L .23393 .5087 L .654 .726 .902 r
F
.25275 .50645 m .25001 .50804 L .25082 .50844 L F
.25123 .5042 m .25047 .53578 L .2514 .50416 L .567 .342 .533 r
F
.25123 .5042 m .2514 .50416 L .25182 .48998 L F
.25012 .50469 m .24935 .53656 L .25029 .50458 L .398 .209 .505 r
F
.2503 .50112 m .25041 .50824 L .25015 .50104 L .844 .571 .525 r
F
.25012 .50469 m .25029 .50458 L .2505 .49742 L .398 .209 .505 r
F
.24211 .50981 m .23393 .5087 L .22522 .51513 L .654 .726 .902 r
F
.24612 .50724 m .23393 .5087 L .24211 .50981 L F
.23393 .5087 m .22224 .5101 L .22308 .51152 L F
.23393 .5087 m .22308 .51152 L .22522 .51513 L F
.25174 .50407 m .25047 .53578 L .25157 .53544 L .567 .342 .533 r
F
.2514 .50416 m .25047 .53578 L .25174 .50407 L F
.24906 .50682 m .2492 .51511 L .24892 .53196 L .989 .721 .393 r
F
.24915 .50697 m .2492 .51511 L .24906 .50682 L F
.24975 .50777 m .24994 .5397 L .24965 .50768 L .927 .648 .491 r
F
.25012 .50469 m .24952 .50507 L .24935 .53656 L .398 .209 .505 r
F
.25029 .49755 m .24952 .50507 L .25012 .50469 L F
.24071 .5107 m .22522 .51513 L .22874 .51835 L .654 .726 .902 r
F
.24071 .5107 m .22874 .51835 L .23008 .51958 L F
.24924 .50713 m .24927 .53911 L .24918 .50703 L .989 .721 .393 r
F
.24936 .50537 m .24883 .5376 L .24943 .50525 L 0 0 .368 r
F
.24924 .50713 m .24944 .5075 L .24927 .53911 L .989 .721 .393 r
F
.2492 .51511 m .24927 .53911 L .24892 .53196 L F
.24892 .53196 m .24927 .53911 L .24889 .53841 L F
.24952 .50507 m .24883 .5376 L .24935 .53656 L 0 0 .368 r
F
.24943 .50525 m .24883 .5376 L .24952 .50507 L F
.24383 .5156 m .23008 .51958 L .23648 .52313 L .654 .726 .902 r
F
.24643 .5108 m .23008 .51958 L .24383 .5156 L F
.23032 .48661 m .22366 .48511 L .22354 .48562 L F
.23032 .48661 m .22354 .48562 L .22243 .49026 L F
.24906 .49944 m .24903 .5064 L .24905 .4993 L .798 .638 .081 r
F
.24903 .5064 m .24889 .53841 L .24902 .50628 L F
.24383 .5156 m .24303 .51707 L .24938 .51119 L .654 .726 .902 r
F
.24383 .5156 m .24938 .51119 L .24937 .51105 L F
.24903 .5064 m .24906 .50682 L .24889 .53841 L .798 .638 .081 r
F
.2493 .50999 m .24383 .5156 L .24937 .51101 L .654 .726 .902 r
F
.24383 .5156 m .23648 .52313 L .24303 .51707 L F
.24938 .49835 m .24928 .50552 L .24948 .49817 L 0 0 .368 r
F
.24928 .50552 m .24883 .5376 L .24936 .50537 L F
.24905 .49911 m .24902 .50628 L .24904 .49899 L .798 .638 .081 r
F
.24902 .50628 m .24889 .53841 L .24901 .50618 L F
.24938 .49835 m .24904 .49899 L .249 .50603 L 0 0 .368 r
F
.249 .50603 m .24889 .53841 L .24883 .5376 L .798 .638 .081 r
F
.24901 .50618 m .24889 .53841 L .249 .50603 L F
.24928 .50552 m .249 .50603 L .24883 .5376 L 0 0 .368 r
F
.24303 .51707 m .23648 .52313 L .23927 .52403 L .654 .726 .902 r
F
.24303 .51707 m .23927 .52403 L .24399 .52554 L F
.42751 .97698 m .42458 .9736 L .42484 .9758 L .86 .578 .509 r
F
.42777 .97918 m .42751 .97698 L .42484 .9758 L F
0 g
.42751 .97698 m
.42953 .9786 L
s
.58899 .75986 m .57994 .74843 L .57936 .75961 L .683 .77 .917 r
F
.58899 .75986 m .59439 .7488 L .57994 .74843 L F
.67947 .39422 m .67925 .45167 L .6797 .45272 L .982 .725 .331 r
F
.67947 .39422 m .67903 .39317 L .67925 .45167 L F
.30712 .51483 m .34368 .51225 L .31369 .50546 L .654 .726 .902 r
F
.28041 .50337 m .30712 .51483 L .31369 .50546 L F
.56612 .87431 m .56851 .88336 L .57211 .87619 L .644 .733 .913 r
F
.127 .923 .03 r
.56691 .90355 m
.56734 .88299 L
s
.56612 .87431 m .55954 .88054 L .56851 .88336 L .644 .733 .913 r
F
0 g
.56851 .88336 m
.57822 .88471 L
s
.4122 .982 m .40918 .98019 L .40702 .98204 L .692 .759 .904 r
F
0 g
.40563 .98414 m
.40702 .98204 L
s
.41405 .98101 m .40918 .98019 L .4122 .982 L .692 .759 .904 r
F
.55346 .77662 m .54058 .76939 L .53128 .77684 L .683 .771 .917 r
F
.56142 .77264 m .54058 .76939 L .55346 .77662 L F
.41593 .97814 m .4149 .97551 L .4117 .97652 L .692 .759 .904 r
F
.4182 .97783 m .4149 .97551 L .41593 .97814 L F
.54058 .76939 m .53078 .77227 L .53128 .77684 L .405 .261 .57 r
F
0 g
.52524 .78526 m
.53128 .77684 L
s
.54058 .76939 m .54009 .76482 L .53078 .77227 L .405 .261 .57 r
F
0 g
.52475 .78069 m
.53078 .77227 L
s
.588 .8845 m .59743 .87898 L .59719 .88275 L .598 .382 .559 r
F
.5851 .87695 m .588 .8845 L .59719 .88275 L .644 .733 .913 r
F
.127 .923 .03 r
.63416 .86273 m
.63426 .85921 L
s
.57858 .87709 m .588 .8845 L .5851 .87695 L .644 .733 .913 r
F
0 g
.57822 .88471 m
.588 .8845 L
s
.72061 .53508 m .74099 .5192 L .74059 .52647 L .494 .288 .528 r
F
.70577 .51677 m .72061 .53508 L .74059 .52647 L .654 .726 .902 r
F
.69042 .52001 m .72061 .53508 L .70577 .51677 L F
0 g
.69761 .53993 m
.72061 .53508 L
s
.4182 .97783 m .41831 .97503 L .4149 .97551 L .692 .759 .904 r
F
.67196 .39408 m .67222 .4534 L .67218 .45259 L .772 .616 .051 r
F
.6725 .39305 m .67196 .39408 L .67218 .45259 L 0 0 .382 r
F
.559 .64484 m .57113 .62949 L .57145 .63517 L .39 .237 .55 r
F
.54178 .6344 m .559 .64484 L .57145 .63517 L .673 .758 .914 r
F
.53114 .63943 m .559 .64484 L .54178 .6344 L F
0 g
.54304 .65238 m
.559 .64484 L
s
.48096 .52428 m .45418 .51276 L .44752 .52217 L .654 .726 .902 r
F
.48612 .52036 m .45418 .51276 L .48096 .52428 L F
.42484 .9758 m .42458 .9736 L .42145 .97294 L .793 .528 .536 r
F
0 g
.42458 .9736 m
.42725 .97479 L
s
.48665 .51316 m .46514 .49779 L .45488 .5056 L .654 .726 .902 r
F
.49325 .5103 m .46514 .49779 L .48665 .51316 L F
.53532 .52712 m .55333 .50956 L .53051 .52268 L F
.53532 .52712 m .56294 .51845 L .55333 .50956 L F
.42281 .98053 m .42196 .97733 L .42072 .98009 L .692 .759 .904 r
F
.42281 .98053 m .4251 .97799 L .42196 .97733 L F
.53082 .51547 m .54085 .49534 L .52449 .51194 L .654 .726 .902 r
F
.53082 .51547 m .55352 .50241 L .54085 .49534 L F
.45418 .51276 m .4174 .51536 L .44752 .52217 L F
.55191 .87645 m .55978 .87677 L .55954 .88054 L .856 .609 .565 r
F
.55191 .87645 m .55215 .87268 L .55978 .87677 L F
.56128 .86782 m .55978 .87677 L .56637 .87055 L .644 .733 .913 r
F
.56128 .86782 m .55215 .87268 L .55978 .87677 L F
0 g
.55978 .87677 m
.56259 .87765 L
s
.72118 .65919 m .70937 .64625 L .69336 .65379 L .673 .758 .915 r
F
.73346 .65593 m .70937 .64625 L .72118 .65919 L F
.73312 .65026 m .72746 .63567 L .70903 .64057 L .673 .758 .914 r
F
.74617 .64898 m .72746 .63567 L .73312 .65026 L F
.59743 .87898 m .60565 .87204 L .60541 .87581 L .502 .302 .541 r
F
.59719 .88275 m .59743 .87898 L .60541 .87581 L F
.59147 .87202 m .59743 .87898 L .60541 .87581 L .644 .733 .913 r
F
.127 .923 .03 r
.63591 .85867 m
.63598 .85517 L
s
.58535 .87319 m .59743 .87898 L .59147 .87202 L .644 .733 .913 r
F
0 g
.59164 .88009 m
.59743 .87898 L
s
.28928 .6424 m .27309 .64427 L .27338 .64994 L .515 .33 .567 r
F
.28928 .6424 m .28898 .63672 L .27309 .64427 L F
0 g
.26075 .65394 m
.27309 .64427 L
s
.33984 .65728 m .32752 .64126 L .32689 .65648 L .673 .758 .914 r
F
.33984 .65728 m .34696 .64246 L .32752 .64126 L F
.56879 .52851 m .59059 .50977 L .56294 .51845 L .654 .726 .902 r
F
.56879 .52851 m .59934 .52488 L .59059 .50977 L F
.41405 .98101 m .41195 .97871 L .40918 .98019 L .692 .759 .904 r
F
.41618 .98034 m .41195 .97871 L .41405 .98101 L F
.61976 .76058 m .61926 .75602 L .60788 .75128 L .86 .591 .53 r
F
0 g
.61926 .75602 m
.62784 .76252 L
s
.67903 .39317 m .6782 .45085 L .67925 .45167 L .91 .629 .497 r
F
.67903 .39317 m .67798 .39234 L .6782 .45085 L F
0 g
.67903 .39317 m
.67947 .39422 L
s
.67903 .39317 m
.67903 .39317 L
s
.4149 .97551 m .41144 .97432 L .4117 .97652 L .6 .388 .565 r
F
.4149 .97551 m .41464 .97331 L .41144 .97432 L F
0 g
.40867 .9758 m
.41144 .97432 L
s
.72631 .75494 m .71145 .76403 L .72803 .75755 L .683 .771 .917 r
F
.72631 .75494 m .70801 .75882 L .71145 .76403 L F
.41195 .97871 m .40892 .978 L .40918 .98019 L .515 .327 .565 r
F
0 g
.40702 .98204 m
.40918 .98019 L
s
.41195 .97871 m .4117 .97652 L .40892 .978 L .515 .327 .565 r
F
0 g
.40677 .97985 m
.40892 .978 L
s
.42072 .98009 m .41857 .97723 L .41846 .98002 L .692 .759 .904 r
F
.42072 .98009 m .42196 .97733 L .41857 .97723 L F
.56964 .76088 m .56537 .75034 L .55167 .75441 L .683 .77 .917 r
F
.57936 .75961 m .56537 .75034 L .56964 .76088 L F
.2685 .75589 m .2696 .75994 L .27007 .76451 L .79 .573 .007 r
F
.2685 .75589 m .26802 .75132 L .2696 .75994 L F
0 g
.2696 .75994 m
.27236 .76402 L
s
.67362 .39226 m .6725 .39305 L .67272 .45155 L .402 .214 .508 r
F
.6725 .39305 m .67218 .45259 L .67272 .45155 L 0 0 .382 r
F
0 g
.67196 .39408 m
.6725 .39305 L
s
.6725 .39305 m
.6725 .39305 L
s
.28701 .75031 m .26987 .75988 L .28804 .75603 L .683 .77 .917 r
F
.28701 .75031 m .26831 .7513 L .26987 .75988 L F
.77985 .75037 m .80015 .74352 L .78147 .74452 L .683 .771 .917 r
F
.76198 .74844 m .77985 .75037 L .78147 .74452 L F
.75996 .75123 m .77985 .75037 L .76198 .74844 L F
.42777 .97918 m .42484 .9758 L .4251 .97799 L .86 .578 .509 r
F
0 g
.42777 .97918 m
.42979 .9808 L
s
.74617 .64898 m .74705 .63376 L .72746 .63567 L .673 .758 .914 r
F
.4217 .97513 m .42145 .97294 L .41806 .97284 L .731 .482 .552 r
F
.42484 .9758 m .42145 .97294 L .4217 .97513 L .793 .528 .536 r
F
0 g
.42145 .97294 m
.42458 .9736 L
s
.79953 .64616 m .78402 .63352 L .78436 .63919 L .86 .596 .538 r
F
.79987 .65184 m .79953 .64616 L .78436 .63919 L F
0 g
.79953 .64616 m
.81093 .6554 L
s
.44093 .63755 m .45215 .64112 L .45247 .64679 L .931 .657 .497 r
F
.44093 .63755 m .44061 .63188 L .45215 .64112 L F
.46273 .62386 m .45215 .64112 L .47042 .63003 L .673 .757 .914 r
F
.46273 .62386 m .44061 .63188 L .45215 .64112 L F
0 g
.45215 .64112 m
.45766 .64364 L
s
.41618 .98034 m .41515 .9777 L .41195 .97871 L .692 .759 .904 r
F
.41846 .98002 m .41515 .9777 L .41618 .98034 L F
.49977 .62267 m .49256 .6375 L .50551 .6383 L .673 .757 .914 r
F
.79901 .76147 m .80095 .74808 L .80146 .75265 L 0 0 .401 r
F
.78106 .75953 m .79901 .76147 L .80146 .75265 L .683 .771 .917 r
F
0 g
.79289 .76989 m
.79901 .76147 L
s
.59339 .49889 m .60821 .50495 L .6078 .51223 L .928 .67 .525 r
F
.59339 .49889 m .59381 .49161 L .60821 .50495 L F
0 g
.60821 .50495 m
.61442 .50842 L
s
.41846 .98002 m .41857 .97723 L .41515 .9777 L .692 .759 .904 r
F
.57936 .75961 m .57994 .74843 L .56537 .75034 L .683 .77 .917 r
F
.56092 .76807 m .55203 .75884 L .54009 .76482 L F
.5701 .76535 m .55203 .75884 L .56092 .76807 L F
.4251 .97799 m .42484 .9758 L .4217 .97513 L .793 .528 .536 r
F
0 g
.42484 .9758 m
.42751 .97698 L
s
.45488 .5056 m .42822 .49412 L .41829 .50818 L .654 .726 .902 r
F
.30708 .76133 m .29234 .77042 L .30885 .76394 L .683 .77 .917 r
F
.30708 .76133 m .28881 .76521 L .29234 .77042 L F
.62174 .48283 m .60855 .50476 L .63129 .49169 L .654 .726 .902 r
F
.62174 .48283 m .59422 .49148 L .60855 .50476 L F
.42738 .50123 m .41784 .50808 L .4174 .51536 L .066 0 .392 r
F
.42738 .50123 m .42782 .49395 L .41784 .50808 L F
0 g
.41403 .52359 m
.41784 .50808 L
s
.59898 .77064 m .59547 .75777 L .59004 .76888 L .683 .771 .917 r
F
.59898 .77064 m .60888 .76042 L .59547 .75777 L F
.36093 .75678 m .38125 .7499 L .36246 .7509 L .683 .77 .917 r
F
.34291 .75484 m .36093 .75678 L .36246 .7509 L F
.34091 .75765 m .36093 .75678 L .34291 .75484 L F
.41831 .97503 m .41464 .97331 L .4149 .97551 L .669 .438 .561 r
F
.41831 .97503 m .41806 .97284 L .41464 .97331 L F
0 g
.41144 .97432 m
.41464 .97331 L
s
.74099 .5192 m .74138 .51192 L .75698 .50015 L .345 .168 .491 r
F
0 g
.73097 .5164 m
.74138 .51192 L
s
.77698 .46152 m
.83626 .5363 L
s
.31384 .65776 m .30794 .64318 L .28957 .64807 L .673 .758 .914 r
F
.32689 .65648 m .30794 .64318 L .31384 .65776 L F
.4217 .97513 m .41806 .97284 L .41831 .97503 L .731 .482 .552 r
F
0 g
.41464 .97331 m
.41806 .97284 L
s
.41806 .97284 m
.42145 .97294 L
s
.67798 .39234 m .67713 .45047 L .6782 .45085 L .81 .54 .531 r
F
.67798 .39234 m .6769 .39196 L .67713 .45047 L F
0 g
.67798 .39234 m
.67903 .39317 L
s
.67362 .39226 m .67272 .45155 L .67384 .45077 L .402 .214 .508 r
F
.67473 .39192 m .67362 .39226 L .67384 .45077 L .568 .343 .534 r
F
0 g
.6725 .39305 m
.67362 .39226 L
s
.71967 .49632 m .74106 .51169 L .75658 .49998 L .654 .726 .902 r
F
.70642 .50203 m .74106 .51169 L .71967 .49632 L F
.59934 .52488 m .59976 .5176 L .591 .50249 L .99 .743 .456 r
F
0 g
.59976 .5176 m
.60226 .53344 L
s
.6769 .39196 m .67604 .45034 L .67713 .45047 L .734 .477 .539 r
F
.6769 .39196 m .67582 .39183 L .67604 .45034 L F
0 g
.6769 .39196 m
.67798 .39234 L
s
.67473 .39192 m .67384 .45077 L .67495 .45043 L .568 .343 .534 r
F
.67582 .39183 m .67473 .39192 L .67495 .45043 L .66 .416 .54 r
F
0 g
.67362 .39226 m
.67473 .39192 L
s
.127 .923 .03 r
.66809 .51971 m
.66817 .51875 L
s
.41515 .9777 m .4117 .97652 L .41195 .97871 L .6 .388 .565 r
F
.41515 .9777 m .4149 .97551 L .4117 .97652 L F
0 g
.40892 .978 m
.4117 .97652 L
s
.67582 .39183 m .67495 .45043 L .67604 .45034 L .66 .416 .54 r
F
0 g
.67582 .39183 m
.6769 .39196 L
s
.67473 .39192 m
.67582 .39183 L
s
.40918 .98019 m
.41195 .97871 L
s
.58954 .76431 m .58045 .75283 L .57986 .76406 L .683 .77 .917 r
F
.58954 .76431 m .59497 .7532 L .58045 .75283 L F
.32689 .65648 m .32752 .64126 L .30794 .64318 L .673 .758 .914 r
F
.70903 .64057 m .69269 .64244 L .69302 .64811 L .517 .332 .569 r
F
.70903 .64057 m .70869 .6349 L .69269 .64244 L F
0 g
.6802 .65211 m
.69269 .64244 L
s
.38024 .65366 m .36465 .64102 L .36495 .64669 L .859 .596 .54 r
F
0 g
.38024 .65366 m
.3918 .66289 L
s
.75945 .65546 m .74739 .63944 L .74651 .65466 L .673 .758 .915 r
F
.75945 .65546 m .7668 .64064 L .74739 .63944 L F
.42196 .97733 m .4217 .97513 L .41831 .97503 L .731 .482 .552 r
F
.4251 .97799 m .4217 .97513 L .42196 .97733 L .793 .528 .536 r
F
0 g
.4217 .97513 m
.42484 .9758 L
s
.4251 .97799 m
.42777 .97918 L
s
.56103 .87159 m .55954 .88054 L .56612 .87431 L .644 .733 .913 r
F
.56103 .87159 m .55191 .87645 L .55954 .88054 L F
0 g
.55954 .88054 m
.56851 .88336 L
s
.54639 .8676 m .5524 .86892 L .55215 .87268 L .925 .677 .543 r
F
.54639 .8676 m .54663 .86383 L .5524 .86892 L F
0 g
.5524 .86892 m
.5558 .87074 L
s
.127 .923 .03 r
.66848 .51976 m
.66852 .51837 L
s
.59719 .88275 m .60541 .87581 L .60516 .87958 L .502 .302 .541 r
F
.59123 .87579 m .59719 .88275 L .60516 .87958 L .644 .733 .913 r
F
.127 .923 .03 r
.63585 .86218 m
.63591 .85867 L
s
.5851 .87695 m .59719 .88275 L .59123 .87579 L .644 .733 .913 r
F
0 g
.588 .8845 m
.59719 .88275 L
s
.55779 .86063 m .55254 .86884 L .56162 .864 L .645 .732 .913 r
F
.55779 .86063 m .5468 .86378 L .55254 .86884 L F
.68828 .75407 m .6892 .75812 L .68971 .76269 L .764 .552 0 r
F
.68828 .75407 m .68777 .7495 L .6892 .75812 L F
0 g
.6892 .75812 m
.69191 .76222 L
s
.60541 .87581 m .60565 .87204 L .61186 .86766 L .355 .182 .503 r
F
.127 .923 .03 r
.59528 2.19089 m
.63168 .94737 L
s
.63168 .94737 m
.63416 .86273 L
s
.60473 2.63091 m
.63389 .9736 L
s
.63389 .9736 m
.63585 .86218 L
s
0 g
.59993 .87432 m
.60565 .87204 L
s
.70674 .74849 m .68947 .75806 L .70768 .75421 L .683 .771 .917 r
F
.70674 .74849 m .68806 .74948 L .68947 .75806 L F
.59695 .86608 m .60552 .87196 L .6117 .8676 L .645 .732 .913 r
F
.59166 .86818 m .60552 .87196 L .59695 .86608 L F
.41857 .97723 m .4149 .97551 L .41515 .9777 L .669 .438 .561 r
F
.41857 .97723 m .41831 .97503 L .4149 .97551 L F
0 g
.4117 .97652 m
.4149 .97551 L
s
.49378 .62126 m .48059 .63468 L .49256 .6375 L .673 .757 .914 r
F
.42196 .97733 m .41831 .97503 L .41857 .97723 L .731 .482 .552 r
F
0 g
.4149 .97551 m
.41831 .97503 L
s
.41831 .97503 m
.4217 .97513 L
s
.127 .923 .03 r
.41493 3.10975 m
.42207 .84032 L
s
0 g
.42196 .97733 m
.4251 .97799 L
s
.61976 .76058 m .60788 .75128 L .60838 .75585 L .86 .591 .53 r
F
.62027 .76515 m .61976 .76058 L .60838 .75585 L F
0 g
.61976 .76058 m
.62834 .76708 L
s
.72682 .75951 m .71196 .7686 L .72854 .76212 L .683 .771 .917 r
F
.72682 .75951 m .70852 .76339 L .71196 .7686 L F
.26897 .76046 m .27007 .76451 L .27054 .76908 L .79 .573 .007 r
F
.26897 .76046 m .2685 .75589 L .27007 .76451 L F
.28729 .75489 m .27007 .76451 L .28834 .76064 L .683 .77 .917 r
F
.28729 .75489 m .2685 .75589 L .27007 .76451 L F
0 g
.27007 .76451 m
.27284 .76859 L
s
.78054 .75496 m .80095 .74808 L .78217 .74908 L .683 .771 .917 r
F
.76259 .75302 m .78054 .75496 L .78217 .74908 L F
.76055 .75583 m .78054 .75496 L .76259 .75302 L F
.3057 .74932 m .28804 .75603 L .30622 .75218 L .683 .77 .917 r
F
.3057 .74932 m .28701 .75031 L .28804 .75603 L F
.5701 .76535 m .5658 .75475 L .55203 .75884 L F
.57986 .76406 m .5658 .75475 L .5701 .76535 L F
0 g
.41195 .97871 m
.41515 .9777 L
s
.73346 .65593 m .7278 .64135 L .70937 .64625 L .673 .758 .915 r
F
.74651 .65466 m .7278 .64135 L .73346 .65593 L F
.49325 .5103 m .47834 .49207 L .46514 .49779 L .654 .726 .902 r
F
.50087 .50869 m .47834 .49207 L .49325 .5103 L F
.52449 .51194 m .52595 .49053 L .51704 .50953 L F
.52449 .51194 m .54085 .49534 L .52595 .49053 L F
.28957 .64807 m .27338 .64994 L .27368 .65561 L .515 .33 .567 r
F
0 g
.26133 .66528 m
.27368 .65561 L
s
.28957 .64807 m .28928 .6424 L .27338 .64994 L .515 .33 .567 r
F
0 g
.26104 .65961 m
.27338 .64994 L
s
.127 .923 .03 r
.28255 .63405 m
.28342 .6983 L
s
.56142 .77264 m .55253 .76342 L .54058 .76939 L .683 .771 .917 r
F
.5706 .76992 m .55253 .76342 L .56142 .77264 L F
.34234 .75026 m .36179 .74634 L .3431 .74733 L .683 .77 .917 r
F
0 g
.41857 .97723 m
.42196 .97733 L
s
.22271 .50282 m .19819 .51653 L .22569 .50786 L .654 .726 .902 r
F
.22271 .50282 m .19221 .50646 L .19819 .51653 L F
.57986 .76406 m .58045 .75283 L .5658 .75475 L .683 .77 .917 r
F
.36141 .76135 m .38173 .75447 L .36294 .75547 L F
.34338 .75941 m .36141 .76135 L .36294 .75547 L F
.34139 .76221 m .36141 .76135 L .34338 .75941 L F
.30693 .52222 m .34368 .51962 L .31354 .51281 L .654 .726 .902 r
F
.28008 .5107 m .30693 .52222 L .31354 .51281 L F
.27495 .51463 m .30693 .52222 L .28008 .5107 L F
0 g
.41515 .9777 m
.41857 .97723 L
s
.15898 .49424 m .16221 .50283 L .16173 .5101 L .931 .749 .27 r
F
0 g
.16619 .50205 m
.16642 .50233 L
s
.15898 .49424 m .15946 .48696 L .16221 .50283 L .931 .749 .27 r
F
0 g
.16096 .49561 m
.16619 .50205 L
s
.16221 .50283 m
.16621 .50957 L
s
.74651 .65466 m .74739 .63944 L .7278 .64135 L .673 .758 .915 r
F
.79987 .65184 m .78436 .63919 L .78471 .64487 L .86 .596 .538 r
F
0 g
.79987 .65184 m
.81127 .66107 L
s
.46304 .62954 m .45247 .64679 L .47073 .6357 L .673 .758 .914 r
F
.46304 .62954 m .44093 .63755 L .45247 .64679 L F
0 g
.45247 .64679 m
.46773 .65376 L
s
.50008 .62834 m .49288 .64317 L .50583 .64397 L .673 .758 .914 r
F
.67588 .48567 m .67492 .50578 L .69116 .50526 L .654 .726 .902 r
F
.66782 .48456 m .67492 .50578 L .67588 .48567 L F
.66782 .48456 m .65882 .50357 L .67492 .50578 L F
.19118 .48862 m .16266 .50278 L .19299 .49915 L F
.19118 .48862 m .15993 .48699 L .16266 .50278 L F
.48053 .53155 m .45374 .52003 L .44708 .52945 L F
.48568 .52763 m .45374 .52003 L .48053 .53155 L F
.57323 .86052 m .56668 .86672 L .57263 .86858 L .645 .732 .913 r
F
.58268 .86183 m .58556 .86934 L .59166 .86818 L F
.57943 .8619 m .58556 .86934 L .58268 .86183 L F
.57113 .62949 m .5708 .62382 L .57889 .61266 L .171 .076 .496 r
F
0 g
.56375 .6293 m
.5708 .62382 L
s
.48612 .52036 m .46449 .50491 L .45418 .51276 L .654 .726 .902 r
F
.49275 .51749 m .46449 .50491 L .48612 .52036 L F
.5349 .5344 m .55291 .51684 L .53009 .52996 L F
.5349 .5344 m .56252 .52573 L .55291 .51684 L F
.54614 .87137 m .55215 .87268 L .55191 .87645 L .925 .677 .543 r
F
.54614 .87137 m .54639 .8676 L .55215 .87268 L F
.55744 .86443 m .55215 .87268 L .56128 .86782 L .644 .733 .913 r
F
.55744 .86443 m .54639 .8676 L .55215 .87268 L F
0 g
.55215 .87268 m
.55555 .87451 L
s
.54922 .61653 m .57048 .62371 L .57853 .61261 L .673 .757 .914 r
F
.54097 .62295 m .57048 .62371 L .54922 .61653 L F
.53051 .52268 m .54059 .50245 L .52414 .51913 L .654 .726 .902 r
F
.53051 .52268 m .55333 .50956 L .54059 .50245 L F
.34368 .51962 m .34413 .51235 L .34791 .49682 L 0 0 .133 r
F
0 g
.33966 .51871 m
.34413 .51235 L
s
.45374 .52003 m .41696 .52263 L .44708 .52945 L .654 .726 .902 r
F
.59004 .76888 m .58095 .7574 L .58036 .76863 L .683 .771 .917 r
F
.59004 .76888 m .59547 .75777 L .58095 .7574 L F
.31369 .50546 m .34368 .51225 L .34744 .4968 L .654 .726 .902 r
F
.60541 .87581 m .61186 .86766 L .61162 .87143 L .355 .182 .503 r
F
.60516 .87958 m .60541 .87581 L .61162 .87143 L F
.59679 .8699 m .60541 .87581 L .61162 .87143 L .644 .733 .913 r
F
.59147 .87202 m .60541 .87581 L .59679 .8699 L F
0 g
.59968 .87809 m
.60541 .87581 L
s
.38125 .7499 m .38077 .74533 L .37923 .7367 L .783 .567 0 r
F
0 g
.37955 .74999 m
.38063 .74585 L
s
.51309 .62811 m .51887 .6427 L .53114 .63943 L .673 .758 .914 r
F
.36179 .74634 m .38048 .74534 L .37896 .73676 L .683 .77 .917 r
F
.51891 .6208 m .53082 .63376 L .54146 .62873 L .673 .757 .914 r
F
.56837 .53579 m .59017 .51705 L .56252 .52573 L .654 .726 .902 r
F
.56837 .53579 m .59893 .53215 L .59017 .51705 L F
.68879 .75864 m .68971 .76269 L .69021 .76726 L .764 .552 0 r
F
.68879 .75864 m .68828 .75407 L .68971 .76269 L F
.70706 .75307 m .68971 .76269 L .70801 .75882 L .683 .771 .917 r
F
.70706 .75307 m .68828 .75407 L .68971 .76269 L F
0 g
.68971 .76269 m
.69242 .76679 L
s
.72543 .7475 m .70768 .75421 L .7259 .75036 L .683 .771 .917 r
F
.72543 .7475 m .70674 .74849 L .70768 .75421 L F
.55203 .75884 m .53959 .76025 L .54009 .76482 L .524 .346 .582 r
F
.55203 .75884 m .55154 .75428 L .53959 .76025 L F
0 g
.53029 .7677 m
.53959 .76025 L
s
.36465 .64102 m .36434 .63535 L .34636 .63112 L .794 .544 .56 r
F
0 g
.36434 .63535 m
.37963 .64232 L
s
.70937 .64625 m .69302 .64811 L .69336 .65379 L .517 .332 .569 r
F
0 g
.68087 .66346 m
.69336 .65379 L
s
.70937 .64625 m .70903 .64057 L .69302 .64811 L .517 .332 .569 r
F
0 g
.68053 .65778 m
.69302 .64811 L
s
.62027 .76515 m .60838 .75585 L .60888 .76042 L .86 .591 .53 r
F
0 g
.62027 .76515 m
.62884 .77165 L
s
.76198 .74844 m .78147 .74452 L .76279 .74551 L .683 .771 .917 r
F
.59297 .50617 m .6078 .51223 L .60738 .5195 L .928 .67 .525 r
F
.59297 .50617 m .59339 .49889 L .6078 .51223 L F
.62105 .4902 m .6078 .51223 L .63065 .4991 L .654 .726 .902 r
F
.62105 .4902 m .59339 .49889 L .6078 .51223 L F
0 g
.6078 .51223 m
.61401 .5157 L
s
.66038 .48215 m .65882 .50357 L .66782 .48456 L .654 .726 .902 r
F
.66038 .48215 m .64394 .49876 L .65882 .50357 L F
.50087 .50869 m .49359 .48884 L .47834 .49207 L F
.50898 .50843 m .49359 .48884 L .50087 .50869 L F
.28777 .75946 m .27054 .76908 L .28881 .76521 L .683 .77 .917 r
F
.28777 .75946 m .26897 .76046 L .27054 .76908 L F
0 g
.27054 .76908 m
.27585 .7769 L
s
.51704 .50953 m .50982 .48831 L .50898 .50843 L .654 .726 .902 r
F
.51704 .50953 m .52595 .49053 L .50982 .48831 L F
.78106 .75953 m .80146 .75265 L .78269 .75364 L .683 .771 .917 r
F
.7631 .75758 m .78106 .75953 L .78269 .75364 L F
.76106 .76039 m .78106 .75953 L .7631 .75758 L F
.30609 .75389 m .28834 .76064 L .30661 .75676 L .683 .77 .917 r
F
.30609 .75389 m .28729 .75489 L .28834 .76064 L F
.684 .4854 m .69116 .50526 L .70642 .50203 L .654 .726 .902 r
F
.67588 .48567 m .69116 .50526 L .684 .4854 L F
.57918 .86571 m .57882 .87332 L .58535 .87319 L .644 .733 .913 r
F
.57595 .86525 m .57882 .87332 L .57918 .86571 L F
.57595 .86525 m .57235 .87242 L .57882 .87332 L F
.45418 .51276 m .42738 .50123 L .4174 .51536 L .654 .726 .902 r
F
.42694 .50851 m .4174 .51536 L .41696 .52263 L .066 0 .392 r
F
.42694 .50851 m .42738 .50123 L .4174 .51536 L F
0 g
.41359 .53086 m
.4174 .51536 L
s
.5706 .76992 m .5663 .75932 L .55253 .76342 L .683 .771 .917 r
F
.58036 .76863 m .5663 .75932 L .5706 .76992 L F
.74099 .5192 m .75698 .50015 L .75659 .50743 L .345 .168 .491 r
F
.74059 .52647 m .74099 .5192 L .75659 .50743 L F
.71949 .50375 m .74099 .5192 L .75659 .50743 L .654 .726 .902 r
F
.70617 .50949 m .74099 .5192 L .71949 .50375 L F
0 g
.73057 .52368 m
.74099 .5192 L
s
.4941 .62693 m .49288 .64317 L .50008 .62834 L .673 .758 .914 r
F
.4941 .62693 m .48091 .64035 L .49288 .64317 L F
.36179 .74634 m .37896 .73676 L .36077 .74062 L .683 .77 .917 r
F
.127 .923 .03 r
.3743 .67975 m
.37516 .73757 L
s
.3743 .67975 m
.37446 .73772 L
s
.3431 .74733 m .36179 .74634 L .36077 .74062 L .683 .77 .917 r
F
.34291 .75484 m .36246 .7509 L .34367 .75189 L F
.5707 .85916 m .56162 .864 L .56668 .86672 L .645 .732 .913 r
F
.58036 .76863 m .58095 .7574 L .5663 .75932 L .683 .771 .917 r
F
.58572 .86125 m .59166 .86818 L .59695 .86608 L .645 .732 .913 r
F
.58268 .86183 m .59166 .86818 L .58572 .86125 L F
.127 .923 .03 r
.34149 4.70583 m
.37263 4.30671 L
s
.37263 4.30671 m
.57142 1.75881 L
s
.46514 .49779 m .42822 .49412 L .45488 .5056 L .654 .726 .902 r
F
.59934 .52488 m .591 .50249 L .59059 .50977 L .99 .743 .456 r
F
.59893 .53215 m .59934 .52488 L .59059 .50977 L F
0 g
.59934 .52488 m
.60185 .54071 L
s
.57295 .86432 m .57235 .87242 L .57595 .86525 L .644 .733 .913 r
F
.127 .923 .03 r
.64906 .7637 m
.64935 .75994 L
s
.57295 .86432 m .56637 .87055 L .57235 .87242 L .644 .733 .913 r
F
.58245 .86564 m .58535 .87319 L .59147 .87202 L F
.57918 .86571 m .58535 .87319 L .58245 .86564 L F
.50898 .50843 m .50982 .48831 L .49359 .48884 L .654 .726 .902 r
F
.56309 .51126 m .57624 .48934 L .55352 .50241 L F
.56309 .51126 m .59059 .50262 L .57624 .48934 L F
.55719 .8682 m .55191 .87645 L .56103 .87159 L .644 .733 .913 r
F
.55719 .8682 m .54614 .87137 L .55191 .87645 L F
0 g
.55191 .87645 m
.55954 .88054 L
s
.80095 .74808 m .80043 .74351 L .79905 .73488 L .757 .546 0 r
F
0 g
.79914 .74817 m
.80034 .74385 L
s
.78147 .74452 m .80015 .74352 L .79877 .73494 L .683 .771 .917 r
F
.60516 .87958 m .61162 .87143 L .61138 .8752 L .355 .182 .503 r
F
.59655 .87367 m .60516 .87958 L .61138 .8752 L .644 .733 .913 r
F
.127 .923 .03 r
.64876 .76747 m
.64906 .7637 L
s
.59123 .87579 m .60516 .87958 L .59655 .87367 L .644 .733 .913 r
F
0 g
.59719 .88275 m
.60516 .87958 L
s
.48869 .61893 m .47042 .63003 L .48059 .63468 L .673 .757 .914 r
F
.3431 .74733 m .36077 .74062 L .34258 .74447 L .683 .77 .917 r
F
.74513 .75564 m .76106 .76039 L .7631 .75758 L .683 .771 .917 r
F
.78436 .63919 m .78402 .63352 L .76612 .62929 L .794 .544 .559 r
F
0 g
.78402 .63352 m
.79918 .64049 L
s
.52382 .61255 m .54097 .62295 L .54922 .61653 L .673 .757 .914 r
F
.38125 .7499 m .37923 .7367 L .37972 .74127 L .783 .567 0 r
F
.36246 .7509 m .38125 .7499 L .37972 .74127 L .683 .77 .917 r
F
.38173 .75447 m .38125 .7499 L .37972 .74127 L .783 .567 0 r
F
0 g
.38003 .75456 m
.38111 .75042 L
s
.127 .923 .03 r
.38161 .81212 m
.39617 8.82545 L
s
.49569 8.80031 m
.5019 8.41822 L
s
.5019 8.41822 m
.50985 7.92924 L
s
.50985 7.92924 m
.51805 7.4247 L
s
.63008 .53175 m
.63022 .52318 L
s
.40081 8.82545 m
.44418 7.25589 L
s
.44418 7.25589 m
.50207 5.16087 L
s
.50207 5.16087 m
.60593 1.40229 L
s
.57113 .62949 m .57889 .61266 L .57922 .61833 L .171 .076 .496 r
F
.57145 .63517 m .57113 .62949 L .57922 .61833 L F
.54976 .62227 m .57113 .62949 L .57922 .61833 L .673 .757 .914 r
F
.54146 .62873 m .57113 .62949 L .54976 .62227 L F
0 g
.56407 .63498 m
.57113 .62949 L
s
.70757 .75764 m .69021 .76726 L .70852 .76339 L .683 .771 .917 r
F
.70757 .75764 m .68879 .75864 L .69021 .76726 L F
0 g
.69021 .76726 m
.69538 .77508 L
s
.72584 .75207 m .70801 .75882 L .72631 .75494 L .683 .771 .917 r
F
.72584 .75207 m .70706 .75307 L .70801 .75882 L F
.55253 .76342 m .54009 .76482 L .54058 .76939 L .524 .346 .582 r
F
0 g
.53128 .77684 m
.54058 .76939 L
s
.55253 .76342 m .55203 .75884 L .54009 .76482 L .524 .346 .582 r
F
0 g
.53078 .77227 m
.54009 .76482 L
s
.60838 .75585 m .60788 .75128 L .59447 .74863 L .794 .542 .557 r
F
0 g
.60788 .75128 m
.61926 .75602 L
s
.57894 .86947 m .57858 .87709 L .5851 .87695 L .644 .733 .913 r
F
.127 .923 .03 r
.6265 .75195 m
.62662 .7448 L
s
.5757 .86902 m .57858 .87709 L .57894 .86947 L .644 .733 .913 r
F
.5757 .86902 m .57211 .87619 L .57858 .87709 L F
.78147 .74452 m .79877 .73494 L .78055 .73879 L .683 .771 .917 r
F
.76279 .74551 m .78147 .74452 L .78055 .73879 L F
.76259 .75302 m .78217 .74908 L .7634 .75007 L F
.49275 .51749 m .47776 .49916 L .46449 .50491 L .654 .726 .902 r
F
.5004 .51586 m .47776 .49916 L .49275 .51749 L F
.51922 .62647 m .53114 .63943 L .54178 .6344 L .673 .758 .914 r
F
.51309 .62811 m .53114 .63943 L .51922 .62647 L F
.54288 .86186 m .54663 .86383 L .54639 .8676 L .99 .751 .477 r
F
.54288 .86186 m .54312 .8581 L .54663 .86383 L F
0 g
.54663 .86383 m
.54979 .86662 L
s
.52414 .51913 m .52561 .49762 L .51666 .51672 L .654 .726 .902 r
F
.52414 .51913 m .54059 .50245 L .52561 .49762 L F
.55547 .85682 m .5468 .86378 L .55779 .86063 L .645 .732 .913 r
F
.55547 .85682 m .54331 .85808 L .5468 .86378 L F
.57041 .86295 m .56637 .87055 L .57295 .86432 L .644 .733 .913 r
F
.57041 .86295 m .56128 .86782 L .56637 .87055 L F
.30656 .75846 m .28881 .76521 L .30708 .76133 L .683 .77 .917 r
F
.30656 .75846 m .28777 .75946 L .28881 .76521 L F
.22224 .5101 m .19771 .52381 L .22522 .51513 L .654 .726 .902 r
F
.22224 .5101 m .19174 .51374 L .19771 .52381 L F
.3244 .74832 m .32002 .73778 L .31546 .73913 L .683 .77 .917 r
F
.58551 .86505 m .59147 .87202 L .59679 .8699 L .644 .733 .913 r
F
.58245 .86564 m .59147 .87202 L .58551 .86505 L F
.61162 .87143 m .61186 .86766 L .61589 .86237 L .089 0 .41 r
F
0 g
.60717 .87097 m
.61186 .86766 L
s
.60107 .86317 m .6117 .8676 L .61571 .86233 L .645 .732 .913 r
F
.127 .923 .03 r
.66877 .85509 m
.66906 .84622 L
s
.62407 .74554 m
.62614 .67061 L
s
.59695 .86608 m .6117 .8676 L .60107 .86317 L .645 .732 .913 r
F
.67547 .49305 m .67451 .51326 L .69083 .51273 L .654 .726 .902 r
F
.66737 .49193 m .67451 .51326 L .67547 .49305 L F
.66737 .49193 m .65832 .51103 L .67451 .51326 L F
.36246 .7509 m .37972 .74127 L .36143 .74515 L .683 .77 .917 r
F
.34367 .75189 m .36246 .7509 L .36143 .74515 L F
.57271 .86808 m .57211 .87619 L .5757 .86902 L .644 .733 .913 r
F
.57271 .86808 m .56612 .87431 L .57211 .87619 L F
.30764 .6375 m .28898 .63672 L .28928 .6424 L .603 .396 .574 r
F
.30764 .6375 m .30735 .63183 L .28898 .63672 L F
0 g
.27309 .64427 m
.28898 .63672 L
s
.30647 .5295 m .34323 .5269 L .31308 .52009 L .654 .726 .902 r
F
.27962 .51798 m .30647 .5295 L .31308 .52009 L F
.27449 .5219 m .30647 .5295 L .27962 .51798 L F
.34338 .75941 m .36294 .75547 L .34415 .75646 L .683 .77 .917 r
F
.36465 .64102 m .34636 .63112 L .34666 .63679 L .794 .544 .56 r
F
.127 .923 .03 r
.36448 .6232 m
.36452 .63385 L
s
.36495 .64669 m .36465 .64102 L .34666 .63679 L .794 .544 .56 r
F
0 g
.36465 .64102 m
.37994 .64799 L
s
.5822 .8694 m .5851 .87695 L .59123 .87579 L .644 .733 .913 r
F
.57894 .86947 m .5851 .87695 L .5822 .8694 L F
.1585 .50152 m .16173 .5101 L .16125 .51738 L .931 .749 .27 r
F
.1585 .50152 m .15898 .49424 L .16173 .5101 L F
.19039 .49588 m .16173 .5101 L .19221 .50646 L .654 .726 .902 r
F
.19039 .49588 m .15898 .49424 L .16173 .5101 L F
0 g
.16173 .5101 m
.16573 .51685 L
s
.48568 .52763 m .46406 .51219 L .45374 .52003 L .654 .726 .902 r
F
.49232 .52476 m .46406 .51219 L .48568 .52763 L F
.56879 .85747 m .55779 .86063 L .56162 .864 L .645 .732 .913 r
F
.76279 .74551 m .78055 .73879 L .76233 .74265 L .683 .771 .917 r
F
.53009 .52996 m .54017 .50973 L .52372 .52641 L .654 .726 .902 r
F
.53009 .52996 m .55291 .51684 L .54017 .50973 L F
.34368 .51962 m .34791 .49682 L .34746 .5041 L 0 0 .133 r
F
.34323 .5269 m .34368 .51962 L .34746 .5041 L F
.31354 .51281 m .34368 .51962 L .34746 .5041 L .654 .726 .902 r
F
0 g
.3392 .52599 m
.34368 .51962 L
s
.58837 .8602 m .59695 .86608 L .60107 .86317 L .645 .732 .913 r
F
.58572 .86125 m .59695 .86608 L .58837 .8602 L F
.80095 .74808 m .79905 .73488 L .79956 .73945 L .757 .546 0 r
F
.78217 .74908 m .80095 .74808 L .79956 .73945 L .683 .771 .917 r
F
.80146 .75265 m .80095 .74808 L .79956 .73945 L .757 .546 0 r
F
0 g
.79965 .75274 m
.80085 .74842 L
s
.30646 .74639 m .28701 .75031 L .3057 .74932 L .683 .77 .917 r
F
.34367 .75189 m .36143 .74515 L .34316 .74902 L F
.43359 .62099 m .4403 .62621 L .44061 .63188 L .987 .712 .384 r
F
.43359 .62099 m .43328 .61532 L .4403 .62621 L F
0 g
.4403 .62621 m
.44528 .63019 L
s
.38173 .75447 m .37972 .74127 L .3802 .74584 L .783 .567 0 r
F
.36294 .75547 m .38173 .75447 L .3802 .74584 L .683 .77 .917 r
F
.127 .923 .03 r
.38137 .67707 m
.38161 .81212 L
s
0 g
.37942 .76329 m
.38173 .75447 L
s
.45798 .61088 m .44064 .62609 L .46263 .61811 L .673 .757 .914 r
F
.45798 .61088 m .43364 .61525 L .44064 .62609 L F
.65989 .48951 m .65832 .51103 L .66737 .49193 L .654 .726 .902 r
F
.65989 .48951 m .64336 .5062 L .65832 .51103 L F
.68363 .49278 m .69083 .51273 L .70617 .50949 L F
.67547 .49305 m .69083 .51273 L .68363 .49278 L F
.22243 .49026 m .19299 .49915 L .22333 .49552 L F
.22243 .49026 m .19118 .48862 L .19299 .49915 L F
.65405 .47861 m .64394 .49876 L .66038 .48215 L F
.65405 .47861 m .63129 .49169 L .64394 .49876 L F
.62064 .49748 m .60738 .5195 L .63024 .50638 L F
.62064 .49748 m .59297 .50617 L .60738 .5195 L F
0 g
.60738 .5195 m
.62645 .53015 L
s
.72635 .75664 m .70852 .76339 L .72682 .75951 L .683 .771 .917 r
F
.72635 .75664 m .70757 .75764 L .70852 .76339 L F
.48901 .6246 m .48091 .64035 L .4941 .62693 L .673 .758 .914 r
F
.48901 .6246 m .47073 .6357 L .48091 .64035 L F
.74411 .7465 m .73991 .73595 L .73533 .73731 L .683 .771 .917 r
F
.54263 .86563 m .54639 .8676 L .54614 .87137 L .99 .751 .477 r
F
.54263 .86563 m .54288 .86186 L .54639 .8676 L F
.5551 .8606 m .54639 .8676 L .55744 .86443 L .644 .733 .913 r
F
.5551 .8606 m .54288 .86186 L .54639 .8676 L F
0 g
.54639 .8676 m
.54955 .87039 L
s
.69164 .48379 m .70642 .50203 L .71967 .49632 L .654 .726 .902 r
F
.684 .4854 m .70642 .50203 L .69164 .48379 L F
.48464 .61013 m .47028 .62424 L .48847 .6132 L .673 .757 .914 r
F
.48464 .61013 m .46263 .61811 L .47028 .62424 L F
.5004 .51586 m .49308 .49591 L .47776 .49916 L .654 .726 .902 r
F
.50856 .5156 m .49308 .49591 L .5004 .51586 L F
.57017 .86672 m .56612 .87431 L .57271 .86808 L .644 .733 .913 r
F
.57017 .86672 m .56103 .87159 L .56612 .87431 L F
.45374 .52003 m .42694 .50851 L .41696 .52263 L .654 .726 .902 r
F
0 g
.41315 .53814 m
.41696 .52263 L
s
.60838 .75585 m .59447 .74863 L .59497 .7532 L .794 .542 .557 r
F
.127 .923 .03 r
.59776 .75183 m
.59797 .74329 L
s
.60888 .76042 m .60838 .75585 L .59497 .7532 L .794 .542 .557 r
F
0 g
.60838 .75585 m
.61976 .76058 L
s
.51666 .51672 m .5094 .49539 L .50856 .5156 L .654 .726 .902 r
F
.51666 .51672 m .52561 .49762 L .5094 .49539 L F
.52423 .61828 m .54146 .62873 L .54976 .62227 L .673 .757 .914 r
F
.78217 .74908 m .79956 .73945 L .78125 .74332 L .683 .771 .917 r
F
.7634 .75007 m .78217 .74908 L .78125 .74332 L F
.31369 .50546 m .34744 .4968 L .31618 .49516 L .654 .726 .902 r
F
.28369 .49868 m .31369 .50546 L .31618 .49516 L F
.127 .923 .03 r
.30707 .47543 m
.3087 .49597 L
s
.28041 .50337 m .31369 .50546 L .28369 .49868 L .654 .726 .902 r
F
.72746 .63567 m .70869 .6349 L .70903 .64057 L .604 .397 .575 r
F
.72746 .63567 m .72712 .63 L .70869 .6349 L F
0 g
.69269 .64244 m
.70869 .6349 L
s
.7631 .75758 m .78269 .75364 L .76391 .75464 L .683 .771 .917 r
F
.58527 .86882 m .59123 .87579 L .59655 .87367 L .644 .733 .913 r
F
.5822 .8694 m .59123 .87579 L .58527 .86882 L F
.78436 .63919 m .76612 .62929 L .76646 .63496 L .794 .544 .559 r
F
.78471 .64487 m .78436 .63919 L .76646 .63496 L F
0 g
.78436 .63919 m
.79953 .64616 L
s
.74059 .52647 m .75659 .50743 L .7562 .51471 L .345 .168 .491 r
F
.71909 .51103 m .74059 .52647 L .7562 .51471 L .654 .726 .902 r
F
.70577 .51677 m .74059 .52647 L .71909 .51103 L F
0 g
.72061 .53508 m
.74059 .52647 L
s
.61162 .87143 m .61589 .86237 L .61565 .86614 L .089 0 .41 r
F
.61138 .8752 m .61162 .87143 L .61565 .86614 L F
.60093 .86698 m .61162 .87143 L .61565 .86614 L .644 .733 .913 r
F
.127 .923 .03 r
.62397 .74912 m
.62407 .74554 L
s
.66865 .85862 m
.66877 .85509 L
s
.59679 .8699 m .61162 .87143 L .60093 .86698 L .644 .733 .913 r
F
0 g
.60693 .87474 m
.61162 .87143 L
s
.28852 .74445 m .26831 .7513 L .28701 .75031 L .683 .77 .917 r
F
.30646 .74639 m .28852 .74445 L .28701 .75031 L F
.57145 .63517 m .57922 .61833 L .57954 .62401 L .171 .076 .496 r
F
.55008 .62795 m .57145 .63517 L .57954 .62401 L .673 .758 .914 r
F
.54178 .6344 m .57145 .63517 L .55008 .62795 L F
0 g
.559 .64484 m
.57145 .63517 L
s
.34258 .74447 m .35727 .73542 L .34083 .74187 L .683 .77 .917 r
F
.34258 .74447 m .36077 .74062 L .35727 .73542 L F
.59893 .53215 m .59059 .50977 L .59017 .51705 L .99 .743 .456 r
F
0 g
.59332 .50648 m
.59976 .5176 L
s
.59893 .53215 m
.60143 .54799 L
s
.46449 .50491 m .42738 .50123 L .45418 .51276 L .654 .726 .902 r
F
.36294 .75547 m .3802 .74584 L .36191 .74972 L .683 .77 .917 r
F
.34415 .75646 m .36294 .75547 L .36191 .74972 L F
.56849 .86126 m .56128 .86782 L .57041 .86295 L .644 .733 .913 r
F
.56849 .86126 m .55744 .86443 L .56128 .86782 L F
.50856 .5156 m .5094 .49539 L .49308 .49591 L .654 .726 .902 r
F
.58817 .86399 m .59679 .8699 L .60093 .86698 L .644 .733 .913 r
F
.58551 .86505 m .59679 .8699 L .58817 .86399 L F
.56294 .51845 m .57617 .49642 L .55333 .50956 L .654 .726 .902 r
F
.56294 .51845 m .59059 .50977 L .57617 .49642 L F
.5658 .75475 m .55154 .75428 L .55203 .75884 L .607 .405 .583 r
F
.5658 .75475 m .5653 .75018 L .55154 .75428 L F
0 g
.53959 .76025 m
.55154 .75428 L
s
.72623 .74457 m .70674 .74849 L .72543 .7475 L .683 .771 .917 r
F
.7634 .75007 m .78125 .74332 L .76293 .7472 L F
.28852 .74445 m .27057 .74252 L .26831 .7513 L .683 .77 .917 r
F
.27077 .74706 m .26802 .75132 L .2685 .75589 L 0 0 .379 r
F
0 g
.26871 .75507 m
.26885 .75587 L
s
.27077 .74706 m .2703 .74249 L .26802 .75132 L 0 0 .379 r
F
.30794 .64318 m .28928 .6424 L .28957 .64807 L .603 .396 .574 r
F
0 g
.27368 .65561 m
.28957 .64807 L
s
.30794 .64318 m .30764 .6375 L .28928 .6424 L .603 .396 .574 r
F
0 g
.27338 .64994 m
.28928 .6424 L
s
.34666 .63679 m .34636 .63112 L .32692 .62991 L .733 .497 .57 r
F
0 g
.34636 .63112 m
.36434 .63535 L
s
.36495 .64669 m .34666 .63679 L .34696 .64246 L .794 .544 .56 r
F
0 g
.36495 .64669 m
.38024 .65366 L
s
.127 .923 .03 r
.36452 .63385 m
.36479 .70403 L
s
.80146 .75265 m .79956 .73945 L .80008 .74402 L .757 .546 0 r
F
.78269 .75364 m .80146 .75265 L .80008 .74402 L .683 .771 .917 r
F
.127 .923 .03 r
.80044 .75979 m
.80253 .71721 L
s
0 g
.79901 .76147 m
.80146 .75265 L
s
.30685 .75095 m .28729 .75489 L .30609 .75389 L .683 .77 .917 r
F
.34415 .75646 m .36191 .74972 L .34363 .75359 L F
.55485 .86437 m .54614 .87137 L .55719 .8682 L .644 .733 .913 r
F
.55485 .86437 m .54263 .86563 L .54614 .87137 L F
0 g
.54614 .87137 m
.55191 .87645 L
s
.70835 .74263 m .68806 .74948 L .70674 .74849 L .683 .771 .917 r
F
.72623 .74457 m .70835 .74263 L .70674 .74849 L F
0 g
.25624 .47202 m
.25652 .41956 L
s
.49232 .52476 m .47733 .50644 L .46406 .51219 L .654 .726 .902 r
F
.49998 .52314 m .47733 .50644 L .49232 .52476 L F
0 g
.24971 .47191 m
.24999 .41944 L
s
.74462 .75107 m .75012 .73995 L .74528 .73983 L .683 .771 .917 r
F
.61138 .8752 m .61565 .86614 L .61541 .86991 L .089 0 .41 r
F
.60069 .87075 m .61138 .8752 L .61541 .86991 L .644 .733 .913 r
F
.127 .923 .03 r
.66853 .86214 m
.66865 .85862 L
s
.62388 .75271 m
.62397 .74912 L
s
.59655 .87367 m .61138 .8752 L .60069 .87075 L .644 .733 .913 r
F
0 g
.60516 .87958 m
.61138 .8752 L
s
.52372 .52641 m .52518 .5049 L .51623 .52399 L .654 .726 .902 r
F
.52372 .52641 m .54017 .50973 L .52518 .5049 L F
.76233 .74265 m .77714 .73359 L .76062 .74005 L .683 .771 .917 r
F
.76233 .74265 m .78055 .73879 L .77714 .73359 L F
.56763 .85557 m .55779 .86063 L .56879 .85747 L .645 .732 .913 r
F
.56763 .85557 m .55547 .85682 L .55779 .86063 L F
.60888 .76042 m .59497 .7532 L .59547 .75777 L .794 .542 .557 r
F
0 g
.60888 .76042 m
.62027 .76515 L
s
.127 .923 .03 r
.59619 .81622 m
.59776 .75183 L
s
.78269 .75364 m .80008 .74402 L .78176 .74789 L .683 .771 .917 r
F
.76391 .75464 m .78269 .75364 L .78176 .74789 L F
.59497 .7532 m .59447 .74863 L .57995 .74826 L .733 .498 .571 r
F
0 g
.59447 .74863 m
.60788 .75128 L
s
.30844 .74359 m .28852 .74445 L .30646 .74639 L .683 .77 .917 r
F
.4339 .62667 m .44061 .63188 L .44093 .63755 L .987 .712 .384 r
F
.4339 .62667 m .43359 .62099 L .44061 .63188 L F
.45805 .6166 m .44061 .63188 L .46273 .62386 L .673 .757 .914 r
F
.45805 .6166 m .43359 .62099 L .44061 .63188 L F
0 g
.44061 .63188 m
.44559 .63586 L
s
.60107 .86317 m .61571 .86233 L .60374 .85966 L .645 .732 .913 r
F
.59043 .85874 m .60107 .86317 L .60374 .85966 L F
.58837 .8602 m .60107 .86317 L .59043 .85874 L F
.67507 .50033 m .6741 .52054 L .69042 .52001 L .654 .726 .902 r
F
.66697 .49921 m .6741 .52054 L .67507 .50033 L F
.66697 .49921 m .65791 .51831 L .6741 .52054 L F
.28881 .749 m .2685 .75589 L .28729 .75489 L .683 .77 .917 r
F
.30685 .75095 m .28881 .749 L .28729 .75489 L F
.18992 .50316 m .16125 .51738 L .19174 .51374 L .654 .726 .902 r
F
.18992 .50316 m .1585 .50152 L .16125 .51738 L F
0 g
.16125 .51738 m
.17023 .53248 L
s
0 0 0 r
2.5 Mabswid
.31421 .52576 Mdot
.56824 .86502 m .56103 .87159 L .57017 .86672 L .644 .733 .913 r
F
.56824 .86502 m .55719 .8682 L .56103 .87159 L F
.32536 .75746 m .3124 .75022 L .30932 .75271 L .683 .77 .917 r
F
.34316 .74902 m .35792 .73992 L .34139 .74641 L F
.34316 .74902 m .36143 .74515 L .35792 .73992 L F
.36077 .74062 m .37371 .72896 L .35727 .73542 L F
.36077 .74062 m .37896 .73676 L .37371 .72896 L F
.127 .923 .03 r
.5 Mabswid
.3752 .73975 m
.37523 .74222 L
s
.37446 .74004 m
.37447 .74238 L
s
.32722 .63559 m .30735 .63183 L .30764 .6375 L .672 .449 .574 r
F
.32722 .63559 m .32692 .62991 L .30735 .63183 L F
0 g
.28898 .63672 m
.30735 .63183 L
s
.48485 .61584 m .47042 .63003 L .48869 .61893 L .673 .757 .914 r
F
.48485 .61584 m .46273 .62386 L .47042 .63003 L F
.58793 .86776 m .59655 .87367 L .60069 .87075 L .644 .733 .913 r
F
.58527 .86882 m .59655 .87367 L .58793 .86776 L F
.52455 .62395 m .54178 .6344 L .55008 .62795 L .673 .758 .914 r
F
.51922 .62647 m .54178 .6344 L .52455 .62395 L F
.70835 .74263 m .69046 .74069 L .68806 .74948 L .683 .771 .917 r
F
.6907 .74524 m .68777 .7495 L .68828 .75407 L 0 0 .397 r
F
0 g
.68844 .7535 m
.68853 .75405 L
s
.6907 .74524 m .69019 .74067 L .68777 .7495 L 0 0 .397 r
F
.7278 .64135 m .70903 .64057 L .70937 .64625 L .604 .397 .575 r
F
0 g
.69336 .65379 m
.70937 .64625 L
s
.7278 .64135 m .72746 .63567 L .70903 .64057 L .604 .397 .575 r
F
0 g
.69302 .64811 m
.70903 .64057 L
s
.76646 .63496 m .76612 .62929 L .74671 .62809 L .733 .496 .57 r
F
0 g
.76612 .62929 m
.78402 .63352 L
s
.78471 .64487 m .76646 .63496 L .7668 .64064 L .794 .544 .559 r
F
0 g
.78471 .64487 m
.79987 .65184 L
s
.34323 .5269 m .34746 .5041 L .34701 .51138 L 0 0 .133 r
F
.31308 .52009 m .34323 .5269 L .34701 .51138 L .654 .726 .902 r
F
0 g
.3333 .54101 m
.34323 .5269 L
s
.5663 .75932 m .55203 .75884 L .55253 .76342 L .607 .405 .583 r
F
0 g
.54058 .76939 m
.55253 .76342 L
s
.5663 .75932 m .5658 .75475 L .55203 .75884 L .607 .405 .583 r
F
0 g
.54009 .76482 m
.55203 .75884 L
s
.72665 .74913 m .70706 .75307 L .72584 .75207 L .683 .771 .917 r
F
.76391 .75464 m .78176 .74789 L .76344 .75177 L F
.27124 .75163 m .2685 .75589 L .26897 .76046 L 0 0 .379 r
F
0 g
.26918 .75964 m
.26933 .76044 L
s
.28881 .749 m .27077 .74706 L .2685 .75589 L .683 .77 .917 r
F
.27124 .75163 m .27077 .74706 L .2685 .75589 L 0 0 .379 r
F
.34083 .74187 m .35153 .7311 L .33796 .73971 L .683 .77 .917 r
F
.34083 .74187 m .35727 .73542 L .35153 .7311 L F
.30732 .75552 m .28777 .75946 L .30656 .75846 L F
.34666 .63679 m .32692 .62991 L .32722 .63559 L .733 .497 .57 r
F
0 g
.30735 .63183 m
.32692 .62991 L
s
.32692 .62991 m
.34636 .63112 L
s
.65353 .48596 m .64336 .5062 L .65989 .48951 L .654 .726 .902 r
F
.65353 .48596 m .63065 .4991 L .64336 .5062 L F
.65948 .49679 m .65791 .51831 L .66697 .49921 L F
.65948 .49679 m .64295 .51348 L .65791 .51831 L F
.2218 .49753 m .19221 .50646 L .22271 .50282 L F
.2218 .49753 m .19039 .49588 L .19221 .50646 L F
.68323 .50006 m .69042 .52001 L .70577 .51677 L F
.67507 .50033 m .69042 .52001 L .68323 .50006 L F
.69131 .49116 m .70617 .50949 L .71949 .50375 L F
.68363 .49278 m .70617 .50949 L .69131 .49116 L F
.58045 .75283 m .5653 .75018 L .5658 .75475 L .673 .454 .579 r
F
.58045 .75283 m .57995 .74826 L .5653 .75018 L F
0 g
.55154 .75428 m
.5653 .75018 L
s
.54922 .61653 m .57853 .61261 L .55458 .60912 L .673 .757 .914 r
F
.52795 .60934 m .54922 .61653 L .55458 .60912 L F
.54186 .85587 m .54312 .8581 L .54288 .86186 L .925 .75 .267 r
F
.54186 .85587 m .54211 .8521 L .54312 .8581 L F
0 g
.54312 .8581 m
.54528 .86162 L
s
.51061 .54202 m
.51061 .57329 L
s
.5548 .85285 m .54331 .85808 L .55547 .85682 L .645 .732 .913 r
F
.5548 .85285 m .5423 .85211 L .54331 .85808 L F
.49998 .52314 m .49265 .50319 L .47733 .50644 L .654 .726 .902 r
F
.50813 .52288 m .49265 .50319 L .49998 .52314 L F
.34696 .64246 m .34666 .63679 L .32722 .63559 L .733 .497 .57 r
F
0 g
.34666 .63679 m
.36465 .64102 L
s
.72826 .74177 m .70835 .74263 L .72623 .74457 L .683 .771 .917 r
F
.31354 .51281 m .34746 .5041 L .31604 .50246 L .654 .726 .902 r
F
.28338 .50599 m .31354 .51281 L .31604 .50246 L F
.127 .923 .03 r
.30914 .50156 m
.30927 .50319 L
s
.28008 .5107 m .31354 .51281 L .28338 .50599 L .654 .726 .902 r
F
.56732 .85934 m .55744 .86443 L .56849 .86126 L .644 .733 .913 r
F
.56732 .85934 m .5551 .8606 L .55744 .86443 L F
.51623 .52399 m .50898 .50267 L .50813 .52288 L .654 .726 .902 r
F
.51623 .52399 m .52518 .5049 L .50898 .50267 L F
0 g
.50408 .54168 m
.50408 .57317 L
s
.70868 .74718 m .68828 .75407 L .70706 .75307 L .683 .771 .917 r
F
.72665 .74913 m .70868 .74718 L .70706 .75307 L F
.58463 .48376 m .59381 .49161 L .59339 .49889 L .99 .743 .456 r
F
.58463 .48376 m .58504 .47648 L .59381 .49161 L F
0 g
.59381 .49161 m
.59957 .49695 L
s
.61565 .86614 m .61589 .86237 L .61747 .85653 L 0 0 .152 r
F
.127 .923 .03 r
.51805 7.4247 m
.61711 1.32987 L
s
.57142 1.75881 m
.61849 1.15544 L
s
.61849 1.15544 m
.64876 .76747 L
s
0 g
.6129 .8663 m
.61589 .86237 L
s
.60093 .86698 m .61565 .86614 L .60362 .86345 L .644 .733 .913 r
F
.59024 .86253 m .60093 .86698 L .60362 .86345 L F
.58817 .86399 m .60093 .86698 L .59024 .86253 L F
.127 .923 .03 r
.58973 .86289 m
.58977 .86114 L
s
.58958 .863 m
.58977 .86114 L
s
.60374 .85966 m .61571 .86233 L .61728 .85651 L .645 .732 .913 r
F
.74513 .75564 m .73631 .7464 L .73232 .7484 L .683 .771 .917 r
F
.61594 .47279 m .59422 .49148 L .62174 .48283 L .654 .726 .902 r
F
.61594 .47279 m .5855 .47643 L .59422 .49148 L F
.76293 .7472 m .77782 .7381 L .76122 .74459 L .683 .771 .917 r
F
.76293 .7472 m .78125 .74332 L .77782 .7381 L F
.78055 .73879 m .79366 .72714 L .77714 .73359 L F
.78055 .73879 m .79877 .73494 L .79366 .72714 L F
.59497 .7532 m .57995 .74826 L .58045 .75283 L .733 .498 .571 r
F
0 g
.5653 .75018 m
.57995 .74826 L
s
.57995 .74826 m
.59447 .74863 L
s
.74705 .63376 m .72712 .63 L .72746 .63567 L .672 .449 .574 r
F
.74705 .63376 m .74671 .62809 L .72712 .63 L F
0 g
.70869 .6349 m
.72712 .63 L
s
.5818 .85995 m .58251 .85939 L .58251 .85962 L .361 .183 .5 r
F
.58268 .85939 m .58817 .86399 L .59024 .86253 L .644 .733 .913 r
F
.57954 .85808 m .58227 .85995 L .58268 .85939 L F
.58227 .85995 m .58817 .86399 L .58268 .85939 L F
.58251 .85939 m .58294 .85871 L .58294 .85902 L .082 0 .419 r
F
.58227 .85995 m .58551 .86505 L .58817 .86399 L .644 .733 .913 r
F
.5818 .85995 m .58251 .85962 L .5818 .86011 L .361 .183 .5 r
F
.57954 .85808 m .58175 .86066 L .58227 .85995 L .644 .733 .913 r
F
.58175 .86066 m .58551 .86505 L .58227 .85995 L F
.58147 .86033 m .58245 .86564 L .58551 .86505 L F
.58251 .85962 m .58295 .86258 L .58254 .86314 L .082 0 .419 r
F
.58251 .85939 m .58253 .85959 L .58251 .85962 L F
.58253 .85959 m .58295 .86258 L .58251 .85962 L F
.58253 .85959 m .58294 .85902 L .58295 .86258 L F
.58251 .85939 m .58294 .85902 L .58253 .85959 L F
.58254 .86314 m .58295 .86258 L .58305 .91785 L F
.58297 .85885 m .59024 .86253 L .59158 .86077 L .644 .733 .913 r
F
.57954 .85808 m .58287 .85947 L .58297 .85885 L F
.58287 .85947 m .59024 .86253 L .58297 .85885 L F
.58294 .85871 m .58306 .85791 L .58306 .85829 L 0 0 .148 r
F
.58295 .85896 m .58306 .85829 L .58307 .86185 L F
.58294 .85871 m .58306 .85829 L .58295 .85896 L F
.58282 .86332 m .58793 .86776 L .59 .8663 L .644 .733 .913 r
F
.58077 .86038 m .58084 .864 L .58078 .86402 L .519 .305 .529 r
F
.58063 .86091 m .58245 .86564 L .58147 .86033 L .644 .733 .913 r
F
.58077 .86038 m .5818 .85995 L .5818 .86367 L .519 .305 .529 r
F
.5819 .86363 m .58114 .864 L .5823 .86391 L .644 .733 .913 r
F
.58107 .86392 m .58114 .864 L .5819 .86363 L F
.58121 .86408 m .58134 .8648 L .58156 .86449 L F
.58134 .8648 m .5822 .8694 L .58156 .86449 L F
.58038 .86465 m .5822 .8694 L .58121 .86408 L F
.58084 .864 m .5818 .86367 L .5819 .91909 L .519 .305 .529 r
F
.58077 .86038 m .5818 .86367 L .58084 .864 L F
.57918 .86059 m .58077 .86038 L .58078 .86402 L .642 .403 .541 r
F
.5793 .86185 m .58107 .86392 L .5819 .86363 L .644 .733 .913 r
F
.5793 .86185 m .5819 .86363 L .58282 .86332 L F
.58295 .86258 m .58316 .91705 L .58305 .91785 L 0 0 .148 r
F
.58294 .85871 m .58296 .86253 L .58295 .86258 L F
.58296 .86253 m .58316 .91705 L .58295 .86258 L F
.5819 .86363 m .58269 .86417 L .58282 .86332 L .644 .733 .913 r
F
.58269 .86417 m .58793 .86776 L .58283 .86332 L F
.58269 .86417 m .58283 .86332 L .58282 .86332 L F
.57992 .9169 m .58089 .91951 L .58302 .91883 L .692 .759 .904 r
F
.57988 .91687 m .57989 .91691 L .57992 .9169 L F
.57989 .91691 m .58089 .91951 L .57992 .9169 L F
.58191 .9181 m .58122 .91874 L .58215 .91825 L F
.58087 .91645 m .58158 .91826 L .58087 .91859 L .519 .305 .529 r
F
.57875 .91703 m .57862 .91982 L .58089 .91951 L .692 .759 .904 r
F
.57875 .91703 m .58089 .91951 L .57988 .91687 L F
.58002 .91875 m .57901 .91924 L .58015 .91908 L F
.57928 .91675 m .58039 .91868 L .57928 .91889 L .642 .403 .541 r
F
.57913 .91643 m .57902 .91894 L .58002 .91875 L .692 .759 .904 r
F
.57902 .91894 m .57901 .91924 L .58002 .91875 L F
.57862 .91982 m .5819 .92214 L .58089 .91951 L F
.57901 .91924 m .58116 .92173 L .58015 .91908 L F
.57928 .91889 m .58087 .91952 L .57928 .91972 L .642 .403 .541 r
F
.58105 .91856 m .58015 .91908 L .58122 .91874 L .692 .759 .904 r
F
.58085 .9186 m .58039 .91868 L .57928 .91675 L .642 .403 .541 r
F
.57913 .91643 m .58002 .91875 L .58105 .91856 L .692 .759 .904 r
F
.58002 .91875 m .58015 .91908 L .58105 .91856 L F
.58087 .91645 m .57988 .91687 L .58095 .91653 L F
.5798 .91665 m .57988 .91687 L .58087 .91645 L F
.58079 .91646 m .58085 .9186 L .57928 .91675 L .642 .403 .541 r
F
.58089 .91951 m .5851 .92113 L .58302 .91883 L .692 .759 .904 r
F
.58015 .91908 m .5833 .92105 L .58122 .91874 L F
.58085 .9186 m .58087 .91952 L .58039 .91868 L .642 .403 .541 r
F
.58039 .91868 m .58087 .91952 L .57928 .91889 L F
.57918 .86059 m .58079 .91646 L .57928 .91675 L F
.57887 .91424 m .5798 .91665 L .58087 .91645 L .692 .759 .904 r
F
.57913 .91643 m .58102 .91852 L .58191 .9181 L F
.58102 .91852 m .58122 .91874 L .58191 .9181 L F
.58087 .91859 m .5819 .91909 L .58087 .91952 L .519 .305 .529 r
F
.58122 .91874 m .58516 .92006 L .58215 .91825 L .692 .759 .904 r
F
.58158 .91826 m .5819 .91909 L .58087 .91859 L .519 .305 .529 r
F
.58078 .86402 m .58184 .91599 L .58087 .91645 L F
.5817 .91679 m .58302 .91883 L .58487 .91785 L .692 .759 .904 r
F
.58095 .91653 m .58148 .91712 L .5817 .91679 L F
.58148 .91712 m .58302 .91883 L .5817 .91679 L F
.58168 .91614 m .58487 .91785 L .58187 .91604 L F
.58095 .91653 m .58113 .9166 L .58168 .91614 L F
.58113 .9166 m .58487 .91785 L .58168 .91614 L F
.57988 .91687 m .58302 .91883 L .58095 .91653 L F
.58259 .91754 m .58215 .91825 L .58287 .91763 L F
.57913 .91643 m .58191 .9181 L .58259 .91754 L F
.58191 .9181 m .58215 .91825 L .58259 .91754 L F
.5819 .91811 m .58261 .91853 L .5819 .91909 L .361 .183 .5 r
F
.58189 .91596 m .58238 .91771 L .5819 .91811 L F
.58238 .91771 m .58261 .91853 L .5819 .91811 L F
.58319 .86272 m .59 .8663 L .59134 .86454 L .644 .733 .913 r
F
.5818 .85995 m .58185 .86364 L .5818 .86367 L .361 .183 .5 r
F
.5793 .86185 m .58251 .86319 L .58319 .86272 L .644 .733 .913 r
F
.58306 .85829 m .59158 .86077 L .5921 .85882 L F
.57954 .85808 m .58336 .85893 L .58306 .85829 L F
.58336 .85893 m .59158 .86077 L .58306 .85829 L F
.58306 .85791 m .58262 .85687 L .58262 .85733 L .984 .727 .338 r
F
.58302 .8582 m .58262 .85733 L .58262 .86089 L F
.58306 .85791 m .58262 .85733 L .58302 .8582 L F
.58251 .86318 m .58302 .91474 L .5826 .91538 L .082 0 .419 r
F
.58251 .85939 m .58254 .86314 L .58251 .86318 L F
.58254 .86314 m .58302 .91474 L .58251 .86318 L F
.58331 .86209 m .59134 .86454 L .59186 .86259 L .644 .733 .913 r
F
.5818 .86011 m .58251 .86318 L .58185 .86364 L .361 .183 .5 r
F
.5793 .86185 m .5829 .86265 L .58331 .86209 L .644 .733 .913 r
F
.5829 .86265 m .59134 .86454 L .58331 .86209 L F
.58114 .864 m .58527 .86882 L .5823 .86391 L F
.58304 .86179 m .58262 .86089 L .58272 .91601 L .984 .727 .338 r
F
.58294 .85871 m .58307 .86185 L .58296 .86253 L 0 0 .148 r
F
.58306 .85791 m .58262 .86089 L .58304 .86179 L .984 .727 .338 r
F
.58251 .86319 m .58396 .86379 L .58319 .86272 L .644 .733 .913 r
F
.58396 .86379 m .59 .8663 L .58356 .86291 L F
.58396 .86379 m .58356 .86291 L .58319 .86272 L F
.5818 .86367 m .58257 .91541 L .58189 .91596 L .361 .183 .5 r
F
.58185 .86364 m .58257 .91541 L .5818 .86367 L F
.58187 .91604 m .58487 .91785 L .58631 .91662 L .692 .759 .904 r
F
.58257 .91541 m .5826 .91753 L .58189 .91596 L .361 .183 .5 r
F
.5826 .91538 m .5829 .91706 L .58261 .91752 L .082 0 .419 r
F
.57913 .91643 m .58333 .91693 L .58352 .91619 L .692 .759 .904 r
F
.58333 .91693 m .58334 .91693 L .58334 .91691 L F
.58333 .91693 m .58334 .91691 L .58352 .91619 L F
.58215 .91825 m .58661 .91882 L .58287 .91763 L F
.5826 .91753 m .58261 .91853 L .58238 .91771 L .361 .183 .5 r
F
.5826 .91753 m .58238 .91771 L .58189 .91596 L F
.58302 .91689 m .58287 .91763 L .58334 .91693 L .692 .759 .904 r
F
.58184 .91599 m .5819 .91909 L .58087 .91645 L .519 .305 .529 r
F
.57913 .91643 m .5826 .91754 L .58302 .91689 L .692 .759 .904 r
F
.5826 .91754 m .58287 .91763 L .58302 .91689 L F
.58261 .91752 m .58305 .91785 L .58261 .91853 L .082 0 .419 r
F
.5829 .91706 m .58305 .91785 L .58261 .91752 L F
.58187 .91604 m .58631 .91662 L .58259 .91543 L .692 .759 .904 r
F
.58302 .91474 m .58304 .91686 L .5826 .91538 L .082 0 .419 r
F
.57913 .91643 m .58346 .9162 L .5834 .91548 L .692 .759 .904 r
F
.58346 .9162 m .58352 .91619 L .58351 .91613 L F
.58346 .9162 m .58351 .91613 L .5834 .91548 L F
.58304 .91686 m .58305 .91785 L .5829 .91706 L .082 0 .419 r
F
.58304 .91686 m .5829 .91706 L .5826 .91538 L F
.58084 .864 m .5819 .91909 L .58078 .86402 L .519 .305 .529 r
F
.58296 .86253 m .58307 .86185 L .58316 .91705 L 0 0 .148 r
F
.58307 .86185 m .58272 .91601 L .58316 .91705 L .984 .727 .338 r
F
.58306 .85791 m .58304 .86179 L .58307 .86185 L F
.58304 .86179 m .58272 .91601 L .58307 .86185 L F
.5823 .86391 m .58527 .86882 L .58612 .86848 L .644 .733 .913 r
F
.58481 .86563 m .58612 .86848 L .58793 .86776 L F
.5823 .86391 m .58612 .86848 L .58481 .86563 L F
.5793 .86185 m .57894 .86947 L .5822 .8694 L F
.57929 .86414 m .58078 .86402 L .58087 .91952 L .642 .403 .541 r
F
.57918 .86059 m .58078 .86402 L .57929 .86414 L F
.58246 .86555 m .5822 .8694 L .58527 .86882 L .644 .733 .913 r
F
.58156 .86449 m .58204 .86815 L .58246 .86555 L F
.58204 .86815 m .5822 .8694 L .58246 .86555 L F
.5793 .86185 m .58038 .86465 L .58121 .86408 L F
.5818 .86011 m .58251 .85962 L .58251 .86318 L .361 .183 .5 r
F
.58185 .86364 m .58251 .86318 L .58261 .91853 L F
.57954 .85808 m .58063 .86091 L .58147 .86033 L .644 .733 .913 r
F
.59547 .75777 m .59497 .7532 L .58045 .75283 L .733 .498 .571 r
F
0 g
.59497 .7532 m
.60838 .75585 L
s
.75659 .50743 m .75698 .50015 L .76714 .48601 L .08 0 .401 r
F
0 g
.74841 .50662 m
.75698 .50015 L
s
.30884 .74814 m .28881 .749 L .30685 .75095 L .683 .77 .917 r
F
.46406 .51219 m .42694 .50851 L .45374 .52003 L .654 .726 .902 r
F
.28929 .75357 m .26897 .76046 L .28777 .75946 L .683 .77 .917 r
F
.30732 .75552 m .28929 .75357 L .28777 .75946 L F
.73002 .4885 m .75658 .49998 L .76668 .48591 L .654 .726 .902 r
F
.71967 .49632 m .75658 .49998 L .73002 .4885 L F
.46514 .49779 m .44361 .4824 L .42822 .49412 L F
.47834 .49207 m .44361 .4824 L .46514 .49779 L F
.50813 .52288 m .50898 .50267 L .49265 .50319 L F
.34363 .75359 m .3584 .74449 L .34187 .75098 L .683 .77 .917 r
F
.34363 .75359 m .36191 .74972 L .3584 .74449 L F
.56252 .52573 m .57575 .5037 L .55291 .51684 L .654 .726 .902 r
F
.56252 .52573 m .59017 .51705 L .57575 .5037 L F
.36143 .74515 m .37444 .73343 L .35792 .73992 L .683 .77 .917 r
F
.36143 .74515 m .37972 .74127 L .37444 .73343 L F
.127 .923 .03 r
.37526 .74398 m
.3753 .74688 L
s
.37447 .7443 m
.37448 .74705 L
s
.37972 .74127 m .37923 .7367 L .37396 .72886 L .981 .69 .343 r
F
0 g
.37923 .7367 m
.38077 .74533 L
s
.127 .923 .03 r
.36555 .90354 m
.39585 8.82585 L
s
0 g
.51061 .57329 m
.51062 .59273 L
s
.55352 .50241 m .55723 .47872 L .54085 .49534 L .654 .726 .902 r
F
.55352 .50241 m .57624 .48934 L .55723 .47872 L F
.127 .923 .03 r
.56943 .48553 m
.5697 .47236 L
s
0 g
.50408 .57317 m
.50408 .58728 L
s
.6912 .74981 m .68828 .75407 L .68879 .75864 L 0 0 .397 r
F
0 g
.68894 .75807 m
.68903 .75862 L
s
.70868 .74718 m .6907 .74524 L .68828 .75407 L .683 .771 .917 r
F
.6912 .74981 m .6907 .74524 L .68828 .75407 L 0 0 .397 r
F
.32663 .82332 m .32533 .82833 L .32857 .82826 L .644 .733 .913 r
F
.32524 .768 m .32652 .82333 L .32503 .82345 L .641 .402 .541 r
F
.32561 .82073 m .32551 .82341 L .32663 .82332 L .644 .733 .913 r
F
.32551 .82341 m .32533 .82833 L .32663 .82332 L F
.32533 .82833 m .32504 .83593 L .33153 .83579 L F
.3263 .82691 m .32506 .83214 L .32833 .83207 L F
.32503 .82345 m .3266 .82681 L .32503 .82701 L .641 .402 .541 r
F
.32535 .8245 m .32526 .82699 L .3263 .82691 L .644 .733 .913 r
F
.32526 .82699 m .32506 .83214 L .3263 .82691 L F
.32652 .82333 m .3266 .82681 L .32503 .82345 L .641 .402 .541 r
F
.127 .923 .03 r
.35394 4.38678 m
.39501 8.82706 L
s
.32062 .78408 m
.3212 .84737 L
s
.32914 .82313 m .33162 .82768 L .33425 .82662 L .644 .733 .913 r
F
.32662 .82333 m .32762 .82637 L .3266 .82681 L .517 .303 .528 r
F
.32683 .7678 m .32758 .82299 L .32662 .82333 L F
.32561 .82073 m .32857 .82826 L .33162 .82768 L .644 .733 .913 r
F
.32758 .82299 m .32762 .82637 L .32662 .82333 L .517 .303 .528 r
F
.32834 .82248 m .32876 .82513 L .32833 .82581 L .071 0 .412 r
F
.32855 .7668 m .32875 .82191 L .32834 .82248 L F
.32847 .82268 m .32783 .82319 L .32914 .82313 L .644 .733 .913 r
F
.32778 .82324 m .33162 .82768 L .32914 .82313 L F
.32875 .82191 m .32876 .82513 L .32834 .82248 L .071 0 .412 r
F
.32783 .82319 m .32778 .82324 L .3278 .82323 L .644 .733 .913 r
F
.32783 .82319 m .3278 .82323 L .32914 .82313 L F
.32561 .82073 m .32757 .82299 L .32847 .82268 L F
.32764 .82297 m .32833 .82581 L .32762 .82637 L .356 .178 .497 r
F
.32785 .76736 m .3283 .82251 L .32764 .82297 L F
.32764 .82297 m .32778 .82324 L .32847 .82268 L .644 .733 .913 r
F
.32758 .82301 m .32778 .82324 L .32764 .82297 L F
.3283 .82251 m .32833 .82581 L .32764 .82297 L .356 .178 .497 r
F
.32757 .82299 m .32758 .82301 L .32764 .82297 L .644 .733 .913 r
F
.32524 .768 m .32683 .7678 L .32662 .82333 L .641 .402 .541 r
F
.32652 .82333 m .32662 .82333 L .3266 .82681 L F
.32524 .768 m .32662 .82333 L .32652 .82333 L F
.32434 .82332 m .31911 .82695 L .3221 .82788 L .644 .733 .913 r
F
.32551 .82354 m .3221 .82788 L .32533 .82833 L F
.32434 .82332 m .3221 .82788 L .32551 .82354 L F
.31911 .82695 m .31859 .83503 L .3221 .82788 L F
.32311 .82664 m .31626 .82938 L .31882 .83075 L F
.32346 .82315 m .32501 .82701 L .32344 .82671 L .751 .492 .54 r
F
.32227 .82615 m .32181 .8264 L .32317 .82658 L .644 .733 .913 r
F
.32245 .82624 m .32344 .82675 L .32245 .82628 L .844 .572 .526 r
F
.32321 .82303 m .31657 .82559 L .31911 .82695 L .644 .733 .913 r
F
.32367 .76774 m .32493 .82343 L .32346 .82315 L .751 .492 .54 r
F
.32561 .82073 m .32221 .82256 L .32321 .82303 L .644 .733 .913 r
F
.32221 .82256 m .31657 .82559 L .32321 .82303 L F
.32246 .82268 m .32344 .82671 L .32245 .82624 L .844 .572 .526 r
F
.32268 .76727 m .32339 .82312 L .32246 .82268 L F
.32314 .82309 m .32305 .82318 L .32434 .82332 L .644 .733 .913 r
F
.32305 .82318 m .31911 .82695 L .32372 .82375 L F
.32305 .82318 m .32372 .82375 L .32434 .82332 L F
.31464 .82389 m .30752 .83044 L .31657 .82559 L F
.32094 .82495 m .31278 .82376 L .31313 .82576 L F
.3218 .82211 m .32244 .82623 L .32179 .82567 L .927 .648 .492 r
F
.32493 .82343 m .32501 .82701 L .32346 .82315 L .751 .492 .54 r
F
.32535 .8245 m .32004 .82419 L .32094 .82495 L .644 .733 .913 r
F
.32367 .76774 m .32524 .768 L .32503 .82345 L .751 .492 .54 r
F
.32367 .76774 m .32503 .82345 L .32493 .82343 L F
.32221 .82256 m .31464 .82389 L .31657 .82559 L .644 .733 .913 r
F
.32561 .82073 m .3211 .82203 L .32221 .82256 L F
.3211 .82203 m .31464 .82389 L .32221 .82256 L F
.32268 .76727 m .32367 .76774 L .32346 .82315 L .844 .572 .526 r
F
.32339 .82312 m .32346 .82315 L .32344 .82675 L F
.32268 .76727 m .32346 .82315 L .32339 .82312 L F
.32004 .82419 m .31278 .82376 L .32094 .82495 L .644 .733 .913 r
F
.31657 .82559 m .31261 .83316 L .31911 .82695 L F
.32181 .8264 m .31432 .82768 L .31626 .82938 L F
.32493 .82343 m .32503 .82345 L .32501 .82701 L .751 .492 .54 r
F
.32242 .82264 m .32245 .82624 L .3218 .82211 L .927 .648 .492 r
F
.32245 .82624 m .32245 .82628 L .32244 .82623 L F
.32245 .82624 m .32244 .82623 L .3218 .82211 L F
.32232 .82613 m .31998 .82605 L .32181 .8264 L .644 .733 .913 r
F
.32535 .8245 m .32166 .82556 L .32232 .82613 L F
.32166 .82556 m .31998 .82605 L .32232 .82613 L F
.31998 .82605 m .31432 .82768 L .32181 .8264 L F
.32179 .82567 m .32245 .82628 L .32179 .82569 L .927 .648 .492 r
F
.32244 .82623 m .32245 .82628 L .32179 .82567 L F
.32202 .76668 m .32242 .82264 L .3218 .82211 L F
.32339 .82312 m .32344 .82671 L .32246 .82268 L .844 .572 .526 r
F
.32344 .82671 m .32344 .82675 L .32245 .82624 L F
.32317 .82658 m .32181 .8264 L .32311 .82664 L .644 .733 .913 r
F
.32535 .8245 m .32227 .82615 L .32317 .82658 L F
.32181 .8264 m .31626 .82938 L .32311 .82664 L F
.3221 .82788 m .31859 .83503 L .32504 .83593 L F
.32535 .8245 m .31882 .83075 L .32182 .83169 L F
.32344 .82671 m .32501 .82701 L .32344 .82675 L .751 .492 .54 r
F
.3221 .82788 m .32504 .83593 L .32533 .82833 L .644 .733 .913 r
F
.32535 .8245 m .32182 .83169 L .32506 .83214 L F
.32501 .82701 m .32501 .82701 L .32344 .82671 L .751 .492 .54 r
F
.32561 .82073 m .32434 .82332 L .32551 .82354 L .644 .733 .913 r
F
.32561 .82073 m .32314 .82309 L .32434 .82332 L F
0 g
.32502 .82459 m
.32502 .82453 L
s
.32524 .768 m
.32526 .76296 L
s
.28369 .49868 m .31618 .49516 L .28493 .49353 L .654 .726 .902 r
F
.45836 .62228 m .44093 .63755 L .46304 .62954 L .673 .758 .914 r
F
.45836 .62228 m .4339 .62667 L .44093 .63755 L F
0 g
.44093 .63755 m
.45247 .64679 L
s
.76062 .74005 m .77148 .72927 L .75779 .73789 L .683 .771 .917 r
F
.76062 .74005 m .77714 .73359 L .77148 .72927 L F
.30844 .74359 m .29247 .73886 L .28852 .74445 L .683 .77 .917 r
F
.31151 .74112 m .29247 .73886 L .30844 .74359 L F
.72716 .7537 m .70757 .75764 L .72635 .75664 L .683 .771 .917 r
F
.32947 .82233 m .33425 .82662 L .3363 .82517 L .644 .733 .913 r
F
.32561 .82073 m .32847 .82268 L .32947 .82233 L F
.32847 .82268 m .33425 .82662 L .32947 .82233 L F
.32683 .7678 m .32785 .76736 L .32764 .82297 L .517 .303 .528 r
F
.32758 .82299 m .32764 .82297 L .32762 .82637 L F
.32683 .7678 m .32764 .82297 L .32758 .82299 L F
.76646 .63496 m .74671 .62809 L .74705 .63376 L .733 .496 .57 r
F
0 g
.72712 .63 m
.74671 .62809 L
s
.74671 .62809 m
.76612 .62929 L
s
.127 .923 .03 r
.56128 .85997 m
.56149 .85793 L
s
.56145 .85995 m
.56149 .85793 L
s
.32148 .78375 m
.32188 .80214 L
s
.3226 .83559 m
.32285 .84689 L
s
.32752 .64126 m .30764 .6375 L .30794 .64318 L .672 .449 .574 r
F
0 g
.28957 .64807 m
.30794 .64318 L
s
.32752 .64126 m .32722 .63559 L .30764 .6375 L .672 .449 .574 r
F
0 g
.28928 .6424 m
.30764 .6375 L
s
.48516 .62152 m .47073 .6357 L .48901 .6246 L .673 .758 .914 r
F
.48516 .62152 m .46304 .62954 L .47073 .6357 L F
.28929 .75357 m .27124 .75163 L .26897 .76046 L .683 .77 .917 r
F
.127 .923 .03 r
.25025 .74747 m
.2513 .80634 L
s
0 g
.26897 .76046 m
.27054 .76908 L
s
.32959 .82162 m .3363 .82517 L .33762 .82341 L .644 .733 .913 r
F
.32561 .82073 m .3289 .82209 L .32959 .82162 L F
.3289 .82209 m .3363 .82517 L .32959 .82162 L F
.32785 .76736 m .32855 .7668 L .32834 .82248 L .356 .178 .497 r
F
.3283 .82251 m .32834 .82248 L .32833 .82581 L F
.32785 .76736 m .32834 .82248 L .3283 .82251 L F
.127 .923 .03 r
.36555 7.72012 m
.3926 8.82558 L
s
.7668 .64064 m .76646 .63496 L .74705 .63376 L .733 .496 .57 r
F
0 g
.76646 .63496 m
.78436 .63919 L
s
.34139 .74641 m .35214 .73558 L .33851 .74424 L .683 .77 .917 r
F
.34139 .74641 m .35792 .73992 L .35214 .73558 L F
.32155 .8219 m .31345 .82199 L .31464 .82389 L .644 .733 .913 r
F
.32561 .82073 m .32076 .82123 L .32155 .8219 L F
.32076 .82123 m .31345 .82199 L .32155 .8219 L F
.32202 .76668 m .32268 .76727 L .32246 .82268 L .927 .648 .492 r
F
.32242 .82264 m .32246 .82268 L .32245 .82628 L F
.32202 .76668 m .32246 .82268 L .32242 .82264 L F
.127 .923 .03 r
.23291 2.29941 m
.36555 7.72012 L
s
.54162 .85964 m .54288 .86186 L .54263 .86563 L .925 .75 .267 r
F
.54162 .85964 m .54186 .85587 L .54288 .86186 L F
.55442 .85661 m .54288 .86186 L .5551 .8606 L .644 .733 .913 r
F
.55442 .85661 m .54186 .85587 L .54288 .86186 L F
0 g
.54288 .86186 m
.54503 .86539 L
s
.56707 .86311 m .55719 .8682 L .56824 .86502 L .644 .733 .913 r
F
.56707 .86311 m .55485 .86437 L .55719 .8682 L F
.25032 .61704 m .25003 .61137 L .2696 .60946 L .672 .449 .574 r
F
.23086 .61584 m .25003 .61137 L .25032 .61704 L .733 .497 .57 r
F
.23086 .61584 m .23057 .61017 L .25003 .61137 L F
.58095 .7574 m .5658 .75475 L .5663 .75932 L .673 .454 .579 r
F
0 g
.55253 .76342 m
.5663 .75932 L
s
.58095 .7574 m .58045 .75283 L .5658 .75475 L .673 .454 .579 r
F
0 g
.55203 .75884 m
.5658 .75475 L
s
.127 .923 .03 r
.56974 .79387 m
.57031 .73289 L
s
.56706 .80681 m
.56859 .73357 L
s
.57762 .86033 m .57918 .86059 L .57919 .86414 L .751 .492 .54 r
F
.57919 .86415 m .5757 .86902 L .57894 .86947 L .644 .733 .913 r
F
.57772 .86386 m .57919 .86414 L .57928 .91972 L .751 .492 .54 r
F
.57762 .86033 m .57919 .86414 L .57772 .86386 L F
.5793 .86185 m .57824 .86396 L .57919 .86415 L .644 .733 .913 r
F
.57824 .86396 m .5757 .86902 L .57919 .86415 L F
.64928 .47418 m .63129 .49169 L .65405 .47861 L .654 .726 .902 r
F
.64928 .47418 m .62174 .48283 L .63129 .49169 L F
.61565 .86614 m .61747 .85653 L .61722 .86029 L 0 0 .152 r
F
.61541 .86991 m .61565 .86614 L .61722 .86029 L F
.60362 .86345 m .61565 .86614 L .61722 .86029 L .644 .733 .913 r
F
0 g
.61266 .87006 m
.61565 .86614 L
s
.56729 .85358 m .55547 .85682 L .56763 .85557 L .645 .732 .913 r
F
.56729 .85358 m .5548 .85285 L .55547 .85682 L F
.60069 .87075 m .61541 .86991 L .60338 .86722 L .644 .733 .913 r
F
.59 .8663 m .60069 .87075 L .60338 .86722 L F
.58793 .86776 m .60069 .87075 L .59 .8663 L F
.33796 .73971 m .34393 .72795 L .33416 .73814 L .683 .77 .917 r
F
.33796 .73971 m .35153 .7311 L .34393 .72795 L F
.32944 .82095 m .33762 .82341 L .33812 .82146 L .644 .733 .913 r
F
.32561 .82073 m .32905 .82149 L .32944 .82095 L F
.32905 .82149 m .33762 .82341 L .32944 .82095 L F
.32855 .7668 m .32898 .76612 L .32877 .82188 L .071 0 .412 r
F
.32875 .82191 m .32877 .82188 L .32876 .82513 L F
.32855 .7668 m .32877 .82188 L .32875 .82191 L F
.72869 .74632 m .70868 .74718 L .72665 .74913 L .683 .771 .917 r
F
.25062 .59596 m .25003 .61114 L .26951 .60924 L .673 .757 .914 r
F
.23771 .59517 m .25003 .61114 L .25062 .59596 L F
.23771 .59517 m .23068 .60995 L .25003 .61114 L F
.70919 .75175 m .68879 .75864 L .70757 .75764 L .683 .771 .917 r
F
.72716 .7537 m .70919 .75175 L .70757 .75764 L F
.60374 .85966 m .61728 .85651 L .60478 .85578 L .645 .732 .913 r
F
.59177 .85699 m .60374 .85966 L .60478 .85578 L F
.59043 .85874 m .60374 .85966 L .59177 .85699 L F
.69827 .48093 m .71967 .49632 L .73002 .4885 L .654 .726 .902 r
F
.69164 .48379 m .71967 .49632 L .69827 .48093 L F
0 g
.57918 .85703 m
.57918 .85806 L
s
.57663 .85986 m .57762 .86033 L .57762 .86385 L .844 .571 .525 r
F
.57778 .91664 m .57658 .91677 L .57762 .91699 L .692 .759 .904 r
F
.57762 .91699 m .57862 .91982 L .57875 .91703 L F
.57902 .91887 m .57788 .91921 L .57901 .91924 L F
.57779 .91662 m .57771 .91661 L .57778 .91664 L F
.5792 .91675 m .57928 .91972 L .57771 .91661 L .751 .492 .54 r
F
.57913 .91643 m .57807 .91879 L .57902 .91887 L .692 .759 .904 r
F
.57807 .91879 m .57788 .91921 L .57902 .91887 L F
.57762 .91699 m .57637 .91975 L .57862 .91982 L F
.57637 .91975 m .5785 .92261 L .57862 .91982 L F
.57788 .91921 m .57888 .92204 L .57901 .91924 L F
.57771 .91876 m .57928 .91972 L .57771 .91946 L .751 .492 .54 r
F
.57771 .91661 m .57884 .91886 L .57771 .91876 L F
.57884 .91886 m .57928 .91972 L .57771 .91876 L F
.57597 .85927 m .57663 .85986 L .57664 .86338 L .928 .648 .489 r
F
.57734 .86371 m .57719 .86385 L .57817 .86411 L .644 .733 .913 r
F
.5756 .85858 m .57597 .85927 L .57598 .86281 L .988 .72 .386 r
F
.57562 .86221 m .57598 .86281 L .57607 .91841 L F
.5756 .85858 m .57598 .86281 L .57562 .86221 L F
.57719 .86385 m .5768 .86422 L .5778 .86437 L .644 .733 .913 r
F
.5768 .86422 m .57271 .86808 L .57716 .86484 L F
.5768 .86422 m .57716 .86484 L .5778 .86437 L F
.57719 .86385 m .5778 .86437 L .57817 .86411 L F
.5758 .91552 m .57503 .91584 L .57635 .91594 L .692 .759 .904 r
F
.57569 .91638 m .57429 .91931 L .57658 .91677 L F
.57569 .91638 m .57252 .91852 L .57429 .91931 L F
.57568 .91721 m .57474 .91667 L .57486 .91739 L F
.57569 .91509 m .57599 .91773 L .57569 .91723 L .988 .72 .386 r
F
.57635 .91594 m .57619 .91593 L .57624 .91601 L .692 .759 .904 r
F
.57658 .91677 m .57429 .91931 L .57637 .91975 L F
.57669 .91621 m .57673 .91899 L .57606 .91572 L .928 .648 .489 r
F
.57602 .86285 m .57664 .86338 L .57673 .91899 L F
.57698 .91633 m .57658 .91677 L .57778 .91664 L .692 .759 .904 r
F
.57913 .91643 m .57534 .91664 L .57568 .91721 L F
.57534 .91664 m .57474 .91667 L .57568 .91721 L F
.57913 .91643 m .57486 .91739 L .57527 .91804 L F
.57569 .91723 m .57607 .91841 L .57569 .91772 L .988 .72 .386 r
F
.57651 .91821 m .57527 .91804 L .57594 .91859 L .692 .759 .904 r
F
.57555 .85777 m .5756 .85858 L .5756 .86217 L .779 .622 .059 r
F
.57658 .91677 m .57637 .91975 L .57762 .91699 L .692 .759 .904 r
F
.57698 .91633 m .57569 .91638 L .57658 .91677 L F
.57664 .86338 m .57766 .91659 L .57672 .91623 L .844 .571 .525 r
F
.57887 .91424 m .57621 .91603 L .57698 .91633 L .692 .759 .904 r
F
.57621 .91603 m .57569 .91638 L .57698 .91633 L F
.57721 .91856 m .57594 .91859 L .57683 .91898 L F
.57766 .91659 m .57771 .91946 L .57672 .91623 L .844 .571 .525 r
F
.57766 .91659 m .57771 .91661 L .57771 .91946 L F
.57913 .91643 m .57643 .91826 L .57721 .91856 L .692 .759 .904 r
F
.57643 .91826 m .57594 .91859 L .57721 .91856 L F
.57913 .91643 m .57683 .91898 L .57788 .91921 L F
.57673 .91838 m .57771 .91946 L .57673 .91899 L .844 .571 .525 r
F
.57672 .91623 m .57747 .91866 L .57673 .91838 L F
.57747 .91866 m .57771 .91946 L .57673 .91838 L F
.57663 .85986 m .5767 .8634 L .57664 .86338 L F
.5767 .8634 m .57771 .91946 L .57664 .86338 L F
.57577 .91633 m .57503 .91584 L .57569 .91638 L .692 .759 .904 r
F
.57624 .91601 m .57574 .91594 L .57577 .91633 L F
.57574 .91594 m .57503 .91584 L .57577 .91633 L F
.57503 .91584 m .57252 .91852 L .57569 .91638 L F
.57565 .91662 m .57493 .91594 L .57474 .91667 L F
.57619 .91593 m .57503 .91584 L .57624 .91601 L F
.57605 .91569 m .57607 .91841 L .57569 .91509 L .988 .72 .386 r
F
.57913 .91643 m .57561 .91602 L .57565 .91662 L .692 .759 .904 r
F
.57561 .91602 m .57493 .91594 L .57565 .91662 L F
.57564 .91646 m .57569 .91772 L .57564 .91691 L .779 .622 .059 r
F
.57564 .91432 m .57568 .91709 L .57564 .91646 L F
.57568 .91709 m .57569 .91772 L .57564 .91646 L F
.57555 .86143 m .57568 .91505 L .57564 .91432 L F
.57568 .91505 m .57569 .91772 L .57564 .91432 L F
.57555 .85777 m .57556 .86147 L .57555 .86143 L F
.57663 .85986 m .57762 .86385 L .5767 .8634 L .844 .571 .525 r
F
.57449 .86323 m .56707 .86311 L .56824 .86502 L .644 .733 .913 r
F
.57597 .85927 m .57664 .86338 L .57602 .86285 L .928 .648 .489 r
F
.5793 .86185 m .57505 .86229 L .57449 .86323 L .644 .733 .913 r
F
.57505 .86229 m .56707 .86311 L .57449 .86323 L F
.57555 .85777 m .5756 .86217 L .57556 .86147 L .779 .622 .059 r
F
.57608 .85675 m .57555 .85777 L .57555 .86143 L 0 0 .381 r
F
.57556 .86147 m .57569 .91772 L .57555 .86143 L .779 .622 .059 r
F
.57653 .86333 m .57569 .8635 L .57571 .86377 L .644 .733 .913 r
F
.57564 .8629 m .56824 .86502 L .57653 .86333 L F
.57556 .86147 m .5756 .86217 L .57569 .91772 L .779 .622 .059 r
F
.5756 .86217 m .57605 .91569 L .57569 .91509 L .988 .72 .386 r
F
.57562 .86221 m .57605 .91569 L .5756 .86217 L F
.57597 .85927 m .57602 .86285 L .57598 .86281 L .928 .648 .489 r
F
.57268 .86253 m .56674 .86111 L .56707 .86311 L .644 .733 .913 r
F
.57598 .86281 m .57669 .91621 L .57606 .91572 L .928 .648 .489 r
F
.57887 .91424 m .57525 .91505 L .57503 .91584 L .692 .759 .904 r
F
.57525 .91505 m .57462 .91519 L .57492 .91567 L F
.57525 .91505 m .57492 .91567 L .57503 .91584 L F
.57887 .91424 m .5745 .91447 L .57462 .91519 L F
.57617 .91331 m .57573 .91629 L .57618 .91545 L 0 0 .381 r
F
.57887 .91424 m .57468 .91374 L .5745 .91447 L .692 .759 .904 r
F
.57566 .91427 m .57564 .91691 L .57617 .91331 L 0 0 .381 r
F
.57616 .91548 m .57612 .91462 L .57539 .91524 L .692 .759 .904 r
F
.57887 .91424 m .5758 .91552 L .57635 .91594 L F
.57762 .86385 m .5792 .91675 L .57771 .91661 L .751 .492 .54 r
F
.57887 .91424 m .57698 .91633 L .57771 .91661 L .692 .759 .904 r
F
.57887 .91424 m .57762 .91699 L .57875 .91703 L F
.57913 .91643 m .5765 .91485 L .57616 .91548 L F
.5773 .91464 m .57618 .91589 L .5773 .91512 L .404 .216 .509 r
F
.57762 .86033 m .57772 .86386 L .57762 .86385 L .751 .492 .54 r
F
.5793 .86185 m .57564 .8629 L .57653 .86333 L .644 .733 .913 r
F
.57726 .86378 m .57716 .86382 L .57719 .86385 L F
.57817 .86411 m .57271 .86808 L .5757 .86902 L F
.57467 .8578 m .5675 .8554 L .56698 .85734 L F
.57954 .85808 m .57565 .85721 L .57467 .8578 L F
.57565 .85721 m .5675 .8554 L .57467 .8578 L F
.57446 .85695 m .56885 .85363 L .5675 .8554 L F
.5772 .85598 m .57608 .85675 L .57608 .85696 L .404 .216 .509 r
F
.57711 .85635 m .57608 .85696 L .57609 .86052 L F
.5772 .85598 m .57608 .85696 L .57711 .85635 L F
.57565 .85721 m .57596 .85659 L .57446 .85695 L .644 .733 .913 r
F
.57954 .85808 m .5764 .85677 L .57565 .85721 L F
.5764 .85677 m .57596 .85659 L .57565 .85721 L F
.57596 .85659 m .56885 .85363 L .57446 .85695 L F
.57831 .85564 m .5772 .85598 L .5772 .85629 L .569 .345 .536 r
F
.5793 .86185 m .5761 .86356 L .57726 .86378 L .644 .733 .913 r
F
.57719 .86385 m .5767 .86405 L .5768 .86422 L F
.5767 .8634 m .57762 .86385 L .57771 .91661 L .844 .571 .525 r
F
.5767 .8634 m .57771 .91661 L .57766 .91659 L F
.57596 .85659 m .57092 .85217 L .56885 .85363 L .644 .733 .913 r
F
.57954 .85808 m .57701 .85634 L .57596 .85659 L F
.57701 .85634 m .57092 .85217 L .57596 .85659 L F
.57772 .86386 m .5792 .91675 L .57762 .86385 L .751 .492 .54 r
F
.5793 .86185 m .57734 .86371 L .57817 .86411 L .644 .733 .913 r
F
.57088 .86136 m .56726 .85916 L .56674 .86111 L F
.57389 .86064 m .5686 .8574 L .56726 .85916 L F
.5756 .85858 m .57562 .86221 L .5756 .86217 L .988 .72 .386 r
F
.5793 .86185 m .57549 .86026 L .57389 .86064 L .644 .733 .913 r
F
.57549 .86026 m .5686 .8574 L .57389 .86064 L F
.5783 .85603 m .57824 .85961 L .57831 .85603 L .569 .345 .536 r
F
.57549 .86026 m .57067 .85594 L .5686 .8574 L .644 .733 .913 r
F
.5772 .8563 m .57714 .8599 L .5772 .85629 L .404 .216 .509 r
F
.57714 .8599 m .57618 .91545 L .57714 .85989 L F
.57714 .8599 m .57714 .85989 L .5772 .85629 L F
.57608 .85675 m .57605 .86058 L .57609 .86052 L 0 0 .381 r
F
.57609 .86052 m .5766 .86 L .57549 .86026 L .644 .733 .913 r
F
.5793 .86185 m .57677 .86012 L .57609 .86052 L F
.5772 .85598 m .57609 .86052 L .57714 .8599 L .404 .216 .509 r
F
.57677 .86012 m .5766 .86 L .57609 .86052 L .644 .733 .913 r
F
.57608 .85675 m .57555 .86143 L .57605 .86058 L 0 0 .381 r
F
.5766 .86 m .57067 .85594 L .57549 .86026 L .644 .733 .913 r
F
.5783 .85603 m .5772 .85629 L .57721 .85985 L .569 .345 .536 r
F
.57824 .85961 m .57721 .85985 L .5773 .91512 L F
.5783 .85603 m .57721 .85985 L .57824 .85961 L F
.57824 .85961 m .5773 .91512 L .57825 .85961 L F
.57824 .85961 m .57825 .85961 L .57831 .85603 L F
.57545 .91383 m .57515 .91305 L .57468 .91374 L .692 .759 .904 r
F
.57887 .91424 m .57611 .91335 L .57545 .91383 L F
.57611 .91335 m .57515 .91305 L .57545 .91383 L F
.57887 .91424 m .57679 .91194 L .57587 .91243 L F
.5773 .91249 m .57618 .91545 L .5773 .91464 L .404 .216 .509 r
F
.57721 .85985 m .57622 .91327 L .5773 .91249 L F
.57887 .91424 m .57587 .91243 L .57515 .91305 L .692 .759 .904 r
F
.57622 .91327 m .57618 .91545 L .5773 .91249 L .404 .216 .509 r
F
.5772 .85629 m .57714 .85989 L .57721 .85985 L F
.57714 .85989 m .57618 .91545 L .57721 .85985 L F
.57433 .86156 m .57389 .86064 L .57088 .86136 L .644 .733 .913 r
F
.5793 .86185 m .57533 .86097 L .57433 .86156 L F
.57533 .86097 m .57389 .86064 L .57433 .86156 L F
.57389 .86064 m .56726 .85916 L .57088 .86136 L F
.5773 .91249 m .57786 .9116 L .57679 .91194 L .692 .759 .904 r
F
.57887 .91424 m .57809 .91221 L .5773 .91249 L F
.57832 .85959 m .57735 .91247 L .5784 .9121 L .569 .345 .536 r
F
.57809 .91221 m .57786 .9116 L .5773 .91249 L .692 .759 .904 r
F
.57658 .91489 m .57705 .91412 L .57612 .91462 L F
.57887 .91424 m .57771 .91661 L .57779 .91662 L F
.57913 .91643 m .57746 .91458 L .57658 .91489 L F
.57746 .91458 m .57705 .91412 L .57658 .91489 L F
.57913 .91643 m .57812 .91378 L .57705 .91412 L F
.57841 .91424 m .5773 .91512 L .57841 .91478 L .569 .345 .536 r
F
.5784 .9121 m .5775 .91456 L .57841 .91424 L F
.5775 .91456 m .5773 .91512 L .57841 .91424 L F
.57735 .91247 m .5773 .91512 L .5784 .9121 L F
.57831 .85603 m .57825 .85961 L .57832 .85959 L F
.57825 .85961 m .5773 .91512 L .57832 .85959 L F
.57831 .85564 m .5783 .85603 L .57831 .85603 L F
.57831 .85564 m .5772 .85629 L .5783 .85603 L F
.5772 .85598 m .5772 .8563 L .5772 .85629 L .404 .216 .509 r
F
.57618 .91545 m .57618 .91589 L .5773 .91464 L F
.5765 .91485 m .57612 .91462 L .57616 .91547 L .692 .759 .904 r
F
.57618 .91545 m .57616 .91547 L .57616 .91548 L F
.5765 .91485 m .57616 .91547 L .57618 .91545 L F
.57618 .91545 m .57564 .91691 L .57618 .91589 L 0 0 .381 r
F
.57573 .91629 m .57564 .91691 L .57618 .91545 L F
.57609 .86052 m .57566 .91427 L .57617 .91331 L F
.57605 .86058 m .57564 .91691 L .57609 .86052 L F
.57505 .86229 m .57433 .86156 L .57268 .86253 L .644 .733 .913 r
F
.5793 .86185 m .57544 .86162 L .57505 .86229 L F
.57544 .86162 m .57433 .86156 L .57505 .86229 L F
.57433 .86156 m .56674 .86111 L .57268 .86253 L F
.5768 .86422 m .57576 .86461 L .5758 .86516 L F
.57602 .86285 m .57673 .91899 L .57598 .86281 L .928 .648 .489 r
F
.57714 .8599 m .57609 .86052 L .57618 .91589 L .404 .216 .509 r
F
.57605 .86058 m .57555 .86143 L .57564 .91691 L 0 0 .381 r
F
.57571 .86377 m .56824 .86502 L .57017 .86672 L .644 .733 .913 r
F
.57569 .8635 m .56824 .86502 L .57571 .86377 L F
.5758 .86516 m .57017 .86672 L .57271 .86808 L F
.57576 .86461 m .57017 .86672 L .5758 .86516 L F
.5767 .86405 m .57017 .86672 L .5768 .86422 L F
.57913 .91643 m .57594 .91776 L .57651 .91821 L .692 .759 .904 r
F
.57594 .91776 m .57527 .91804 L .57651 .91821 L F
.57607 .91786 m .57673 .91899 L .57607 .91841 L .928 .648 .489 r
F
.57606 .91572 m .57658 .91826 L .57607 .91786 L F
.57658 .91826 m .57673 .91899 L .57607 .91786 L F
.57599 .91773 m .57607 .91841 L .57569 .91723 L .988 .72 .386 r
F
.57716 .86382 m .57017 .86672 L .57719 .86385 L .644 .733 .913 r
F
.5761 .86356 m .57017 .86672 L .57726 .86378 L F
.32125 .82118 m .3131 .81999 L .31345 .82199 L F
.32561 .82073 m .32082 .82045 L .32125 .82118 L F
.323 .81915 m .32187 .82317 L .32299 .82239 L .4 .212 .507 r
F
.32322 .76338 m .32195 .81977 L .323 .81915 L F
.32195 .81977 m .32187 .82317 L .323 .81915 L F
.32081 .82045 m .3131 .81999 L .32125 .82118 L .644 .733 .913 r
F
.32163 .76599 m .32202 .76668 L .3218 .82211 L .989 .721 .393 r
F
.32178 .82207 m .3218 .82211 L .32179 .82569 L F
.32163 .76599 m .3218 .82211 L .32178 .82207 L F
.57922 .61833 m .57889 .61266 L .58207 .60077 L 0 0 .327 r
F
0 g
.5743 .61899 m
.57889 .61266 L
s
.55458 .60912 m .57853 .61261 L .58169 .60078 L .673 .757 .914 r
F
.34696 .64246 m .32722 .63559 L .32752 .64126 L .733 .497 .57 r
F
0 g
.30764 .6375 m
.32722 .63559 L
s
.32722 .63559 m
.34666 .63679 L
s
.34696 .64246 m
.36495 .64669 L
s
.127 .923 .03 r
.34555 .62674 m
.34593 .68911 L
s
.44285 .48944 m .42782 .49395 L .42738 .50123 L .34 .162 .487 r
F
.44285 .48944 m .44328 .48217 L .42782 .49395 L F
0 g
.41784 .50808 m
.42782 .49395 L
s
.29247 .73886 m .27057 .74252 L .28852 .74445 L .683 .77 .917 r
F
.76344 .75177 m .77833 .74267 L .76173 .74916 L .683 .771 .917 r
F
.76344 .75177 m .78176 .74789 L .77833 .74267 L F
.59547 .75777 m .58045 .75283 L .58095 .7574 L .733 .498 .571 r
F
0 g
.5658 .75475 m
.58045 .75283 L
s
.58045 .75283 m
.59497 .7532 L
s
.59547 .75777 m
.60888 .76042 L
s
.78125 .74332 m .79443 .73161 L .77782 .7381 L .683 .771 .917 r
F
.78125 .74332 m .79956 .73945 L .79443 .73161 L F
.54976 .62227 m .57922 .61833 L .55515 .61483 L .673 .757 .914 r
F
.52838 .61505 m .54976 .62227 L .55515 .61483 L F
.52423 .61828 m .54976 .62227 L .52838 .61505 L F
.79956 .73945 m .79905 .73488 L .79391 .72704 L .98 .687 .329 r
F
0 g
.79905 .73488 m
.80043 .74351 L
s
.58095 .7574 m
.59547 .75777 L
s
.30932 .75271 m .28929 .75357 L .30732 .75552 L .683 .77 .917 r
F
.74695 .82151 m .74556 .82651 L .74881 .82644 L .645 .732 .913 r
F
.74505 .76618 m .74684 .82151 L .74534 .82163 L .642 .403 .541 r
F
.74597 .81891 m .74583 .82159 L .74695 .82151 L .645 .732 .913 r
F
.74583 .82159 m .74556 .82651 L .74695 .82151 L F
.74556 .82651 m .74516 .83411 L .75166 .83398 L F
.74665 .82509 m .74533 .83032 L .7486 .83025 L F
.74534 .82163 m .74695 .82499 L .74538 .82519 L .642 .403 .541 r
F
.74574 .82268 m .7456 .82517 L .74665 .82509 L .645 .732 .913 r
F
.74556 .82651 m .75166 .83398 L .74881 .82644 L F
.7456 .82517 m .74533 .83032 L .74665 .82509 L F
.74684 .82151 m .74695 .82499 L .74534 .82163 L .642 .403 .541 r
F
.127 .923 .03 r
.78465 .8433 m
.78691 .78079 L
s
.78309 .84383 m
.78613 .77967 L
s
.74946 .82131 m .75187 .82586 L .75453 .82481 L .645 .732 .913 r
F
.74694 .82151 m .74798 .82455 L .74695 .82499 L .519 .306 .53 r
F
.74664 .76598 m .7479 .82117 L .74694 .82151 L F
.74597 .81891 m .74881 .82644 L .75187 .82586 L .645 .732 .913 r
F
.7479 .82117 m .74798 .82455 L .74694 .82151 L .519 .306 .53 r
F
.74868 .82066 m .74913 .82331 L .74869 .82399 L .088 0 .422 r
F
.74838 .76498 m .74909 .82009 L .74868 .82066 L F
.7488 .82086 m .74816 .82137 L .74946 .82131 L .645 .732 .913 r
F
.7481 .82142 m .75187 .82586 L .74946 .82131 L F
.74909 .82009 m .74913 .82331 L .74868 .82066 L .088 0 .422 r
F
.74816 .82137 m .7481 .82142 L .74813 .82142 L .645 .732 .913 r
F
.74816 .82137 m .74813 .82142 L .74946 .82131 L F
.74597 .81891 m .7479 .82117 L .7488 .82086 L F
.74796 .82115 m .74869 .82399 L .74798 .82455 L .362 .185 .501 r
F
.74767 .76554 m .74864 .82069 L .74796 .82115 L F
.74796 .82115 m .7481 .82142 L .7488 .82086 L .645 .732 .913 r
F
.74791 .82119 m .7481 .82142 L .74796 .82115 L F
.74864 .82069 m .74869 .82399 L .74796 .82115 L .362 .185 .501 r
F
.7479 .82117 m .74791 .82119 L .74796 .82115 L .645 .732 .913 r
F
.74505 .76618 m .74664 .76598 L .74694 .82151 L .642 .403 .541 r
F
.74684 .82151 m .74694 .82151 L .74695 .82499 L F
.74505 .76618 m .74694 .82151 L .74684 .82151 L F
.74466 .8215 m .73936 .82513 L .74234 .82606 L .645 .732 .913 r
F
.74582 .82172 m .74234 .82606 L .74556 .82651 L F
.74466 .8215 m .74234 .82606 L .74582 .82172 L F
.73936 .82513 m .73871 .83322 L .74234 .82606 L F
.74346 .82482 m .73656 .82756 L .7391 .82893 L F
.74377 .82133 m .74536 .82519 L .74379 .82489 L .751 .492 .54 r
F
.7425 .76545 m .74348 .76592 L .74377 .82133 L .845 .571 .524 r
F
.74371 .8213 m .74377 .82133 L .74379 .82493 L F
.7425 .76545 m .74377 .82133 L .74371 .8213 L F
.74353 .82121 m .73684 .82377 L .73936 .82513 L .645 .732 .913 r
F
.74348 .76592 m .74525 .82161 L .74377 .82133 L .751 .492 .54 r
F
.74597 .81891 m .74253 .82074 L .74353 .82121 L .645 .732 .913 r
F
.74253 .82074 m .73684 .82377 L .74353 .82121 L F
.74574 .82268 m .74217 .82458 L .74346 .82482 L F
.74217 .82458 m .73656 .82756 L .74346 .82482 L F
.74234 .82606 m .73871 .83322 L .74516 .83411 L F
.74217 .82971 m .7391 .82893 L .74209 .82987 L F
.74234 .82606 m .74516 .83411 L .74556 .82651 L F
.74574 .82268 m .74196 .82623 L .74217 .82971 L F
.74196 .82623 m .7391 .82893 L .74217 .82971 L F
.74346 .82127 m .74337 .82136 L .74466 .8215 L F
.74337 .82136 m .73936 .82513 L .74403 .82193 L F
.74337 .82136 m .74403 .82193 L .74466 .8215 L F
.74348 .76592 m .74505 .76618 L .74534 .82163 L .751 .492 .54 r
F
.74348 .76592 m .74534 .82163 L .74525 .82161 L F
.74147 .76417 m .74185 .76486 L .74213 .82029 L .988 .719 .38 r
F
.74211 .82025 m .74213 .82029 L .74215 .82387 L F
.74147 .76417 m .74213 .82029 L .74211 .82025 L F
.74242 .8208 m .73493 .82207 L .73684 .82377 L .645 .732 .913 r
F
.74253 .82074 m .7424 .82076 L .74242 .8208 L F
.7424 .82076 m .73493 .82207 L .74242 .8208 L F
.7425 .76545 m .74371 .8213 L .74279 .82086 L .845 .571 .524 r
F
.74597 .81891 m .74143 .82021 L .74253 .82074 L .645 .732 .913 r
F
.74176 .81965 m .74215 .82387 L .74178 .82318 L .988 .719 .38 r
F
.74147 .76417 m .74211 .82025 L .74176 .81965 L F
.74143 .82021 m .7424 .82076 L .74233 .82064 L .645 .732 .913 r
F
.74211 .82025 m .74215 .82387 L .74176 .81965 L .988 .719 .38 r
F
.74143 .82021 m .73493 .82207 L .7424 .82076 L .645 .732 .913 r
F
.74233 .82064 m .7424 .82076 L .74253 .82074 L F
.73684 .82377 m .73276 .83134 L .73936 .82513 L F
.74163 .82386 m .73349 .82394 L .73464 .82586 L F
.74279 .82086 m .74378 .82488 L .74281 .82442 L .845 .571 .524 r
F
.74213 .82029 m .7428 .82441 L .74215 .82385 L .929 .648 .486 r
F
.74574 .82268 m .74033 .82324 L .74163 .82386 L .645 .732 .913 r
F
.74033 .82324 m .73349 .82394 L .74163 .82386 L F
.74281 .82442 m .74379 .82493 L .74281 .82446 L .845 .571 .524 r
F
.74378 .82488 m .74379 .82493 L .74281 .82442 L F
.74371 .8213 m .74379 .82493 L .74279 .82086 L F
.74132 .82313 m .73316 .82194 L .73349 .82394 L .645 .732 .913 r
F
.74174 .82237 m .74178 .82318 L .74178 .82321 L .769 .613 .047 r
F
.74174 .82237 m .74178 .82321 L .74174 .82247 L F
.74525 .82161 m .74536 .82519 L .74377 .82133 L .751 .492 .54 r
F
.74574 .82268 m .74042 .82237 L .74132 .82313 L .645 .732 .913 r
F
.74042 .82237 m .73316 .82194 L .74132 .82313 L F
.74217 .82458 m .73464 .82586 L .73656 .82756 L F
.74525 .82161 m .74534 .82163 L .74536 .82519 L .751 .492 .54 r
F
.74275 .82082 m .74281 .82442 L .74213 .82029 L .929 .648 .486 r
F
.74281 .82442 m .74281 .82446 L .7428 .82441 L F
.74281 .82442 m .7428 .82441 L .74213 .82029 L F
.74268 .82431 m .74034 .82423 L .74217 .82458 L .645 .732 .913 r
F
.74574 .82268 m .74202 .82374 L .74268 .82431 L F
.74202 .82374 m .74034 .82423 L .74268 .82431 L F
.74034 .82423 m .73464 .82586 L .74217 .82458 L F
.74215 .82385 m .74281 .82446 L .74215 .82387 L .929 .648 .486 r
F
.7428 .82441 m .74281 .82446 L .74215 .82385 L F
.74185 .76486 m .74275 .82082 L .74213 .82029 L F
.7348 .84424 m .74474 .84182 L .74451 .84559 L .733 .498 .572 r
F
.7348 .84424 m .73503 .84047 L .74474 .84182 L F
.73871 .83322 m .74475 .84171 L .74516 .83411 L .645 .732 .913 r
F
.73871 .83322 m .73508 .84036 L .74475 .84171 L F
.73456 .84801 m .74451 .84559 L .74428 .84936 L .733 .498 .572 r
F
.73456 .84801 m .7348 .84424 L .74451 .84559 L F
.73844 .83706 m .74451 .84559 L .74492 .83796 L .645 .732 .913 r
F
.73844 .83706 m .7348 .84424 L .74451 .84559 L F
.73821 .84083 m .74428 .84936 L .74469 .84173 L F
.73821 .84083 m .73456 .84801 L .74428 .84936 L F
.74209 .82987 m .73844 .83706 L .74492 .83796 L F
.74186 .83364 m .73821 .84083 L .74469 .84173 L F
.74217 .83301 m .73886 .8327 L .74186 .83364 L F
.74574 .82268 m .74209 .82987 L .74533 .83032 L F
.74281 .82446 m .74379 .82493 L .74381 .82845 L .845 .571 .524 r
F
.74353 .82831 m .74198 .82977 L .74436 .82871 L .645 .732 .913 r
F
.74416 .88127 m .74296 .8814 L .744 .88162 L .692 .759 .904 r
F
.744 .88162 m .74498 .88445 L .74512 .88165 L F
.74512 .88165 m .74498 .88445 L .74725 .88414 L F
.74541 .8835 m .74426 .88383 L .74539 .88387 L F
.74417 .88125 m .74409 .88124 L .74416 .88127 L F
.74558 .88137 m .74567 .88435 L .74409 .88124 L .751 .492 .54 r
F
.74553 .88105 m .74445 .88341 L .74541 .8835 L .692 .759 .904 r
F
.74445 .88341 m .74426 .88383 L .74541 .8835 L F
.744 .88162 m .74273 .88439 L .74498 .88445 L F
.74498 .88445 m .74484 .88725 L .74825 .88678 L F
.74426 .88383 m .74525 .88668 L .74539 .88387 L F
.7441 .88338 m .74567 .88435 L .7441 .88409 L .751 .492 .54 r
F
.74409 .88124 m .74523 .88348 L .7441 .88338 L F
.74523 .88348 m .74567 .88435 L .7441 .88338 L F
.74186 .83364 m .74469 .84173 L .7451 .83409 L .645 .732 .913 r
F
.7391 .82893 m .73844 .83706 L .74209 .82987 L F
.74215 .82387 m .74281 .82446 L .74283 .82798 L .929 .648 .486 r
F
.74209 .82987 m .74492 .83796 L .74533 .83032 L .645 .732 .913 r
F
.74436 .82871 m .74198 .82977 L .74217 .83301 L F
.74221 .82745 m .74283 .82798 L .74312 .88362 L .929 .648 .486 r
F
.74215 .82387 m .74283 .82798 L .74221 .82745 L F
.74178 .82318 m .74215 .82387 L .74217 .82741 L .988 .719 .38 r
F
.74169 .87905 m .74108 .87836 L .74089 .87909 L .692 .759 .904 r
F
.74298 .82882 m .73632 .83133 L .73886 .8327 L .645 .732 .913 r
F
.74288 .82865 m .73632 .83133 L .74298 .82882 L F
.74335 .82843 m .74287 .82862 L .74338 .82845 L F
.74287 .82862 m .73632 .83133 L .74288 .82865 L F
.74287 .82862 m .74288 .82865 L .74338 .82845 L F
.742 .87959 m .74089 .87909 L .74101 .87981 L .692 .759 .904 r
F
.74296 .8814 m .74065 .88394 L .74273 .88439 L F
.7429 .88283 m .74166 .88267 L .74233 .88321 L F
.74229 .82816 m .73632 .83133 L .74335 .82843 L .645 .732 .913 r
F
.74325 .82834 m .74335 .82843 L .74345 .82838 L F
.74229 .82816 m .74335 .82843 L .74325 .82834 L F
.74217 .82741 m .74307 .88083 L .74245 .88034 L .929 .648 .486 r
F
.74215 .82387 m .74221 .82745 L .74217 .82741 L F
.74221 .82745 m .74307 .88083 L .74217 .82741 L F
.74336 .88096 m .74296 .8814 L .74416 .88127 L .692 .759 .904 r
F
.74296 .8814 m .74273 .88439 L .744 .88162 L F
.74336 .88096 m .74207 .881 L .74296 .8814 L F
.74283 .82798 m .74404 .88122 L .7431 .88086 L .845 .571 .524 r
F
.74526 .87886 m .74259 .88066 L .74336 .88096 L .692 .759 .904 r
F
.74259 .88066 m .74207 .881 L .74336 .88096 L F
.7436 .88319 m .74233 .88321 L .74322 .88361 L F
.74404 .88122 m .7441 .88409 L .7431 .88086 L .845 .571 .524 r
F
.74404 .88122 m .74409 .88124 L .7441 .88409 L F
.74553 .88105 m .74281 .88289 L .7436 .88319 L .692 .759 .904 r
F
.74281 .88289 m .74233 .88321 L .7436 .88319 L F
.74553 .88105 m .74322 .88361 L .74426 .88383 L F
.74311 .883 m .7441 .88409 L .74312 .88362 L .845 .571 .524 r
F
.7431 .88086 m .74385 .88329 L .74311 .883 L F
.74385 .88329 m .7441 .88409 L .74311 .883 L F
.74281 .82446 m .74289 .82801 L .74283 .82798 L F
.74289 .82801 m .7441 .88409 L .74283 .82798 L F
.73936 .82513 m .73276 .83134 L .73871 .83322 L .645 .732 .913 r
F
.73656 .82756 m .73246 .83518 L .7391 .82893 L F
.74281 .82446 m .74381 .82845 L .74289 .82801 L .845 .571 .524 r
F
.72771 .82862 m .72616 .83756 L .73276 .83134 L .645 .732 .913 r
F
.73656 .82756 m .72738 .83244 L .73246 .83518 L F
.74065 .82784 m .73325 .82771 L .73441 .82963 L F
.74174 .82237 m .74176 .82607 L .74175 .82603 L .769 .613 .047 r
F
.74178 .82318 m .74182 .82681 L .7418 .82677 L .988 .719 .38 r
F
.74174 .82247 m .74178 .82321 L .7418 .82677 L .769 .613 .047 r
F
.74174 .82247 m .7418 .82677 L .74176 .82607 L F
.74228 .82135 m .74174 .82237 L .74175 .82603 L 0 0 .386 r
F
.74175 .82603 m .74209 .88234 L .74204 .88153 L .769 .613 .047 r
F
.74176 .82607 m .74209 .88234 L .74175 .82603 L F
.74272 .82793 m .74188 .8281 L .7419 .82837 L .645 .732 .913 r
F
.74183 .8275 m .73441 .82963 L .74272 .82793 L F
.7418 .82677 m .74243 .88031 L .74207 .87971 L .988 .719 .38 r
F
.74182 .82681 m .74246 .88303 L .7418 .82677 L F
.74182 .82681 m .74217 .82741 L .74245 .88034 L F
.74178 .82318 m .74217 .82741 L .74182 .82681 L F
.74176 .82607 m .7418 .82677 L .74209 .88234 L .769 .613 .047 r
F
.73684 .82377 m .72771 .82862 L .73276 .83134 L .645 .732 .913 r
F
.73464 .82586 m .72738 .83244 L .73656 .82756 L F
.73887 .82713 m .73293 .82571 L .73325 .82771 L F
.74182 .82681 m .74245 .88034 L .74243 .88031 L .988 .719 .38 r
F
.74053 .82616 m .73346 .82376 L .73293 .82571 L .645 .732 .913 r
F
.74551 .82645 m .74154 .82556 L .74053 .82616 L F
.74154 .82556 m .73346 .82376 L .74053 .82616 L F
.74526 .87886 m .74169 .87905 L .742 .87959 L .692 .759 .904 r
F
.74526 .87886 m .74185 .87845 L .74169 .87905 L F
.74185 .87845 m .7413 .87839 L .74149 .87871 L F
.74185 .87845 m .74149 .87871 L .74169 .87905 L F
.74526 .87886 m .74141 .88046 L .74207 .881 L F
.74526 .87886 m .7432 .87655 L .74227 .87705 L F
.7437 .87711 m .74277 .87993 L .74371 .87925 L .405 .218 .51 r
F
.74319 .87963 m .74346 .87874 L .74253 .87923 L .692 .759 .904 r
F
.74381 .82845 m .74558 .88137 L .74409 .88124 L .751 .492 .54 r
F
.74553 .88105 m .74384 .87916 L .74319 .87963 L .692 .759 .904 r
F
.74384 .87916 m .74346 .87874 L .74319 .87963 L F
.74526 .87886 m .74336 .88096 L .74409 .88124 L F
.74526 .87886 m .74409 .88124 L .74417 .88125 L F
.74526 .87886 m .744 .88162 L .74512 .88165 L F
.74526 .87886 m .74164 .87967 L .74141 .88046 L F
.74164 .87967 m .74101 .87981 L .7413 .88029 L F
.74164 .87967 m .7413 .88029 L .74141 .88046 L F
.74257 .87793 m .74213 .88091 L .74258 .88007 L 0 0 .386 r
F
.74205 .87889 m .74204 .88153 L .74257 .87793 L F
.74257 .8801 m .74253 .87923 L .7418 .87986 L .692 .759 .904 r
F
.74553 .88105 m .74291 .87946 L .74257 .8801 L F
.74526 .87886 m .74155 .87766 L .74108 .87836 L F
.74526 .87886 m .74227 .87705 L .74155 .87766 L F
.74262 .87789 m .74259 .88007 L .7437 .87711 L .405 .218 .51 r
F
.74553 .88105 m .7418 .87986 L .74133 .88056 L .692 .759 .904 r
F
.74259 .88007 m .74258 .88051 L .74277 .87993 L .405 .218 .51 r
F
.74259 .88007 m .74277 .87993 L .7437 .87711 L F
.74291 .87946 m .74253 .87923 L .74256 .88008 L .692 .759 .904 r
F
.74258 .88007 m .74256 .88008 L .74257 .8801 L F
.74291 .87946 m .74256 .88008 L .74258 .88007 L F
.74243 .88031 m .74246 .88303 L .74207 .87971 L .988 .719 .38 r
F
.74307 .88083 m .74312 .88362 L .74245 .88034 L .929 .648 .486 r
F
.74553 .88105 m .74133 .88056 L .74114 .88129 L .692 .759 .904 r
F
.74258 .88007 m .74204 .88153 L .74258 .88051 L 0 0 .386 r
F
.74213 .88091 m .74204 .88153 L .74258 .88007 L F
.7423 .82511 m .74205 .87889 L .74257 .87793 L F
.74371 .87925 m .74258 .88051 L .74371 .87973 L .405 .218 .51 r
F
.74277 .87993 m .74258 .88051 L .74371 .87925 L F
.74345 .82838 m .74335 .82843 L .74338 .82845 L .645 .732 .913 r
F
.74379 .82493 m .74536 .82519 L .74538 .82875 L .751 .492 .54 r
F
.73493 .82207 m .72771 .82862 L .73684 .82377 L .645 .732 .913 r
F
.74009 .82524 m .73482 .82199 L .73346 .82376 L F
.74551 .82645 m .74169 .82486 L .74009 .82524 L F
.74169 .82486 m .73482 .82199 L .74009 .82524 L F
.74111 .81941 m .73346 .81817 L .73378 .82017 L F
.74185 .76486 m .7425 .76545 L .74279 .82086 L .929 .648 .486 r
F
.74185 .76486 m .74279 .82086 L .74275 .82082 L F
.74179 .82011 m .73378 .82017 L .73493 .82207 L .645 .732 .913 r
F
.74597 .81891 m .74174 .81934 L .74179 .82011 L F
.74174 .81934 m .73378 .82017 L .74179 .82011 L F
.74143 .76336 m .74147 .76417 L .74176 .81965 L .769 .613 .047 r
F
.74176 .8196 m .74176 .81965 L .74178 .82318 L F
.74143 .76336 m .74176 .81965 L .74176 .8196 L F
.74339 .81733 m .74228 .82135 L .74341 .82057 L .405 .218 .51 r
F
.7431 .76155 m .74232 .81796 L .74339 .81733 L F
.74597 .81891 m .74118 .81863 L .74111 .81941 L .645 .732 .913 r
F
.74232 .81796 m .74228 .82135 L .74339 .81733 L .405 .218 .51 r
F
.74118 .81863 m .74013 .81856 L .7406 .81897 L .645 .732 .913 r
F
.74118 .81863 m .7406 .81897 L .74111 .81941 L F
.74013 .81856 m .73346 .81817 L .74111 .81941 L F
.74275 .82082 m .74279 .82086 L .74281 .82446 L .929 .648 .486 r
F
.7417 .81866 m .73399 .81623 L .73346 .81817 L .645 .732 .913 r
F
.74597 .81891 m .74166 .81794 L .7417 .81866 L F
.74166 .81794 m .73399 .81623 L .7417 .81866 L F
.74172 .8189 m .74178 .82318 L .74174 .82237 L .769 .613 .047 r
F
.74143 .76336 m .74176 .8196 L .74172 .8189 L F
.74176 .8196 m .74178 .82318 L .74172 .8189 L F
.74216 .82118 m .73713 .81675 L .73505 .81822 L .645 .732 .913 r
F
.74574 .82268 m .74321 .82093 L .74216 .82118 L F
.74321 .82093 m .73713 .81675 L .74216 .82118 L F
.74451 .82023 m .74341 .82057 L .74341 .82089 L .57 .345 .536 r
F
.74065 .82154 m .73505 .81822 L .7337 .81999 L .645 .732 .913 r
F
.74341 .82057 m .74228 .82135 L .74228 .82155 L .405 .218 .51 r
F
.74331 .82094 m .74228 .82155 L .7423 .82511 L F
.74341 .82057 m .74228 .82155 L .74331 .82094 L F
.74185 .82181 m .74216 .82118 L .74065 .82154 L .645 .732 .913 r
F
.74574 .82268 m .7426 .82137 L .74185 .82181 L F
.74226 .81799 m .74174 .82237 L .74228 .82135 L 0 0 .386 r
F
.74197 .76233 m .74175 .81885 L .74226 .81799 L F
.74175 .81885 m .74174 .82237 L .74226 .81799 L F
.74197 .76233 m .74143 .76336 L .74172 .8189 L F
.74175 .81885 m .74172 .8189 L .74174 .82237 L F
.74197 .76233 m .74172 .8189 L .74175 .81885 L F
.74256 .81748 m .73741 .81301 L .73534 .81447 L .645 .732 .913 r
F
.7445 .81706 m .74341 .82057 L .74451 .82023 L .57 .345 .536 r
F
.7442 .76122 m .74345 .81731 L .7445 .81706 L F
.74597 .81891 m .7436 .81728 L .74262 .81751 L .645 .732 .913 r
F
.74597 .81891 m .74256 .81748 L .74221 .81807 L F
.74345 .81731 m .74341 .82057 L .7445 .81706 L .57 .345 .536 r
F
.74262 .81751 m .74295 .81683 L .74256 .81748 L .645 .732 .913 r
F
.7436 .81728 m .74295 .81683 L .74262 .81751 L F
.74295 .81683 m .73741 .81301 L .74256 .81748 L F
.74221 .81807 m .73534 .81447 L .73399 .81623 L F
.74256 .81748 m .73534 .81447 L .74221 .81807 L F
.7426 .82137 m .74216 .82118 L .74185 .82181 L F
.74216 .82118 m .73505 .81822 L .74065 .82154 L F
.74391 .82847 m .74558 .88137 L .74381 .82845 L .751 .492 .54 r
F
.74379 .82493 m .74538 .82875 L .74391 .82847 L F
.74551 .82645 m .74353 .82831 L .74436 .82871 L .645 .732 .913 r
F
.74428 .84936 m .74451 .84559 L .75431 .84539 L .67 .444 .568 r
F
.74428 .84936 m .75431 .84539 L .75407 .84916 L F
.74469 .84173 m .74428 .84936 L .75407 .84916 L .645 .732 .913 r
F
.74574 .82268 m .73758 .82085 L .73316 .82194 L F
.73758 .82085 m .7337 .81999 L .73342 .82099 L F
.73758 .82085 m .73342 .82099 L .73316 .82194 L F
.74597 .81891 m .74346 .82127 L .74466 .8215 L F
.74561 .82015 m .74451 .82023 L .74451 .82062 L .66 .418 .542 r
F
.74451 .84559 m .74474 .84182 L .75454 .84162 L .67 .444 .568 r
F
.74516 .83411 m .74475 .84171 L .7545 .8415 L .645 .732 .913 r
F
.74451 .84559 m .75454 .84162 L .75431 .84539 L .67 .444 .568 r
F
.74492 .83796 m .74451 .84559 L .75431 .84539 L .645 .732 .913 r
F
.74492 .83796 m .75431 .84539 L .75145 .83782 L F
.74469 .84173 m .75407 .84916 L .75122 .84159 L F
.7451 .83409 m .74469 .84173 L .75122 .84159 L F
.74551 .82645 m .74186 .83364 L .7451 .83409 L F
.74391 .82847 m .74538 .82875 L .74567 .88435 L .751 .492 .54 r
F
.74536 .82519 m .74536 .82519 L .74379 .82489 L F
.74597 .81891 m .74466 .8215 L .74582 .82172 L .645 .732 .913 r
F
.74041 .82432 m .7369 .82052 L .73482 .82199 L F
.74551 .82645 m .74233 .82426 L .74041 .82432 L F
.74228 .82135 m .74175 .82603 L .74226 .82517 L 0 0 .386 r
F
.74233 .82426 m .7369 .82052 L .74041 .82432 L .645 .732 .913 r
F
.74574 .82268 m .7398 .81569 L .73713 .81675 L F
.7456 .82059 m .74451 .82062 L .74453 .82419 L .66 .418 .542 r
F
.74556 .82415 m .74453 .82419 L .74482 .8794 L F
.7456 .82059 m .74453 .82419 L .74556 .82415 L F
.74561 .82015 m .74451 .82062 L .7456 .82059 L F
.74228 .82135 m .74226 .82517 L .7423 .82511 L 0 0 .386 r
F
.74281 .82459 m .73957 .81946 L .7369 .82052 L .645 .732 .913 r
F
.74551 .82645 m .74374 .82437 L .74281 .82459 L F
.74374 .82437 m .73957 .81946 L .74281 .82459 L F
.74551 .82645 m .74229 .82816 L .74345 .82838 L F
.74379 .82493 m .74391 .82847 L .74381 .82845 L .751 .492 .54 r
F
.74338 .82845 m .74288 .82865 L .74298 .82882 L .645 .732 .913 r
F
.74289 .82801 m .74381 .82845 L .74409 .88124 L .845 .571 .524 r
F
.74289 .82801 m .74409 .88124 L .74404 .88122 L F
.74379 .82489 m .74536 .82519 L .74379 .82493 L .751 .492 .54 r
F
.74446 .8242 m .74343 .82445 L .74371 .87973 L .57 .345 .536 r
F
.7437 .87711 m .74427 .87621 L .7432 .87655 L .692 .759 .904 r
F
.74526 .87886 m .7445 .87682 L .7437 .87711 L F
.74453 .82419 m .74375 .87709 L .74481 .87671 L .57 .345 .536 r
F
.7445 .87682 m .74427 .87621 L .7437 .87711 L .692 .759 .904 r
F
.74375 .87709 m .74371 .87973 L .74481 .87671 L .57 .345 .536 r
F
.74387 .8792 m .74453 .8784 L .74346 .87874 L .692 .759 .904 r
F
.74553 .88105 m .74472 .87889 L .74387 .8792 L F
.74481 .87671 m .74391 .87918 L .74482 .87886 L .57 .345 .536 r
F
.74472 .87889 m .74453 .8784 L .74387 .8792 L .692 .759 .904 r
F
.74482 .87886 m .74371 .87973 L .74482 .8794 L .57 .345 .536 r
F
.74391 .87918 m .74371 .87973 L .74482 .87886 L F
.74451 .82062 m .74447 .8242 L .74453 .82419 L F
.74447 .8242 m .74371 .87973 L .74453 .82419 L F
.74451 .82023 m .74451 .82063 L .74451 .82062 L F
.74451 .82063 m .74371 .87973 L .74451 .82062 L F
.74441 .82065 m .74341 .82089 L .74343 .82445 L F
.74451 .82023 m .74341 .82089 L .74441 .82065 L F
.74451 .82023 m .74343 .82445 L .74446 .8242 L F
.74343 .82445 m .74262 .87789 L .7437 .87711 L .405 .218 .51 r
F
.74341 .82057 m .74335 .82449 L .74343 .82445 L F
.74551 .82645 m .74183 .8275 L .74272 .82793 L .645 .732 .913 r
F
.74335 .82449 m .74258 .88051 L .74343 .82445 L .405 .218 .51 r
F
.74226 .82517 m .74204 .88153 L .7423 .82511 L 0 0 .386 r
F
.74124 .82689 m .74053 .82616 L .73887 .82713 L .645 .732 .913 r
F
.74551 .82645 m .74164 .82622 L .74124 .82689 L F
.74164 .82622 m .74053 .82616 L .74124 .82689 L F
.74053 .82616 m .73293 .82571 L .73887 .82713 L F
.74551 .82645 m .74124 .82689 L .74068 .82783 L F
.74335 .82449 m .7423 .82511 L .74258 .88051 L .405 .218 .51 r
F
.74341 .82057 m .7423 .82511 L .74335 .82449 L F
.74226 .82517 m .74175 .82603 L .74204 .88153 L 0 0 .386 r
F
.74068 .82783 m .73762 .82726 L .74065 .82784 L .645 .732 .913 r
F
.74124 .82689 m .73762 .82726 L .74068 .82783 L F
.73762 .82726 m .73325 .82771 L .74065 .82784 L F
.7419 .82837 m .73441 .82963 L .73632 .83133 L F
.74188 .8281 m .73441 .82963 L .7419 .82837 L F
.74553 .88105 m .74233 .88239 L .7429 .88283 L .692 .759 .904 r
F
.74245 .88034 m .74297 .88289 L .74246 .88248 L .929 .648 .486 r
F
.74207 .881 m .74065 .88394 L .74296 .8814 L .692 .759 .904 r
F
.74553 .88105 m .74126 .88201 L .74166 .88267 L F
.74208 .88185 m .74246 .88303 L .74209 .88234 L .988 .719 .38 r
F
.74207 .87971 m .74238 .88236 L .74208 .88185 L F
.74233 .88239 m .74166 .88267 L .74264 .8828 L .692 .759 .904 r
F
.74238 .88236 m .74246 .88303 L .74208 .88185 L .988 .719 .38 r
F
.74246 .88248 m .74264 .8828 L .7429 .88283 L .692 .759 .904 r
F
.74233 .88239 m .74264 .8828 L .74246 .88248 L F
.74246 .88248 m .74312 .88362 L .74246 .88303 L .929 .648 .486 r
F
.74297 .88289 m .74312 .88362 L .74246 .88248 L F
.74169 .87905 m .74089 .87909 L .742 .87959 L .692 .759 .904 r
F
.7413 .87839 m .74108 .87836 L .74169 .87905 L F
.74243 .88031 m .74245 .88034 L .74246 .88303 L .988 .719 .38 r
F
.74198 .82977 m .73886 .8327 L .74217 .83301 L .645 .732 .913 r
F
0 g
.74503 .76115 m
.74505 .76618 L
s
.32752 .64126 m
.34696 .64246 L
s
.32843 .82018 m .32735 .82247 L .32842 .82329 L .908 .63 .503 r
F
.32864 .76427 m .32742 .81943 L .32843 .82018 L F
.32898 .76612 m .32888 .82119 L .32877 .82188 L 0 0 .131 r
F
.329 .82038 m .33812 .82146 L .33777 .81947 L .644 .733 .913 r
F
.32561 .82073 m .32892 .82092 L .329 .82038 L F
.32892 .82092 m .33812 .82146 L .329 .82038 L F
.32898 .76612 m .32909 .76531 L .32888 .82115 L 0 0 .131 r
F
.32888 .82119 m .32888 .82115 L .32887 .82432 L F
.32898 .76612 m .32888 .82115 L .32888 .82119 L F
.32742 .81943 m .32735 .82247 L .32843 .82018 L .908 .63 .503 r
F
.32656 .81879 m .32952 .81699 L .32913 .81357 L .644 .733 .913 r
F
.32737 .81939 m .32628 .82209 L .32735 .82247 L .809 .541 .534 r
F
.32758 .76345 m .32634 .81903 L .32737 .81939 L F
.32561 .82073 m .3271 .8193 L .32643 .81906 L .644 .733 .913 r
F
.32909 .76531 m .32864 .76427 L .32843 .82018 L .986 .729 .347 r
F
.32845 .82023 m .32843 .82018 L .32842 .82329 L F
.32909 .76531 m .32843 .82018 L .32845 .82023 L F
.32773 .8187 m .33466 .81587 L .33211 .81451 L .644 .733 .913 r
F
.32561 .82073 m .32807 .81941 L .32773 .8187 L F
.32807 .81941 m .33466 .81587 L .32773 .8187 L F
.32807 .81941 m .33659 .81756 L .33466 .81587 L F
.32561 .82073 m .32832 .81995 L .32807 .81941 L F
.32832 .81995 m .33659 .81756 L .32807 .81941 L F
.32877 .82188 m .32887 .82432 L .32876 .82513 L 0 0 .131 r
F
.32888 .82119 m .32887 .82432 L .32877 .82188 L F
.32888 .82115 m .32842 .82329 L .32887 .82432 L .986 .729 .347 r
F
.32909 .76531 m .32845 .82023 L .32888 .82115 L F
.32845 .82023 m .32842 .82329 L .32888 .82115 L F
.32634 .81903 m .32628 .82209 L .32737 .81939 L .809 .541 .534 r
F
.32643 .81906 m .32716 .81924 L .32656 .81879 L .644 .733 .913 r
F
.3271 .8193 m .32716 .81924 L .32643 .81906 L F
.32716 .81924 m .32952 .81699 L .32656 .81879 L F
.32952 .81699 m .33211 .81451 L .33 .81384 L F
.32952 .81699 m .33 .81384 L .32913 .81357 L F
.59059 .50977 m .591 .50249 L .57658 .48914 L .928 .67 .525 r
F
0 g
.591 .50249 m
.59299 .50592 L
s
.72826 .74177 m .71239 .73703 L .70835 .74263 L .683 .771 .917 r
F
.73136 .73929 m .71239 .73703 L .72826 .74177 L F
0 0 0 r
2.5 Mabswid
.37449 .74856 Mdot
.127 .923 .03 r
.5 Mabswid
.56088 .86375 m
.56107 .86195 L
s
.32081 .82045 m .3136 .81805 L .3131 .81999 L .644 .733 .913 r
F
.32561 .82073 m .32028 .81954 L .32081 .82045 L F
.32028 .81954 m .3136 .81805 L .32081 .82045 L F
.32142 .82147 m .32179 .82569 L .3214 .825 L .989 .721 .393 r
F
.32163 .76599 m .32178 .82207 L .32142 .82147 L F
.32178 .82207 m .32179 .82569 L .32142 .82147 L F
.32129 .81976 m .31492 .81629 L .3136 .81805 L .644 .733 .913 r
F
.32561 .82073 m .32122 .81891 L .32129 .81976 L F
.32122 .81891 m .31492 .81629 L .32129 .81976 L F
.32158 .76518 m .32163 .76599 L .32142 .82147 L .794 .634 .076 r
F
.32141 .82142 m .32142 .82147 L .3214 .825 L F
.32158 .76518 m .32142 .82147 L .32141 .82142 L F
.26989 .61513 m .2696 .60946 L .28796 .60456 L .603 .396 .574 r
F
.127 .923 .03 r
.2815 .55736 m
.28217 .6061 L
s
.25032 .61704 m .2696 .60946 L .26989 .61513 L .672 .449 .574 r
F
0 g
.25003 .61137 m
.2696 .60946 L
s
.74981 .82051 m .75453 .82481 L .7566 .82335 L .645 .732 .913 r
F
.74597 .81891 m .7488 .82086 L .74981 .82051 L F
.7488 .82086 m .75453 .82481 L .74981 .82051 L F
.74664 .76598 m .74767 .76554 L .74796 .82115 L .519 .306 .53 r
F
.7479 .82117 m .74796 .82115 L .74798 .82455 L F
.74664 .76598 m .74796 .82115 L .7479 .82117 L F
.127 .923 .03 r
.49657 8.79907 m
.58383 1.31001 L
s
.58837 .92017 m
.58896 .86917 L
s
0 0 0 r
2.5 Mabswid
.58896 .86917 Mdot
.48232 .60651 m .46263 .61811 L .48464 .61013 L .673 .757 .914 r
F
.48232 .60651 m .45798 .61088 L .46263 .61811 L F
.36191 .74972 m .37492 .738 L .3584 .74449 L .683 .77 .917 r
F
.36191 .74972 m .3802 .74584 L .37492 .738 L F
.127 .923 .03 r
.5 Mabswid
.37449 .74856 m
.39604 8.82655 L
s
.37972 .74127 m .37396 .72886 L .37444 .73343 L .981 .69 .343 r
F
.3802 .74584 m .37972 .74127 L .37444 .73343 L F
0 g
.37972 .74127 m
.38125 .7499 L
s
.74739 .63944 m .72746 .63567 L .7278 .64135 L .672 .449 .574 r
F
0 g
.70937 .64625 m
.7278 .64135 L
s
.74739 .63944 m .74705 .63376 L .72746 .63567 L .672 .449 .574 r
F
0 g
.70903 .64057 m
.72746 .63567 L
s
.26361 .59469 m .26951 .60924 L .28778 .60436 L .673 .757 .914 r
F
.127 .923 .03 r
.28219 .60793 m
.28222 .61031 L
s
.25062 .59596 m .26951 .60924 L .26361 .59469 L .673 .757 .914 r
F
0 0 0 r
2.5 Mabswid
.37532 .74822 Mdot
.70919 .75175 m .6912 .74981 L .68879 .75864 L .683 .771 .917 r
F
0 g
.5 Mabswid
.68879 .75864 m
.69021 .76726 L
s
.74994 .8198 m .7566 .82335 L .75795 .82159 L .645 .732 .913 r
F
.74597 .81891 m .74924 .82027 L .74994 .8198 L F
.74924 .82027 m .7566 .82335 L .74994 .8198 L F
.74767 .76554 m .74838 .76498 L .74868 .82066 L .362 .185 .501 r
F
.74864 .82069 m .74868 .82066 L .74869 .82399 L F
.74767 .76554 m .74868 .82066 L .74864 .82069 L F
.76122 .74459 m .77213 .73376 L .75837 .74242 L .683 .771 .917 r
F
.76122 .74459 m .77782 .7381 L .77213 .73376 L F
.30884 .74814 m .29279 .74338 L .28881 .749 L .683 .77 .917 r
F
.31192 .74565 m .29279 .74338 L .30884 .74814 L F
.127 .923 .03 r
.56137 .8637 m
.56142 .86145 L
s
.31151 .74112 m .29861 .7339 L .29247 .73886 L .683 .77 .917 r
F
.31546 .73913 m .29861 .7339 L .31151 .74112 L F
.65312 .49324 m .64295 .51348 L .65948 .49679 L .654 .726 .902 r
F
.65312 .49324 m .63024 .50638 L .64295 .51348 L F
.32122 .81891 m .31696 .81483 L .31492 .81629 L .644 .733 .913 r
F
.32561 .82073 m .32113 .81767 L .32122 .81891 L F
.32113 .81767 m .31696 .81483 L .32122 .81891 L F
.32136 .82072 m .3214 .825 L .32135 .82419 L .794 .634 .076 r
F
.32158 .76518 m .32141 .82142 L .32136 .82072 L F
.32141 .82142 m .3214 .825 L .32136 .82072 L F
.32189 .81981 m .32135 .82419 L .32187 .82317 L 0 0 .373 r
F
.3221 .76415 m .32139 .82067 L .32189 .81981 L F
.32139 .82067 m .32135 .82419 L .32189 .81981 L F
.32306 .81778 m .32265 .81319 L .3196 .81377 L .644 .733 .913 r
F
.3252 .81885 m .3241 .82205 L .32519 .82196 L .66 .417 .541 r
F
.32541 .76295 m .32417 .81888 L .3252 .81885 L F
.32561 .82073 m .32488 .81886 L .32402 .81889 L .644 .733 .913 r
F
.32322 .81909 m .32306 .81778 L .32256 .81865 L F
.32561 .82073 m .32403 .8189 L .32322 .81909 L F
.32432 .76304 m .32307 .81913 L .32411 .81888 L .568 .344 .535 r
F
.32403 .8189 m .32306 .81778 L .32322 .81909 L .644 .733 .913 r
F
.32411 .81888 m .32299 .82239 L .3241 .82205 L .568 .344 .535 r
F
.32307 .81913 m .32299 .82239 L .32411 .81888 L F
.32417 .81888 m .3241 .82205 L .3252 .81885 L .66 .417 .541 r
F
.32402 .81889 m .32389 .81634 L .32306 .81778 L .644 .733 .913 r
F
.32488 .81886 m .32389 .81634 L .32402 .81889 L F
.32389 .81634 m .32265 .81319 L .32306 .81778 L F
.32256 .81865 m .3196 .81377 L .31696 .81483 L F
.32306 .81778 m .3196 .81377 L .32256 .81865 L F
.3221 .76415 m .32158 .76518 L .32136 .82072 L 0 0 .373 r
F
.32139 .82067 m .32136 .82072 L .32135 .82419 L F
.3221 .76415 m .32136 .82072 L .32139 .82067 L F
.55418 .86038 m .54263 .86563 L .55485 .86437 L .644 .733 .913 r
F
.55418 .86038 m .54162 .85964 L .54263 .86563 L F
0 g
.54263 .86563 m
.54614 .87137 L
s
.22133 .50481 m .19174 .51374 L .22224 .5101 L .654 .726 .902 r
F
.22133 .50481 m .18992 .50316 L .19174 .51374 L F
.69091 .49844 m .70577 .51677 L .71909 .51103 L F
.68323 .50006 m .70577 .51677 L .69091 .49844 L F
.75779 .73789 m .76395 .72612 L .75402 .73632 L .683 .771 .917 r
F
.75779 .73789 m .77148 .72927 L .76395 .72612 L F
.7498 .81913 m .75795 .82159 L .75848 .81964 L .645 .732 .913 r
F
.74597 .81891 m .7494 .81967 L .7498 .81913 L F
.7494 .81967 m .75795 .82159 L .7498 .81913 L F
.74838 .76498 m .74882 .7643 L .74912 .82006 L .088 0 .422 r
F
.74909 .82009 m .74912 .82006 L .74913 .82331 L F
.74838 .76498 m .74912 .82006 L .74909 .82009 L F
.34187 .75098 m .35262 .74015 L .33899 .74881 L .683 .77 .917 r
F
.34187 .75098 m .3584 .74449 L .35262 .74015 L F
.56698 .85734 m .5551 .8606 L .56732 .85934 L .644 .733 .913 r
F
.56698 .85734 m .55442 .85661 L .5551 .8606 L F
.61541 .86991 m .61722 .86029 L .61698 .86406 L 0 0 .152 r
F
.60338 .86722 m .61541 .86991 L .61698 .86406 L .644 .733 .913 r
F
0 g
.61138 .8752 m
.61541 .86991 L
s
.31308 .52009 m .34701 .51138 L .31559 .50974 L .654 .726 .902 r
F
.28292 .51327 m .31308 .52009 L .31559 .50974 L F
.127 .923 .03 r
.30979 .50967 m
.30984 .51036 L
s
.27962 .51798 m .31308 .52009 L .28292 .51327 L .654 .726 .902 r
F
.7668 .64064 m .74705 .63376 L .74739 .63944 L .733 .496 .57 r
F
0 g
.72746 .63567 m
.74705 .63376 L
s
.74705 .63376 m
.76646 .63496 L
s
.7668 .64064 m
.78471 .64487 L
s
0 0 0 r
2.5 Mabswid
.5896 .86817 Mdot
.58421 .49104 m .59339 .49889 L .59297 .50617 L .99 .743 .456 r
F
.58421 .49104 m .58463 .48376 L .59339 .49889 L F
.61522 .48011 m .59339 .49889 L .62105 .4902 L .654 .726 .902 r
F
.61522 .48011 m .58463 .48376 L .59339 .49889 L F
0 g
.5 Mabswid
.59339 .49889 m
.59915 .50423 L
s
.60362 .86345 m .61722 .86029 L .60466 .85956 L .644 .733 .913 r
F
.59158 .86077 m .60362 .86345 L .60466 .85956 L F
.59024 .86253 m .60362 .86345 L .59158 .86077 L F
.71239 .73703 m .69046 .74069 L .70835 .74263 L .683 .771 .917 r
F
0 g
.5663 .75932 m
.58095 .7574 L
s
.30794 .64318 m
.32752 .64126 L
s
.59177 .85699 m .60478 .85578 L .59229 .85505 L .645 .732 .913 r
F
.33416 .73814 m .335 .72619 L .3297 .73726 L .683 .77 .917 r
F
.33416 .73814 m .34393 .72795 L .335 .72619 L F
.21284 .6116 m .23057 .61017 L .23086 .61584 L .794 .544 .56 r
F
.21284 .6116 m .21255 .60593 L .23057 .61017 L F
0 g
.23057 .61017 m
.25003 .61137 L
s
.33851 .74424 m .34451 .73242 L .33469 .74266 L .683 .77 .917 r
F
.33851 .74424 m .35214 .73558 L .34451 .73242 L F
.7292 .75089 m .70919 .75175 L .72716 .7537 L .683 .771 .917 r
F
0 g
.74739 .63944 m
.7668 .64064 L
s
.7488 .81836 m .74777 .82065 L .74882 .82147 L .91 .629 .499 r
F
.7485 .76245 m .74781 .81761 L .7488 .81836 L F
.74882 .7643 m .74923 .81937 L .74912 .82006 L 0 0 .158 r
F
.74937 .81856 m .75848 .81964 L .75816 .81765 L .645 .732 .913 r
F
.74597 .81891 m .74928 .8191 L .74937 .81856 L F
.74928 .8191 m .75848 .81964 L .74937 .81856 L F
.74882 .7643 m .74894 .76349 L .74924 .81933 L 0 0 .158 r
F
.74923 .81937 m .74924 .81933 L .74926 .8225 L F
.74882 .7643 m .74924 .81933 L .74923 .81937 L F
.74781 .81761 m .74777 .82065 L .7488 .81836 L .91 .629 .499 r
F
.74912 .82006 m .74926 .8225 L .74913 .82331 L 0 0 .158 r
F
.74923 .81937 m .74926 .8225 L .74912 .82006 L F
.74924 .81933 m .74882 .82147 L .74926 .8225 L .982 .725 .331 r
F
.74894 .76349 m .74882 .81841 L .74924 .81933 L F
.74882 .81841 m .74882 .82147 L .74924 .81933 L F
.7476 .81571 m .74995 .81517 L .7496 .81175 L .645 .732 .913 r
F
.74775 .81757 m .74669 .82027 L .74777 .82065 L .809 .541 .532 r
F
.74745 .76163 m .74673 .81721 L .74775 .81757 L F
.74597 .81891 m .74749 .81748 L .74682 .81724 L .645 .732 .913 r
F
.74845 .81759 m .75701 .81574 L .75511 .81405 L F
.74597 .81891 m .74869 .81813 L .74845 .81759 L F
.74869 .81813 m .75701 .81574 L .74845 .81759 L F
.74894 .76349 m .7485 .76245 L .7488 .81836 L .982 .725 .331 r
F
.74882 .81841 m .7488 .81836 L .74882 .82147 L F
.74894 .76349 m .7488 .81836 L .74882 .81841 L F
.74673 .81721 m .74669 .82027 L .74775 .81757 L .809 .541 .532 r
F
.74682 .81724 m .74755 .81742 L .74695 .81697 L .645 .732 .913 r
F
.74749 .81748 m .74755 .81742 L .74682 .81724 L F
.74695 .81697 m .74791 .8164 L .7476 .81571 L F
.74791 .8164 m .74995 .81517 L .7476 .81571 L F
.74755 .81742 m .74995 .81517 L .74695 .81697 L F
.74995 .81517 m .75258 .81268 L .75048 .81202 L F
.74995 .81517 m .75048 .81202 L .7496 .81175 L F
.32817 .81999 m .33777 .81947 L .33659 .81756 L .644 .733 .913 r
F
.32561 .82073 m .32873 .8204 L .32817 .81999 L F
.32873 .8204 m .33777 .81947 L .32817 .81999 L F
.32864 .76427 m .32758 .76345 L .32737 .81939 L .908 .63 .503 r
F
.32742 .81943 m .32737 .81939 L .32735 .82247 L F
.32864 .76427 m .32737 .81939 L .32742 .81943 L F
0 g
.32845 .81495 m
.32864 .76427 L
s
.32864 .76427 m
.32867 .75617 L
s
.75659 .50743 m .76714 .48601 L .76674 .49329 L .08 0 .401 r
F
.7562 .51471 m .75659 .50743 L .76674 .49329 L F
.72989 .49589 m .75659 .50743 L .76674 .49329 L .654 .726 .902 r
F
.71949 .50375 m .75659 .50743 L .72989 .49589 L F
0 g
.74801 .51389 m
.75659 .50743 L
s
.127 .923 .03 r
.49653 8.79933 m
.56065 .86596 L
s
0 0 0 r
2.5 Mabswid
.56065 .86596 Mdot
.22575 .59235 m .23068 .60995 L .23771 .59517 L .673 .757 .914 r
F
.22575 .59235 m .21275 .60573 L .23068 .60995 L F
.32322 .76338 m .3221 .76415 L .32187 .82317 L .4 .212 .507 r
F
0 g
.5 Mabswid
.32191 .81333 m
.3221 .76415 L
s
.3221 .76415 m
.32213 .7565 L
s
.78176 .74789 m .79494 .73618 L .77833 .74267 L .683 .771 .917 r
F
.78176 .74789 m .80008 .74402 L .79494 .73618 L F
.29279 .74338 m .27077 .74706 L .28881 .749 L .683 .77 .917 r
F
.79956 .73945 m .79391 .72704 L .79443 .73161 L .98 .687 .329 r
F
.80008 .74402 m .79956 .73945 L .79443 .73161 L F
0 g
.79956 .73945 m
.80095 .74808 L
s
.35727 .73542 m .3651 .72247 L .35153 .7311 L .683 .77 .917 r
F
.35727 .73542 m .37371 .72896 L .3651 .72247 L F
.25061 .62272 m .25032 .61704 L .26989 .61513 L .672 .449 .574 r
F
.23115 .62152 m .25032 .61704 L .25061 .62272 L .733 .497 .57 r
F
.23115 .62152 m .23086 .61584 L .25032 .61704 L F
.2509 .60179 m .25032 .61704 L .26989 .61513 L .673 .757 .914 r
F
.23793 .60099 m .25032 .61704 L .2509 .60179 L F
.23793 .60099 m .23086 .61584 L .25032 .61704 L F
.46449 .50491 m .44285 .48944 L .42738 .50123 L .654 .726 .902 r
F
.47776 .49916 m .44285 .48944 L .46449 .50491 L F
.55333 .50956 m .55706 .48575 L .54059 .50245 L F
.55333 .50956 m .57617 .49642 L .55706 .48575 L F
.72869 .74632 m .71274 .74156 L .70868 .74718 L .683 .771 .917 r
F
.73181 .74383 m .71274 .74156 L .72869 .74632 L F
.28338 .50599 m .31604 .50246 L .28463 .50082 L .654 .726 .902 r
F
.57922 .61833 m .58207 .60077 L .58239 .60644 L 0 0 .327 r
F
.57954 .62401 m .57922 .61833 L .58239 .60644 L F
.55515 .61483 m .57922 .61833 L .58239 .60644 L .673 .757 .914 r
F
0 g
.57463 .62466 m
.57922 .61833 L
s
.73136 .73929 m .7186 .73208 L .71239 .73703 L .683 .771 .917 r
F
.73533 .73731 m .7186 .73208 L .73136 .73929 L F
.32758 .76345 m .3265 .76308 L .32628 .82209 L .809 .541 .534 r
F
.3802 .74584 m .37444 .73343 L .37492 .738 L .981 .69 .343 r
F
0 g
.3802 .74584 m
.38173 .75447 L
s
.55008 .62795 m .57954 .62401 L .55547 .6205 L .673 .758 .914 r
F
.5287 .62072 m .55008 .62795 L .55547 .6205 L F
.52455 .62395 m .55008 .62795 L .5287 .62072 L F
.31546 .73913 m .30651 .72993 L .29861 .7339 L .683 .77 .917 r
F
.32002 .73778 m .30651 .72993 L .31546 .73913 L F
.32432 .76304 m .32322 .76338 L .32299 .82239 L .568 .344 .535 r
F
.76173 .74916 m .77264 .73833 L .75888 .74699 L .683 .771 .917 r
F
.76173 .74916 m .77833 .74267 L .77264 .73833 L F
0 g
.57918 .86059 m
.57919 .86177 L
s
.57918 .86059 m
.57918 .86059 L
s
.3265 .76308 m .32519 .82196 L .32628 .82209 L .734 .478 .541 r
F
0 g
.32523 .7714 m
.32524 .768 L
s
.3265 .76308 m .32541 .76295 L .32519 .82196 L .734 .478 .541 r
F
.30932 .75271 m .29326 .74795 L .28929 .75357 L .683 .77 .917 r
F
.3124 .75022 m .29326 .74795 L .30932 .75271 L F
.32541 .76295 m .32432 .76304 L .3241 .82205 L .66 .417 .541 r
F
0 0 0 r
2.5 Mabswid
.56135 .86497 Mdot
.127 .923 .03 r
.5 Mabswid
.39962 8.82721 m
.56135 .86497 L
s
.48251 .61221 m .46273 .62386 L .48485 .61584 L .673 .757 .914 r
F
.48251 .61221 m .45805 .6166 L .46273 .62386 L F
.26989 .61513 m .28796 .60456 L .28826 .61023 L .603 .396 .574 r
F
.27019 .6208 m .26989 .61513 L .28826 .61023 L F
.25061 .62272 m .26989 .61513 L .27019 .6208 L .672 .449 .574 r
F
.26396 .60051 m .26989 .61513 L .28826 .61023 L .673 .757 .914 r
F
.127 .923 .03 r
.28227 .61373 m
.2823 .61564 L
s
.2509 .60179 m .26989 .61513 L .26396 .60051 L .673 .757 .914 r
F
0 g
.25032 .61704 m
.26989 .61513 L
s
.3297 .73726 m .32535 .72594 L .32487 .73714 L .683 .77 .917 r
F
.3297 .73726 m .335 .72619 L .32535 .72594 L F
.31192 .74565 m .29896 .7384 L .29279 .74338 L F
.31589 .74366 m .29896 .7384 L .31192 .74565 L F
.56674 .86111 m .55485 .86437 L .56707 .86311 L .644 .733 .913 r
F
.56674 .86111 m .55418 .86038 L .55485 .86437 L F
0 g
.7278 .64135 m
.74739 .63944 L
s
.64873 .4815 m .63065 .4991 L .65353 .48596 L .654 .726 .902 r
F
.64873 .4815 m .62105 .4902 L .63065 .4991 L F
.19363 .47831 m .16358 .47152 L .15993 .48699 L F
.16265 .4787 m .15946 .48696 L .15898 .49424 L 0 0 .121 r
F
0 g
.15998 .49 m
.16073 .49433 L
s
.1128 .43644 m
.1559 .4894 L
s
.1559 .4894 m
.15904 .49326 L
s
.16265 .4787 m .16313 .47142 L .15946 .48696 L 0 0 .121 r
F
.19363 .47831 m .15993 .48699 L .19118 .48862 L .654 .726 .902 r
F
.75402 .73632 m .75506 .72437 L .74958 .73544 L .683 .771 .917 r
F
.75402 .73632 m .76395 .72612 L .75506 .72437 L F
.22366 .48511 m .19118 .48862 L .22243 .49026 L .654 .726 .902 r
F
.22366 .48511 m .19363 .47831 L .19118 .48862 L F
.60338 .86722 m .61698 .86406 L .60442 .86333 L .644 .733 .913 r
F
.59134 .86454 m .60338 .86722 L .60442 .86333 L F
.59 .8663 m .60338 .86722 L .59134 .86454 L F
.75837 .74242 m .76456 .73059 L .75459 .74084 L .683 .771 .917 r
F
.75837 .74242 m .77213 .73376 L .76456 .73059 L F
.69797 .48828 m .71949 .50375 L .72989 .49589 L .654 .726 .902 r
F
.69131 .49116 m .71949 .50375 L .69797 .48828 L F
0 0 0 r
2.5 Mabswid
.31043 .51777 Mdot
.74755 .81742 m .75511 .81405 L .75258 .81268 L .645 .732 .913 r
F
.74597 .81891 m .74805 .8178 L .74755 .81742 L F
.74805 .8178 m .75511 .81405 L .74755 .81742 L F
.7485 .76245 m .74745 .76163 L .74775 .81757 L .91 .629 .499 r
F
.74903 .81803 m .75816 .81765 L .75701 .81574 L .645 .732 .913 r
F
.74597 .81891 m .75024 .81847 L .74903 .81803 L F
.75024 .81847 m .75816 .81765 L .74903 .81803 L F
.74745 .76163 m .74638 .76126 L .74668 .81719 L .809 .541 .532 r
F
.74673 .81721 m .74668 .81719 L .74669 .82027 L F
.74745 .76163 m .74668 .81719 L .74673 .81721 L F
.74781 .81761 m .74775 .81757 L .74777 .82065 L .91 .629 .499 r
F
.7485 .76245 m .74775 .81757 L .74781 .81761 L F
0 g
.5 Mabswid
.7485 .76245 m
.74877 .81338 L
s
.74846 .75435 m
.7485 .76245 L
s
.59158 .86077 m .60466 .85956 L .5921 .85882 L .644 .733 .913 r
F
.54342 .85002 m .54211 .8521 L .54186 .85587 L 0 0 .148 r
F
0 g
.5424 .85384 m
.54276 .85592 L
s
.55583 .84897 m .54385 .84629 L .5423 .85211 L .645 .732 .913 r
F
.54342 .85002 m .54367 .84625 L .54211 .8521 L 0 0 .148 r
F
.55583 .84897 m .5423 .85211 L .5548 .85285 L .645 .732 .913 r
F
.28493 .49353 m .31442 .48463 L .28404 .48826 L .654 .726 .902 r
F
.28493 .49353 m .31618 .49516 L .31442 .48463 L F
.56781 .85164 m .5548 .85285 L .56729 .85358 L .645 .732 .913 r
F
.56781 .85164 m .55583 .84897 L .5548 .85285 L F
.74354 .81723 m .74007 .81195 L .73741 .81301 L F
.74559 .81703 m .74451 .82023 L .74561 .82015 L .66 .418 .542 r
F
.7453 .76113 m .74455 .81706 L .74559 .81703 L F
.74597 .81891 m .74441 .81707 L .74354 .81723 L .645 .732 .913 r
F
.74455 .81706 m .74451 .82023 L .74559 .81703 L .66 .418 .542 r
F
.74441 .81707 m .74422 .81684 L .74379 .81709 L .645 .732 .913 r
F
.74441 .81707 m .74379 .81709 L .74354 .81723 L F
.74422 .81684 m .74007 .81195 L .74354 .81723 L F
.7431 .76155 m .74197 .76233 L .74226 .81799 L .405 .218 .51 r
F
.74232 .81796 m .74226 .81799 L .74228 .82135 L F
.7431 .76155 m .74226 .81799 L .74232 .81796 L F
0 g
.74197 .76233 m
.74224 .81451 L
s
.74193 .75467 m
.74197 .76233 L
s
.32002 .73778 m .31563 .72722 L .30651 .72993 L .683 .77 .917 r
F
.32487 .73714 m .31563 .72722 L .32002 .73778 L F
.31618 .49516 m .3448 .481 L .31442 .48463 L .654 .726 .902 r
F
.31618 .49516 m .34744 .4968 L .3448 .481 L F
.57979 .85431 m .58015 .84672 L .5769 .84679 L .645 .732 .913 r
F
.57979 .85431 m .58337 .84717 L .58015 .84672 L F
.71274 .74156 m .6907 .74524 L .70868 .74718 L .683 .771 .917 r
F
.34719 .50134 m .34791 .49682 L .34526 .48095 L .925 .744 .259 r
F
.34746 .5041 m .34526 .48095 L .34481 .48823 L F
.3416 .47757 m .36457 .47755 L .36412 .48483 L .793 .542 .558 r
F
.3416 .47757 m .34206 .4703 L .36457 .47755 L F
.35857 .4534 m .3423 .47005 L .3647 .47727 L .654 .726 .902 r
F
.34392 .48574 m .36412 .48483 L .36367 .49211 L .793 .542 .558 r
F
.34115 .48485 m .34397 .48485 L .34392 .48574 L F
.34397 .48485 m .36412 .48483 L .34392 .48574 L F
.34481 .48823 m .34526 .48095 L .34431 .47933 L .989 .743 .461 r
F
.32241 .4669 m .34206 .4703 L .3416 .47757 L .858 .601 .55 r
F
.32241 .4669 m .32287 .45962 L .34206 .4703 L F
.31442 .48463 m .3448 .481 L .34415 .47989 L .654 .726 .902 r
F
.33926 .47717 m .3416 .47757 L .34155 .47844 L .858 .601 .55 r
F
.34584 .44631 m .32321 .45942 L .3423 .47005 L .654 .726 .902 r
F
.34516 .45372 m .32241 .4669 L .3416 .47757 L F
.32935 .47166 m .34415 .47989 L .33595 .46593 L F
.31442 .48463 m .34415 .47989 L .32935 .47166 L F
.31442 .48463 m .32935 .47166 L .30851 .47459 L F
.32236 .46777 m .32241 .4669 L .33926 .47717 L .858 .601 .55 r
F
.32935 .47166 m .33595 .46593 L .32517 .46933 L .654 .726 .902 r
F
.32935 .47166 m .32517 .46933 L .30851 .47459 L F
.33926 .47717 m .32241 .4669 L .3416 .47757 L .858 .601 .55 r
F
.30786 .45352 m .32287 .45962 L .32241 .4669 L .927 .669 .527 r
F
.30786 .45352 m .30832 .44624 L .32287 .45962 L F
.33619 .43743 m .32321 .45942 L .34584 .44631 L .654 .726 .902 r
F
.33619 .43743 m .30873 .44611 L .32321 .45942 L F
.33546 .4448 m .32241 .4669 L .34516 .45372 L F
.33546 .4448 m .30786 .45352 L .32241 .4669 L F
.31599 .46191 m .33595 .46593 L .32147 .45262 L F
.30851 .47459 m .32435 .46959 L .31599 .46191 L F
.32062 .46617 m .32241 .4669 L .32236 .46777 L .927 .669 .527 r
F
.32435 .46959 m .33595 .46593 L .31599 .46191 L .654 .726 .902 r
F
.30851 .47459 m .31599 .46191 L .29885 .46572 L F
.31599 .46191 m .32147 .45262 L .31191 .45816 L F
.31599 .46191 m .31191 .45816 L .29885 .46572 L F
.32062 .46617 m .30786 .45352 L .32241 .4669 L .927 .669 .527 r
F
.30781 .45439 m .30786 .45352 L .32062 .46617 L F
.29894 .43834 m .30832 .44624 L .30786 .45352 L .989 .743 .462 r
F
.33028 .42736 m .30873 .44611 L .33619 .43743 L .654 .726 .902 r
F
.32952 .43468 m .30786 .45352 L .33546 .4448 L F
.29894 .43834 m .29939 .43106 L .30832 .44624 L .989 .743 .462 r
F
.33028 .42736 m .29985 .43101 L .30873 .44611 L .654 .726 .902 r
F
.32952 .43468 m .29894 .43834 L .30786 .45352 L F
.30198 .44449 m .32147 .45262 L .30236 .44197 L F
.29885 .46572 m .3105 .45897 L .30198 .44449 L F
.30674 .45257 m .30786 .45352 L .30781 .45439 L .989 .743 .462 r
F
.3105 .45897 m .32147 .45262 L .30198 .44449 L .654 .726 .902 r
F
.29885 .46572 m .30198 .44449 L .28611 .45863 L F
.29888 .43921 m .29894 .43834 L .29988 .44006 L .989 .743 .462 r
F
.29983 .44083 m .29988 .44006 L .30674 .45257 L F
.29888 .43921 m .29988 .44006 L .29983 .44083 L F
.30198 .44449 m .30236 .44197 L .3012 .44316 L .654 .726 .902 r
F
.30198 .44449 m .3012 .44316 L .28611 .45863 L F
.29848 .44563 m .29888 .43921 L .30674 .45257 L .989 .743 .462 r
F
.30214 .44901 m .3026 .44172 L .29983 .44083 L .794 .542 .557 r
F
.28611 .45863 m .29979 .44461 L .2799 .43473 L .654 .726 .902 r
F
.29979 .44461 m .30236 .44197 L .29917 .44095 L F
.29979 .44461 m .29917 .44095 L .2799 .43473 L F
.2958 .42969 m .29856 .43731 L .29848 .44563 L .926 .745 .261 r
F
.29856 .43731 m .29894 .43834 L .29888 .43921 L F
.29943 .44722 m .29983 .44083 L .28004 .43445 L .794 .542 .557 r
F
.29856 .43731 m .29888 .43921 L .29848 .44563 L .926 .745 .261 r
F
.30674 .45257 m .29894 .43834 L .30786 .45352 L .989 .743 .462 r
F
.31912 .45755 m .32181 .45242 L .3026 .44172 L .858 .601 .55 r
F
.3074 .4608 m .30781 .45439 L .32062 .46617 L .927 .669 .527 r
F
.3074 .4608 m .32062 .46617 L .32196 .47418 L F
.32062 .46617 m .32236 .46777 L .32196 .47418 L F
.32196 .47418 m .32236 .46777 L .33926 .47717 L .858 .601 .55 r
F
.32764 .46456 m .3074 .4608 L .32196 .47418 L .654 .726 .902 r
F
.33423 .47061 m .33636 .4658 L .32181 .45242 L .927 .669 .527 r
F
.33423 .47061 m .32181 .45242 L .32141 .45883 L F
.34584 .44631 m .3423 .47005 L .35857 .4534 L .654 .726 .902 r
F
.33501 .45208 m .32196 .47418 L .34471 .46101 L F
.33591 .47308 m .33423 .47061 L .32136 .4597 L .927 .669 .527 r
F
.31942 .457 m .3074 .4608 L .32764 .46456 L .654 .726 .902 r
F
.33423 .47061 m .32141 .45883 L .32136 .4597 L .927 .669 .527 r
F
.32196 .47418 m .33926 .47717 L .34115 .48485 L .858 .601 .55 r
F
.33926 .47717 m .34155 .47844 L .34115 .48485 L F
.3416 .48181 m .32196 .47418 L .34115 .48485 L .654 .726 .902 r
F
.33186 .46844 m .32196 .47418 L .34218 .47793 L F
.34115 .48485 m .3416 .47757 L .34437 .47846 L .793 .542 .558 r
F
.34481 .48823 m .34475 .48716 L .34391 .48584 L .989 .743 .461 r
F
.34475 .48716 m .34431 .47933 L .34392 .48574 L F
.34475 .48716 m .34392 .48574 L .34391 .48584 L F
.34115 .48485 m .34437 .47846 L .34397 .48485 L .793 .542 .558 r
F
.3438 .48555 m .34431 .47933 L .33636 .4658 L .989 .743 .461 r
F
.34255 .48342 m .34115 .48485 L .34392 .48574 L .654 .726 .902 r
F
.34391 .48584 m .34392 .48574 L .3438 .48555 L .989 .743 .461 r
F
.34392 .48574 m .34431 .47933 L .3438 .48555 L F
.33596 .47221 m .33636 .4658 L .33423 .47061 L .927 .669 .527 r
F
.34471 .46101 m .33327 .46763 L .34218 .47793 L .654 .726 .902 r
F
.33327 .46763 m .33186 .46844 L .33596 .47221 L F
.3438 .48555 m .33636 .4658 L .33596 .47221 L .989 .743 .461 r
F
.33327 .46763 m .33596 .47221 L .34218 .47793 L .654 .726 .902 r
F
.34397 .48198 m .34255 .48342 L .34463 .48598 L F
.34255 .48342 m .34392 .48574 L .34463 .48598 L F
.34397 .48485 m .34437 .47846 L .36412 .48483 L .793 .542 .558 r
F
.34386 .48661 m .3438 .48555 L .33591 .47308 L .989 .743 .461 r
F
.34481 .48823 m .34391 .48584 L .34386 .48661 L F
.34391 .48584 m .3438 .48555 L .34386 .48661 L F
.3438 .48555 m .33596 .47221 L .33591 .47308 L F
.34218 .47793 m .33897 .47733 L .3416 .48181 L .654 .726 .902 r
F
.33897 .47733 m .32196 .47418 L .3416 .48181 L F
.33501 .45208 m .31942 .457 L .32764 .46456 L F
.33591 .47308 m .33596 .47221 L .33423 .47061 L .927 .669 .527 r
F
.32136 .4597 m .32141 .45883 L .31912 .45755 L .858 .601 .55 r
F
.32141 .45883 m .32181 .45242 L .31912 .45755 L F
.29848 .44563 m .30674 .45257 L .3074 .4608 L .989 .743 .462 r
F
.30674 .45257 m .30781 .45439 L .3074 .4608 L F
.31425 .45484 m .29943 .44724 L .3074 .4608 L .654 .726 .902 r
F
.3022 .44813 m .29943 .44724 L .31425 .45484 L F
.31912 .45755 m .3026 .44172 L .3022 .44813 L .858 .601 .55 r
F
.32906 .44196 m .3074 .4608 L .33501 .45208 L .654 .726 .902 r
F
.32136 .4597 m .31912 .45755 L .30214 .44901 L .858 .601 .55 r
F
.31912 .45755 m .3022 .44813 L .30214 .44901 L F
.32906 .44196 m .30031 .44708 L .31662 .45278 L .654 .726 .902 r
F
.30187 .44803 m .29983 .44083 L .2995 .44727 L .794 .542 .557 r
F
.30031 .44708 m .29943 .44724 L .3022 .44813 L .654 .726 .902 r
F
.30031 .44708 m .3022 .44813 L .31662 .45278 L F
.31662 .45278 m .3022 .44813 L .31425 .45484 L F
.32906 .44196 m .29848 .44563 L .29943 .44724 L F
.2995 .44727 m .29983 .44083 L .29943 .44722 L .794 .542 .557 r
F
.30214 .44901 m .30187 .44803 L .2995 .44727 L F
.35795 .46085 m .3416 .47757 L .36412 .48483 L .654 .726 .902 r
F
.3575 .46813 m .34397 .48198 L .36367 .49211 L F
.34397 .48198 m .34463 .48598 L .36367 .49211 L F
.34746 .5041 m .34751 .50323 L .34719 .50134 L .925 .744 .259 r
F
.34751 .50323 m .34791 .49682 L .34719 .50134 L F
0 g
.34615 .50403 m
.34692 .50089 L
s
.77714 .73359 m .78517 .72065 L .77148 .72927 L .683 .771 .917 r
F
.77714 .73359 m .79366 .72714 L .78517 .72065 L F
.59229 .85505 m .60412 .8518 L .59195 .85306 L .645 .732 .913 r
F
.59229 .85505 m .60478 .85578 L .60412 .8518 L F
.44241 .49673 m .42738 .50123 L .42694 .50851 L .34 .162 .487 r
F
.44241 .49673 m .44285 .48944 L .42738 .50123 L F
0 g
.4174 .51536 m
.42738 .50123 L
s
.60478 .85578 m .61629 .85055 L .60412 .8518 L .645 .732 .913 r
F
.60478 .85578 m .61728 .85651 L .61629 .85055 L F
.32487 .73714 m .32535 .72594 L .31563 .72722 L .683 .77 .917 r
F
.61722 .86029 m .61747 .85653 L .61647 .85053 L .923 .748 .262 r
F
0 g
.61646 .86025 m
.61705 .85806 L
s
.33469 .74266 m .33553 .73065 L .3302 .74178 L .683 .77 .917 r
F
.33469 .74266 m .34451 .73242 L .33553 .73065 L F
.33899 .74881 m .34499 .73699 L .33517 .74723 L F
.33899 .74881 m .35262 .74015 L .34499 .73699 L F
.29247 .73886 m .2765 .73412 L .27057 .74252 L F
.27673 .73862 m .2703 .74249 L .27077 .74706 L .196 .11 .526 r
F
.27673 .73862 m .27626 .73405 L .2703 .74249 L F
0 g
.26802 .75132 m
.2703 .74249 L
s
.59059 .50977 m .57658 .48914 L .57617 .49642 L .928 .67 .525 r
F
.59017 .51705 m .59059 .50977 L .57617 .49642 L F
0 g
.59059 .50977 m
.59934 .52488 L
s
.29326 .74795 m .27124 .75163 L .28929 .75357 L .683 .77 .917 r
F
.80008 .74402 m .79443 .73161 L .79494 .73618 L .98 .687 .329 r
F
0 g
.80008 .74402 m
.80146 .75265 L
s
.35792 .73992 m .36579 .72691 L .35214 .73558 L .683 .77 .917 r
F
.35792 .73992 m .37444 .73343 L .36579 .72691 L F
.73533 .73731 m .72655 .72811 L .7186 .73208 L .683 .771 .917 r
F
.73991 .73595 m .72655 .72811 L .73533 .73731 L F
.47834 .49207 m .46342 .47381 L .44361 .4824 L .654 .726 .902 r
F
.49359 .48884 m .46342 .47381 L .47834 .49207 L F
.7442 .76122 m .7431 .76155 L .74341 .82057 L .57 .345 .536 r
F
.54085 .49534 m .53486 .4715 L .52595 .49053 L .654 .726 .902 r
F
.54085 .49534 m .55723 .47872 L .53486 .4715 L F
.21313 .61728 m .23086 .61584 L .23115 .62152 L .794 .544 .56 r
F
.21313 .61728 m .21284 .6116 L .23086 .61584 L F
.22591 .59816 m .23086 .61584 L .23793 .60099 L .673 .757 .914 r
F
.22591 .59816 m .21284 .6116 L .23086 .61584 L F
0 g
.23086 .61584 m
.25032 .61704 L
s
.28826 .61023 m .28796 .60456 L .30388 .597 L .515 .329 .567 r
F
0 g
.27963 .60678 m
.28796 .60456 L
s
.74638 .76126 m .74561 .82015 L .74669 .82027 L .734 .478 .541 r
F
.74638 .76126 m .7453 .76113 L .74561 .82015 L F
.7292 .75089 m .71325 .74613 L .70919 .75175 L .683 .771 .917 r
F
.73232 .7484 m .71325 .74613 L .7292 .75089 L F
.7453 .76113 m .7442 .76122 L .74451 .82023 L .66 .418 .542 r
F
.2758 .59144 m .28778 .60436 L .30362 .59684 L .673 .757 .914 r
F
.26361 .59469 m .28778 .60436 L .2758 .59144 L F
.74958 .73544 m .74543 .72412 L .74477 .73531 L .683 .771 .917 r
F
.74958 .73544 m .75506 .72437 L .74543 .72412 L F
.55458 .60912 m .58169 .60078 L .55668 .60123 L .673 .757 .914 r
F
.53063 .60563 m .55458 .60912 L .55668 .60123 L F
.52795 .60934 m .55458 .60912 L .53063 .60563 L F
.73181 .74383 m .71898 .73658 L .71274 .74156 L .683 .771 .917 r
F
.7358 .74183 m .71898 .73658 L .73181 .74383 L F
.2512 .60747 m .25061 .62272 L .27019 .6208 L .673 .757 .914 r
F
.23822 .60667 m .25061 .62272 L .2512 .60747 L F
.23822 .60667 m .23115 .62152 L .25061 .62272 L F
.31589 .74366 m .3069 .73441 L .29896 .7384 L .683 .77 .917 r
F
.32047 .74229 m .3069 .73441 L .31589 .74366 L F
.43156 .6092 m .43328 .61532 L .43359 .62099 L .833 .628 .08 r
F
.43156 .6092 m .43125 .60352 L .43328 .61532 L F
0 g
.43328 .61532 m
.43659 .62045 L
s
.45664 .60306 m .43364 .61525 L .45798 .61088 L .673 .757 .914 r
F
.127 .923 .03 r
.44984 .60666 m
.4502 .55023 L
s
.45664 .60306 m .43162 .60351 L .43364 .61525 L .673 .757 .914 r
F
.57954 .62401 m .58239 .60644 L .58272 .61212 L 0 0 .327 r
F
.55547 .6205 m .57954 .62401 L .58272 .61212 L .673 .758 .914 r
F
0 g
.57145 .63517 m
.57954 .62401 L
s
.73991 .73595 m .7357 .72539 L .72655 .72811 L .683 .771 .917 r
F
.74477 .73531 m .7357 .72539 L .73991 .73595 L F
.3124 .75022 m .29943 .74297 L .29326 .74795 L .683 .77 .917 r
F
.31637 .74823 m .29943 .74297 L .3124 .75022 L F
.3302 .74178 m .32583 .7304 L .32535 .74165 L F
.3302 .74178 m .33553 .73065 L .32583 .7304 L F
.59134 .86454 m .60442 .86333 L .59186 .86259 L .644 .733 .913 r
F
.54317 .85379 m .54186 .85587 L .54162 .85964 L 0 0 .148 r
F
0 g
.54216 .85761 m
.54251 .85969 L
s
.55546 .85271 m .54342 .85002 L .54186 .85587 L .644 .733 .913 r
F
.54317 .85379 m .54342 .85002 L .54186 .85587 L 0 0 .148 r
F
.55546 .85271 m .54186 .85587 L .55442 .85661 L .644 .733 .913 r
F
.6148 .48739 m .59297 .50617 L .62064 .49748 L .654 .726 .902 r
F
.6148 .48739 m .58421 .49104 L .59297 .50617 L F
0 g
.59297 .50617 m
.60738 .5195 L
s
.74477 .73531 m .74543 .72412 L .7357 .72539 L .683 .771 .917 r
F
.5675 .8554 m .55442 .85661 L .56698 .85734 L .644 .733 .913 r
F
.5675 .8554 m .55546 .85271 L .55442 .85661 L F
.29861 .7339 m .2765 .73412 L .29247 .73886 L .683 .77 .917 r
F
.75459 .74084 m .75563 .72882 L .75012 .73995 L .683 .771 .917 r
F
.75459 .74084 m .76456 .73059 L .75563 .72882 L F
.57954 .85808 m .57358 .85111 L .57092 .85217 L .644 .733 .913 r
F
0 g
.57608 .8534 m
.57608 .85403 L
s
.57954 .85808 m .57664 .85052 L .57358 .85111 L .644 .733 .913 r
F
.57954 .85808 m .57991 .85045 L .57664 .85052 L F
.57954 .85808 m .58314 .8509 L .57991 .85045 L F
.57954 .85808 m .58614 .85184 L .58314 .8509 L F
.57954 .85808 m .58868 .85321 L .58614 .85184 L F
.58262 .85687 m .58156 .85606 L .58156 .85654 L .909 .63 .501 r
F
.58305 .85707 m .59177 .85682 L .5906 .85491 L .644 .733 .913 r
F
.57954 .85808 m .58445 .85758 L .58305 .85707 L F
.58445 .85758 m .59177 .85682 L .58305 .85707 L F
.58313 .85771 m .5921 .85882 L .59177 .85682 L F
.57954 .85808 m .58397 .85834 L .58313 .85771 L F
.58397 .85834 m .5921 .85882 L .58313 .85771 L F
.58134 .85993 m .58844 .85698 L .58589 .85561 L F
.58156 .85606 m .58049 .85568 L .58049 .85972 L .809 .541 .533 r
F
.5793 .86185 m .58199 .86042 L .58157 .8601 L .644 .733 .913 r
F
.5793 .86185 m .58157 .8601 L .58127 .85999 L F
.58261 .85732 m .58156 .85654 L .58157 .8601 L .909 .63 .501 r
F
.5793 .86185 m .58335 .86143 L .58263 .86089 L .644 .733 .913 r
F
.58485 .86128 m .59186 .86259 L .59153 .86059 L F
.5793 .86185 m .58785 .86235 L .58485 .86128 L F
.58785 .86235 m .59186 .86259 L .58485 .86128 L F
.57887 .91424 m .58259 .91543 L .58306 .91473 L .692 .759 .904 r
F
.58157 .8601 m .58064 .912 L .58166 .91227 L .809 .541 .533 r
F
.58084 .91205 m .58204 .91209 L .58116 .9117 L .692 .759 .904 r
F
.57887 .91424 m .58175 .91229 L .58084 .91205 L F
.58175 .91229 m .58204 .91209 L .58084 .91205 L F
.57887 .91424 m .58324 .914 L .58312 .91328 L F
.57887 .91424 m .58312 .91328 L .58271 .91263 L F
.58166 .91227 m .58085 .9142 L .58166 .91441 L .809 .541 .533 r
F
.57887 .91424 m .58306 .91473 L .58324 .914 L .692 .759 .904 r
F
.58109 .91426 m .58232 .91428 L .58143 .91388 L F
.57887 .91424 m .58187 .91604 L .58259 .91543 L F
.57913 .91643 m .582 .9145 L .58109 .91426 L F
.57913 .91643 m .5834 .91548 L .583 .91482 L F
.58272 .91511 m .58166 .9152 L .58272 .91601 L .909 .63 .501 r
F
.58262 .86089 m .58168 .91442 L .58272 .91511 L F
.57887 .91424 m .58095 .91653 L .58187 .91604 L .692 .759 .904 r
F
.57913 .91643 m .583 .91482 L .58232 .91428 L F
.58168 .91442 m .58166 .9152 L .58272 .91511 L .909 .63 .501 r
F
.582 .9145 m .58232 .91428 L .58145 .91427 L .692 .759 .904 r
F
.58166 .91441 m .58145 .91427 L .58109 .91426 L F
.582 .9145 m .58145 .91427 L .58166 .91441 L F
.58166 .91441 m .58059 .91482 L .58166 .9152 L .809 .541 .533 r
F
.58085 .9142 m .58059 .91482 L .58166 .91441 L F
.57887 .91424 m .58271 .91263 L .58204 .91209 L .692 .759 .904 r
F
.58064 .912 m .58059 .91482 L .58166 .91227 L .809 .541 .533 r
F
.58156 .85654 m .5815 .86008 L .58157 .8601 L F
.5815 .86008 m .58059 .91482 L .58157 .8601 L F
.58255 .86083 m .58157 .8601 L .58166 .9152 L .909 .63 .501 r
F
.58261 .85732 m .58157 .8601 L .58255 .86083 L F
.58263 .86089 m .59153 .86059 L .59036 .85868 L .644 .733 .913 r
F
.58335 .86143 m .59153 .86059 L .58263 .86089 L F
.58199 .86042 m .59036 .85868 L .58844 .85698 L F
.5793 .86185 m .58263 .86089 L .58199 .86042 L F
.58263 .86089 m .59036 .85868 L .58199 .86042 L F
.58261 .85732 m .58255 .86083 L .58262 .85733 L .909 .63 .501 r
F
.58255 .86083 m .58166 .9152 L .58256 .86084 L F
.58255 .86083 m .58256 .86084 L .58262 .85733 L F
.58149 .86007 m .58049 .85972 L .58059 .91482 L .809 .541 .533 r
F
.57954 .85808 m .58249 .85724 L .58193 .85681 L .644 .733 .913 r
F
.58156 .85606 m .58049 .85972 L .58149 .86007 L .809 .541 .533 r
F
.58127 .85999 m .58157 .8601 L .58134 .85993 L .644 .733 .913 r
F
.58262 .85733 m .58256 .86084 L .58262 .86089 L .909 .63 .501 r
F
.58199 .86042 m .58844 .85698 L .58134 .85993 L .644 .733 .913 r
F
.58256 .86084 m .58166 .9152 L .58262 .86089 L .909 .63 .501 r
F
.58262 .85687 m .58261 .85732 L .58262 .85733 L F
.58156 .85606 m .58155 .85654 L .58156 .85654 L .809 .541 .533 r
F
.58155 .85654 m .58059 .91482 L .58156 .85654 L F
.58262 .85687 m .58156 .85654 L .58261 .85732 L .909 .63 .501 r
F
.58193 .85681 m .5906 .85491 L .58868 .85321 L .644 .733 .913 r
F
.58249 .85724 m .5906 .85491 L .58193 .85681 L F
.75888 .74699 m .76507 .73516 L .7551 .74541 L .683 .771 .917 r
F
.75888 .74699 m .77264 .73833 L .76507 .73516 L F
.71239 .73703 m .69652 .7323 L .69046 .74069 L F
.5921 .85882 m .604 .85556 L .59177 .85682 L .644 .733 .913 r
F
.5921 .85882 m .60466 .85956 L .604 .85556 L F
.69679 .7368 m .69019 .74067 L .6907 .74524 L .208 .121 .532 r
F
.69679 .7368 m .69628 .73223 L .69019 .74067 L F
0 g
.68777 .7495 m
.69019 .74067 L
s
.60466 .85956 m .61623 .8543 L .604 .85556 L .644 .733 .913 r
F
.60466 .85956 m .61722 .86029 L .61623 .8543 L F
.61722 .86029 m .61647 .85053 L .61623 .8543 L .923 .748 .262 r
F
.61698 .86406 m .61722 .86029 L .61623 .8543 L F
0 g
.61622 .86402 m
.61681 .86183 L
s
.127 .923 .03 r
.61711 1.32987 m
.6265 .75195 L
s
.56914 .84988 m .55583 .84897 L .56781 .85164 L .645 .732 .913 r
F
.59195 .85306 m .6018 .84799 L .59079 .85115 L F
.59195 .85306 m .60412 .8518 L .6018 .84799 L F
.48283 .61789 m .46304 .62954 L .48516 .62152 L .673 .758 .914 r
F
.48283 .61789 m .45836 .62228 L .46304 .62954 L F
.7562 .51471 m .76674 .49329 L .76635 .50057 L .08 0 .401 r
F
.72949 .50317 m .7562 .51471 L .76635 .50057 L .654 .726 .902 r
F
.71909 .51103 m .7562 .51471 L .72949 .50317 L F
0 g
.74059 .52647 m
.7562 .51471 L
s
.27019 .6208 m .28826 .61023 L .28856 .6159 L .603 .396 .574 r
F
.26425 .60619 m .27019 .6208 L .28856 .6159 L .673 .757 .914 r
F
.127 .923 .03 r
.28237 .62096 m
.28255 .63405 L
s
.28232 .61757 m
.28237 .62096 L
s
.2512 .60747 m .27019 .6208 L .26425 .60619 L .673 .757 .914 r
F
0 g
.25061 .62272 m
.27019 .6208 L
s
.32047 .74229 m .31606 .73168 L .3069 .73441 L .683 .77 .917 r
F
.32535 .74165 m .31606 .73168 L .32047 .74229 L F
.71325 .74613 m .6912 .74981 L .70919 .75175 L .683 .771 .917 r
F
.77782 .7381 m .78589 .72509 L .77213 .73376 L F
.77782 .7381 m .79443 .73161 L .78589 .72509 L F
.32535 .74165 m .32583 .7304 L .31606 .73168 L .683 .77 .917 r
F
.33517 .74723 m .33601 .73522 L .33068 .74635 L F
.33517 .74723 m .34499 .73699 L .33601 .73522 L F
.46406 .51219 m .44241 .49673 L .42694 .50851 L .654 .726 .902 r
F
0 g
.41696 .52263 m
.42694 .50851 L
s
.47733 .50644 m .44241 .49673 L .46406 .51219 L .654 .726 .902 r
F
.27721 .74319 m .27077 .74706 L .27124 .75163 L .196 .11 .526 r
F
.29279 .74338 m .27673 .73862 L .27077 .74706 L .683 .77 .917 r
F
.27721 .74319 m .27673 .73862 L .27077 .74706 L .196 .11 .526 r
F
0 g
.2685 .75589 m
.27077 .74706 L
s
.58262 .85733 m
.58262 .85871 L
s
.55291 .51684 m .55664 .49303 L .54017 .50973 L .654 .726 .902 r
F
.55291 .51684 m .57575 .5037 L .55664 .49303 L F
.28292 .51327 m .31559 .50974 L .28417 .50809 L F
0 g
.57617 .91331 m
.57617 .91459 L
s
.3584 .74449 m .36627 .73149 L .35262 .74015 L .683 .77 .917 r
F
.3584 .74449 m .37492 .738 L .36627 .73149 L F
.7358 .74183 m .72697 .73259 L .71898 .73658 L .683 .771 .917 r
F
.7404 .74047 m .72697 .73259 L .7358 .74183 L F
.73232 .7484 m .71949 .74115 L .71325 .74613 L F
.73631 .7464 m .71949 .74115 L .73232 .7484 L F
.75012 .73995 m .74594 .72857 L .74528 .73983 L F
.75012 .73995 m .75563 .72882 L .74594 .72857 L F
.31637 .74823 m .30737 .73898 L .29943 .74297 L .683 .77 .917 r
F
.32095 .74686 m .30737 .73898 L .31637 .74823 L F
.7186 .73208 m .69652 .7323 L .71239 .73703 L .683 .771 .917 r
F
.25594 .49014 m .2562 .4857 L .25445 .48971 L .675 .735 .895 r
F
.25594 .49014 m .25919 .48655 L .2562 .4857 L F
.64832 .48878 m .63024 .50638 L .65312 .49324 L .654 .726 .902 r
F
.64832 .48878 m .62064 .49748 L .63024 .50638 L F
.25279 .49942 m .24844 .49643 L .24741 .49729 L .675 .735 .895 r
F
.19285 .48552 m .16265 .4787 L .15898 .49424 L .654 .726 .902 r
F
.16217 .48598 m .15898 .49424 L .1585 .50152 L 0 0 .121 r
F
0 g
.1595 .49727 m
.16026 .50161 L
s
.16217 .48598 m .16265 .4787 L .15898 .49424 L 0 0 .121 r
F
.19285 .48552 m .15898 .49424 L .19039 .49588 L .654 .726 .902 r
F
.19748 .60462 m .21255 .60593 L .21284 .6116 L .859 .596 .541 r
F
.19748 .60462 m .1972 .59894 L .21255 .60593 L F
0 g
.21255 .60593 m
.21728 .60704 L
s
.2262 .60384 m .23115 .62152 L .23822 .60667 L .673 .757 .914 r
F
.2262 .60384 m .21313 .61728 L .23115 .62152 L F
0 g
.23115 .62152 m
.25061 .62272 L
s
.28826 .61023 m .30388 .597 L .30417 .60267 L .515 .329 .567 r
F
.28856 .6159 m .28826 .61023 L .30417 .60267 L F
.27621 .59724 m .28826 .61023 L .30417 .60267 L .673 .757 .914 r
F
.26396 .60051 m .28826 .61023 L .27621 .59724 L F
0 g
.27992 .61245 m
.28826 .61023 L
s
.55522 .85648 m .54162 .85964 L .55418 .86038 L .644 .733 .913 r
F
.55522 .85648 m .54317 .85379 L .54162 .85964 L F
0 g
.54162 .85964 m
.54263 .86563 L
s
.22304 .49235 m .19039 .49588 L .2218 .49753 L .654 .726 .902 r
F
.22304 .49235 m .19285 .48552 L .19039 .49588 L F
.56726 .85916 m .55418 .86038 L .56674 .86111 L .644 .733 .913 r
F
.56726 .85916 m .55522 .85648 L .55418 .86038 L F
.58038 .8597 m .58589 .85561 L .5829 .85467 L F
.5793 .86185 m .58142 .85985 L .58038 .8597 L F
.58142 .85985 m .58589 .85561 L .58038 .8597 L F
.58049 .85972 m .57955 .91194 L .58058 .91198 L .734 .478 .541 r
F
.5799 .91196 m .58116 .9117 L .58012 .91148 L .692 .759 .904 r
F
.57887 .91424 m .58089 .912 L .5799 .91196 L F
.58089 .912 m .58116 .9117 L .5799 .91196 L F
.57955 .91194 m .5795 .91469 L .58058 .91198 L .734 .478 .541 r
F
.57924 .91407 m .58039 .91366 L .57926 .91363 L .692 .759 .904 r
F
.57887 .91424 m .57875 .91703 L .57988 .91687 L F
.57913 .91643 m .58019 .91411 L .57924 .91407 L F
.58058 .91198 m .57974 .91409 L .58059 .91413 L .734 .478 .541 r
F
.58019 .91411 m .58039 .91366 L .57924 .91407 L .692 .759 .904 r
F
.57913 .91643 m .58143 .91388 L .58039 .91366 L F
.58059 .91413 m .5795 .91469 L .58059 .91482 L .734 .478 .541 r
F
.57974 .91409 m .5795 .91469 L .58059 .91413 L F
.58049 .85568 m .58042 .8597 L .58049 .85972 L F
.58042 .8597 m .5795 .91469 L .58049 .85972 L F
.58049 .85568 m .5794 .85555 L .5795 .91469 L F
.37444 .73343 m .37396 .72886 L .3653 .72234 L .932 .647 .478 r
F
0 g
.37396 .72886 m
.37923 .7367 L
s
.57611 .85967 m .57333 .85488 L .57067 .85594 L .644 .733 .913 r
F
.5793 .86185 m .57739 .85962 L .57611 .85967 L F
.57739 .85962 m .57333 .85488 L .57611 .85967 L F
.5794 .85555 m .57831 .85564 L .57832 .85959 L .66 .418 .542 r
F
.57934 .85956 m .57832 .85959 L .57841 .91478 L F
.5794 .85555 m .57832 .85959 L .57934 .85956 L F
.69757 .49556 m .71909 .51103 L .72949 .50317 L .654 .726 .902 r
F
.69091 .49844 m .71909 .51103 L .69757 .49556 L F
.35153 .7311 m .3537 .71775 L .34393 .72795 L .683 .77 .917 r
F
.35153 .7311 m .3651 .72247 L .3537 .71775 L F
.21556 .58771 m .21275 .60573 L .22575 .59235 L .673 .757 .914 r
F
.21556 .58771 m .19747 .59877 L .21275 .60573 L F
0 g
.57608 .85696 m
.57608 .85809 L
s
.5793 .86185 m .5764 .85429 L .57333 .85488 L .644 .733 .913 r
F
0 g
.57609 .86052 m
.57617 .91227 L
s
.5793 .86185 m .57966 .85422 L .5764 .85429 L .644 .733 .913 r
F
.5793 .86185 m .5829 .85467 L .57966 .85422 L F
.25445 .48971 m .25297 .4854 L .25283 .48956 L .675 .735 .895 r
F
.25283 .48956 m .24972 .48566 L .25121 .48969 L F
.25283 .48956 m .25297 .4854 L .24972 .48566 L F
.2545 .49254 m .25301 .4882 L .25288 .49239 L F
.25288 .49239 m .24975 .48847 L .25125 .49252 L F
.25288 .49239 m .25301 .4882 L .24975 .48847 L F
.25293 .49523 m .2498 .49131 L .25129 .49537 L F
.25293 .49523 m .25306 .49105 L .2498 .49131 L F
.25297 .4854 m .24823 .48163 L .24972 .48566 L F
.25297 .4854 m .2531 .48123 L .24823 .48163 L F
.25301 .4882 m .24825 .48441 L .24975 .48847 L F
.25301 .4882 m .25315 .48401 L .24825 .48441 L F
.25306 .49105 m .2483 .48726 L .2498 .49131 L F
.25306 .49105 m .2532 .48686 L .2483 .48726 L F
.25315 .48401 m .24821 .48157 L .24825 .48441 L .665 .425 .546 r
F
.25315 .48401 m .2531 .48117 L .24821 .48157 L F
.2532 .48686 m .24825 .48441 L .2483 .48726 L F
.2532 .48686 m .25315 .48401 L .24825 .48441 L F
.25322 .49917 m .25388 .47894 L .24572 .4792 L .654 .726 .902 r
F
0 g
.24954 .50256 m
.24956 .49814 L
s
.25445 .48971 m .2562 .4857 L .25297 .4854 L .675 .735 .895 r
F
.25601 .49296 m .25626 .4885 L .2545 .49254 L F
.2545 .49254 m .25626 .4885 L .25301 .4882 L F
.25919 .48655 m .25795 .48168 L .2562 .4857 L F
.25455 .49538 m .25306 .49105 L .25293 .49523 L F
.25455 .49538 m .25631 .49135 L .25306 .49105 L F
.2562 .4857 m .2531 .48123 L .25297 .4854 L F
.2562 .4857 m .25795 .48168 L .2531 .48123 L F
.25927 .48936 m .25802 .48447 L .25626 .4885 L F
.25626 .4885 m .25315 .48401 L .25301 .4882 L F
.25626 .4885 m .25802 .48447 L .25315 .48401 L F
.25631 .49135 m .2532 .48686 L .25306 .49105 L F
.25631 .49135 m .25807 .48732 L .2532 .48686 L F
.25802 .48447 m .25798 .48162 L .2531 .48117 L .731 .477 .544 r
F
.26253 .48575 m .25798 .48162 L .25802 .48447 L .794 .529 .537 r
F
.25802 .48447 m .2531 .48117 L .25315 .48401 L .731 .477 .544 r
F
.25807 .48732 m .25802 .48447 L .25315 .48401 L F
.25807 .48732 m .25315 .48401 L .2532 .48686 L F
.25322 .49917 m .26199 .48005 L .25388 .47894 L .654 .726 .902 r
F
0 g
.25609 .49917 m
.2561 .49836 L
s
.59186 .86259 m .60376 .85933 L .59153 .86059 L .644 .733 .913 r
F
.59186 .86259 m .60442 .86333 L .60376 .85933 L F
.57807 .91215 m .57899 .91144 L .57786 .9116 L .692 .759 .904 r
F
.57887 .91424 m .57897 .91202 L .57807 .91215 L F
.5794 .85555 m .57845 .91209 L .5795 .91194 L .66 .418 .542 r
F
.57897 .91202 m .57899 .91144 L .57807 .91215 L .692 .759 .904 r
F
.57887 .91424 m .58012 .91148 L .57899 .91144 L F
.57845 .91209 m .57841 .91478 L .5795 .91194 L .66 .418 .542 r
F
.5783 .91426 m .57926 .91363 L .57812 .91378 L .692 .759 .904 r
F
.57913 .91643 m .57924 .91412 L .5783 .91426 L F
.5795 .91194 m .57863 .91421 L .5795 .91408 L .66 .418 .542 r
F
.57924 .91412 m .57926 .91363 L .5783 .91426 L .692 .759 .904 r
F
.5795 .91408 m .57841 .91478 L .5795 .91469 L .66 .418 .542 r
F
.57863 .91421 m .57841 .91478 L .5795 .91408 L F
.64638 .46916 m .62174 .48283 L .64928 .47418 L .654 .726 .902 r
F
.64638 .46916 m .61594 .47279 L .62174 .48283 L F
.55515 .61483 m .58239 .60644 L .55726 .6069 L .673 .757 .914 r
F
.53107 .61133 m .55515 .61483 L .55726 .6069 L F
.52838 .61505 m .55515 .61483 L .53107 .61133 L F
.7404 .74047 m .73617 .72986 L .72697 .73259 L .683 .771 .917 r
F
.74528 .73983 m .73617 .72986 L .7404 .74047 L F
.33068 .74635 m .32631 .73497 L .32583 .74622 L .683 .77 .917 r
F
.33068 .74635 m .33601 .73522 L .32631 .73497 L F
.28463 .50082 m .31427 .49188 L .28374 .49552 L .654 .726 .902 r
F
.28463 .50082 m .31604 .50246 L .31427 .49188 L F
.60442 .86333 m .61599 .85807 L .60376 .85933 L .644 .733 .913 r
F
.60442 .86333 m .61698 .86406 L .61599 .85807 L F
.61698 .86406 m .61623 .8543 L .61599 .85807 L .923 .748 .262 r
F
0 g
.61541 .86991 m
.61698 .86406 L
s
.127 .923 .03 r
.61239 2.53783 m
.66853 .86214 L
s
.56885 .85363 m .55546 .85271 L .5675 .8554 L .644 .733 .913 r
F
.31604 .50246 m .34481 .48823 L .31427 .49188 L .654 .726 .902 r
F
.31604 .50246 m .34746 .5041 L .34481 .48823 L F
.67808 .46898 m .67588 .48567 L .67665 .48564 L F
.67891 .47128 m .67665 .48564 L .684 .4854 L F
.67808 .46898 m .67665 .48564 L .67891 .47128 L F
.67957 .45354 m .6797 .45272 L .67975 .46596 L 0 0 .152 r
F
.67933 .4686 m .684 .4854 L .68783 .48459 L .654 .726 .902 r
F
.68269 .47275 m .68783 .48459 L .69164 .48379 L F
.67933 .4686 m .68783 .48459 L .68269 .47275 L F
.67914 .45422 m .67957 .45354 L .67962 .46673 L .082 0 .419 r
F
.67957 .46748 m .69164 .48379 L .69827 .48093 L .654 .726 .902 r
F
.67802 .46823 m .67822 .46879 L .67864 .46817 L F
.67782 .46825 m .67785 .46835 L .67802 .46823 L F
.67785 .46835 m .684 .4854 L .67802 .46823 L F
.6774 .45523 m .67842 .45479 L .67848 .46789 L .517 .303 .528 r
F
.67778 .46815 m .67782 .46825 L .67869 .46781 L .654 .726 .902 r
F
.67785 .46835 m .67772 .46951 L .67808 .46898 L F
.67782 .46825 m .6778 .46839 L .67785 .46835 L F
.67869 .46781 m .68269 .47275 L .67957 .46748 L F
.68269 .47275 m .69164 .48379 L .6816 .47023 L F
.68269 .47275 m .6816 .47023 L .67957 .46748 L F
.67914 .45422 m .67962 .46673 L .67928 .46723 L .082 0 .419 r
F
.6797 .45272 m .67925 .45167 L .6793 .46494 L .982 .725 .331 r
F
.67925 .46913 m .684 .4854 L .67933 .4686 L .654 .726 .902 r
F
.67876 .46937 m .68015 .47033 L .6792 .46868 L .675 .735 .895 r
F
.67684 .46552 m .69827 .48093 L .69898 .48038 L .654 .726 .902 r
F
.68398 .46861 m .69898 .48038 L .70344 .47701 L F
.67684 .46552 m .69898 .48038 L .68398 .46861 L F
.67962 .46805 m .68118 .46947 L .68185 .46847 L .675 .735 .895 r
F
.67768 .46819 m .67848 .46789 L .67848 .46927 L .517 .303 .528 r
F
.67729 .47139 m .68178 .47461 L .67882 .47098 L .675 .735 .895 r
F
.67768 .46819 m .67848 .46927 L .67784 .46954 L .517 .303 .528 r
F
.67586 .46735 m .67882 .47098 L .68015 .47033 L .675 .735 .895 r
F
.67534 .48277 m .68017 .47952 L .68025 .48237 L .665 .425 .546 r
F
.68083 .48501 m .67663 .49301 L .68363 .49278 L .654 .726 .902 r
F
.67608 .48517 m .68025 .48237 L .68031 .48503 L .665 .425 .546 r
F
.67878 .47932 m .67787 .48511 L .68083 .48501 L .654 .726 .902 r
F
.67787 .48511 m .67663 .49301 L .68083 .48501 L F
.67534 .48277 m .67527 .47992 L .68017 .47952 L .665 .425 .546 r
F
.67554 .47858 m .68025 .48237 L .67881 .47831 L .675 .735 .895 r
F
.67777 .47652 m .67717 .48513 L .67878 .47932 L .654 .726 .902 r
F
.67717 .48513 m .67663 .49301 L .67787 .48511 L F
.67608 .48517 m .67534 .48277 L .68025 .48237 L .665 .425 .546 r
F
.67717 .48513 m .67787 .48511 L .67878 .47932 L .654 .726 .902 r
F
.67326 .4547 m .67424 .45518 L .67429 .46812 L .845 .571 .523 r
F
.67222 .4534 m .6726 .4541 L .67265 .46704 L .988 .719 .38 r
F
.67644 .47394 m .67298 .4782 L .67588 .48567 L .654 .726 .902 r
F
.67298 .4782 m .66782 .48456 L .6734 .48533 L F
.67298 .4782 m .6734 .48533 L .67588 .48567 L F
.67218 .45259 m .67222 .4534 L .67227 .46635 L .772 .616 .051 r
F
.67553 .47229 m .67288 .47651 L .67644 .47394 L .654 .726 .902 r
F
.67288 .47651 m .66782 .48456 L .67298 .4782 L F
.67288 .47651 m .67298 .4782 L .67644 .47394 L F
.67614 .47018 m .67523 .47175 L .6766 .47059 L F
.67523 .47175 m .66782 .48456 L .67553 .47229 L F
.67523 .47175 m .67553 .47229 L .6766 .47059 L F
.67638 .46915 m .67592 .46998 L .67666 .46929 L F
.67592 .46998 m .66782 .48456 L .67614 .47018 L F
.67592 .46998 m .67614 .47018 L .67666 .46929 L F
.6755 .46835 m .67536 .46865 L .67669 .46858 L F
.67536 .46865 m .66782 .48456 L .67638 .46915 L F
.67536 .46865 m .67638 .46915 L .67669 .46858 L F
.67222 .4534 m .67235 .4665 L .67227 .46635 L .988 .719 .38 r
F
.67218 .45259 m .67224 .46574 L .67223 .46557 L .772 .616 .051 r
F
.67218 .45259 m .67227 .46635 L .67224 .46574 L F
.67272 .45155 m .67218 .45259 L .67223 .46557 L 0 0 .382 r
F
.6755 .46835 m .66573 .47727 L .66782 .48456 L .654 .726 .902 r
F
.67427 .46811 m .66639 .47608 L .6755 .46835 L F
.66639 .47608 m .66038 .48215 L .66573 .47727 L F
.66639 .47608 m .66573 .47727 L .6755 .46835 L F
.67684 .46552 m .65405 .47861 L .66038 .48215 L F
.6754 .48519 m .67534 .48277 L .67608 .48517 L .665 .425 .546 r
F
.67584 .48525 m .66737 .49193 L .67547 .49305 L .654 .726 .902 r
F
.67155 .48466 m .67534 .48277 L .6754 .48519 L .731 .477 .544 r
F
.67608 .48028 m .67269 .48482 L .67584 .48525 L .654 .726 .902 r
F
.67269 .48482 m .66737 .49193 L .67584 .48525 L F
.67055 .48516 m .67155 .48466 L .67541 .48561 L .731 .477 .544 r
F
.67155 .48466 m .6754 .48519 L .67541 .48561 L F
.67224 .47539 m .67043 .47941 L .67527 .47986 L .675 .735 .895 r
F
.67048 .48231 m .67041 .47947 L .67527 .47992 L .731 .477 .544 r
F
.6723 .47828 m .67534 .48277 L .67554 .47858 L .675 .735 .895 r
F
.67437 .47717 m .67273 .48062 L .67608 .48028 L .654 .726 .902 r
F
.67155 .48466 m .67048 .48231 L .67534 .48277 L .731 .477 .544 r
F
.67086 .48457 m .66737 .49193 L .67269 .48482 L .654 .726 .902 r
F
.67055 .48516 m .67053 .48452 L .67155 .48466 L .731 .477 .544 r
F
.67053 .48452 m .67048 .48231 L .67155 .48466 L F
.67048 .48231 m .67527 .47992 L .67534 .48277 L F
.6723 .47828 m .67048 .48231 L .67534 .48277 L .675 .735 .895 r
F
.67273 .48062 m .67086 .48457 L .67296 .48446 L .654 .726 .902 r
F
.67086 .48457 m .67269 .48482 L .67296 .48446 L F
.67273 .48062 m .67296 .48446 L .67608 .48028 L F
.67424 .45518 m .67464 .46818 L .67429 .46812 L .751 .491 .538 r
F
.67326 .4547 m .67352 .46773 L .6733 .46763 L .845 .571 .523 r
F
.67326 .4547 m .67429 .46812 L .67352 .46773 L F
.67684 .46552 m .66587 .46897 L .65405 .47861 L .654 .726 .902 r
F
.66587 .46897 m .64928 .47418 L .65267 .47733 L F
.66587 .46897 m .65267 .47733 L .65405 .47861 L F
.6726 .4541 m .67326 .4547 L .6733 .46763 L .93 .648 .486 r
F
.67384 .45077 m .67272 .45155 L .67276 .4646 L .402 .214 .508 r
F
.67296 .46921 m .67034 .46941 L .67129 .47028 L .675 .735 .895 r
F
.67352 .46773 m .67429 .46812 L .67429 .46969 L .845 .571 .523 r
F
.66725 .48346 m .66582 .4842 L .67084 .48462 L .654 .726 .902 r
F
.66606 .48388 m .66724 .48346 L .67055 .48516 L .794 .529 .536 r
F
.66724 .48346 m .67048 .48231 L .67053 .48452 L F
.66724 .48346 m .67053 .48452 L .67055 .48516 L F
.67084 .48462 m .66582 .4842 L .66737 .49193 L .654 .726 .902 r
F
.67273 .48062 m .66725 .48346 L .67084 .48462 L F
.67437 .47717 m .67261 .47861 L .67273 .48062 L F
.66599 .48103 m .67041 .47947 L .67048 .48231 L .794 .529 .536 r
F
.6693 .47742 m .67048 .48231 L .6723 .47828 L .675 .735 .895 r
F
.67261 .47861 m .66582 .4842 L .67273 .48062 L .654 .726 .902 r
F
.67232 .46867 m .66976 .4684 L .67034 .46941 L .675 .735 .895 r
F
.67224 .47539 m .67527 .47986 L .67547 .47569 L F
.67411 .47424 m .6723 .47828 L .67554 .47858 L F
.67413 .47674 m .67258 .47814 L .67437 .47717 L .654 .726 .902 r
F
.67258 .47814 m .66582 .4842 L .67261 .47861 L F
.67258 .47814 m .67261 .47861 L .67437 .47717 L F
.6726 .46856 m .67034 .46941 L .67296 .46921 L .675 .735 .895 r
F
.67152 .46938 m .67058 .46807 L .6699 .46908 L F
.67256 .47095 m .67224 .47539 L .67405 .47137 L F
.67345 .47291 m .67134 .47314 L .67261 .47381 L F
.6733 .47263 m .67134 .47314 L .67345 .47291 L F
.6724 .47099 m .67267 .47408 L .67243 .47363 L .988 .719 .38 r
F
.6734 .47003 m .67129 .47028 L .67256 .47095 L .675 .735 .895 r
F
.67352 .46773 m .67429 .46969 L .67355 .46935 L .845 .571 .523 r
F
.67586 .46735 m .67296 .46921 L .6734 .47003 L .675 .735 .895 r
F
.67296 .46921 m .67129 .47028 L .6734 .47003 L F
.67237 .46814 m .67255 .47127 L .6724 .47099 L .988 .719 .38 r
F
.67235 .4665 m .67243 .46825 L .67237 .46814 L F
.67243 .46825 m .67255 .47127 L .67237 .46814 L F
.67256 .47095 m .66926 .47454 L .67224 .47539 L .675 .735 .895 r
F
.6732 .47195 m .67038 .47226 L .67134 .47314 L F
.67255 .47127 m .67267 .47408 L .6724 .47099 L .988 .719 .38 r
F
.67405 .47137 m .67224 .47539 L .67547 .47569 L .675 .735 .895 r
F
.67382 .47249 m .6733 .47263 L .67345 .47291 L F
.67488 .47607 m .67413 .47674 L .67437 .47717 L .654 .726 .902 r
F
.67286 .47164 m .67332 .47205 L .67333 .47467 L .93 .648 .486 r
F
.66667 .48266 m .65353 .48596 L .65989 .48951 L .654 .726 .902 r
F
.66926 .47454 m .66596 .47813 L .67043 .47941 L .675 .735 .895 r
F
.66599 .48103 m .66591 .47818 L .67041 .47947 L .794 .529 .536 r
F
.6693 .47742 m .66599 .48103 L .67048 .48231 L .675 .735 .895 r
F
.67399 .47527 m .66946 .47763 L .66667 .48266 L .654 .726 .902 r
F
.66573 .47727 m .66261 .48287 L .66782 .48456 L F
.66266 .48119 m .65353 .48596 L .66573 .4829 L F
.66224 .48186 m .66341 .4816 L .66606 .48388 L .862 .585 .518 r
F
.66341 .4816 m .66599 .48103 L .66604 .48307 L F
.66341 .4816 m .66604 .48307 L .66606 .48388 L F
.66676 .47608 m .66599 .48103 L .6693 .47742 L .675 .735 .895 r
F
.66946 .47763 m .66266 .48119 L .66667 .48266 L .654 .726 .902 r
F
.66266 .48119 m .66573 .4829 L .66667 .48266 L F
.67262 .47143 m .67038 .47226 L .6732 .47195 L .675 .735 .895 r
F
.67224 .46998 m .67226 .47274 L .67225 .47262 L .772 .616 .051 r
F
.67228 .46797 m .66976 .4684 L .67232 .46867 L .675 .735 .895 r
F
.67223 .46557 m .67225 .47006 L .67224 .46998 L .772 .616 .051 r
F
.67129 .47028 m .66926 .47454 L .67256 .47095 L .675 .735 .895 r
F
.67264 .47143 m .6698 .47125 L .67038 .47226 L F
.67413 .47513 m .67394 .47523 L .67399 .47527 L .654 .726 .902 r
F
.67394 .47523 m .65353 .48596 L .67399 .47527 L F
.66573 .47727 m .66038 .48215 L .66261 .48287 L F
.66926 .47454 m .67043 .47941 L .67224 .47539 L .675 .735 .895 r
F
.66341 .4816 m .66217 .47901 L .66599 .48103 L .862 .585 .518 r
F
.66224 .48186 m .66222 .48094 L .66341 .4816 L F
.66222 .48094 m .66217 .47901 L .66341 .4816 L F
.67261 .47381 m .6723 .47828 L .67411 .47424 L .675 .735 .895 r
F
.67261 .47381 m .6693 .47742 L .6723 .47828 L F
.67283 .47487 m .66224 .48095 L .67394 .47523 L .654 .726 .902 r
F
.66224 .48095 m .65353 .48596 L .66264 .48117 L F
.66217 .47901 m .66591 .47818 L .66599 .48103 L .862 .585 .518 r
F
.66676 .47608 m .66217 .47901 L .66599 .48103 L .675 .735 .895 r
F
.66224 .48095 m .66264 .48117 L .67394 .47523 L .654 .726 .902 r
F
.67375 .47505 m .67394 .47523 L .67413 .47513 L F
.67283 .47487 m .67394 .47523 L .67375 .47505 L F
.67279 .46717 m .6729 .47428 L .67265 .46704 L .93 .648 .486 r
F
.66667 .48266 m .66638 .48318 L .67488 .47607 L .654 .726 .902 r
F
.66638 .48318 m .66582 .4842 L .6668 .48332 L F
.66724 .48346 m .66599 .48103 L .67048 .48231 L .794 .529 .536 r
F
.66638 .48318 m .6668 .48332 L .67488 .47607 L .654 .726 .902 r
F
.66606 .48388 m .66604 .48307 L .66724 .48346 L .794 .529 .536 r
F
.66604 .48307 m .66599 .48103 L .66724 .48346 L F
.67349 .47578 m .67141 .47599 L .67269 .47666 L .675 .735 .895 r
F
.67586 .46735 m .67256 .47095 L .67405 .47137 L F
.67355 .46935 m .67429 .46969 L .6743 .47251 L .845 .571 .523 r
F
.67405 .47137 m .67547 .47569 L .67566 .47152 L .675 .735 .895 r
F
.67593 .4702 m .6732 .47195 L .67332 .47205 L F
.67386 .4723 m .67332 .47205 L .67374 .47242 L F
.67429 .46969 m .67446 .47253 L .6743 .47251 L .751 .491 .538 r
F
.67429 .46812 m .67435 .4697 L .67429 .46969 L F
.67435 .4697 m .67446 .47253 L .67429 .46969 L F
.67574 .46991 m .67405 .47137 L .67566 .47152 L .675 .735 .895 r
F
.67477 .46977 m .67405 .47137 L .67574 .46991 L F
.67541 .48561 m .6754 .48519 L .67608 .48517 L .665 .425 .546 r
F
.67541 .48561 m .67608 .48517 L .68032 .48521 L F
.67608 .48517 m .68031 .48503 L .68032 .48521 L F
.67777 .47652 m .67547 .49305 L .67663 .49301 L .654 .726 .902 r
F
.67561 .48143 m .67541 .48561 L .68032 .48521 L .675 .735 .895 r
F
.67584 .48396 m .67503 .48537 L .67572 .48663 L .654 .726 .902 r
F
.67547 .47569 m .67527 .47986 L .68015 .47946 L .675 .735 .895 r
F
.6767 .46834 m .67588 .48567 L .67782 .46825 L .654 .726 .902 r
F
.67573 .47439 m .67554 .47858 L .67881 .47831 L .675 .735 .895 r
F
.6763 .47555 m .67437 .47717 L .67608 .48028 L .654 .726 .902 r
F
.67746 .48406 m .67507 .50033 L .67662 .50028 L F
.67865 .48736 m .67662 .50028 L .68323 .50006 L F
.67746 .48406 m .67662 .50028 L .67865 .48736 L F
.67928 .46723 m .67931 .46719 L .67931 .46729 L .082 0 .419 r
F
.67931 .46719 m .67962 .46673 L .67931 .46729 L F
.67931 .46729 m .67962 .46673 L .67963 .46802 L F
.67928 .46723 m .67963 .46802 L .67935 .46844 L F
.67982 .46738 m .68185 .46847 L .68212 .46739 L .675 .735 .895 r
F
.6774 .45523 m .67848 .46789 L .67768 .46819 L .517 .303 .528 r
F
.67684 .46552 m .67869 .46781 L .67957 .46748 L .654 .726 .902 r
F
.67842 .45479 m .67863 .46778 L .67848 .46789 L .359 .181 .499 r
F
.67581 .45544 m .67745 .46828 L .67621 .46839 L .641 .401 .54 r
F
.67684 .46552 m .6767 .46834 L .67782 .46825 L .654 .726 .902 r
F
.67586 .46735 m .68016 .46815 L .67982 .46738 L .675 .735 .895 r
F
.68016 .46815 m .68185 .46847 L .67982 .46738 L F
.67842 .45479 m .67914 .45422 L .67919 .46737 L .359 .181 .499 r
F
.67842 .45479 m .67919 .46737 L .67863 .46778 L F
.67957 .45354 m .67975 .46596 L .67965 .46656 L 0 0 .152 r
F
.67957 .45354 m .67965 .46656 L .67962 .46673 L F
.67914 .45422 m .67928 .46723 L .67919 .46737 L .082 0 .419 r
F
.67962 .46519 m .70812 .46716 L .7073 .46188 L .654 .726 .902 r
F
.67684 .46552 m .68028 .4657 L .67962 .46519 L F
.68028 .4657 m .70812 .46716 L .67962 .46519 L F
.67925 .45167 m .6782 .45085 L .67825 .46411 L .91 .629 .497 r
F
.67858 .47204 m .67864 .47238 L .67878 .47217 L .675 .735 .895 r
F
.67864 .46817 m .684 .4854 L .67896 .46814 L .654 .726 .902 r
F
.67822 .46879 m .684 .4854 L .67864 .46817 L F
.67729 .47139 m .67872 .47543 L .68178 .47461 L .675 .735 .895 r
F
.67864 .47238 m .67891 .47385 L .67878 .47217 L F
.67773 .47241 m .67891 .47385 L .67858 .47204 L F
.67817 .47222 m .67849 .47208 L .6785 .47494 L .517 .303 .528 r
F
.67856 .46923 m .67876 .46937 L .67896 .46906 L .675 .735 .895 r
F
.67856 .46923 m .67896 .46906 L .67919 .4687 L F
.67863 .46778 m .67919 .4687 L .67866 .46913 L .359 .181 .499 r
F
.67896 .46814 m .67925 .46913 L .67933 .4686 L .654 .726 .902 r
F
.67909 .46877 m .67919 .4687 L .6792 .46868 L .675 .735 .895 r
F
.67856 .46923 m .67919 .4687 L .67909 .46877 L F
.67863 .46778 m .67919 .46737 L .67919 .4687 L .359 .181 .499 r
F
.67872 .47543 m .68015 .47946 L .68474 .47824 L .675 .735 .895 r
F
.67737 .47426 m .67881 .47831 L .68188 .47749 L F
.67898 .47669 m .68462 .47902 L .68031 .47604 L F
.67854 .4754 m .68343 .48144 L .67904 .47467 L .654 .726 .902 r
F
.68025 .48237 m .68478 .47829 L .68486 .48114 L .592 .367 .544 r
F
.68343 .48144 m .69131 .49116 L .68254 .47937 L .654 .726 .902 r
F
.67881 .47831 m .68486 .48114 L .68188 .47749 L .675 .735 .895 r
F
.67737 .47426 m .68188 .47749 L .67891 .47385 L F
.68025 .48237 m .68017 .47952 L .68478 .47829 L .592 .367 .544 r
F
.67898 .47669 m .68195 .48034 L .68462 .47902 L .675 .735 .895 r
F
.68343 .48144 m .68254 .47937 L .67904 .47467 L .654 .726 .902 r
F
.67904 .47467 m .68254 .47937 L .68116 .4762 L F
.67872 .47543 m .68474 .47824 L .68178 .47461 L .675 .735 .895 r
F
.67891 .47385 m .68188 .47749 L .68455 .47618 L F
.67921 .47432 m .68031 .47604 L .68135 .47517 L F
.6766 .47059 m .67553 .47229 L .67644 .47394 L .654 .726 .902 r
F
.67772 .46951 m .67588 .48567 L .67808 .46898 L F
.6778 .46839 m .67588 .48567 L .67785 .46835 L F
.67566 .47152 m .67547 .47569 L .67872 .47543 L .675 .735 .895 r
F
.676 .47305 m .67898 .47669 L .68031 .47604 L F
.67783 .47519 m .6785 .47494 L .67783 .47519 L .517 .303 .528 r
F
.67566 .47152 m .67872 .47543 L .67729 .47139 L .675 .735 .895 r
F
.67773 .47241 m .67737 .47426 L .67891 .47385 L F
.67669 .46858 m .67638 .46915 L .67666 .46929 L .654 .726 .902 r
F
.67775 .46967 m .67729 .47139 L .67882 .47098 L .675 .735 .895 r
F
.67621 .46839 m .67745 .46828 L .67745 .46971 L .641 .401 .54 r
F
.67621 .46839 m .67745 .46971 L .67665 .46982 L F
.67586 .46735 m .67673 .46981 L .67775 .46967 L .675 .735 .895 r
F
.67673 .46981 m .67729 .47139 L .67775 .46967 L F
.67665 .46982 m .67745 .46971 L .67746 .47253 L .641 .401 .54 r
F
.67679 .47262 m .67685 .47279 L .67746 .47253 L .675 .735 .895 r
F
.67685 .47279 m .67737 .47426 L .67773 .47241 L F
.67687 .48243 m .67658 .48535 L .67746 .48406 L .654 .726 .902 r
F
.67547 .47569 m .68015 .47946 L .67872 .47543 L .675 .735 .895 r
F
.67573 .47439 m .67881 .47831 L .67737 .47426 L F
.67736 .47537 m .67714 .47745 L .67777 .47652 L .654 .726 .902 r
F
.67554 .47858 m .67534 .48277 L .68025 .48237 L .675 .735 .895 r
F
.67714 .47745 m .67547 .49305 L .67777 .47652 L .654 .726 .902 r
F
.67735 .47534 m .67629 .47577 L .67736 .47537 L F
.67634 .47268 m .67748 .47533 L .67643 .47542 L .641 .401 .54 r
F
.6768 .47382 m .67631 .47543 L .67735 .47534 L .654 .726 .902 r
F
.67679 .47262 m .67573 .47439 L .67737 .47426 L .675 .735 .895 r
F
.67586 .46993 m .67602 .47273 L .67587 .47275 L .641 .401 .54 r
F
.67586 .46842 m .67592 .46993 L .67586 .46993 L F
.67666 .46929 m .67614 .47018 L .6766 .47059 L .654 .726 .902 r
F
.67574 .46995 m .67566 .47152 L .67673 .46981 L .675 .735 .895 r
F
.67592 .46993 m .67602 .47273 L .67586 .46993 L .641 .401 .54 r
F
.67673 .46981 m .67566 .47152 L .67729 .47139 L .675 .735 .895 r
F
.67581 .47276 m .67573 .47439 L .67679 .47262 L F
.67629 .47577 m .67547 .49305 L .67736 .47537 L .654 .726 .902 r
F
.67591 .48252 m .67507 .50033 L .67687 .48243 L F
.67631 .47543 m .67588 .47547 L .6763 .47555 L F
.67643 .47542 m .67625 .47543 L .67586 .46842 L .641 .401 .54 r
F
.67418 .47709 m .67561 .48143 L .67581 .47724 L .675 .735 .895 r
F
.67485 .47527 m .67591 .48252 L .67507 .48235 L .751 .491 .538 r
F
.67581 .47274 m .67411 .47424 L .67573 .47439 L .675 .735 .895 r
F
.67464 .46818 m .67586 .46842 L .67588 .47547 L .751 .491 .538 r
F
.67593 .4702 m .67485 .47259 L .67581 .47274 L .675 .735 .895 r
F
.67485 .47259 m .67411 .47424 L .67581 .47274 L F
.67411 .47424 m .67554 .47858 L .67573 .47439 L F
.67477 .47258 m .67527 .47535 L .67485 .47527 L .751 .491 .538 r
F
.67464 .46818 m .67503 .47262 L .67477 .47258 L F
.67503 .47262 m .67527 .47535 L .67477 .47258 L F
.67523 .47534 m .67437 .47717 L .6763 .47555 L .654 .726 .902 r
F
.67527 .47535 m .67591 .48252 L .67485 .47527 L .751 .491 .538 r
F
.67464 .47523 m .67399 .47527 L .67436 .4756 L .654 .726 .902 r
F
.67643 .4728 m .67413 .47513 L .67464 .47523 L F
.6743 .47251 m .67442 .47518 L .67431 .47516 L .751 .491 .538 r
F
.67431 .47516 m .67447 .47524 L .67464 .47523 L .654 .726 .902 r
F
.67572 .48663 m .66697 .49921 L .67507 .50033 L F
.67503 .48537 m .66697 .49921 L .67572 .48663 L F
.67237 .48112 m .67055 .48516 L .67541 .48561 L .675 .735 .895 r
F
.67469 .48292 m .67272 .48707 L .67584 .48396 L .654 .726 .902 r
F
.67272 .48707 m .66697 .49921 L .67284 .48912 L F
.67272 .48707 m .67284 .48912 L .67584 .48396 L F
.67399 .47527 m .67356 .4757 L .67488 .47607 L F
.67356 .4757 m .66667 .48266 L .67411 .47669 L F
.67356 .4757 m .67411 .47669 L .67488 .47607 L F
.67494 .47542 m .67269 .47666 L .67418 .47709 L .675 .735 .895 r
F
.67413 .47513 m .67399 .47527 L .67447 .47524 L .654 .726 .902 r
F
.67413 .47513 m .67447 .47524 L .67431 .47516 L F
.676 .47305 m .67396 .47527 L .67494 .47542 L .675 .735 .895 r
F
.67396 .47527 m .67269 .47666 L .67494 .47542 L F
.66217 .47901 m .6621 .47617 L .66591 .47818 L .862 .585 .518 r
F
.6596 .47851 m .64873 .4815 L .66224 .48096 L .654 .726 .902 r
F
.65936 .47924 m .66031 .47916 L .66224 .48186 L .934 .65 .478 r
F
.66031 .47916 m .66217 .47901 L .66222 .48094 L F
.66031 .47916 m .66222 .48094 L .66224 .48186 L F
.66224 .48096 m .64873 .4815 L .65353 .48596 L .654 .726 .902 r
F
.67283 .47487 m .6596 .47851 L .66224 .48096 L F
.67325 .47463 m .67098 .47452 L .67283 .47487 L F
.67269 .47666 m .66937 .48027 L .67237 .48112 L .675 .735 .895 r
F
.67225 .47262 m .67229 .47981 L .67228 .47967 L .772 .616 .051 r
F
.67479 .47273 m .67261 .47381 L .67411 .47424 L .675 .735 .895 r
F
.67593 .4702 m .67396 .47235 L .67479 .47273 L F
.67396 .47235 m .67261 .47381 L .67479 .47273 L F
.67361 .47219 m .67429 .47515 L .67367 .47484 L .845 .571 .523 r
F
.67355 .46935 m .67393 .47234 L .67361 .47219 L F
.67387 .47244 m .67374 .47242 L .67382 .47249 L .675 .735 .895 r
F
.67393 .47234 m .67429 .47515 L .67361 .47219 L .845 .571 .523 r
F
.67446 .47253 m .67456 .47521 L .6743 .47251 L .751 .491 .538 r
F
.67464 .46818 m .67588 .47547 L .67527 .47535 L F
.66673 .4732 m .66596 .47813 L .66926 .47454 L .675 .735 .895 r
F
.66673 .4732 m .66217 .47612 L .66596 .47813 L F
.65929 .47639 m .6621 .47617 L .66217 .47901 L .934 .65 .478 r
F
.65929 .47639 m .65922 .47355 L .6621 .47617 L F
.66484 .47433 m .66217 .47901 L .66676 .47608 L .675 .735 .895 r
F
.66484 .47433 m .65929 .47639 L .66217 .47901 L F
.65769 .47541 m .64582 .47646 L .65929 .47819 L .654 .726 .902 r
F
.65762 .4762 m .65819 .47626 L .65936 .47924 L .986 .71 .376 r
F
.65819 .47626 m .65929 .47639 L .65934 .47826 L F
.65819 .47626 m .65934 .47826 L .65936 .47924 L F
.65929 .47819 m .64582 .47646 L .64873 .4815 L .654 .726 .902 r
F
.67222 .47412 m .65769 .47541 L .65929 .47819 L F
.67393 .47234 m .6743 .47251 L .67431 .47516 L .845 .571 .523 r
F
.67286 .47164 m .67333 .47467 L .6729 .47428 L .93 .648 .486 r
F
.67643 .4728 m .67089 .47346 L .67222 .47412 L .654 .726 .902 r
F
.66482 .47146 m .6593 .47351 L .66217 .47612 L .675 .735 .895 r
F
.65819 .47626 m .65755 .47335 L .65929 .47639 L .986 .71 .376 r
F
.65762 .4762 m .65759 .47523 L .65819 .47626 L F
.65759 .47523 m .65755 .47335 L .65819 .47626 L F
.67129 .47028 m .66673 .4732 L .66926 .47454 L .675 .735 .895 r
F
.67038 .47226 m .66676 .47608 L .67134 .47314 L F
.67038 .47226 m .66484 .47433 L .66676 .47608 L F
.67089 .47346 m .65749 .47506 L .67222 .47412 L .654 .726 .902 r
F
.65749 .47506 m .64582 .47646 L .65769 .47541 L F
.66367 .4723 m .65929 .47639 L .66484 .47433 L .675 .735 .895 r
F
.65749 .47506 m .65769 .47541 L .67222 .47412 L .654 .726 .902 r
F
.67429 .47515 m .67431 .47516 L .67432 .47532 L .845 .571 .523 r
F
.67393 .47234 m .67431 .47516 L .67429 .47515 L F
.67134 .47314 m .6693 .47742 L .67261 .47381 L .675 .735 .895 r
F
.67243 .47363 m .67267 .47429 L .67243 .47385 L .988 .719 .38 r
F
.67332 .47205 m .67134 .47314 L .67382 .47249 L .675 .735 .895 r
F
.6732 .47195 m .67316 .47198 L .67332 .47205 L F
.67316 .47198 m .67134 .47314 L .67332 .47205 L F
.67332 .47205 m .67348 .47475 L .67333 .47467 L .845 .571 .523 r
F
.6733 .46763 m .67342 .47209 L .67332 .47205 L F
.67342 .47209 m .67348 .47475 L .67332 .47205 L F
.67243 .47363 m .67236 .47351 L .67233 .47085 L .988 .719 .38 r
F
.67243 .47363 m .6725 .48077 L .67236 .47351 L F
.67237 .48112 m .67541 .48561 L .67561 .48143 L .675 .735 .895 r
F
.67483 .48246 m .67451 .48276 L .67489 .48248 L .654 .726 .902 r
F
.67643 .4728 m .67222 .47412 L .67325 .47463 L F
.67303 .47495 m .67141 .47599 L .67349 .47578 L .675 .735 .895 r
F
.676 .47305 m .67045 .47511 L .67141 .47599 L F
.67243 .47385 m .67267 .47429 L .6727 .48113 L .988 .719 .38 r
F
.67255 .47127 m .67266 .47147 L .67267 .47408 L F
.67261 .47198 m .67257 .47915 L .67271 .4718 L 0 0 .382 r
F
.6663 .49043 m .66625 .4905 L .67257 .48464 L .654 .726 .902 r
F
.67257 .48463 m .67257 .48464 L .67455 .4828 L F
.6663 .49043 m .67257 .48464 L .67257 .48463 L F
.67226 .47274 m .67229 .47991 L .67225 .47262 L .772 .616 .051 r
F
.67272 .48707 m .66625 .4905 L .66697 .49921 L .654 .726 .902 r
F
.67422 .4839 m .67261 .48524 L .67272 .48707 L F
.67261 .48524 m .66625 .4905 L .67272 .48707 L F
.67227 .47289 m .6723 .4734 L .67232 .48045 L .772 .616 .051 r
F
.67227 .47289 m .6723 .48003 L .67226 .47274 L F
.66582 .4842 m .66241 .49033 L .66737 .49193 L .654 .726 .902 r
F
.6729 .47428 m .67277 .47417 L .67265 .46704 L .93 .648 .486 r
F
.67266 .47147 m .67277 .47417 L .67267 .47408 L F
.67273 .47153 m .67277 .47417 L .67266 .47147 L F
.67277 .47417 m .6729 .48131 L .67267 .47408 L F
.66582 .4842 m .65989 .48951 L .66241 .49033 L .654 .726 .902 r
F
.67326 .48167 m .67306 .48179 L .67406 .48207 L F
.67306 .48179 m .65312 .49324 L .67341 .48242 L F
.67306 .48179 m .67341 .48242 L .67406 .48207 L F
.66667 .48266 m .65989 .48951 L .66582 .4842 L F
.66937 .48027 m .66606 .48388 L .67055 .48516 L .675 .735 .895 r
F
.67283 .48192 m .64832 .48878 L .65312 .49324 L .654 .726 .902 r
F
.67269 .47666 m .67237 .48112 L .67418 .47709 L .675 .735 .895 r
F
.6729 .47428 m .67333 .47467 L .67336 .48172 L .93 .648 .486 r
F
.6726 .4541 m .67279 .46717 L .67265 .46704 L F
.67222 .4534 m .67265 .46704 L .67235 .4665 L .988 .719 .38 r
F
.6726 .4541 m .6733 .46763 L .67279 .46717 L .93 .648 .486 r
F
.67424 .45518 m .67586 .46842 L .67464 .46818 L .751 .491 .538 r
F
.66587 .46897 m .64638 .46916 L .64928 .47418 L .654 .726 .902 r
F
.67684 .46552 m .67003 .46634 L .66587 .46897 L F
.67003 .46634 m .64638 .46916 L .66587 .46897 L F
.67643 .4728 m .67139 .47254 L .67089 .47346 L F
.67139 .47254 m .66874 .4724 L .67035 .4732 L F
.67139 .47254 m .67035 .4732 L .67089 .47346 L F
.67381 .48195 m .67446 .51383 L .67366 .48187 L .845 .571 .523 r
F
.67418 .47709 m .67237 .48112 L .67561 .48143 L .675 .735 .895 r
F
.67367 .47502 m .67434 .48221 L .67381 .48195 L .845 .571 .523 r
F
.67603 .48008 m .67237 .48123 L .67326 .48167 L .654 .726 .902 r
F
.67406 .48207 m .67386 .48218 L .67391 .48222 L F
.67399 .48214 m .67352 .48262 L .67483 .48246 L F
.67352 .48262 m .66695 .48925 L .67388 .48328 L F
.67352 .48262 m .67388 .48328 L .67483 .48246 L F
.67236 .47351 m .67244 .48066 L .6723 .4734 L .988 .719 .38 r
F
.67326 .48167 m .6712 .4816 L .67283 .48192 L .654 .726 .902 r
F
.66937 .48027 m .67055 .48516 L .67237 .48112 L .675 .735 .895 r
F
.6712 .4816 m .64832 .48878 L .67283 .48192 L .654 .726 .902 r
F
.67386 .48218 m .66963 .48444 L .67391 .48222 L F
.66531 .48345 m .64541 .48374 L .64832 .48878 L F
.67442 .47518 m .67471 .48228 L .67431 .47516 L .751 .491 .538 r
F
.67434 .48221 m .67483 .48246 L .67496 .48233 L .654 .726 .902 r
F
.67451 .48276 m .67455 .4828 L .67489 .48248 L F
.67471 .48228 m .67603 .51409 L .67463 .48227 L .751 .491 .538 r
F
.67471 .48228 m .67463 .48227 L .67431 .47516 L F
.67496 .48233 m .67483 .48246 L .67489 .48248 L .654 .726 .902 r
F
.67514 .47553 m .67436 .4756 L .67488 .47607 L F
.67507 .48235 m .67483 .48231 L .67429 .46812 L .751 .491 .538 r
F
.67272 .45155 m .67223 .46557 L .67264 .46482 L 0 0 .382 r
F
.66914 .46512 m .64687 .45872 L .64556 .46389 L .654 .726 .902 r
F
.67684 .46552 m .6719 .4644 L .66914 .46512 L F
.6719 .4644 m .64687 .45872 L .66914 .46512 L F
.67495 .45043 m .67384 .45077 L .67389 .46389 L .568 .343 .534 r
F
.67586 .46735 m .67344 .46568 L .67278 .46613 L .675 .735 .895 r
F
.65705 .47009 m .65747 .4705 L .65755 .47335 L .846 .649 .108 r
F
.66366 .46944 m .6593 .47351 L .66482 .47146 L .675 .735 .895 r
F
.66334 .47013 m .65755 .47335 L .66367 .4723 L F
.66835 .47238 m .6454 .46955 L .65687 .47178 L .654 .726 .902 r
F
.67308 .46913 m .67285 .46902 L .67296 .46921 L .675 .735 .895 r
F
.65969 .46757 m .64556 .46389 L .64638 .46916 L .654 .726 .902 r
F
.67684 .46552 m .66914 .46512 L .65969 .46757 L F
.66914 .46512 m .64556 .46389 L .65969 .46757 L F
.67485 .47527 m .67507 .48235 L .67468 .47523 L .751 .491 .538 r
F
.67643 .4728 m .67175 .47231 L .67139 .47254 L .654 .726 .902 r
F
.6729 .47428 m .673 .4814 L .67277 .47417 L .93 .648 .486 r
F
.67222 .47412 m .67098 .47452 L .67325 .47463 L .654 .726 .902 r
F
.67243 .47363 m .67267 .47408 L .67267 .47429 L .988 .719 .38 r
F
.676 .47305 m .66987 .4741 L .67045 .47511 L .675 .735 .895 r
F
.67353 .47118 m .67279 .47165 L .67282 .4787 L .402 .214 .508 r
F
.6729 .48131 m .67347 .51335 L .67282 .48124 L .93 .648 .486 r
F
.67256 .48443 m .67257 .48457 L .67451 .48276 L .654 .726 .902 r
F
.6727 .48113 m .67347 .51335 L .67282 .51275 L .93 .648 .486 r
F
.67282 .48124 m .67347 .51335 L .6727 .48113 L F
.67451 .48276 m .6663 .49043 L .67455 .4828 L .654 .726 .902 r
F
.6729 .47428 m .67336 .48172 L .673 .4814 L .93 .648 .486 r
F
.673 .4814 m .67347 .51335 L .6729 .48131 L F
.673 .4814 m .6729 .48131 L .67277 .47417 L F
.66482 .47146 m .66217 .47612 L .66673 .4732 L .675 .735 .895 r
F
.65755 .47335 m .65922 .47355 L .65929 .47639 L .986 .71 .376 r
F
.65755 .47335 m .65747 .4705 L .65922 .47355 L F
.66367 .4723 m .65755 .47335 L .65929 .47639 L .675 .735 .895 r
F
.65756 .47505 m .64499 .47116 L .64582 .47646 L .654 .726 .902 r
F
.65726 .47307 m .65755 .47335 L .65759 .47523 L .846 .649 .108 r
F
.67089 .47346 m .65713 .47224 L .65756 .47505 L .654 .726 .902 r
F
.65713 .47224 m .64499 .47116 L .65756 .47505 L F
.65712 .47294 m .65726 .47307 L .65762 .4762 L .846 .649 .108 r
F
.65726 .47307 m .65759 .47523 L .65762 .4762 L F
.67134 .47314 m .66676 .47608 L .6693 .47742 L .675 .735 .895 r
F
.67098 .47452 m .65926 .4782 L .67283 .47487 L .654 .726 .902 r
F
.65926 .4782 m .64873 .4815 L .6596 .47851 L F
.66031 .47916 m .65929 .47639 L .66217 .47901 L .934 .65 .478 r
F
.65926 .4782 m .6596 .47851 L .67283 .47487 L .654 .726 .902 r
F
.65936 .47924 m .65934 .47826 L .66031 .47916 L .934 .65 .478 r
F
.65934 .47826 m .65929 .47639 L .66031 .47916 L F
.66491 .47718 m .66224 .48186 L .66683 .47892 L .675 .735 .895 r
F
.66755 .47964 m .6459 .47325 L .64458 .47844 L .654 .726 .902 r
F
.67367 .47484 m .67356 .47479 L .6733 .46763 L .845 .571 .523 r
F
.67643 .4728 m .67241 .47189 L .67175 .47231 L .654 .726 .902 r
F
.67403 .47519 m .67303 .47495 L .67349 .47578 L .675 .735 .895 r
F
.67353 .47118 m .67342 .47832 L .67374 .47105 L .402 .214 .508 r
F
.67366 .48187 m .67354 .48181 L .67333 .47467 L .845 .571 .523 r
F
.673 .4814 m .67336 .48172 L .67347 .51335 L .93 .648 .486 r
F
.67333 .47467 m .67354 .48181 L .67336 .48172 L .845 .571 .523 r
F
.65687 .47178 m .6454 .46955 L .64499 .47116 L .654 .726 .902 r
F
.6698 .47125 m .66484 .47433 L .67038 .47226 L .675 .735 .895 r
F
.67034 .46941 m .66482 .47146 L .66673 .4732 L F
.6698 .47125 m .66367 .4723 L .66484 .47433 L F
.66874 .4724 m .65706 .47179 L .67089 .47346 L .654 .726 .902 r
F
.65706 .47179 m .64499 .47116 L .65713 .47224 L F
.65726 .47307 m .65705 .47009 L .65755 .47335 L .846 .649 .108 r
F
.65706 .47179 m .65713 .47224 L .67089 .47346 L .654 .726 .902 r
F
.65712 .47294 m .6571 .47205 L .65726 .47307 L .846 .649 .108 r
F
.6571 .47205 m .65705 .47009 L .65726 .47307 L F
.67141 .47599 m .66683 .47892 L .66937 .48027 L .675 .735 .895 r
F
.66342 .47298 m .65762 .4762 L .66374 .47515 L F
.66342 .47298 m .65712 .47294 L .65762 .4762 L F
.6706 .47885 m .64927 .46853 L .6459 .47325 L .654 .726 .902 r
F
.6729 .48131 m .67282 .48124 L .67267 .47408 L .93 .648 .486 r
F
.67267 .47408 m .67282 .48124 L .6727 .48113 L F
.67603 .48008 m .67221 .47843 L .6706 .47885 L .654 .726 .902 r
F
.67045 .47511 m .66491 .47718 L .66683 .47892 L .675 .735 .895 r
F
.66987 .4741 m .66374 .47515 L .66491 .47718 L F
.67221 .47843 m .64927 .46853 L .6706 .47885 L .654 .726 .902 r
F
.67417 .47509 m .67283 .47487 L .67413 .47513 L F
.67456 .47521 m .67455 .47521 L .6743 .47251 L .751 .491 .538 r
F
.67456 .47536 m .67446 .47534 L .6743 .47251 L F
.67643 .4728 m .67325 .47463 L .67417 .47509 L .654 .726 .902 r
F
.67325 .47463 m .67283 .47487 L .67417 .47509 L F
.67429 .47515 m .67432 .47532 L .67367 .47484 L .845 .571 .523 r
F
.67593 .4702 m .67332 .47205 L .67386 .4723 L .675 .735 .895 r
F
.67355 .46935 m .6743 .47251 L .67393 .47234 L .845 .571 .523 r
F
.67485 .47527 m .67468 .47523 L .67429 .46812 L .751 .491 .538 r
F
.67593 .4702 m .67374 .47242 L .67387 .47244 L .675 .735 .895 r
F
.676 .47305 m .66971 .47301 L .66987 .4741 L F
.67464 .47075 m .67392 .47094 L .67394 .47799 L .568 .343 .534 r
F
.67431 .47516 m .67463 .48227 L .67434 .48221 L .751 .491 .538 r
F
.67603 .48008 m .67326 .48167 L .67406 .48207 L .654 .726 .902 r
F
.67381 .48195 m .67434 .48221 L .67446 .51383 L .845 .571 .523 r
F
.67399 .48214 m .67483 .48246 L .67434 .48221 L .654 .726 .902 r
F
.67489 .48248 m .67393 .48338 L .67422 .4839 L F
.66366 .46944 m .65757 .47049 L .6593 .47351 L .675 .735 .895 r
F
.66334 .47013 m .65705 .47009 L .65755 .47335 L F
.66976 .4684 m .66366 .46944 L .66482 .47146 L F
.66964 .47016 m .66334 .47013 L .66367 .4723 L F
.66951 .47208 m .65742 .47081 L .66835 .47238 L .654 .726 .902 r
F
.65742 .47081 m .6454 .46955 L .65736 .47103 L F
.65742 .47081 m .65736 .47103 L .66835 .47238 L F
.65768 .4698 m .65705 .47009 L .6571 .47205 L 0 0 .263 r
F
.65705 .47009 m .65698 .46725 L .65747 .4705 L .846 .649 .108 r
F
.65742 .47081 m .64631 .46597 L .6454 .46955 L .654 .726 .902 r
F
.67175 .47231 m .65792 .46886 L .65742 .47081 L F
.66334 .46728 m .65707 .46725 L .65757 .47049 L .675 .735 .895 r
F
.66387 .46796 m .65785 .46684 L .65705 .47009 L F
.65768 .4698 m .65785 .46684 L .65705 .47009 L 0 0 .263 r
F
.65792 .46886 m .64631 .46597 L .65742 .47081 L .654 .726 .902 r
F
.65792 .46969 m .6579 .46894 L .65768 .4698 L 0 0 .263 r
F
.6579 .46894 m .65785 .46684 L .65768 .4698 L F
.65792 .46969 m .65768 .4698 L .65712 .47294 L F
.65768 .4698 m .6571 .47205 L .65712 .47294 L F
.67034 .46941 m .66673 .4732 L .67129 .47028 L .675 .735 .895 r
F
.66964 .47016 m .66367 .4723 L .6698 .47125 L F
.6696 .46732 m .66366 .46944 L .66976 .4684 L F
.6699 .46908 m .66387 .46796 L .66334 .47013 L F
.67241 .47189 m .64631 .46597 L .67175 .47231 L .654 .726 .902 r
F
.67244 .48066 m .67239 .48058 L .6723 .4734 L .988 .719 .38 r
F
.67243 .47363 m .6727 .48113 L .6725 .48077 L F
.67141 .47599 m .66937 .48027 L .67269 .47666 L .675 .735 .895 r
F
.67045 .47511 m .66683 .47892 L .67141 .47599 L F
.66987 .4741 m .66491 .47718 L .67045 .47511 L F
.65785 .46684 m .65698 .46725 L .65705 .47009 L 0 0 .263 r
F
.66971 .47301 m .66342 .47298 L .66374 .47515 L .675 .735 .895 r
F
.66334 .46728 m .65757 .47049 L .66366 .46944 L F
.66386 .46513 m .65786 .46401 L .65707 .46725 L F
.65785 .46684 m .65777 .46399 L .65698 .46725 L 0 0 .263 r
F
.66387 .46796 m .65705 .47009 L .66334 .47013 L .675 .735 .895 r
F
.67125 .47163 m .65989 .46616 L .65811 .46865 L .654 .726 .902 r
F
.65994 .46667 m .6595 .4667 L .65792 .46969 L .122 .013 .446 r
F
.6595 .4667 m .65785 .46684 L .6579 .46894 L F
.6595 .4667 m .6579 .46894 L .65792 .46969 L F
.65811 .46865 m .64968 .46124 L .64631 .46597 L .654 .726 .902 r
F
.65989 .46616 m .64968 .46124 L .65811 .46865 L F
.67243 .47363 m .67233 .47085 L .67237 .47093 L .988 .719 .38 r
F
.67643 .4728 m .67279 .47123 L .67125 .47163 L .654 .726 .902 r
F
.67231 .47082 m .6698 .47125 L .67264 .47143 L .675 .735 .895 r
F
.67229 .47082 m .66964 .47016 L .6698 .47125 L F
.67227 .46635 m .67236 .47351 L .6723 .4734 L .988 .719 .38 r
F
.66976 .4684 m .66482 .47146 L .67034 .46941 L .675 .735 .895 r
F
.6696 .46732 m .66334 .46728 L .66366 .46944 L F
.66386 .46513 m .65707 .46725 L .66334 .46728 L F
.6699 .46908 m .66334 .47013 L .66964 .47016 L F
.67058 .46807 m .66387 .46796 L .6699 .46908 L F
.66522 .46595 m .65785 .46684 L .66387 .46796 L F
.66522 .46595 m .65987 .46382 L .65785 .46684 L F
.6595 .4667 m .65987 .46382 L .65785 .46684 L .122 .013 .446 r
F
.65994 .46667 m .65993 .4661 L .6595 .4667 L F
.65993 .4661 m .65987 .46382 L .6595 .4667 L F
.67279 .47123 m .66017 .46577 L .67125 .47163 L .654 .726 .902 r
F
.66017 .46577 m .64968 .46124 L .65989 .46616 L F
.66017 .46577 m .65989 .46616 L .67125 .47163 L F
.65351 .46023 m .65022 .45402 L .64687 .45872 L F
.67424 .45518 m .67581 .45544 L .67586 .46842 L .751 .491 .538 r
F
.67604 .45034 m .67495 .45043 L .675 .4636 L .66 .416 .54 r
F
.67586 .46735 m .67502 .465 L .67416 .46527 L .675 .735 .895 r
F
.67384 .45077 m .67276 .4646 L .67364 .46405 L .402 .214 .508 r
F
.67272 .45155 m .67264 .46482 L .67276 .4646 L 0 0 .382 r
F
.67421 .46364 m .66202 .44723 L .65539 .4501 L .654 .726 .902 r
F
.67684 .46552 m .67527 .46359 L .67421 .46364 L F
.67527 .46359 m .66202 .44723 L .67421 .46364 L F
.67621 .46839 m .67643 .47542 L .67586 .46842 L .641 .401 .54 r
F
.67586 .46735 m .67574 .46995 L .67673 .46981 L .675 .735 .895 r
F
.67587 .47275 m .67613 .47545 L .67588 .47547 L .641 .401 .54 r
F
.67602 .47273 m .67613 .47545 L .67587 .47275 L F
.67658 .48535 m .67507 .50033 L .67746 .48406 L .654 .726 .902 r
F
.67581 .47724 m .67561 .48143 L .67888 .48116 L .675 .735 .895 r
F
.67588 .47547 m .6762 .48249 L .67591 .48252 L .641 .401 .54 r
F
.67591 .48252 m .67469 .48292 L .67584 .48396 L .654 .726 .902 r
F
.67496 .48233 m .67469 .48292 L .67591 .48252 L F
.67507 .48235 m .67591 .48252 L .67603 .51409 L .751 .491 .538 r
F
.67684 .46552 m .65539 .4501 L .65022 .45402 L .654 .726 .902 r
F
.67495 .45043 m .67389 .46389 L .67475 .46367 L .568 .343 .534 r
F
.67384 .45077 m .67364 .46405 L .67389 .46389 L .402 .214 .508 r
F
.67581 .45544 m .67621 .46839 L .67586 .46842 L .641 .401 .54 r
F
.67684 .46552 m .66966 .44561 L .66202 .44723 L .654 .726 .902 r
F
.66986 .46624 m .66386 .46513 L .66334 .46728 L .675 .735 .895 r
F
.66521 .46312 m .65786 .46401 L .66386 .46513 L F
.66521 .46312 m .65988 .461 L .65786 .46401 L F
.65987 .46382 m .65777 .46399 L .65785 .46684 L .122 .013 .446 r
F
.65987 .46382 m .6598 .46097 L .65777 .46399 L F
.66986 .46624 m .66334 .46728 L .6696 .46732 L .675 .735 .895 r
F
.67058 .46807 m .66522 .46595 L .66387 .46796 L F
.67177 .47079 m .663 .46379 L .66029 .46583 L .654 .726 .902 r
F
.66306 .46408 m .66265 .46405 L .65994 .46667 L .359 .189 .51 r
F
.66265 .46405 m .65987 .46382 L .65993 .4661 L F
.66265 .46405 m .65993 .4661 L .65994 .46667 L F
.66029 .46583 m .65487 .45731 L .64968 .46124 L .654 .726 .902 r
F
.66943 .46384 m .67031 .4627 L .65351 .46023 L F
.66731 .46422 m .66299 .46123 L .65987 .46382 L .675 .735 .895 r
F
.66306 .46408 m .66299 .46123 L .65987 .46382 L .359 .189 .51 r
F
.663 .46379 m .65487 .45731 L .66029 .46583 L .654 .726 .902 r
F
.67464 .46818 m .67485 .47527 L .67429 .46812 L .751 .491 .538 r
F
.67593 .4702 m .67231 .47082 L .67264 .47143 L .675 .735 .895 r
F
.67225 .47006 m .67226 .47274 L .67224 .46998 L .772 .616 .051 r
F
.67593 .4702 m .67262 .47143 L .6732 .47195 L .675 .735 .895 r
F
.67265 .46704 m .67273 .47153 L .67266 .47147 L .93 .648 .486 r
F
.67261 .47198 m .67271 .4718 L .67273 .46905 L 0 0 .382 r
F
.67643 .4728 m .67353 .47071 L .67177 .47079 L .654 .726 .902 r
F
.67225 .47018 m .66964 .47016 L .67229 .47082 L .675 .735 .895 r
F
.67224 .46574 m .6723 .4734 L .67227 .47289 L .772 .616 .051 r
F
.67237 .46814 m .6724 .47099 L .67231 .46803 L .988 .719 .38 r
F
.6724 .47099 m .67243 .47363 L .67237 .47093 L F
.6724 .47099 m .67237 .47093 L .67231 .46803 L F
.67196 .47018 m .6699 .46908 L .66964 .47016 L .675 .735 .895 r
F
.67352 .46773 m .67367 .47484 L .6733 .46763 L .845 .571 .523 r
F
.67214 .47018 m .67204 .46948 L .67196 .47018 L .675 .735 .895 r
F
.67235 .4665 m .67266 .47147 L .67255 .47127 L .988 .719 .38 r
F
.67593 .4702 m .67246 .46956 L .67214 .47018 L .675 .735 .895 r
F
.67225 .46749 m .67228 .46797 L .67229 .47079 L .772 .616 .051 r
F
.67228 .47055 m .67229 .47079 L .6723 .4734 L F
.67225 .46749 m .67229 .47079 L .67228 .47055 L F
.67224 .46998 m .67204 .46948 L .67214 .47018 L .675 .735 .895 r
F
.67224 .46574 m .67227 .46635 L .67228 .46797 L .772 .616 .051 r
F
.67264 .46482 m .67223 .46557 L .67223 .46717 L 0 0 .382 r
F
.67237 .47093 m .67233 .47085 L .67227 .46635 L .988 .719 .38 r
F
.67235 .4665 m .67237 .46814 L .67227 .46635 L F
.67237 .46814 m .67231 .46803 L .67227 .46635 L F
.67224 .46733 m .66986 .46624 L .6696 .46732 L .675 .735 .895 r
F
.67224 .46737 m .67224 .46725 L .67223 .46557 L .772 .616 .051 r
F
.67264 .46482 m .67264 .4664 L .67276 .4646 L 0 0 .382 r
F
.67224 .46737 m .67226 .47022 L .67224 .46725 L .772 .616 .051 r
F
.67226 .47022 m .67225 .47015 L .67223 .46557 L F
.67246 .46672 m .67223 .46717 L .67224 .46733 L .675 .735 .895 r
F
.67226 .47022 m .67227 .47289 L .67225 .47015 L .772 .616 .051 r
F
.67227 .47289 m .67226 .47274 L .67223 .46557 L F
.67256 .46655 m .67223 .46717 L .67225 .47262 L 0 0 .382 r
F
.67586 .46735 m .67228 .46797 L .67228 .46797 L .675 .735 .895 r
F
.6726 .46856 m .67228 .46797 L .67232 .46867 L F
.67586 .46735 m .67228 .46797 L .6726 .46856 L F
.67235 .4665 m .67265 .46704 L .67265 .46866 L .988 .719 .38 r
F
.67247 .46832 m .67265 .46866 L .67266 .47147 L F
.67235 .4665 m .67265 .46866 L .67247 .46832 L F
.67278 .46895 m .6721 .46755 L .67217 .46871 L .675 .735 .895 r
F
.67475 .46367 m .67389 .46389 L .67391 .46817 L .568 .343 .534 r
F
.67279 .46717 m .6733 .46763 L .67331 .46924 L .93 .648 .486 r
F
.67314 .46909 m .67285 .46902 L .67308 .46913 L .675 .735 .895 r
F
.67299 .46895 m .67285 .46902 L .67314 .46909 L F
.67298 .46895 m .67331 .46924 L .67332 .47205 L .93 .648 .486 r
F
.67279 .46717 m .67331 .46924 L .67298 .46895 L F
.67586 .46735 m .67299 .46895 L .67314 .46909 L .675 .735 .895 r
F
.67586 .46735 m .6696 .46732 L .66976 .4684 L F
.67684 .46552 m .67427 .46811 L .6755 .46835 L .654 .726 .902 r
F
.67586 .46735 m .67246 .46672 L .67224 .46733 L .675 .735 .895 r
F
.67346 .46566 m .67277 .46614 L .67278 .46896 L .402 .214 .508 r
F
.67279 .46717 m .67332 .47205 L .67286 .47164 L .93 .648 .486 r
F
.67312 .46872 m .67278 .46896 L .67279 .47165 L .402 .214 .508 r
F
.67346 .46566 m .67278 .46896 L .67312 .46872 L F
.67264 .4664 m .67262 .46926 L .67273 .46622 L 0 0 .382 r
F
.67267 .46917 m .67273 .46905 L .67276 .4646 L F
.67224 .46574 m .67228 .46797 L .67225 .46749 L .772 .616 .051 r
F
.67345 .46848 m .67295 .46655 L .67162 .46721 L .675 .735 .895 r
F
.67586 .46735 m .6726 .46856 L .67285 .46902 L F
.67593 .4702 m .6742 .46808 L .67345 .46848 L F
.67593 .4702 m .67278 .46895 L .67246 .46956 L F
.67469 .46792 m .67392 .47094 L .67464 .47075 L .568 .343 .534 r
F
.67475 .46367 m .67425 .46806 L .67469 .46792 L F
.67425 .46806 m .67392 .47094 L .67469 .46792 L F
.67475 .46367 m .67391 .46817 L .67425 .46806 L F
.6742 .46808 m .67414 .468 L .67391 .46817 L .675 .735 .895 r
F
.6742 .46808 m .67391 .46817 L .67345 .46848 L F
.67586 .46735 m .67278 .46613 L .67205 .46665 L F
.67364 .46405 m .67312 .46872 L .67357 .4684 L .402 .214 .508 r
F
.67414 .468 m .67295 .46655 L .67345 .46848 L .675 .735 .895 r
F
.67279 .46895 m .67328 .46836 L .67278 .46895 L F
.67593 .4702 m .67345 .46848 L .67279 .46895 L F
.67345 .46848 m .67328 .46836 L .67279 .46895 L F
.67353 .47118 m .67374 .47105 L .6738 .46824 L .402 .214 .508 r
F
.67367 .46833 m .6738 .46824 L .67389 .46389 L F
.67353 .47118 m .6738 .46824 L .67367 .46833 L F
.67425 .46806 m .67391 .46817 L .67392 .47094 L .568 .343 .534 r
F
.67328 .46836 m .67314 .46827 L .67305 .46844 L .675 .735 .895 r
F
.67328 .46836 m .67305 .46844 L .67278 .46895 L F
.67262 .46926 m .67267 .46917 L .67273 .46622 L 0 0 .382 r
F
.67264 .46482 m .6724 .46968 L .67262 .46926 L F
.67314 .46827 m .6721 .46755 L .67278 .46895 L .675 .735 .895 r
F
.67262 .46926 m .67261 .47198 L .67267 .46917 L 0 0 .382 r
F
.67264 .4664 m .67273 .46622 L .67276 .4646 L F
.67264 .46482 m .67223 .46717 L .67256 .46655 L F
.67246 .46672 m .6722 .46667 L .67223 .46717 L .675 .735 .895 r
F
.6722 .46667 m .66986 .46624 L .67224 .46733 L F
.67224 .46574 m .67224 .46737 L .67223 .46557 L .772 .616 .051 r
F
.67217 .46871 m .67162 .46721 L .67058 .46807 L .675 .735 .895 r
F
.6721 .46755 m .67162 .46721 L .67217 .46871 L F
.67364 .46405 m .67277 .46614 L .67346 .46566 L .402 .214 .508 r
F
.67344 .46568 m .67313 .46546 L .67278 .46613 L .675 .735 .895 r
F
.67313 .46546 m .67157 .46438 L .67278 .46612 L F
.67313 .46546 m .67278 .46612 L .67278 .46613 L F
.67246 .46956 m .67221 .46951 L .67224 .46998 L F
.67221 .46951 m .67204 .46948 L .67224 .46998 L F
.67262 .46926 m .67225 .47262 L .67261 .47198 L 0 0 .382 r
F
.67593 .4702 m .67225 .47018 L .67229 .47082 L .675 .735 .895 r
F
.6724 .46968 m .67225 .47262 L .67262 .46926 L 0 0 .382 r
F
.67357 .4684 m .67279 .47165 L .67353 .47118 L .402 .214 .508 r
F
.67312 .46872 m .67279 .47165 L .67357 .4684 L F
.67204 .46948 m .67152 .46938 L .6717 .46971 L .675 .735 .895 r
F
.67204 .46948 m .6717 .46971 L .67196 .47018 L F
.67152 .46938 m .6699 .46908 L .67196 .47018 L F
.67162 .46721 m .66522 .46595 L .67058 .46807 L F
.67053 .46524 m .66521 .46312 L .66386 .46513 L F
.66731 .46422 m .65987 .46382 L .66522 .46595 L F
.66299 .46123 m .6598 .46097 L .65987 .46382 L .359 .189 .51 r
F
.67353 .47071 m .65487 .45731 L .67177 .47079 L .654 .726 .902 r
F
.67031 .4627 m .65022 .45402 L .65351 .46023 L F
.67261 .47198 m .67273 .46905 L .67267 .46917 L 0 0 .382 r
F
.67246 .46956 m .67087 .46819 L .67152 .46938 L .675 .735 .895 r
F
.67278 .46895 m .67087 .46819 L .67246 .46956 L F
.67087 .46819 m .67058 .46807 L .67152 .46938 L F
.67053 .46524 m .66386 .46513 L .66986 .46624 L F
.66728 .4614 m .65988 .461 L .66521 .46312 L F
.67162 .46721 m .66731 .46422 L .66522 .46595 L F
.66728 .4614 m .66299 .45843 L .65988 .461 L F
.66299 .46123 m .66292 .45838 L .6598 .46097 L .359 .189 .51 r
F
.67157 .46438 m .66728 .4614 L .66521 .46312 L .675 .735 .895 r
F
.66997 .4629 m .66299 .46123 L .66731 .46422 L F
.667 .45925 m .66292 .45838 L .66299 .46123 L .497 .294 .534 r
F
.67353 .47071 m .66711 .46199 L .66354 .46353 L .654 .726 .902 r
F
.66707 .4621 m .66693 .46207 L .66306 .46408 L .497 .294 .534 r
F
.66693 .46207 m .66299 .46123 L .66306 .46374 L F
.66693 .46207 m .66306 .46374 L .66306 .46408 L F
.66354 .46353 m .66154 .45442 L .65487 .45731 L .654 .726 .902 r
F
.66993 .46009 m .66299 .45843 L .66728 .4614 L .675 .735 .895 r
F
.66997 .4629 m .667 .45925 L .66299 .46123 L F
.66707 .4621 m .667 .45925 L .66299 .46123 L .497 .294 .534 r
F
.66711 .46199 m .66154 .45442 L .66354 .46353 L .654 .726 .902 r
F
.67473 .46509 m .67469 .46792 L .67493 .46503 L .568 .343 .534 r
F
.67469 .46792 m .67464 .47075 L .67478 .46789 L F
.67469 .46792 m .67478 .46789 L .67493 .46503 L F
.67362 .46555 m .67357 .4684 L .67382 .46541 L .402 .214 .508 r
F
.67357 .4684 m .67353 .47118 L .67367 .46833 L F
.67357 .4684 m .67367 .46833 L .67382 .46541 L F
.67389 .46389 m .67374 .47105 L .67392 .47094 L F
.67414 .468 m .67449 .46614 L .67295 .46655 L .675 .735 .895 r
F
.6742 .46808 m .67421 .46795 L .67414 .468 L F
.67421 .46795 m .67449 .46614 L .67414 .468 L F
.67583 .46493 m .675 .465 L .67501 .46782 L .66 .416 .54 r
F
.67586 .46735 m .67477 .46977 L .67574 .46991 L .675 .735 .895 r
F
.67593 .4702 m .67508 .46781 L .6742 .46808 L F
.67567 .47212 m .67456 .46899 L .67374 .46921 L F
.67643 .4728 m .67475 .47072 L .67475 .47072 L .654 .726 .902 r
F
.67578 .46775 m .67501 .46782 L .67502 .47063 L .66 .416 .54 r
F
.67578 .46775 m .67502 .47063 L .67574 .47057 L F
.67514 .47062 m .6762 .46886 L .67456 .46899 L .675 .735 .895 r
F
.67567 .47212 m .67612 .47053 L .67514 .47062 L F
.67593 .4702 m .67581 .47276 L .67679 .47262 L F
.67602 .47264 m .67612 .47053 L .67567 .47212 L F
.67684 .46552 m .67263 .4637 L .66943 .46384 L .654 .726 .902 r
F
.67263 .4637 m .67031 .4627 L .66943 .46384 L F
.67464 .47075 m .67477 .47072 L .675 .4636 L .568 .343 .534 r
F
.67364 .46405 m .67276 .4646 L .67277 .46614 L .402 .214 .508 r
F
.67278 .46613 m .67157 .46438 L .67053 .46524 L .675 .735 .895 r
F
.67362 .46555 m .67382 .46541 L .67389 .46389 L .402 .214 .508 r
F
.67586 .46735 m .67289 .46372 L .67157 .46438 L .675 .735 .895 r
F
.67289 .46372 m .66728 .4614 L .67157 .46438 L F
.67289 .46372 m .66993 .46009 L .66728 .4614 L F
.67442 .46332 m .66993 .46009 L .67289 .46372 L F
.67449 .46614 m .66997 .4629 L .67295 .46655 L F
.67364 .46405 m .67362 .46552 L .67373 .46399 L .402 .214 .508 r
F
.67362 .46552 m .67362 .46555 L .67373 .46399 L F
.67373 .46399 m .67362 .46555 L .67389 .46389 L F
.67449 .46614 m .67305 .46208 L .66997 .4629 L .675 .735 .895 r
F
.66993 .46009 m .66697 .45646 L .66299 .45843 L F
.67299 .45928 m .66697 .45646 L .66993 .46009 L F
.67205 .46665 m .67053 .46524 L .66986 .46624 L F
.67278 .46613 m .67053 .46524 L .67205 .46665 L F
.67295 .46655 m .66731 .46422 L .67162 .46721 L F
.67456 .46899 m .67312 .46493 L .67005 .46575 L F
.67299 .45928 m .67156 .45524 L .66697 .45646 L F
.67305 .46208 m .667 .45925 L .66997 .4629 L F
.67442 .46332 m .67299 .45928 L .66993 .46009 L F
.67305 .46208 m .67161 .45802 L .667 .45925 L F
.67161 .45802 m .66692 .45641 L .667 .45925 L .591 .367 .544 r
F
.67161 .45802 m .67154 .45518 L .66692 .45641 L F
.67312 .46493 m .67168 .46087 L .66707 .4621 L .675 .735 .895 r
F
.67168 .46087 m .667 .45925 L .66707 .46201 L .591 .367 .544 r
F
.67157 .46438 m .66521 .46312 L .67053 .46524 L .675 .735 .895 r
F
.67295 .46655 m .66997 .4629 L .66731 .46422 L F
.667 .45925 m .66692 .45641 L .66292 .45838 L .497 .294 .534 r
F
.67474 .47072 m .66365 .45398 L .66154 .45442 L .654 .726 .902 r
F
.66874 .46166 m .66707 .46201 L .66707 .4621 L .591 .367 .544 r
F
.67168 .46087 m .66707 .46201 L .66874 .46166 L F
.66885 .46163 m .66922 .45279 L .66365 .45398 L .654 .726 .902 r
F
.67643 .4728 m .67215 .46093 L .66885 .46163 L F
.67168 .46087 m .67161 .45802 L .667 .45925 L .591 .367 .544 r
F
.67215 .46093 m .66922 .45279 L .66885 .46163 L .654 .726 .902 r
F
.67643 .4728 m .66365 .45398 L .67474 .47072 L F
.676 .47305 m .67602 .47264 L .67567 .47212 L .675 .735 .895 r
F
.67684 .46552 m .6755 .46835 L .67669 .46858 L .654 .726 .902 r
F
.67593 .4702 m .67605 .46772 L .67508 .46781 L .675 .735 .895 r
F
.67574 .47062 m .67595 .47061 L .67601 .46773 L .66 .416 .54 r
F
.67603 .46491 m .67607 .46491 L .67609 .46355 L F
.67604 .45034 m .67585 .46356 L .67609 .46355 L F
.67604 .45034 m .675 .4636 L .67585 .46356 L F
.67713 .45047 m .67604 .45034 L .67609 .46355 L .734 .477 .539 r
F
.67581 .45544 m .6774 .45523 L .67745 .46828 L .641 .401 .54 r
F
.67713 .45047 m .67609 .46355 L .67693 .46368 L .734 .477 .539 r
F
.67495 .45043 m .67475 .46367 L .675 .4636 L .568 .343 .534 r
F
.67684 .46552 m .6778 .44535 L .66966 .44561 L .654 .726 .902 r
F
.67693 .46368 m .67609 .46355 L .6761 .4649 L .734 .477 .539 r
F
.67586 .46735 m .677 .46482 L .67597 .46492 L .675 .735 .895 r
F
.67581 .47724 m .67888 .48116 L .67744 .4771 L F
.67631 .47543 m .67629 .47577 L .67735 .47534 L .654 .726 .902 r
F
.67643 .47542 m .67643 .47549 L .67625 .47543 L .641 .401 .54 r
F
.67643 .47549 m .67665 .48245 L .67626 .47551 L F
.67643 .47549 m .67626 .47551 L .67625 .47543 L F
.67685 .47543 m .67581 .47724 L .67744 .4771 L .675 .735 .895 r
F
.67643 .4728 m .67588 .47547 L .67631 .47543 L .654 .726 .902 r
F
.676 .47305 m .67588 .47556 L .67685 .47543 L .675 .735 .895 r
F
.67588 .47556 m .67581 .47724 L .67685 .47543 L F
.67665 .48245 m .6764 .48247 L .67586 .46842 L .641 .401 .54 r
F
.67641 .47324 m .67631 .47543 L .6768 .47382 L .654 .726 .902 r
F
.6797 .45272 m .67965 .46573 L .67975 .46596 L .982 .725 .331 r
F
.67888 .46435 m .70442 .45686 L .69964 .45242 L .654 .726 .902 r
F
.67684 .46552 m .67966 .46464 L .67888 .46435 L F
.67966 .46464 m .70442 .45686 L .67888 .46435 L F
.6786 .47485 m .67898 .47469 L .67921 .47432 L .675 .735 .895 r
F
.67882 .47098 m .68178 .47461 L .68443 .4733 L F
.67921 .4715 m .68024 .47319 L .68128 .47233 L F
.67768 .46819 m .67817 .47222 L .67777 .47239 L .517 .303 .528 r
F
.67784 .46954 m .67849 .47208 L .67817 .47222 L F
.67593 .4702 m .67856 .47202 L .67921 .4715 L .675 .735 .895 r
F
.67961 .46805 m .67951 .46881 L .67962 .46805 L F
.6793 .46853 m .67923 .46863 L .67919 .46737 L .082 0 .419 r
F
.67869 .46781 m .67782 .46825 L .67896 .46814 L .654 .726 .902 r
F
.67586 .46735 m .6792 .46868 L .67961 .46805 L .675 .735 .895 r
F
.6792 .46868 m .67951 .46881 L .67961 .46805 L F
.67928 .46723 m .6793 .46853 L .67919 .46737 L .082 0 .419 r
F
.6793 .46853 m .67933 .47131 L .67923 .46863 L F
.68486 .48114 m .68478 .47829 L .68878 .47632 L .497 .294 .534 r
F
.68486 .48114 m .68878 .47632 L .68886 .47916 L F
.68893 .48201 m .68886 .47916 L .69198 .47658 L .36 .19 .51 r
F
.68178 .47461 m .68474 .47824 L .68872 .47627 L .675 .735 .895 r
F
.68188 .47749 m .68886 .47916 L .68455 .47618 L F
.68893 .48201 m .69198 .47658 L .69205 .47943 L .36 .19 .51 r
F
.68188 .47749 m .68486 .48114 L .68886 .47916 L .675 .735 .895 r
F
.68493 .48399 m .68886 .47916 L .68893 .48201 L .497 .294 .534 r
F
.68462 .47902 m .68893 .48201 L .69205 .47943 L .675 .735 .895 r
F
.68462 .47902 m .69205 .47943 L .6867 .4773 L F
.68031 .47604 m .68462 .47902 L .6867 .4773 L F
.68031 .47604 m .6867 .4773 L .68135 .47517 L F
.67959 .47417 m .69797 .48828 L .70317 .48435 L .654 .726 .902 r
F
.67878 .47217 m .68024 .47319 L .6792 .47151 L .675 .735 .895 r
F
.67933 .47131 m .67936 .4742 L .67924 .47145 L .082 0 .419 r
F
.67879 .47498 m .68031 .47604 L .67921 .47432 L .675 .735 .895 r
F
.67904 .47467 m .67946 .47498 L .67943 .4741 L .654 .726 .902 r
F
.67965 .46656 m .67966 .46782 L .67962 .46673 L 0 0 .152 r
F
.67951 .46881 m .68015 .47033 L .68118 .46947 L .675 .735 .895 r
F
.68015 .47033 m .6865 .47159 L .68118 .46947 L F
.67984 .46953 m .68222 .47024 L .68206 .46915 L F
.67968 .47059 m .67966 .47067 L .67964 .46796 L 0 0 .152 r
F
.67933 .47131 m .67924 .47145 L .67919 .46737 L .082 0 .419 r
F
.67866 .46913 m .67919 .4687 L .6792 .47151 L .359 .181 .499 r
F
.6792 .47151 m .68024 .47319 L .67921 .4715 L .675 .735 .895 r
F
.6792 .46868 m .67946 .46913 L .67951 .46881 L F
.67935 .46844 m .67963 .46802 L .67965 .47378 L .082 0 .419 r
F
.67878 .47217 m .67891 .47385 L .68024 .47319 L .675 .735 .895 r
F
.68178 .47461 m .68872 .47627 L .68443 .4733 L F
.68024 .47319 m .68455 .47618 L .68663 .47445 L F
.68002 .47307 m .68203 .47417 L .68229 .47308 L F
.6793 .47429 m .67928 .47432 L .67924 .47145 L .082 0 .419 r
F
.67936 .4742 m .6793 .47429 L .67924 .47145 L F
.67817 .47222 m .6785 .4749 L .67777 .47239 L .517 .303 .528 r
F
.6792 .47151 m .67924 .47428 L .67921 .47432 L .082 0 .419 r
F
.67928 .47432 m .67924 .47437 L .6792 .47151 L F
.67823 .48295 m .67895 .48543 L .67912 .4844 L .654 .726 .902 r
F
.67853 .48199 m .67936 .51287 L .67865 .51344 L .359 .181 .499 r
F
.67752 .47491 m .67875 .47676 L .67898 .47669 L .675 .735 .895 r
F
.67881 .47831 m .68025 .48237 L .68486 .48114 L F
.67777 .47652 m .68363 .49278 L .67909 .47727 L .654 .726 .902 r
F
.67819 .47592 m .67909 .47727 L .67854 .4754 L F
.67777 .47652 m .67909 .47727 L .67819 .47592 L F
.68125 .48053 m .68493 .48399 L .68195 .48034 L .675 .735 .895 r
F
.68364 .48432 m .68363 .49278 L .68796 .49187 L .654 .726 .902 r
F
.68059 .48497 m .68025 .48237 L .68486 .48114 L .592 .367 .544 r
F
.68375 .4843 m .68486 .48114 L .68493 .48399 L F
.6813 .48482 m .68363 .49278 L .68364 .48432 L .654 .726 .902 r
F
.68032 .48521 m .68059 .48497 L .68375 .4843 L .592 .367 .544 r
F
.68059 .48497 m .68486 .48114 L .68375 .4843 L F
.68291 .48304 m .68493 .48399 L .68125 .48053 L .675 .735 .895 r
F
.67854 .4754 m .68364 .48432 L .68343 .48144 L .654 .726 .902 r
F
.68364 .48432 m .68796 .49187 L .6846 .48412 L F
.68291 .48304 m .68375 .4843 L .68493 .48399 L .675 .735 .895 r
F
.68364 .48432 m .6846 .48412 L .68343 .48144 L .654 .726 .902 r
F
.6829 .48302 m .6813 .48482 L .68364 .48432 L F
.67909 .47727 m .6813 .48482 L .6829 .48302 L F
.68032 .48521 m .68031 .48503 L .68059 .48497 L .592 .367 .544 r
F
.68031 .48503 m .68025 .48237 L .68059 .48497 L F
.67888 .48116 m .68032 .48521 L .68375 .4843 L .675 .735 .895 r
F
.67888 .48116 m .68375 .4843 L .68291 .48304 L F
.67744 .4771 m .68195 .48034 L .67898 .47669 L F
.67854 .4754 m .67909 .47727 L .6829 .48302 L .654 .726 .902 r
F
.67888 .48116 m .68291 .48304 L .68125 .48053 L .675 .735 .895 r
F
.68886 .47916 m .68878 .47632 L .69191 .47373 L .36 .19 .51 r
F
.68886 .47916 m .69191 .47373 L .69198 .47658 L F
.68455 .47618 m .68886 .47916 L .69198 .47658 L .675 .735 .895 r
F
.69205 .47943 m .69198 .47658 L .69401 .47356 L .124 .015 .447 r
F
.68455 .47618 m .69198 .47658 L .68663 .47445 L .675 .735 .895 r
F
.6867 .4773 m .69205 .47943 L .69408 .47641 L F
.69205 .47943 m .69401 .47356 L .69408 .47641 L .124 .015 .447 r
F
.6867 .4773 m .69408 .47641 L .68806 .47529 L .675 .735 .895 r
F
.68135 .47517 m .6867 .4773 L .68806 .47529 L F
.68135 .47517 m .68806 .47529 L .68203 .47417 L F
.68024 .47367 m .70317 .48435 L .70655 .47963 L .654 .726 .902 r
F
.67848 .46789 m .67861 .47486 L .6785 .47494 L .359 .181 .499 r
F
.676 .47305 m .6796 .47372 L .68002 .47307 L .675 .735 .895 r
F
.67891 .47385 m .68455 .47618 L .68024 .47319 L F
.676 .47305 m .68135 .47517 L .68203 .47417 L F
.67936 .47409 m .67965 .47378 L .67936 .4742 L .082 0 .419 r
F
.67964 .47367 m .67965 .47378 L .67936 .47409 L F
.6786 .47485 m .67879 .47498 L .67898 .47469 L .675 .735 .895 r
F
.67744 .4771 m .67888 .48116 L .68195 .48034 L F
.67875 .47476 m .67924 .48147 L .67886 .48175 L .359 .181 .499 r
F
.67866 .46913 m .67892 .47464 L .67875 .47476 L F
.67892 .47464 m .67924 .48147 L .67875 .47476 L F
.67684 .46552 m .70344 .47701 L .70544 .47422 L .654 .726 .902 r
F
.6902 .46855 m .70544 .47422 L .7068 .47232 L F
.67684 .46552 m .70544 .47422 L .6902 .46855 L F
.6782 .45085 m .67713 .45047 L .67718 .46371 L .81 .54 .531 r
F
.67561 .48143 m .68032 .48521 L .67888 .48116 L .675 .735 .895 r
F
.67687 .48243 m .67709 .48304 L .67786 .48234 L .654 .726 .902 r
F
.67709 .48304 m .67789 .48246 L .67786 .48234 L F
.67824 .47504 m .67777 .47652 L .67854 .4754 L F
.67634 .47268 m .67746 .47253 L .67748 .47533 L .641 .401 .54 r
F
.67643 .4728 m .67736 .47537 L .67824 .47504 L .654 .726 .902 r
F
.67736 .47537 m .67777 .47652 L .67824 .47504 L F
.67946 .47498 m .69797 .48828 L .67959 .47417 L F
.67943 .4741 m .67946 .47498 L .67959 .47417 L F
.67936 .4742 m .67965 .47378 L .67968 .48083 L .082 0 .419 r
F
.67828 .48287 m .68417 .49013 L .67878 .48215 L .654 .726 .902 r
F
.68417 .49013 m .69091 .49844 L .68341 .48837 L F
.68417 .49013 m .68341 .48837 L .67878 .48215 L F
.67969 .47351 m .67974 .48047 L .67968 .4736 L 0 0 .152 r
F
.67974 .48047 m .67972 .48059 L .67967 .47366 L F
.67882 .47098 m .68443 .4733 L .68015 .47033 L .675 .735 .895 r
F
.67963 .47089 m .68128 .47233 L .68196 .47132 L F
.67866 .46913 m .6792 .47151 L .67893 .47172 L .359 .181 .499 r
F
.67784 .46954 m .67848 .46927 L .67849 .47208 L .517 .303 .528 r
F
.67593 .4702 m .67952 .47163 L .67963 .47089 L .675 .735 .895 r
F
.67952 .47163 m .68128 .47233 L .67963 .47089 L F
.67968 .4736 m .67967 .47366 L .67965 .47076 L 0 0 .152 r
F
.67946 .46913 m .68015 .47033 L .67951 .46881 L .675 .735 .895 r
F
.67966 .47072 m .67965 .47076 L .67962 .46673 L 0 0 .152 r
F
.67968 .4736 m .67965 .47076 L .67966 .47072 L F
.67974 .48047 m .67967 .47366 L .67968 .4736 L F
.68134 .46819 m .68148 .46814 L .68141 .46808 L .675 .735 .895 r
F
.67684 .46552 m .7068 .47232 L .70784 .46823 L .654 .726 .902 r
F
.69644 .46655 m .70784 .46823 L .70812 .46716 L F
.67684 .46552 m .70784 .46823 L .69644 .46655 L F
.67665 .48245 m .67762 .51388 L .6764 .48247 L .641 .401 .54 r
F
.67643 .47542 m .67748 .47533 L .67748 .47534 L F
.67685 .47543 m .67744 .4771 L .67768 .47531 L .675 .735 .895 r
F
.68493 .48399 m .68486 .48114 L .68886 .47916 L .497 .294 .534 r
F
.68195 .48034 m .68493 .48399 L .68893 .48201 L .675 .735 .895 r
F
.68195 .48034 m .68893 .48201 L .68462 .47902 L F
.68116 .4762 m .69131 .49116 L .69797 .48828 L .654 .726 .902 r
F
.68254 .47937 m .69131 .49116 L .68116 .4762 L F
.68068 .48209 m .69757 .49556 L .70277 .49163 L F
.6785 .47494 m .67875 .48183 L .67853 .48199 L .359 .181 .499 r
F
.67603 .48008 m .67903 .48224 L .68068 .48209 L .654 .726 .902 r
F
.68343 .48144 m .68796 .49187 L .69131 .49116 L F
.67933 .47131 m .67964 .47367 L .67936 .47409 L .082 0 .419 r
F
.67936 .4742 m .67944 .48117 L .6793 .47429 L F
.67962 .47265 m .67933 .47199 L .67936 .47904 L .982 .725 .331 r
F
.67709 .48304 m .68323 .50006 L .67789 .48246 L .654 .726 .902 r
F
.67823 .48295 m .68804 .49904 L .67828 .48287 L F
.67938 .48127 m .6798 .51219 L .67935 .48131 L .082 0 .419 r
F
.67944 .48117 m .6798 .51219 L .67938 .48127 L F
.67924 .48147 m .6798 .51219 L .67936 .51287 L F
.67935 .48131 m .6798 .51219 L .67924 .48147 L F
.68076 .48116 m .70277 .49163 L .70615 .48691 L .654 .726 .902 r
F
.67875 .4747 m .67867 .47476 L .67848 .46789 L .359 .181 .499 r
F
.67643 .47549 m .67748 .47534 L .6775 .48237 L .641 .401 .54 r
F
.67665 .48245 m .6775 .48237 L .67762 .51388 L F
.67591 .48252 m .67762 .51388 L .67603 .51409 L F
.67886 .48175 m .67875 .48183 L .67861 .47486 L .359 .181 .499 r
F
.67867 .47482 m .67861 .47486 L .67848 .46789 L F
.67886 .48175 m .67861 .47486 L .67867 .47482 L F
.67863 .46778 m .67875 .4747 L .67848 .46789 L F
.67586 .46735 m .67856 .46923 L .6792 .46868 L .675 .735 .895 r
F
.67966 .46782 m .67964 .46796 L .67962 .46673 L 0 0 .152 r
F
.67965 .46656 m .67975 .46721 L .67967 .46772 L F
.67684 .46552 m .7073 .46188 L .70442 .45686 L .654 .726 .902 r
F
.67857 .46562 m .68138 .4653 L .68042 .46443 L .675 .735 .895 r
F
.67586 .46735 m .67921 .46611 L .67857 .46562 L F
.67905 .46598 m .67921 .46611 L .6793 .46494 L .91 .629 .497 r
F
.67965 .46573 m .6793 .46494 L .67931 .46618 L .982 .725 .331 r
F
.67921 .46611 m .68138 .4653 L .67857 .46562 L .675 .735 .895 r
F
.67907 .46475 m .67905 .46598 L .6793 .46494 L .91 .629 .497 r
F
.67684 .46552 m .67778 .46815 L .67869 .46781 L .654 .726 .902 r
F
.67586 .46735 m .68212 .46739 L .68195 .46631 L .675 .735 .895 r
F
.67905 .46598 m .67901 .46876 L .67921 .46611 L .91 .629 .497 r
F
.68114 .48044 m .69482 .48435 L .68502 .4807 L .654 .726 .902 r
F
.67768 .46819 m .67798 .4822 L .67745 .46828 L .517 .303 .528 r
F
.67786 .48234 m .67789 .48246 L .67792 .48244 L .654 .726 .902 r
F
.67798 .4822 m .67865 .51344 L .67782 .48226 L .517 .303 .528 r
F
.67798 .4822 m .67782 .48226 L .67745 .46828 L F
.67921 .47432 m .67935 .48131 L .67924 .48147 L .082 0 .419 r
F
.67603 .48008 m .68076 .48116 L .68114 .48044 L .654 .726 .902 r
F
.68076 .48116 m .68259 .48157 L .68164 .48082 L F
.68076 .48116 m .68164 .48082 L .68114 .48044 L F
.68259 .48157 m .69482 .48435 L .68114 .48044 L F
.67969 .47351 m .67968 .4736 L .67962 .46673 L 0 0 .152 r
F
.67951 .46881 m .68118 .46947 L .67962 .46805 L .675 .735 .895 r
F
.67967 .46772 m .67975 .46721 L .67976 .47002 L 0 0 .152 r
F
.68015 .47033 m .68443 .4733 L .6865 .47159 L .675 .735 .895 r
F
.67972 .47029 m .67976 .47002 L .67977 .47284 L 0 0 .152 r
F
.67745 .46828 m .67763 .47527 L .67748 .47533 L .517 .303 .528 r
F
.67893 .47172 m .6792 .47151 L .67921 .47432 L .359 .181 .499 r
F
.67856 .47202 m .67878 .47217 L .6792 .47151 L .675 .735 .895 r
F
.67866 .46913 m .67921 .47432 L .67891 .47456 L .359 .181 .499 r
F
.67928 .46723 m .6795 .47105 L .67933 .47131 L .082 0 .419 r
F
.67593 .4702 m .67976 .47002 L .67957 .46958 L .675 .735 .895 r
F
.67905 .46598 m .67826 .46538 L .67828 .47101 L .91 .629 .497 r
F
.67593 .4702 m .68018 .47099 L .67985 .47022 L .675 .735 .895 r
F
.67965 .46656 m .67977 .473 L .67969 .47351 L 0 0 .152 r
F
.67972 .46993 m .67971 .47268 L .67976 .47002 L .982 .725 .331 r
F
.67967 .46772 m .67976 .47002 L .67972 .47029 L 0 0 .152 r
F
.676 .47305 m .68099 .47308 L .68029 .47254 L .675 .735 .895 r
F
.67962 .47265 m .6797 .47285 L .67971 .47268 L .982 .725 .331 r
F
.67968 .47059 m .67969 .47351 L .67966 .47067 L 0 0 .152 r
F
.67962 .47249 m .67971 .47268 L .67975 .46596 L .982 .725 .331 r
F
.68005 .47235 m .68218 .47232 L .68153 .4721 L .675 .735 .895 r
F
.676 .47305 m .68029 .47254 L .68005 .47235 L F
.68029 .47254 m .68218 .47232 L .68005 .47235 L F
.67957 .47416 m .70317 .48435 L .68024 .47367 L .654 .726 .902 r
F
.68103 .48035 m .70734 .48224 L .70188 .48144 L F
.67944 .48117 m .67938 .48127 L .67928 .47432 L .082 0 .419 r
F
.67603 .48008 m .68114 .48044 L .68103 .48035 L .654 .726 .902 r
F
.68114 .48044 m .70734 .48224 L .68103 .48035 L F
.67828 .48287 m .67914 .48428 L .67918 .48398 L F
.67886 .48175 m .67936 .51287 L .67875 .48183 L .359 .181 .499 r
F
.67828 .48287 m .67878 .48215 L .67863 .48195 L .654 .726 .902 r
F
.67875 .48183 m .67936 .51287 L .67853 .48199 L .359 .181 .499 r
F
.67886 .48175 m .67924 .48147 L .67936 .51287 L F
.68443 .4733 m .68872 .47627 L .69183 .4737 L .675 .735 .895 r
F
.69198 .47658 m .69191 .47373 L .69394 .47071 L .124 .015 .447 r
F
.68663 .47445 m .69198 .47658 L .69401 .47356 L .675 .735 .895 r
F
.68024 .47319 m .68663 .47445 L .68128 .47233 L F
.69408 .47641 m .69401 .47356 L .69481 .47031 L 0 0 .265 r
F
.69408 .47641 m .69481 .47031 L .69488 .47316 L F
.68806 .47529 m .69408 .47641 L .69488 .47316 L .675 .735 .895 r
F
.69198 .47658 m .69394 .47071 L .69401 .47356 L .124 .015 .447 r
F
.68443 .4733 m .69183 .4737 L .6865 .47159 L .675 .735 .895 r
F
.68663 .47445 m .69401 .47356 L .68798 .47244 L F
.68806 .47529 m .69488 .47316 L .68859 .47312 L F
.68128 .47233 m .68663 .47445 L .68798 .47244 L F
.68203 .47417 m .68806 .47529 L .68859 .47312 L F
.68203 .47417 m .68859 .47312 L .68229 .47308 L F
.68109 .47305 m .70655 .47963 L .70787 .47445 L .654 .726 .902 r
F
.6796 .47372 m .68203 .47417 L .68002 .47307 L .675 .735 .895 r
F
.68024 .47367 m .70655 .47963 L .68109 .47305 L .654 .726 .902 r
F
.6865 .47159 m .69183 .4737 L .69384 .47069 L .675 .735 .895 r
F
.69401 .47356 m .69394 .47071 L .69473 .46746 L 0 0 .265 r
F
.69401 .47356 m .69473 .46746 L .69481 .47031 L F
.68798 .47244 m .69401 .47356 L .69481 .47031 L .675 .735 .895 r
F
.68128 .47233 m .68798 .47244 L .68196 .47132 L F
.68859 .47312 m .69488 .47316 L .69439 .4699 L F
.6865 .47159 m .69384 .47069 L .68785 .46958 L F
.68798 .47244 m .69481 .47031 L .68851 .47027 L F
.68859 .47312 m .69439 .4699 L .68826 .47095 L F
.68229 .47308 m .68859 .47312 L .68826 .47095 L F
.68118 .46947 m .6865 .47159 L .68785 .46958 L F
.68196 .47132 m .68798 .47244 L .68851 .47027 L F
.68229 .47308 m .68826 .47095 L .68213 .472 L F
.67987 .47239 m .70787 .47445 L .70706 .46915 L .654 .726 .902 r
F
.67962 .46673 m .67967 .47366 L .67965 .47378 L 0 0 .152 r
F
.67962 .47265 m .67971 .47268 L .67962 .47249 L .982 .725 .331 r
F
.67971 .47268 m .6797 .47285 L .67971 .47269 L F
.67977 .47285 m .67977 .47297 L .67977 .47297 L 0 0 .152 r
F
.67977 .47285 m .67977 .47284 L .67977 .47297 L F
.67972 .47029 m .67977 .47284 L .67977 .47285 L F
.67977 .47284 m .6797 .47285 L .67977 .473 L .982 .725 .331 r
F
.67976 .47002 m .67971 .47269 L .67977 .47284 L F
.67971 .47269 m .6797 .47285 L .67977 .47284 L F
.67971 .47268 m .67971 .47269 L .67976 .47002 L F
.67936 .47189 m .6821 .472 L .68162 .47111 L .675 .735 .895 r
F
.67924 .47145 m .67928 .47432 L .6792 .47151 L .082 0 .419 r
F
.676 .47305 m .6796 .47243 L .67936 .47189 L .675 .735 .895 r
F
.6795 .47105 m .67965 .47378 L .67933 .47131 L .082 0 .419 r
F
.6796 .47243 m .6821 .472 L .67936 .47189 L .675 .735 .895 r
F
.67953 .47243 m .67978 .47298 L .67987 .47239 L .654 .726 .902 r
F
.67643 .4728 m .67976 .47298 L .67953 .47243 L F
.67976 .47298 m .67978 .47298 L .67953 .47243 L F
.68029 .47254 m .68229 .47308 L .68218 .47232 L .675 .735 .895 r
F
.68099 .47308 m .68229 .47308 L .68029 .47254 L F
.67978 .47298 m .70787 .47445 L .67987 .47239 L .654 .726 .902 r
F
.67965 .47378 m .67972 .48059 L .67968 .48083 L 0 0 .152 r
F
.67967 .47366 m .67972 .48059 L .67965 .47378 L F
.67936 .47904 m .70666 .47643 L .70375 .47138 L .654 .726 .902 r
F
.67768 .47531 m .67744 .4771 L .67875 .47676 L .675 .735 .895 r
F
.6778 .48226 m .67828 .48287 L .67863 .48195 L .654 .726 .902 r
F
.67786 .48234 m .67823 .48295 L .67828 .48287 L F
.67792 .48244 m .67812 .48311 L .67823 .48295 L F
.67783 .47519 m .6785 .47494 L .67853 .48199 L .517 .303 .528 r
F
.67798 .4822 m .67853 .48199 L .67865 .51344 L F
.67783 .47519 m .67853 .48199 L .67798 .4822 L F
.68716 .47876 m .70747 .48173 L .70666 .47643 L .654 .726 .902 r
F
.67643 .4728 m .67957 .47416 L .68024 .47367 L F
.67643 .4728 m .67904 .47467 L .67943 .4741 L F
.67897 .47153 m .67828 .47101 L .67831 .47821 L .91 .629 .497 r
F
.67603 .48008 m .68008 .4796 L .67936 .47904 L .654 .726 .902 r
F
.67603 .48008 m .67924 .48147 L .67992 .48097 L F
.67969 .47351 m .6798 .48005 L .67974 .48047 L 0 0 .152 r
F
.68785 .46958 m .69384 .47069 L .69464 .46746 L .675 .735 .895 r
F
.68851 .47027 m .69481 .47031 L .69432 .46705 L F
.69488 .47316 m .69481 .47031 L .69432 .46705 L .844 .648 .105 r
F
.69488 .47316 m .69432 .46705 L .69439 .4699 L F
.676 .47305 m .67936 .47189 L .67933 .47181 L .675 .735 .895 r
F
.68153 .4721 m .68218 .47232 L .68213 .472 L F
.68838 .46743 m .69464 .46746 L .69415 .46422 L F
.69481 .47031 m .69473 .46746 L .69424 .4642 L .844 .648 .105 r
F
.68196 .47132 m .68851 .47027 L .68222 .47024 L .675 .735 .895 r
F
.69481 .47031 m .69424 .4642 L .69432 .46705 L .844 .648 .105 r
F
.68785 .46958 m .69464 .46746 L .68838 .46743 L .675 .735 .895 r
F
.68851 .47027 m .69432 .46705 L .68819 .4681 L F
.68213 .472 m .6871 .46892 L .68155 .47098 L F
.68118 .46947 m .68785 .46958 L .68185 .46847 L F
.68222 .47024 m .68851 .47027 L .68819 .4681 L F
.68213 .472 m .68826 .47095 L .6871 .46892 L F
.68826 .47095 m .69265 .46685 L .6871 .46892 L F
.68826 .47095 m .69439 .4699 L .69265 .46685 L F
.67983 .47174 m .70706 .46915 L .70415 .46409 L .654 .726 .902 r
F
.67891 .47456 m .67921 .47432 L .67924 .48147 L .359 .181 .499 r
F
.67887 .47865 m .67903 .47878 L .67917 .47186 L .91 .629 .497 r
F
.67932 .46899 m .67917 .47169 L .67933 .47181 L F
.6793 .46494 m .67923 .46892 L .67932 .46899 L F
.67919 .46737 m .67924 .47145 L .6792 .47151 L .082 0 .419 r
F
.67923 .46892 m .67917 .47169 L .67932 .46899 L .91 .629 .497 r
F
.67593 .4702 m .67984 .46953 L .67986 .4694 L .675 .735 .895 r
F
.67927 .46896 m .67986 .4694 L .67996 .4687 L F
.67593 .4702 m .67986 .4694 L .67927 .46896 L F
.67901 .46876 m .67897 .4717 L .67923 .46892 L .91 .629 .497 r
F
.67947 .46933 m .67933 .47199 L .67963 .46972 L .982 .725 .331 r
F
.67593 .4702 m .67973 .47022 L .67976 .47002 L .675 .735 .895 r
F
.67957 .46958 m .67976 .47002 L .67984 .46953 L F
.67804 .47083 m .68059 .47011 L .67932 .46944 L F
.67975 .46596 m .67972 .46993 L .67976 .47002 L .982 .725 .331 r
F
.67965 .46573 m .67947 .46933 L .67963 .46972 L F
.67966 .46782 m .67968 .47059 L .67964 .46796 L 0 0 .152 r
F
.679 .46824 m .68134 .46819 L .68052 .46726 L .675 .735 .895 r
F
.67593 .4702 m .6793 .46895 L .679 .46824 L F
.67963 .46972 m .67967 .46982 L .67975 .46596 L .982 .725 .331 r
F
.67959 .46684 m .67931 .46618 L .67933 .47199 L F
.6793 .46895 m .68134 .46819 L .679 .46824 L .675 .735 .895 r
F
.67965 .46656 m .67975 .46596 L .67975 .46721 L 0 0 .152 r
F
.67927 .46608 m .68195 .46631 L .68138 .4653 L .675 .735 .895 r
F
.67586 .46735 m .67954 .46672 L .67927 .46608 L F
.67965 .46573 m .67964 .46696 L .67975 .46596 L .982 .725 .331 r
F
.67964 .46696 m .67971 .46712 L .67975 .46596 L F
.67965 .46573 m .67931 .46618 L .67959 .46684 L F
.67954 .46672 m .68195 .46631 L .67927 .46608 L .675 .735 .895 r
F
.67964 .46696 m .67963 .46972 L .67971 .46712 L .982 .725 .331 r
F
.67963 .46972 m .67962 .47265 L .67967 .46982 L F
.67795 .46809 m .67791 .47088 L .67812 .46814 L .81 .54 .531 r
F
.67777 .47239 m .6785 .4749 L .67783 .47519 L .517 .303 .528 r
F
.67791 .47088 m .6778 .47802 L .67803 .47092 L .81 .54 .531 r
F
.67791 .47088 m .67803 .47092 L .67812 .46814 L F
.67593 .4702 m .67773 .47241 L .67858 .47204 L .675 .735 .895 r
F
.676 .47305 m .67869 .47132 L .67828 .47101 L F
.676 .47305 m .6786 .47485 L .67921 .47432 L F
.6785 .4749 m .6785 .47494 L .67783 .47519 L .517 .303 .528 r
F
.67643 .4728 m .67854 .4754 L .67904 .47467 L .654 .726 .902 r
F
.6778 .47802 m .67797 .47809 L .67825 .46411 L .81 .54 .531 r
F
.67797 .4709 m .67828 .47101 L .67804 .47083 L .675 .735 .895 r
F
.676 .47305 m .67828 .47101 L .67797 .4709 L F
.67913 .47165 m .67917 .47169 L .67923 .46892 L .91 .629 .497 r
F
.67897 .4717 m .67912 .47182 L .67923 .46892 L F
.67869 .47132 m .68059 .47011 L .67804 .47083 L .675 .735 .895 r
F
.67621 .46839 m .67746 .47253 L .67634 .47268 L .641 .401 .54 r
F
.67679 .47262 m .67746 .47253 L .67773 .47241 L .675 .735 .895 r
F
.676 .47305 m .67933 .47181 L .67903 .47111 L F
.67912 .47182 m .67917 .47186 L .67917 .47169 L .91 .629 .497 r
F
.67912 .47182 m .67917 .47169 L .67913 .47165 L F
.67887 .47865 m .67917 .47186 L .67912 .47182 L F
.67925 .47192 m .68117 .47224 L .67983 .47174 L .654 .726 .902 r
F
.67643 .4728 m .67985 .47239 L .67925 .47192 L F
.67985 .47239 m .68117 .47224 L .67925 .47192 L F
.6821 .472 m .68213 .472 L .68212 .47199 L .675 .735 .895 r
F
.6821 .472 m .68212 .47199 L .68155 .47098 L F
.68117 .47224 m .70706 .46915 L .67983 .47174 L .654 .726 .902 r
F
.67811 .47095 m .67811 .4711 L .67828 .47101 L .81 .54 .531 r
F
.67643 .4728 m .67925 .47192 L .67871 .4715 L .654 .726 .902 r
F
.67811 .4711 m .67797 .47809 L .67827 .47116 L .81 .54 .531 r
F
.67811 .4711 m .67827 .47116 L .67828 .47101 L F
.67905 .46598 m .67828 .47101 L .67897 .47153 L .91 .629 .497 r
F
.67593 .4702 m .67879 .46837 L .67789 .46807 L .675 .735 .895 r
F
.67825 .46411 m .67811 .47095 L .67828 .47101 L .81 .54 .531 r
F
.67984 .46953 m .68206 .46915 L .67996 .4687 L .675 .735 .895 r
F
.67901 .46876 m .67923 .46892 L .6793 .46494 L .91 .629 .497 r
F
.67798 .46797 m .68052 .46726 L .67925 .46659 L .675 .735 .895 r
F
.67795 .46809 m .67812 .46814 L .67825 .46411 L .81 .54 .531 r
F
.67789 .46807 m .67804 .46802 L .67798 .46797 L .675 .735 .895 r
F
.67804 .46802 m .68052 .46726 L .67798 .46797 L F
.67879 .46837 m .68052 .46726 L .67789 .46807 L F
.67684 .46552 m .69964 .45242 L .69332 .44887 L .654 .726 .902 r
F
.67801 .46402 m .67799 .46529 L .67825 .46411 L .81 .54 .531 r
F
.67799 .46529 m .67795 .46809 L .67816 .46534 L F
.67799 .46529 m .67816 .46534 L .67825 .46411 L F
.6774 .45523 m .67768 .46819 L .67745 .46828 L .517 .303 .528 r
F
.67586 .46735 m .67857 .46562 L .67826 .46538 L .675 .735 .895 r
F
.67781 .46523 m .67826 .46538 L .67791 .46512 L F
.67586 .46735 m .67826 .46538 L .67781 .46523 L F
.6771 .47061 m .67932 .46944 L .67782 .46901 L F
.67593 .4702 m .67679 .47262 L .67773 .47241 L F
.676 .47305 m .67797 .4709 L .6771 .47061 L F
.67797 .4709 m .67932 .46944 L .6771 .47061 L F
.6797 .45272 m .6793 .46494 L .67965 .46573 L .982 .725 .331 r
F
.67684 .46552 m .69332 .44887 L .68587 .44646 L .654 .726 .902 r
F
.67801 .46402 m .67718 .46371 L .67718 .46502 L .81 .54 .531 r
F
.67786 .46524 m .67719 .46783 L .67753 .46795 L F
.67702 .46777 m .67925 .46659 L .67775 .46616 L .675 .735 .895 r
F
.67719 .46783 m .67704 .47063 L .6772 .47065 L .734 .477 .539 r
F
.67718 .46371 m .6771 .46782 L .67719 .46783 L F
.67593 .4702 m .67789 .46807 L .67719 .46783 L .675 .735 .895 r
F
.6771 .46782 m .67704 .47063 L .67719 .46783 L .734 .477 .539 r
F
.67643 .47549 m .6775 .48237 L .67665 .48245 L .641 .401 .54 r
F
.67643 .47542 m .67748 .47534 L .67643 .47549 L F
.676 .47305 m .67685 .47543 L .67768 .47531 L .675 .735 .895 r
F
.6762 .48249 m .67762 .51388 L .67591 .48252 L .641 .401 .54 r
F
.67586 .46735 m .67781 .46523 L .67718 .46502 L .675 .735 .895 r
F
.6782 .45085 m .67718 .46371 L .67801 .46402 L .81 .54 .531 r
F
.6782 .45085 m .67801 .46402 L .67825 .46411 L F
.67925 .45167 m .67825 .46411 L .67907 .46475 L .91 .629 .497 r
F
.67925 .45167 m .67907 .46475 L .6793 .46494 L F
.67684 .46552 m .68587 .44646 L .6778 .44535 L .654 .726 .902 r
F
.67691 .46499 m .67711 .46501 L .67718 .46371 L .734 .477 .539 r
F
.67692 .46499 m .67718 .46502 L .67694 .46494 L .675 .735 .895 r
F
.67586 .46735 m .67718 .46502 L .67692 .46499 L F
.67693 .46368 m .67691 .46499 L .67718 .46371 L .734 .477 .539 r
F
.67593 .4702 m .677 .46781 L .67611 .46772 L .675 .735 .895 r
F
.67609 .46355 m .67601 .46773 L .67611 .46772 L .66 .416 .54 r
F
.67605 .46772 m .67611 .46772 L .67605 .46771 L .675 .735 .895 r
F
.67593 .4702 m .67611 .46772 L .67605 .46772 L F
.67611 .46772 m .67595 .47061 L .67612 .4706 L .66 .416 .54 r
F
.67601 .46773 m .67595 .47061 L .67611 .46772 L F
.67691 .46499 m .6761 .4649 L .67612 .4706 L .734 .477 .539 r
F
.67605 .46771 m .67775 .46616 L .67613 .46601 L .675 .735 .895 r
F
.67687 .4678 m .67697 .46781 L .67711 .46501 L .734 .477 .539 r
F
.677 .46781 m .67775 .46616 L .67605 .46771 L .675 .735 .895 r
F
.67691 .46499 m .67687 .4678 L .67711 .46501 L .734 .477 .539 r
F
.67687 .4678 m .67683 .47071 L .67697 .46781 L F
.68134 .46819 m .68141 .46808 L .68052 .46726 L .675 .735 .895 r
F
.68195 .46631 m .68805 .46526 L .6869 .46324 L F
.68212 .46739 m .68805 .46526 L .68195 .46631 L F
.68148 .46814 m .68511 .46432 L .68052 .46726 L F
.68148 .46814 m .68703 .46607 L .68511 .46432 L F
.68518 .46717 m .68595 .46221 L .68264 .46582 L F
.67829 .47092 m .693 .45607 L .67739 .47079 L .654 .726 .902 r
F
.67797 .47809 m .6781 .47813 L .67827 .47116 L .81 .54 .531 r
F
.67828 .47101 m .6781 .47813 L .67831 .47821 L F
.67875 .4747 m .67886 .48175 L .67867 .47476 L .359 .181 .499 r
F
.67861 .47486 m .67875 .48183 L .6785 .47494 L F
.67897 .47153 m .67831 .47821 L .67887 .47865 L .91 .629 .497 r
F
.67643 .4728 m .68024 .47367 L .68109 .47305 L .654 .726 .902 r
F
.67917 .47169 m .67903 .47878 L .67933 .47181 L .91 .629 .497 r
F
.67933 .47181 m .68162 .47111 L .6813 .47107 L .675 .735 .895 r
F
.67936 .47189 m .68162 .47111 L .67933 .47181 L F
.67985 .47022 m .68196 .47132 L .68222 .47024 L F
.68018 .47099 m .68196 .47132 L .67985 .47022 L F
.68014 .4704 m .68155 .47098 L .68059 .47011 L F
.67996 .47157 m .68155 .47098 L .68014 .4704 L F
.67897 .4717 m .67887 .47865 L .67912 .47182 L .91 .629 .497 r
F
.67737 .47082 m .67829 .47092 L .67739 .47079 L .654 .726 .902 r
F
.67643 .4728 m .67812 .4711 L .67737 .47082 L F
.67791 .47088 m .6772 .47076 L .6779 .47102 L .81 .54 .531 r
F
.67812 .4711 m .67829 .47092 L .67737 .47082 L .654 .726 .902 r
F
.67791 .47088 m .6772 .47065 L .6772 .47076 L .81 .54 .531 r
F
.676 .47305 m .67875 .47676 L .67752 .47491 L .675 .735 .895 r
F
.6779 .47102 m .6772 .47076 L .67723 .47781 L .81 .54 .531 r
F
.67782 .48226 m .67769 .4823 L .67748 .47533 L .517 .303 .528 r
F
.67603 .48008 m .6778 .48226 L .67863 .48195 L .654 .726 .902 r
F
.67748 .47533 m .67769 .4823 L .6775 .48237 L .517 .303 .528 r
F
.67936 .4742 m .67968 .48083 L .67944 .48117 L .082 0 .419 r
F
.67962 .47265 m .67936 .47904 L .67959 .47958 L .982 .725 .331 r
F
.68805 .46526 m .69415 .46422 L .69242 .46119 L .675 .735 .895 r
F
.69432 .46705 m .69424 .4642 L .6925 .46116 L .986 .71 .375 r
F
.68819 .4681 m .69432 .46705 L .69257 .46401 L .675 .735 .895 r
F
.69432 .46705 m .6925 .46116 L .69257 .46401 L .986 .71 .375 r
F
.69439 .4699 m .69432 .46705 L .69257 .46401 L F
.69439 .4699 m .69257 .46401 L .69265 .46685 L F
.68838 .46743 m .69415 .46422 L .68805 .46526 L .675 .735 .895 r
F
.68819 .4681 m .69257 .46401 L .68703 .46607 L F
.6871 .46892 m .69265 .46685 L .68977 .46423 L F
.67815 .47795 m .69896 .46692 L .6926 .46335 L .654 .726 .902 r
F
.67603 .48008 m .67943 .47813 L .67815 .47795 L F
.67966 .47974 m .67972 .47987 L .67977 .473 L .982 .725 .331 r
F
.67959 .47958 m .67966 .47974 L .6797 .47285 L F
.67969 .47351 m .67977 .473 L .67975 .47664 L 0 0 .152 r
F
.67977 .473 m .67972 .47987 L .6798 .48005 L .982 .725 .331 r
F
.67943 .47813 m .69896 .46692 L .67815 .47795 L .654 .726 .902 r
F
.67704 .47074 m .67689 .47776 L .6772 .47076 L .734 .477 .539 r
F
.6768 .48224 m .67687 .48243 L .67692 .48243 L .654 .726 .902 r
F
.6768 .48224 m .67692 .48243 L .67786 .48234 L F
.67603 .48008 m .6768 .48224 L .67786 .48234 L F
.67689 .47776 m .67627 .50899 L .67703 .47778 L .734 .477 .539 r
F
.67689 .47776 m .67703 .47778 L .6772 .47076 L F
.6778 .47802 m .67723 .47781 L .67735 .50912 L .81 .54 .531 r
F
.67763 .47527 m .67782 .48226 L .67748 .47533 L .517 .303 .528 r
F
.67791 .47088 m .67723 .47781 L .6778 .47802 L .81 .54 .531 r
F
.67903 .47111 m .67996 .47157 L .68014 .4704 L .675 .735 .895 r
F
.68185 .46847 m .68785 .46958 L .68838 .46743 L F
.68212 .46739 m .68838 .46743 L .68805 .46526 L F
.68222 .47024 m .68819 .4681 L .68206 .46915 L F
.68185 .46847 m .68838 .46743 L .68212 .46739 L F
.68206 .46915 m .68819 .4681 L .68703 .46607 L F
.68155 .47098 m .68518 .46717 L .68059 .47011 L F
.68155 .47098 m .6871 .46892 L .68518 .46717 L F
.6871 .46892 m .68977 .46423 L .68518 .46717 L F
.68805 .46526 m .69242 .46119 L .6869 .46324 L F
.68703 .46607 m .69257 .46401 L .6897 .46138 L F
.69265 .46685 m .69257 .46401 L .6897 .46138 L .934 .65 .478 r
F
.67942 .47109 m .68516 .47006 L .69936 .45963 L .654 .726 .902 r
F
.6813 .47107 m .68162 .47111 L .68155 .47098 L .675 .735 .895 r
F
.6811 .47133 m .68516 .47006 L .67942 .47109 L .654 .726 .902 r
F
.67996 .4687 m .68206 .46915 L .68148 .46814 L .675 .735 .895 r
F
.67973 .47022 m .68222 .47024 L .67984 .46953 L F
.68206 .46915 m .68703 .46607 L .68148 .46814 L F
.68059 .47011 m .68518 .46717 L .68264 .46582 L F
.69265 .46685 m .6897 .46138 L .68977 .46423 L .934 .65 .478 r
F
.68014 .47067 m .69936 .45963 L .68044 .46875 L .654 .726 .902 r
F
.6797 .47285 m .67966 .47974 L .67977 .473 L .982 .725 .331 r
F
.67962 .47265 m .67959 .47958 L .6797 .47285 L F
.68195 .46631 m .6869 .46324 L .68138 .4653 L .675 .735 .895 r
F
.68138 .4653 m .6869 .46324 L .68499 .46151 L F
.68703 .46607 m .6897 .46138 L .68511 .46432 L F
.68511 .46432 m .68588 .45936 L .68256 .46298 L F
.6869 .46324 m .68955 .45858 L .68499 .46151 L F
.68511 .46432 m .6897 .46138 L .68588 .45936 L F
.68518 .46717 m .68977 .46423 L .68595 .46221 L F
.68977 .46423 m .68588 .45936 L .68595 .46221 L .862 .585 .518 r
F
.67712 .47777 m .6926 .46335 L .6851 .46093 L .654 .726 .902 r
F
.6772 .47065 m .67703 .47778 L .67723 .47781 L .734 .477 .539 r
F
.67711 .47779 m .67713 .47777 L .67712 .47777 L .654 .726 .902 r
F
.67713 .47777 m .6926 .46335 L .67712 .47777 L F
.67603 .48008 m .67815 .47795 L .67711 .47779 L F
.67903 .47878 m .67916 .47888 L .67933 .47181 L .91 .629 .497 r
F
.67944 .48117 m .67928 .47432 L .6793 .47429 L .082 0 .419 r
F
.67928 .47432 m .67938 .48127 L .67924 .47437 L F
.67938 .48127 m .67935 .48131 L .67924 .47437 L F
.67924 .47428 m .67935 .48131 L .67921 .47432 L F
.67933 .47181 m .67916 .47888 L .67936 .47904 L .91 .629 .497 r
F
.67815 .47795 m .6926 .46335 L .67711 .47779 L .654 .726 .902 r
F
.67683 .47071 m .67673 .47774 L .67704 .47074 L .734 .477 .539 r
F
.67673 .47774 m .67627 .50899 L .67689 .47776 L F
.67673 .47774 m .67689 .47776 L .67704 .47074 L F
.67683 .47071 m .67704 .47074 L .67718 .46371 L F
.68138 .4653 m .68499 .46151 L .68042 .46443 L .675 .735 .895 r
F
.68042 .46443 m .68499 .46151 L .68246 .46016 L F
.68052 .46726 m .68256 .46298 L .67925 .46659 L F
.68052 .46726 m .68511 .46432 L .68256 .46298 L F
.68499 .46151 m .68576 .45657 L .68246 .46016 L F
.68499 .46151 m .68955 .45858 L .68576 .45657 L F
.67932 .46944 m .67964 .46497 L .67782 .46901 L F
.67932 .46944 m .68264 .46582 L .67964 .46497 L F
.6869 .46324 m .69242 .46119 L .68955 .45858 L F
.6897 .46138 m .68962 .45854 L .68581 .45651 L .862 .585 .518 r
F
.68256 .46298 m .68588 .45936 L .68138 .45808 L .675 .735 .895 r
F
.6897 .46138 m .68581 .45651 L .68588 .45936 L .862 .585 .518 r
F
.68246 .46016 m .68576 .45657 L .68128 .45529 L .675 .735 .895 r
F
.68588 .45936 m .68581 .45651 L .68131 .45523 L .794 .529 .536 r
F
.68042 .46443 m .68246 .46016 L .67916 .46376 L .675 .735 .895 r
F
.67925 .46659 m .68256 .46298 L .67957 .46212 L F
.68264 .46582 m .68146 .46093 L .67964 .46497 L F
.68264 .46582 m .68595 .46221 L .68146 .46093 L F
.68595 .46221 m .68588 .45936 L .68138 .45808 L .794 .529 .536 r
F
.68595 .46221 m .68138 .45808 L .68146 .46093 L F
.67739 .47079 m .693 .45607 L .68551 .45365 L .654 .726 .902 r
F
.677 .46781 m .67719 .46783 L .67702 .46777 L .675 .735 .895 r
F
.67593 .4702 m .67719 .46783 L .677 .46781 L F
.67789 .46807 m .67925 .46659 L .67702 .46777 L F
.67786 .46524 m .67718 .46502 L .67719 .46783 L .81 .54 .531 r
F
.67753 .46795 m .67719 .46783 L .6772 .47065 L F
.67801 .46402 m .67718 .46502 L .67786 .46524 L F
.67694 .46494 m .67916 .46376 L .67767 .46333 L .675 .735 .895 r
F
.67801 .46402 m .6772 .47065 L .67791 .47088 L .81 .54 .531 r
F
.67781 .46523 m .67916 .46376 L .67694 .46494 L .675 .735 .895 r
F
.67704 .47063 m .67704 .47074 L .6772 .47065 L .734 .477 .539 r
F
.67704 .47074 m .6772 .47076 L .6772 .47065 L F
.67643 .4728 m .68014 .47067 L .68044 .46875 L .654 .726 .902 r
F
.67907 .46475 m .67825 .46411 L .67826 .46538 L .91 .629 .497 r
F
.67791 .46512 m .68042 .46443 L .67916 .46376 L .675 .735 .895 r
F
.67907 .46475 m .67826 .46538 L .67905 .46598 L .91 .629 .497 r
F
.67857 .46562 m .68042 .46443 L .67791 .46512 L .675 .735 .895 r
F
.676 .47305 m .67709 .47063 L .67612 .47053 L F
.67683 .47061 m .67612 .4706 L .67683 .47071 L .734 .477 .539 r
F
.67691 .46499 m .67613 .47053 L .67683 .47061 L F
.67613 .47053 m .67612 .4706 L .67683 .47061 L F
.67612 .47053 m .67782 .46901 L .6762 .46886 L .675 .735 .895 r
F
.67709 .47063 m .67782 .46901 L .67612 .47053 L F
.67693 .46368 m .6761 .4649 L .67691 .46499 L .734 .477 .539 r
F
.677 .46482 m .67767 .46333 L .67597 .46492 L .675 .735 .895 r
F
.67643 .4728 m .67641 .47324 L .6768 .47382 L .654 .726 .902 r
F
.67916 .46376 m .67947 .45931 L .67767 .46333 L .675 .735 .895 r
F
.67916 .46376 m .68246 .46016 L .67947 .45931 L F
.67713 .45047 m .67693 .46368 L .67718 .46371 L .734 .477 .539 r
F
.67767 .46333 m .67947 .45931 L .67625 .45901 L .675 .735 .895 r
F
.67925 .46659 m .67957 .46212 L .67775 .46616 L F
.67775 .46616 m .67957 .46212 L .67632 .46182 L F
.68246 .46016 m .68128 .45529 L .67947 .45931 L F
.67782 .46901 m .67639 .46466 L .6762 .46886 L F
.67782 .46901 m .67964 .46497 L .67639 .46466 L F
.67947 .45931 m .67644 .45484 L .67625 .45901 L F
.67947 .45931 m .68128 .45529 L .67644 .45484 L F
.68256 .46298 m .68138 .45808 L .67957 .46212 L F
.67767 .46333 m .67625 .45901 L .67605 .46318 L F
.67957 .46212 m .67652 .45762 L .67632 .46182 L F
.67957 .46212 m .68138 .45808 L .67652 .45762 L F
.67597 .46489 m .67767 .46333 L .67605 .46318 L F
.67599 .46489 m .67767 .46333 L .67597 .46489 L F
.67775 .46616 m .67632 .46182 L .67613 .46601 L F
.67964 .46497 m .67659 .46047 L .67639 .46466 L F
.67964 .46497 m .68146 .46093 L .67659 .46047 L F
.68138 .45808 m .68131 .45523 L .67644 .45477 L .731 .477 .544 r
F
.68588 .45936 m .68131 .45523 L .68138 .45808 L .794 .529 .536 r
F
.68138 .45808 m .67644 .45477 L .67652 .45762 L .731 .477 .544 r
F
.68146 .46093 m .68138 .45808 L .67652 .45762 L F
.68146 .46093 m .67652 .45762 L .67659 .46047 L F
.67643 .4728 m .68551 .45365 L .6774 .45253 L .654 .726 .902 r
F
.6762 .47655 m .6851 .46093 L .67699 .45981 L F
.67643 .4728 m .67523 .47534 L .67588 .47547 L F
.67683 .47071 m .67612 .4706 L .67615 .47765 L .734 .477 .539 r
F
.67603 .48008 m .67711 .47779 L .67614 .47765 L .654 .726 .902 r
F
.67613 .47545 m .67762 .51388 L .67588 .47547 L .641 .401 .54 r
F
.67603 .48008 m .67591 .48252 L .67687 .48243 L .654 .726 .902 r
F
.67673 .47774 m .67615 .47765 L .67627 .50899 L .734 .477 .539 r
F
.67683 .47071 m .67615 .47765 L .67673 .47774 L F
.67614 .47765 m .67712 .47777 L .67616 .47741 L .654 .726 .902 r
F
.67711 .47779 m .67712 .47777 L .67614 .47765 L F
.67616 .47741 m .67649 .47679 L .6762 .47655 L F
.67963 .46972 m .67933 .47199 L .67962 .47265 L .982 .725 .331 r
F
.67933 .47181 m .67996 .47157 L .67903 .47111 L .675 .735 .895 r
F
.67871 .4715 m .6811 .47133 L .67942 .47109 L .654 .726 .902 r
F
.68059 .47011 m .68264 .46582 L .67932 .46944 L .675 .735 .895 r
F
.67649 .47679 m .6851 .46093 L .6762 .47655 L .654 .726 .902 r
F
.67925 .47192 m .6811 .47133 L .67871 .4715 L F
.67712 .47777 m .6851 .46093 L .67616 .47741 L F
.67769 .4823 m .67865 .51344 L .6775 .48237 L .517 .303 .528 r
F
.67797 .47809 m .67735 .50912 L .6781 .47813 L .81 .54 .531 r
F
.6789 .47843 m .70375 .47138 L .69896 .46692 L .654 .726 .902 r
F
.67603 .48008 m .68 .47884 L .6789 .47843 L F
.68 .47884 m .70375 .47138 L .6789 .47843 L F
.67782 .48226 m .67865 .51344 L .67769 .4823 L .517 .303 .528 r
F
.6775 .48237 m .67865 .51344 L .67762 .51388 L F
.67831 .47821 m .67735 .50912 L .67843 .5095 L .81 .54 .531 r
F
.6781 .47813 m .67735 .50912 L .67831 .47821 L F
.67887 .47865 m .67831 .47821 L .67843 .5095 L .91 .629 .497 r
F
.68008 .4796 m .68269 .48043 L .68716 .47876 L .654 .726 .902 r
F
.67603 .48008 m .68103 .48035 L .68008 .4796 L F
.68103 .48035 m .68269 .48043 L .68008 .4796 L F
.68269 .48043 m .70747 .48173 L .68716 .47876 L F
.68008 .4796 m .70666 .47643 L .67936 .47904 L F
.67903 .47878 m .67843 .5095 L .67916 .47888 L .91 .629 .497 r
F
.67936 .47904 m .67843 .5095 L .67948 .51032 L F
.67916 .47888 m .67843 .5095 L .67936 .47904 L F
.67887 .47865 m .67843 .5095 L .67903 .47878 L F
.6778 .47802 m .67735 .50912 L .67797 .47809 L .81 .54 .531 r
F
.68502 .4807 m .70615 .48691 L .70734 .48224 L .654 .726 .902 r
F
.69482 .48435 m .70615 .48691 L .68502 .4807 L F
.68516 .47006 m .70415 .46409 L .69937 .45965 L F
.68516 .47006 m .69937 .45965 L .69936 .45963 L F
.69827 .48093 m .73002 .4885 L .70344 .47701 L F
.73002 .4885 m .76668 .48591 L .73675 .47911 L F
.70344 .47701 m .73002 .4885 L .73675 .47911 L F
.70317 .48435 m .73665 .48646 L .70655 .47963 L F
.70188 .48144 m .70734 .48224 L .70747 .48173 L F
.67723 .47781 m .67627 .50899 L .67735 .50912 L .734 .477 .539 r
F
.67703 .47778 m .67627 .50899 L .67723 .47781 L F
.67992 .48097 m .67955 .48161 L .68076 .48116 L .654 .726 .902 r
F
.67924 .48147 m .67955 .48161 L .67992 .48097 L F
.67955 .48161 m .70277 .49163 L .68076 .48116 L F
.67959 .47958 m .67936 .47904 L .67948 .51032 L .982 .725 .331 r
F
.67903 .48224 m .68153 .48404 L .68068 .48209 L .654 .726 .902 r
F
.68153 .48404 m .69757 .49556 L .68069 .4821 L F
.68153 .48404 m .68069 .4821 L .68068 .48209 L F
.69257 .46401 m .6925 .46116 L .68962 .45854 L .934 .65 .478 r
F
.69257 .46401 m .68962 .45854 L .6897 .46138 L F
.68977 .46423 m .6897 .46138 L .68588 .45936 L .862 .585 .518 r
F
.68044 .46875 m .69936 .45963 L .693 .45607 L .654 .726 .902 r
F
.67789 .48246 m .68323 .50006 L .67792 .48244 L F
.67944 .48117 m .67968 .48083 L .6798 .51219 L .082 0 .419 r
F
.67966 .47974 m .67948 .51032 L .67972 .47987 L .982 .725 .331 r
F
.67959 .47958 m .67948 .51032 L .67966 .47974 L F
.68153 .48404 m .69091 .49844 L .69757 .49556 L .654 .726 .902 r
F
.67863 .48195 m .68341 .48837 L .68153 .48404 L F
.68341 .48837 m .69091 .49844 L .68153 .48404 L F
.67974 .48047 m .67992 .51137 L .67972 .48059 L 0 0 .152 r
F
.67918 .48398 m .68804 .49904 L .68417 .49013 L .654 .726 .902 r
F
.67914 .48428 m .68804 .49904 L .67918 .48398 L F
.67968 .48083 m .67992 .51137 L .6798 .51219 L 0 0 .152 r
F
.67972 .48059 m .67992 .51137 L .67968 .48083 L F
.67912 .4844 m .68323 .50006 L .68804 .49904 L .654 .726 .902 r
F
.67895 .48543 m .68323 .50006 L .67912 .4844 L F
.67812 .48311 m .68323 .50006 L .67823 .48295 L F
.68417 .49013 m .68804 .49904 L .69091 .49844 L F
.67974 .48047 m .6798 .48005 L .67992 .51137 L 0 0 .152 r
F
.6798 .48005 m .67948 .51032 L .67992 .51137 L .982 .725 .331 r
F
.67972 .47987 m .67948 .51032 L .6798 .48005 L F
.67585 .46356 m .67583 .46493 L .67609 .46355 L .66 .416 .54 r
F
.67586 .46735 m .67597 .46492 L .67502 .465 L .675 .735 .895 r
F
.67583 .46493 m .67574 .47062 L .67603 .46491 L .66 .416 .54 r
F
.67583 .46493 m .67603 .46491 L .67609 .46355 L F
.67585 .46356 m .675 .4636 L .675 .465 L F
.67475 .46367 m .67473 .46509 L .675 .4636 L .568 .343 .534 r
F
.67473 .46509 m .67493 .46503 L .675 .4636 L F
.67502 .465 m .67605 .46318 L .67442 .46332 L .675 .735 .895 r
F
.67585 .46356 m .675 .465 L .67583 .46493 L .66 .416 .54 r
F
.67597 .46492 m .67605 .46318 L .67502 .465 L .675 .735 .895 r
F
.67597 .46492 m .67599 .46489 L .67597 .46489 L F
.67588 .46774 m .67601 .46773 L .67607 .46491 L .66 .416 .54 r
F
.67588 .46774 m .67607 .46491 L .67603 .46491 L F
.67574 .47062 m .67601 .46773 L .67588 .46774 L F
.67583 .46493 m .67501 .46782 L .67578 .46775 L F
.67508 .46781 m .67613 .46601 L .67449 .46614 L .675 .735 .895 r
F
.67605 .46772 m .67613 .46601 L .67508 .46781 L F
.67612 .47053 m .6762 .46886 L .67514 .47062 L F
.67643 .4728 m .67475 .47072 L .67584 .47238 L .654 .726 .902 r
F
.67574 .47057 m .67502 .47063 L .67502 .47065 L .66 .416 .54 r
F
.67507 .48235 m .67603 .51409 L .67483 .48231 L .751 .491 .538 r
F
.67483 .48231 m .67603 .51409 L .67471 .48228 L F
.67643 .4728 m .67436 .4756 L .67514 .47553 L .654 .726 .902 r
F
.67588 .47556 m .67418 .47709 L .67581 .47724 L .675 .735 .895 r
F
.67527 .47535 m .67588 .47547 L .67588 .47556 L .751 .491 .538 r
F
.67527 .47535 m .67588 .47556 L .67528 .47547 L F
.676 .47305 m .67494 .47542 L .67588 .47556 L .675 .735 .895 r
F
.67494 .47542 m .67418 .47709 L .67588 .47556 L F
.67528 .47547 m .67588 .47556 L .67591 .48252 L .751 .491 .538 r
F
.66971 .47301 m .66374 .47515 L .66987 .4741 L .675 .735 .895 r
F
.67139 .47254 m .66951 .47208 L .66835 .47238 L .654 .726 .902 r
F
.66997 .47193 m .66342 .47298 L .66971 .47301 L .675 .735 .895 r
F
.66997 .47193 m .66395 .47081 L .66342 .47298 L F
.67065 .47092 m .6653 .46879 L .66395 .47081 L F
.6653 .46879 m .65792 .46969 L .66395 .47081 L F
.6653 .46879 m .65994 .46667 L .65792 .46969 L F
.66738 .46707 m .65994 .46667 L .6653 .46879 L F
.66738 .46707 m .66306 .46408 L .65994 .46667 L F
.67284 .47779 m .66113 .46171 L .65446 .46459 L .654 .726 .902 r
F
.67483 .48231 m .67471 .48228 L .6743 .47251 L .751 .491 .538 r
F
.67603 .48008 m .67413 .47774 L .67284 .47779 L .654 .726 .902 r
F
.67367 .47484 m .67381 .48195 L .67356 .47479 L .845 .571 .523 r
F
.67381 .48195 m .67366 .48187 L .6733 .46763 L F
.67265 .479 m .67272 .47888 L .67279 .47165 L 0 0 .382 r
F
.67279 .47165 m .67272 .47888 L .67282 .4787 L F
.67323 .47482 m .67303 .47495 L .67403 .47519 L .675 .735 .895 r
F
.67348 .47475 m .67366 .48187 L .67333 .47467 L .845 .571 .523 r
F
.67257 .47915 m .67265 .479 L .67271 .4718 L 0 0 .382 r
F
.6725 .48077 m .67244 .48066 L .67236 .47351 L .988 .719 .38 r
F
.67261 .47198 m .67228 .47967 L .67257 .47915 L 0 0 .382 r
F
.67065 .47092 m .66395 .47081 L .66997 .47193 L .675 .735 .895 r
F
.67413 .47774 m .66113 .46171 L .67284 .47779 L .654 .726 .902 r
F
.67175 .47231 m .66951 .47208 L .67139 .47254 L F
.676 .47305 m .66997 .47193 L .66971 .47301 L .675 .735 .895 r
F
.67574 .47062 m .67502 .47065 L .67505 .4777 L .66 .416 .54 r
F
.67564 .47767 m .67505 .4777 L .67517 .50908 L F
.67574 .47062 m .67505 .4777 L .67564 .47767 L F
.67574 .47057 m .67502 .47065 L .67574 .47062 L F
.67508 .46781 m .67508 .4678 L .67501 .46782 L .675 .735 .895 r
F
.67508 .46781 m .67501 .46782 L .6742 .46808 L F
.67508 .4678 m .67449 .46614 L .6742 .46808 L F
.67584 .47238 m .67475 .47072 L .67386 .47095 L .654 .726 .902 r
F
.676 .47305 m .67567 .47212 L .67302 .4694 L .675 .735 .895 r
F
.67475 .47072 m .6747 .47066 L .67386 .47095 L .654 .726 .902 r
F
.67276 .4646 m .67271 .4718 L .67279 .47165 L 0 0 .382 r
F
.6747 .47066 m .66154 .45442 L .67353 .47071 L .654 .726 .902 r
F
.67567 .47212 m .67374 .46921 L .67302 .4694 L .675 .735 .895 r
F
.67502 .47065 m .67471 .47779 L .67505 .4777 L .568 .343 .534 r
F
.675 .4636 m .67485 .47069 L .67502 .47065 L F
.67485 .47069 m .67471 .47779 L .67502 .47065 L F
.67386 .47095 m .6747 .47066 L .67353 .47071 L .654 .726 .902 r
F
.67603 .48008 m .67496 .48233 L .67591 .48252 L F
.67574 .47062 m .67517 .50908 L .67595 .47061 L .66 .416 .54 r
F
.67612 .4706 m .67517 .50908 L .67627 .50899 L F
.67595 .47061 m .67517 .50908 L .67612 .4706 L F
.67416 .46527 m .67442 .46332 L .67289 .46372 L .675 .735 .895 r
F
.67502 .465 m .67442 .46332 L .67416 .46527 L F
.67464 .47075 m .67454 .47783 L .67477 .47072 L .568 .343 .534 r
F
.66395 .47081 m .65712 .47294 L .66342 .47298 L .675 .735 .895 r
F
.66395 .47081 m .65792 .46969 L .65712 .47294 L F
.67282 .4787 m .65446 .46459 L .64927 .46853 L .654 .726 .902 r
F
.67367 .47502 m .67432 .47532 L .67434 .48221 L .845 .571 .523 r
F
.67603 .48008 m .6735 .47827 L .67282 .4787 L .654 .726 .902 r
F
.6723 .4734 m .67239 .48058 L .67232 .48045 L .988 .719 .38 r
F
.6723 .48003 m .67229 .47991 L .67226 .47274 L .772 .616 .051 r
F
.67227 .47289 m .67232 .48045 L .6723 .48003 L F
.67229 .47991 m .67229 .47981 L .67225 .47262 L F
.6735 .47827 m .65446 .46459 L .67282 .4787 L .654 .726 .902 r
F
.67374 .47105 m .67359 .47821 L .67392 .47094 L .402 .214 .508 r
F
.67336 .48172 m .67446 .51383 L .67347 .51335 L .845 .571 .523 r
F
.67359 .47821 m .67293 .5102 L .67374 .47812 L .402 .214 .508 r
F
.67359 .47821 m .67374 .47812 L .67392 .47094 L F
.67454 .47783 m .67394 .47799 L .67406 .50942 L .568 .343 .534 r
F
.67456 .47521 m .67456 .47536 L .67455 .47521 L .751 .491 .538 r
F
.67367 .47484 m .67432 .47532 L .67367 .47502 L .845 .571 .523 r
F
.676 .47305 m .67323 .47482 L .67403 .47519 L .675 .735 .895 r
F
.67464 .47075 m .67394 .47799 L .67454 .47783 L .568 .343 .534 r
F
.67342 .47832 m .67293 .5102 L .67359 .47821 L .402 .214 .508 r
F
.67342 .47832 m .67359 .47821 L .67374 .47105 L F
.67104 .47982 m .6706 .47885 L .66755 .47964 L .654 .726 .902 r
F
.67603 .48008 m .67205 .47918 L .67104 .47982 L F
.67205 .47918 m .6706 .47885 L .67104 .47982 L F
.66374 .47515 m .65936 .47924 L .66491 .47718 L .675 .735 .895 r
F
.66374 .47515 m .65762 .4762 L .65936 .47924 L F
.6706 .47885 m .6459 .47325 L .66755 .47964 L .654 .726 .902 r
F
.67434 .48221 m .67603 .51409 L .67446 .51383 L .751 .491 .538 r
F
.67454 .47783 m .67406 .50942 L .67471 .47779 L .568 .343 .534 r
F
.67456 .47536 m .67483 .48231 L .67446 .47534 L .751 .491 .538 r
F
.67454 .47783 m .67471 .47779 L .675 .4636 L .568 .343 .534 r
F
.67342 .47832 m .67282 .4787 L .67293 .5102 L .402 .214 .508 r
F
.67353 .47118 m .67282 .4787 L .67342 .47832 L F
.66683 .47892 m .66606 .48388 L .66937 .48027 L .675 .735 .895 r
F
.66938 .48088 m .66755 .47964 L .66819 .48102 L .654 .726 .902 r
F
.67603 .48008 m .67104 .47982 L .66938 .48088 L F
.67104 .47982 m .66755 .47964 L .66938 .48088 L F
.66491 .47718 m .65936 .47924 L .66224 .48186 L .675 .735 .895 r
F
.66755 .47964 m .6587 .47918 L .66478 .48036 L .654 .726 .902 r
F
.66755 .47964 m .66478 .48036 L .66819 .48102 L F
.67449 .48275 m .67451 .48276 L .67483 .48246 L F
.67463 .48227 m .67603 .51409 L .67434 .48221 L .751 .491 .538 r
F
.67603 .48008 m .67399 .48214 L .67496 .48233 L .654 .726 .902 r
F
.67505 .4777 m .67406 .50942 L .67517 .50908 L .568 .343 .534 r
F
.67471 .47779 m .67406 .50942 L .67505 .4777 L F
.66819 .48102 m .64458 .47844 L .64541 .48374 L .654 .726 .902 r
F
.6587 .47918 m .64458 .47844 L .66819 .48102 L F
.67603 .48008 m .66938 .48088 L .66893 .48116 L F
.6712 .4816 m .66893 .48116 L .66531 .48345 L F
.67603 .48008 m .66893 .48116 L .6712 .4816 L F
.66683 .47892 m .66224 .48186 L .66606 .48388 L .675 .735 .895 r
F
.66938 .48088 m .64541 .48374 L .66531 .48345 L .654 .726 .902 r
F
.67366 .48187 m .67446 .51383 L .67354 .48181 L .845 .571 .523 r
F
.67354 .48181 m .67446 .51383 L .67336 .48172 L F
.67394 .47799 m .67293 .5102 L .67406 .50942 L .402 .214 .508 r
F
.67392 .47094 m .67374 .47812 L .67394 .47799 L F
.67374 .47812 m .67293 .5102 L .67394 .47799 L F
.67244 .48066 m .67282 .51275 L .67239 .48058 L .988 .719 .38 r
F
.67237 .48123 m .6712 .4816 L .67326 .48167 L .654 .726 .902 r
F
.67232 .48045 m .67282 .51275 L .67244 .51205 L .988 .719 .38 r
F
.67239 .48058 m .67282 .51275 L .67232 .48045 L F
.67391 .48222 m .66963 .48444 L .66695 .48925 L .654 .726 .902 r
F
.67271 .4718 m .67265 .479 L .67279 .47165 L 0 0 .382 r
F
.6725 .48077 m .67282 .51275 L .67244 .48066 L .988 .719 .38 r
F
.67393 .48338 m .66625 .4905 L .67422 .4839 L .654 .726 .902 r
F
.6725 .48077 m .6727 .48113 L .67282 .51275 L .988 .719 .38 r
F
.67265 .479 m .6724 .51124 L .67272 .47888 L 0 0 .382 r
F
.66695 .48925 m .65312 .49324 L .65948 .49679 L .654 .726 .902 r
F
.66963 .48444 m .65312 .49324 L .66695 .48925 L F
.6723 .48003 m .67244 .51205 L .67229 .47991 L .772 .616 .051 r
F
.66695 .48925 m .6663 .49043 L .67257 .48457 L .654 .726 .902 r
F
.66695 .48925 m .67257 .48457 L .67256 .48443 L F
.66695 .48925 m .67451 .48276 L .67449 .48275 L F
.67282 .4787 m .6724 .51124 L .67293 .5102 L 0 0 .382 r
F
.67272 .47888 m .6724 .51124 L .67282 .4787 L F
.66695 .48925 m .65948 .49679 L .6663 .49043 L .654 .726 .902 r
F
.6723 .48003 m .67232 .48045 L .67244 .51205 L .772 .616 .051 r
F
.67229 .47991 m .67244 .51205 L .67229 .47981 L F
.67257 .47915 m .6724 .51124 L .67265 .479 L 0 0 .382 r
F
.6663 .49043 m .65948 .49679 L .66625 .4905 L .654 .726 .902 r
F
.67261 .47198 m .67225 .47262 L .67228 .47967 L 0 0 .382 r
F
.67228 .47967 m .67244 .51205 L .6724 .51124 L .772 .616 .051 r
F
.67229 .47981 m .67244 .51205 L .67228 .47967 L F
.67257 .47915 m .67228 .47967 L .6724 .51124 L 0 0 .382 r
F
.66625 .4905 m .65948 .49679 L .66226 .49769 L .654 .726 .902 r
F
.66625 .4905 m .66226 .49769 L .66697 .49921 L F
.56914 .84988 m .5585 .84545 L .55583 .84897 L .645 .732 .913 r
F
.5712 .84843 m .5585 .84545 L .56914 .84988 L F
.74528 .73983 m .74594 .72857 L .73617 .72986 L .683 .771 .917 r
F
.34701 .51138 m .34746 .5041 L .34481 .48823 L .925 .744 .259 r
F
0 g
.3457 .51131 m
.34663 .50748 L
s
.59177 .85682 m .60167 .85173 L .5906 .85491 L .644 .733 .913 r
F
.59177 .85682 m .604 .85556 L .60167 .85173 L F
.7551 .74541 m .75614 .7334 L .75063 .74452 L .683 .771 .917 r
F
.7551 .74541 m .76507 .73516 L .75614 .7334 L F
.43187 .61487 m .43359 .62099 L .4339 .62667 L .833 .628 .08 r
F
.43187 .61487 m .43156 .6092 L .43359 .62099 L F
.4567 .60874 m .43359 .62099 L .45805 .6166 L .673 .757 .914 r
F
.4567 .60874 m .43156 .6092 L .43359 .62099 L F
0 g
.43359 .62099 m
.4369 .62613 L
s
.29896 .7384 m .27673 .73862 L .29279 .74338 L .683 .77 .917 r
F
.59079 .85115 m .59798 .84462 L .58888 .84947 L .645 .732 .913 r
F
.59079 .85115 m .6018 .84799 L .59798 .84462 L F
.5585 .84545 m .54385 .84629 L .55583 .84897 L F
.6973 .74137 m .6907 .74524 L .6912 .74981 L .208 .121 .532 r
F
.71274 .74156 m .69679 .7368 L .6907 .74524 L .683 .771 .917 r
F
.6973 .74137 m .69679 .7368 L .6907 .74524 L .208 .121 .532 r
F
0 g
.68828 .75407 m
.6907 .74524 L
s
.60412 .8518 m .61281 .84483 L .6018 .84799 L .645 .732 .913 r
F
.60412 .8518 m .61629 .85055 L .61281 .84483 L F
.32095 .74686 m .31654 .73625 L .30737 .73898 L .683 .77 .917 r
F
.32583 .74622 m .31654 .73625 L .32095 .74686 L F
.59017 .51705 m .57617 .49642 L .57575 .5037 L .928 .67 .525 r
F
0 g
.59017 .51705 m
.59893 .53215 L
s
.77833 .74267 m .78641 .72966 L .77264 .73833 L .683 .771 .917 r
F
.77833 .74267 m .79494 .73618 L .78641 .72966 L F
.32583 .74622 m .32631 .73497 L .31654 .73625 L .683 .77 .917 r
F
.49359 .48884 m .48629 .46896 L .46342 .47381 L .654 .726 .902 r
F
.50982 .48831 m .48629 .46896 L .49359 .48884 L F
.48165 .6026 m .45798 .61088 L .48232 .60651 L .673 .757 .914 r
F
.48165 .6026 m .45664 .60306 L .45798 .61088 L F
.29326 .74795 m .27721 .74319 L .27124 .75163 L .683 .77 .917 r
F
0 g
.26897 .76046 m
.27124 .75163 L
s
.52595 .49053 m .51066 .46817 L .50982 .48831 L .654 .726 .902 r
F
.52595 .49053 m .53486 .4715 L .51066 .46817 L F
.47776 .49916 m .46276 .48082 L .44285 .48944 L F
.49308 .49591 m .46276 .48082 L .47776 .49916 L F
.22694 .48041 m .19363 .47831 L .22366 .48511 L F
.54059 .50245 m .53457 .47849 L .52561 .49762 L F
.54059 .50245 m .55706 .48575 L .53457 .47849 L F
.28404 .48826 m .30851 .47459 L .28108 .48325 L F
.28404 .48826 m .31442 .48463 L .30851 .47459 L F
.73631 .7464 m .72748 .73716 L .71949 .74115 L .683 .771 .917 r
F
.74091 .74504 m .72748 .73716 L .73631 .7464 L F
.38844 .48818 m .38889 .4809 L .41336 .48011 L .667 .431 .554 r
F
.36412 .48483 m .38889 .4809 L .38844 .48818 L .732 .488 .558 r
F
.36412 .48483 m .36457 .47755 L .38889 .4809 L F
.79443 .73161 m .79391 .72704 L .78538 .72052 L .934 .647 .473 r
F
0 g
.79391 .72704 m
.79905 .73488 L
s
.77148 .72927 m .77388 .71592 L .76395 .72612 L .683 .771 .917 r
F
.77148 .72927 m .78517 .72065 L .77388 .71592 L F
.75063 .74452 m .74646 .73315 L .74579 .7444 L F
.75063 .74452 m .75614 .7334 L .74646 .73315 L F
.24844 .49643 m .24203 .49517 L .24741 .49729 L .675 .735 .895 r
F
.38965 .46044 m .3889 .48059 L .41325 .47981 L .654 .726 .902 r
F
.37351 .45822 m .3889 .48059 L .38965 .46044 L F
.37351 .45822 m .3647 .47727 L .3889 .48059 L F
0 g
.36457 .47755 m
.38889 .4809 L
s
.5712 .84843 m .56262 .84254 L .5585 .84545 L .645 .732 .913 r
F
.57385 .84737 m .56262 .84254 L .5712 .84843 L F
.71898 .73658 m .69679 .7368 L .71274 .74156 L .683 .771 .917 r
F
.58888 .84947 m .59291 .8419 L .58635 .84811 L .645 .732 .913 r
F
.58888 .84947 m .59798 .84462 L .59291 .8419 L F
.5686 .8574 m .55522 .85648 L .56726 .85916 L .644 .733 .913 r
F
.37444 .73343 m .3653 .72234 L .36579 .72691 L .932 .647 .478 r
F
.37492 .738 m .37444 .73343 L .36579 .72691 L F
0 g
.37444 .73343 m
.37972 .74127 L
s
.56885 .85363 m .55814 .84918 L .55546 .85271 L .644 .733 .913 r
F
.57092 .85217 m .55814 .84918 L .56885 .85363 L F
.59153 .86059 m .60142 .8555 L .59036 .85868 L F
.59153 .86059 m .60376 .85933 L .60142 .8555 L F
.50982 .48831 m .51066 .46817 L .48629 .46896 L .654 .726 .902 r
F
.5906 .85491 m .59782 .84834 L .58868 .85321 L .644 .733 .913 r
F
.5906 .85491 m .60167 .85173 L .59782 .84834 L F
.55814 .84918 m .54342 .85002 L .55546 .85271 L F
.35214 .73558 m .35433 .72217 L .34451 .73242 L .683 .77 .917 r
F
.35214 .73558 m .36579 .72691 L .35433 .72217 L F
.74091 .74504 m .73668 .73443 L .72748 .73716 L .683 .771 .917 r
F
.74579 .7444 m .73668 .73443 L .74091 .74504 L F
.5585 .84545 m .54785 .84102 L .54385 .84629 L .645 .732 .913 r
F
.54744 .84472 m .54367 .84625 L .54342 .85002 L .086 0 .408 r
F
.54744 .84472 m .54769 .84095 L .54367 .84625 L F
0 g
.54211 .8521 m
.54367 .84625 L
s
.604 .85556 m .61273 .84855 L .60167 .85173 L .644 .733 .913 r
F
.604 .85556 m .61623 .8543 L .61273 .84855 L F
.74579 .7444 m .74646 .73315 L .73668 .73443 L .683 .771 .917 r
F
.53063 .60563 m .55668 .60123 L .53167 .60169 L .673 .757 .914 r
F
.29943 .74297 m .27721 .74319 L .29326 .74795 L .683 .77 .917 r
F
.71325 .74613 m .6973 .74137 L .6912 .74981 L .683 .771 .917 r
F
0 g
.68879 .75864 m
.6912 .74981 L
s
.19777 .61029 m .21284 .6116 L .21313 .61728 L .859 .596 .541 r
F
.19777 .61029 m .19748 .60462 L .21284 .6116 L F
.21567 .5935 m .21284 .6116 L .22591 .59816 L .673 .757 .914 r
F
.21567 .5935 m .19748 .60462 L .21284 .6116 L F
0 g
.21284 .6116 m
.21757 .61272 L
s
.28856 .6159 m .30417 .60267 L .30447 .60835 L .515 .329 .567 r
F
.27651 .60292 m .28856 .6159 L .30447 .60835 L .673 .757 .914 r
F
.26425 .60619 m .28856 .6159 L .27651 .60292 L F
0 g
.27019 .6208 m
.28856 .6159 L
s
.24844 .49643 m .24409 .49345 L .24203 .49517 L .675 .735 .895 r
F
.24976 .49578 m .24409 .49345 L .24844 .49643 L F
.61623 .8543 m .61647 .85053 L .61297 .84479 L .99 .751 .475 r
F
0 g
.61647 .85053 m
.61747 .85653 L
s
.32449 .84741 m .32475 .84364 L .33454 .84343 L .67 .443 .568 r
F
.127 .923 .03 r
.32172 .90284 m
.35394 4.38678 L
s
.31476 .84606 m .32475 .84364 L .32449 .84741 L .733 .498 .572 r
F
.127 .923 .03 r
.32375 .88834 m
.32385 .89315 L
s
.3217 .90066 m
.32172 .90284 L
s
.31476 .84606 m .31503 .84229 L .32475 .84364 L .733 .498 .572 r
F
.29861 .7339 m .2857 .72669 L .2765 .73412 L .683 .77 .917 r
F
.30651 .72993 m .2857 .72669 L .29861 .7339 L F
.32504 .83593 m .32476 .84353 L .33449 .84332 L .644 .733 .913 r
F
.31859 .83503 m .32476 .84353 L .32504 .83593 L F
.31859 .83503 m .31508 .84218 L .32476 .84353 L F
.55547 .6205 m .58272 .61212 L .55758 .61258 L .673 .758 .914 r
F
.53139 .617 m .55547 .6205 L .55758 .61258 L F
.5287 .62072 m .55547 .6205 L .53139 .617 L F
.45701 .61441 m .4339 .62667 L .45836 .62228 L F
.45701 .61441 m .43187 .61487 L .4339 .62667 L F
0 g
.4339 .62667 m
.44093 .63755 L
s
.57385 .84737 m .56791 .84043 L .56262 .84254 L .645 .732 .913 r
F
.5769 .84679 m .56791 .84043 L .57385 .84737 L F
.24976 .49578 m .24673 .49213 L .24409 .49345 L .675 .735 .895 r
F
.25129 .49537 m .24673 .49213 L .24976 .49578 L F
.58635 .84811 m .58695 .84003 L .58337 .84717 L .645 .732 .913 r
F
.58635 .84811 m .59291 .8419 L .58695 .84003 L F
.30576 .84324 m .31503 .84229 L .31476 .84606 L .793 .551 .572 r
F
.30576 .84324 m .30602 .83947 L .31503 .84229 L F
0 g
.31503 .84229 m
.32475 .84364 L
s
.34482 .47119 m
.34712 .47193 L
s
.34326 .47069 m
.34482 .47119 L
s
.33427 .8472 m .33454 .84343 L .34371 .84168 L .597 .381 .558 r
F
.32449 .84741 m .33454 .84343 L .33427 .8472 L .67 .443 .568 r
F
0 g
.32475 .84364 m
.33454 .84343 L
s
.31261 .83316 m .31508 .84218 L .31859 .83503 L .644 .733 .913 r
F
.31261 .83316 m .30612 .83937 L .31508 .84218 L F
.48184 .60828 m .45805 .6166 L .48251 .61221 L .673 .757 .914 r
F
.48184 .60828 m .4567 .60874 L .45805 .6166 L F
.41292 .48738 m .41336 .48011 L .43633 .47523 L .592 .367 .545 r
F
.38844 .48818 m .41336 .48011 L .41292 .48738 L .667 .431 .554 r
F
0 g
.38889 .4809 m
.41336 .48011 L
s
.33153 .83579 m .33449 .84332 L .34362 .84158 L .644 .733 .913 r
F
.32504 .83593 m .33449 .84332 L .33153 .83579 L F
.19238 .4928 m .1585 .50152 L .18992 .50316 L .654 .726 .902 r
F
.19238 .4928 m .16217 .48598 L .1585 .50152 L F
0 g
.1585 .50152 m
.16125 .51738 L
s
.79443 .73161 m .78538 .72052 L .78589 .72509 L .934 .647 .473 r
F
.79494 .73618 m .79443 .73161 L .78589 .72509 L F
0 g
.79443 .73161 m
.79956 .73945 L
s
.35857 .4534 m .3647 .47727 L .37351 .45822 L .654 .726 .902 r
F
0 g
.36204 .47674 m
.36457 .47755 L
s
.57092 .85217 m .56228 .84625 L .55814 .84918 L .644 .733 .913 r
F
.57358 .85111 m .56228 .84625 L .57092 .85217 L F
.22257 .49963 m .18992 .50316 L .22133 .50481 L .654 .726 .902 r
F
.22257 .49963 m .19238 .4928 L .18992 .50316 L F
.58868 .85321 m .59274 .8456 L .58614 .85184 L .644 .733 .913 r
F
.58868 .85321 m .59782 .84834 L .59274 .8456 L F
.77213 .73376 m .77454 .72034 L .76456 .73059 L .683 .771 .917 r
F
.77213 .73376 m .78589 .72509 L .77454 .72034 L F
.4059 .45992 m .41325 .47981 L .4361 .47495 L .654 .726 .902 r
F
.38965 .46044 m .41325 .47981 L .4059 .45992 L F
.64582 .47646 m .62105 .4902 L .64873 .4815 L F
.64582 .47646 m .61522 .48011 L .62105 .4902 L F
.24673 .49213 m .23973 .49046 L .24409 .49345 L .675 .735 .895 r
F
.24673 .49213 m .24371 .48849 L .23973 .49046 L F
.2498 .49131 m .24371 .48849 L .24673 .49213 L F
.25275 .50645 m .24525 .48648 L .2376 .48811 L .654 .726 .902 r
F
.25275 .50645 m .25341 .48622 L .24525 .48648 L F
.25275 .50645 m .26153 .48733 L .25341 .48622 L F
.5769 .84679 m .57401 .83926 L .56791 .84043 L .645 .732 .913 r
F
.58015 .84672 m .57401 .83926 L .5769 .84679 L F
.5686 .8574 m .5579 .85294 L .55522 .85648 L .644 .733 .913 r
F
.57067 .85594 m .5579 .85294 L .5686 .8574 L F
.58337 .84717 m .58051 .83913 L .58015 .84672 L .645 .732 .913 r
F
.58337 .84717 m .58695 .84003 L .58051 .83913 L F
.28417 .50809 m .31381 .49916 L .28328 .50281 L .654 .726 .902 r
F
.28417 .50809 m .31559 .50974 L .31381 .49916 L F
.59036 .85868 m .59758 .85211 L .58844 .85698 L .644 .733 .913 r
F
.59036 .85868 m .60142 .8555 L .59758 .85211 L F
.5579 .85294 m .54317 .85379 L .55522 .85648 L F
.71949 .74115 m .6973 .74137 L .71325 .74613 L .683 .771 .917 r
F
.31559 .50974 m .34436 .49551 L .31381 .49916 L .654 .726 .902 r
F
.31559 .50974 m .34701 .51138 L .34436 .49551 L F
.56262 .84254 m .54785 .84102 L .5585 .84545 L .645 .732 .913 r
F
.72989 .49589 m .76674 .49329 L .73665 .48646 L .654 .726 .902 r
F
.70317 .48435 m .72989 .49589 L .73665 .48646 L F
.69797 .48828 m .72989 .49589 L .70317 .48435 L F
.30417 .60267 m .30388 .597 L .31625 .58729 L .386 .233 .548 r
F
0 g
.29548 .60098 m
.30388 .597 L
s
.34701 .51138 m .34481 .48823 L .34436 .49551 L .925 .744 .259 r
F
0 g
.34618 .48647 m
.34791 .49682 L
s
.34323 .5269 m
.34701 .51138 L
s
.54719 .84849 m .54342 .85002 L .54317 .85379 L .086 0 .408 r
F
.55814 .84918 m .54744 .84472 L .54342 .85002 L .644 .733 .913 r
F
.54719 .84849 m .54744 .84472 L .54342 .85002 L .086 0 .408 r
F
0 g
.54186 .85587 m
.54342 .85002 L
s
.34393 .72795 m .34031 .71511 L .335 .72619 L .683 .77 .917 r
F
.34393 .72795 m .3537 .71775 L .34031 .71511 L F
.60376 .85933 m .61249 .85232 L .60142 .8555 L .644 .733 .913 r
F
.60376 .85933 m .61599 .85807 L .61249 .85232 L F
.58015 .84672 m .58051 .83913 L .57401 .83926 L .645 .732 .913 r
F
.58211 .46787 m .58504 .47648 L .58463 .48376 L .917 .738 .246 r
F
.58211 .46787 m .58253 .46059 L .58504 .47648 L F
0 g
.58504 .47648 m
.58896 .48324 L
s
.37492 .738 m .36579 .72691 L .36627 .73149 L .932 .647 .478 r
F
0 g
.37492 .738 m
.3802 .74584 L
s
.127 .923 .03 r
.72294 2.10999 m
.78031 .90222 L
s
.78031 .90222 m
.78115 .88453 L
s
.78115 .88453 m
.78309 .84383 L
s
.74771 1.86283 m
.78262 .89907 L
s
.78262 .89907 m
.78349 .87507 L
s
.7318 2.30207 m
.74771 1.86283 L
s
.78349 .87507 m
.78465 .8433 L
s
.6018 .84799 m .60708 .83976 L .59798 .84462 L .645 .732 .913 r
F
.6018 .84799 m .61281 .84483 L .60708 .83976 L F
.61428 .46225 m .5855 .47643 L .61594 .47279 L .654 .726 .902 r
F
.61428 .46225 m .583 .46061 L .5855 .47643 L F
.28635 .58642 m .30362 .59684 L .31593 .58719 L .673 .757 .914 r
F
.2758 .59144 m .30362 .59684 L .28635 .58642 L F
.35262 .74015 m .35481 .72674 L .34499 .73699 L .683 .77 .917 r
F
.35262 .74015 m .36627 .73149 L .35481 .72674 L F
.7186 .73208 m .70583 .72486 L .69652 .7323 L .683 .771 .917 r
F
.72655 .72811 m .70583 .72486 L .7186 .73208 L F
.61623 .8543 m .61297 .84479 L .61273 .84855 L .99 .751 .475 r
F
.61599 .85807 m .61623 .8543 L .61273 .84855 L F
0 g
.61623 .8543 m
.61722 .86029 L
s
.32423 .85118 m .32449 .84741 L .33427 .8472 L .67 .443 .568 r
F
.3145 .84983 m .32449 .84741 L .32423 .85118 L .733 .498 .572 r
F
.127 .923 .03 r
.3212 .84737 m
.32121 .8482 L
s
.32285 .84718 m
.32287 .8478 L
s
.3145 .84983 m .31476 .84606 L .32449 .84741 L .733 .498 .572 r
F
.32478 .83978 m .32449 .84741 L .33427 .8472 L .644 .733 .913 r
F
.31829 .83887 m .32449 .84741 L .32478 .83978 L F
.31829 .83887 m .31476 .84606 L .32449 .84741 L F
.46276 .48082 m .44328 .48217 L .44285 .48944 L .492 .285 .526 r
F
.46276 .48082 m .46319 .47354 L .44328 .48217 L F
0 g
.42782 .49395 m
.44328 .48217 L
s
0 0 0 r
2.5 Mabswid
.44973 .62429 Mdot
.127 .923 .03 r
.5 Mabswid
.44779 .92819 m
.44973 .62429 L
s
.39746 8.82576 m
.44779 .92819 L
s
.58239 .60644 m .58207 .60077 L .5801 .58896 L .825 .622 .07 r
F
0 g
.58054 .60648 m
.58179 .60182 L
s
.76674 .49329 m .76714 .48601 L .77115 .47046 L 0 0 .159 r
F
0 g
.76259 .49234 m
.76714 .48601 L
s
.55668 .60123 m .58169 .60078 L .57974 .58903 L .673 .757 .914 r
F
.73675 .47911 m .76668 .48591 L .77068 .47043 L .654 .726 .902 r
F
.127 .923 .03 r
.39967 8.82518 m
.51301 3.25714 L
s
.57617 .49642 m .57658 .48914 L .55748 .47847 L .858 .601 .549 r
F
0 g
.57658 .48914 m
.59066 .50217 L
s
.47733 .50644 m .46232 .4881 L .44241 .49673 L .654 .726 .902 r
F
.49265 .50319 m .46232 .4881 L .47733 .50644 L F
.49308 .49591 m .48575 .47594 L .46276 .48082 L F
.5094 .49539 m .48575 .47594 L .49308 .49591 L F
.22633 .48763 m .19285 .48552 L .22304 .49235 L F
.29896 .7384 m .28598 .73115 L .27673 .73862 L .683 .77 .917 r
F
.3069 .73441 m .28598 .73115 L .29896 .7384 L F
.52561 .49762 m .51025 .47514 L .5094 .49539 L .654 .726 .902 r
F
.52561 .49762 m .53457 .47849 L .51025 .47514 L F
.57358 .85111 m .5676 .84413 L .56228 .84625 L .644 .733 .913 r
F
.57664 .85052 m .5676 .84413 L .57358 .85111 L F
.28598 .73115 m .27626 .73405 L .27673 .73862 L .402 .257 .568 r
F
.28598 .73115 m .28551 .72658 L .27626 .73405 L F
0 g
.2703 .74249 m
.27626 .73405 L
s
.72583 .84142 m .73503 .84047 L .7348 .84424 L .793 .551 .571 r
F
.72583 .84142 m .72606 .83765 L .73503 .84047 L F
0 g
.73503 .84047 m
.7366 .84069 L
s
.54017 .50973 m .53415 .48577 L .52518 .5049 L .654 .726 .902 r
F
.54017 .50973 m .55664 .49303 L .53415 .48577 L F
.58614 .85184 m .58675 .84372 L .58314 .8509 L .644 .733 .913 r
F
.58614 .85184 m .59274 .8456 L .58675 .84372 L F
.53107 .61133 m .55726 .6069 L .53212 .60736 L .673 .757 .914 r
F
.75431 .84539 m .75454 .84162 L .76375 .83986 L .598 .382 .559 r
F
0 g
.7529 .84165 m
.75454 .84162 L
s
.28374 .49552 m .30833 .48178 L .28076 .49048 L .654 .726 .902 r
F
.28374 .49552 m .31427 .49188 L .30833 .48178 L F
.127 .923 .03 r
.52635 .47033 m
.52672 .4466 L
s
.73276 .83134 m .73508 .84036 L .73871 .83322 L .645 .732 .913 r
F
.73276 .83134 m .72616 .83756 L .73508 .84036 L F
.75166 .83398 m .7545 .8415 L .76367 .83976 L F
.127 .923 .03 r
.79915 .78596 m
.80044 .75979 L
s
.74516 .83411 m .7545 .8415 L .75166 .83398 L .645 .732 .913 r
F
.3055 .84701 m .31476 .84606 L .3145 .84983 L .793 .551 .572 r
F
.3055 .84701 m .30576 .84324 L .31476 .84606 L F
.31229 .83699 m .31476 .84606 L .31829 .83887 L .644 .733 .913 r
F
.31229 .83699 m .30576 .84324 L .31476 .84606 L F
0 g
.31476 .84606 m
.32449 .84741 L
s
.127 .923 .03 r
.28433 .76511 m
.28438 .76869 L
s
.21596 .59917 m .21313 .61728 L .2262 .60384 L .673 .757 .914 r
F
.21596 .59917 m .19777 .61029 L .21313 .61728 L F
0 g
.21313 .61728 m
.23115 .62152 L
s
.33427 .8472 m .34371 .84168 L .34345 .84545 L .597 .381 .558 r
F
.33401 .85097 m .33427 .8472 L .34345 .84545 L F
.32423 .85118 m .33427 .8472 L .33401 .85097 L .67 .443 .568 r
F
.3313 .83964 m .33427 .8472 L .34345 .84545 L .644 .733 .913 r
F
.32478 .83978 m .33427 .8472 L .3313 .83964 L F
0 g
.32449 .84741 m
.33427 .8472 L
s
.388 .49545 m .38844 .48818 L .41292 .48738 L .667 .431 .554 r
F
.36367 .49211 m .38844 .48818 L .388 .49545 L .732 .488 .558 r
F
.36367 .49211 m .36412 .48483 L .38844 .48818 L F
.3892 .46793 m .38844 .48818 L .41292 .48738 L .654 .726 .902 r
F
.37297 .46569 m .38844 .48818 L .3892 .46793 L F
.37297 .46569 m .36412 .48483 L .38844 .48818 L F
.55668 .60123 m .57974 .58903 L .55537 .5934 L .673 .757 .914 r
F
.53167 .60169 m .55668 .60123 L .55537 .5934 L F
.57067 .85594 m .56204 .85002 L .5579 .85294 L .644 .733 .913 r
F
.127 .923 .03 r
.56438 .73356 m
.56446 .72997 L
s
.57333 .85488 m .56204 .85002 L .57067 .85594 L .644 .733 .913 r
F
.58844 .85698 m .59249 .84937 L .58589 .85561 L F
.58844 .85698 m .59758 .85211 L .59249 .84937 L F
.22694 .48041 m .20017 .46892 L .19363 .47831 L .654 .726 .902 r
F
.23204 .4765 m .20017 .46892 L .22694 .48041 L F
.29809 .83914 m .30602 .83947 L .30576 .84324 L .855 .609 .566 r
F
.29809 .83914 m .29835 .83537 L .30602 .83947 L F
0 g
.30602 .83947 m
.30879 .84033 L
s
.57664 .85052 m .57374 .84296 L .5676 .84413 L .644 .733 .913 r
F
.57991 .85045 m .57374 .84296 L .57664 .85052 L F
.28108 .48325 m .29885 .46572 L .27626 .47881 L .654 .726 .902 r
F
.28108 .48325 m .30851 .47459 L .29885 .46572 L F
.76395 .72612 m .76054 .71328 L .75506 .72437 L .683 .771 .917 r
F
.76395 .72612 m .77388 .71592 L .76054 .71328 L F
.58314 .8509 m .58027 .84282 L .57991 .85045 L .644 .733 .913 r
F
.58314 .8509 m .58675 .84372 L .58027 .84282 L F
.30752 .83044 m .30612 .83937 L .31261 .83316 L F
.30752 .83044 m .29849 .8353 L .30612 .83937 L F
.79494 .73618 m .78589 .72509 L .78641 .72966 L .934 .647 .473 r
F
0 g
.79494 .73618 m
.80008 .74402 L
s
.34345 .84545 m .34371 .84168 L .35166 .8385 L .5 .299 .539 r
F
0 g
.33789 .84279 m
.34371 .84168 L
s
.127 .923 .03 r
.34837 .91079 m
.37559 2.35367 L
s
.34584 .77704 m
.34704 .84035 L
s
.34577 .90425 m
.39548 8.82698 L
s
.34498 .77739 m
.34538 .84101 L
s
.20017 .46892 m .16358 .47152 L .19363 .47831 L .654 .726 .902 r
F
.77264 .73833 m .77505 .72491 L .76507 .73516 L .683 .771 .917 r
F
.77264 .73833 m .78641 .72966 L .77505 .72491 L F
.33762 .83463 m .34362 .84158 L .35153 .83841 L .644 .733 .913 r
F
.33153 .83579 m .34362 .84158 L .33762 .83463 L F
.56228 .84625 m .54744 .84472 L .55814 .84918 L F
.5579 .85294 m .54719 .84849 L .54317 .85379 L F
0 g
.54162 .85964 m
.54317 .85379 L
s
.57991 .85045 m .58027 .84282 L .57374 .84296 L .644 .733 .913 r
F
.30651 .72993 m .29755 .72073 L .2857 .72669 L .683 .77 .917 r
F
.31563 .72722 m .29755 .72073 L .30651 .72993 L F
.60167 .85173 m .60697 .84346 L .59782 .84834 L .644 .733 .913 r
F
.60167 .85173 m .61273 .84855 L .60697 .84346 L F
.5094 .49539 m .51025 .47514 L .48575 .47594 L .654 .726 .902 r
F
.48216 .61396 m .45836 .62228 L .48283 .61789 L .673 .758 .914 r
F
.48216 .61396 m .45701 .61441 L .45836 .62228 L F
.61599 .85807 m .61273 .84855 L .61249 .85232 L .99 .751 .475 r
F
0 g
.61599 .85807 m
.61698 .86406 L
s
.32451 .84355 m .32423 .85118 L .33401 .85097 L .644 .733 .913 r
F
.31803 .84264 m .32423 .85118 L .32451 .84355 L F
.127 .923 .03 r
.2513 .80634 m
.25136 .8099 L
s
.323 .85392 m
.32375 .88834 L
s
.32294 .851 m
.323 .85392 L
s
.32124 .85076 m
.32127 .85443 L
s
.31803 .84264 m .3145 .84983 L .32423 .85118 L .644 .733 .913 r
F
.34451 .73242 m .34087 .71951 L .33553 .73065 L .683 .77 .917 r
F
.34451 .73242 m .35433 .72217 L .34087 .71951 L F
.53167 .60169 m .55537 .5934 L .53102 .59777 L .673 .757 .914 r
F
.71898 .73658 m .70615 .72933 L .69679 .7368 L .683 .771 .917 r
F
.72697 .73259 m .70615 .72933 L .71898 .73658 L F
.70615 .72933 m .69628 .73223 L .69679 .7368 L .407 .262 .571 r
F
.70615 .72933 m .70564 .72475 L .69628 .73223 L F
0 g
.69019 .74067 m
.69628 .73223 L
s
.57333 .85488 m .56736 .8479 L .56204 .85002 L .644 .733 .913 r
F
.5764 .85429 m .56736 .8479 L .57333 .85488 L F
.30417 .60267 m .31625 .58729 L .31655 .59297 L .386 .233 .548 r
F
.30447 .60835 m .30417 .60267 L .31655 .59297 L F
.28682 .5922 m .30417 .60267 L .31655 .59297 L .673 .757 .914 r
F
.27621 .59724 m .30417 .60267 L .28682 .5922 L F
0 g
.29578 .60666 m
.30417 .60267 L
s
.72559 .84519 m .7348 .84424 L .73456 .84801 L .793 .551 .571 r
F
.72559 .84519 m .72583 .84142 L .7348 .84424 L F
.73246 .83518 m .7348 .84424 L .73844 .83706 L .645 .732 .913 r
F
.73246 .83518 m .72583 .84142 L .7348 .84424 L F
0 g
.7348 .84424 m
.73636 .84446 L
s
.58589 .85561 m .5865 .84749 L .5829 .85467 L .644 .733 .913 r
F
.58589 .85561 m .59249 .84937 L .5865 .84749 L F
.75431 .84539 m .76375 .83986 L .76352 .84363 L .598 .382 .559 r
F
.75407 .84916 m .75431 .84539 L .76352 .84363 L F
.75145 .83782 m .75431 .84539 L .76352 .84363 L .645 .732 .913 r
F
0 g
.75267 .84542 m
.75431 .84539 L
s
.127 .923 .03 r
.79898 .78952 m
.79915 .78596 L
s
.335 .72619 m .32582 .71473 L .32535 .72594 L .683 .77 .917 r
F
.335 .72619 m .34031 .71511 L .32582 .71473 L F
.127 .923 .03 r
.33269 .65916 m
.33382 .71494 L
s
.33269 .65916 m
.33311 .71492 L
s
.31202 .84076 m .3145 .84983 L .31803 .84264 L .644 .733 .913 r
F
.31202 .84076 m .3055 .84701 L .3145 .84983 L F
0 g
.3145 .84983 m
.32423 .85118 L
s
.127 .923 .03 r
.28438 .76869 m
.28443 .77227 L
s
.29943 .74297 m .28646 .73572 L .27721 .74319 L .683 .77 .917 r
F
.30737 .73898 m .28646 .73572 L .29943 .74297 L F
.28646 .73572 m .27673 .73862 L .27721 .74319 L .402 .257 .568 r
F
0 g
.27124 .75163 m
.27721 .74319 L
s
.28646 .73572 m .28598 .73115 L .27673 .73862 L .402 .257 .568 r
F
0 g
.27077 .74706 m
.27673 .73862 L
s
.127 .923 .03 r
.28354 .70687 m
.28433 .76511 L
s
.33401 .85097 m .34345 .84545 L .34319 .84922 L .597 .381 .558 r
F
.33104 .84341 m .33401 .85097 L .34319 .84922 L .644 .733 .913 r
F
.32451 .84355 m .33401 .85097 L .33104 .84341 L F
0 g
.32423 .85118 m
.33401 .85097 L
s
.50666 .60215 m .49479 .58922 L .48949 .59173 L .673 .757 .914 r
F
.50666 .60215 m .5009 .58759 L .49479 .58922 L F
.50666 .60215 m .51385 .58735 L .5074 .58695 L F
0 g
.34508 .4787 m
.34667 .47921 L
s
.35795 .46085 m .36412 .48483 L .37297 .46569 L .654 .726 .902 r
F
0 g
.36159 .48401 m
.36412 .48483 L
s
.36412 .48483 m
.38844 .48818 L
s
.71821 .83732 m .72606 .83765 L .72583 .84142 L .856 .609 .564 r
F
.127 .923 .03 r
.70591 1.46137 m
.71942 .98965 L
s
.72378 .83755 m
.72519 .78806 L
s
.69471 1.52981 m
.71503 1.02215 L
s
.72242 .8375 m
.72411 .79519 L
s
.71821 .83732 m .71845 .83355 L .72606 .83765 L .856 .609 .564 r
F
0 g
.72606 .83765 m
.72889 .83854 L
s
.58239 .60644 m .5801 .58896 L .58043 .59464 L .825 .622 .07 r
F
.55726 .6069 m .58239 .60644 L .58043 .59464 L .673 .757 .914 r
F
.58272 .61212 m .58239 .60644 L .58043 .59464 L .825 .622 .07 r
F
0 g
.58087 .61215 m
.58211 .60749 L
s
.56262 .84254 m .55403 .83665 L .54785 .84102 L .645 .732 .913 r
F
.56791 .84043 m .55403 .83665 L .56262 .84254 L F
.127 .923 .03 r
.56107 .83857 m
.56226 .77939 L
s
.56258 .83898 m
.56309 .77905 L
s
.72771 .82862 m .71858 .83348 L .72616 .83756 L .645 .732 .913 r
F
.41292 .48738 m .43633 .47523 L .43589 .48251 L .592 .367 .545 r
F
.41248 .49466 m .41292 .48738 L .43589 .48251 L F
.388 .49545 m .41292 .48738 L .41248 .49466 L .667 .431 .554 r
F
.40553 .4674 m .41292 .48738 L .43589 .48251 L .654 .726 .902 r
F
.3892 .46793 m .41292 .48738 L .40553 .4674 L F
0 g
.38844 .48818 m
.41292 .48738 L
s
.76352 .84363 m .76375 .83986 L .77176 .83668 L .502 .302 .541 r
F
0 g
.75798 .84096 m
.76375 .83986 L
s
.59798 .84462 m .59948 .83568 L .59291 .8419 L .645 .732 .913 r
F
.59798 .84462 m .60708 .83976 L .59948 .83568 L F
.29782 .84291 m .30576 .84324 L .3055 .84701 L .855 .609 .566 r
F
.29782 .84291 m .29809 .83914 L .30576 .84324 L F
.30717 .83426 m .30576 .84324 L .31229 .83699 L .644 .733 .913 r
F
.30717 .83426 m .29809 .83914 L .30576 .84324 L F
0 g
.30576 .84324 m
.30853 .8441 L
s
.75777 .83281 m .76367 .83976 L .77163 .83659 L .645 .732 .913 r
F
.75166 .83398 m .76367 .83976 L .75777 .83281 L F
.5764 .85429 m .57349 .84673 L .56736 .8479 L .644 .733 .913 r
F
.57966 .85422 m .57349 .84673 L .5764 .85429 L F
.5829 .85467 m .58002 .84659 L .57966 .85422 L F
.5829 .85467 m .5865 .84749 L .58002 .84659 L F
.34345 .84545 m .35166 .8385 L .3514 .84227 L .5 .299 .539 r
F
.34319 .84922 m .34345 .84545 L .3514 .84227 L F
.33742 .83847 m .34345 .84545 L .3514 .84227 L .644 .733 .913 r
F
.3313 .83964 m .34345 .84545 L .33742 .83847 L F
0 g
.33763 .84656 m
.34345 .84545 L
s
.72655 .72811 m .71776 .7189 L .70583 .72486 L .683 .771 .917 r
F
.7357 .72539 m .71776 .7189 L .72655 .72811 L F
.64541 .48374 m .62064 .49748 L .64832 .48878 L .654 .726 .902 r
F
.64541 .48374 m .6148 .48739 L .62064 .49748 L F
.53139 .617 m .55758 .61258 L .53244 .61304 L .673 .758 .914 r
F
.56204 .85002 m .54719 .84849 L .5579 .85294 L .644 .733 .913 r
F
.36579 .72691 m .3653 .72234 L .35385 .7176 L .859 .591 .532 r
F
0 g
.3653 .72234 m
.37396 .72886 L
s
.57966 .85422 m .58002 .84659 L .57349 .84673 L .644 .733 .913 r
F
.18584 .59535 m .1972 .59894 L .19748 .60462 L .93 .657 .499 r
F
.127 .923 .03 r
.19203 .62902 m
.19345 .68683 L
s
.18584 .59535 m .18555 .58967 L .1972 .59894 L .93 .657 .499 r
F
0 g
.1972 .59894 m
.20268 .60144 L
s
.60142 .8555 m .60673 .84723 L .59758 .85211 L .644 .733 .913 r
F
.60142 .8555 m .61249 .85232 L .60673 .84723 L F
.72949 .50317 m .76635 .50057 L .73626 .49374 L .654 .726 .902 r
F
.70277 .49163 m .72949 .50317 L .73626 .49374 L F
.69757 .49556 m .72949 .50317 L .70277 .49163 L F
.31563 .72722 m .31124 .71665 L .29755 .72073 L .683 .77 .917 r
F
.32535 .72594 m .31124 .71665 L .31563 .72722 L F
.76456 .73059 m .76114 .71769 L .75563 .72882 L .683 .771 .917 r
F
.76456 .73059 m .77454 .72034 L .76114 .71769 L F
.55365 .84033 m .54769 .84095 L .54744 .84472 L .354 .18 .502 r
F
.55365 .84033 m .5539 .83656 L .54769 .84095 L F
0 g
.54367 .84625 m
.54769 .84095 L
s
.20784 .58156 m .19747 .59877 L .21556 .58771 L .673 .757 .914 r
F
.20784 .58156 m .18588 .58955 L .19747 .59877 L F
.127 .923 .03 r
.18968 .53269 m
.19172 .58743 L
s
.18968 .53269 m
.19102 .58768 L
s
.58169 .47515 m .58463 .48376 L .58421 .49104 L .917 .738 .246 r
F
.58169 .47515 m .58211 .46787 L .58463 .48376 L F
.61355 .46951 m .58463 .48376 L .61522 .48011 L .654 .726 .902 r
F
.61355 .46951 m .58211 .46787 L .58463 .48376 L F
0 g
.58463 .48376 m
.58854 .49052 L
s
.2536 .58346 m .25175 .59585 L .26361 .59469 L .673 .757 .914 r
F
.25404 .58049 m .26361 .59469 L .2577 .58013 L F
.2512 .58077 m .2536 .58346 L .25404 .58049 L F
.2536 .58346 m .26361 .59469 L .25404 .58049 L F
.25624 .53855 m .25635 .53773 L .2562 .566 L 0 0 .125 r
F
.25149 .58652 m .2509 .60179 L .26396 .60051 L .673 .757 .914 r
F
.2512 .58077 m .25175 .59585 L .2536 .58346 L F
.25149 .58652 m .26396 .60051 L .25802 .58588 L F
.25093 .54018 m .2525 .54044 L .25235 .56858 L .751 .491 .539 r
F
.25178 .5922 m .2512 .60747 L .26425 .60619 L .673 .757 .914 r
F
.25178 .5922 m .26425 .60619 L .25832 .59156 L F
.25511 .5398 m .25529 .56766 L .25496 .56791 L .353 .175 .495 r
F
.25409 .54024 m .25443 .56814 L .25394 .56834 L .515 .301 .526 r
F
.2525 .54044 m .25311 .56847 L .25235 .56858 L .641 .401 .539 r
F
.25817 .56771 m .26908 .57599 L .27318 .57277 L .673 .757 .914 r
F
.25409 .54024 m .25511 .5398 L .25496 .56791 L .515 .301 .526 r
F
.2537 .57027 m .2512 .58077 L .2577 .58013 L .673 .757 .914 r
F
.25327 .56921 m .25286 .57151 L .2537 .57027 L F
.25286 .57151 m .2512 .58077 L .2537 .57027 L F
.2577 .58013 m .2758 .59144 L .2638 .5785 L F
.25337 .57442 m .25378 .57543 L .25434 .57368 L F
.25378 .57543 m .25802 .58588 L .25454 .57431 L F
.25378 .57543 m .25454 .57431 L .25434 .57368 L F
.25474 .56874 m .26069 .57516 L .25541 .56774 L F
.26069 .57516 m .2638 .5785 L .25985 .57344 L F
.26069 .57516 m .25985 .57344 L .25541 .56774 L F
.25581 .53923 m .25624 .53855 L .25609 .56674 L .065 0 .408 r
F
.25635 .53773 m .25589 .53668 L .25574 .56507 L .986 .729 .348 r
F
.25438 .56835 m .2577 .58013 L .2638 .5785 L .673 .757 .914 r
F
.2525 .54044 m .25394 .56834 L .25311 .56847 L .641 .401 .539 r
F
.25179 .56556 m .25327 .56921 L .25438 .56835 L .673 .757 .914 r
F
.25327 .56921 m .2577 .58013 L .25438 .56835 L F
.25511 .5398 m .25581 .53923 L .25566 .56738 L .353 .175 .495 r
F
.25555 .56746 m .25566 .56738 L .25563 .57269 L F
.25511 .5398 m .25566 .56738 L .25555 .56746 L F
.25337 .57442 m .25149 .58652 L .25802 .58588 L .673 .757 .914 r
F
.2547 .57406 m .25562 .57505 L .2553 .57318 L F
.25562 .57505 m .26415 .58425 L .2558 .5738 L F
.25562 .57505 m .2558 .5738 L .2553 .57318 L F
.25259 .57917 m .25178 .5922 L .25385 .592 L F
.25229 .57922 m .25377 .59902 L .25218 .59922 L .641 .401 .539 r
F
.2531 .57463 m .25149 .58652 L .25337 .57442 L .673 .757 .914 r
F
.25311 .57378 m .25195 .57448 L .25319 .57396 L F
.25295 .56945 m .2512 .58077 L .25327 .56921 L F
.25304 .56872 m .2512 .58077 L .25307 .56871 L F
.25295 .56865 m .2512 .58077 L .25305 .56866 L F
.25167 .56868 m .2512 .58077 L .25298 .56849 L F
.25235 .56858 m .25259 .57386 L .25232 .5739 L .641 .401 .539 r
F
.25208 .57123 m .25197 .57395 L .25311 .57378 L .673 .757 .914 r
F
.25197 .57395 m .25195 .57448 L .25311 .57378 L F
.25195 .57448 m .25149 .58652 L .25318 .574 L F
.25312 .57399 m .25318 .574 L .25319 .57396 L F
.25195 .57448 m .25318 .574 L .25312 .57399 L F
.25153 .56849 m .25235 .56858 L .25232 .5739 L .751 .491 .539 r
F
.25228 .57922 m .25178 .5922 L .25259 .57925 L .673 .757 .914 r
F
.25229 .57922 m .25259 .57925 L .25259 .57917 L F
.25228 .57922 m .25259 .57925 L .25229 .57922 L F
.25164 .57382 m .25232 .5739 L .25229 .57922 L .751 .491 .539 r
F
.25175 .57915 m .25229 .57922 L .25218 .59922 L F
.25164 .57382 m .25229 .57922 L .25175 .57915 L F
.25153 .56849 m .25232 .5739 L .25164 .57382 L F
.25232 .5739 m .25284 .57913 L .25229 .57922 L .641 .401 .539 r
F
.25259 .57386 m .25284 .57913 L .25232 .5739 L F
.25284 .57913 m .25377 .59902 L .25229 .57922 L F
.25237 .57691 m .25228 .57922 L .25259 .57917 L .673 .757 .914 r
F
.2551 .58364 m .25385 .592 L .25832 .59156 L F
.2638 .5785 m .28635 .58642 L .26908 .57599 L F
.25762 .5731 m .26946 .58172 L .27358 .57848 L F
.25311 .56847 m .25391 .57366 L .25349 .57372 L .641 .401 .539 r
F
.25529 .56766 m .25533 .57292 L .25496 .56791 L .353 .175 .495 r
F
.25802 .58588 m .26396 .60051 L .27621 .59724 L .673 .757 .914 r
F
.25559 .58038 m .25832 .59156 L .26444 .58992 L F
.25467 .57939 m .25538 .58176 L .25559 .58038 L F
.25538 .58176 m .25832 .59156 L .25559 .58038 L F
.25704 .56632 m .27318 .57277 L .27583 .56905 L F
.25179 .56556 m .25613 .56702 L .25704 .56632 L F
.25613 .56702 m .27318 .57277 L .25704 .56632 L F
.25529 .56766 m .25563 .57269 L .25533 .57292 L .353 .175 .495 r
F
.25511 .5398 m .25555 .56746 L .25529 .56766 L F
.25555 .56746 m .25563 .57269 L .25529 .56766 L F
.25581 .53923 m .25609 .56674 L .25602 .56684 L .065 0 .408 r
F
.25696 .56546 m .27583 .56905 L .27683 .5651 L .673 .757 .914 r
F
.25348 .57964 m .25832 .59156 L .25431 .579 L F
.25434 .57368 m .25533 .57695 L .25562 .57505 L F
.25533 .57292 m .25537 .57819 L .25505 .57314 L .353 .175 .495 r
F
.25537 .57819 m .2555 .59801 L .25515 .57836 L F
.25537 .57819 m .25515 .57836 L .25505 .57314 L F
.25571 .57258 m .25575 .57779 L .25563 .57269 L .065 0 .408 r
F
.25725 .5703 m .27726 .57078 L .27655 .56683 L .673 .757 .914 r
F
.25588 .57233 m .25577 .57248 L .25566 .56738 L .065 0 .408 r
F
.25523 .56473 m .2551 .56998 L .25574 .56507 L .908 .63 .502 r
F
.25533 .57292 m .25505 .57314 L .25496 .56791 L .353 .175 .495 r
F
.25208 .57123 m .25668 .57115 L .25673 .57107 L .673 .757 .914 r
F
.25467 .57939 m .25514 .57869 L .25498 .57849 L F
.25451 .57963 m .25832 .59156 L .25467 .57939 L F
.25505 .57314 m .25515 .57836 L .25493 .57323 L .353 .175 .495 r
F
.25515 .57836 m .2555 .59801 L .25505 .57843 L F
.25515 .57836 m .25505 .57843 L .25493 .57323 L F
.2638 .5785 m .2758 .59144 L .28635 .58642 L .673 .757 .914 r
F
.26415 .58425 m .28682 .5922 L .26946 .58172 L F
.25561 .578 m .26975 .5874 L .27388 .58416 L F
.25772 .57205 m .27358 .57848 L .27624 .57475 L F
.25449 .57342 m .25424 .57352 L .25394 .56834 L .515 .301 .526 r
F
.25588 .57233 m .25589 .57759 L .25577 .57248 L .065 0 .408 r
F
.25589 .57759 m .25575 .57779 L .25566 .56738 L F
.25591 .57079 m .25569 .57571 L .25584 .57602 L .986 .729 .348 r
F
.25587 .56707 m .25606 .57206 L .25588 .57233 L .065 0 .408 r
F
.25598 .56555 m .25583 .57063 L .25591 .57079 L .986 .729 .348 r
F
.25208 .57123 m .25629 .57265 L .25674 .57247 L .673 .757 .914 r
F
.25583 .57063 m .25569 .57571 L .25591 .57079 L .986 .729 .348 r
F
.25644 .57187 m .25674 .57247 L .25772 .57205 L .673 .757 .914 r
F
.25208 .57123 m .25674 .57247 L .25644 .57187 L F
.25774 .56915 m .2638 .5785 L .26908 .57599 L F
.25985 .57344 m .2638 .5785 L .25774 .56915 L F
.25629 .57265 m .27358 .57848 L .25772 .57205 L F
.25443 .56814 m .25449 .57342 L .25394 .56834 L .515 .301 .526 r
F
.25449 .57342 m .25455 .57869 L .25424 .57352 L F
.25417 .57885 m .25431 .579 L .2549 .57855 L .673 .757 .914 r
F
.25331 .57922 m .25385 .592 L .2551 .58364 L F
.25325 .57907 m .25325 .57924 L .25331 .57922 L F
.25325 .57924 m .25385 .592 L .25331 .57922 L F
.25388 .57898 m .25479 .59858 L .25377 .59902 L .515 .301 .526 r
F
.2552 .57312 m .2547 .57406 L .2553 .57318 L .673 .757 .914 r
F
.25311 .56847 m .25394 .56834 L .25391 .57366 L .641 .401 .539 r
F
.25208 .57123 m .25421 .57353 L .2552 .57312 L .673 .757 .914 r
F
.25421 .57353 m .2547 .57406 L .2552 .57312 L F
.25391 .57366 m .25423 .57883 L .25388 .57898 L .515 .301 .526 r
F
.25394 .56834 m .25408 .57359 L .25391 .57366 L F
.25408 .57359 m .25423 .57883 L .25391 .57366 L F
.25423 .57883 m .25479 .59858 L .25388 .57898 L F
.25431 .579 m .25451 .57963 L .25467 .57939 L .673 .757 .914 r
F
.25455 .57869 m .25479 .59858 L .25423 .57883 L .515 .301 .526 r
F
.25455 .57869 m .25423 .57883 L .25394 .56834 L F
.25349 .57372 m .25391 .57366 L .25388 .57898 L .641 .401 .539 r
F
.25237 .57691 m .25417 .57885 L .25498 .57849 L .673 .757 .914 r
F
.25449 .57342 m .25493 .57323 L .2549 .57855 L .515 .301 .526 r
F
.25431 .579 m .25467 .57939 L .25497 .57852 L .673 .757 .914 r
F
.25431 .579 m .25497 .57852 L .2549 .57855 L F
.25455 .57869 m .2549 .57855 L .25479 .59858 L .515 .301 .526 r
F
.25449 .57342 m .2549 .57855 L .25455 .57869 L F
.2549 .57855 m .25497 .57852 L .25498 .57849 L .673 .757 .914 r
F
.25417 .57885 m .2549 .57855 L .25498 .57849 L F
.25237 .57691 m .25498 .57849 L .25561 .578 L F
.2577 .58013 m .26361 .59469 L .2758 .59144 L F
.25562 .57505 m .25802 .58588 L .26415 .58425 L F
.25533 .57695 m .25802 .58588 L .25562 .57505 L F
.25498 .57849 m .26975 .5874 L .25561 .578 L F
.25893 .57787 m .27388 .58416 L .27654 .58043 L F
.2553 .57318 m .25992 .57895 L .25783 .57471 L F
.25608 .57193 m .25607 .57712 L .25606 .57206 L 0 0 .125 r
F
.25607 .57712 m .25604 .59652 L .25606 .57722 L F
.25607 .57712 m .25606 .57722 L .25606 .57206 L F
.25992 .57895 m .26415 .58425 L .25783 .57471 L .673 .757 .914 r
F
.25602 .57744 m .26275 .58041 L .25893 .57787 L F
.25237 .57691 m .25592 .57811 L .25602 .57744 L F
.25592 .57811 m .26275 .58041 L .25602 .57744 L F
.25783 .57471 m .26415 .58425 L .26946 .58172 L F
.26275 .58041 m .27388 .58416 L .25893 .57787 L F
.2551 .56998 m .25498 .57523 L .25553 .57026 L .908 .63 .502 r
F
.2549 .57855 m .2555 .59801 L .25479 .59858 L .353 .175 .495 r
F
.25493 .57323 m .25505 .57843 L .2549 .57855 L F
.25505 .57843 m .2555 .59801 L .2549 .57855 L F
.25715 .57683 m .27654 .58043 L .27755 .57645 L .673 .757 .914 r
F
.25237 .57691 m .25629 .57748 L .25715 .57683 L F
.25629 .57748 m .27654 .58043 L .25715 .57683 L F
.25587 .57337 m .26946 .58172 L .25762 .5731 L F
.25566 .5734 m .25585 .57351 L .25587 .57337 L F
.25585 .57351 m .26946 .58172 L .25587 .57337 L F
.25611 .57689 m .25607 .57712 L .25608 .57193 L 0 0 .125 r
F
.2561 .57182 m .25608 .57193 L .25609 .56674 L F
.25611 .57689 m .25608 .57193 L .2561 .57182 L F
.25641 .57619 m .27755 .57645 L .27685 .57251 L .673 .757 .914 r
F
.25533 .57292 m .2556 .57801 L .25537 .57819 L .353 .175 .495 r
F
.25237 .57691 m .25736 .57682 L .25641 .57619 L .673 .757 .914 r
F
.25736 .57682 m .27755 .57645 L .25641 .57619 L F
.25537 .57819 m .2556 .57801 L .2555 .59801 L .353 .175 .495 r
F
.25569 .57571 m .25451 .59464 L .25558 .59547 L .908 .63 .502 r
F
.25513 .57308 m .25566 .5734 L .25587 .57251 L .673 .757 .914 r
F
.25533 .57292 m .25563 .57269 L .2556 .57801 L .353 .175 .495 r
F
.25566 .56738 m .25571 .57258 L .25563 .57269 L .065 0 .408 r
F
.25574 .56507 m .25531 .57546 L .25569 .57571 L .908 .63 .502 r
F
.25575 .57779 m .25569 .57788 L .25563 .57269 L .065 0 .408 r
F
.25591 .56805 m .26908 .57599 L .25817 .56771 L .673 .757 .914 r
F
.25443 .56814 m .25493 .57323 L .25449 .57342 L .515 .301 .526 r
F
.25496 .56791 m .25505 .57314 L .25493 .57323 L .353 .175 .495 r
F
.27318 .57277 m .29986 .57255 L .27583 .56905 L .673 .757 .914 r
F
.27259 .57086 m .27624 .57475 L .27726 .57078 L F
.25624 .53855 m .2562 .566 L .25614 .56639 L 0 0 .125 r
F
.25624 .53855 m .25614 .56639 L .25609 .56674 L F
.25635 .53773 m .25598 .56555 L .2562 .566 L .986 .729 .348 r
F
.25547 .56489 m .27683 .5651 L .27614 .56118 L .673 .757 .914 r
F
.25409 .54024 m .25496 .56791 L .25443 .56814 L .515 .301 .526 r
F
.25179 .56556 m .25634 .56547 L .25547 .56489 L .673 .757 .914 r
F
.25634 .56547 m .27683 .5651 L .25547 .56489 L F
.25589 .53668 m .25483 .53586 L .25468 .56436 L .908 .63 .502 r
F
.25484 .56447 m .25468 .56436 L .25465 .56968 L F
.25589 .53668 m .25468 .56436 L .25484 .56447 L F
.25443 .56814 m .25496 .56791 L .25493 .57323 L .515 .301 .526 r
F
.25208 .57123 m .25673 .57107 L .25594 .57054 L .673 .757 .914 r
F
.25612 .57164 m .2561 .57182 L .25609 .56674 L 0 0 .125 r
F
.25609 .56674 m .25608 .57193 L .25606 .57206 L F
.25614 .56639 m .25617 .57132 L .25612 .57164 L F
.25208 .57123 m .2563 .57047 L .25634 .57016 L .673 .757 .914 r
F
.25541 .56774 m .25985 .57344 L .25774 .56915 L F
.25614 .56639 m .25612 .57164 L .25609 .56674 L 0 0 .125 r
F
.25602 .56684 m .25609 .56674 L .25606 .57206 L .065 0 .408 r
F
.25666 .5672 m .25591 .56805 L .25817 .56771 L .673 .757 .914 r
F
.25614 .56639 m .2562 .566 L .25617 .57132 L 0 0 .125 r
F
.2562 .566 m .25591 .57079 L .25617 .57132 L .986 .729 .348 r
F
.25561 .56995 m .25634 .57016 L .25642 .56965 L .673 .757 .914 r
F
.25208 .57123 m .25634 .57016 L .25561 .56995 L F
.25465 .56968 m .25439 .57493 L .25462 .575 L .809 .541 .533 r
F
.25609 .57116 m .25835 .57215 L .25685 .57115 L .673 .757 .914 r
F
.25208 .57123 m .25644 .57187 L .25609 .57116 L F
.25644 .57187 m .25835 .57215 L .25609 .57116 L F
.25581 .53923 m .25587 .56707 L .25566 .56738 L .065 0 .408 r
F
.25179 .56556 m .25539 .56773 L .25666 .5672 L .673 .757 .914 r
F
.25598 .56555 m .25574 .56507 L .25571 .57039 L .986 .729 .348 r
F
.25583 .57063 m .25571 .57039 L .25569 .57571 L F
.25587 .56707 m .25588 .57233 L .25566 .56738 L .065 0 .408 r
F
.25598 .56555 m .25571 .57039 L .25583 .57063 L .986 .729 .348 r
F
.25594 .57054 m .25673 .57107 L .25725 .5703 L .673 .757 .914 r
F
.25644 .56623 m .27583 .56905 L .25696 .56546 L F
.2525 .54044 m .25409 .54024 L .25394 .56834 L .641 .401 .539 r
F
.25483 .53586 m .2536 .56406 L .25389 .56414 L .809 .541 .533 r
F
.25179 .56556 m .25474 .56874 L .25541 .56774 L .673 .757 .914 r
F
.25415 .56421 m .25354 .57469 L .2539 .57479 L .809 .541 .533 r
F
.25483 .53586 m .25389 .56414 L .25415 .56421 L F
.25371 .56941 m .25385 .56945 L .25415 .56421 L F
.25523 .56473 m .25465 .56968 L .2551 .56998 L .908 .63 .502 r
F
.25589 .53668 m .25484 .56447 L .25523 .56473 L F
.25179 .56556 m .25644 .56623 L .25676 .56575 L .673 .757 .914 r
F
.25179 .56556 m .25676 .56575 L .25634 .56547 L F
.25484 .56447 m .25465 .56968 L .25523 .56473 L .908 .63 .502 r
F
.25468 .56436 m .25403 .5695 L .25465 .56968 L .809 .541 .533 r
F
.25483 .53586 m .25415 .56421 L .25468 .56436 L F
.25415 .56421 m .25403 .5695 L .25468 .56436 L F
.25589 .53668 m .25523 .56473 L .25574 .56507 L .908 .63 .502 r
F
.25581 .53923 m .25602 .56684 L .25587 .56707 L .065 0 .408 r
F
.25635 .53773 m .25574 .56507 L .25598 .56555 L .986 .729 .348 r
F
.25322 .57376 m .25388 .57898 L .25334 .57906 L .641 .401 .539 r
F
.25311 .56847 m .25349 .57372 L .25322 .57376 L F
.25349 .57372 m .25388 .57898 L .25322 .57376 L F
.25428 .5736 m .25337 .57442 L .25434 .57368 L .673 .757 .914 r
F
.25307 .56871 m .25295 .56945 L .25327 .56921 L F
.25305 .56866 m .25304 .56872 L .25307 .56871 L F
.25298 .56849 m .25295 .56865 L .25305 .56866 L F
.25311 .56847 m .25322 .57376 L .25235 .56858 L .641 .401 .539 r
F
.25322 .57376 m .25259 .57386 L .25235 .56858 L F
.25208 .57123 m .25311 .57378 L .25428 .5736 L .673 .757 .914 r
F
.25311 .57378 m .25337 .57442 L .25428 .5736 L F
.25237 .57691 m .25432 .57491 L .25354 .57469 L F
.25319 .57396 m .2531 .57463 L .25337 .57442 L F
.2536 .56406 m .25316 .57466 L .25354 .57469 L .734 .477 .54 r
F
.25343 .57468 m .25354 .57469 L .25344 .57466 L .673 .757 .914 r
F
.25259 .57917 m .25385 .592 L .25325 .57907 L F
.25322 .57376 m .25377 .59902 L .25259 .57386 L .641 .401 .539 r
F
.25237 .57691 m .25354 .57469 L .25343 .57468 L .673 .757 .914 r
F
.25237 .57691 m .25348 .57964 L .25431 .579 L F
.25354 .57469 m .25235 .59414 L .25343 .59427 L .734 .477 .54 r
F
.25316 .57466 m .25235 .59414 L .25354 .57469 L F
.25375 .53548 m .25307 .56402 L .2536 .56406 L F
.25208 .57123 m .25382 .56944 L .25357 .56937 L .673 .757 .914 r
F
.25294 .56933 m .25338 .56936 L .2536 .56406 L .734 .477 .54 r
F
.25298 .56933 m .25357 .56937 L .25304 .56922 L .673 .757 .914 r
F
.25208 .57123 m .25357 .56937 L .25298 .56933 L F
.25307 .56402 m .25294 .56933 L .2536 .56406 L .734 .477 .54 r
F
.25237 .57691 m .25259 .57917 L .25325 .57907 L .673 .757 .914 r
F
.25496 .56947 m .27418 .56319 L .2703 .56009 L F
.25208 .57123 m .25659 .56959 L .25496 .56947 L F
.25659 .56959 m .27418 .56319 L .25496 .56947 L F
.25307 .56402 m .25248 .56929 L .25294 .56933 L .734 .477 .54 r
F
.25375 .53548 m .25268 .56399 L .25307 .56402 L F
.25179 .56556 m .2536 .56406 L .25327 .56403 L .673 .757 .914 r
F
.25268 .56399 m .25248 .56929 L .25307 .56402 L .734 .477 .54 r
F
.25179 .56556 m .25403 .56418 L .2536 .56406 L .673 .757 .914 r
F
.25327 .56403 m .2536 .56406 L .25332 .56398 L F
.25254 .56398 m .25332 .56398 L .25263 .56378 L F
.25179 .56556 m .25327 .56403 L .25254 .56398 L F
.25327 .56403 m .25332 .56398 L .25254 .56398 L F
.25375 .53548 m .25266 .53535 L .25251 .56398 L .734 .477 .54 r
F
.25268 .56399 m .25251 .56398 L .25248 .56929 L F
.25375 .53548 m .25251 .56398 L .25268 .56399 L F
.25294 .56933 m .25248 .56929 L .25235 .59414 L F
.25294 .56933 m .25235 .59414 L .25338 .56936 L F
.2536 .56406 m .26992 .55447 L .25332 .56398 L .673 .757 .914 r
F
.25403 .56418 m .25417 .5641 L .2536 .56406 L F
.25417 .5641 m .26992 .55447 L .2536 .56406 L F
.25332 .56398 m .26992 .55447 L .26482 .55214 L F
.25291 .56319 m .26482 .55214 L .25884 .55073 L F
.25263 .56378 m .25311 .56332 L .25291 .56319 L F
.25311 .56332 m .26482 .55214 L .25291 .56319 L F
.25634 .56547 m .25676 .56575 L .25696 .56546 L F
.25476 .56374 m .27378 .55755 L .26992 .55447 L F
.25179 .56556 m .25762 .56343 L .25476 .56374 L F
.25762 .56343 m .27378 .55755 L .25476 .56374 L F
.25093 .54018 m .25235 .56858 L .25153 .56849 L .751 .491 .539 r
F
.25266 .53535 m .25157 .53544 L .25141 .56409 L .66 .416 .54 r
F
.2512 .58077 m .25062 .59596 L .25175 .59585 L .673 .757 .914 r
F
.24474 .58037 m .25062 .59596 L .25076 .59237 L F
.24983 .58068 m .25076 .59237 L .2512 .58077 L F
.24474 .58037 m .25076 .59237 L .24983 .58068 L F
.24883 .5376 m .24889 .53841 L .24873 .56687 L .798 .638 .081 r
F
.245 .58612 m .2509 .60179 L .25095 .60052 L .673 .757 .914 r
F
.24983 .58642 m .25095 .60052 L .25149 .58652 L F
.24474 .58037 m .23771 .59517 L .25062 .59596 L F
.245 .58612 m .25095 .60052 L .24983 .58642 L F
.24927 .53911 m .24994 .5397 L .24978 .568 L .927 .648 .491 r
F
.25156 .57142 m .24474 .58037 L .2512 .58077 L .673 .757 .914 r
F
.25164 .56944 m .25098 .57048 L .25156 .57142 L F
.25098 .57048 m .24474 .58037 L .25156 .57142 L F
.24889 .53841 m .24927 .53911 L .24911 .56749 L .989 .721 .393 r
F
.24927 .53911 m .24978 .568 L .24944 .56774 L .927 .648 .491 r
F
.24994 .5397 m .25093 .54018 L .25077 .5684 L .844 .571 .525 r
F
.24994 .5397 m .25077 .5684 L .25026 .56819 L F
.24883 .5376 m .2487 .56649 L .24867 .56613 L .798 .638 .081 r
F
.24889 .53841 m .24911 .56749 L .24892 .56717 L .989 .721 .393 r
F
.24883 .5376 m .24873 .56687 L .2487 .56649 L .798 .638 .081 r
F
.24935 .53656 m .24883 .5376 L .24867 .56613 L 0 0 .368 r
F
.25011 .57445 m .24375 .58031 L .25036 .57485 L .673 .757 .914 r
F
.23876 .57896 m .23771 .59517 L .24474 .58037 L F
.24375 .58031 m .23899 .5847 L .24347 .58082 L F
.24375 .58031 m .24347 .58082 L .25036 .57485 L F
.25011 .56908 m .23876 .57896 L .24474 .58037 L F
.24873 .56687 m .24892 .57254 L .2487 .57218 L .989 .721 .393 r
F
.24889 .53841 m .24892 .56717 L .24873 .56687 L F
.24951 .56789 m .23876 .57896 L .25049 .56828 L .673 .757 .914 r
F
.24892 .56717 m .24892 .57254 L .24873 .56687 L .989 .721 .393 r
F
.2504 .56848 m .24997 .56886 L .25011 .56908 L .673 .757 .914 r
F
.24997 .56886 m .23876 .57896 L .25011 .56908 L F
.24867 .57081 m .24868 .57187 L .24864 .57145 L .798 .638 .081 r
F
.24877 .5674 m .23367 .57664 L .24886 .56856 L .673 .757 .914 r
F
.2487 .56649 m .24868 .57187 L .24867 .56613 L .798 .638 .081 r
F
.2487 .56649 m .24873 .56687 L .2487 .57218 L F
.2487 .56649 m .2487 .57218 L .24868 .57187 L F
.24894 .56565 m .24867 .56613 L .24864 .57145 L 0 0 .368 r
F
.24997 .5734 m .23387 .58237 L .23899 .5847 L .673 .757 .914 r
F
.25138 .56923 m .24474 .58037 L .25164 .56944 L F
.25049 .56828 m .25033 .56843 L .2504 .56848 L F
.25045 .56836 m .24474 .58037 L .25167 .5685 L F
.25026 .56819 m .25077 .5684 L .25074 .57371 L .844 .571 .525 r
F
.25018 .57365 m .25062 .57398 L .25086 .57376 L .673 .757 .914 r
F
.25018 .57365 m .25086 .57376 L .25074 .57371 L F
.25185 .57724 m .245 .58612 L .25149 .58652 L F
.25089 .57373 m .25011 .57445 L .25036 .57485 L F
.25213 .58306 m .24529 .5918 L .25178 .5922 L F
.2487 .57218 m .24875 .57763 L .24867 .5775 L .989 .721 .393 r
F
.24532 .57221 m .23367 .57664 L .23876 .57896 L .673 .757 .914 r
F
.2491 .57306 m .22999 .57928 L .23387 .58237 L F
.24978 .568 m .24992 .57339 L .24975 .57332 L .844 .571 .525 r
F
.25155 .56871 m .24474 .58037 L .25166 .56875 L .673 .757 .914 r
F
.25077 .5684 m .25102 .57375 L .25074 .57371 L .751 .491 .539 r
F
.25208 .57123 m .24813 .57267 L .2491 .57306 L .673 .757 .914 r
F
.24813 .57267 m .22999 .57928 L .2491 .57306 L F
.25026 .56819 m .25032 .57354 L .24978 .568 L .844 .571 .525 r
F
.25126 .57925 m .25106 .57967 L .25227 .57965 L .673 .757 .914 r
F
.25106 .57967 m .24529 .5918 L .25189 .58031 L F
.25106 .57967 m .25189 .58031 L .25227 .57965 L F
.25033 .56843 m .23876 .57896 L .2504 .56848 L F
.24669 .56972 m .23367 .57664 L .24532 .57221 L F
.24756 .56814 m .22981 .57356 L .23367 .57664 L F
.24927 .53911 m .24944 .56774 L .24911 .56749 L .927 .648 .491 r
F
.25179 .56556 m .24829 .56683 L .24756 .56814 L .673 .757 .914 r
F
.24829 .56683 m .22981 .57356 L .24756 .56814 L F
.24892 .56717 m .24911 .56749 L .24908 .5728 L .989 .721 .393 r
F
.24892 .56717 m .24908 .5728 L .24892 .57254 L F
.24919 .56518 m .24886 .57105 L .24917 .5705 L 0 0 .368 r
F
.24935 .53656 m .24894 .56565 L .24919 .56518 L F
.24994 .5397 m .25026 .56819 L .24978 .568 L .844 .571 .525 r
F
.25179 .56556 m .24877 .5674 L .24886 .56856 L .673 .757 .914 r
F
.24894 .56565 m .24886 .57105 L .24919 .56518 L 0 0 .368 r
F
.248 .57197 m .2269 .57169 L .22761 .57563 L .673 .757 .914 r
F
.24944 .56774 m .24975 .57332 L .24958 .57318 L .927 .648 .491 r
F
.24488 .56807 m .22744 .56993 L .22981 .57356 L .673 .757 .914 r
F
.25179 .56556 m .24748 .56633 L .24488 .56807 L F
.24748 .56633 m .22744 .56993 L .24488 .56807 L F
.25047 .53578 m .24935 .53656 L .24919 .56518 L .398 .209 .505 r
F
.24937 .56507 m .24919 .56518 L .24917 .5705 L F
.25047 .53578 m .24919 .56518 L .24937 .56507 L F
.24947 .5731 m .2492 .57289 L .24911 .56749 L .927 .648 .491 r
F
.25208 .57123 m .24796 .57131 L .248 .57197 L .673 .757 .914 r
F
.24892 .57254 m .24893 .57791 L .2487 .57218 L .989 .721 .393 r
F
.24893 .57791 m .24895 .59789 L .24875 .57763 L F
.24893 .57791 m .24875 .57763 L .2487 .57218 L F
.25119 .57619 m .245 .58612 L .25185 .57724 L .673 .757 .914 r
F
.24962 .57859 m .24943 .57871 L .25023 .57903 L F
.2491 .57306 m .23387 .58237 L .24997 .5734 L F
.24892 .57254 m .24902 .57271 L .24892 .57431 L .989 .721 .393 r
F
.24902 .57271 m .24908 .5728 L .24892 .57431 L F
.245 .58612 m .23793 .60099 L .2509 .60179 L .673 .757 .914 r
F
.23899 .5847 m .23793 .60099 L .245 .58612 L F
.25061 .58062 m .23928 .59038 L .24529 .5918 L F
.24529 .5918 m .2512 .60747 L .25178 .5922 L F
.25072 .57903 m .25218 .59922 L .25061 .59896 L .751 .491 .539 r
F
.25074 .57371 m .25105 .57907 L .25072 .57903 L F
.25105 .57907 m .25218 .59922 L .25072 .57903 L F
.25133 .5791 m .24989 .57946 L .25061 .58062 L .673 .757 .914 r
F
.25193 .575 m .25119 .57619 L .25185 .57724 L F
.25153 .56849 m .25164 .57382 L .25077 .5684 L .751 .491 .539 r
F
.25198 .57386 m .25073 .57407 L .25193 .575 L .673 .757 .914 r
F
.25089 .57373 m .25073 .57407 L .25198 .57386 L F
.25118 .58154 m .24529 .5918 L .25213 .58306 L F
.2444 .57913 m .23899 .5847 L .24375 .58031 L F
.23876 .57896 m .22575 .59235 L .23771 .59517 L F
.2492 .57885 m .23028 .58496 L .23416 .58805 L F
.25175 .57915 m .25126 .5791 L .25102 .57375 L .751 .491 .539 r
F
.24958 .57318 m .24975 .57332 L .24972 .57863 L .927 .648 .491 r
F
.25073 .57407 m .245 .58612 L .25193 .575 L .673 .757 .914 r
F
.25237 .57691 m .24756 .57866 L .2492 .57885 L F
.24901 .57602 m .23899 .5847 L .24912 .57745 L F
.24756 .57866 m .23028 .58496 L .2492 .57885 L F
.25164 .57382 m .25175 .57915 L .25102 .57375 L .751 .491 .539 r
F
.25175 .57915 m .25218 .59922 L .25126 .5791 L F
.25164 .57382 m .25102 .57375 L .25077 .5684 L F
.25208 .57123 m .25089 .57373 L .25198 .57386 L .673 .757 .914 r
F
.25237 .57691 m .25035 .57899 L .25133 .5791 L F
.25035 .57899 m .24989 .57946 L .25133 .5791 L F
.24868 .57187 m .2487 .57218 L .24867 .5775 L .798 .638 .081 r
F
.24865 .57726 m .24867 .5775 L .24856 .5972 L F
.24978 .5736 m .2444 .57913 L .25062 .57398 L .673 .757 .914 r
F
.24868 .57187 m .24867 .5775 L .24865 .57726 L .798 .638 .081 r
F
.24989 .57946 m .24891 .58048 L .25061 .58062 L .673 .757 .914 r
F
.24912 .57745 m .23899 .5847 L .245 .58612 L F
.24891 .58048 m .23928 .59038 L .24903 .58198 L F
.24891 .58048 m .24903 .58198 L .25061 .58062 L F
.24892 .57431 m .24908 .5728 L .24906 .57812 L .989 .721 .393 r
F
.24893 .57791 m .24906 .57812 L .24895 .59789 L F
.24892 .57431 m .24906 .57812 L .24893 .57791 L F
.24886 .57105 m .24879 .57645 L .24917 .5705 L 0 0 .368 r
F
.24875 .57763 m .24895 .59789 L .24867 .5775 L .989 .721 .393 r
F
.23367 .57664 m .22575 .59235 L .23876 .57896 L .673 .757 .914 r
F
.23367 .57664 m .21556 .58771 L .22575 .59235 L F
.22999 .57928 m .21567 .5935 L .23387 .58237 L F
.24169 .5808 m .2279 .58131 L .23028 .58496 L F
.24978 .5736 m .25062 .57398 L .25018 .57365 L F
.25032 .57354 m .25038 .5789 L .24992 .57339 L .844 .571 .525 r
F
.24972 .57863 m .25023 .57903 L .25042 .57892 L .673 .757 .914 r
F
.25038 .5789 m .25061 .59896 L .25007 .57877 L .844 .571 .525 r
F
.25038 .5789 m .25007 .57877 L .24992 .57339 L F
.24873 .57824 m .24571 .57811 L .24169 .5808 L .673 .757 .914 r
F
.2444 .57913 m .24375 .58031 L .25062 .57398 L F
.25036 .57485 m .24901 .57602 L .24912 .57745 L F
.24944 .56774 m .24972 .57863 L .2495 .57846 L .927 .648 .491 r
F
.25237 .57691 m .24757 .57778 L .24873 .57824 L .673 .757 .914 r
F
.24757 .57778 m .24571 .57811 L .24873 .57824 L F
.24571 .57811 m .2279 .58131 L .24169 .5808 L F
.25032 .57354 m .24992 .57339 L .24978 .568 L .844 .571 .525 r
F
.25026 .56819 m .25074 .57371 L .25032 .57354 L F
.24329 .57443 m .22761 .57563 L .22999 .57928 L .673 .757 .914 r
F
.25208 .57123 m .2466 .57222 L .24329 .57443 L F
.2466 .57222 m .22761 .57563 L .24329 .57443 L F
.24962 .57859 m .25023 .57903 L .24972 .57863 L F
.2495 .57846 m .24972 .57863 L .24961 .59849 L .927 .648 .491 r
F
.24972 .57863 m .25061 .59896 L .24961 .59849 L .844 .571 .525 r
F
.24943 .57871 m .24978 .57928 L .25023 .57903 L .673 .757 .914 r
F
.24993 .57872 m .25061 .59896 L .24972 .57863 L .844 .571 .525 r
F
.24992 .57339 m .25007 .57877 L .24975 .57332 L F
.25007 .57877 m .25061 .59896 L .24993 .57872 L F
.25007 .57877 m .24993 .57872 L .24975 .57332 L F
.24757 .57778 m .22719 .57737 L .2279 .58131 L .673 .757 .914 r
F
.25032 .57354 m .25072 .57903 L .25038 .5789 L .844 .571 .525 r
F
.25237 .57691 m .24571 .57703 L .24757 .57778 L .673 .757 .914 r
F
.24571 .57703 m .22719 .57737 L .24757 .57778 L F
.24911 .56749 m .2492 .57289 L .24908 .5728 L .927 .648 .491 r
F
.23059 .57162 m .22791 .56772 L .2269 .57169 L .673 .757 .914 r
F
.23977 .56772 m .22674 .56601 L .22744 .56993 L F
.25031 .56444 m .24964 .57018 L .25028 .56975 L .398 .209 .505 r
F
.25047 .53578 m .24977 .5648 L .25031 .56444 L F
.24944 .56774 m .24978 .568 L .24975 .57332 L .927 .648 .491 r
F
.24977 .5648 m .24964 .57018 L .25031 .56444 L .398 .209 .505 r
F
.24748 .56633 m .2464 .56565 L .23977 .56772 L .673 .757 .914 r
F
.25179 .56556 m .24855 .56561 L .24748 .56633 L F
.24855 .56561 m .2464 .56565 L .24748 .56633 L F
.2464 .56565 m .22674 .56601 L .23977 .56772 L F
.25157 .53544 m .25047 .53578 L .25031 .56444 L .567 .342 .533 r
F
.25048 .56438 m .25031 .56444 L .25028 .56975 L F
.25157 .53544 m .25031 .56444 L .25048 .56438 L F
.25032 .57354 m .25074 .57371 L .25072 .57903 L .844 .571 .525 r
F
.25208 .57123 m .2491 .57306 L .24997 .5734 L .673 .757 .914 r
F
.24886 .56856 m .24669 .56972 L .24532 .57221 L F
.24761 .57058 m .23056 .56398 L .22791 .56772 L F
.25208 .57123 m .24893 .57017 L .24761 .57058 L F
.24893 .57017 m .23056 .56398 L .24761 .57058 L F
.25074 .57371 m .25086 .57376 L .25089 .57373 L F
.25102 .57375 m .25126 .5791 L .25074 .57371 L .751 .491 .539 r
F
.25126 .5791 m .25218 .59922 L .25105 .57907 L F
.25126 .5791 m .25105 .57907 L .25074 .57371 L F
.24383 .57707 m .22746 .57631 L .23528 .57722 L .673 .757 .914 r
F
.24975 .57332 m .24993 .57872 L .24972 .57863 L .844 .571 .525 r
F
.25237 .57691 m .24491 .57673 L .24383 .57707 L .673 .757 .914 r
F
.24491 .57673 m .22746 .57631 L .24383 .57707 L F
.25075 .56961 m .25062 .57496 L .25138 .56941 L .567 .342 .533 r
F
.25237 .57691 m .24962 .57859 L .25042 .57892 L .673 .757 .914 r
F
.25038 .5789 m .25072 .57903 L .25061 .59896 L .844 .571 .525 r
F
.24689 .57612 m .23085 .56966 L .2282 .5734 L .673 .757 .914 r
F
.2495 .57846 m .24929 .5783 L .2492 .57289 L .927 .648 .491 r
F
.25237 .57691 m .24851 .57561 L .24689 .57612 L .673 .757 .914 r
F
.24851 .57561 m .23085 .56966 L .24689 .57612 L F
.25075 .56961 m .25028 .56975 L .25025 .57507 L .567 .342 .533 r
F
.24511 .57136 m .24455 .57014 L .23059 .57162 L .673 .757 .914 r
F
.24455 .57014 m .22791 .56772 L .23059 .57162 L F
.24717 .57132 m .2269 .57169 L .248 .57197 L F
.2472 .57517 m .23497 .56642 L .23085 .56966 L F
.24964 .57018 m .24951 .57557 L .25028 .56975 L .398 .209 .505 r
F
.2495 .57846 m .24961 .59849 L .24929 .5783 L .927 .648 .491 r
F
.24908 .5728 m .24961 .59849 L .24895 .59789 L F
.24951 .57557 m .24903 .59535 L .25001 .57523 L .398 .209 .505 r
F
.25208 .57123 m .24978 .5736 L .25089 .57373 L .673 .757 .914 r
F
.24951 .57557 m .25001 .57523 L .25028 .56975 L .398 .209 .505 r
F
.24913 .57582 m .24914 .57496 L .2472 .57517 L .673 .757 .914 r
F
.25237 .57691 m .24981 .57537 L .24913 .57582 L F
.24947 .5731 m .2495 .57846 L .2492 .57289 L .927 .648 .491 r
F
.24964 .57018 m .24914 .57582 L .24951 .57557 L .398 .209 .505 r
F
.24981 .57537 m .24914 .57496 L .24913 .57582 L .673 .757 .914 r
F
.24886 .57105 m .24861 .57677 L .24879 .57645 L 0 0 .368 r
F
.24914 .57496 m .23497 .56642 L .2472 .57517 L .673 .757 .914 r
F
.25208 .57123 m .24761 .57058 L .24511 .57136 L F
.25185 .56936 m .25138 .56941 L .25136 .57473 L .66 .416 .54 r
F
.25227 .57965 m .25118 .58154 L .25213 .58306 L .673 .757 .914 r
F
.25172 .57469 m .25136 .57473 L .25125 .59423 L .66 .416 .54 r
F
.25185 .56936 m .25136 .57473 L .25172 .57469 L F
.25062 .57496 m .25025 .57507 L .25015 .59456 L .567 .342 .533 r
F
.25075 .56961 m .25025 .57507 L .25062 .57496 L F
.25062 .57496 m .25015 .59456 L .25112 .5748 L F
.25062 .57496 m .25112 .5748 L .25138 .56941 L F
.25136 .57473 m .25015 .59456 L .25125 .59423 L F
.25138 .56941 m .25112 .5748 L .25136 .57473 L F
.25112 .5748 m .25015 .59456 L .25136 .57473 L F
.24491 .57673 m .2282 .5734 L .22746 .57631 L .673 .757 .914 r
F
.25237 .57691 m .24689 .57612 L .24491 .57673 L F
.24689 .57612 m .2282 .5734 L .24491 .57673 L F
.22981 .57356 m .21556 .58771 L .23367 .57664 L F
.23528 .57722 m .22746 .57631 L .22719 .57737 L F
.25093 .54018 m .25153 .56849 L .25077 .5684 L .751 .491 .539 r
F
.25179 .56556 m .25045 .56836 L .25167 .5685 L .673 .757 .914 r
F
.2464 .56565 m .22774 .56205 L .22674 .56601 L F
.24935 .53656 m .24867 .56613 L .24894 .56565 L 0 0 .368 r
F
.25179 .56556 m .24833 .56505 L .2464 .56565 L .673 .757 .914 r
F
.24833 .56505 m .22774 .56205 L .2464 .56565 L F
.25141 .56409 m .25075 .56961 L .25138 .56941 L .567 .342 .533 r
F
.25157 .53544 m .25088 .56426 L .25141 .56409 L F
.25088 .56426 m .25075 .56961 L .25141 .56409 L F
.25179 .56556 m .24951 .56789 L .25049 .56828 L .673 .757 .914 r
F
.24833 .56505 m .23038 .55834 L .22774 .56205 L F
.25179 .56556 m .24935 .56473 L .24833 .56505 L F
.24935 .56473 m .23038 .55834 L .24833 .56505 L F
.25088 .56426 m .25028 .56975 L .25075 .56961 L .567 .342 .533 r
F
.25157 .53544 m .25048 .56438 L .25088 .56426 L F
.25048 .56438 m .25028 .56975 L .25088 .56426 L F
.24761 .57058 m .24455 .57014 L .24511 .57136 L .673 .757 .914 r
F
.25197 .56403 m .25141 .56409 L .25138 .56941 L .66 .416 .54 r
F
.25166 .56875 m .25138 .56923 L .25164 .56944 L .673 .757 .914 r
F
.25167 .5685 m .25155 .56871 L .25166 .56875 L F
.25179 .56556 m .25167 .56868 L .25298 .56849 L F
.25197 .56403 m .25138 .56941 L .25185 .56936 L .66 .416 .54 r
F
.24944 .56774 m .24947 .5731 L .24911 .56749 L .927 .648 .491 r
F
.24977 .5648 m .24917 .5705 L .24964 .57018 L .398 .209 .505 r
F
.25047 .53578 m .24937 .56507 L .24977 .5648 L F
.24937 .56507 m .24917 .5705 L .24977 .5648 L F
.24969 .56485 m .23448 .55511 L .23038 .55834 L .673 .757 .914 r
F
.25179 .56556 m .25013 .56456 L .24969 .56485 L F
.25013 .56456 m .23448 .55511 L .24969 .56485 L F
.24894 .56565 m .24864 .57145 L .24886 .57105 L 0 0 .368 r
F
.2478 .56979 m .23468 .56074 L .23056 .56398 L .673 .757 .914 r
F
.25208 .57123 m .2494 .56962 L .2478 .56979 L F
.2494 .56962 m .23468 .56074 L .2478 .56979 L F
.25248 .56929 m .25125 .59423 L .25235 .59414 L .66 .416 .54 r
F
.25266 .53535 m .25197 .56403 L .25251 .56398 L F
.25184 .56405 m .25263 .56378 L .25186 .56356 L .673 .757 .914 r
F
.25179 .56556 m .25254 .56397 L .25184 .56405 L F
.25254 .56397 m .25263 .56378 L .25184 .56405 L F
.25251 .56398 m .25185 .56936 L .25248 .56929 L .66 .416 .54 r
F
.25197 .56403 m .25185 .56936 L .25251 .56398 L F
.25237 .57691 m .25126 .57925 L .25227 .57965 L .673 .757 .914 r
F
.25185 .56936 m .25125 .59423 L .25248 .56929 L .66 .416 .54 r
F
.24861 .57677 m .24856 .5972 L .2485 .59638 L .798 .638 .081 r
F
.24864 .57145 m .24862 .57692 L .24861 .57677 L F
.24862 .57692 m .24856 .5972 L .24861 .57677 L F
.24844 .57454 m .24028 .56389 L .23497 .56642 L .673 .757 .914 r
F
.24981 .57537 m .24836 .57363 L .24844 .57454 L F
.24836 .57363 m .24028 .56389 L .24844 .57454 L F
.25237 .57691 m .2505 .5749 L .24981 .57537 L F
.24879 .57645 m .24902 .57602 L .24917 .5705 L 0 0 .368 r
F
.24886 .57105 m .24864 .57145 L .24861 .57677 L F
.2505 .5749 m .24028 .56389 L .24981 .57537 L .673 .757 .914 r
F
.25025 .57507 m .24903 .59535 L .25015 .59456 L .398 .209 .505 r
F
.25028 .56975 m .25001 .57523 L .25025 .57507 L F
.25001 .57523 m .24903 .59535 L .25025 .57507 L F
.24964 .57018 m .24917 .5705 L .24914 .57582 L F
.2492 .57289 m .24961 .59849 L .24908 .5728 L .927 .648 .491 r
F
.24951 .57557 m .24914 .57582 L .24903 .59535 L .398 .209 .505 r
F
.24879 .57645 m .2485 .59638 L .24902 .57602 L 0 0 .368 r
F
.24943 .57871 m .24658 .58046 L .24978 .57928 L .673 .757 .914 r
F
.24658 .58046 m .23416 .58805 L .24608 .58135 L F
.24658 .58046 m .24608 .58135 L .24978 .57928 L F
.24796 .57131 m .24717 .57132 L .24752 .5716 L F
.24796 .57131 m .24752 .5716 L .248 .57197 L F
.24868 .57187 m .24865 .57726 L .24864 .57145 L .798 .638 .081 r
F
.24865 .57726 m .24856 .5972 L .24862 .57692 L F
.24865 .57726 m .24862 .57692 L .24864 .57145 L F
.24891 .58048 m .24608 .58135 L .24349 .58605 L .673 .757 .914 r
F
.25042 .57892 m .24885 .5798 L .24891 .58048 L F
.24885 .5798 m .24608 .58135 L .24891 .58048 L F
.24879 .57645 m .24861 .57677 L .2485 .59638 L 0 0 .368 r
F
.24349 .58605 m .23416 .58805 L .23928 .59038 L .673 .757 .914 r
F
.24608 .58135 m .23416 .58805 L .24349 .58605 L F
.24867 .5775 m .24895 .59789 L .24856 .5972 L .989 .721 .393 r
F
.25208 .57123 m .23999 .55821 L .23468 .56074 L .673 .757 .914 r
F
.24996 .57432 m .24642 .56225 L .24028 .56389 L F
.25237 .57691 m .25074 .5729 L .24996 .57432 L F
.25074 .5729 m .24642 .56225 L .24996 .57432 L F
.24914 .57582 m .2485 .59638 L .24903 .59535 L 0 0 .368 r
F
.24917 .5705 m .24902 .57602 L .24914 .57582 L F
.24902 .57602 m .2485 .59638 L .24914 .57582 L F
.25266 .53535 m .25141 .56409 L .25197 .56403 L .66 .416 .54 r
F
.25304 .56922 m .26518 .55775 L .25917 .55633 L .673 .757 .914 r
F
.25179 .56556 m .27614 .56118 L .27378 .55755 L F
.25382 .56944 m .26518 .55775 L .25304 .56922 L F
.25389 .56414 m .25371 .56941 L .25415 .56421 L .809 .541 .533 r
F
.25371 .56941 m .25354 .57469 L .25385 .56945 L F
.25332 .56398 m .26482 .55214 L .25263 .56378 L .673 .757 .914 r
F
.25186 .56356 m .25884 .55073 L .25237 .55032 L F
.25263 .56378 m .25884 .55073 L .25186 .56356 L F
.25483 .53586 m .25375 .53548 L .2536 .56406 L .809 .541 .533 r
F
.25389 .56414 m .2536 .56406 L .25357 .56937 L F
.25217 .56897 m .25917 .55633 L .25267 .55593 L .673 .757 .914 r
F
.25208 .57123 m .25304 .56922 L .25217 .56897 L F
.25389 .56414 m .25357 .56937 L .25371 .56941 L .809 .541 .533 r
F
.25304 .56922 m .25917 .55633 L .25217 .56897 L .673 .757 .914 r
F
.25371 .56941 m .25357 .56937 L .25354 .57469 L .809 .541 .533 r
F
.25334 .57906 m .25388 .57898 L .25377 .59902 L .641 .401 .539 r
F
.25685 .57115 m .26122 .57256 L .27259 .57086 L .673 .757 .914 r
F
.25668 .57115 m .27726 .57078 L .25725 .5703 L F
.25587 .57251 m .25566 .5734 L .25762 .5731 L F
.25612 .57164 m .25617 .57132 L .25614 .57664 L 0 0 .125 r
F
.25611 .57689 m .25614 .57664 L .25604 .59652 L F
.25612 .57164 m .25614 .57664 L .25611 .57689 L F
.25648 .5744 m .27448 .56887 L .2706 .56577 L .673 .757 .914 r
F
.25588 .57233 m .25606 .57206 L .25603 .57738 L .065 0 .408 r
F
.25591 .57079 m .25584 .57602 L .25617 .57132 L .986 .729 .348 r
F
.25589 .57759 m .25593 .59733 L .25575 .57779 L .065 0 .408 r
F
.25575 .57779 m .25593 .59733 L .25569 .57788 L F
.2556 .57801 m .25593 .59733 L .2555 .59801 L F
.25563 .57269 m .25569 .57788 L .2556 .57801 L F
.25569 .57788 m .25593 .59733 L .2556 .57801 L F
.25588 .57233 m .25603 .57738 L .25589 .57759 L F
.25612 .57164 m .25611 .57689 L .2561 .57182 L 0 0 .125 r
F
.25606 .57206 m .25606 .57722 L .25603 .57738 L F
.25584 .57602 m .25605 .57644 L .25617 .57132 L .986 .729 .348 r
F
.2551 .56998 m .25465 .56968 L .25462 .575 L .908 .63 .502 r
F
.25237 .57691 m .25632 .57548 L .25523 .57517 L .673 .757 .914 r
F
.25498 .57523 m .25462 .575 L .25451 .59464 L .908 .63 .502 r
F
.2551 .56998 m .25462 .575 L .25498 .57523 L F
.25835 .57215 m .26122 .57256 L .25685 .57115 L .673 .757 .914 r
F
.25439 .57484 m .25916 .57276 L .26548 .56343 L F
.25237 .57691 m .25504 .57528 L .25439 .57484 L F
.25504 .57528 m .25916 .57276 L .25439 .57484 L F
.25642 .56965 m .27655 .56683 L .27418 .56319 L F
.2563 .57047 m .27655 .56683 L .25642 .56965 L F
.25916 .57276 m .2706 .56577 L .26549 .56344 L F
.25916 .57276 m .26549 .56344 L .26548 .56343 L F
.25584 .57602 m .25558 .59547 L .25605 .57644 L .986 .729 .348 r
F
.25589 .57759 m .25603 .57738 L .25593 .59733 L .065 0 .408 r
F
.25611 .57689 m .25604 .59652 L .25607 .57712 L 0 0 .125 r
F
.25603 .57738 m .25604 .59652 L .25593 .59733 L F
.25606 .57722 m .25604 .59652 L .25603 .57738 L F
.25614 .57664 m .25558 .59547 L .25604 .59652 L .986 .729 .348 r
F
.25617 .57132 m .25605 .57644 L .25614 .57664 L F
.25605 .57644 m .25558 .59547 L .25614 .57664 L F
.25632 .57548 m .27448 .56887 L .25539 .57511 L .673 .757 .914 r
F
.25545 .57523 m .25539 .57511 L .25523 .57517 L F
.25632 .57548 m .25539 .57511 L .25545 .57523 L F
.25538 .57508 m .25642 .57478 L .25648 .5744 L F
.25523 .57517 m .25539 .57511 L .25538 .57508 L F
.25539 .57511 m .25642 .57478 L .25538 .57508 L F
.26122 .57256 m .27624 .57475 L .27259 .57086 L F
.25642 .57478 m .27448 .56887 L .25648 .5744 L F
.25403 .5695 m .2539 .57479 L .25465 .56968 L .809 .541 .533 r
F
.2539 .57479 m .25343 .59427 L .25439 .57493 L F
.25208 .57123 m .25513 .57308 L .25587 .57251 L .673 .757 .914 r
F
.2539 .57479 m .25439 .57493 L .25465 .56968 L .809 .541 .533 r
F
.2539 .57479 m .25354 .57469 L .25343 .59427 L F
.25237 .57691 m .2569 .5761 L .25716 .57572 L .673 .757 .914 r
F
.25632 .57548 m .25716 .57572 L .25765 .57499 L F
.25237 .57691 m .25716 .57572 L .25632 .57548 L F
.2551 .56998 m .25553 .57026 L .25574 .56507 L .908 .63 .502 r
F
.25539 .56773 m .25591 .56805 L .25666 .5672 L .673 .757 .914 r
F
.25602 .56684 m .25606 .57206 L .25587 .56707 L .065 0 .408 r
F
.25598 .56555 m .25591 .57079 L .2562 .566 L .986 .729 .348 r
F
.25208 .57123 m .2703 .56009 L .26518 .55775 L .673 .757 .914 r
F
.25344 .57466 m .26548 .56343 L .25946 .56201 L F
.25498 .57523 m .25531 .57546 L .25553 .57026 L .908 .63 .502 r
F
.25432 .57491 m .26548 .56343 L .25344 .57466 L .673 .757 .914 r
F
.25462 .575 m .25343 .59427 L .25451 .59464 L .809 .541 .533 r
F
.25439 .57493 m .25343 .59427 L .25462 .575 L F
.25765 .57499 m .27685 .57251 L .27448 .56887 L .673 .757 .914 r
F
.2569 .5761 m .27685 .57251 L .25765 .57499 L F
.25531 .57546 m .25451 .59464 L .25569 .57571 L .908 .63 .502 r
F
.25498 .57523 m .25451 .59464 L .25531 .57546 L F
.25467 .57939 m .26444 .58992 L .25514 .57869 L .673 .757 .914 r
F
.25584 .57602 m .25569 .57571 L .25558 .59547 L .986 .729 .348 r
F
.25802 .58588 m .27621 .59724 L .26415 .58425 L .673 .757 .914 r
F
.25792 .58026 m .26444 .58992 L .26975 .5874 L F
.25498 .57849 m .26008 .58464 L .25792 .58026 L F
.26008 .58464 m .26444 .58992 L .25792 .58026 L F
.48269 .59866 m .45664 .60306 L .48165 .6026 L F
.55726 .6069 m .58043 .59464 L .55594 .59903 L F
.53212 .60736 m .55726 .6069 L .55594 .59903 L F
.61273 .84855 m .61297 .84479 L .60721 .83969 L .926 .677 .542 r
F
0 g
.61297 .84479 m
.61647 .85053 L
s
.32535 .72594 m .32582 .71473 L .31124 .71665 L .683 .77 .917 r
F
.3069 .73441 m .29789 .72516 L .28598 .73115 L F
.31606 .73168 m .29789 .72516 L .3069 .73441 L F
.46232 .4881 m .44285 .48944 L .44241 .49673 L .492 .285 .526 r
F
0 g
.42694 .50851 m
.44241 .49673 L
s
.46232 .4881 m .46276 .48082 L .44285 .48944 L .492 .285 .526 r
F
0 g
.42738 .50123 m
.44285 .48944 L
s
.76674 .49329 m .77115 .47046 L .77076 .47774 L 0 0 .159 r
F
.76635 .50057 m .76674 .49329 L .77076 .47774 L F
.73665 .48646 m .76674 .49329 L .77076 .47774 L .654 .726 .902 r
F
0 g
.76219 .49962 m
.76674 .49329 L
s
.34499 .73699 m .34135 .72409 L .33601 .73522 L .683 .77 .917 r
F
.34499 .73699 m .35481 .72674 L .34135 .72409 L F
.75506 .72437 m .74609 .71291 L .74543 .72412 L .683 .771 .917 r
F
.75506 .72437 m .76054 .71328 L .74609 .71291 L F
.73223 .83895 m .73456 .84801 L .73821 .84083 L .645 .732 .913 r
F
.73223 .83895 m .72559 .84519 L .73456 .84801 L F
0 g
.73456 .84801 m
.74187 .84903 L
s
.71949 .74115 m .70666 .7339 L .6973 .74137 L .683 .771 .917 r
F
.72748 .73716 m .70666 .7339 L .71949 .74115 L F
.57617 .49642 m .55748 .47847 L .55706 .48575 L .858 .601 .549 r
F
.57575 .5037 m .57617 .49642 L .55706 .48575 L F
0 g
.57617 .49642 m
.59059 .50977 L
s
.70666 .7339 m .69679 .7368 L .6973 .74137 L .407 .262 .571 r
F
0 g
.6912 .74981 m
.6973 .74137 L
s
.70666 .7339 m .70615 .72933 L .69679 .7368 L .407 .262 .571 r
F
0 g
.6907 .74524 m
.69679 .7368 L
s
.75407 .84916 m .76352 .84363 L .76329 .8474 L .598 .382 .559 r
F
.75122 .84159 m .75407 .84916 L .76329 .8474 L .645 .732 .913 r
F
.127 .923 .03 r
.79881 .79307 m
.79898 .78952 L
s
0 g
.74549 .84934 m
.75407 .84916 L
s
.49265 .50319 m .48532 .48322 L .46232 .4881 L .654 .726 .902 r
F
.50898 .50267 m .48532 .48322 L .49265 .50319 L F
.22586 .49491 m .19238 .4928 L .22257 .49963 L F
.52518 .5049 m .50982 .48243 L .50898 .50267 L F
.52518 .5049 m .53415 .48577 L .50982 .48243 L F
.28328 .50281 m .30787 .48907 L .2803 .49776 L F
.28328 .50281 m .31381 .49916 L .30787 .48907 L F
.45871 .59516 m .43162 .60351 L .45664 .60306 L .673 .757 .914 r
F
.48269 .59866 m .45871 .59516 L .45664 .60306 L F
.53212 .60736 m .55594 .59903 L .53146 .60343 L F
.71798 .84109 m .72583 .84142 L .72559 .84519 L .856 .609 .564 r
F
.127 .923 .03 r
.72227 .84127 m
.72234 .83954 L
s
.72367 .84133 m
.7237 .84027 L
s
.71798 .84109 m .71821 .83732 L .72583 .84142 L .856 .609 .564 r
F
.72738 .83244 m .72583 .84142 L .73246 .83518 L .645 .732 .913 r
F
.72738 .83244 m .71821 .83732 L .72583 .84142 L F
0 g
.72583 .84142 m
.72865 .84231 L
s
.33553 .73065 m .32631 .71914 L .32583 .7304 L .683 .77 .917 r
F
.33553 .73065 m .34087 .71951 L .32631 .71914 L F
.56228 .84625 m .55365 .84033 L .54744 .84472 L .644 .733 .913 r
F
.5676 .84413 m .55365 .84033 L .56228 .84625 L F
.38875 .47521 m .388 .49545 L .41248 .49466 L .654 .726 .902 r
F
.37253 .47298 m .388 .49545 L .38875 .47521 L F
.127 .923 .03 r
.38109 .52474 m
.38122 .5961 L
s
.38104 .4945 m
.38109 .52474 L
s
.37253 .47298 m .36367 .49211 L .388 .49545 L .654 .726 .902 r
F
.76352 .84363 m .77176 .83668 L .77153 .84045 L .502 .302 .541 r
F
.76329 .8474 m .76352 .84363 L .77153 .84045 L F
.7576 .83665 m .76352 .84363 L .77153 .84045 L .645 .732 .913 r
F
.75145 .83782 m .76352 .84363 L .7576 .83665 L F
0 g
.75774 .84473 m
.76352 .84363 L
s
.64556 .46389 m .61594 .47279 L .64638 .46916 L .654 .726 .902 r
F
.64556 .46389 m .61428 .46225 L .61594 .47279 L F
.30691 .83803 m .3055 .84701 L .31202 .84076 L .644 .733 .913 r
F
.30691 .83803 m .29782 .84291 L .3055 .84701 L F
0 g
.3055 .84701 m
.3145 .84983 L
s
.43589 .48251 m .43633 .47523 L .45624 .46659 L .492 .285 .526 r
F
0 g
.42577 .47747 m
.43633 .47523 L
s
.59782 .84834 m .59934 .83936 L .59274 .8456 L .644 .733 .913 r
F
.59782 .84834 m .60697 .84346 L .59934 .83936 L F
.127 .923 .03 r
.56099 .84233 m
.56103 .84045 L
s
.29227 .83404 m .29835 .83537 L .29809 .83914 L .924 .676 .545 r
F
.127 .923 .03 r
.25136 .8099 m
.25232 .86393 L
s
.29227 .83404 m .29253 .83027 L .29835 .83537 L .924 .676 .545 r
F
0 g
.29835 .83537 m
.30174 .83718 L
s
.78589 .72509 m .78538 .72052 L .77402 .71577 L .86 .591 .529 r
F
0 g
.78538 .72052 m
.79391 .72704 L
s
.34319 .84922 m .3514 .84227 L .35114 .84604 L .5 .299 .539 r
F
.33716 .84224 m .34319 .84922 L .35114 .84604 L .644 .733 .913 r
F
.127 .923 .03 r
.34721 .84967 m
.34837 .91079 L
s
.34717 .84762 m
.34721 .84967 L
s
.34544 .85021 m
.34577 .90425 L
s
.34542 .84833 m
.34544 .85021 L
s
.33104 .84341 m .34319 .84922 L .33716 .84224 L .644 .733 .913 r
F
0 g
.33401 .85097 m
.34319 .84922 L
s
.30366 .82706 m .29849 .8353 L .30752 .83044 L .644 .733 .913 r
F
.30366 .82706 m .2927 .83022 L .29849 .8353 L F
.30447 .60835 m .31655 .59297 L .31685 .59864 L .386 .233 .548 r
F
.28712 .59788 m .30447 .60835 L .31685 .59864 L .673 .757 .914 r
F
.27651 .60292 m .30447 .60835 L .28712 .59788 L F
0 g
.28856 .6159 m
.30447 .60835 L
s
.22633 .48763 m .19943 .47609 L .19285 .48552 L .654 .726 .902 r
F
.23146 .4837 m .19943 .47609 L .22633 .48763 L F
.73675 .47911 m .77068 .47043 L .7394 .46879 L F
.7068 .47232 m .73675 .47911 L .7394 .46879 L F
.70344 .47701 m .73675 .47911 L .7068 .47232 L F
.42114 .45668 m .4361 .47495 L .45591 .46636 L F
.4059 .45992 m .4361 .47495 L .42114 .45668 L F
.7357 .72539 m .73149 .71482 L .71776 .7189 L .683 .771 .917 r
F
.74543 .72412 m .73149 .71482 L .7357 .72539 L F
.3514 .84227 m .35166 .8385 L .35783 .83411 L .351 .177 .5 r
F
0 g
.34594 .84079 m
.35166 .8385 L
s
.127 .923 .03 r
.35614 .82356 m
.3562 .83527 L
s
.23204 .4765 m .21037 .46109 L .20017 .46892 L .654 .726 .902 r
F
.23862 .47364 m .21037 .46109 L .23204 .4765 L F
.28076 .49048 m .29862 .47287 L .27591 .48603 L F
.28076 .49048 m .30833 .48178 L .29862 .47287 L F
.34289 .83252 m .35153 .83841 L .35767 .83404 L .644 .733 .913 r
F
.127 .923 .03 r
.35639 .87404 m
.35834 1.26798 L
s
.35621 .83617 m
.35639 .87404 L
s
.33762 .83463 m .35153 .83841 L .34289 .83252 L .644 .733 .913 r
F
.27626 .47881 m .28611 .45863 L .26989 .47527 L .654 .726 .902 r
F
.27626 .47881 m .29885 .46572 L .28611 .45863 L F
.19943 .47609 m .16265 .4787 L .19285 .48552 L F
.5534 .8441 m .54744 .84472 L .54719 .84849 L .354 .18 .502 r
F
.5534 .8441 m .55365 .84033 L .54744 .84472 L F
0 g
.54342 .85002 m
.54744 .84472 L
s
.56791 .84043 m .56196 .83348 L .55403 .83665 L .645 .732 .913 r
F
.57401 .83926 m .56196 .83348 L .56791 .84043 L F
.74543 .72412 m .74609 .71291 L .73149 .71482 L .683 .771 .917 r
F
.72697 .73259 m .71814 .72334 L .70615 .72933 L F
.73617 .72986 m .71814 .72334 L .72697 .73259 L F
.36579 .72691 m .35385 .7176 L .35433 .72217 L .859 .591 .532 r
F
.36627 .73149 m .36579 .72691 L .35433 .72217 L F
0 g
.36579 .72691 m
.37444 .73343 L
s
.45871 .59516 m .43472 .59167 L .43162 .60351 L .673 .757 .914 r
F
.59291 .8419 m .59054 .83288 L .58695 .84003 L .645 .732 .913 r
F
.59291 .8419 m .59948 .83568 L .59054 .83288 L F
.43467 .5973 m .43125 .60352 L .43156 .6092 L 0 0 .32 r
F
0 g
.43196 .60766 m
.43222 .60918 L
s
.43467 .5973 m .43436 .59162 L .43125 .60352 L 0 0 .32 r
F
.50698 .60782 m .50118 .59319 L .49504 .59483 L .673 .757 .914 r
F
.127 .923 .03 r
.56255 .84275 m
.56257 .83996 L
s
.58272 .61212 m .58043 .59464 L .58075 .60032 L .825 .622 .07 r
F
.55758 .61258 m .58272 .61212 L .58075 .60032 L .673 .758 .914 r
F
0 g
.57954 .62401 m
.58272 .61212 L
s
.50898 .50267 m .50982 .48243 L .48532 .48322 L .654 .726 .902 r
F
.61273 .84855 m .60721 .83969 L .60697 .84346 L .926 .677 .542 r
F
.61249 .85232 m .61273 .84855 L .60697 .84346 L F
0 g
.61273 .84855 m
.61623 .8543 L
s
.31427 .49188 m .33591 .47308 L .30833 .48178 L .654 .726 .902 r
F
.31427 .49188 m .34481 .48823 L .33591 .47308 L F
0 g
.34367 .47824 m
.34437 .47846 L
s
.34437 .47846 m
.34508 .4787 L
s
.76507 .73516 m .76165 .72226 L .75614 .7334 L .683 .771 .917 r
F
.76507 .73516 m .77505 .72491 L .76165 .72226 L F
.31606 .73168 m .31165 .72106 L .29789 .72516 L .683 .77 .917 r
F
.32583 .7304 m .31165 .72106 L .31606 .73168 L F
.30737 .73898 m .29837 .72973 L .28646 .73572 L F
.31654 .73625 m .29837 .72973 L .30737 .73898 L F
.53102 .59777 m .55074 .58616 L .5287 .59416 L .673 .757 .914 r
F
.53102 .59777 m .55537 .5934 L .55074 .58616 L F
.32583 .7304 m .32631 .71914 L .31165 .72106 L .683 .77 .917 r
F
.18612 .60103 m .19748 .60462 L .19777 .61029 L .93 .657 .499 r
F
.18612 .60103 m .18584 .59535 L .19748 .60462 L F
.2079 .58732 m .19748 .60462 L .21567 .5935 L .673 .757 .914 r
F
.2079 .58732 m .18584 .59535 L .19748 .60462 L F
0 g
.19748 .60462 m
.20297 .60711 L
s
.20017 .46892 m .17339 .45743 L .16358 .47152 L .654 .726 .902 r
F
.127 .923 .03 r
.19346 .44902 m
.19387 .46622 L
s
.75563 .72882 m .74661 .71731 L .74594 .72857 L .683 .771 .917 r
F
.75563 .72882 m .76114 .71769 L .74661 .71731 L F
.17251 .46453 m .16313 .47142 L .16265 .4787 L .054 0 .385 r
F
.17251 .46453 m .17298 .45725 L .16313 .47142 L F
0 g
.15946 .48696 m
.16313 .47142 L
s
.48289 .60431 m .4567 .60874 L .48184 .60828 L .673 .757 .914 r
F
.55758 .61258 m .58075 .60032 L .55626 .60471 L .673 .758 .914 r
F
.53244 .61304 m .55758 .61258 L .55626 .60471 L F
.72715 .83621 m .72559 .84519 L .73223 .83895 L .645 .732 .913 r
F
.72715 .83621 m .71798 .84109 L .72559 .84519 L F
0 g
.72559 .84519 m
.73456 .84801 L
s
.127 .923 .03 r
.71942 .98965 m
.72323 .85653 L
s
.72323 .85653 m
.72359 .84411 L
s
.71503 1.02215 m
.72164 .85703 L
s
.72164 .85703 m
.72218 .84335 L
s
.71247 .83222 m .71845 .83355 L .71821 .83732 L .926 .677 .541 r
F
.71247 .83222 m .7127 .82845 L .71845 .83355 L F
0 g
.71845 .83355 m
.72185 .83538 L
s
.31911 .82695 m .31261 .83316 L .31859 .83503 L .644 .733 .913 r
F
.56204 .85002 m .5534 .8441 L .54719 .84849 L F
0 g
.54317 .85379 m
.54719 .84849 L
s
.56736 .8479 m .5534 .8441 L .56204 .85002 L .644 .733 .913 r
F
.32857 .82826 m .33153 .83579 L .33762 .83463 L F
.32533 .82833 m .33153 .83579 L .32857 .82826 L F
.76329 .8474 m .77153 .84045 L .7713 .84422 L .502 .302 .541 r
F
.75737 .84042 m .76329 .8474 L .7713 .84422 L .645 .732 .913 r
F
.75122 .84159 m .76329 .8474 L .75737 .84042 L F
0 g
.75407 .84916 m
.76329 .8474 L
s
.7239 .82524 m .71858 .83348 L .72771 .82862 L .645 .732 .913 r
F
.7239 .82524 m .71287 .82841 L .71858 .83348 L F
.3575 .46813 m .36367 .49211 L .37253 .47298 L .654 .726 .902 r
F
0 g
.36367 .49211 m
.388 .49545 L
s
.59758 .85211 m .59909 .84313 L .59249 .84937 L .644 .733 .913 r
F
.59758 .85211 m .60673 .84723 L .59909 .84313 L F
.77153 .84045 m .77176 .83668 L .77801 .83229 L .357 .184 .504 r
F
0 g
.76604 .83895 m
.77176 .83668 L
s
.292 .83781 m .29809 .83914 L .29782 .84291 L .924 .676 .545 r
F
.292 .83781 m .29227 .83404 L .29809 .83914 L F
.30329 .83086 m .29809 .83914 L .30717 .83426 L .644 .733 .913 r
F
.30329 .83086 m .29227 .83404 L .29809 .83914 L F
0 g
.29809 .83914 m
.30147 .84095 L
s
.41248 .49466 m .43589 .48251 L .43545 .48979 L .592 .367 .545 r
F
.40508 .47468 m .41248 .49466 L .43545 .48979 L .654 .726 .902 r
F
.38875 .47521 m .41248 .49466 L .40508 .47468 L F
0 g
.388 .49545 m
.41248 .49466 L
s
.76308 .8307 m .77163 .83659 L .77785 .83222 L .645 .732 .913 r
F
.75777 .83281 m .77163 .83659 L .76308 .8307 L F
0 g
.67903 .39317 m
.67923 .44555 L
s
.33601 .73522 m .32678 .72371 L .32631 .73497 L .683 .77 .917 r
F
.33601 .73522 m .34135 .72409 L .32678 .72371 L F
.3514 .84227 m .35783 .83411 L .35757 .83788 L .351 .177 .5 r
F
.35114 .84604 m .3514 .84227 L .35757 .83788 L F
.34272 .83635 m .3514 .84227 L .35757 .83788 L .644 .733 .913 r
F
.33742 .83847 m .3514 .84227 L .34272 .83635 L F
0 g
.34568 .84456 m
.3514 .84227 L
s
.57401 .83926 m .57112 .83173 L .56196 .83348 L .645 .732 .913 r
F
.58051 .83913 m .57112 .83173 L .57401 .83926 L F
0 g
.6725 .39305 m
.67269 .44551 L
s
.58695 .84003 m .58087 .83153 L .58051 .83913 L .645 .732 .913 r
F
.58695 .84003 m .59054 .83288 L .58087 .83153 L F
.78589 .72509 m .77402 .71577 L .77454 .72034 L .86 .591 .529 r
F
.78641 .72966 m .78589 .72509 L .77454 .72034 L F
0 g
.78589 .72509 m
.79443 .73161 L
s
.5676 .84413 m .56163 .83715 L .55365 .84033 L .644 .733 .913 r
F
.127 .923 .03 r
.56091 .84614 m
.56096 .84398 L
s
.57374 .84296 m .56163 .83715 L .5676 .84413 L .644 .733 .913 r
F
.45878 .60081 m .43156 .6092 L .4567 .60874 L .673 .757 .914 r
F
.48289 .60431 m .45878 .60081 L .4567 .60874 L F
.53244 .61304 m .55626 .60471 L .53178 .6091 L .673 .758 .914 r
F
.73617 .72986 m .73194 .71924 L .71814 .72334 L .683 .771 .917 r
F
.74594 .72857 m .73194 .71924 L .73617 .72986 L F
.59274 .8456 m .59035 .83654 L .58675 .84372 L .644 .733 .913 r
F
.59274 .8456 m .59934 .83936 L .59035 .83654 L F
.29789 .72516 m .28551 .72658 L .28598 .73115 L .522 .344 .58 r
F
.29789 .72516 m .29742 .72059 L .28551 .72658 L F
0 g
.27626 .73405 m
.28551 .72658 L
s
.61314 .47679 m .58421 .49104 L .6148 .48739 L .654 .726 .902 r
F
.61314 .47679 m .58169 .47515 L .58421 .49104 L F
0 g
.58421 .49104 m
.59297 .50617 L
s
.61249 .85232 m .60697 .84346 L .60673 .84723 L .926 .677 .542 r
F
0 g
.61249 .85232 m
.61599 .85807 L
s
.58051 .83913 m .58087 .83153 L .57112 .83173 L .645 .732 .913 r
F
.72748 .73716 m .71865 .72791 L .70666 .7339 L .683 .771 .917 r
F
.73668 .73443 m .71865 .72791 L .72748 .73716 L F
.36627 .73149 m .35433 .72217 L .35481 .72674 L .859 .591 .532 r
F
0 g
.36627 .73149 m
.37492 .738 L
s
.127 .923 .03 r
.36479 .70403 m
.36555 .90354 L
s
.23899 .5847 m .22591 .59816 L .23793 .60099 L .673 .757 .914 r
F
.74594 .72857 m .74661 .71731 L .73194 .71924 L .683 .771 .917 r
F
.127 .923 .03 r
.28238 .59064 m
.28269 .59417 L
s
.48536 .59495 m .45871 .59516 L .48269 .59866 L .673 .757 .914 r
F
.32506 .83214 m .32478 .83978 L .3313 .83964 L .644 .733 .913 r
F
.32182 .83169 m .32478 .83978 L .32506 .83214 L F
.32182 .83169 m .31829 .83887 L .32478 .83978 L F
.31654 .73625 m .31212 .72564 L .29837 .72973 L .683 .77 .917 r
F
.32631 .73497 m .31212 .72564 L .31654 .73625 L F
.76635 .50057 m .77076 .47774 L .77037 .48502 L 0 0 .159 r
F
.73626 .49374 m .76635 .50057 L .77037 .48502 L .654 .726 .902 r
F
0 g
.7562 .51471 m
.76635 .50057 L
s
.57575 .5037 m .55706 .48575 L .55664 .49303 L .858 .601 .549 r
F
0 g
.57575 .5037 m
.59017 .51705 L
s
.31657 .82559 m .30752 .83044 L .31261 .83316 L .644 .733 .913 r
F
.32631 .73497 m .32678 .72371 L .31212 .72564 L .683 .77 .917 r
F
.43498 .60298 m .43156 .6092 L .43187 .61487 L 0 0 .32 r
F
0 g
.43227 .61333 m
.43253 .61486 L
s
.45878 .60081 m .43467 .5973 L .43156 .6092 L .673 .757 .914 r
F
.43498 .60298 m .43467 .5973 L .43156 .6092 L 0 0 .32 r
F
.23862 .47364 m .22353 .45536 L .21037 .46109 L .654 .726 .902 r
F
.24622 .47202 m .22353 .45536 L .23862 .47364 L F
.33162 .82768 m .33762 .83463 L .34289 .83252 L .644 .733 .913 r
F
.32857 .82826 m .33762 .83463 L .33162 .82768 L F
.74881 .82644 m .75166 .83398 L .75777 .83281 L .645 .732 .913 r
F
.127 .923 .03 r
.49419 8.79983 m
.50954 7.2051 L
s
.50954 7.2051 m
.51165 6.98614 L
s
.57106 .81187 m
.573 .61 L
s
.39977 8.82563 m
.50161 3.99574 L
s
.56873 .81286 m
.573 .61 L
s
.50161 3.99574 m
.52361 2.95267 L
s
.26989 .47527 m .27115 .45381 L .26241 .47287 L .654 .726 .902 r
F
.26989 .47527 m .28611 .45863 L .27115 .45381 L F
.31882 .83075 m .31829 .83887 L .32182 .83169 L .644 .733 .913 r
F
.31882 .83075 m .31229 .83699 L .31829 .83887 L F
.32833 .83207 m .3313 .83964 L .33742 .83847 L F
.32506 .83214 m .3313 .83964 L .32833 .83207 L F
.71223 .83599 m .71821 .83732 L .71798 .84109 L .926 .677 .541 r
F
.71223 .83599 m .71247 .83222 L .71821 .83732 L F
.72355 .82904 m .71821 .83732 L .72738 .83244 L .645 .732 .913 r
F
.72355 .82904 m .71247 .83222 L .71821 .83732 L F
0 g
.71821 .83732 m
.72162 .83915 L
s
.56163 .83715 m .5539 .83656 L .55365 .84033 L .501 .301 .54 r
F
.56163 .83715 m .56187 .83338 L .5539 .83656 L F
0 g
.54769 .84095 m
.5539 .83656 L
s
.75614 .7334 m .74712 .72188 L .74646 .73315 L .683 .771 .917 r
F
.75614 .7334 m .76165 .72226 L .74712 .72188 L F
.34516 .45372 m .3416 .47757 L .35795 .46085 L .654 .726 .902 r
F
.77153 .84045 m .77801 .83229 L .77778 .83606 L .357 .184 .504 r
F
.7713 .84422 m .77153 .84045 L .77778 .83606 L F
.76294 .83453 m .77153 .84045 L .77778 .83606 L .645 .732 .913 r
F
.7576 .83665 m .77153 .84045 L .76294 .83453 L F
0 g
.76581 .84272 m
.77153 .84045 L
s
.30303 .83463 m .29782 .84291 L .30691 .83803 L .644 .733 .913 r
F
.30303 .83463 m .292 .83781 L .29782 .84291 L F
0 g
.29782 .84291 m
.3055 .84701 L
s
.64499 .47116 m .61522 .48011 L .64582 .47646 L .654 .726 .902 r
F
.64499 .47116 m .61355 .46951 L .61522 .48011 L F
.60697 .84346 m .60721 .83969 L .59958 .83559 L .856 .609 .564 r
F
0 g
.60721 .83969 m
.61297 .84479 L
s
.53146 .60343 m .55129 .59176 L .52913 .59979 L .673 .757 .914 r
F
.53146 .60343 m .55594 .59903 L .55129 .59176 L F
.43589 .48251 m .45624 .46659 L .4558 .47387 L .492 .285 .526 r
F
.43545 .48979 m .43589 .48251 L .4558 .47387 L F
.42085 .46414 m .43589 .48251 L .4558 .47387 L .654 .726 .902 r
F
.40553 .4674 m .43589 .48251 L .42085 .46414 L F
0 g
.42532 .48475 m
.43589 .48251 L
s
.35114 .84604 m .35757 .83788 L .35731 .84165 L .351 .177 .5 r
F
.34246 .84012 m .35114 .84604 L .35731 .84165 L .644 .733 .913 r
F
.33716 .84224 m .35114 .84604 L .34246 .84012 L F
0 g
.34319 .84922 m
.35114 .84604 L
s
.20819 .59299 m .19777 .61029 L .21596 .59917 L .673 .757 .914 r
F
.20819 .59299 m .18612 .60103 L .19777 .61029 L F
0 g
.19777 .61029 m
.21313 .61728 L
s
.127 .923 .03 r
.19147 .6062 m
.19203 .62902 L
s
.19145 .60527 m
.19147 .6062 L
s
.24529 .5918 m .23822 .60667 L .2512 .60747 L .673 .757 .914 r
F
.57374 .84296 m .57083 .83539 L .56163 .83715 L .644 .733 .913 r
F
.58027 .84282 m .57083 .83539 L .57374 .84296 L F
.73665 .48646 m .77076 .47774 L .73932 .47609 L .654 .726 .902 r
F
.70655 .47963 m .73665 .48646 L .73932 .47609 L F
.58675 .84372 m .58063 .83518 L .58027 .84282 L .644 .733 .913 r
F
.58675 .84372 m .59035 .83654 L .58063 .83518 L F
.22586 .49491 m .19896 .48337 L .19238 .4928 L .654 .726 .902 r
F
.23099 .49098 m .19896 .48337 L .22586 .49491 L F
.31655 .59297 m .31625 .58729 L .32424 .5761 L .162 .067 .492 r
F
0 g
.30925 .59278 m
.31625 .58729 L
s
.71814 .72334 m .70564 .72475 L .70615 .72933 L .524 .346 .582 r
F
.71814 .72334 m .71763 .71876 L .70564 .72475 L F
0 g
.69628 .73223 m
.70564 .72475 L
s
.23146 .4837 m .20968 .46822 L .19943 .47609 L .654 .726 .902 r
F
.23807 .48083 m .20968 .46822 L .23146 .4837 L F
.2803 .49776 m .29816 .48015 L .27545 .49331 L F
.2803 .49776 m .30787 .48907 L .29816 .48015 L F
0 0 0 r
2.5 Mabswid
.56089 .84751 Mdot
.127 .923 .03 r
.5 Mabswid
.39961 8.82693 m
.55549 1.11441 L
s
.4832 .60999 m .45701 .61441 L .48216 .61396 L .673 .758 .914 r
F
.56736 .8479 m .56138 .84092 L .5534 .8441 L .644 .733 .913 r
F
.127 .923 .03 r
.55549 1.11441 m
.56089 .84751 L
s
.57349 .84673 m .56138 .84092 L .56736 .8479 L .644 .733 .913 r
F
.29456 .57998 m .31593 .58719 L .32388 .57605 L .673 .757 .914 r
F
.127 .923 .03 r
.31043 .51777 m
.31516 .57722 L
s
.31421 .52576 m
.31535 .57719 L
s
.31421 .52576 m
.31471 .57728 L
s
.28635 .58642 m .31593 .58719 L .29456 .57998 L .673 .757 .914 r
F
.27591 .48603 m .28581 .46575 L .2695 .48247 L .654 .726 .902 r
F
.27591 .48603 m .29862 .47287 L .28581 .46575 L F
.78641 .72966 m .77454 .72034 L .77505 .72491 L .86 .591 .529 r
F
0 g
.78641 .72966 m
.79494 .73618 L
s
.59249 .84937 m .59011 .84031 L .5865 .84749 L .644 .733 .913 r
F
.59249 .84937 m .59909 .84313 L .59011 .84031 L F
.19896 .48337 m .16217 .48598 L .19238 .4928 L .654 .726 .902 r
F
.55537 .5934 m .5728 .57817 L .55074 .58616 L .673 .757 .914 r
F
.55537 .5934 m .57974 .58903 L .5728 .57817 L F
.48575 .47594 m .46319 .47354 L .46276 .48082 L .592 .368 .545 r
F
.48575 .47594 m .48618 .46866 L .46319 .47354 L F
0 g
.44758 .48031 m
.46319 .47354 L
s
.50515 .71342 m .50465 .70885 L .51931 .70692 L .673 .453 .579 r
F
.4906 .71304 m .50465 .70885 L .50515 .71342 L .733 .497 .571 r
F
.4906 .71304 m .49011 .70847 L .50465 .70885 L F
.74533 .83032 m .74492 .83796 L .75145 .83782 L .645 .732 .913 r
F
.58027 .84282 m .58063 .83518 L .57083 .83539 L .644 .733 .913 r
F
.50521 .69746 m .50466 .70868 L .51925 .70676 L .683 .77 .917 r
F
.49556 .69721 m .50466 .70868 L .50521 .69746 L F
.49556 .69721 m .49019 .7083 L .50466 .70868 L F
.25832 .59156 m .26425 .60619 L .27651 .60292 L .673 .757 .914 r
F
.55706 .48575 m .55748 .47847 L .535 .47121 L .794 .542 .557 r
F
0 g
.55748 .47847 m
.57658 .48914 L
s
.26415 .58425 m .27621 .59724 L .28682 .5922 L .673 .757 .914 r
F
.73668 .73443 m .73245 .72381 L .71865 .72791 L .683 .771 .917 r
F
.74646 .73315 m .73245 .72381 L .73668 .73443 L F
.31381 .49916 m .33546 .48036 L .30787 .48907 L .654 .726 .902 r
F
.31381 .49916 m .34436 .49551 L .33546 .48036 L F
0 g
.04255 8.73353 m
.1128 .43644 L
s
.29837 .72973 m .28598 .73115 L .28646 .73572 L .522 .344 .58 r
F
0 g
.27721 .74319 m
.28646 .73572 L
s
.29837 .72973 m .29789 .72516 L .28598 .73115 L .522 .344 .58 r
F
0 g
.27673 .73862 m
.28598 .73115 L
s
.35433 .72217 m .35385 .7176 L .34039 .71494 L .794 .542 .557 r
F
0 g
.35385 .7176 m
.3653 .72234 L
s
.3248 .83591 m .32451 .84355 L .33104 .84341 L .644 .733 .913 r
F
.32156 .83546 m .32451 .84355 L .3248 .83591 L F
.32156 .83546 m .31803 .84264 L .32451 .84355 L F
.5198 .71149 m .51931 .70692 L .53309 .70282 L .606 .405 .583 r
F
.50515 .71342 m .51931 .70692 L .5198 .71149 L .673 .453 .579 r
F
0 g
.50465 .70885 m
.51931 .70692 L
s
.127 .923 .03 r
.49472 8.79955 m
.55969 1.17867 L
s
.55969 1.17867 m
.56251 .84699 L
s
0 0 0 r
2.5 Mabswid
.56251 .84699 Mdot
.74646 .73315 m .74712 .72188 L .73245 .72381 L .683 .771 .917 r
F
.2887 .82829 m .29253 .83027 L .29227 .83404 L .989 .751 .482 r
F
.2887 .82829 m .28896 .82452 L .29253 .83027 L F
0 g
.5 Mabswid
.29253 .83027 m
.2957 .83305 L
s
.75187 .82586 m .75777 .83281 L .76308 .8307 L .645 .732 .913 r
F
.74881 .82644 m .75777 .83281 L .75187 .82586 L F
.3013 .82324 m .2927 .83022 L .30366 .82706 L .644 .733 .913 r
F
.3013 .82324 m .28915 .8245 L .2927 .83022 L F
.31626 .82938 m .31229 .83699 L .31882 .83075 L F
.31626 .82938 m .30717 .83426 L .31229 .83699 L F
.51494 .69618 m .51925 .70676 L .53295 .70268 L .683 .77 .917 r
F
.50521 .69746 m .51925 .70676 L .51494 .69618 L F
.5287 .59416 m .5431 .58001 L .52488 .59108 L .673 .757 .914 r
F
.5287 .59416 m .55074 .58616 L .5431 .58001 L F
.7391 .82893 m .73246 .83518 L .73844 .83706 L .645 .732 .913 r
F
.7068 .47232 m .7394 .46879 L .70812 .46716 L .654 .726 .902 r
F
.33139 .83149 m .33742 .83847 L .34272 .83635 L .644 .733 .913 r
F
.32833 .83207 m .33742 .83847 L .33139 .83149 L F
.45909 .60648 m .43187 .61487 L .45701 .61441 L .673 .758 .914 r
F
.4832 .60999 m .45909 .60648 L .45701 .61441 L F
.7486 .83025 m .75145 .83782 L .7576 .83665 L .645 .732 .913 r
F
.74533 .83032 m .75145 .83782 L .7486 .83025 L F
.35757 .83788 m .35783 .83411 L .36181 .8288 L .078 0 .403 r
F
.127 .923 .03 r
.35725 2.54738 m
.3955 8.82573 L
s
0 g
.35317 .83742 m
.35783 .83411 L
s
.127 .923 .03 r
.28287 .59633 m
.28317 .59976 L
s
.34699 .8296 m .35767 .83404 L .36163 .82876 L .644 .733 .913 r
F
.34289 .83252 m .35767 .83404 L .34699 .8296 L F
.24622 .47202 m .23875 .45212 L .22353 .45536 L .654 .726 .902 r
F
.25434 .47176 m .23875 .45212 L .24622 .47202 L F
.39039 .35145 m .39183 .40977 L .39024 .40998 L .641 .4 .539 r
F
.39039 .35145 m .39197 .35124 L .39183 .40977 L F
.38881 .35119 m .39039 .35145 L .39024 .40998 L .751 .491 .538 r
F
0 g
.39039 .35145 m
.39039 .35145 L
s
.31855 .83452 m .31803 .84264 L .32156 .83546 L .644 .733 .913 r
F
.31855 .83452 m .31202 .84076 L .31803 .84264 L F
.26241 .47287 m .255 .45159 L .25434 .47176 L .654 .726 .902 r
F
.26241 .47287 m .27115 .45381 L .255 .45159 L F
.32806 .83584 m .33104 .84341 L .33716 .84224 L .644 .733 .913 r
F
.3248 .83591 m .33104 .84341 L .32806 .83584 L F
.72332 .83281 m .71798 .84109 L .72715 .83621 L .645 .732 .913 r
F
.72332 .83281 m .71223 .83599 L .71798 .84109 L F
0 g
.71798 .84109 m
.72559 .84519 L
s
.19943 .47609 m .17251 .46453 L .16265 .4787 L .654 .726 .902 r
F
.17203 .47181 m .16265 .4787 L .16217 .48598 L .054 0 .385 r
F
.17203 .47181 m .17251 .46453 L .16265 .4787 L F
0 g
.15898 .49424 m
.16265 .4787 L
s
.127 .923 .03 r
.19394 .46935 m
.19405 .47378 L
s
.56138 .84092 m .55365 .84033 L .5534 .8441 L .501 .301 .54 r
F
0 g
.54719 .84849 m
.5534 .8441 L
s
.56138 .84092 m .56163 .83715 L .55365 .84033 L .501 .301 .54 r
F
0 g
.54744 .84472 m
.55365 .84033 L
s
.39197 .35124 m .39286 .40933 L .39183 .40977 L .515 .301 .526 r
F
.39197 .35124 m .393 .3508 L .39286 .40933 L F
0 g
.39039 .35145 m
.39197 .35124 L
s
.38881 .35119 m .39024 .40998 L .38867 .40971 L .751 .491 .538 r
F
.38783 .35071 m .38881 .35119 L .38867 .40971 L .845 .571 .524 r
F
0 g
.38881 .35119 m
.39039 .35145 L
s
.27898 .37529 m
.31013 .36383 L
s
.23928 .59038 m .23822 .60667 L .24529 .5918 L .673 .757 .914 r
F
.23928 .59038 m .2262 .60384 L .23822 .60667 L F
.7713 .84422 m .77778 .83606 L .77755 .83983 L .357 .184 .504 r
F
.7627 .8383 m .7713 .84422 L .77755 .83983 L .645 .732 .913 r
F
.75737 .84042 m .7713 .84422 L .7627 .8383 L F
0 g
.76329 .8474 m
.7713 .84422 L
s
.48557 .60059 m .45878 .60081 L .48289 .60431 L .673 .757 .914 r
F
.60697 .84346 m .59958 .83559 L .59934 .83936 L .856 .609 .564 r
F
.60673 .84723 m .60697 .84346 L .59934 .83936 L F
0 g
.60697 .84346 m
.61273 .84855 L
s
.31464 .82389 m .30366 .82706 L .30752 .83044 L .644 .733 .913 r
F
.21037 .46109 m .17339 .45743 L .20017 .46892 L .654 .726 .902 r
F
.34436 .49551 m .34481 .48823 L .33591 .47308 L .989 .743 .461 r
F
0 g
.34392 .48574 m
.34463 .48598 L
s
.34245 .47616 m
.34431 .47933 L
s
.34463 .48598 m
.36367 .49211 L
s
.34481 .48823 m
.34746 .5041 L
s
.34386 .48661 m
.34481 .48823 L
s
.393 .3508 m .39357 .40876 L .39286 .40933 L .354 .175 .495 r
F
0 g
.54645 .27687 m
.6116 .2529 L
s
.393 .3508 m .3937 .35023 L .39357 .40876 L .354 .175 .495 r
F
0 g
.39197 .35124 m
.393 .3508 L
s
.57349 .84673 m .57059 .83916 L .56138 .84092 L .644 .733 .913 r
F
.127 .923 .03 r
.56622 .84699 m
.56627 .84484 L
s
.58002 .84659 m .57059 .83916 L .57349 .84673 L .644 .733 .913 r
F
.33425 .82662 m .34289 .83252 L .34699 .8296 L F
.33162 .82768 m .34289 .83252 L .33425 .82662 L F
.5865 .84749 m .58038 .83895 L .58002 .84659 L F
.5865 .84749 m .59011 .84031 L .58038 .83895 L F
.38783 .35071 m .38867 .40971 L .38768 .40924 L .845 .571 .524 r
F
.38716 .35011 m .38783 .35071 L .38768 .40924 L .929 .648 .488 r
F
0 g
.38783 .35071 m
.38881 .35119 L
s
.31013 .36383 m
.3357 .35442 L
s
.25434 .47176 m .255 .45159 L .23875 .45212 L .654 .726 .902 r
F
.67345 .59078 m .67311 .58511 L .69272 .58319 L .672 .449 .574 r
F
.65401 .58958 m .67311 .58511 L .67345 .59078 L .733 .496 .569 r
F
.127 .923 .03 r
.6628 .58752 m
.66758 .52622 L
s
.65531 .7549 m
.65648 .71789 L
s
.66056 .58804 m
.66202 .54164 L
s
.65787 .75413 m
.65892 .70173 L
s
.6612 .5879 m
.66212 .5416 L
s
.65401 .58958 m .65368 .5839 L .67311 .58511 L .733 .496 .569 r
F
.45909 .60648 m .43498 .60298 L .43187 .61487 L .673 .758 .914 r
F
0 g
.43187 .61487 m
.4339 .62667 L
s
.67396 .56967 m .67313 .58488 L .69263 .58297 L .673 .757 .914 r
F
.66106 .56887 m .67313 .58488 L .67396 .56967 L F
.127 .923 .03 r
.66689 .56923 m
.66829 .52545 L
s
.66106 .56887 m .65379 .58368 L .67313 .58488 L .673 .757 .914 r
F
.127 .923 .03 r
.66887 .56935 m
.67 .51567 L
s
.66893 .56936 m
.67069 .51495 L
s
.71865 .72791 m .70615 .72933 L .70666 .7339 L .524 .346 .582 r
F
0 g
.6973 .74137 m
.70666 .7339 L
s
.71865 .72791 m .71814 .72334 L .70615 .72933 L .524 .346 .582 r
F
0 g
.69679 .7368 m
.70615 .72933 L
s
.3937 .35023 m .394 .40807 L .39357 .40876 L .069 0 .411 r
F
.3937 .35023 m .39413 .34954 L .394 .40807 L F
0 g
.393 .3508 m
.3937 .35023 L
s
.47715 .71038 m .49011 .70847 L .4906 .71304 L .794 .542 .557 r
F
.47715 .71038 m .47666 .70581 L .49011 .70847 L F
0 g
.49011 .70847 m
.50465 .70885 L
s
.77454 .72034 m .77402 .71577 L .76063 .71312 L .794 .542 .556 r
F
0 g
.77402 .71577 m
.78538 .72052 L
s
.23387 .58237 m .22591 .59816 L .23899 .5847 L .673 .757 .914 r
F
.23387 .58237 m .21567 .5935 L .22591 .59816 L F
.58002 .84659 m .58038 .83895 L .57059 .83916 L .644 .733 .913 r
F
.38716 .35011 m .38768 .40924 L .38702 .40864 L .929 .648 .488 r
F
.38678 .34941 m .38716 .35011 L .38702 .40864 L .989 .72 .388 r
F
0 g
.38716 .35011 m
.38783 .35071 L
s
.3357 .35442 m
.35756 .34638 L
s
.50564 .71799 m .50515 .71342 L .5198 .71149 L .673 .453 .579 r
F
.49109 .71761 m .50515 .71342 L .50564 .71799 L .733 .497 .571 r
F
.49109 .71761 m .4906 .71304 L .50515 .71342 L F
.5057 .70215 m .50515 .71342 L .5198 .71149 L .683 .77 .917 r
F
.496 .70189 m .50515 .71342 L .5057 .70215 L F
.496 .70189 m .4906 .71304 L .50515 .71342 L F
.48664 .69545 m .49019 .7083 L .49556 .69721 L F
.48664 .69545 m .47681 .70566 L .49019 .7083 L F
.70899 .82647 m .7127 .82845 L .71247 .83222 L .99 .751 .473 r
F
.70899 .82647 m .70922 .8227 L .7127 .82845 L F
0 g
.7127 .82845 m
.71585 .83125 L
s
.53178 .6091 m .55161 .59744 L .52945 .60547 L .673 .758 .914 r
F
.53178 .6091 m .55626 .60471 L .55161 .59744 L F
.48536 .59495 m .46405 .58774 L .45871 .59516 L .673 .757 .914 r
F
.48949 .59173 m .46405 .58774 L .48536 .59495 L F
.72159 .82143 m .71287 .82841 L .7239 .82524 L .645 .732 .913 r
F
.72159 .82143 m .70941 .82268 L .71287 .82841 L F
.26908 .57599 m .28635 .58642 L .29456 .57998 L .673 .757 .914 r
F
.75167 .82967 m .7576 .83665 L .76294 .83453 L .645 .732 .913 r
F
.7486 .83025 m .7576 .83665 L .75167 .82967 L F
.28844 .83206 m .29227 .83404 L .292 .83781 L .989 .751 .482 r
F
.28844 .83206 m .2887 .82829 L .29227 .83404 L F
.30091 .82703 m .29227 .83404 L .30329 .83086 L .644 .733 .913 r
F
.30091 .82703 m .2887 .82829 L .29227 .83404 L F
0 g
.29227 .83404 m
.29544 .83682 L
s
.77778 .83606 m .77801 .83229 L .78208 .82698 L .095 0 .413 r
F
0 g
.7733 .8356 m
.77801 .83229 L
s
.316 .83315 m .31202 .84076 L .31855 .83452 L .644 .733 .913 r
F
.316 .83315 m .30691 .83803 L .31202 .84076 L F
.76723 .82779 m .77785 .83222 L .7819 .82694 L .645 .732 .913 r
F
.76308 .8307 m .77785 .83222 L .76723 .82779 L F
.31655 .59297 m .32424 .5761 L .32454 .58178 L .162 .067 .492 r
F
.31685 .59864 m .31655 .59297 L .32454 .58178 L F
.29507 .58573 m .31655 .59297 L .32454 .58178 L .673 .757 .914 r
F
.28682 .5922 m .31655 .59297 L .29507 .58573 L F
0 g
.30955 .59846 m
.31655 .59297 L
s
.69306 .58886 m .69272 .58319 L .71117 .57828 L .603 .397 .574 r
F
.67345 .59078 m .69272 .58319 L .69306 .58886 L .672 .449 .574 r
F
0 g
.67311 .58511 m
.69272 .58319 L
s
.35433 .72217 m .34039 .71494 L .34087 .71951 L .794 .542 .557 r
F
.35481 .72674 m .35433 .72217 L .34087 .71951 L F
0 g
.35433 .72217 m
.36579 .72691 L
s
.73886 .8327 m .73821 .84083 L .74186 .83364 L .645 .732 .913 r
F
.73886 .8327 m .73223 .83895 L .73821 .84083 L F
.39413 .34954 m .39411 .40725 L .394 .40807 L 0 0 .133 r
F
.39413 .34954 m .39425 .34872 L .39411 .40725 L F
0 g
.3937 .35023 m
.39413 .34954 L
s
.33112 .83526 m .33716 .84224 L .34246 .84012 L .644 .733 .913 r
F
.32806 .83584 m .33716 .84224 L .33112 .83526 L F
.74836 .83402 m .75122 .84159 L .75737 .84042 L .645 .732 .913 r
F
.7451 .83409 m .75122 .84159 L .74836 .83402 L F
.5198 .71149 m .53309 .70282 L .53358 .70739 L .606 .405 .583 r
F
.5203 .71606 m .5198 .71149 L .53358 .70739 L F
.50564 .71799 m .5198 .71149 L .5203 .71606 L .673 .453 .579 r
F
.51548 .70086 m .5198 .71149 L .53358 .70739 L .683 .77 .917 r
F
.5057 .70215 m .5198 .71149 L .51548 .70086 L F
0 g
.50515 .71342 m
.5198 .71149 L
s
.35757 .83788 m .36181 .8288 L .36155 .83257 L .078 0 .403 r
F
.35731 .84165 m .35757 .83788 L .36155 .83257 L F
.34683 .83342 m .35757 .83788 L .36155 .83257 L .644 .733 .913 r
F
.34272 .83635 m .35757 .83788 L .34683 .83342 L F
0 g
.35291 .84119 m
.35757 .83788 L
s
.38678 .34941 m .38702 .40864 L .38664 .40794 L .989 .72 .388 r
F
.38673 .34859 m .38678 .34941 L .38664 .40794 L .79 .631 .071 r
F
0 g
.38678 .34941 m
.38716 .35011 L
s
.68697 .5684 m .69263 .58297 L .71099 .57808 L .673 .757 .914 r
F
.67396 .56967 m .69263 .58297 L .68697 .5684 L F
.55594 .59903 m .57345 .58372 L .55129 .59176 L F
.55594 .59903 m .58043 .59464 L .57345 .58372 L F
.23807 .48083 m .22291 .46246 L .20968 .46822 L .654 .726 .902 r
F
.24572 .4792 m .22291 .46246 L .23807 .48083 L F
.26444 .58992 m .27651 .60292 L .28712 .59788 L .673 .757 .914 r
F
.127 .923 .03 r
.28243 .59566 m
.28244 .59624 L
s
.25832 .59156 m .27651 .60292 L .26444 .58992 L .673 .757 .914 r
F
.73493 .82207 m .7239 .82524 L .72771 .82862 L .645 .732 .913 r
F
.2695 .48247 m .27078 .4609 L .26199 .48005 L .654 .726 .902 r
F
.2695 .48247 m .28581 .46575 L .27078 .4609 L F
.57083 .83539 m .56187 .83338 L .56163 .83715 L .597 .381 .558 r
F
.57083 .83539 m .57108 .83162 L .56187 .83338 L F
0 g
.5539 .83656 m
.56187 .83338 L
s
.60673 .84723 m .59934 .83936 L .59909 .84313 L .856 .609 .564 r
F
0 g
.60673 .84723 m
.61249 .85232 L
s
.127 .923 .03 r
.60593 1.40229 m
.62388 .75271 L
s
.75453 .82481 m .76308 .8307 L .76723 .82779 L .645 .732 .913 r
F
.75187 .82586 m .76308 .8307 L .75453 .82481 L F
.31432 .82768 m .30717 .83426 L .31626 .82938 L .644 .733 .913 r
F
.31432 .82768 m .30329 .83086 L .30717 .83426 L F
.59934 .83936 m .59958 .83559 L .5906 .83277 L .793 .551 .572 r
F
0 g
.59958 .83559 m
.60721 .83969 L
s
.34471 .46101 m .34115 .48485 L .3575 .46813 L .654 .726 .902 r
F
.127 .923 .03 r
.33732 1.23009 m
.44909 2.53122 L
s
0 0 0 r
2.5 Mabswid
.28339 .60234 Mdot
.64458 .47844 m .6148 .48739 L .64541 .48374 L .654 .726 .902 r
F
.64458 .47844 m .61314 .47679 L .6148 .48739 L F
.33404 .83042 m .34272 .83635 L .34683 .83342 L .644 .733 .913 r
F
.127 .923 .03 r
.5 Mabswid
.29745 .76598 m
.2978 .77005 L
s
.33139 .83149 m .34272 .83635 L .33404 .83042 L .644 .733 .913 r
F
.58043 .59464 m .5801 .58896 L .57313 .57805 L .986 .711 .379 r
F
0 g
.5801 .58896 m
.58207 .60077 L
s
.39425 .34872 m .39366 .4062 L .39411 .40725 L .985 .728 .342 r
F
.39425 .34872 m .3938 .34767 L .39366 .4062 L F
.31165 .72106 m .29742 .72059 L .29789 .72516 L .606 .405 .582 r
F
.31165 .72106 m .31117 .71649 L .29742 .72059 L F
0 g
.28551 .72658 m
.29742 .72059 L
s
.127 .923 .03 r
.29128 .69423 m
.29745 .76598 L
s
.53358 .70739 m .53309 .70282 L .54504 .69683 L .523 .345 .581 r
F
0 g
.52642 .70481 m
.53309 .70282 L
s
.43545 .48979 m .4558 .47387 L .45536 .48116 L .492 .285 .526 r
F
.42041 .47142 m .43545 .48979 L .45536 .48116 L .654 .726 .902 r
F
.40508 .47468 m .43545 .48979 L .42041 .47142 L F
0 g
.41248 .49466 m
.43545 .48979 L
s
.38673 .34859 m .38664 .40794 L .38658 .40712 L .79 .631 .071 r
F
.38726 .34755 m .38673 .34859 L .38658 .40712 L 0 0 .372 r
F
.52913 .59979 m .54361 .58558 L .52529 .5967 L .673 .757 .914 r
F
.52913 .59979 m .55129 .59176 L .54361 .58558 L F
.46405 .58774 m .43472 .59167 L .45871 .59516 L F
.52408 .69346 m .53295 .70268 L .54485 .69672 L .683 .77 .917 r
F
.51494 .69618 m .53295 .70268 L .52408 .69346 L F
.73626 .49374 m .77037 .48502 L .73892 .48337 L .654 .726 .902 r
F
.70615 .48691 m .73626 .49374 L .73892 .48337 L F
.70277 .49163 m .73626 .49374 L .70615 .48691 L F
.23099 .49098 m .20921 .4755 L .19896 .48337 L F
.2376 .48811 m .20921 .4755 L .23099 .49098 L F
0 0 0 r
2.5 Mabswid
.33323 .72977 Mdot
.127 .923 .03 r
.5 Mabswid
.33323 .72977 m
.33372 .79363 L
s
.27545 .49331 m .28535 .47303 L .26904 .48975 L .654 .726 .902 r
F
.27545 .49331 m .29816 .48015 L .28535 .47303 L F
.63606 .58533 m .65368 .5839 L .65401 .58958 L .794 .544 .559 r
F
.63606 .58533 m .63573 .57965 L .65368 .5839 L F
0 g
.65368 .5839 m
.67311 .58511 L
s
.48532 .48322 m .46276 .48082 L .46232 .4881 L .592 .368 .545 r
F
0 g
.44241 .49673 m
.46232 .4881 L
s
.48532 .48322 m .48575 .47594 L .46276 .48082 L .592 .368 .545 r
F
0 g
.44285 .48944 m
.46276 .48082 L
s
.48589 .60626 m .45909 .60648 L .4832 .60999 L .673 .758 .914 r
F
.127 .923 .03 r
.33411 .72944 m
.33541 .79315 L
s
0 0 0 r
2.5 Mabswid
.33411 .72944 Mdot
.70875 .83024 m .71247 .83222 L .71223 .83599 L .99 .751 .473 r
F
.70875 .83024 m .70899 .82647 L .71247 .83222 L F
.72124 .82521 m .71247 .83222 L .72355 .82904 L .645 .732 .913 r
F
.72124 .82521 m .70899 .82647 L .71247 .83222 L F
0 g
.5 Mabswid
.71247 .83222 m
.71562 .83502 L
s
.52488 .59108 m .53297 .57537 L .51981 .58876 L .673 .757 .914 r
F
.52488 .59108 m .5431 .58001 L .53297 .57537 L F
.73632 .83133 m .73223 .83895 L .73886 .8327 L .645 .732 .913 r
F
.73632 .83133 m .72715 .83621 L .73223 .83895 L F
.64915 .56605 m .65379 .58368 L .66106 .56887 L .673 .757 .914 r
F
.64915 .56605 m .63593 .57945 L .65379 .58368 L F
.55706 .48575 m .535 .47121 L .53457 .47849 L .794 .542 .557 r
F
.55664 .49303 m .55706 .48575 L .53457 .47849 L F
0 g
.55706 .48575 m
.57617 .49642 L
s
.47764 .71496 m .4906 .71304 L .49109 .71761 L .794 .542 .557 r
F
.47764 .71496 m .47715 .71038 L .4906 .71304 L F
.48703 .70012 m .4906 .71304 L .496 .70189 L .683 .77 .917 r
F
.127 .923 .03 r
.38142 .56956 m
.38243 .64107 L
s
.48703 .70012 m .47715 .71038 L .4906 .71304 L .683 .77 .917 r
F
0 g
.4906 .71304 m
.50515 .71342 L
s
.77454 .72034 m .76063 .71312 L .76114 .71769 L .794 .542 .556 r
F
.77505 .72491 m .77454 .72034 L .76114 .71769 L F
0 g
.77454 .72034 m
.78589 .72509 L
s
.75144 .83344 m .75737 .84042 L .7627 .8383 L .645 .732 .913 r
F
.74836 .83402 m .75737 .84042 L .75144 .83344 L F
.3938 .34767 m .3926 .40537 L .39366 .4062 L .909 .63 .5 r
F
.3938 .34767 m .39274 .34684 L .3926 .40537 L F
0 g
.3938 .34767 m
.39425 .34872 L
s
.3938 .34767 m
.3938 .34767 L
s
.30065 .8308 m .292 .83781 L .30303 .83463 L .644 .733 .913 r
F
.127 .923 .03 r
.2978 .77005 m
.29814 .77411 L
s
.30065 .8308 m .28844 .83206 L .292 .83781 L .644 .733 .913 r
F
0 g
.292 .83781 m
.29782 .84291 L
s
.77778 .83606 m .78208 .82698 L .78185 .83075 L .095 0 .413 r
F
.77755 .83983 m .77778 .83606 L .78185 .83075 L F
.7671 .8316 m .77778 .83606 L .78185 .83075 L .645 .732 .913 r
F
.76294 .83453 m .77778 .83606 L .7671 .8316 L F
0 g
.77307 .83937 m
.77778 .83606 L
s
.50619 .70672 m .50564 .71799 L .5203 .71606 L .683 .77 .917 r
F
.49649 .70647 m .50564 .71799 L .50619 .70672 L F
.127 .923 .03 r
.38243 .64107 m
.38249 .64538 L
s
.49649 .70647 m .49109 .71761 L .50564 .71799 L .683 .77 .917 r
F
.67378 .59646 m .67345 .59078 L .69306 .58886 L .672 .449 .574 r
F
.65434 .59525 m .67345 .59078 L .67378 .59646 L .733 .496 .569 r
F
.127 .923 .03 r
.66108 .59368 m
.66115 .59002 L
s
.66038 .59384 m
.6605 .58998 L
s
.66234 .59338 m
.6626 .59011 L
s
.65434 .59525 m .65401 .58958 L .67345 .59078 L .733 .496 .569 r
F
.67429 .5755 m .67345 .59078 L .69306 .58886 L .673 .757 .914 r
F
.66132 .5747 m .67345 .59078 L .67429 .5755 L F
.66132 .5747 m .65401 .58958 L .67345 .59078 L F
.38838 .34676 m .38726 .34755 L .38711 .40608 L .398 .209 .505 r
F
.38726 .34755 m .38658 .40712 L .38711 .40608 L 0 0 .372 r
F
0 g
.38673 .34859 m
.38726 .34755 L
s
.38726 .34755 m
.38726 .34755 L
s
.17869 .58443 m .18555 .58967 L .18584 .59535 L .987 .713 .391 r
F
.17869 .58443 m .1784 .57876 L .18555 .58967 L F
0 g
.18555 .58967 m
.19053 .59364 L
s
.127 .923 .03 r
.19241 .60589 m
.19266 .61265 L
s
0 0 0 r
2.5 Mabswid
.19241 .60589 Mdot
.35731 .84165 m .36155 .83257 L .36129 .83634 L .078 0 .403 r
F
.127 .923 .03 r
.5 Mabswid
.32486 4.1561 m
.4981 8.79982 L
s
.35915 1.96213 m
.49803 8.79987 L
s
.34552 2.33428 m
.39525 8.82622 L
s
.34657 .83719 m .35731 .84165 L .36129 .83634 L .644 .733 .913 r
F
.34246 .84012 m .35731 .84165 L .34657 .83719 L F
0 g
.35114 .84604 m
.35731 .84165 L
s
.2031 .57431 m .18588 .58955 L .20784 .58156 L .673 .757 .914 r
F
.2031 .57431 m .17877 .57869 L .18588 .58955 L F
.70655 .47963 m .73932 .47609 L .70787 .47445 L .654 .726 .902 r
F
.31345 .82199 m .30366 .82706 L .31464 .82389 L .644 .733 .913 r
F
.31345 .82199 m .3013 .82324 L .30366 .82706 L F
0 0 0 r
2.5 Mabswid
.2825 .601 Mdot
.35481 .72674 m .34087 .71951 L .34135 .72409 L .794 .542 .557 r
F
0 g
.5 Mabswid
.35481 .72674 m
.36627 .73149 L
s
.127 .923 .03 r
.34599 .69769 m
.34643 .77106 L
s
.34087 .71951 m .34039 .71494 L .32583 .71456 L .733 .497 .571 r
F
0 g
.34039 .71494 m
.35385 .7176 L
s
.5203 .71606 m .53358 .70739 L .53408 .71196 L .606 .405 .583 r
F
.51597 .70543 m .5203 .71606 L .53408 .71196 L .683 .77 .917 r
F
.50619 .70672 m .5203 .71606 L .51597 .70543 L F
0 g
.50564 .71799 m
.5203 .71606 L
s
.23416 .58805 m .2262 .60384 L .23928 .59038 L .673 .757 .914 r
F
.23416 .58805 m .21596 .59917 L .2262 .60384 L F
.73464 .82586 m .72355 .82904 L .72738 .83244 L .645 .732 .913 r
F
.34699 .8296 m .36163 .82876 L .34963 .82608 L .644 .733 .913 r
F
.3363 .82517 m .34699 .8296 L .34963 .82608 L F
.33425 .82662 m .34699 .8296 L .3363 .82517 L F
.22981 .57356 m .20784 .58156 L .21556 .58771 L .673 .757 .914 r
F
.57059 .83916 m .56163 .83715 L .56138 .84092 L .597 .381 .558 r
F
0 g
.5534 .8441 m
.56138 .84092 L
s
.57059 .83916 m .57083 .83539 L .56163 .83715 L .597 .381 .558 r
F
0 g
.55365 .84033 m
.56163 .83715 L
s
.127 .923 .03 r
.56627 .84484 m
.56691 .81393 L
s
.24572 .4792 m .23821 .4592 L .22291 .46246 L .654 .726 .902 r
F
.25388 .47894 m .23821 .4592 L .24572 .4792 L F
.4558 .47387 m .45624 .46659 L .47173 .45479 L .34 .162 .487 r
F
0 g
.44584 .4711 m
.45624 .46659 L
s
.75434 .82861 m .76294 .83453 L .7671 .8316 L .645 .732 .913 r
F
.75167 .82967 m .76294 .83453 L .75434 .82861 L F
.19896 .48337 m .17203 .47181 L .16217 .48598 L .654 .726 .902 r
F
.127 .923 .03 r
.19411 .47649 m
.19423 .48134 L
s
0 g
.1585 .50152 m
.16217 .48598 L
s
.26199 .48005 m .25454 .45867 L .25388 .47894 L .654 .726 .902 r
F
.26199 .48005 m .27078 .4609 L .25454 .45867 L F
.26946 .58172 m .28682 .5922 L .29507 .58573 L .673 .757 .914 r
F
.73194 .71924 m .71763 .71876 L .71814 .72334 L .607 .406 .583 r
F
.73194 .71924 m .73143 .71467 L .71763 .71876 L F
0 g
.70564 .72475 m
.71763 .71876 L
s
.39274 .34684 m .39152 .40499 L .3926 .40537 L .81 .54 .531 r
F
.39274 .34684 m .39166 .34646 L .39152 .40499 L F
0 g
.39274 .34684 m
.3938 .34767 L
s
.48557 .60059 m .46415 .59335 L .45878 .60081 L .673 .757 .914 r
F
.48972 .59735 m .46415 .59335 L .48557 .60059 L F
.31406 .83145 m .30691 .83803 L .316 .83315 L .644 .733 .913 r
F
.127 .923 .03 r
.19753 .74319 m
.1978 .75034 L
s
.31406 .83145 m .30303 .83463 L .30691 .83803 L .644 .733 .913 r
F
.59934 .83936 m .5906 .83277 L .59035 .83654 L .793 .551 .572 r
F
.59909 .84313 m .59934 .83936 L .59035 .83654 L F
0 g
.59934 .83936 m
.60697 .84346 L
s
.38838 .34676 m .38711 .40608 L .38823 .40529 L .398 .209 .505 r
F
.38948 .34642 m .38838 .34676 L .38823 .40529 L .567 .342 .533 r
F
0 g
.38726 .34755 m
.38838 .34676 L
s
.43435 .45094 m .45591 .46636 L .47133 .45461 L .654 .726 .902 r
F
.42114 .45668 m .45591 .46636 L .43435 .45094 L F
.33377 .83419 m .34246 .84012 L .34657 .83719 L .644 .733 .913 r
F
.33112 .83526 m .34246 .84012 L .33377 .83419 L F
.31685 .59864 m .32454 .58178 L .32484 .58746 L .162 .067 .492 r
F
.29537 .59141 m .31685 .59864 L .32484 .58746 L .673 .757 .914 r
F
.28712 .59788 m .31685 .59864 L .29537 .59141 L F
0 g
.30447 .60835 m
.31685 .59864 L
s
.69306 .58886 m .71117 .57828 L .7115 .58395 L .603 .397 .574 r
F
.69339 .59454 m .69306 .58886 L .7115 .58395 L F
.67378 .59646 m .69306 .58886 L .69339 .59454 L .672 .449 .574 r
F
.68736 .57422 m .69306 .58886 L .7115 .58395 L .673 .757 .914 r
F
.67429 .5755 m .69306 .58886 L .68736 .57422 L F
0 g
.67345 .59078 m
.69306 .58886 L
s
.39166 .34646 m .39043 .40486 L .39152 .40499 L .734 .477 .539 r
F
.39166 .34646 m .39057 .34633 L .39043 .40486 L F
0 g
.39166 .34646 m
.39274 .34684 L
s
.38948 .34642 m .38823 .40529 L .38934 .40495 L .567 .342 .533 r
F
.39057 .34633 m .38948 .34642 L .38934 .40495 L .66 .416 .54 r
F
0 g
.38838 .34676 m
.38948 .34642 L
s
.34436 .49551 m .33591 .47308 L .33546 .48036 L .989 .743 .461 r
F
0 g
.34436 .49551 m
.34701 .51138 L
s
.34397 .49486 m
.34436 .49551 L
s
.48949 .59173 m .4723 .5813 L .46405 .58774 L .673 .757 .914 r
F
.49479 .58922 m .4723 .5813 L .48949 .59173 L F
.39057 .34633 m .38934 .40495 L .39043 .40486 L .66 .416 .54 r
F
0 g
.39057 .34633 m
.39166 .34646 L
s
.35756 .34638 m
.44892 .31276 L
s
.38948 .34642 m
.39057 .34633 L
s
.61688 .45192 m .58689 .44512 L .583 .46061 L .654 .726 .902 r
F
.58602 .45229 m .58253 .46059 L .58211 .46787 L 0 0 .147 r
F
0 g
.58307 .46403 m
.58369 .46795 L
s
.58602 .45229 m .58644 .44501 L .58253 .46059 L 0 0 .147 r
F
.61688 .45192 m .583 .46061 L .61428 .46225 L .654 .726 .902 r
F
.20968 .46822 m .17251 .46453 L .19943 .47609 L F
.58063 .83518 m .57108 .83162 L .57083 .83539 L .67 .443 .568 r
F
.58063 .83518 m .58087 .83141 L .57108 .83162 L F
0 g
.56187 .83338 m
.57108 .83162 L
s
.31212 .72564 m .29789 .72516 L .29837 .72973 L .606 .405 .582 r
F
0 g
.28646 .73572 m
.29837 .72973 L
s
.31212 .72564 m .31165 .72106 L .29789 .72516 L .606 .405 .582 r
F
0 g
.28598 .73115 m
.29789 .72516 L
s
.55626 .60471 m .57378 .5894 L .55161 .59744 L .673 .758 .914 r
F
.55626 .60471 m .58075 .60032 L .57378 .5894 L F
.64687 .45872 m .61428 .46225 L .64556 .46389 L .654 .726 .902 r
F
.64687 .45872 m .61688 .45192 L .61428 .46225 L F
.59035 .83654 m .5906 .83277 L .58087 .83141 L .733 .498 .572 r
F
0 g
.5906 .83277 m
.59958 .83559 L
s
.53358 .70739 m .54504 .69683 L .54554 .7014 L .523 .345 .581 r
F
.53408 .71196 m .53358 .70739 L .54554 .7014 L F
.52467 .69813 m .53358 .70739 L .54554 .7014 L .683 .77 .917 r
F
.51548 .70086 m .53358 .70739 L .52467 .69813 L F
0 g
.52691 .70938 m
.53358 .70739 L
s
.25388 .47894 m .25454 .45867 L .23821 .4592 L .654 .726 .902 r
F
.30833 .48178 m .32136 .4597 L .29862 .47287 L F
.30833 .48178 m .33591 .47308 L .32136 .4597 L F
.70812 .46716 m .73778 .45825 L .7073 .46188 L F
.70812 .46716 m .7394 .46879 L .73778 .45825 L F
.7394 .46879 m .76827 .45461 L .73778 .45825 L F
.7394 .46879 m .77068 .47043 L .76827 .45461 L F
.51025 .47514 m .48618 .46866 L .48575 .47594 L .667 .431 .554 r
F
.51025 .47514 m .51068 .46786 L .48618 .46866 L F
0 g
.46319 .47354 m
.48618 .46866 L
s
.77076 .47774 m .77115 .47046 L .76873 .45455 L .91 .732 .235 r
F
0 g
.77434 .45818 m
.77698 .46152 L
s
.76929 .47766 m
.77038 .47343 L
s
.721 .82898 m .71223 .83599 L .72332 .83281 L .645 .732 .913 r
F
.721 .82898 m .70875 .83024 L .71223 .83599 L F
0 g
.71223 .83599 m
.71798 .84109 L
s
.53457 .47849 m .535 .47121 L .51068 .46786 L .732 .487 .558 r
F
0 g
.535 .47121 m
.55748 .47847 L
s
.58043 .59464 m .57313 .57805 L .57345 .58372 L .986 .711 .379 r
F
.58075 .60032 m .58043 .59464 L .57345 .58372 L F
0 g
.58043 .59464 m
.58239 .60644 L
s
.77755 .83983 m .78185 .83075 L .78162 .83452 L .095 0 .413 r
F
.76687 .83537 m .77755 .83983 L .78162 .83452 L .645 .732 .913 r
F
.7627 .8383 m .77755 .83983 L .76687 .83537 L F
0 g
.7713 .84422 m
.77755 .83983 L
s
.52945 .60547 m .54393 .59126 L .52561 .60238 L .673 .758 .914 r
F
.52945 .60547 m .55161 .59744 L .54393 .59126 L F
.32631 .71914 m .31117 .71649 L .31165 .72106 L .673 .453 .579 r
F
.32631 .71914 m .32583 .71456 L .31117 .71649 L F
0 g
.29742 .72059 m
.31117 .71649 L
s
.46415 .59335 m .43467 .5973 L .45878 .60081 L .673 .757 .914 r
F
.73378 .82017 m .7239 .82524 L .73493 .82207 L .645 .732 .913 r
F
.73378 .82017 m .72159 .82143 L .7239 .82524 L F
.48752 .70469 m .49109 .71761 L .49649 .70647 L .683 .77 .917 r
F
.48752 .70469 m .47764 .71496 L .49109 .71761 L F
0 g
.49109 .71761 m
.50564 .71799 L
s
.77505 .72491 m .76114 .71769 L .76165 .72226 L .794 .542 .556 r
F
0 g
.77505 .72491 m
.78641 .72966 L
s
.59035 .83654 m .58087 .83141 L .58063 .83518 L .733 .498 .572 r
F
0 g
.58087 .83141 m
.5906 .83277 L
s
.57108 .83162 m
.58087 .83141 L
s
.28763 .82228 m .28896 .82452 L .2887 .82829 L .933 .757 .28 r
F
.127 .923 .03 r
.22113 1.37574 m
.32486 4.1561 L
s
.1978 .75034 m
.22113 1.37574 L
s
.28763 .82228 m .28789 .81851 L .28896 .82452 L .933 .757 .28 r
F
0 g
.28896 .82452 m
.29115 .82804 L
s
.46572 .70563 m .47666 .70581 L .47715 .71038 L .86 .591 .531 r
F
.46572 .70563 m .46523 .70106 L .47666 .70581 L F
0 g
.47666 .70581 m
.48077 .70663 L
s
.76114 .71769 m .76063 .71312 L .7461 .71274 L .733 .497 .571 r
F
0 g
.76063 .71312 m
.77402 .71577 L
s
.30059 .81926 m .28915 .8245 L .3013 .82324 L .644 .733 .913 r
F
.30059 .81926 m .28808 .81852 L .28915 .8245 L F
0 0 0 r
2.5 Mabswid
.23596 .6018 Mdot
.76723 .82779 m .7819 .82694 L .76993 .82426 L .645 .732 .913 r
F
.7566 .82335 m .76723 .82779 L .76993 .82426 L F
.75453 .82481 m .76723 .82779 L .7566 .82335 L F
.31313 .82576 m .30329 .83086 L .31432 .82768 L .644 .733 .913 r
F
.31313 .82576 m .30091 .82703 L .30329 .83086 L F
.47906 .69229 m .47681 .70566 L .48664 .69545 L .683 .77 .917 r
F
.47906 .69229 m .46544 .70093 L .47681 .70566 L F
.36155 .83257 m .36181 .8288 L .36333 .82294 L 0 0 .136 r
F
0 g
.5 Mabswid
.35887 .83273 m
.36181 .8288 L
s
.34683 .83342 m .36155 .83257 L .34949 .82988 L .644 .733 .913 r
F
.33609 .82896 m .34683 .83342 L .34949 .82988 L F
.33404 .83042 m .34683 .83342 L .33609 .82896 L F
.127 .923 .03 r
.31474 .58086 m
.31477 .58309 L
s
.34963 .82608 m .36163 .82876 L .36314 .82293 L .644 .733 .913 r
F
.73441 .82963 m .72715 .83621 L .73632 .83133 L .645 .732 .913 r
F
.73441 .82963 m .72332 .83281 L .72715 .83621 L F
.63639 .59101 m .65401 .58958 L .65434 .59525 L .794 .544 .559 r
F
.63639 .59101 m .63606 .58533 L .65401 .58958 L F
.64935 .57186 m .65401 .58958 L .66132 .5747 L .673 .757 .914 r
F
.64935 .57186 m .63606 .58533 L .65401 .58958 L F
0 g
.65401 .58958 m
.67345 .59078 L
s
.7115 .58395 m .71117 .57828 L .7272 .57071 L .517 .331 .568 r
F
0 g
.70289 .58048 m
.71117 .57828 L
s
.34087 .71951 m .32583 .71456 L .32631 .71914 L .733 .497 .571 r
F
0 g
.31117 .71649 m
.32583 .71456 L
s
.32583 .71456 m
.34039 .71494 L
s
.75411 .83238 m .7627 .8383 L .76687 .83537 L .645 .732 .913 r
F
.75144 .83344 m .7627 .8383 L .75411 .83238 L F
.32833 .82581 m .32876 .82513 L .32876 .82544 L .071 0 .412 r
F
.32738 .83092 m .32806 .83584 L .33112 .83526 L .644 .733 .913 r
F
.32501 .82701 m .3266 .82681 L .32659 .83045 L .641 .402 .541 r
F
.32596 .83049 m .32657 .83204 L .32695 .83042 L .644 .733 .913 r
F
.32509 .82827 m .3248 .83591 L .32806 .83584 L F
.3251 .83056 m .32659 .83045 L .32638 .88597 L .641 .402 .541 r
F
.32501 .82701 m .32659 .83045 L .3251 .83056 L F
.32695 .83042 m .32657 .83204 L .32738 .83092 L .644 .733 .913 r
F
.32509 .82827 m .32596 .83049 L .32695 .83042 L F
.32657 .83204 m .32806 .83584 L .32738 .83092 L F
.32857 .82669 m .33139 .83149 L .33404 .83042 L F
.32535 .8245 m .32837 .82799 L .32857 .82669 L F
.32837 .82799 m .33139 .83149 L .32857 .82669 L F
.32876 .82513 m .32887 .82432 L .32887 .82471 L 0 0 .131 r
F
.3285 .8306 m .33112 .83526 L .33377 .83419 L .644 .733 .913 r
F
.3268 .82818 m .32833 .83207 L .32758 .82708 L F
.3266 .82681 m .32762 .82637 L .32761 .83009 L .517 .303 .528 r
F
.32665 .83042 m .32761 .83009 L .3274 .88553 L F
.3266 .82681 m .32761 .83009 L .32665 .83042 L F
.32758 .82708 m .32833 .83207 L .33139 .83149 L .644 .733 .913 r
F
.32771 .83006 m .32829 .83197 L .3285 .8306 L F
.32509 .82827 m .32688 .83034 L .32771 .83006 L F
.32647 .88298 m .32857 .88528 L .33041 .88429 L .692 .759 .903 r
F
.32665 .88304 m .33041 .88429 L .3272 .88259 L F
.32854 .88333 m .32844 .88397 L .32884 .88337 L F
.32854 .88329 m .32865 .88349 L .32854 .88429 L 0 0 .131 r
F
.32863 .82974 m .33377 .83419 L .33583 .83273 L .644 .733 .913 r
F
.32509 .82827 m .3285 .8306 L .32863 .82974 L F
.3285 .8306 m .33377 .83419 L .32863 .82974 L F
.32874 .829 m .32865 .88252 L .32854 .88329 L 0 0 .131 r
F
.32876 .82513 m .32875 .82895 L .32874 .829 L F
.32875 .82895 m .32865 .88252 L .32874 .829 L F
.32739 .88248 m .33041 .88429 L .33184 .88306 L .692 .759 .903 r
F
.32752 .88276 m .33041 .88429 L .32761 .88262 L F
.32812 .88182 m .3284 .8835 L .32811 .88396 L .071 0 .412 r
F
.32647 .88298 m .32665 .88304 L .3272 .88259 L .692 .759 .903 r
F
.32741 .88241 m .32789 .88415 L .32741 .88455 L .356 .178 .497 r
F
.32752 .88276 m .32761 .88262 L .32739 .88248 L .692 .759 .903 r
F
.32808 .88185 m .32811 .88497 L .32741 .88241 L .356 .178 .497 r
F
.32462 .88287 m .32883 .88337 L .32901 .88263 L .692 .759 .903 r
F
.32883 .88337 m .32884 .88337 L .32884 .88336 L F
.32883 .88337 m .32884 .88336 L .32901 .88263 L F
.32544 .88334 m .32644 .88596 L .32857 .88528 L F
.3254 .88332 m .32542 .88335 L .32544 .88334 L F
.32542 .88335 m .32644 .88596 L .32544 .88334 L F
.32741 .88455 m .32673 .88519 L .32766 .88469 L F
.32639 .88289 m .32708 .8847 L .32638 .88504 L .517 .303 .528 r
F
.32427 .88347 m .32417 .88627 L .32644 .88596 L .692 .759 .903 r
F
.32427 .88347 m .32644 .88596 L .3254 .88332 L F
.32553 .8852 m .32452 .88568 L .32566 .88553 L F
.3248 .8832 m .3259 .88513 L .32479 .88534 L .641 .402 .541 r
F
.32462 .88287 m .32453 .88539 L .32553 .8852 L .692 .759 .903 r
F
.32453 .88539 m .32452 .88568 L .32553 .8852 L F
.32417 .88627 m .32748 .8886 L .32644 .88596 L F
.32452 .88568 m .3267 .88818 L .32566 .88553 L F
.32479 .88534 m .32638 .88597 L .32479 .88617 L .641 .402 .541 r
F
.32656 .885 m .32566 .88553 L .32673 .88519 L .692 .759 .903 r
F
.32636 .88504 m .3259 .88513 L .3248 .8832 L .641 .402 .541 r
F
.32462 .88287 m .32553 .8852 L .32656 .885 L .692 .759 .903 r
F
.32553 .8852 m .32566 .88553 L .32656 .885 L F
.32639 .88289 m .3254 .88332 L .32647 .88298 L F
.32532 .8831 m .3254 .88332 L .32639 .88289 L F
.32631 .88291 m .32636 .88504 L .3248 .8832 L .641 .402 .541 r
F
.32644 .88596 m .33067 .88759 L .32857 .88528 L .692 .759 .903 r
F
.32566 .88553 m .32884 .8875 L .32673 .88519 L F
.32636 .88504 m .32638 .88597 L .3259 .88513 L .641 .402 .541 r
F
.3259 .88513 m .32638 .88597 L .32479 .88534 L F
.32501 .82701 m .32631 .88291 L .3248 .8832 L F
.32437 .88067 m .32532 .8831 L .32639 .88289 L .692 .759 .903 r
F
.32462 .88287 m .32653 .88497 L .32741 .88455 L F
.32653 .88497 m .32673 .88519 L .32741 .88455 L F
.32638 .88504 m .3274 .88553 L .32638 .88597 L .517 .303 .528 r
F
.32673 .88519 m .33069 .88651 L .32766 .88469 L .692 .759 .903 r
F
.32708 .8847 m .3274 .88553 L .32638 .88504 L .517 .303 .528 r
F
.32981 .82932 m .33583 .83273 L .33716 .83096 L .644 .733 .913 r
F
.32762 .82637 m .32765 .83006 L .32761 .83009 L .356 .178 .497 r
F
.32762 .82637 m .32833 .82581 L .32832 .8296 L F
.32761 .83009 m .32829 .83197 L .32771 .83006 L .644 .733 .913 r
F
.32765 .83006 m .32832 .8296 L .32811 .88497 L .356 .178 .497 r
F
.32762 .82637 m .32832 .8296 L .32765 .83006 L F
.32899 .82914 m .32862 .82974 L .32981 .82932 L .644 .733 .913 r
F
.32509 .82827 m .32831 .82961 L .32899 .82914 L F
.32831 .82961 m .32862 .82974 L .32899 .82914 L F
.32862 .82974 m .33583 .83273 L .32981 .82932 L F
.32659 .83045 m .32736 .88243 L .32639 .88289 L .517 .303 .528 r
F
.3266 .82681 m .32665 .83042 L .32659 .83045 L F
.32665 .83042 m .32736 .88243 L .32659 .83045 L F
.3254 .88332 m .32857 .88528 L .32647 .88298 L .692 .759 .903 r
F
.32739 .88456 m .32708 .8847 L .32639 .88289 L .517 .303 .528 r
F
.32462 .88287 m .32741 .88455 L .32838 .88407 L .692 .759 .903 r
F
.32741 .88455 m .32766 .88469 L .32832 .88411 L F
.32741 .88455 m .32832 .88411 L .32838 .88407 L F
.32736 .88243 m .32739 .88456 L .32639 .88289 L .517 .303 .528 r
F
.32739 .88456 m .3274 .88553 L .32708 .8847 L F
.32741 .88455 m .32811 .88497 L .3274 .88553 L .356 .178 .497 r
F
.32789 .88415 m .32811 .88497 L .32741 .88455 L F
.32865 .88252 m .32865 .88349 L .32854 .88329 L 0 0 .131 r
F
.32851 .88333 m .32838 .88407 L .32844 .88397 L .692 .759 .903 r
F
.32851 .88333 m .32844 .88397 L .32854 .88333 L F
.32462 .88287 m .3281 .88398 L .32851 .88333 L F
.3281 .88398 m .32838 .88407 L .32851 .88333 L F
.32766 .88469 m .33213 .88527 L .32838 .88407 L F
.32811 .88396 m .32854 .88429 L .32811 .88497 L .071 0 .412 r
F
.3284 .8835 m .32854 .88429 L .32811 .88396 L F
.3296 .82626 m .33404 .83042 L .33609 .82896 L .644 .733 .913 r
F
.32535 .8245 m .33039 .82793 L .3296 .82626 L F
.33039 .82793 m .33404 .83042 L .3296 .82626 L F
.32739 .88248 m .33184 .88306 L .3281 .88187 L .692 .759 .903 r
F
.32853 .88118 m .32853 .8833 L .32812 .88182 L .071 0 .412 r
F
.32853 .8833 m .32854 .88429 L .3284 .8835 L F
.32853 .8833 m .3284 .8835 L .32812 .88182 L F
.3272 .88259 m .32752 .88276 L .32739 .88248 L .692 .759 .903 r
F
.32462 .88287 m .32896 .88264 L .32889 .88191 L F
.32896 .88264 m .32901 .88263 L .329 .88257 L F
.32896 .88264 m .329 .88257 L .32889 .88191 L F
.32875 .82895 m .32886 .82827 L .32865 .88349 L 0 0 .131 r
F
.32834 .82956 m .32874 .829 L .32854 .88429 L .071 0 .412 r
F
.32876 .82513 m .32887 .82471 L .32876 .82544 L 0 0 .131 r
F
.32887 .8247 m .33742 .82719 L .33792 .82524 L .644 .733 .913 r
F
.32535 .8245 m .32917 .82535 L .32887 .8247 L F
.32917 .82535 m .33742 .82719 L .32887 .8247 L F
.32887 .82432 m .32842 .82329 L .32842 .82374 L .986 .729 .347 r
F
.32832 .8296 m .32853 .88118 L .32812 .88182 L .071 0 .412 r
F
.32834 .82956 m .32853 .88118 L .32832 .8296 L F
.32876 .82544 m .32887 .82471 L .32886 .82827 L 0 0 .131 r
F
.32876 .82544 m .32886 .82827 L .32875 .82895 L F
.32833 .82604 m .32876 .82544 L .32874 .829 L .071 0 .412 r
F
.32833 .82604 m .32874 .829 L .32834 .82956 L F
.32833 .82581 m .32876 .82544 L .32833 .82604 L F
.32535 .8245 m .33609 .82896 L .33742 .82719 L .644 .733 .913 r
F
.32887 .8247 m .32842 .82374 L .3284 .8273 L .986 .729 .347 r
F
.32829 .82365 m .33757 .82323 L .33638 .82131 L .644 .733 .913 r
F
.32535 .8245 m .32893 .82413 L .32829 .82365 L F
.32893 .82413 m .33757 .82323 L .32829 .82365 L F
.32842 .82329 m .32735 .82247 L .32735 .82295 L .908 .63 .503 r
F
.32509 .82827 m .32869 .82907 L .3291 .8285 L .644 .733 .913 r
F
.32761 .83009 m .32808 .88185 L .32741 .88241 L .356 .178 .497 r
F
.32702 .8305 m .32829 .83197 L .32761 .83009 L .644 .733 .913 r
F
.32765 .83006 m .32811 .88497 L .32761 .83009 L .356 .178 .497 r
F
.32887 .82432 m .32842 .82374 L .32887 .8247 L .986 .729 .347 r
F
.32887 .82432 m .32887 .8247 L .32887 .82471 L F
.32893 .82413 m .33792 .82524 L .33757 .82323 L .644 .733 .913 r
F
.32535 .8245 m .32978 .82476 L .32893 .82413 L F
.32978 .82476 m .33792 .82524 L .32893 .82413 L F
.32833 .82581 m .32834 .82956 L .32832 .8296 L .071 0 .412 r
F
.32887 .8247 m .32883 .82821 L .32887 .82471 L .986 .729 .347 r
F
.32883 .82821 m .3282 .88245 L .32883 .82821 L F
.32883 .82821 m .32883 .82821 L .32887 .82471 L F
.32868 .8279 m .33766 .82901 L .33731 .827 L .644 .733 .913 r
F
.32509 .82827 m .32896 .8285 L .32868 .8279 L F
.32896 .8285 m .33766 .82901 L .32868 .8279 L F
.32841 .82731 m .33731 .827 L .33612 .82509 L F
.32509 .82827 m .32914 .82785 L .32841 .82731 L F
.32914 .82785 m .33731 .827 L .32841 .82731 L F
.32437 .88067 m .32857 .88117 L .32874 .88044 L .692 .759 .903 r
F
.32437 .88067 m .32874 .88044 L .32862 .87972 L F
.3284 .8273 m .32713 .88163 L .3282 .88245 L .908 .63 .503 r
F
.32842 .82374 m .32834 .82726 L .3284 .8273 L F
.32834 .82726 m .32713 .88163 L .3284 .8273 L F
.32842 .82329 m .32841 .82374 L .32842 .82374 L F
.32841 .82374 m .32713 .88163 L .32842 .82374 L F
.32841 .82374 m .32735 .82295 L .32713 .88163 L F
.32842 .82329 m .32735 .82295 L .32841 .82374 L F
.32769 .82578 m .33418 .82338 L .33162 .82202 L .644 .733 .913 r
F
.32535 .8245 m .3268 .82818 L .32758 .82708 L F
.32707 .82285 m .33444 .81961 L .33189 .81825 L F
.32535 .8245 m .32788 .82314 L .32707 .82285 L F
.32788 .82314 m .33444 .81961 L .32707 .82285 L F
.32735 .82247 m .32628 .82209 L .32627 .82257 L .809 .541 .534 r
F
.32788 .82314 m .33638 .82131 L .33444 .81961 L .644 .733 .913 r
F
.32535 .8245 m .32885 .82349 L .32788 .82314 L F
.32885 .82349 m .33638 .82131 L .32788 .82314 L F
.32437 .88067 m .3281 .88187 L .32857 .88117 L .692 .759 .903 r
F
.32735 .82295 m .32612 .87843 L .32714 .8787 L .809 .541 .534 r
F
.32632 .87849 m .32753 .87853 L .32664 .87813 L .692 .759 .903 r
F
.32437 .88067 m .32724 .87873 L .32632 .87849 L F
.32724 .87873 m .32753 .87853 L .32632 .87849 L F
.32437 .88067 m .32862 .87972 L .3282 .87907 L F
.32714 .8787 m .32632 .88063 L .32714 .88084 L .809 .541 .534 r
F
.32657 .88069 m .3278 .88071 L .3269 .88032 L .692 .759 .903 r
F
.32437 .88067 m .32739 .88248 L .3281 .88187 L F
.32462 .88287 m .32747 .88093 L .32657 .88069 L F
.32747 .88093 m .3278 .88071 L .32657 .88069 L F
.32714 .88084 m .32605 .88126 L .32713 .88163 L .809 .541 .534 r
F
.32632 .88063 m .32605 .88126 L .32714 .88084 L F
.32437 .88067 m .3282 .87907 L .32753 .87853 L .692 .759 .903 r
F
.32612 .87843 m .32605 .88126 L .32714 .8787 L .809 .541 .534 r
F
.32735 .82247 m .32734 .82295 L .32735 .82295 L F
.32734 .82295 m .32605 .88126 L .32735 .82295 L F
.32722 .82291 m .32627 .82257 L .32626 .82613 L F
.32735 .82247 m .32627 .82257 L .32722 .82291 L F
.32509 .82827 m .32795 .82673 L .32704 .8264 L .644 .733 .913 r
F
.32509 .82827 m .32841 .82731 L .3281 .82665 L F
.32688 .83034 m .32702 .8305 L .32761 .83009 L F
.32727 .82649 m .32626 .82613 L .32605 .88126 L .809 .541 .534 r
F
.32735 .82247 m .32626 .82613 L .32727 .82649 L F
.32704 .8264 m .3281 .82665 L .32769 .82578 L .644 .733 .913 r
F
.32795 .82673 m .3281 .82665 L .32704 .8264 L F
.3281 .82665 m .33418 .82338 L .32769 .82578 L F
.32883 .82821 m .3284 .8273 L .3282 .88245 L .986 .729 .347 r
F
.32887 .8247 m .3284 .8273 L .32883 .82821 L F
.3281 .82665 m .33612 .82509 L .33418 .82338 L .644 .733 .913 r
F
.32887 .82471 m .32883 .82821 L .32886 .82827 L .986 .729 .347 r
F
.32841 .82731 m .33612 .82509 L .3281 .82665 L .644 .733 .913 r
F
.32886 .82827 m .3282 .88245 L .32865 .88349 L .986 .729 .347 r
F
.32883 .82821 m .3282 .88245 L .32886 .82827 L F
.3291 .8285 m .33716 .83096 L .33766 .82901 L .644 .733 .913 r
F
.32869 .82907 m .33716 .83096 L .3291 .8285 L F
.32829 .83197 m .33112 .83526 L .3285 .8306 L F
.51981 .58876 m .52104 .57255 L .51385 .58735 L .673 .757 .914 r
F
.51981 .58876 m .53297 .57537 L .52104 .57255 L F
.34135 .72409 m .34087 .71951 L .32631 .71914 L .733 .497 .571 r
F
0 g
.34087 .71951 m
.35433 .72217 L
s
.2376 .48811 m .22244 .46974 L .20921 .4755 L .654 .726 .902 r
F
.24525 .48648 m .22244 .46974 L .2376 .48811 L F
.69921 .56514 m .71099 .57808 L .72694 .57055 L .673 .757 .914 r
F
.68697 .5684 m .71099 .57808 L .69921 .56514 L F
.59909 .84313 m .59035 .83654 L .59011 .84031 L .793 .551 .572 r
F
0 g
.59909 .84313 m
.60673 .84723 L
s
.52529 .5967 m .53342 .58091 L .5202 .59437 L .673 .757 .914 r
F
.52529 .5967 m .54361 .58558 L .53342 .58091 L F
.26904 .48975 m .27031 .46819 L .26153 .48733 L .654 .726 .902 r
F
.26904 .48975 m .28535 .47303 L .27031 .46819 L F
.67462 .58118 m .67378 .59646 L .69339 .59454 L .673 .758 .914 r
F
.66165 .58037 m .67378 .59646 L .67462 .58118 L F
.127 .923 .03 r
.66191 .599 m
.66216 .59574 L
s
.66165 .58037 m .65434 .59525 L .67378 .59646 L .673 .758 .914 r
F
.127 .923 .03 r
.66013 .60198 m
.66033 .59562 L
s
.66092 .60169 m
.66104 .59567 L
s
.73245 .72381 m .71814 .72334 L .71865 .72791 L .607 .406 .583 r
F
0 g
.70666 .7339 m
.71865 .72791 L
s
.73245 .72381 m .73194 .71924 L .71814 .72334 L .607 .406 .583 r
F
0 g
.70615 .72933 m
.71814 .72334 L
s
.17897 .59011 m .18584 .59535 L .18612 .60103 L .987 .713 .391 r
F
.17897 .59011 m .17869 .58443 L .18584 .59535 L F
.20315 .58003 m .18584 .59535 L .2079 .58732 L .673 .757 .914 r
F
.20315 .58003 m .17869 .58443 L .18584 .59535 L F
0 g
.18584 .59535 m
.19082 .59932 L
s
.39041 .44027 m .38965 .46044 L .4059 .45992 L .654 .726 .902 r
F
.38233 .43915 m .38965 .46044 L .39041 .44027 L F
.38233 .43915 m .37351 .45822 L .38965 .46044 L F
.58038 .83895 m .57083 .83539 L .57059 .83916 L .67 .443 .568 r
F
0 g
.56138 .84092 m
.57059 .83916 L
s
.58038 .83895 m .58063 .83518 L .57083 .83539 L .67 .443 .568 r
F
0 g
.56163 .83715 m
.57083 .83539 L
s
.59011 .84031 m .59035 .83654 L .58063 .83518 L .733 .498 .572 r
F
0 g
.59035 .83654 m
.59934 .83936 L
s
.127 .923 .03 r
.32042 .42841 m
.32043 .42854 L
s
.22999 .57928 m .2079 .58732 L .21567 .5935 L .673 .757 .914 r
F
.26975 .5874 m .28712 .59788 L .29537 .59141 L F
.26444 .58992 m .28712 .59788 L .26975 .5874 L F
.53408 .71196 m .54554 .7014 L .54604 .70597 L .523 .345 .581 r
F
.52516 .7027 m .53408 .71196 L .54604 .70597 L .683 .77 .917 r
F
.51597 .70543 m .53408 .71196 L .52516 .7027 L F
0 g
.5203 .71606 m
.53408 .71196 L
s
.49479 .58922 m .4829 .57628 L .4723 .5813 L .673 .757 .914 r
F
.5009 .58759 m .4829 .57628 L .49479 .58922 L F
.48589 .60626 m .46446 .59903 L .45909 .60648 L .673 .758 .914 r
F
.49004 .60303 m .46446 .59903 L .48589 .60626 L F
.55074 .58616 m .56134 .56893 L .5431 .58001 L .673 .757 .914 r
F
.55074 .58616 m .5728 .57817 L .56134 .56893 L F
.74661 .71731 m .73143 .71467 L .73194 .71924 L .673 .454 .579 r
F
.74661 .71731 m .7461 .71274 L .73143 .71467 L F
0 g
.71763 .71876 m
.73143 .71467 L
s
.53457 .47849 m .51068 .46786 L .51025 .47514 L .732 .487 .558 r
F
0 g
.51068 .46786 m
.535 .47121 L
s
.48618 .46866 m
.51068 .46786 L
s
.70801 .82046 m .70922 .8227 L .70899 .82647 L .92 .746 .257 r
F
.70801 .82046 m .70825 .81669 L .70922 .8227 L F
0 g
.70922 .8227 m
.71136 .82623 L
s
.69339 .59454 m .7115 .58395 L .71184 .58963 L .603 .397 .574 r
F
.6877 .5799 m .69339 .59454 L .71184 .58963 L .673 .758 .914 r
F
.67462 .58118 m .69339 .59454 L .6877 .5799 L F
0 g
.67378 .59646 m
.69339 .59454 L
s
.72095 .81744 m .70941 .82268 L .72159 .82143 L .645 .732 .913 r
F
.72095 .81744 m .70844 .8167 L .70941 .82268 L F
.55664 .49303 m .53457 .47849 L .53415 .48577 L .794 .542 .557 r
F
0 g
.55664 .49303 m
.57575 .5037 L
s
.73349 .82394 m .72355 .82904 L .73464 .82586 L .645 .732 .913 r
F
.73349 .82394 m .72124 .82521 L .72355 .82904 L F
.59011 .84031 m .58063 .83518 L .58038 .83895 L .733 .498 .572 r
F
0 g
.58063 .83518 m
.59035 .83654 L
s
.59011 .84031 m
.59909 .84313 L
s
.57083 .83539 m
.58063 .83518 L
s
.28736 .82605 m .2887 .82829 L .28844 .83206 L .933 .757 .28 r
F
.28736 .82605 m .28763 .82228 L .2887 .82829 L F
.3002 .82302 m .2887 .82829 L .30091 .82703 L .644 .733 .913 r
F
.3002 .82302 m .28763 .82228 L .2887 .82829 L F
0 g
.2887 .82829 m
.29088 .83181 L
s
.48972 .59735 m .47244 .58687 L .46415 .59335 L .673 .757 .914 r
F
.49504 .59483 m .47244 .58687 L .48972 .59735 L F
.78185 .83075 m .78208 .82698 L .78369 .82112 L 0 0 .162 r
F
0 g
.77907 .83091 m
.78208 .82698 L
s
.7671 .8316 m .78185 .83075 L .76982 .82806 L .645 .732 .913 r
F
.75642 .82714 m .7671 .8316 L .76982 .82806 L F
.75434 .82861 m .7671 .8316 L .75642 .82714 L F
.76993 .82426 m .7819 .82694 L .78351 .82111 L F
.31287 .82953 m .30303 .83463 L .31406 .83145 L .644 .733 .913 r
F
.31287 .82953 m .30065 .8308 L .30303 .83463 L F
.50577 .68623 m .50521 .69746 L .51494 .69618 L .683 .77 .917 r
F
.50577 .68623 m .51494 .69618 L .51063 .68559 L F
.50626 .69086 m .5057 .70215 L .51548 .70086 L F
.50626 .69086 m .51548 .70086 L .51115 .69022 L F
.50563 .63553 m .5072 .63579 L .5072 .67785 L .751 .491 .539 r
F
.50759 .67811 m .50577 .68623 L .51063 .68559 L .683 .77 .917 r
F
.50749 .67788 m .50743 .67817 L .50759 .67811 L F
.50743 .67817 m .50577 .68623 L .50759 .67811 L F
.5079 .68225 m .50626 .69086 L .51115 .69022 L F
.50617 .67804 m .50577 .68623 L .50745 .67787 L F
.5072 .67785 m .50745 .67787 L .50746 .67781 L F
.50617 .67804 m .50745 .67787 L .5072 .67785 L F
.50398 .63447 m .50464 .63506 L .50464 .67737 L .929 .648 .488 r
F
.50509 .67753 m .50479 .67816 L .50618 .67792 L .683 .77 .917 r
F
.50355 .63296 m .5036 .63377 L .5036 .67628 L .783 .625 .063 r
F
.50387 .68006 m .50094 .68611 L .50396 .68138 L .683 .77 .917 r
F
.49648 .68523 m .49556 .69721 L .50094 .68611 L F
.50376 .68275 m .49311 .68826 L .49692 .68985 L F
.5042 .6772 m .50419 .67721 L .50509 .67753 L F
.50615 .67847 m .50094 .68611 L .50577 .68623 L F
.5055 .68228 m .5014 .69074 L .50624 .68282 L F
.50094 .68611 m .50521 .69746 L .50577 .68623 L F
.50503 .67765 m .49977 .68231 L .50094 .68611 L F
.49977 .68231 m .49648 .68523 L .49797 .68552 L F
.49977 .68231 m .49797 .68552 L .50094 .68611 L F
.50355 .63296 m .50359 .67608 L .50355 .67556 L .783 .625 .063 r
F
.5036 .63377 m .50388 .67671 L .5036 .67628 L .989 .72 .386 r
F
.50355 .63296 m .5036 .67628 L .50359 .67608 L .783 .625 .063 r
F
.5036 .63377 m .50398 .63447 L .50398 .67688 L .989 .72 .386 r
F
.50408 .63193 m .50355 .63296 L .50355 .67556 L 0 0 .377 r
F
.50362 .68082 m .50283 .68114 L .50367 .68156 L .683 .77 .917 r
F
.50464 .63506 m .50535 .67762 L .50464 .67737 L .845 .571 .524 r
F
.50398 .63447 m .50464 .67737 L .50446 .67723 L .929 .648 .488 r
F
.50464 .63506 m .50563 .63553 L .50563 .67772 L .845 .571 .524 r
F
.50464 .63506 m .50563 .67772 L .50554 .67769 L F
.5037 .67772 m .50377 .67871 L .50465 .67793 L .683 .77 .917 r
F
.50654 .68518 m .5014 .69074 L .50626 .69086 L F
.50094 .68611 m .49556 .69721 L .50521 .69746 L F
.5014 .69074 m .496 .70189 L .5057 .70215 L F
.49692 .68985 m .496 .70189 L .5014 .69074 L F
.50551 .68785 m .49741 .69442 L .5019 .69531 L F
.50542 .68193 m .50563 .682 L .50563 .68628 L .845 .571 .524 r
F
.5014 .69074 m .5057 .70215 L .50626 .69086 L .683 .77 .917 r
F
.50717 .68684 m .5019 .69531 L .50675 .69544 L F
.50618 .67792 m .50593 .67831 L .50615 .67847 L F
.50669 .68209 m .50654 .68233 L .50668 .68238 L F
.50666 .6828 m .50626 .69086 L .5079 .68225 L F
.50676 .67782 m .50698 .6864 L .50563 .67772 L .751 .491 .539 r
F
.5072 .68641 m .50618 .68648 L .50717 .68684 L .683 .77 .917 r
F
.50625 .68634 m .50618 .68648 L .5072 .68641 L F
.50698 .6864 m .50721 .6947 L .50643 .68635 L .751 .491 .539 r
F
.50668 .68238 m .50572 .6839 L .50654 .68518 L .683 .77 .917 r
F
.5055 .68228 m .50624 .68282 L .50669 .68209 L F
.50698 .6864 m .50643 .68635 L .50563 .67772 L .751 .491 .539 r
F
.50669 .68209 m .50666 .6828 L .50788 .68219 L .683 .77 .917 r
F
.50687 .68211 m .5072 .68213 L .50721 .6947 L .751 .491 .539 r
F
.50731 .68415 m .50625 .68634 L .5072 .68641 L .683 .77 .917 r
F
.50618 .68648 m .5019 .69531 L .50717 .68684 L F
.50464 .68593 m .50563 .69444 L .50464 .69397 L .845 .571 .524 r
F
.50419 .67721 m .50465 .67793 L .50509 .67753 L .683 .77 .917 r
F
.50479 .67816 m .50387 .68006 L .50541 .67912 L F
.50593 .67831 m .50094 .68611 L .50615 .67847 L F
.50464 .67737 m .5049 .68174 L .50464 .68165 L .845 .571 .524 r
F
.50681 .67957 m .50362 .68082 L .50365 .68129 L .683 .77 .917 r
F
.50394 .68139 m .50365 .68129 L .50367 .68156 L F
.50681 .67957 m .50365 .68129 L .50394 .68139 L F
.50654 .68233 m .5014 .69074 L .50668 .68238 L F
.50464 .68165 m .50515 .68611 L .50464 .68593 L .845 .571 .524 r
F
.5055 .68228 m .49692 .68985 L .5014 .69074 L .683 .77 .917 r
F
.50563 .67772 m .50603 .68204 L .50563 .682 L .751 .491 .539 r
F
.50681 .67957 m .50475 .68172 L .5055 .68228 L .683 .77 .917 r
F
.50475 .68172 m .49692 .68985 L .5055 .68228 L F
.50419 .67721 m .5037 .67772 L .50465 .67793 L F
.50387 .68006 m .50396 .68138 L .50541 .67912 L F
.50446 .67723 m .50451 .68154 L .50398 .67688 L .929 .648 .488 r
F
.50572 .6839 m .5014 .69074 L .50654 .68518 L .683 .77 .917 r
F
.50398 .63447 m .50446 .67723 L .50398 .67688 L .929 .648 .488 r
F
.50499 .67762 m .49648 .68523 L .50503 .67765 L .683 .77 .917 r
F
.50464 .63506 m .50554 .67769 L .50535 .67762 L .845 .571 .524 r
F
.50563 .63553 m .50676 .67782 L .50563 .67772 L .751 .491 .539 r
F
.50632 .675 m .49979 .67756 L .49269 .68365 L .683 .77 .917 r
F
.49979 .67756 m .48982 .68148 L .49185 .68301 L F
.49979 .67756 m .49185 .68301 L .49269 .68365 L F
.50521 .63114 m .50408 .63193 L .50408 .67461 L .401 .213 .507 r
F
.50451 .68154 m .50415 .68129 L .50398 .67688 L .929 .648 .488 r
F
.50045 .6811 m .49269 .68365 L .49648 .68523 L .683 .77 .917 r
F
.49269 .68365 m .47906 .69229 L .48664 .69545 L F
.49813 .68298 m .48848 .68346 L .49023 .68608 L F
.5037 .6753 m .50366 .67965 L .50408 .67461 L 0 0 .377 r
F
.5036 .68057 m .50374 .68505 L .5036 .68485 L .989 .72 .386 r
F
.50367 .68156 m .49311 .68826 L .50376 .68275 L .683 .77 .917 r
F
.5037 .68072 m .5038 .68516 L .5036 .68057 L .989 .72 .386 r
F
.50481 .68674 m .49741 .69442 L .50551 .68785 L .683 .77 .917 r
F
.5038 .68516 m .50398 .69337 L .50374 .68505 L .989 .72 .386 r
F
.5038 .68516 m .50374 .68505 L .5036 .68057 L F
.49269 .68365 m .48664 .69545 L .49648 .68523 L .683 .77 .917 r
F
.50367 .68156 m .49023 .68608 L .49311 .68826 L F
.50365 .68492 m .48847 .68514 L .48897 .68803 L F
.50359 .68042 m .5036 .68057 L .5036 .68485 L .783 .625 .063 r
F
.49692 .68985 m .48703 .70012 L .496 .70189 L .683 .77 .917 r
F
.49829 .69351 m .4936 .69284 L .49741 .69442 L F
.50731 .68415 m .50146 .68785 L .49829 .69351 L F
.50146 .68785 m .4936 .69284 L .49829 .69351 L F
.5036 .68485 m .50398 .69337 L .5036 .69268 L .989 .72 .386 r
F
.5045 .68198 m .50367 .68156 L .50376 .68275 L .683 .77 .917 r
F
.49979 .67756 m .48808 .67887 L .48982 .68148 L F
.5031 .67977 m .48877 .67761 L .48798 .68057 L F
.5039 .68104 m .50377 .68082 L .5036 .67628 L .989 .72 .386 r
F
.50427 .67448 m .50418 .67883 L .50439 .6744 L .401 .213 .507 r
F
.50446 .67723 m .50464 .68165 L .50451 .68154 L .929 .648 .488 r
F
.50681 .67957 m .50328 .68032 L .50283 .68114 L .683 .77 .917 r
F
.50418 .67883 m .50408 .68317 L .50424 .67879 L .401 .213 .507 r
F
.50418 .67883 m .50424 .67879 L .50439 .6744 L F
.50388 .67671 m .50398 .68116 L .5039 .68104 L .989 .72 .386 r
F
.50681 .67957 m .5036 .67922 L .5031 .67977 L .683 .77 .917 r
F
.5036 .67922 m .50269 .67912 L .50301 .67963 L F
.5036 .67922 m .50301 .67963 L .5031 .67977 L F
.50333 .67689 m .49269 .68365 L .5042 .6772 L F
.50269 .67912 m .48877 .67761 L .5031 .67977 L F
.50388 .67671 m .5039 .68104 L .5036 .67628 L .989 .72 .386 r
F
.5039 .68104 m .50393 .68536 L .50377 .68082 L F
.50393 .68536 m .50398 .69337 L .5038 .68516 L F
.50393 .68536 m .5038 .68516 L .5036 .67628 L F
.49648 .68523 m .48664 .69545 L .49556 .69721 L .683 .77 .917 r
F
.50399 .68545 m .48897 .68803 L .49072 .69066 L F
.50542 .68193 m .50563 .68628 L .5055 .68623 L .845 .571 .524 r
F
.5039 .68104 m .50398 .68116 L .50398 .69337 L .989 .72 .386 r
F
.50731 .68415 m .50365 .68492 L .50399 .68545 L .683 .77 .917 r
F
.50365 .68492 m .48897 .68803 L .50399 .68545 L F
.50408 .68317 m .50355 .69187 L .50409 .69084 L 0 0 .377 r
F
.50408 .68131 m .50367 .68156 L .5045 .68198 L .683 .77 .917 r
F
.50398 .68116 m .50464 .69397 L .50398 .69337 L .929 .648 .488 r
F
.50398 .67688 m .50415 .68129 L .50398 .68116 L F
.50415 .68129 m .50464 .69397 L .50398 .68116 L F
.50192 .67848 m .49269 .68365 L .50045 .6811 L .683 .77 .917 r
F
.5037 .67772 m .49648 .68523 L .50377 .67871 L F
.50294 .68039 m .48798 .68057 L .48848 .68346 L F
.50408 .67889 m .50381 .68367 L .50408 .68317 L 0 0 .377 r
F
.50408 .67461 m .50394 .67914 L .50408 .67889 L F
.50394 .67914 m .50381 .68367 L .50408 .67889 L F
.50328 .68032 m .50215 .67982 L .50294 .68039 L .683 .77 .917 r
F
.50446 .67723 m .50464 .67737 L .50464 .68165 L .929 .648 .488 r
F
.50681 .67957 m .50361 .67974 L .50328 .68032 L .683 .77 .917 r
F
.50361 .67974 m .50215 .67982 L .50328 .68032 L F
.50215 .67982 m .48798 .68057 L .50294 .68039 L F
.50458 .68588 m .49567 .68895 L .4936 .69284 L F
.50374 .68505 m .50398 .69337 L .5036 .68485 L .989 .72 .386 r
F
.50381 .68367 m .50355 .69187 L .50408 .68317 L 0 0 .377 r
F
.5036 .68475 m .5036 .68485 L .5036 .69268 L .783 .625 .063 r
F
.50359 .68042 m .5036 .68485 L .5036 .68475 L F
.50731 .68415 m .50357 .68434 L .50365 .68492 L .683 .77 .917 r
F
.50357 .68434 m .50329 .68436 L .5036 .68485 L F
.50357 .68434 m .5036 .68485 L .50365 .68492 L F
.50329 .68436 m .48847 .68514 L .50365 .68492 L F
.50143 .68071 m .48848 .68346 L .49813 .68298 L F
.50283 .68114 m .49023 .68608 L .50234 .68201 L F
.50376 .68376 m .49127 .67936 L .48926 .68219 L F
.50618 .68648 m .50481 .68674 L .50551 .68785 L F
.50535 .68618 m .50481 .68674 L .50618 .68648 L F
.50509 .67753 m .50499 .67762 L .50503 .67765 L F
.50535 .67762 m .50542 .68193 L .50464 .67737 L .845 .571 .524 r
F
.50542 .68193 m .50563 .69444 L .5049 .68174 L F
.50542 .68193 m .5049 .68174 L .50464 .67737 L F
.50535 .67762 m .50563 .682 L .50542 .68193 L F
.50681 .67957 m .50408 .68131 L .50418 .68148 L .683 .77 .917 r
F
.50477 .68169 m .50418 .68148 L .5045 .68198 L F
.50681 .67957 m .50418 .68148 L .50477 .68169 L F
.50731 .68415 m .50408 .68318 L .50376 .68376 L F
.50283 .68114 m .50143 .68071 L .49813 .68298 L F
.50408 .68318 m .49127 .67936 L .50376 .68376 L F
.50366 .67965 m .50362 .684 L .50394 .67914 L 0 0 .377 r
F
.50362 .684 m .50355 .69187 L .50381 .68367 L F
.50362 .684 m .50381 .68367 L .50394 .67914 L F
.50388 .67671 m .50398 .67688 L .50398 .68116 L .989 .72 .386 r
F
.50366 .67965 m .50394 .67914 L .50408 .67461 L 0 0 .377 r
F
.50328 .68032 m .50143 .68071 L .50283 .68114 L .683 .77 .917 r
F
.50451 .68154 m .50455 .68586 L .50415 .68129 L .929 .648 .488 r
F
.50431 .67874 m .50408 .68317 L .50423 .68307 L .401 .213 .507 r
F
.50439 .6744 m .50424 .67879 L .50431 .67874 L F
.50424 .67879 m .50408 .68317 L .50431 .67874 L F
.50521 .63114 m .50427 .67448 L .50439 .6744 L F
.50632 .675 m .50227 .67586 L .49979 .67756 L .683 .77 .917 r
F
.50227 .67586 m .48808 .67887 L .49979 .67756 L F
.5042 .6772 m .50192 .67848 L .50045 .6811 L F
.50359 .67608 m .5036 .67628 L .5036 .68057 L .783 .625 .063 r
F
.50455 .68586 m .50464 .69397 L .50432 .68569 L .929 .648 .488 r
F
.50515 .68611 m .50563 .69444 L .50464 .68593 L .845 .571 .524 r
F
.50521 .6824 m .50409 .69084 L .50521 .69006 L .401 .213 .507 r
F
.50632 .675 m .50333 .67689 L .5042 .6772 L .683 .77 .917 r
F
.50632 .675 m .5042 .6772 L .50509 .67753 L F
.50227 .67586 m .48758 .67599 L .48808 .67887 L F
.5036 .63377 m .50398 .67688 L .50388 .67671 L .989 .72 .386 r
F
.50632 .675 m .50329 .67516 L .50227 .67586 L .683 .77 .917 r
F
.50329 .67516 m .48758 .67599 L .50227 .67586 L F
.50521 .67384 m .50423 .68307 L .50521 .6824 L .401 .213 .507 r
F
.50521 .63114 m .50439 .6744 L .50521 .67384 L F
.50431 .67874 m .50472 .67846 L .50521 .67384 L F
.50427 .67448 m .50408 .67461 L .50408 .67889 L F
.50408 .63193 m .5037 .6753 L .50408 .67461 L 0 0 .377 r
F
.50408 .63193 m .50355 .67556 L .5037 .6753 L F
.50462 .67404 m .49743 .66575 L .49346 .66775 L .683 .77 .917 r
F
.50632 .675 m .50521 .67384 L .50462 .67404 L F
.50521 .67384 m .49743 .66575 L .50462 .67404 L F
.50631 .63081 m .50521 .63114 L .50521 .67384 L .568 .343 .534 r
F
.50451 .68154 m .50464 .68165 L .50464 .69397 L .929 .648 .488 r
F
.50731 .68415 m .50399 .68545 L .50458 .68588 L .683 .77 .917 r
F
.50235 .67909 m .49078 .67479 L .48877 .67761 L F
.5036 .67628 m .5037 .68072 L .5036 .68057 L .989 .72 .386 r
F
.50359 .67608 m .5036 .68057 L .50359 .68042 L .783 .625 .063 r
F
.50681 .67957 m .50368 .67864 L .50235 .67909 L .683 .77 .917 r
F
.50368 .67864 m .49078 .67479 L .50235 .67909 L F
.50551 .67374 m .50521 .67384 L .50521 .67812 L .568 .343 .534 r
F
.50283 .68114 m .50234 .68201 L .50367 .68156 L .683 .77 .917 r
F
.50359 .67608 m .5036 .68475 L .50355 .67556 L .783 .625 .063 r
F
.5036 .68475 m .5036 .69268 L .50358 .6845 L F
.5036 .68475 m .50358 .6845 L .50355 .67556 L F
.50479 .67816 m .50541 .67912 L .50618 .67792 L .683 .77 .917 r
F
.50554 .67769 m .50563 .682 L .50535 .67762 L .845 .571 .524 r
F
.5037 .6753 m .50355 .67984 L .50366 .67965 L 0 0 .377 r
F
.50355 .67556 m .50357 .68003 L .50355 .67984 L .783 .625 .063 r
F
.50554 .67769 m .50563 .67772 L .50563 .682 L .845 .571 .524 r
F
.50094 .67528 m .48836 .67305 L .48758 .67599 L .683 .77 .917 r
F
.50632 .675 m .50289 .67462 L .50094 .67528 L F
.50289 .67462 m .48836 .67305 L .50094 .67528 L F
.50632 .675 m .50509 .67753 L .50618 .67792 L F
.50631 .67347 m .50543 .67804 L .50631 .67775 L .568 .343 .534 r
F
.50631 .63081 m .50551 .67374 L .50631 .67347 L F
.50551 .67374 m .50543 .67804 L .50631 .67347 L F
.50368 .67864 m .49389 .67229 L .49078 .67479 L .683 .77 .917 r
F
.50681 .67957 m .5046 .67832 L .50368 .67864 L F
.5046 .67832 m .49389 .67229 L .50368 .67864 L F
.5055 .68623 m .50563 .68628 L .50563 .69444 L .845 .571 .524 r
F
.50643 .68635 m .50617 .68633 L .50563 .682 L .751 .491 .539 r
F
.50731 .68415 m .50535 .68618 L .50563 .68628 L .683 .77 .917 r
F
.50625 .68634 m .50563 .68628 L .50618 .68648 L F
.50731 .68415 m .50563 .68628 L .50625 .68634 L F
.50564 .682 m .5055 .68228 L .50669 .68209 L F
.50603 .68204 m .50643 .68635 L .50563 .682 L .751 .491 .539 r
F
.50643 .68635 m .50721 .6947 L .50617 .68633 L F
.50563 .682 m .50721 .6947 L .50563 .69444 L F
.50631 .67775 m .50521 .69006 L .50632 .68972 L .568 .343 .534 r
F
.50731 .68415 m .50553 .68229 L .50459 .68261 L .683 .77 .917 r
F
.50681 .67957 m .506 .67757 L .50533 .67803 L F
.50681 .67957 m .50533 .67803 L .50477 .67842 L F
.50431 .67874 m .50423 .68307 L .50472 .67846 L .401 .213 .507 r
F
.50632 .675 m .49037 .67023 L .48836 .67305 L .683 .77 .917 r
F
.50632 .675 m .49346 .66775 L .49037 .67023 L F
.50477 .67842 m .49788 .67028 L .49389 .67229 L F
.50427 .67448 m .50408 .67889 L .50418 .67883 L .401 .213 .507 r
F
.5037 .6753 m .50355 .67556 L .50355 .67984 L 0 0 .377 r
F
.50533 .67803 m .49788 .67028 L .50477 .67842 L .683 .77 .917 r
F
.50418 .67883 m .50408 .67889 L .50408 .68317 L .401 .213 .507 r
F
.50553 .68229 m .50297 .67349 L .49837 .67486 L .683 .77 .917 r
F
.50563 .63553 m .5072 .67785 L .50676 .67782 L .751 .491 .539 r
F
.50631 .63081 m .50521 .67384 L .50551 .67374 L .568 .343 .534 r
F
.50681 .67957 m .50691 .67766 L .50608 .67778 L .683 .77 .917 r
F
.50676 .67782 m .5072 .67785 L .5072 .68213 L .751 .491 .539 r
F
.50745 .67787 m .50577 .68623 L .50749 .67788 L .683 .77 .917 r
F
.50676 .67782 m .5072 .68213 L .50687 .68211 L .751 .491 .539 r
F
.50681 .67957 m .50669 .68209 L .50788 .68219 L .683 .77 .917 r
F
.50632 .675 m .50617 .67804 L .50746 .67781 L F
.50879 .63559 m .50981 .63515 L .50982 .67711 L .517 .303 .528 r
F
.50746 .67781 m .51063 .68559 L .50879 .67757 L .683 .77 .917 r
F
.51115 .69022 m .51548 .70086 L .52467 .69813 L F
.51049 .68745 m .51164 .69479 L .51624 .69343 L F
.50958 .68651 m .51022 .68909 L .51049 .68745 L F
.51022 .68909 m .51164 .69479 L .51049 .68745 L F
.5079 .68225 m .51115 .69022 L .50895 .68182 L F
.5088 .68185 m .50895 .68182 L .50894 .68178 L F
.5079 .68225 m .50895 .68182 L .5088 .68185 L F
.50834 .67765 m .50879 .67757 L .5088 .68185 L .641 .402 .54 r
F
.50915 .68606 m .50838 .68679 L .50922 .68614 L .683 .77 .917 r
F
.50816 .68624 m .50838 .68679 L .50915 .68606 L F
.50746 .67781 m .50745 .67787 L .50749 .67788 L F
.50834 .67765 m .50845 .68191 L .5072 .67785 L .641 .402 .54 r
F
.50781 .68202 m .5079 .68225 L .5088 .68185 L .683 .77 .917 r
F
.50822 .68639 m .50675 .69544 L .51164 .69479 L F
.5088 .68613 m .50982 .69406 L .5088 .6945 L .517 .303 .528 r
F
.5088 .68185 m .50914 .68597 L .5088 .68613 L F
.50838 .68679 m .51164 .69479 L .50922 .68614 L .683 .77 .917 r
F
.50914 .68597 m .50982 .69406 L .5088 .68613 L .517 .303 .528 r
F
.50816 .68624 m .50813 .68642 L .50822 .68639 L .683 .77 .917 r
F
.50813 .68642 m .50675 .69544 L .50822 .68639 L F
.5072 .68642 m .50675 .69544 L .50816 .68624 L F
.50788 .68219 m .50666 .6828 L .5079 .68225 L F
.5072 .67785 m .5088 .6945 L .50721 .6947 L .641 .402 .54 r
F
.50731 .68415 m .5072 .68642 L .50816 .68624 L .683 .77 .917 r
F
.50845 .68191 m .50857 .68617 L .50761 .68206 L .641 .402 .54 r
F
.50857 .68617 m .5088 .6945 L .50801 .68627 L F
.50857 .68617 m .50801 .68627 L .50761 .68206 L F
.50845 .68191 m .50761 .68206 L .5072 .67785 L F
.50681 .67957 m .50781 .68202 L .50894 .68178 L .683 .77 .917 r
F
.50834 .67765 m .5088 .68185 L .50845 .68191 L .641 .402 .54 r
F
.50781 .68202 m .5088 .68185 L .50894 .68178 L .683 .77 .917 r
F
.50731 .68415 m .50816 .68624 L .50915 .68606 L F
.50845 .68191 m .5088 .68185 L .5088 .68613 L .641 .402 .54 r
F
.50857 .68617 m .5088 .68613 L .5088 .6945 L F
.50845 .68191 m .5088 .68613 L .50857 .68617 L F
.51096 .68448 m .51108 .692 L .51097 .69281 L 0 0 .142 r
F
.51095 .6339 m .51107 .63309 L .51108 .67519 L F
.51043 .67926 m .51063 .68559 L .51521 .68423 L .683 .77 .917 r
F
.51063 .68559 m .52408 .69346 L .51521 .68423 L F
.51071 .68177 m .51574 .68885 L .51973 .68685 L F
.51001 .68185 m .51063 .68559 L .51043 .67926 L F
.51046 .68336 m .51574 .68885 L .51071 .68177 L F
.51053 .68084 m .5109 .68457 L .51053 .68512 L .076 0 .415 r
F
.51043 .67926 m .51521 .68423 L .51071 .67747 L .683 .77 .917 r
F
.51053 .67656 m .51072 .68056 L .51053 .68084 L .076 0 .415 r
F
.51072 .68056 m .5109 .68457 L .51053 .68084 L F
.51012 .68143 m .51046 .68336 L .51071 .68177 L .683 .77 .917 r
F
.50879 .67757 m .50905 .68173 L .5088 .68185 L .517 .303 .528 r
F
.50681 .67957 m .50949 .68235 L .51012 .68143 L .683 .77 .917 r
F
.50906 .67871 m .51063 .68559 L .5094 .6782 L F
.50949 .68235 m .51046 .68336 L .51012 .68143 L F
.51081 .67634 m .51917 .68224 L .52227 .67976 L F
.50879 .63559 m .50953 .67724 L .50879 .67757 L .517 .303 .528 r
F
.50632 .675 m .50992 .67703 L .51081 .67634 L .683 .77 .917 r
F
.51052 .63459 m .51095 .6339 L .51096 .67592 L .076 0 .415 r
F
.51071 .67747 m .51521 .68423 L .5155 .68408 L .683 .77 .917 r
F
.51521 .68423 m .53202 .68948 L .51917 .68224 L F
.51062 .68071 m .51973 .68685 L .52284 .68435 L F
.50879 .67757 m .50906 .67871 L .5094 .6782 L F
.50953 .67724 m .5096 .68149 L .50879 .67757 L .517 .303 .528 r
F
.50922 .68614 m .5094 .68677 L .50958 .68651 L .683 .77 .917 r
F
.51063 .68559 m .51494 .69618 L .52408 .69346 L F
.5091 .68195 m .51115 .69022 L .51574 .68885 L F
.51177 .67559 m .52227 .67976 L .52427 .67695 L F
.51038 .68096 m .51053 .68512 L .51043 .6852 L .358 .18 .498 r
F
.51298 .67464 m .52427 .67695 L .52506 .674 L .683 .77 .917 r
F
.50981 .63515 m .51041 .67665 L .51033 .67672 L .358 .18 .498 r
F
.51107 .63309 m .51062 .63205 L .51063 .67429 L .984 .727 .339 r
F
.51521 .68423 m .52408 .69346 L .53202 .68948 L .683 .77 .917 r
F
.51574 .68885 m .53264 .69413 L .51973 .68685 L F
.51197 .68554 m .52023 .69142 L .52333 .68893 L F
.50994 .68134 m .51012 .68143 L .5103 .68118 L F
.50994 .68134 m .5103 .68118 L .51062 .68071 L F
.51038 .68096 m .51043 .6852 L .50982 .68139 L .358 .18 .498 r
F
.51043 .6852 m .51053 .69349 L .51006 .68548 L F
.51043 .6852 m .51006 .68548 L .50982 .68139 L F
.51054 .68511 m .51282 .68725 L .51197 .68554 L .683 .77 .917 r
F
.50894 .68178 m .50901 .68203 L .5091 .68195 L F
.50905 .68173 m .50982 .69406 L .5088 .68185 L .517 .303 .528 r
F
.50731 .68415 m .5099 .68561 L .51054 .68511 L .683 .77 .917 r
F
.5099 .68561 m .51282 .68725 L .51054 .68511 L F
.51282 .68725 m .52023 .69142 L .51197 .68554 L F
.51013 .67714 m .51917 .68224 L .51053 .67656 L F
.51084 .6761 m .51087 .68034 L .51053 .67656 L .076 0 .415 r
F
.51096 .6802 m .51107 .68385 L .51096 .68448 L 0 0 .142 r
F
.51096 .67592 m .51101 .67989 L .51096 .6802 L F
.51071 .68177 m .51973 .68685 L .51086 .68087 L .683 .77 .917 r
F
.51101 .67989 m .51107 .68385 L .51096 .6802 L 0 0 .142 r
F
.50632 .675 m .51043 .67926 L .51071 .67747 L .683 .77 .917 r
F
.51041 .67665 m .51053 .67656 L .51053 .68084 L .358 .18 .498 r
F
.51012 .68143 m .51071 .68177 L .51062 .68076 L .683 .77 .917 r
F
.51047 .68088 m .51053 .68084 L .51053 .68512 L .358 .18 .498 r
F
.51041 .67665 m .51053 .68084 L .51047 .68088 L F
.51053 .68084 m .51062 .68076 L .51062 .68071 L .683 .77 .917 r
F
.51012 .68143 m .51062 .68076 L .51053 .68084 L F
.51071 .68177 m .51086 .68087 L .51062 .68071 L F
.51087 .68034 m .5109 .68457 L .51072 .68056 L .076 0 .415 r
F
.51087 .68034 m .51072 .68056 L .51053 .67656 L F
.51053 .67656 m .51917 .68224 L .51081 .67634 L .683 .77 .917 r
F
.51217 .67843 m .52564 .67857 L .52515 .67568 L F
.51084 .6761 m .51096 .6802 L .51087 .68034 L .076 0 .415 r
F
.50992 .67703 m .51013 .67714 L .51053 .67656 L .683 .77 .917 r
F
.51033 .67672 m .51038 .68096 L .50982 .67711 L .358 .18 .498 r
F
.5094 .6782 m .51001 .68185 L .51043 .67926 L .683 .77 .917 r
F
.51047 .68088 m .51053 .68512 L .51038 .68096 L .358 .18 .498 r
F
.51043 .6852 m .51053 .68512 L .51053 .69349 L F
.50922 .68614 m .51552 .69268 L .50982 .68567 L .683 .77 .917 r
F
.5094 .68677 m .51164 .69479 L .50958 .68651 L F
.51006 .68548 m .51053 .69349 L .50982 .68567 L .358 .18 .498 r
F
.51063 .67857 m .50958 .69014 L .51064 .69096 L .909 .63 .5 r
F
.51041 .67665 m .51047 .68088 L .51033 .67672 L .358 .18 .498 r
F
.50981 .63515 m .51052 .63459 L .51053 .67656 L F
.50981 .63515 m .51053 .67656 L .51041 .67665 L F
.51052 .63459 m .51084 .6761 L .51053 .67656 L .076 0 .415 r
F
.51052 .63459 m .51096 .67592 L .51084 .6761 L F
.51095 .6339 m .51108 .67519 L .51105 .6754 L 0 0 .142 r
F
.51095 .6339 m .51105 .6754 L .51096 .67592 L F
.51039 .67413 m .52506 .674 L .52456 .67113 L .683 .77 .917 r
F
.50632 .675 m .51134 .67473 L .51039 .67413 L F
.51134 .67473 m .52506 .674 L .51039 .67413 L F
.51063 .67429 m .50979 .67804 L .51063 .67857 L .909 .63 .5 r
F
.51062 .63205 m .50987 .67381 L .51063 .67429 L F
.50632 .675 m .51125 .67553 L .51086 .67476 L .683 .77 .917 r
F
.50981 .63515 m .51033 .67672 L .50982 .67711 L .358 .18 .498 r
F
.50987 .67381 m .50979 .67804 L .51063 .67429 L .909 .63 .5 r
F
.50982 .67711 m .51038 .68096 L .50982 .68139 L .358 .18 .498 r
F
.50681 .67957 m .51157 .67932 L .51165 .6792 L .683 .77 .917 r
F
.51033 .67672 m .51047 .68088 L .51038 .68096 L .358 .18 .498 r
F
.50982 .68139 m .51006 .68548 L .50982 .68567 L F
.50901 .68203 m .51115 .69022 L .5091 .68195 L .683 .77 .917 r
F
.5096 .68149 m .50982 .68139 L .50982 .69406 L .517 .303 .528 r
F
.50972 .68228 m .51026 .68262 L .51063 .67857 L .909 .63 .5 r
F
.51177 .67559 m .52427 .67695 L .51298 .67464 L .683 .77 .917 r
F
.51081 .67634 m .52227 .67976 L .51177 .67559 L F
.50953 .67724 m .50982 .67711 L .50982 .68139 L .517 .303 .528 r
F
.50681 .67957 m .51165 .6792 L .51086 .67871 L .683 .77 .917 r
F
.5096 .68149 m .50905 .68173 L .50879 .67757 L .517 .303 .528 r
F
.50953 .67724 m .50982 .68139 L .5096 .68149 L F
.50681 .67957 m .51068 .68072 L .51142 .68015 L .683 .77 .917 r
F
.51138 .68007 m .51142 .68015 L .5115 .68008 L F
.50681 .67957 m .51142 .68015 L .51138 .68007 L F
.51073 .67876 m .51063 .68285 L .5107 .68297 L .984 .727 .339 r
F
.51076 .67454 m .5107 .6787 L .51073 .67876 L F
.5107 .6787 m .51063 .68285 L .51073 .67876 L F
.50879 .63559 m .50982 .67711 L .50953 .67724 L .517 .303 .528 r
F
.50632 .675 m .51081 .67634 L .51177 .67559 L .683 .77 .917 r
F
.50909 .686 m .50922 .68614 L .50982 .68567 L F
.50968 .68574 m .50982 .69406 L .50931 .6859 L .517 .303 .528 r
F
.51181 .67931 m .52486 .68153 L .52564 .67857 L .683 .77 .917 r
F
.51076 .67454 m .51063 .67429 L .51063 .67857 L .984 .727 .339 r
F
.5107 .6787 m .51063 .67857 L .51063 .68285 L F
.51076 .67454 m .51063 .67857 L .5107 .6787 L F
.51071 .67747 m .5155 .68408 L .5128 .67865 L .683 .77 .917 r
F
.51102 .67935 m .51336 .68028 L .51181 .67931 L F
.50681 .67957 m .51138 .68007 L .51102 .67935 L F
.51138 .68007 m .51336 .68028 L .51102 .67935 L F
.51336 .68028 m .52486 .68153 L .51181 .67931 L F
.50975 .67374 m .50957 .6779 L .50966 .67796 L .909 .63 .5 r
F
.51062 .63205 m .50967 .67369 L .50975 .67374 L F
.50967 .67369 m .50957 .6779 L .50975 .67374 L F
.50987 .67381 m .50958 .68219 L .50972 .68228 L F
.51062 .63205 m .50975 .67374 L .50987 .67381 L F
.50966 .67796 m .50972 .678 L .50987 .67381 L F
.51086 .67476 m .51177 .67559 L .51298 .67464 L .683 .77 .917 r
F
.51125 .67553 m .51177 .67559 L .51086 .67476 L F
.50968 .68574 m .50931 .6859 L .50905 .68173 L .517 .303 .528 r
F
.50731 .68415 m .51759 .68721 L .51383 .68485 L .683 .77 .917 r
F
.50958 .68219 m .5085 .68976 L .50958 .69014 L .809 .541 .532 r
F
.50681 .67957 m .50994 .68134 L .51062 .68071 L .683 .77 .917 r
F
.51107 .63309 m .51063 .67429 L .51076 .67454 L .984 .727 .339 r
F
.51107 .63309 m .51076 .67454 L .51108 .67519 L F
.50879 .67343 m .52283 .66852 L .51996 .66634 L .683 .77 .917 r
F
.5072 .63579 m .50879 .67757 L .50834 .67765 L .641 .402 .54 r
F
.50632 .675 m .50972 .67366 L .50879 .67343 L .683 .77 .917 r
F
.50972 .67366 m .52283 .66852 L .50879 .67343 L F
.50957 .67362 m .50864 .68196 L .50958 .68219 L .809 .541 .532 r
F
.50957 .63122 m .5088 .67343 L .50957 .67362 L F
.50975 .67374 m .50966 .67796 L .50987 .67381 L .909 .63 .5 r
F
.50957 .63122 m .50849 .63085 L .5085 .67336 L .809 .541 .532 r
F
.50948 .67788 m .5234 .67306 L .52053 .67087 L .683 .77 .917 r
F
.50681 .67957 m .51049 .67813 L .50948 .67788 L F
.51084 .6761 m .51096 .67592 L .51096 .6802 L .076 0 .415 r
F
.51049 .67813 m .5234 .67306 L .50948 .67788 L .683 .77 .917 r
F
.5088 .67343 m .5085 .67336 L .5085 .67764 L .809 .541 .532 r
F
.51105 .6754 m .51108 .67519 L .51108 .67947 L 0 0 .142 r
F
.50951 .67786 m .52053 .67087 L .50885 .67745 L .683 .77 .917 r
F
.50966 .67796 m .50958 .68219 L .50972 .678 L .909 .63 .5 r
F
.50979 .67804 m .50972 .68228 L .51063 .67857 L F
.51086 .67871 m .51165 .6792 L .51217 .67843 L .683 .77 .917 r
F
.51105 .6754 m .51108 .67947 L .51106 .67963 L 0 0 .142 r
F
.51105 .6754 m .51106 .67963 L .51096 .67592 L F
.51106 .67963 m .51107 .68385 L .51101 .67989 L F
.51106 .67963 m .51101 .67989 L .51096 .67592 L F
.51135 .67779 m .52515 .67568 L .5234 .67306 L .683 .77 .917 r
F
.51108 .67519 m .51097 .67924 L .51108 .67947 L .984 .727 .339 r
F
.51043 .67815 m .51122 .67864 L .51135 .67779 L .683 .77 .917 r
F
.50681 .67957 m .51072 .67874 L .51043 .67815 L F
.51076 .67454 m .5107 .68297 L .51108 .67519 L .984 .727 .339 r
F
.5109 .68457 m .51097 .69281 L .51053 .68512 L .076 0 .415 r
F
.5107 .68297 m .51064 .69096 L .51085 .68329 L .984 .727 .339 r
F
.51087 .68034 m .51096 .6802 L .51096 .68448 L .076 0 .415 r
F
.5109 .68457 m .51096 .68448 L .51097 .69281 L F
.51087 .68034 m .51096 .68448 L .5109 .68457 L F
.51134 .68393 m .52535 .6861 L .52614 .68315 L .683 .77 .917 r
F
.50731 .68415 m .51093 .68454 L .51134 .68393 L F
.51093 .68454 m .52535 .6861 L .51134 .68393 L F
.5107 .68297 m .51085 .68329 L .51108 .67519 L .984 .727 .339 r
F
.5096 .68149 m .50968 .68574 L .50905 .68173 L .517 .303 .528 r
F
.50927 .68211 m .50993 .68143 L .5084 .68189 L .683 .77 .917 r
F
.51157 .67932 m .52564 .67857 L .51217 .67843 L F
.50993 .68143 m .51721 .67386 L .50961 .68079 L F
.50993 .68143 m .50961 .68079 L .5084 .68189 L F
.51072 .67874 m .51122 .67864 L .51043 .67815 L F
.51122 .67864 m .52515 .67568 L .51135 .67779 L F
.5084 .68189 m .51721 .67386 L .51272 .67297 L F
.5085 .68192 m .50741 .68963 L .5085 .68976 L .734 .477 .54 r
F
.50681 .67957 m .50864 .67767 L .5085 .67764 L .683 .77 .917 r
F
.5072 .63579 m .50834 .67765 L .5072 .67785 L .641 .402 .54 r
F
.5085 .67336 m .50763 .6776 L .5085 .67764 L .734 .477 .54 r
F
.5072 .63579 m .50879 .63559 L .50879 .67757 L .641 .402 .54 r
F
.50849 .63085 m .50771 .67333 L .5085 .67336 L .734 .477 .54 r
F
.50632 .675 m .50888 .67337 L .50792 .67334 L .683 .77 .917 r
F
.50771 .67333 m .50763 .6776 L .5085 .67336 L .734 .477 .54 r
F
.50792 .67334 m .50903 .67328 L .50837 .67287 L .683 .77 .917 r
F
.50957 .63122 m .5085 .67336 L .5088 .67343 L .809 .541 .532 r
F
.50888 .67337 m .50903 .67328 L .50792 .67334 L .683 .77 .917 r
F
.50632 .675 m .50746 .67781 L .50879 .67757 L F
.50776 .67761 m .5085 .67764 L .50783 .67747 L F
.50681 .67957 m .5085 .67764 L .50776 .67761 L F
.50681 .67957 m .50951 .67786 L .50885 .67745 L F
.5085 .67764 m .50755 .68188 L .5085 .68192 L .734 .477 .54 r
F
.50763 .6776 m .50755 .68188 L .5085 .67764 L F
.50731 .68415 m .50927 .68211 L .5085 .68192 L .683 .77 .917 r
F
.50731 .68415 m .5085 .68192 L .50839 .68192 L F
.50731 .68415 m .50909 .686 L .50993 .68562 L F
.50755 .68188 m .50741 .68963 L .5085 .68192 L .734 .477 .54 r
F
.50839 .68192 m .5085 .68192 L .5084 .68189 L .683 .77 .917 r
F
.50872 .67769 m .5085 .67764 L .5085 .68192 L .809 .541 .532 r
F
.50864 .68196 m .5085 .68192 L .5085 .68976 L F
.50872 .67769 m .5085 .68192 L .50864 .68196 L F
.5088 .67343 m .5085 .67764 L .50872 .67769 L F
.50972 .67366 m .52456 .67113 L .52283 .66852 L .683 .77 .917 r
F
.50632 .675 m .51106 .67399 L .50972 .67366 L F
.51106 .67399 m .52456 .67113 L .50972 .67366 L F
.50903 .67328 m .51996 .66634 L .50837 .67287 L F
.50967 .67369 m .50957 .67362 L .50957 .6779 L .909 .63 .5 r
F
.50783 .67747 m .51672 .66928 L .51223 .6684 L .683 .77 .917 r
F
.50872 .67769 m .50911 .67779 L .50957 .67362 L .809 .541 .532 r
F
.50864 .67767 m .51672 .66928 L .50783 .67747 L .683 .77 .917 r
F
.5088 .67343 m .50872 .67769 L .50957 .67362 L .809 .541 .532 r
F
.50872 .67769 m .50864 .68196 L .50911 .67779 L F
.50731 .68415 m .50999 .68245 L .50958 .68219 L .683 .77 .917 r
F
.50731 .68415 m .50958 .68219 L .50927 .68211 L F
.50864 .68196 m .5085 .68976 L .50958 .68219 L .809 .541 .532 r
F
.50927 .68211 m .50958 .68219 L .50934 .68204 L .683 .77 .917 r
F
.50885 .67745 m .52053 .67087 L .51672 .66928 L F
.50837 .67287 m .51996 .66634 L .51617 .66476 L F
.50759 .67238 m .51617 .66476 L .51171 .66388 L F
.50849 .63085 m .5074 .63072 L .50741 .67332 L .734 .477 .54 r
F
.50731 .68415 m .50742 .68188 L .50741 .68188 L .683 .77 .917 r
F
.50632 .675 m .50792 .67334 L .50741 .67332 L F
.50632 .675 m .50741 .67332 L .50712 .67336 L F
.50662 .67342 m .50632 .68972 L .50741 .67332 L .66 .417 .541 r
F
.50644 .68201 m .50741 .68188 L .50637 .68184 L .683 .77 .917 r
F
.50731 .68415 m .50741 .68188 L .50644 .68201 L F
.50741 .68188 m .50632 .68972 L .50741 .68963 L .66 .417 .541 r
F
.50741 .67332 m .50683 .68196 L .50741 .68188 L F
.50683 .68196 m .50632 .68972 L .50741 .68188 L F
.5074 .63072 m .50662 .67342 L .50741 .67332 L F
.50712 .67336 m .50741 .67332 L .50714 .6733 L .683 .77 .917 r
F
.50792 .67334 m .50837 .67287 L .50714 .6733 L F
.50632 .675 m .50759 .67238 L .50648 .67168 L F
.50573 .67355 m .50687 .66375 L .502 .66439 L F
.50632 .675 m .5064 .67345 L .50573 .67355 L F
.5074 .63072 m .50631 .63081 L .50631 .67775 L .66 .417 .541 r
F
.5064 .67345 m .50687 .66375 L .50573 .67355 L .683 .77 .917 r
F
.50681 .67957 m .50564 .682 L .50669 .68209 L F
.50662 .67342 m .50632 .68203 L .50646 .68201 L .66 .417 .541 r
F
.5074 .63072 m .5065 .67344 L .50662 .67342 L F
.5065 .67344 m .50632 .68203 L .50662 .67342 L F
.50608 .67778 m .50737 .66827 L .50248 .66891 L .683 .77 .917 r
F
.50691 .67766 m .50737 .66827 L .50608 .67778 L F
.50641 .67773 m .50631 .67775 L .50632 .68203 L .66 .417 .541 r
F
.50543 .67804 m .50535 .68235 L .50631 .67775 L .568 .343 .534 r
F
.50551 .67374 m .50521 .67812 L .50543 .67804 L F
.50439 .6744 m .50431 .67874 L .50521 .67384 L .401 .213 .507 r
F
.506 .67757 m .50248 .66891 L .50533 .67803 L .683 .77 .917 r
F
.50637 .68184 m .50787 .67284 L .50297 .67349 L F
.50771 .67333 m .50741 .67332 L .50741 .6776 L .734 .477 .54 r
F
.50756 .6776 m .50741 .6776 L .50741 .68188 L F
.50771 .67333 m .50741 .6776 L .50756 .6776 L F
.50849 .63085 m .50741 .67332 L .50771 .67333 L F
.50714 .6733 m .50837 .67287 L .50759 .67238 L .683 .77 .917 r
F
.50837 .67287 m .51617 .66476 L .50759 .67238 L F
.50759 .67238 m .51171 .66388 L .50648 .67168 L F
.50691 .67758 m .51223 .6684 L .50737 .66827 L F
.50681 .67957 m .50776 .67761 L .50691 .67758 L F
.50776 .67761 m .51223 .6684 L .50691 .67758 L F
.50771 .67333 m .50741 .68188 L .50755 .68188 L .734 .477 .54 r
F
.50742 .68188 m .50787 .67284 L .50637 .68184 L .683 .77 .917 r
F
.50755 .68188 m .50741 .68188 L .50741 .68963 L .734 .477 .54 r
F
.50648 .67168 m .51171 .66388 L .50687 .66375 L .683 .77 .917 r
F
.51062 .63205 m .50957 .63122 L .50957 .67362 L .909 .63 .5 r
F
.51062 .63205 m .50957 .67362 L .50967 .67369 L F
.50966 .67796 m .50957 .6779 L .50958 .68219 L F
.50972 .68228 m .50958 .68219 L .50958 .69014 L F
.51973 .68685 m .53886 .68913 L .52284 .68435 L .683 .77 .917 r
F
.51383 .68485 m .52333 .68893 L .52535 .6861 L F
.51759 .68721 m .52333 .68893 L .51383 .68485 L F
.50934 .68204 m .52102 .67545 L .51721 .67386 L F
.50999 .68245 m .52102 .67545 L .50934 .68204 L F
.50972 .68228 m .50958 .69014 L .51026 .68262 L .909 .63 .5 r
F
.5107 .68297 m .51063 .68285 L .51064 .69096 L .984 .727 .339 r
F
.5128 .67865 m .5155 .68408 L .51917 .68224 L .683 .77 .917 r
F
.51917 .68224 m .5382 .68451 L .52227 .67976 L F
.5115 .68008 m .52284 .68435 L .52486 .68153 L F
.51068 .68072 m .52284 .68435 L .5115 .68008 L F
.50982 .68567 m .51552 .69268 L .50993 .68562 L F
.51115 .69022 m .52467 .69813 L .51574 .68885 L F
.51552 .69268 m .51624 .69343 L .51533 .69231 L F
.51552 .69268 m .51533 .69231 L .50993 .68562 L F
.50993 .68562 m .51624 .69343 L .52023 .69142 L F
.51107 .68385 m .51108 .692 L .51096 .68448 L 0 0 .142 r
F
.51053 .68512 m .51097 .69281 L .51053 .69349 L .076 0 .415 r
F
.51108 .68375 m .51064 .69096 L .51108 .692 L .984 .727 .339 r
F
.51106 .67963 m .51108 .67947 L .51108 .68375 L 0 0 .142 r
F
.51107 .68385 m .51108 .68375 L .51108 .692 L F
.51106 .67963 m .51108 .68375 L .51107 .68385 L F
.51115 .68333 m .52614 .68315 L .52564 .68026 L .683 .77 .917 r
F
.50731 .68415 m .51105 .68395 L .51115 .68333 L F
.51105 .68395 m .52614 .68315 L .51115 .68333 L F
.51108 .67947 m .51093 .68344 L .51108 .68375 L .984 .727 .339 r
F
.51093 .68344 m .51064 .69096 L .51108 .68375 L F
.51063 .68284 m .52564 .68026 L .5239 .67763 L .683 .77 .917 r
F
.50731 .68415 m .5109 .68338 L .51063 .68284 L F
.5109 .68338 m .52564 .68026 L .51063 .68284 L F
.51097 .67924 m .51085 .68329 L .51108 .67947 L .984 .727 .339 r
F
.51085 .68329 m .51064 .69096 L .51093 .68344 L F
.51085 .68329 m .51093 .68344 L .51108 .67947 L F
.50982 .68567 m .51053 .69349 L .50982 .69406 L .358 .18 .498 r
F
.5074 .63072 m .50631 .67775 L .50641 .67773 L .66 .417 .541 r
F
.50731 .68415 m .50644 .68201 L .50553 .68229 L .683 .77 .917 r
F
.50646 .68201 m .50632 .68203 L .50632 .68972 L .66 .417 .541 r
F
.50644 .68201 m .50643 .68199 L .50632 .68203 L .683 .77 .917 r
F
.50644 .68201 m .50632 .68203 L .50553 .68229 L F
.50535 .68235 m .50592 .68216 L .50631 .67775 L .568 .343 .534 r
F
.50543 .67804 m .50521 .67812 L .50521 .6824 L F
.50543 .67804 m .50521 .6824 L .50535 .68235 L F
.50643 .68199 m .50297 .67349 L .50553 .68229 L .683 .77 .917 r
F
.50535 .68235 m .50521 .69006 L .50592 .68216 L .568 .343 .534 r
F
.5034 .68194 m .49837 .67486 L .49438 .67686 L .683 .77 .917 r
F
.50459 .68261 m .50333 .68105 L .5034 .68194 L F
.50333 .68105 m .49837 .67486 L .5034 .68194 L F
.50553 .68229 m .49837 .67486 L .50459 .68261 L F
.50535 .68235 m .50521 .6824 L .50521 .69006 L .568 .343 .534 r
F
.50533 .67803 m .50248 .66891 L .49788 .67028 L .683 .77 .917 r
F
.50455 .68586 m .50432 .68569 L .50415 .68129 L .929 .648 .488 r
F
.5049 .68174 m .50515 .68611 L .50464 .68165 L .845 .571 .524 r
F
.50423 .68307 m .50409 .69084 L .50521 .6824 L .401 .213 .507 r
F
.50399 .68545 m .49647 .6884 L .50458 .68588 L .683 .77 .917 r
F
.49311 .68826 m .48703 .70012 L .49692 .68985 L F
.49647 .6884 m .49072 .69066 L .49567 .68895 L F
.49647 .6884 m .49567 .68895 L .50458 .68588 L F
.50521 .63114 m .50408 .67461 L .50427 .67448 L .401 .213 .507 r
F
.50423 .68307 m .50408 .68317 L .50409 .69084 L F
.49567 .68895 m .49072 .69066 L .49189 .69154 L .683 .77 .917 r
F
.49567 .68895 m .49189 .69154 L .4936 .69284 L F
.50355 .67984 m .5036 .69268 L .50355 .69187 L .783 .625 .063 r
F
.50357 .68003 m .50358 .6845 L .50355 .67984 L F
.50358 .6845 m .5036 .69268 L .50357 .68438 L F
.50358 .6845 m .50357 .68438 L .50355 .67984 L F
.50357 .68434 m .48926 .68219 L .48847 .68514 L .683 .77 .917 r
F
.50366 .67965 m .50355 .67984 L .50355 .68412 L 0 0 .377 r
F
.50362 .684 m .50355 .68412 L .50355 .69187 L F
.50366 .67965 m .50355 .68412 L .50362 .684 L F
.50731 .68415 m .50376 .68376 L .50357 .68434 L .683 .77 .917 r
F
.50376 .68376 m .50352 .68374 L .50355 .68412 L F
.50376 .68376 m .50355 .68412 L .50357 .68434 L F
.50352 .68374 m .48926 .68219 L .50357 .68434 L F
.76114 .71769 m .7461 .71274 L .74661 .71731 L .733 .497 .571 r
F
0 g
.73143 .71467 m
.7461 .71274 L
s
.7461 .71274 m
.76063 .71312 L
s
.32678 .72371 m .31165 .72106 L .31212 .72564 L .673 .453 .579 r
F
0 g
.29837 .72973 m
.31212 .72564 L
s
.32678 .72371 m .32631 .71914 L .31165 .72106 L .673 .453 .579 r
F
0 g
.29789 .72516 m
.31165 .72106 L
s
.32344 .82675 m .32501 .82701 L .325 .83057 L .751 .492 .54 r
F
.325 .83057 m .32156 .83546 L .3248 .83591 L .644 .733 .913 r
F
.32352 .83029 m .325 .83057 L .32479 .88617 L .751 .492 .54 r
F
.32344 .82675 m .325 .83057 L .32352 .83029 L F
.32509 .82827 m .32405 .83039 L .325 .83057 L .644 .733 .913 r
F
.32405 .83039 m .32156 .83546 L .325 .83057 L F
.36155 .83257 m .36333 .82294 L .36307 .82671 L 0 0 .136 r
F
.36129 .83634 m .36155 .83257 L .36307 .82671 L F
.34949 .82988 m .36155 .83257 L .36307 .82671 L .644 .733 .913 r
F
0 g
.35861 .8365 m
.36155 .83257 L
s
.74798 .82455 m .74869 .82399 L .7487 .82422 L .362 .185 .501 r
F
.74887 .82399 m .75434 .82861 L .75642 .82714 L .645 .732 .913 r
F
.74574 .82268 m .74846 .82455 L .74887 .82399 L F
.74846 .82455 m .75434 .82861 L .74887 .82399 L F
.74869 .82399 m .74913 .82331 L .74914 .82362 L .088 0 .422 r
F
.74846 .82455 m .75167 .82967 L .75434 .82861 L .645 .732 .913 r
F
.74798 .82455 m .7487 .82422 L .74798 .82471 L .362 .185 .501 r
F
.74574 .82268 m .74793 .82526 L .74846 .82455 L .645 .732 .913 r
F
.74793 .82526 m .75167 .82967 L .74846 .82455 L F
.74765 .82494 m .7486 .83025 L .75167 .82967 L F
.7487 .82422 m .74915 .82718 L .74874 .82775 L .088 0 .422 r
F
.74869 .82399 m .74872 .82419 L .7487 .82422 L F
.74872 .82419 m .74915 .82718 L .7487 .82422 L F
.74872 .82419 m .74914 .82362 L .74915 .82718 L F
.74869 .82399 m .74914 .82362 L .74872 .82419 L F
.74874 .82775 m .74915 .82718 L .74945 .88247 L F
.74915 .82718 m .74957 .88167 L .74945 .88247 L 0 0 .158 r
F
.74913 .82331 m .74916 .82713 L .74915 .82718 L F
.74916 .82713 m .74957 .88167 L .74915 .82718 L F
.74865 .83016 m .74836 .83402 L .75144 .83344 L .645 .732 .913 r
F
.74775 .8291 m .74821 .83277 L .74865 .83016 L F
.74821 .83277 m .74836 .83402 L .74865 .83016 L F
.7474 .82868 m .74753 .8294 L .74775 .8291 L F
.74753 .8294 m .74836 .83402 L .74775 .8291 L F
.74536 .82519 m .74695 .82499 L .74697 .82863 L .642 .403 .541 r
F
.74635 .82868 m .74656 .82925 L .74733 .8286 L .645 .732 .913 r
F
.74551 .82645 m .7451 .83409 L .74836 .83402 L F
.74512 .88165 m .74725 .88414 L .74626 .8815 L .692 .759 .904 r
F
.74641 .88338 m .74539 .88387 L .74653 .88371 L F
.74566 .88138 m .74678 .88331 L .74567 .88352 L .642 .403 .541 r
F
.74553 .88105 m .74541 .88357 L .74641 .88338 L .692 .759 .904 r
F
.74541 .88357 m .74539 .88387 L .74641 .88338 L F
.74498 .88445 m .74825 .88678 L .74725 .88414 L F
.74539 .88387 m .74753 .88636 L .74653 .88371 L F
.74567 .88352 m .74727 .88415 L .74567 .88435 L .642 .403 .541 r
F
.7463 .88152 m .74725 .88414 L .74939 .88346 L .692 .759 .904 r
F
.74626 .8815 m .74627 .88154 L .7463 .88152 L F
.74627 .88154 m .74725 .88414 L .7463 .88152 L F
.7483 .88273 m .74744 .88318 L .74854 .88287 L F
.74725 .88107 m .74797 .88288 L .74726 .88322 L .519 .306 .53 r
F
.74725 .88107 m .74626 .8815 L .74733 .88116 L .692 .759 .904 r
F
.74618 .88128 m .74626 .8815 L .74725 .88107 L F
.74717 .88109 m .74724 .88322 L .74566 .88138 L .642 .403 .541 r
F
.74553 .88105 m .74741 .88315 L .7483 .88273 L .692 .759 .904 r
F
.74741 .88315 m .74744 .88318 L .7483 .88273 L F
.74725 .88414 m .75145 .88577 L .74939 .88346 L F
.74653 .88371 m .74968 .88569 L .74761 .88337 L F
.74726 .88322 m .7483 .88371 L .74727 .88415 L .519 .306 .53 r
F
.74744 .88318 m .74761 .88337 L .74824 .88303 L .692 .759 .904 r
F
.74761 .88337 m .75154 .88469 L .74854 .88287 L F
.74797 .88288 m .7483 .88371 L .74726 .88322 L .519 .306 .53 r
F
.74902 .82792 m .75411 .83238 L .75619 .83091 L .645 .732 .913 r
F
.74695 .82499 m .74704 .82861 L .74697 .82863 L .519 .306 .53 r
F
.74733 .8286 m .74656 .82925 L .7474 .82868 L .645 .732 .913 r
F
.74656 .82925 m .74836 .83402 L .7474 .82868 L F
.74681 .82551 m .7486 .83025 L .74765 .82494 L F
.74695 .82499 m .74798 .82455 L .748 .82827 L .519 .306 .53 r
F
.74704 .82861 m .748 .82827 L .7483 .88371 L F
.74695 .82499 m .748 .82827 L .74704 .82861 L F
.74917 .82344 m .75642 .82714 L .75778 .82537 L .645 .732 .913 r
F
.74574 .82268 m .74906 .82407 L .74917 .82344 L F
.74906 .82407 m .75642 .82714 L .74917 .82344 L F
.74913 .82331 m .74926 .8225 L .74926 .82289 L 0 0 .158 r
F
.74915 .82356 m .74926 .82289 L .74928 .82645 L F
.74913 .82331 m .74926 .82289 L .74915 .82356 L F
.74916 .82713 m .74928 .82645 L .74957 .88167 L F
.74913 .82331 m .74928 .82645 L .74916 .82713 L F
.74888 .82878 m .75144 .83344 L .75411 .83238 L .645 .732 .913 r
F
.7481 .82824 m .74879 .82932 L .74888 .82878 L F
.74879 .82932 m .75144 .83344 L .74888 .82878 L F
.74551 .82645 m .74727 .82853 L .7481 .82824 L F
.74727 .82853 m .75144 .83344 L .7481 .82824 L F
.74551 .82645 m .7481 .82824 L .74902 .82792 L F
.74928 .82645 m .74913 .88063 L .74957 .88167 L .982 .725 .331 r
F
.74926 .8225 m .74925 .82639 L .74928 .82645 L F
.74925 .82639 m .74913 .88063 L .74928 .82645 L F
.7481 .82824 m .751 .83023 L .74902 .82792 L .645 .732 .913 r
F
.751 .83023 m .75411 .83238 L .75056 .82926 L F
.751 .83023 m .75056 .82926 L .74902 .82792 L F
.74697 .82863 m .74823 .88061 L .74725 .88107 L .519 .306 .53 r
F
.74704 .82861 m .74823 .88061 L .74697 .82863 L F
.74744 .88318 m .74824 .88303 L .74854 .88287 L .692 .759 .904 r
F
.74808 .88141 m .74939 .88346 L .75124 .88248 L F
.74733 .88116 m .74785 .88175 L .74808 .88141 L F
.74785 .88175 m .74939 .88346 L .74808 .88141 L F
.74806 .88077 m .75124 .88248 L .74825 .88067 L F
.74733 .88116 m .74751 .88122 L .74806 .88077 L F
.74751 .88122 m .75124 .88248 L .74806 .88077 L F
.74898 .88216 m .74854 .88287 L .74927 .88225 L F
.74626 .8815 m .74939 .88346 L .74733 .88116 L F
.74553 .88105 m .7483 .88273 L .74898 .88216 L F
.7483 .88273 m .74854 .88287 L .74898 .88216 L F
.74829 .88273 m .74901 .88315 L .7483 .88371 L .362 .185 .501 r
F
.74828 .88059 m .74878 .88233 L .74829 .88273 L F
.74878 .88233 m .74901 .88315 L .74829 .88273 L F
.7494 .82732 m .75619 .83091 L .75755 .82914 L .645 .732 .913 r
F
.74798 .82455 m .74805 .82824 L .748 .82827 L .362 .185 .501 r
F
.74551 .82645 m .74871 .82779 L .7494 .82732 L .645 .732 .913 r
F
.74926 .82288 m .75778 .82537 L .75831 .82342 L F
.74574 .82268 m .74955 .82353 L .74926 .82288 L F
.74955 .82353 m .75778 .82537 L .74926 .82288 L F
.74926 .8225 m .74882 .82147 L .74882 .82192 L .982 .725 .331 r
F
.74922 .8228 m .74882 .82192 L .74884 .82548 L F
.74926 .8225 m .74882 .82192 L .74922 .8228 L F
.74871 .82778 m .74941 .87936 L .74899 .88 L .088 0 .422 r
F
.74869 .82399 m .74874 .82775 L .74871 .82778 L F
.74874 .82775 m .74941 .87936 L .74871 .82778 L F
.74952 .82668 m .75755 .82914 L .75808 .82719 L .645 .732 .913 r
F
.74798 .82471 m .74871 .82778 L .74805 .82824 L .362 .185 .501 r
F
.74551 .82645 m .7491 .82725 L .74952 .82668 L .645 .732 .913 r
F
.7491 .82725 m .75755 .82914 L .74952 .82668 L F
.74925 .82639 m .74884 .82548 L .74913 .88063 L .982 .725 .331 r
F
.74926 .8225 m .74884 .82548 L .74925 .82639 L F
.74871 .82779 m .75016 .82839 L .7494 .82732 L .645 .732 .913 r
F
.75016 .82839 m .75619 .83091 L .74976 .82751 L F
.75016 .82839 m .74976 .82751 L .7494 .82732 L F
.748 .82827 m .74896 .88003 L .74828 .88059 L .362 .185 .501 r
F
.74805 .82824 m .74896 .88003 L .748 .82827 L F
.74825 .88067 m .75124 .88248 L .75269 .88124 L .692 .759 .904 r
F
.74896 .88003 m .74899 .88216 L .74828 .88059 L .362 .185 .501 r
F
.74899 .88 m .7493 .88169 L .74901 .88215 L .088 0 .422 r
F
.74553 .88105 m .74973 .88155 L .74993 .88081 L .692 .759 .904 r
F
.74973 .88155 m .74974 .88155 L .74974 .88154 L F
.74973 .88155 m .74974 .88154 L .74993 .88081 L F
.74854 .88287 m .753 .88345 L .74927 .88225 L F
.74899 .88216 m .74901 .88315 L .74878 .88233 L .362 .185 .501 r
F
.74899 .88216 m .74878 .88233 L .74828 .88059 L F
.74942 .88151 m .74927 .88225 L .74974 .88155 L .692 .759 .904 r
F
.74823 .88061 m .7483 .88371 L .74725 .88107 L .519 .306 .53 r
F
.74553 .88105 m .74899 .88216 L .74942 .88151 L .692 .759 .904 r
F
.74899 .88216 m .74927 .88225 L .74942 .88151 L F
.74901 .88215 m .74945 .88247 L .74901 .88315 L .088 0 .422 r
F
.7493 .88169 m .74945 .88247 L .74901 .88215 L F
.74825 .88067 m .75269 .88124 L .74898 .88005 L .692 .759 .904 r
F
.74941 .87936 m .74944 .88148 L .74899 .88 L .088 0 .422 r
F
.74553 .88105 m .74987 .88082 L .74981 .88009 L .692 .759 .904 r
F
.74987 .88082 m .74993 .88081 L .74992 .88075 L F
.74987 .88082 m .74992 .88075 L .74981 .88009 L F
.74944 .88148 m .74945 .88247 L .7493 .88169 L .088 0 .422 r
F
.74944 .88148 m .7493 .88169 L .74899 .88 L F
.74744 .88318 m .74653 .88371 L .74761 .88337 L .692 .759 .904 r
F
.74724 .88322 m .74678 .88331 L .74566 .88138 L .642 .403 .541 r
F
.74553 .88105 m .74641 .88338 L .74744 .88318 L .692 .759 .904 r
F
.74641 .88338 m .74653 .88371 L .74744 .88318 L F
.74724 .88322 m .74727 .88415 L .74678 .88331 L .642 .403 .541 r
F
.74678 .88331 m .74727 .88415 L .74567 .88352 L F
.74536 .82519 m .74717 .88109 L .74566 .88138 L F
.74526 .87886 m .74618 .88128 L .74725 .88107 L .692 .759 .904 r
F
.74548 .82874 m .74697 .82863 L .74726 .88322 L .642 .403 .541 r
F
.74724 .88322 m .74726 .88322 L .74727 .88415 L F
.74548 .82874 m .74726 .88322 L .74724 .88322 L F
.74536 .82519 m .74697 .82863 L .74548 .82874 L F
.74551 .82645 m .74635 .82868 L .74733 .8286 L .645 .732 .913 r
F
.74798 .82471 m .7487 .82422 L .74871 .82778 L .362 .185 .501 r
F
.74805 .82824 m .74871 .82778 L .74901 .88315 L F
.74574 .82268 m .74681 .82551 L .74765 .82494 L .645 .732 .913 r
F
.3131 .81999 m .3013 .82324 L .31345 .82199 L .644 .733 .913 r
F
.3131 .81999 m .30059 .81926 L .3013 .82324 L F
.46405 .58774 m .44272 .58054 L .43472 .59167 L .673 .757 .914 r
F
.34657 .83719 m .36129 .83634 L .34923 .83365 L .644 .733 .913 r
F
.33583 .83273 m .34657 .83719 L .34923 .83365 L F
.33377 .83419 m .34657 .83719 L .33583 .83273 L F
.46621 .7102 m .47715 .71038 L .47764 .71496 L .86 .591 .531 r
F
.46621 .7102 m .46572 .70563 L .47715 .71038 L F
.47941 .69695 m .47715 .71038 L .48703 .70012 L .683 .77 .917 r
F
.47941 .69695 m .46572 .70563 L .47715 .71038 L F
0 g
.47715 .71038 m
.48126 .7112 L
s
.76165 .72226 m .76114 .71769 L .74661 .71731 L .733 .497 .571 r
F
0 g
.76114 .71769 m
.77454 .72034 L
s
.44271 .5861 m .43436 .59162 L .43467 .5973 L .166 .071 .494 r
F
.44271 .5861 m .4424 .58043 L .43436 .59162 L F
0 g
.43125 .60352 m
.43436 .59162 L
s
.54554 .7014 m .54504 .69683 L .55437 .68934 L .405 .26 .569 r
F
0 g
.53822 .70025 m
.54504 .69683 L
s
.70615 .48691 m .73892 .48337 L .70747 .48173 L .654 .726 .902 r
F
.37486 .43674 m .37351 .45822 L .38233 .43915 L F
.37486 .43674 m .35857 .4534 L .37351 .45822 L F
.34963 .82608 m .36314 .82293 L .35063 .8222 L .644 .733 .913 r
F
.33762 .82341 m .34963 .82608 L .35063 .8222 L F
.3363 .82517 m .34963 .82608 L .33762 .82341 L F
.51385 .58735 m .50813 .57174 L .5074 .58695 L .673 .757 .914 r
F
.51385 .58735 m .52104 .57255 L .50813 .57174 L F
0 g
.32502 .82448 m
.32503 .82345 L
s
.32245 .82628 m .32344 .82675 L .32343 .83027 L .844 .572 .526 r
F
.3233 .88308 m .32209 .88322 L .32314 .88344 L .692 .759 .903 r
F
.32314 .88344 m .32417 .88627 L .32427 .88347 L F
.32453 .88532 m .32339 .88565 L .32452 .88568 L F
.32331 .88306 m .32322 .88306 L .3233 .88308 L F
.32472 .88319 m .32479 .88617 L .32322 .88306 L .751 .492 .54 r
F
.32462 .88287 m .32357 .88523 L .32453 .88532 L .692 .759 .903 r
F
.32314 .88344 m .32191 .8862 L .32417 .88627 L F
.32357 .88523 m .32339 .88565 L .32453 .88532 L F
.32191 .8862 m .32407 .88907 L .32417 .88627 L F
.32339 .88565 m .32442 .8885 L .32452 .88568 L F
.32322 .8852 m .32479 .88617 L .32321 .88591 L .751 .492 .54 r
F
.32322 .88306 m .32435 .8853 L .32322 .8852 L F
.32435 .8853 m .32479 .88617 L .32322 .8852 L F
.32179 .82569 m .32245 .82628 L .32244 .8298 L .927 .648 .492 r
F
.32314 .83013 m .32299 .83027 L .32398 .83053 L .644 .733 .913 r
F
.3214 .825 m .32179 .82569 L .32177 .82923 L .989 .721 .393 r
F
.32141 .82863 m .32177 .82923 L .32156 .88485 L F
.3214 .825 m .32177 .82923 L .32141 .82863 L F
.32299 .83027 m .32261 .83064 L .32361 .8308 L .644 .733 .913 r
F
.32261 .83064 m .31855 .83452 L .32297 .83127 L F
.32261 .83064 m .32297 .83127 L .32361 .8308 L F
.32299 .83027 m .32361 .8308 L .32398 .83053 L F
.3213 .88196 m .32053 .88228 L .32185 .88238 L .692 .759 .903 r
F
.3212 .88282 m .31982 .88576 L .32209 .88322 L F
.3212 .88282 m .31804 .88497 L .31982 .88576 L F
.32116 .88365 m .32022 .88311 L .32035 .88383 L F
.32118 .88153 m .32148 .88417 L .32118 .88367 L .989 .721 .393 r
F
.32185 .88238 m .32169 .88237 L .32175 .88245 L .692 .759 .903 r
F
.32209 .88322 m .31982 .88576 L .32191 .8862 L F
.3222 .88265 m .32222 .88544 L .32157 .88216 L .927 .648 .492 r
F
.32249 .88277 m .32209 .88322 L .3233 .88308 L .692 .759 .903 r
F
.32462 .88287 m .32082 .88308 L .32116 .88365 L F
.32082 .88308 m .32022 .88311 L .32116 .88365 L F
.32462 .88287 m .32035 .88383 L .32076 .88449 L F
.32118 .88367 m .32156 .88485 L .32117 .88416 L .989 .721 .393 r
F
.322 .88465 m .32076 .88449 L .32144 .88503 L .692 .759 .903 r
F
.32135 .82419 m .3214 .825 L .32139 .82859 L .794 .634 .076 r
F
.32398 .83053 m .31855 .83452 L .32156 .83546 L .644 .733 .913 r
F
.32209 .88322 m .32191 .8862 L .32314 .88344 L .692 .759 .903 r
F
.32249 .88277 m .3212 .88282 L .32209 .88322 L F
.32244 .8298 m .32317 .88304 L .32223 .88268 L .844 .572 .526 r
F
.32437 .88067 m .32171 .88248 L .32249 .88277 L .692 .759 .903 r
F
.32171 .88248 m .3212 .88282 L .32249 .88277 L F
.32271 .88501 m .32144 .88503 L .32234 .88543 L F
.32317 .88304 m .32321 .88591 L .32223 .88268 L .844 .572 .526 r
F
.32318 .88304 m .32322 .88306 L .32321 .88591 L F
.32462 .88287 m .32192 .8847 L .32271 .88501 L .692 .759 .903 r
F
.32192 .8847 m .32144 .88503 L .32271 .88501 L F
.32462 .88287 m .32234 .88543 L .32339 .88565 L F
.32222 .88482 m .32321 .88591 L .32222 .88544 L .844 .572 .526 r
F
.32223 .88268 m .32297 .88511 L .32222 .88482 L F
.32297 .88511 m .32321 .88591 L .32222 .88482 L F
.32245 .82628 m .3225 .82983 L .32244 .8298 L F
.3225 .82983 m .32321 .88591 L .32244 .8298 L F
.32128 .88277 m .32053 .88228 L .3212 .88282 L .692 .759 .903 r
F
.32175 .88245 m .32125 .88238 L .32128 .88277 L F
.32125 .88238 m .32053 .88228 L .32128 .88277 L F
.32053 .88228 m .31804 .88497 L .3212 .88282 L F
.32113 .88306 m .3204 .88238 L .32022 .88311 L F
.32169 .88237 m .32053 .88228 L .32175 .88245 L F
.32155 .88213 m .32156 .88485 L .32118 .88153 L .989 .721 .393 r
F
.32462 .88287 m .32109 .88246 L .32113 .88306 L .692 .759 .903 r
F
.32109 .88246 m .3204 .88238 L .32113 .88306 L F
.32112 .8829 m .32117 .88416 L .32112 .88335 L .794 .634 .076 r
F
.32113 .88076 m .32117 .88353 L .32112 .8829 L F
.32117 .88353 m .32117 .88416 L .32112 .8829 L F
.32133 .82785 m .32118 .88149 L .32113 .88076 L F
.32118 .88149 m .32117 .88416 L .32113 .88076 L F
.32135 .82419 m .32134 .82789 L .32133 .82785 L F
.32245 .82628 m .32343 .83027 L .3225 .82983 L .844 .572 .526 r
F
.32029 .82965 m .31287 .82953 L .31406 .83145 L .644 .733 .913 r
F
.32179 .82569 m .32244 .8298 L .32181 .82927 L .927 .648 .492 r
F
.32509 .82827 m .32084 .82871 L .32029 .82965 L .644 .733 .913 r
F
.32084 .82871 m .31287 .82953 L .32029 .82965 L F
.32135 .82419 m .32139 .82859 L .32134 .82789 L .794 .634 .076 r
F
.3204 .82592 m .31313 .82576 L .31432 .82768 L .644 .733 .913 r
F
.32535 .8245 m .32096 .82495 L .3204 .82592 L F
.32096 .82495 m .31313 .82576 L .3204 .82592 L F
.32187 .82317 m .32135 .82419 L .32135 .82428 L 0 0 .373 r
F
.32184 .82342 m .32135 .82428 L .32133 .82785 L F
.32187 .82317 m .32135 .82428 L .32184 .82342 L F
.32134 .82789 m .32117 .88416 L .32133 .82785 L .794 .634 .076 r
F
.32233 .82975 m .32149 .82992 L .32151 .83019 L .644 .733 .913 r
F
.32143 .82932 m .31406 .83145 L .32233 .82975 L F
.32134 .82789 m .32139 .82859 L .32117 .88416 L .794 .634 .076 r
F
.32139 .82859 m .32155 .88213 L .32118 .88153 L .989 .721 .393 r
F
.32141 .82863 m .32155 .88213 L .32139 .82859 L F
.32179 .82569 m .32181 .82927 L .32177 .82923 L .927 .648 .492 r
F
.31847 .82895 m .31251 .82753 L .31287 .82953 L .644 .733 .913 r
F
.32075 .88149 m .31999 .88091 L .32012 .88163 L .692 .759 .903 r
F
.32177 .82923 m .3222 .88265 L .32157 .88216 L .927 .648 .492 r
F
.32437 .88067 m .32108 .88085 L .32075 .88149 L .692 .759 .903 r
F
.32108 .88085 m .31999 .88091 L .32075 .88149 L F
.32437 .88067 m .32012 .88163 L .32053 .88228 L F
.32165 .87975 m .32121 .88273 L .32165 .88189 L 0 0 .373 r
F
.32437 .88067 m .32017 .88018 L .31999 .88091 L .692 .759 .903 r
F
.32115 .88071 m .32112 .88335 L .32165 .87975 L 0 0 .373 r
F
.32163 .88192 m .32158 .88105 L .32086 .88167 L .692 .759 .903 r
F
.32437 .88067 m .3213 .88196 L .32185 .88238 L F
.32343 .83027 m .32472 .88319 L .32322 .88306 L .751 .492 .54 r
F
.32437 .88067 m .32249 .88277 L .32322 .88306 L .692 .759 .903 r
F
.32437 .88067 m .32314 .88344 L .32427 .88347 L F
.32462 .88287 m .32196 .88128 L .32163 .88192 L F
.32277 .88107 m .32164 .88233 L .32276 .88155 L .4 .212 .507 r
F
.32344 .82675 m .32352 .83029 L .32343 .83027 L .751 .492 .54 r
F
.32509 .82827 m .32143 .82932 L .32233 .82975 L .644 .733 .913 r
F
.32047 .82421 m .31328 .82181 L .31278 .82376 L F
.32535 .8245 m .32145 .82363 L .32047 .82421 L F
.32145 .82363 m .31328 .82181 L .32047 .82421 L F
.32025 .82336 m .3146 .82004 L .31328 .82181 L F
.32299 .82239 m .32187 .82317 L .32187 .82337 L .4 .212 .507 r
F
.3229 .82276 m .32187 .82337 L .32186 .82693 L F
.32299 .82239 m .32187 .82337 L .3229 .82276 L F
.32145 .82363 m .32175 .823 L .32025 .82336 L .644 .733 .913 r
F
.32535 .8245 m .32219 .82319 L .32145 .82363 L F
.32219 .82319 m .32175 .823 L .32145 .82363 L F
.32175 .823 m .3146 .82004 L .32025 .82336 L F
.3241 .82205 m .32299 .82239 L .32299 .82271 L .568 .344 .535 r
F
.32307 .8302 m .32296 .83024 L .32299 .83027 L .644 .733 .913 r
F
.32509 .82827 m .3219 .82998 L .32307 .8302 L F
.32299 .83027 m .3225 .83047 L .32261 .83064 L F
.3225 .82983 m .32343 .83027 L .32322 .88306 L .844 .572 .526 r
F
.3225 .82983 m .32322 .88306 L .32318 .88304 L F
.32175 .823 m .31666 .81857 L .3146 .82004 L .644 .733 .913 r
F
.32535 .8245 m .32279 .82275 L .32175 .823 L F
.32279 .82275 m .31666 .81857 L .32175 .823 L F
.32352 .83029 m .32472 .88319 L .32343 .83027 L .751 .492 .54 r
F
.31665 .82777 m .31301 .82558 L .31251 .82753 L .644 .733 .913 r
F
.31966 .82706 m .31434 .82381 L .31301 .82558 L F
.3214 .825 m .32141 .82863 L .32139 .82859 L .989 .721 .393 r
F
.32509 .82827 m .32125 .82668 L .31966 .82706 L .644 .733 .913 r
F
.32125 .82668 m .31434 .82381 L .31966 .82706 L F
.32409 .82245 m .32401 .82602 L .32409 .82244 L .568 .344 .535 r
F
.32125 .82668 m .3164 .82234 L .31434 .82381 L .644 .733 .913 r
F
.32509 .82827 m .32237 .82641 L .32125 .82668 L F
.32187 .82317 m .32133 .82785 L .32183 .82699 L 0 0 .373 r
F
.32237 .82641 m .3164 .82234 L .32125 .82668 L .644 .733 .913 r
F
.32409 .82245 m .32299 .82271 L .32298 .82627 L .568 .344 .535 r
F
.32401 .82602 m .32298 .82627 L .32276 .88155 L F
.32409 .82245 m .32298 .82627 L .32401 .82602 L F
.32401 .82602 m .32276 .88155 L .32401 .82602 L F
.32401 .82602 m .32401 .82602 L .32409 .82244 L F
.32094 .88027 m .32063 .87948 L .32017 .88018 L .692 .759 .903 r
F
.32437 .88067 m .3216 .87979 L .32094 .88027 L F
.3216 .87979 m .32063 .87948 L .32094 .88027 L F
.32437 .88067 m .32226 .87837 L .32134 .87886 L F
.32277 .87893 m .32165 .88188 L .32277 .88107 L .4 .212 .507 r
F
.32298 .82627 m .32171 .87971 L .32277 .87893 L F
.32437 .88067 m .32134 .87886 L .32063 .87948 L .692 .759 .903 r
F
.32171 .87971 m .32165 .88188 L .32277 .87893 L .4 .212 .507 r
F
.32299 .82271 m .32291 .82631 L .32298 .82627 L F
.32291 .82631 m .32165 .88188 L .32298 .82627 L F
.32011 .82798 m .31966 .82706 L .31665 .82777 L .644 .733 .913 r
F
.32509 .82827 m .32111 .82738 L .32011 .82798 L F
.32111 .82738 m .31966 .82706 L .32011 .82798 L F
.31966 .82706 m .31301 .82558 L .31665 .82777 L F
.32277 .87893 m .32333 .87803 L .32226 .87837 L .692 .759 .903 r
F
.32437 .88067 m .32357 .87864 L .32277 .87893 L F
.32408 .826 m .32283 .87891 L .32388 .87853 L .568 .344 .535 r
F
.32357 .87864 m .32333 .87803 L .32277 .87893 L .692 .759 .903 r
F
.32204 .88133 m .32251 .88056 L .32158 .88105 L F
.32437 .88067 m .32322 .88306 L .32331 .88306 L F
.32462 .88287 m .32292 .88101 L .32204 .88133 L F
.32292 .88101 m .32251 .88056 L .32204 .88133 L F
.32462 .88287 m .32358 .88022 L .32251 .88056 L F
.32387 .88067 m .32276 .88155 L .32387 .88122 L .568 .344 .535 r
F
.32388 .87853 m .32297 .881 L .32387 .88067 L F
.32297 .881 m .32276 .88155 L .32387 .88067 L F
.32283 .87891 m .32276 .88155 L .32388 .87853 L F
.32409 .82244 m .32401 .82602 L .32408 .826 L F
.32401 .82602 m .32276 .88155 L .32408 .826 L F
.3241 .82205 m .32409 .82245 L .32409 .82244 L F
.3241 .82205 m .32299 .82271 L .32409 .82245 L F
.32299 .82239 m .32298 .82271 L .32299 .82271 L .4 .212 .507 r
F
.32187 .82317 m .32183 .82699 L .32186 .82693 L 0 0 .373 r
F
.32254 .82653 m .31905 .82128 L .3164 .82234 L .644 .733 .913 r
F
.32509 .82827 m .32323 .82612 L .32254 .82653 L F
.32323 .82612 m .31905 .82128 L .32254 .82653 L F
.32298 .82271 m .3229 .82631 L .32299 .82271 L .4 .212 .507 r
F
.3229 .82631 m .32165 .88188 L .32291 .82631 L F
.3229 .82631 m .32291 .82631 L .32299 .82271 L F
.32165 .88188 m .32164 .88233 L .32277 .88107 L F
.32196 .88128 m .32158 .88105 L .32163 .8819 L .692 .759 .903 r
F
.32165 .88189 m .32163 .8819 L .32163 .88192 L F
.32196 .88128 m .32163 .8819 L .32165 .88189 L F
.32165 .88189 m .32112 .88335 L .32164 .88233 L 0 0 .373 r
F
.32121 .88273 m .32112 .88335 L .32165 .88189 L F
.32186 .82693 m .32115 .88071 L .32165 .87975 L F
.32183 .82699 m .32112 .88335 L .32186 .82693 L F
.32084 .82871 m .32011 .82798 L .31847 .82895 L .644 .733 .913 r
F
.32509 .82827 m .32122 .82804 L .32084 .82871 L F
.32122 .82804 m .32011 .82798 L .32084 .82871 L F
.32011 .82798 m .31251 .82753 L .31847 .82895 L F
.32261 .83064 m .32158 .83103 L .32162 .83159 L F
.32181 .82927 m .32222 .88544 L .32177 .82923 L .927 .648 .492 r
F
.32181 .82927 m .32244 .8298 L .32222 .88544 L F
.3229 .82631 m .32186 .82693 L .32164 .88233 L .4 .212 .507 r
F
.32299 .82239 m .32186 .82693 L .3229 .82631 L F
.32183 .82699 m .32133 .82785 L .32112 .88335 L 0 0 .373 r
F
.32151 .83019 m .31406 .83145 L .316 .83315 L .644 .733 .913 r
F
.32149 .82992 m .31406 .83145 L .32151 .83019 L F
.32162 .83159 m .316 .83315 L .31855 .83452 L F
.32158 .83103 m .316 .83315 L .32162 .83159 L F
.3225 .83047 m .316 .83315 L .32261 .83064 L F
.32462 .88287 m .32143 .88421 L .322 .88465 L .692 .759 .903 r
F
.32143 .88421 m .32076 .88449 L .322 .88465 L F
.32156 .8843 m .32222 .88544 L .32156 .88485 L .927 .648 .492 r
F
.32157 .88216 m .32208 .8847 L .32156 .8843 L F
.32208 .8847 m .32222 .88544 L .32156 .8843 L F
.32148 .88417 m .32156 .88485 L .32118 .88367 L .989 .721 .393 r
F
.32296 .83024 m .316 .83315 L .32299 .83027 L .644 .733 .913 r
F
.3219 .82998 m .316 .83315 L .32307 .8302 L F
.32509 .82827 m .32314 .83013 L .32398 .83053 L F
.29456 .57998 m .32388 .57605 L .29986 .57255 L .673 .757 .914 r
F
.27318 .57277 m .29456 .57998 L .29986 .57255 L F
.26908 .57599 m .29456 .57998 L .27318 .57277 L F
.39854 .44 m .4059 .45992 L .42114 .45668 L .654 .726 .902 r
F
.39041 .44027 m .4059 .45992 L .39854 .44 L F
.53202 .68948 m .54485 .69672 L .55413 .68927 L .683 .77 .917 r
F
.52408 .69346 m .54485 .69672 L .53202 .68948 L F
0 g
.25589 .53668 m
.25606 .50541 L
s
.58075 .60032 m .57345 .58372 L .57378 .5894 L .986 .711 .379 r
F
0 g
.58075 .60032 m
.58272 .61212 L
s
.24525 .48648 m .23774 .46648 L .22244 .46974 L .654 .726 .902 r
F
.25341 .48622 m .23774 .46648 L .24525 .48648 L F
.4558 .47387 m .47173 .45479 L .4713 .46207 L .34 .162 .487 r
F
.45536 .48116 m .4558 .47387 L .4713 .46207 L F
.43413 .45838 m .4558 .47387 L .4713 .46207 L .654 .726 .902 r
F
.42085 .46414 m .4558 .47387 L .43413 .45838 L F
0 g
.4454 .47838 m
.4558 .47387 L
s
.34135 .72409 m .32631 .71914 L .32678 .72371 L .733 .497 .571 r
F
0 g
.31165 .72106 m
.32631 .71914 L
s
.32631 .71914 m
.34087 .71951 L
s
.34135 .72409 m
.35481 .72674 L
s
.26153 .48733 m .25407 .46595 L .25341 .48622 L .654 .726 .902 r
F
.26153 .48733 m .27031 .46819 L .25407 .46595 L F
.57876 .92485 m .5785 .92265 L .58192 .92218 L .669 .437 .561 r
F
.57537 .92475 m .5785 .92265 L .57876 .92485 L .731 .482 .551 r
F
.57537 .92475 m .5751 .92255 L .5785 .92265 L F
0 0 0 r
2.5 Mabswid
.19428 .48364 Mdot
0 g
.5 Mabswid
.24935 .53656 m
.24952 .50507 L
s
.57862 .91982 m .5785 .92261 L .5819 .92214 L .692 .759 .904 r
F
.127 .923 .03 r
.65693 .80083 m
.65772 .76127 L
s
.65383 .80215 m
.65509 .76206 L
s
.57637 .91975 m .57512 .92251 L .5785 .92261 L .692 .759 .904 r
F
.58218 .92438 m .58192 .92218 L .58513 .92116 L .6 .388 .565 r
F
.127 .923 .03 r
.58836 .92054 m
.58837 .92017 L
s
.57876 .92485 m .58192 .92218 L .58218 .92438 L .669 .437 .561 r
F
0 g
.5785 .92265 m
.58192 .92218 L
s
.46446 .59903 m .43498 .60298 L .45909 .60648 L .673 .758 .914 r
F
.58089 .91951 m .5819 .92214 L .5851 .92113 L .692 .759 .904 r
F
0 g
.32678 .72371 m
.34135 .72409 L
s
.5009 .58759 m .49512 .57302 L .4829 .57628 L .673 .757 .914 r
F
.5074 .58695 m .49512 .57302 L .5009 .58759 L F
0 g
.57059 .83916 m
.58038 .83895 L
s
.58038 .83895 m
.59011 .84031 L
s
.57223 .92408 m .5751 .92255 L .57537 .92475 L .793 .527 .535 r
F
.57223 .92408 m .57197 .92188 L .5751 .92255 L F
0 g
.5751 .92255 m
.5785 .92265 L
s
.676 .47305 m .67065 .47092 L .66997 .47193 L .675 .735 .895 r
F
.676 .47305 m .67169 .47006 L .67065 .47092 L F
.676 .47305 m .67302 .4694 L .67169 .47006 L F
.57429 .91931 m .57512 .92251 L .57637 .91975 L .692 .759 .904 r
F
.57429 .91931 m .572 .92185 L .57512 .92251 L F
.61617 .45913 m .58211 .46787 L .61355 .46951 L .654 .726 .902 r
F
.61617 .45913 m .58602 .45229 L .58211 .46787 L F
.5856 .45958 m .58211 .46787 L .58169 .47515 L 0 0 .147 r
F
0 g
.58266 .47131 m
.58328 .47523 L
s
.5856 .45958 m .58602 .45229 L .58211 .46787 L 0 0 .147 r
F
.62082 .57833 m .63573 .57965 L .63606 .58533 L .86 .596 .539 r
F
.127 .923 .03 r
.62867 .57903 m
.63022 .52318 L
s
.62931 .57908 m
.63008 .53175 L
s
.62082 .57833 m .62049 .57265 L .63573 .57965 L .86 .596 .539 r
F
0 g
.63573 .57965 m
.64054 .58079 L
s
.20921 .4755 m .17203 .47181 L .19896 .48337 L .654 .726 .902 r
F
.64968 .57754 m .65434 .59525 L .66165 .58037 L .673 .758 .914 r
F
.64968 .57754 m .63639 .59101 L .65434 .59525 L F
0 g
.65434 .59525 m
.67378 .59646 L
s
.7115 .58395 m .7272 .57071 L .72754 .57638 L .517 .331 .568 r
F
.71184 .58963 m .7115 .58395 L .72754 .57638 L F
.69967 .57095 m .7115 .58395 L .72754 .57638 L .673 .757 .914 r
F
.68736 .57422 m .7115 .58395 L .69967 .57095 L F
0 g
.70323 .58616 m
.7115 .58395 L
s
.5074 .58695 m .50813 .57174 L .49512 .57302 L .673 .757 .914 r
F
.64631 .46597 m .61355 .46951 L .64499 .47116 L .654 .726 .902 r
F
.64631 .46597 m .61617 .45913 L .61355 .46951 L F
.21037 .46109 m .18868 .44567 L .17339 .45743 L F
.22353 .45536 m .18868 .44567 L .21037 .46109 L F
.25341 .48622 m .25407 .46595 L .23774 .46648 L F
.127 .923 .03 r
.40152 8.82548 m
.49918 5.78697 L
s
.50501 5.60561 m
.50933 5.47103 L
s
.66606 .59488 m
.66608 .59448 L
s
.50933 5.47103 m
.51917 5.16486 L
s
.49918 5.78697 m
.50501 5.60561 L
s
.63904 .5614 m .63593 .57945 L .64915 .56605 L .673 .757 .914 r
F
.63904 .5614 m .62077 .57248 L .63593 .57945 L F
.67605 .46318 m .67299 .45928 L .67442 .46332 L .675 .735 .895 r
F
.67605 .46318 m .67625 .45901 L .67299 .45928 L F
.67613 .46601 m .67305 .46208 L .67449 .46614 L F
.67613 .46601 m .67632 .46182 L .67305 .46208 L F
.6762 .46886 m .67312 .46493 L .67456 .46899 L F
.6762 .46886 m .67639 .46466 L .67312 .46493 L F
.67625 .45901 m .67156 .45524 L .67299 .45928 L F
.67625 .45901 m .67644 .45484 L .67156 .45524 L F
.67632 .46182 m .67161 .45802 L .67305 .46208 L F
.67632 .46182 m .67652 .45762 L .67161 .45802 L F
.67639 .46466 m .67168 .46087 L .67312 .46493 L F
.67639 .46466 m .67659 .46047 L .67168 .46087 L F
.67652 .45762 m .67154 .45518 L .67161 .45802 L .665 .425 .546 r
F
.67652 .45762 m .67644 .45477 L .67154 .45518 L F
.67659 .46047 m .67161 .45802 L .67168 .46087 L F
.67659 .46047 m .67652 .45762 L .67161 .45802 L F
.67643 .4728 m .6774 .45253 L .66922 .45279 L .654 .726 .902 r
F
0 g
.67279 .47177 m
.67281 .47611 L
s
.58539 .92336 m .58513 .92116 L .58791 .91968 L .515 .328 .565 r
F
.127 .923 .03 r
.58383 1.31001 m
.58829 .9267 L
s
.58706 2.92802 m
.63828 1.30117 L
s
.63828 1.30117 m
.6503 .91921 L
s
.58218 .92438 m .58513 .92116 L .58539 .92336 L .6 .388 .565 r
F
0 g
.58192 .92218 m
.58513 .92116 L
s
.5202 .59437 m .52144 .57807 L .5142 .59296 L .673 .757 .914 r
F
.5202 .59437 m .53342 .58091 L .52144 .57807 L F
.58302 .91883 m .5851 .92113 L .58787 .91965 L .692 .759 .904 r
F
.127 .923 .03 r
.65965 .79427 m
.661 .75248 L
s
.52561 .60238 m .53374 .58659 L .52052 .60005 L .673 .758 .914 r
F
.52561 .60238 m .54393 .59126 L .53374 .58659 L F
.30787 .48907 m .3209 .46699 L .29816 .48015 L .654 .726 .902 r
F
.30787 .48907 m .33546 .48036 L .3209 .46699 L F
.70787 .47445 m .73769 .46549 L .70706 .46915 L F
.70787 .47445 m .73932 .47609 L .73769 .46549 L F
0 g
.25582 .55054 m
.25589 .53668 L
s
.127 .923 .03 r
.3148 .58621 m
.31482 .5888 L
s
.73932 .47609 m .76834 .46183 L .73769 .46549 L .654 .726 .902 r
F
.73932 .47609 m .77076 .47774 L .76834 .46183 L F
0 g
.2492 .56399 m
.24935 .53656 L
s
.70778 .82423 m .70899 .82647 L .70875 .83024 L .92 .746 .257 r
F
.70778 .82423 m .70801 .82046 L .70899 .82647 L F
.72059 .8212 m .70899 .82647 L .72124 .82521 L .645 .732 .913 r
F
.72059 .8212 m .70801 .82046 L .70899 .82647 L F
0 g
.70899 .82647 m
.71112 .83 L
s
.50982 .48243 m .48575 .47594 L .48532 .48322 L .667 .431 .554 r
F
0 g
.46232 .4881 m
.48532 .48322 L
s
.50982 .48243 m .51025 .47514 L .48575 .47594 L .667 .431 .554 r
F
0 g
.46276 .48082 m
.48575 .47594 L
s
.77076 .47774 m .76873 .45455 L .76834 .46183 L .91 .732 .235 r
F
0 g
.74743 .42424 m
.77434 .45818 L
s
.77037 .48502 m .77076 .47774 L .76834 .46183 L .91 .732 .235 r
F
0 g
.7689 .48494 m
.76999 .48071 L
s
.53415 .48577 m .53457 .47849 L .51025 .47514 L .732 .487 .558 r
F
0 g
.53457 .47849 m
.55706 .48575 L
s
.73325 .82771 m .72332 .83281 L .73441 .82963 L .645 .732 .913 r
F
.73325 .82771 m .721 .82898 L .72332 .83281 L F
.20343 .58571 m .18612 .60103 L .20819 .59299 L .673 .757 .914 r
F
.20343 .58571 m .17897 .59011 L .18612 .60103 L F
0 g
.18612 .60103 m
.19777 .61029 L
s
.74712 .72188 m .73194 .71924 L .73245 .72381 L .673 .454 .579 r
F
0 g
.71865 .72791 m
.73245 .72381 L
s
.74712 .72188 m .74661 .71731 L .73194 .71924 L .673 .454 .579 r
F
0 g
.71814 .72334 m
.73194 .71924 L
s
.29994 .82679 m .28844 .83206 L .30065 .8308 L .644 .733 .913 r
F
.29994 .82679 m .28736 .82605 L .28844 .83206 L F
0 g
.28844 .83206 m
.292 .83781 L
s
.57902 .92704 m .57876 .92485 L .58218 .92438 L .669 .437 .561 r
F
.57563 .92694 m .57876 .92485 L .57902 .92704 L .731 .482 .551 r
F
.57563 .92694 m .57537 .92475 L .57876 .92485 L F
.57888 .92204 m .57876 .92485 L .58218 .92438 L .692 .759 .904 r
F
.127 .923 .03 r
.65958 .79643 m
.65965 .79427 L
s
.65376 .80431 m
.65383 .80215 L
s
.65689 .80299 m
.65693 .80083 L
s
.57662 .92198 m .57876 .92485 L .57888 .92204 L .692 .759 .904 r
F
.57662 .92198 m .57537 .92475 L .57876 .92485 L F
.78185 .83075 m .78369 .82112 L .78346 .82489 L 0 0 .162 r
F
.78162 .83452 m .78185 .83075 L .78346 .82489 L F
.76982 .82806 m .78185 .83075 L .78346 .82489 L .645 .732 .913 r
F
0 g
.77884 .83468 m
.78185 .83075 L
s
.73346 .81817 m .72159 .82143 L .73378 .82017 L .645 .732 .913 r
F
.73346 .81817 m .72095 .81744 L .72159 .82143 L F
.76687 .83537 m .78162 .83452 L .76958 .83183 L F
.75619 .83091 m .76687 .83537 L .76958 .83183 L F
.75411 .83238 m .76687 .83537 L .75619 .83091 L F
.58244 .92657 m .58218 .92438 L .58539 .92336 L .6 .388 .565 r
F
.57902 .92704 m .58218 .92438 L .58244 .92657 L .669 .437 .561 r
F
.58116 .92173 m .58218 .92438 L .58539 .92336 L .692 .759 .904 r
F
.57888 .92204 m .58218 .92438 L .58116 .92173 L F
0 g
.57876 .92485 m
.58218 .92438 L
s
.23028 .58496 m .21596 .59917 L .23416 .58805 L .673 .757 .914 r
F
.23028 .58496 m .20819 .59299 L .21596 .59917 L F
.76993 .82426 m .78351 .82111 L .77099 .82038 L .645 .732 .913 r
F
.75795 .82159 m .76993 .82426 L .77099 .82038 L F
.7566 .82335 m .76993 .82426 L .75795 .82159 L F
.31278 .82376 m .30091 .82703 L .31313 .82576 L .644 .733 .913 r
F
.31278 .82376 m .3002 .82302 L .30091 .82703 L F
.36129 .83634 m .36307 .82671 L .36281 .83048 L 0 0 .136 r
F
.34923 .83365 m .36129 .83634 L .36281 .83048 L .644 .733 .913 r
F
0 g
.35731 .84165 m
.36129 .83634 L
s
.56956 .92289 m .57197 .92188 L .57223 .92408 L .861 .577 .507 r
F
.127 .923 .03 r
.51917 7.67953 m
.57475 4.90437 L
s
.52377 4.93612 m
.55264 4.01832 L
s
.51917 5.16486 m
.55208 4.14125 L
s
.51165 6.98614 m
.53895 4.14903 L
s
.56956 .92289 m .5693 .9207 L .57197 .92188 L .861 .577 .507 r
F
0 g
.57197 .92188 m
.5751 .92255 L
s
.57252 .91852 m .572 .92185 L .57429 .91931 L .692 .759 .904 r
F
.57252 .91852 m .56935 .92066 L .572 .92185 L F
.127 .923 .03 r
.5692 .85166 m
.56967 .80096 L
s
.34949 .82988 m .36307 .82671 L .3505 .82597 L .644 .733 .913 r
F
.33742 .82719 m .34949 .82988 L .3505 .82597 L F
.33609 .82896 m .34949 .82988 L .33742 .82719 L F
0 g
.32501 .82701 m
.32501 .82701 L
s
.76165 .72226 m .74661 .71731 L .74712 .72188 L .733 .497 .571 r
F
0 g
.73194 .71924 m
.74661 .71731 L
s
.74661 .71731 m
.76114 .71769 L
s
.76165 .72226 m
.77505 .72491 L
s
.57249 .92628 m .57537 .92475 L .57563 .92694 L .793 .527 .535 r
F
.57249 .92628 m .57223 .92408 L .57537 .92475 L F
.57453 .92153 m .57537 .92475 L .57662 .92198 L .692 .759 .904 r
F
.57453 .92153 m .57223 .92408 L .57537 .92475 L F
0 g
.57537 .92475 m
.57876 .92485 L
s
.31212 .72564 m
.32678 .72371 L
s
.49504 .59483 m .48309 .58183 L .47244 .58687 L .673 .757 .914 r
F
.50118 .59319 m .48309 .58183 L .49504 .59483 L F
.65022 .45402 m .61688 .45192 L .64687 .45872 L .654 .726 .902 r
F
.4799 .70152 m .47764 .71496 L .48752 .70469 L .683 .77 .917 r
F
.4799 .70152 m .46621 .7102 L .47764 .71496 L F
0 g
.47764 .71496 m
.49109 .71761 L
s
.74712 .72188 m
.76165 .72226 L
s
.33762 .82341 m .35063 .8222 L .33812 .82146 L .644 .733 .913 r
F
.55129 .59176 m .56194 .57444 L .54361 .58558 L .673 .757 .914 r
F
.55129 .59176 m .57345 .58372 L .56194 .57444 L F
.54554 .7014 m .55437 .68934 L .55487 .69391 L .405 .26 .569 r
F
.54604 .70597 m .54554 .7014 L .55487 .69391 L F
.53264 .69413 m .54554 .7014 L .55487 .69391 L .683 .77 .917 r
F
.52467 .69813 m .54554 .7014 L .53264 .69413 L F
0 g
.53871 .70482 m
.54554 .7014 L
s
.51062 .61229 m
.51062 .63205 L
s
.58818 .92188 m .58791 .91968 L .59008 .91782 L .394 .243 .554 r
F
.127 .923 .03 r
.58829 .9267 m
.5883 .92581 L
s
.58539 .92336 m .58791 .91968 L .58818 .92188 L .515 .328 .565 r
F
0 g
.58513 .92116 m
.58791 .91968 L
s
.7073 .46188 m .73201 .44818 L .70442 .45686 L .654 .726 .902 r
F
.7073 .46188 m .73778 .45825 L .73201 .44818 L F
.58565 .92556 m .58539 .92336 L .58818 .92188 L .515 .328 .565 r
F
.58244 .92657 m .58539 .92336 L .58565 .92556 L .6 .388 .565 r
F
.5833 .92105 m .58539 .92336 L .58818 .92188 L .692 .759 .904 r
F
.127 .923 .03 r
.59477 .87431 m
.59602 .82331 L
s
.58116 .92173 m .58539 .92336 L .5833 .92105 L .692 .759 .904 r
F
0 g
.58218 .92438 m
.58539 .92336 L
s
.58487 .91785 m .58787 .91965 L .59003 .9178 L .692 .759 .904 r
F
.127 .923 .03 r
.58838 .91927 m
.58839 .91921 L
s
.58842 .91782 m
.5896 .86817 L
s
.58302 .91883 m .58787 .91965 L .58487 .91785 L .692 .759 .904 r
F
0 g
.50408 .6124 m
.50408 .63193 L
s
.49004 .60303 m .47276 .59255 L .46446 .59903 L .673 .758 .914 r
F
.49536 .60051 m .47276 .59255 L .49004 .60303 L F
.4723 .5813 m .44272 .58054 L .46405 .58774 L .673 .757 .914 r
F
.38996 .44765 m .3892 .46793 L .40553 .4674 L .654 .726 .902 r
F
.38184 .44653 m .3892 .46793 L .38996 .44765 L F
.38184 .44653 m .37297 .46569 L .3892 .46793 L F
.32454 .58178 m .32424 .5761 L .3273 .56418 L 0 0 .314 r
F
0 g
.31973 .58242 m
.32424 .5761 L
s
.29986 .57255 m .32388 .57605 L .32693 .56419 L .673 .757 .914 r
F
.18788 .45272 m .17298 .45725 L .17251 .46453 L .335 .156 .484 r
F
.18788 .45272 m .18836 .44544 L .17298 .45725 L F
0 g
.16313 .47142 m
.17298 .45725 L
s
.57915 .92424 m .57902 .92704 L .58244 .92657 L .692 .759 .904 r
F
.127 .923 .03 r
.65369 .80648 m
.65376 .80431 L
s
.65951 .7986 m
.65958 .79643 L
s
.65685 .80514 m
.65689 .80299 L
s
.57688 .92417 m .57902 .92704 L .57915 .92424 L .692 .759 .904 r
F
.57688 .92417 m .57563 .92694 L .57902 .92704 L F
.46415 .59335 m .44271 .5861 L .43467 .5973 L .673 .757 .914 r
F
.44302 .59178 m .43467 .5973 L .43498 .60298 L .166 .071 .494 r
F
.44302 .59178 m .44271 .5861 L .43467 .5973 L F
0 g
.43156 .6092 m
.43467 .5973 L
s
.29507 .58573 m .32454 .58178 L .3004 .57826 L .673 .757 .914 r
F
.27358 .57848 m .29507 .58573 L .3004 .57826 L F
.26946 .58172 m .29507 .58573 L .27358 .57848 L F
.58143 .92393 m .58244 .92657 L .58565 .92556 L .692 .759 .904 r
F
.57915 .92424 m .58244 .92657 L .58143 .92393 L F
0 g
.57902 .92704 m
.58244 .92657 L
s
.67169 .47006 m .6653 .46879 L .67065 .47092 L .675 .735 .895 r
F
.5142 .59296 m .50846 .57727 L .50772 .59255 L .673 .757 .914 r
F
.5142 .59296 m .52144 .57807 L .50846 .57727 L F
.56982 .92509 m .57223 .92408 L .57249 .92628 L .861 .577 .507 r
F
.56982 .92509 m .56956 .92289 L .57223 .92408 L F
.57275 .92074 m .57223 .92408 L .57453 .92153 L .692 .759 .904 r
F
.57275 .92074 m .56956 .92289 L .57223 .92408 L F
0 g
.57223 .92408 m
.57537 .92475 L
s
.127 .923 .03 r
.57104 .81402 m
.57106 .81187 L
s
.72035 .82497 m .70875 .83024 L .721 .82898 L .645 .732 .913 r
F
.72035 .82497 m .70778 .82423 L .70875 .83024 L F
0 g
.70875 .83024 m
.71223 .83599 L
s
.51062 .63205 m
.51063 .66385 L
s
.57479 .92373 m .57563 .92694 L .57688 .92417 L .692 .759 .904 r
F
.57479 .92373 m .57249 .92628 L .57563 .92694 L F
0 g
.57563 .92694 m
.57902 .92704 L
s
.56755 .92126 m .5693 .9207 L .56956 .92289 L .934 .633 .448 r
F
.127 .923 .03 r
.59893 2.6834 m
.65951 .7986 L
s
.55208 4.14125 m
.59893 2.6834 L
s
.59738 2.59644 m
.65369 .80648 L
s
.55264 4.01832 m
.59738 2.59644 L
s
.53895 4.14903 m
.55792 2.17683 L
s
.55894 1.95052 m
.56073 1.75877 L
s
.52361 2.95267 m
.54478 1.94855 L
s
.56755 .92126 m .56728 .91907 L .5693 .9207 L .934 .633 .448 r
F
0 g
.5693 .9207 m
.57142 .92164 L
s
.22744 .56993 m .20784 .58156 L .22981 .57356 L .673 .757 .914 r
F
.22744 .56993 m .2031 .57431 L .20784 .58156 L F
0 g
.50408 .63193 m
.50408 .66412 L
s
.57118 .91744 m .56935 .92066 L .57252 .91852 L .692 .759 .904 r
F
.57118 .91744 m .56734 .91904 L .56935 .92066 L F
.53415 .48577 m .51025 .47514 L .50982 .48243 L .732 .487 .558 r
F
0 g
.51025 .47514 m
.53457 .47849 L
s
.53415 .48577 m
.55664 .49303 L
s
.48575 .47594 m
.51025 .47514 L
s
.3248 .88283 m
.3248 .88275 L
s
.3248 .88267 m
.3248 .88179 L
s
.32501 .82818 m
.32501 .82701 L
s
.58818 .92188 m .59008 .91782 L .59035 .92002 L .394 .243 .554 r
F
.58844 .92407 m .58818 .92188 L .59035 .92002 L F
.58565 .92556 m .58818 .92188 L .58844 .92407 L .515 .328 .565 r
F
.58516 .92006 m .58818 .92188 L .59035 .92002 L .692 .759 .904 r
F
.127 .923 .03 r
.58837 .92003 m
.58837 .91979 L
s
.5833 .92105 m .58818 .92188 L .58516 .92006 L .692 .759 .904 r
F
0 g
.58539 .92336 m
.58818 .92188 L
s
.50118 .59319 m .49538 .57855 L .48309 .58183 L .673 .757 .914 r
F
.50772 .59255 m .49538 .57855 L .50118 .59319 L F
.73316 .82194 m .72124 .82521 L .73349 .82394 L .645 .732 .913 r
F
.73316 .82194 m .72059 .8212 L .72124 .82521 L F
.78162 .83452 m .78346 .82489 L .78323 .82866 L 0 0 .162 r
F
.76958 .83183 m .78162 .83452 L .78323 .82866 L .645 .732 .913 r
F
0 g
.77755 .83983 m
.78162 .83452 L
s
.58357 .92325 m .58565 .92556 L .58844 .92407 L .692 .759 .904 r
F
.127 .923 .03 r
.59472 .87645 m
.59477 .87431 L
s
.5883 .92581 m
.58832 .9244 L
s
.58832 .9244 m
.58832 .92413 L
s
.58143 .92393 m .58565 .92556 L .58357 .92325 L .692 .759 .904 r
F
0 g
.58244 .92657 m
.58565 .92556 L
s
.76982 .82806 m .78346 .82489 L .77089 .82415 L .645 .732 .913 r
F
.75778 .82537 m .76982 .82806 L .77089 .82415 L F
.75642 .82714 m .76982 .82806 L .75778 .82537 L F
.62115 .58401 m .63606 .58533 L .63639 .59101 L .86 .596 .539 r
F
.127 .923 .03 r
.62922 .58472 m
.62926 .5822 L
s
.62852 .58466 m
.62859 .5819 L
s
.62115 .58401 m .62082 .57833 L .63606 .58533 L .86 .596 .539 r
F
.63919 .56719 m .63606 .58533 L .64935 .57186 L .673 .757 .914 r
F
.63919 .56719 m .62082 .57833 L .63606 .58533 L F
0 g
.63606 .58533 m
.64087 .58647 L
s
.71184 .58963 m .72754 .57638 L .72788 .58206 L .517 .331 .568 r
F
.70001 .57662 m .71184 .58963 L .72788 .58206 L .673 .758 .914 r
F
.6877 .5799 m .71184 .58963 L .70001 .57662 L F
0 g
.69339 .59454 m
.71184 .58963 L
s
.31251 .82753 m .30065 .8308 L .31287 .82953 L .644 .733 .913 r
F
.31251 .82753 m .29994 .82679 L .30065 .8308 L F
0 g
.73245 .72381 m
.74712 .72188 L
s
.67169 .47006 m .66738 .46707 L .6653 .46879 L .675 .735 .895 r
F
.67302 .4694 m .66738 .46707 L .67169 .47006 L F
.50772 .59255 m .50846 .57727 L .49538 .57855 L .673 .757 .914 r
F
.75795 .82159 m .77099 .82038 L .75848 .81964 L .645 .732 .913 r
F
.37433 .44411 m .37297 .46569 L .38184 .44653 L .654 .726 .902 r
F
.37433 .44411 m .35795 .46085 L .37297 .46569 L F
.34923 .83365 m .36281 .83048 L .35024 .82975 L .644 .733 .913 r
F
.33716 .83096 m .34923 .83365 L .35024 .82975 L F
.33583 .83273 m .34923 .83365 L .33716 .83096 L F
.59035 .92002 m .59008 .91782 L .59149 .91572 L .193 .102 .517 r
F
0 g
.58791 .91968 m
.59008 .91782 L
s
.58631 .91662 m .59003 .9178 L .59142 .91571 L .692 .759 .904 r
F
.58487 .91785 m .59003 .9178 L .58631 .91662 L F
.52052 .60005 m .52175 .58375 L .51452 .59863 L .673 .758 .914 r
F
.52052 .60005 m .53374 .58659 L .52175 .58375 L F
.39813 .44738 m .40553 .4674 L .42085 .46414 L .654 .726 .902 r
F
.38996 .44765 m .40553 .4674 L .39813 .44738 L F
.36849 .43319 m .35857 .4534 L .37486 .43674 L F
.36849 .43319 m .34584 .44631 L .35857 .4534 L F
.33742 .82719 m .3505 .82597 L .33792 .82524 L .644 .733 .913 r
F
.28913 .81642 m .28789 .81851 L .28763 .82228 L 0 0 .131 r
F
.127 .923 .03 r
.28754 .99999 m
.31014 2.65674 L
s
0 g
.28818 .82013 m
.28857 .82234 L
s
.30159 .81537 m .28957 .81269 L .28808 .81852 L .644 .733 .913 r
F
.28913 .81642 m .28939 .81265 L .28789 .81851 L 0 0 .131 r
F
.30159 .81537 m .28808 .81852 L .30059 .81926 L .644 .733 .913 r
F
.3136 .81805 m .30059 .81926 L .3131 .81999 L F
.3136 .81805 m .30159 .81537 L .30059 .81926 L F
.40616 .43838 m .42114 .45668 L .43435 .45094 L .654 .726 .902 r
F
.127 .923 .03 r
.43124 .44956 m
.43131 .43185 L
s
.39854 .44 m .42114 .45668 L .40616 .43838 L .654 .726 .902 r
F
.32561 .82073 m .3259 .81312 L .32265 .81319 L .644 .733 .913 r
F
.32561 .82073 m .32913 .81357 L .3259 .81312 L F
0 g
.32842 .82156 m
.32843 .82018 L
s
.57301 .92294 m .57249 .92628 L .57479 .92373 L .692 .759 .904 r
F
.57301 .92294 m .56982 .92509 L .57249 .92628 L F
0 g
.57249 .92628 m
.57563 .92694 L
s
.127 .923 .03 r
.57102 .81617 m
.57104 .81402 L
s
.33812 .82146 m .34993 .81821 L .33777 .81947 L .644 .733 .913 r
F
.33812 .82146 m .35063 .8222 L .34993 .81821 L F
.45708 .6991 m .46523 .70106 L .46572 .70563 L .933 .647 .477 r
F
.127 .923 .03 r
.46378 .70071 m
.46411 .65993 L
s
.45708 .6991 m .45659 .69453 L .46523 .70106 L .933 .647 .477 r
F
0 g
.46523 .70106 m
.46988 .70299 L
s
.67302 .4694 m .67005 .46575 L .66738 .46707 L .675 .735 .895 r
F
.67456 .46899 m .67005 .46575 L .67302 .4694 L F
.35063 .8222 m .36209 .81695 L .34993 .81821 L .644 .733 .913 r
F
.35063 .8222 m .36314 .82293 L .36209 .81695 L F
.45536 .48116 m .4713 .46207 L .47086 .46935 L .34 .162 .487 r
F
.43369 .46566 m .45536 .48116 L .47086 .46935 L .654 .726 .902 r
F
.42041 .47142 m .45536 .48116 L .43369 .46566 L F
0 g
.43545 .48979 m
.45536 .48116 L
s
.57901 .91924 m .57888 .92204 L .58116 .92173 L .692 .759 .904 r
F
0 g
.57928 .91889 m
.57928 .91972 L
s
.57788 .91921 m .57662 .92198 L .57888 .92204 L .692 .759 .904 r
F
.36307 .82671 m .36333 .82294 L .36228 .81693 L .931 .755 .276 r
F
0 g
.36236 .82667 m
.3629 .82461 L
s
0 0 0 r
2.5 Mabswid
.31485 .59156 Mdot
.127 .923 .03 r
.5 Mabswid
.31485 .59156 m
.31631 .74199 L
s
.58015 .91908 m .58116 .92173 L .5833 .92105 L .692 .759 .904 r
F
.47333 .68795 m .46544 .70093 L .47906 .69229 L .683 .77 .917 r
F
.47333 .68795 m .45684 .69443 L .46544 .70093 L F
.54604 .70597 m .55487 .69391 L .55536 .69848 L .405 .26 .569 r
F
.53314 .6987 m .54604 .70597 L .55536 .69848 L .683 .77 .917 r
F
.52516 .7027 m .54604 .70597 L .53314 .6987 L F
0 g
.53408 .71196 m
.54604 .70597 L
s
.56781 .92346 m .56956 .92289 L .56982 .92509 L .934 .633 .448 r
F
.56781 .92346 m .56755 .92126 L .56956 .92289 L F
.57141 .91965 m .56956 .92289 L .57275 .92074 L .692 .759 .904 r
F
.57141 .91965 m .56755 .92126 L .56956 .92289 L F
0 g
.56956 .92289 m
.57168 .92384 L
s
.127 .923 .03 r
.56868 .81502 m
.56873 .81286 L
s
.56918 .8538 m
.5692 .85166 L
s
.32156 .88613 m
.3217 .90066 L
s
.57683 .91898 m .57662 .92198 L .57788 .91921 L .692 .759 .904 r
F
.57683 .91898 m .57453 .92153 L .57662 .92198 L F
.58844 .92407 m .59035 .92002 L .59061 .92222 L .394 .243 .554 r
F
.58542 .92226 m .58844 .92407 L .59061 .92222 L .692 .759 .904 r
F
.127 .923 .03 r
.58831 .92223 m
.58833 .92147 L
s
.58357 .92325 m .58844 .92407 L .58542 .92226 L .692 .759 .904 r
F
0 g
.58565 .92556 m
.58844 .92407 L
s
.127 .923 .03 r
.66875 .57516 m
.66877 .57424 L
s
.58122 .91874 m .5833 .92105 L .58516 .92006 L .692 .759 .904 r
F
.49536 .60051 m .48341 .5875 L .47276 .59255 L .673 .758 .914 r
F
.5015 .59887 m .48341 .5875 L .49536 .60051 L F
.61576 .46642 m .58169 .47515 L .61314 .47679 L .654 .726 .902 r
F
.61576 .46642 m .5856 .45958 L .58169 .47515 L F
0 g
.58169 .47515 m
.58421 .49104 L
s
.6459 .47325 m .61314 .47679 L .64458 .47844 L .654 .726 .902 r
F
.6459 .47325 m .61576 .46642 L .61314 .47679 L F
.55161 .59744 m .56226 .58012 L .54393 .59126 L .673 .758 .914 r
F
.55161 .59744 m .57378 .5894 L .56226 .58012 L F
.59035 .92002 m .59149 .91572 L .59175 .91792 L .193 .102 .517 r
F
.59061 .92222 m .59035 .92002 L .59175 .91792 L F
.58661 .91882 m .59035 .92002 L .59175 .91792 L .692 .759 .904 r
F
.58516 .92006 m .59035 .92002 L .58661 .91882 L F
0 g
.58818 .92188 m
.59035 .92002 L
s
.67005 .46575 m .66306 .46408 L .66738 .46707 L .675 .735 .895 r
F
.67005 .46575 m .66707 .4621 L .66306 .46408 L F
.67312 .46493 m .66707 .4621 L .67005 .46575 L F
.67603 .48008 m .66882 .46008 L .66113 .46171 L .654 .726 .902 r
F
.67603 .48008 m .67699 .45981 L .66882 .46008 L F
.57503 .91584 m .57118 .91744 L .57252 .91852 L .692 .759 .904 r
F
0 0 0 r
2.5 Mabswid
.52612 .48566 Mdot
.127 .923 .03 r
.5 Mabswid
.52554 .52332 m
.52612 .48566 L
s
.20968 .46822 m .18788 .45272 L .17251 .46453 L .654 .726 .902 r
F
.22291 .46246 m .18788 .45272 L .20968 .46822 L F
.56632 .91931 m .56728 .91907 L .56755 .92126 L .975 .672 .303 r
F
.127 .923 .03 r
.56073 1.75877 m
.56555 1.24201 L
s
.54478 1.94855 m
.55769 1.33613 L
s
.55792 2.17683 m
.56517 1.42384 L
s
.56658 .91924 m
.56691 .90355 L
s
.56632 .91931 m .56606 .91711 L .56728 .91907 L .975 .672 .303 r
F
0 g
.56728 .91907 m
.56917 .92059 L
s
.127 .923 .03 r
.43742 7.01981 m
.55949 1.16939 L
s
0 0 0 r
2.5 Mabswid
.58828 .92359 Mdot
.127 .923 .03 r
.5 Mabswid
.40016 8.82725 m
.58085 1.23582 L
s
.57037 .91614 m .56734 .91904 L .57118 .91744 L .692 .759 .904 r
F
.57037 .91614 m .56612 .91709 L .56734 .91904 L F
.127 .923 .03 r
.5661 .85295 m
.56622 .84699 L
s
.70747 .48173 m .7373 .47277 L .70666 .47643 L .654 .726 .902 r
F
.70747 .48173 m .73892 .48337 L .7373 .47277 L F
.73892 .48337 m .76795 .46912 L .7373 .47277 L F
.73892 .48337 m .77037 .48502 L .76795 .46912 L F
.57594 .91859 m .57453 .92153 L .57683 .91898 L .692 .759 .904 r
F
.57594 .91859 m .57275 .92074 L .57453 .92153 L F
.72754 .57638 m .7272 .57071 L .73973 .56099 L .391 .238 .55 r
F
0 g
.71879 .57468 m
.7272 .57071 L
s
.127 .923 .03 r
.66874 .57516 m
.66879 .57377 L
s
0 g
.48532 .48322 m
.50982 .48243 L
s
.77037 .48502 m .76834 .46183 L .76795 .46912 L .91 .732 .235 r
F
0 g
.76635 .50057 m
.77037 .48502 L
s
.29862 .47287 m .30214 .44901 L .28581 .46575 L .654 .726 .902 r
F
.29862 .47287 m .32136 .4597 L .30214 .44901 L F
.73293 .82571 m .721 .82898 L .73325 .82771 L .645 .732 .913 r
F
.73293 .82571 m .72035 .82497 L .721 .82898 L F
.47244 .58687 m .44271 .5861 L .46415 .59335 L .673 .757 .914 r
F
.32454 .58178 m .3273 .56418 L .3276 .56986 L 0 0 .314 r
F
.32484 .58746 m .32454 .58178 L .3276 .56986 L F
.3004 .57826 m .32454 .58178 L .3276 .56986 L .673 .757 .914 r
F
0 g
.32002 .5881 m
.32454 .58178 L
s
.50982 .48243 m
.53415 .48577 L
s
.58631 .91662 m .59142 .91571 L .58724 .91522 L .692 .759 .904 r
F
.58259 .91543 m .58631 .91662 L .58724 .91522 L F
.70985 .56011 m .72694 .57055 L .73941 .56088 L .673 .757 .914 r
F
.69921 .56514 m .72694 .57055 L .70985 .56011 L F
.57927 .92144 m .57915 .92424 L .58143 .92393 L .692 .759 .904 r
F
.57814 .9214 m .57915 .92424 L .57927 .92144 L F
.57814 .9214 m .57688 .92417 L .57915 .92424 L F
.76958 .83183 m .78323 .82866 L .77066 .82793 L .645 .732 .913 r
F
.75755 .82914 m .76958 .83183 L .77066 .82793 L F
.75619 .83091 m .76958 .83183 L .75755 .82914 L F
0 0 0 r
2.5 Mabswid
.67007 .47928 Mdot
.58041 .92128 m .58143 .92393 L .58357 .92325 L .692 .759 .904 r
F
.57927 .92144 m .58143 .92393 L .58041 .92128 L F
.127 .923 .03 r
.5 Mabswid
.58085 1.23582 m
.58828 .92359 L
s
.46446 .59903 m .44302 .59178 L .43498 .60298 L .673 .758 .914 r
F
0 g
.43187 .61487 m
.43498 .60298 L
s
.58215 .91825 m .58516 .92006 L .58661 .91882 L .692 .759 .904 r
F
.29537 .59141 m .32484 .58746 L .30069 .58394 L .673 .757 .914 r
F
.27388 .58416 m .29537 .59141 L .30069 .58394 L F
.26975 .5874 m .29537 .59141 L .27388 .58416 L F
.57167 .92185 m .56982 .92509 L .57301 .92294 L .692 .759 .904 r
F
.57167 .92185 m .56781 .92346 L .56982 .92509 L F
0 g
.56982 .92509 m
.57249 .92628 L
s
.127 .923 .03 r
.56916 .85593 m
.56918 .8538 L
s
.56863 .81718 m
.56868 .81502 L
s
.75778 .82537 m .77089 .82415 L .75831 .82342 L .645 .732 .913 r
F
.70961 .8146 m .70825 .81669 L .70801 .82046 L 0 0 .157 r
F
0 g
.70854 .81851 m
.70887 .82051 L
s
.72201 .81355 m .71003 .81087 L .70844 .8167 L .645 .732 .913 r
F
.70961 .8146 m .70984 .81083 L .70825 .81669 L 0 0 .157 r
F
.72201 .81355 m .70844 .8167 L .72095 .81744 L .645 .732 .913 r
F
.51452 .59863 m .50878 .58295 L .50804 .59823 L .673 .758 .914 r
F
.51452 .59863 m .52175 .58375 L .50878 .58295 L F
.73399 .81623 m .72095 .81744 L .73346 .81817 L .645 .732 .913 r
F
.73399 .81623 m .72201 .81355 L .72095 .81744 L F
.59175 .91792 m .59149 .91572 L .59203 .91352 L 0 0 .388 r
F
.127 .923 .03 r
.57475 4.90437 m
.65196 1.04891 L
s
.65196 1.04891 m
.65685 .80514 L
s
0 g
.59008 .91782 m
.59149 .91572 L
s
.58724 .91522 m .59142 .91571 L .59197 .91352 L .692 .759 .904 r
F
.57709 .92118 m .57688 .92417 L .57814 .9214 L F
.57709 .92118 m .57479 .92373 L .57688 .92417 L F
.127 .923 .03 r
.73386 .81977 m
.73399 .81817 L
s
.73393 .81968 m
.73399 .81817 L
s
.74597 .81891 m .74313 .81137 L .74007 .81195 L .645 .732 .913 r
F
0 g
.74226 .81799 m
.74226 .81858 L
s
.74597 .81891 m .74638 .8113 L .74313 .81137 L .645 .732 .913 r
F
.74597 .81891 m .7496 .81175 L .74638 .8113 L F
0 0 0 r
2.5 Mabswid
.50267 .70901 Mdot
.75848 .81964 m .77036 .81639 L .75816 .81765 L .645 .732 .913 r
F
.75848 .81964 m .77099 .82038 L .77036 .81639 L F
.33716 .83096 m .35024 .82975 L .33766 .82901 L .644 .733 .913 r
F
.127 .923 .03 r
.5 Mabswid
.31631 .74199 m
.31635 .74558 L
s
.28886 .82019 m .28763 .82228 L .28736 .82605 L 0 0 .131 r
F
0 g
.28792 .8239 m
.28831 .82611 L
s
.3012 .81911 m .28913 .81642 L .28763 .82228 L .644 .733 .913 r
F
.28886 .82019 m .28913 .81642 L .28763 .82228 L 0 0 .131 r
F
.3012 .81911 m .28763 .82228 L .3002 .82302 L .644 .733 .913 r
F
.77099 .82038 m .78255 .81513 L .77036 .81639 L .645 .732 .913 r
F
.77099 .82038 m .78351 .82111 L .78255 .81513 L F
.31328 .82181 m .3002 .82302 L .31278 .82376 L .644 .733 .913 r
F
.31328 .82181 m .3012 .81911 L .3002 .82302 L F
.58148 .92094 m .58357 .92325 L .58542 .92226 L .692 .759 .904 r
F
.58041 .92128 m .58357 .92325 L .58148 .92094 L F
.78346 .82489 m .78369 .82112 L .78274 .81511 L .917 .743 .253 r
F
0 g
.78267 .82485 m
.78329 .82259 L
s
.22761 .57563 m .2079 .58732 L .22999 .57928 L .673 .757 .914 r
F
.22761 .57563 m .20315 .58003 L .2079 .58732 L F
.32535 .8245 m .31931 .81751 L .31666 .81857 L .644 .733 .913 r
F
0 g
.32188 .82049 m
.32189 .81981 L
s
.32535 .8245 m .32237 .81692 L .31931 .81751 L .644 .733 .913 r
F
.32535 .8245 m .32564 .81685 L .32237 .81692 L F
.32535 .8245 m .32888 .8173 L .32564 .81685 L F
.32535 .8245 m .33189 .81825 L .32888 .8173 L F
.33792 .82524 m .34979 .82197 L .33757 .82323 L F
.33792 .82524 m .3505 .82597 L .34979 .82197 L F
.64968 .46124 m .61617 .45913 L .64631 .46597 L .654 .726 .902 r
F
.3505 .82597 m .36202 .8207 L .34979 .82197 L .644 .733 .913 r
F
.3505 .82597 m .36307 .82671 L .36202 .8207 L F
.36307 .82671 m .36228 .81693 L .36202 .8207 L .931 .755 .276 r
F
.127 .923 .03 r
.3197 1.09089 m
.39492 8.82539 L
s
.36281 .83048 m .36307 .82671 L .36202 .8207 L .931 .755 .276 r
F
0 g
.3621 .83044 m
.36264 .82838 L
s
.5015 .59887 m .4957 .58423 L .48341 .5875 L .673 .758 .914 r
F
.50804 .59823 m .4957 .58423 L .5015 .59887 L F
.31492 .81629 m .30159 .81537 L .3136 .81805 L .644 .733 .913 r
F
.59061 .92222 m .59175 .91792 L .59201 .92011 L .193 .102 .517 r
F
.58687 .92102 m .59061 .92222 L .59201 .92011 L .692 .759 .904 r
F
.58542 .92226 m .59061 .92222 L .58687 .92102 L F
0 g
.58844 .92407 m
.59061 .92222 L
s
.57527 .91804 m .57275 .92074 L .57594 .91859 L .692 .759 .904 r
F
.57527 .91804 m .57141 .91965 L .57275 .92074 L F
.70706 .46915 m .73189 .45538 L .70415 .46409 L .654 .726 .902 r
F
.70706 .46915 m .73769 .46549 L .73189 .45538 L F
.57462 .91519 m .57118 .91744 L .57503 .91584 L .692 .759 .904 r
F
.57462 .91519 m .57037 .91614 L .57118 .91744 L F
.56658 .9215 m .56755 .92126 L .56781 .92346 L .975 .672 .303 r
F
.56658 .9215 m .56632 .91931 L .56755 .92126 L F
.57059 .91835 m .56755 .92126 L .57141 .91965 L .692 .759 .904 r
F
.57059 .91835 m .56632 .91931 L .56755 .92126 L F
0 g
.56755 .92126 m
.56943 .92279 L
s
.127 .923 .03 r
.56211 1.13079 m
.56571 .96054 L
s
.56571 .96054 m
.56654 .92113 L
s
.5431 .58001 m .54614 .56196 L .53297 .57537 L .673 .757 .914 r
F
.5431 .58001 m .56134 .56893 L .54614 .56196 L F
.33777 .81947 m .34757 .81439 L .33659 .81756 L .644 .733 .913 r
F
.33777 .81947 m .34993 .81821 L .34757 .81439 L F
.63952 .57287 m .63639 .59101 L .64968 .57754 L .673 .758 .914 r
F
.63952 .57287 m .62115 .58401 L .63639 .59101 L F
0 g
.63639 .59101 m
.65434 .59525 L
s
.127 .923 .03 r
.62614 .67061 m
.62824 .59485 L
s
.62824 .59485 m
.62844 .58736 L
s
.62906 .59456 m
.62917 .58769 L
s
.45757 .70367 m .46572 .70563 L .46621 .7102 L .933 .647 .477 r
F
.127 .923 .03 r
.39887 8.82483 m
.47772 3.65771 L
s
.39847 8.82601 m
.49022 1.67826 L
s
.46374 .70515 m
.46375 .70414 L
s
.45757 .70367 m .45708 .6991 L .46572 .70563 L .933 .647 .477 r
F
.47365 .69259 m .46572 .70563 L .47941 .69695 L .683 .77 .917 r
F
.47365 .69259 m .45708 .6991 L .46572 .70563 L F
0 g
.46572 .70563 m
.47037 .70756 L
s
.5762 .92078 m .57479 .92373 L .57709 .92118 L .692 .759 .904 r
F
.5762 .92078 m .57301 .92294 L .57479 .92373 L F
.38951 .45493 m .38875 .47521 L .40508 .47468 L .654 .726 .902 r
F
.38139 .45382 m .38875 .47521 L .38951 .45493 L F
.38139 .45382 m .37253 .47298 L .38875 .47521 L F
.50804 .59823 m .50878 .58295 L .4957 .58423 L .673 .758 .914 r
F
.58661 .91882 m .59175 .91792 L .58755 .91742 L .692 .759 .904 r
F
.58287 .91763 m .58661 .91882 L .58755 .91742 L F
.18741 .46 m .17251 .46453 L .17203 .47181 L .335 .156 .484 r
F
.18741 .46 m .18788 .45272 L .17251 .46453 L F
0 g
.16265 .4787 m
.17251 .46453 L
s
.57345 .58372 m .57313 .57805 L .56162 .56876 L .932 .657 .494 r
F
0 g
.57313 .57805 m
.5801 .58896 L
s
.58724 .91522 m .59197 .91352 L .5876 .91376 L .692 .759 .904 r
F
.58306 .91473 m .58724 .91522 L .5876 .91376 L F
.58259 .91543 m .58724 .91522 L .58306 .91473 L F
0 g
.58272 .91511 m
.58272 .91601 L
s
.58241 .92044 m .58542 .92226 L .58687 .92102 L .692 .759 .904 r
F
.58148 .92094 m .58542 .92226 L .58241 .92044 L F
0 g
.32841 .82509 m
.32842 .82374 L
s
.65022 .45402 m .62358 .44251 L .61688 .45192 L .654 .726 .902 r
F
.65539 .4501 m .62358 .44251 L .65022 .45402 L F
0 g
.32165 .88102 m
.32165 .87975 L
s
.32187 .82454 m
.32187 .82337 L
s
.59175 .91792 m .59203 .91352 L .5923 .91571 L 0 0 .388 r
F
.59201 .92011 m .59175 .91792 L .5923 .91571 L F
.58755 .91742 m .59175 .91792 L .5923 .91571 L .692 .759 .904 r
F
0 g
.59035 .92002 m
.59175 .91792 L
s
.70442 .45686 m .72248 .4393 L .69964 .45242 L .654 .726 .902 r
F
.70442 .45686 m .73201 .44818 L .72248 .4393 L F
.33546 .48036 m .33591 .47308 L .32136 .4597 L .927 .669 .527 r
F
0 g
.33591 .47308 m
.34386 .48661 L
s
.62358 .44251 m .58689 .44512 L .61688 .45192 L .654 .726 .902 r
F
.55487 .69391 m .55437 .68934 L .56043 .68088 L .203 .117 .53 r
F
0 g
.5486 .69397 m
.55437 .68934 L
s
.56597 .91715 m .56606 .91711 L .56632 .91931 L .754 .539 0 r
F
.127 .923 .03 r
.56517 1.42384 m
.56939 .98587 L
s
.55769 1.33613 m
.56574 .95439 L
s
.56555 1.24201 m
.56818 .96053 L
s
.55949 1.16939 m
.56451 .92882 L
s
.56597 .91715 m .5657 .91496 L .56606 .91711 L .754 .539 0 r
F
0 g
.56606 .91711 m
.56728 .91907 L
s
.57014 .91471 m .56612 .91709 L .57037 .91614 L .692 .759 .904 r
F
.57014 .91471 m .56577 .91495 L .56612 .91709 L F
.22353 .45536 m .20843 .43706 L .18868 .44567 L .654 .726 .902 r
F
.23875 .45212 m .20843 .43706 L .22353 .45536 L F
.5382 .68451 m .55413 .68927 L .56016 .68085 L .683 .77 .917 r
F
.53202 .68948 m .55413 .68927 L .5382 .68451 L F
.28611 .45863 m .2799 .43473 L .27115 .45381 L .654 .726 .902 r
F
.73778 .45825 m .75963 .43951 L .73201 .44818 L F
.73778 .45825 m .76827 .45461 L .75963 .43951 L F
.57553 .92024 m .57301 .92294 L .5762 .92078 L .692 .759 .904 r
F
.57553 .92024 m .57167 .92185 L .57301 .92294 L F
.127 .923 .03 r
.73355 .82364 m
.73367 .82217 L
s
.57486 .91739 m .57141 .91965 L .57527 .91804 L .692 .759 .904 r
F
.57486 .91739 m .57059 .91835 L .57141 .91965 L F
.57085 .92055 m .56781 .92346 L .57167 .92185 L F
.57085 .92055 m .56658 .9215 L .56781 .92346 L F
0 g
.56781 .92346 m
.56982 .92509 L
s
.75755 .82914 m .77066 .82793 L .75808 .82719 L .645 .732 .913 r
F
.70937 .81837 m .70801 .82046 L .70778 .82423 L 0 0 .157 r
F
0 g
.70831 .82228 m
.70863 .82428 L
s
.72165 .81729 m .70961 .8146 L .70801 .82046 L .645 .732 .913 r
F
.70937 .81837 m .70961 .8146 L .70801 .82046 L 0 0 .157 r
F
.72165 .81729 m .70801 .82046 L .72059 .8212 L .645 .732 .913 r
F
.7337 .81999 m .72059 .8212 L .73316 .82194 L F
.7337 .81999 m .72165 .81729 L .72059 .8212 L F
.5745 .91447 m .57037 .91614 L .57462 .91519 L .692 .759 .904 r
F
.5745 .91447 m .57014 .91471 L .57037 .91614 L F
.58306 .91473 m .5876 .91376 L .58324 .914 L F
.74574 .82268 m .74288 .8151 L .7398 .81569 L .645 .732 .913 r
F
.74574 .82268 m .74615 .81503 L .74288 .8151 L F
.74574 .82268 m .74939 .81548 L .74615 .81503 L F
.74574 .82268 m .75238 .81642 L .74939 .81548 L F
.74574 .82268 m .75492 .81779 L .75238 .81642 L F
.74882 .82147 m .74777 .82065 L .74777 .82113 L .91 .629 .499 r
F
.74926 .82167 m .75799 .82141 L .75684 .81949 L .645 .732 .913 r
F
.74574 .82268 m .75065 .82217 L .74926 .82167 L F
.75065 .82217 m .75799 .82141 L .74926 .82167 L F
.74933 .82231 m .75831 .82342 L .75799 .82141 L F
.74574 .82268 m .75017 .82294 L .74933 .82231 L F
.75017 .82294 m .75831 .82342 L .74933 .82231 L F
.74756 .82452 m .75469 .82156 L .75215 .8202 L F
.74777 .82065 m .74669 .82027 L .74671 .82431 L .809 .541 .532 r
F
.74551 .82645 m .74821 .82501 L .74779 .82469 L .645 .732 .913 r
F
.74551 .82645 m .74779 .82469 L .74749 .82459 L F
.74881 .82192 m .74777 .82113 L .74779 .82469 L .91 .629 .499 r
F
.74551 .82645 m .74957 .82603 L .74885 .82549 L .645 .732 .913 r
F
.75107 .82587 m .75808 .82719 L .75776 .82518 L F
.74551 .82645 m .75407 .82695 L .75107 .82587 L F
.75407 .82695 m .75808 .82719 L .75107 .82587 L F
.74526 .87886 m .74898 .88005 L .74945 .87935 L .692 .759 .904 r
F
.74779 .82469 m .74705 .87661 L .74807 .87688 L .809 .541 .532 r
F
.74725 .87667 m .74845 .87671 L .74757 .87631 L .692 .759 .904 r
F
.74526 .87886 m .74816 .87691 L .74725 .87667 L F
.74816 .87691 m .74845 .87671 L .74725 .87667 L F
.74526 .87886 m .74963 .87862 L .74952 .8779 L F
.74526 .87886 m .74952 .8779 L .74912 .87725 L F
.74807 .87688 m .74727 .87881 L .74808 .87903 L .809 .541 .532 r
F
.74526 .87886 m .74945 .87935 L .74963 .87862 L .692 .759 .904 r
F
.74751 .87888 m .74874 .8789 L .74785 .8785 L F
.74526 .87886 m .74825 .88067 L .74898 .88005 L F
.74553 .88105 m .74841 .87911 L .74751 .87888 L F
.74553 .88105 m .74981 .88009 L .74941 .87944 L F
.74913 .87973 m .74808 .87981 L .74913 .88063 L .91 .629 .499 r
F
.74884 .82548 m .74809 .87904 L .74913 .87973 L F
.74526 .87886 m .74733 .88116 L .74825 .88067 L .692 .759 .904 r
F
.74553 .88105 m .74941 .87944 L .74874 .8789 L F
.74809 .87904 m .74808 .87981 L .74913 .87973 L .91 .629 .499 r
F
.74841 .87911 m .74874 .8789 L .74786 .87888 L .692 .759 .904 r
F
.74808 .87903 m .74786 .87888 L .74751 .87888 L F
.74841 .87911 m .74786 .87888 L .74808 .87903 L F
.74808 .87903 m .74701 .87944 L .74808 .87981 L .809 .541 .532 r
F
.74727 .87881 m .74701 .87944 L .74808 .87903 L F
.74526 .87886 m .74912 .87725 L .74845 .87671 L .692 .759 .904 r
F
.74705 .87661 m .74701 .87944 L .74807 .87688 L .809 .541 .532 r
F
.74777 .82113 m .74772 .82467 L .74779 .82469 L F
.74772 .82467 m .74701 .87944 L .74779 .82469 L F
.74877 .82543 m .74779 .82469 L .74808 .87981 L .91 .629 .499 r
F
.74881 .82192 m .74779 .82469 L .74877 .82543 L F
.74885 .82549 m .75776 .82518 L .7566 .82327 L .645 .732 .913 r
F
.74957 .82603 m .75776 .82518 L .74885 .82549 L F
.74821 .82501 m .7566 .82327 L .75469 .82156 L F
.74551 .82645 m .74885 .82549 L .74821 .82501 L F
.74885 .82549 m .7566 .82327 L .74821 .82501 L F
.74881 .82192 m .74877 .82543 L .74882 .82192 L .91 .629 .499 r
F
.74877 .82543 m .74808 .87981 L .74878 .82544 L F
.74877 .82543 m .74878 .82544 L .74882 .82192 L F
.74771 .82467 m .74671 .82431 L .74701 .87944 L .809 .541 .532 r
F
.74574 .82268 m .7487 .82183 L .74813 .82141 L .645 .732 .913 r
F
.74777 .82065 m .74671 .82431 L .74771 .82467 L .809 .541 .532 r
F
.74749 .82459 m .74779 .82469 L .74756 .82452 L .645 .732 .913 r
F
.74882 .82192 m .74878 .82544 L .74884 .82548 L .91 .629 .499 r
F
.74821 .82501 m .75469 .82156 L .74756 .82452 L .645 .732 .913 r
F
.74878 .82544 m .74808 .87981 L .74884 .82548 L .91 .629 .499 r
F
.74882 .82147 m .74881 .82192 L .74882 .82192 L F
.74777 .82065 m .74776 .82113 L .74777 .82113 L .809 .541 .532 r
F
.74776 .82113 m .74701 .87944 L .74777 .82113 L F
.74882 .82147 m .74777 .82113 L .74881 .82192 L .91 .629 .499 r
F
.74813 .82141 m .75684 .81949 L .75492 .81779 L .645 .732 .913 r
F
.7487 .82183 m .75684 .81949 L .74813 .82141 L F
.29986 .57255 m .32693 .56419 L .30188 .56464 L .673 .757 .914 r
F
.27583 .56905 m .29986 .57255 L .30188 .56464 L F
.36793 .44054 m .35795 .46085 L .37433 .44411 L .654 .726 .902 r
F
.36793 .44054 m .34516 .45372 L .35795 .46085 L F
.75831 .82342 m .77025 .82015 L .75799 .82141 L .645 .732 .913 r
F
.75831 .82342 m .77089 .82415 L .77025 .82015 L F
.30094 .82288 m .28736 .82605 L .29994 .82679 L .644 .733 .913 r
F
.30094 .82288 m .28886 .82019 L .28736 .82605 L F
.127 .923 .03 r
.28443 .77227 m
.28754 .99999 L
s
0 g
.28736 .82605 m
.28844 .83206 L
s
.77089 .82415 m .78251 .81888 L .77025 .82015 L .645 .732 .913 r
F
.77089 .82415 m .78346 .82489 L .78251 .81888 L F
.58687 .92102 m .59201 .92011 L .58781 .91962 L .692 .759 .904 r
F
.58313 .91983 m .58687 .92102 L .58781 .91962 L F
.58241 .92044 m .58687 .92102 L .58313 .91983 L F
.37388 .45139 m .37253 .47298 L .38139 .45382 L .654 .726 .902 r
F
.37388 .45139 m .3575 .46813 L .37253 .47298 L F
.31301 .82558 m .29994 .82679 L .31251 .82753 L .644 .733 .913 r
F
.31301 .82558 m .30094 .82288 L .29994 .82679 L F
0 g
.57928 .91972 m
.58087 .91952 L
s
.57928 .91972 m
.57928 .91972 L
s
.57771 .91946 m
.57928 .91972 L
s
.78346 .82489 m .78274 .81511 L .78251 .81888 L .917 .743 .253 r
F
.78323 .82866 m .78346 .82489 L .78251 .81888 L F
0 g
.78244 .82862 m
.78306 .82636 L
s
.32615 .82611 m .33162 .82202 L .32862 .82107 L .644 .733 .913 r
F
.32509 .82827 m .32718 .82626 L .32615 .82611 L F
.32718 .82626 m .33162 .82202 L .32615 .82611 L F
.32626 .82613 m .32503 .87837 L .32606 .87842 L .734 .478 .541 r
F
.32538 .87839 m .32664 .87813 L .32559 .87791 L .692 .759 .903 r
F
.32437 .88067 m .32637 .87843 L .32538 .87839 L F
.32637 .87843 m .32664 .87813 L .32538 .87839 L F
.32503 .87837 m .32496 .88113 L .32606 .87842 L .734 .478 .541 r
F
.3247 .8805 m .32585 .88009 L .32472 .88006 L .692 .759 .903 r
F
.32437 .88067 m .32427 .88347 L .3254 .88332 L F
.32437 .88067 m .32647 .88298 L .32739 .88248 L F
.32462 .88287 m .32565 .88054 L .3247 .8805 L F
.32606 .87842 m .32521 .88052 L .32606 .88056 L .734 .478 .541 r
F
.32565 .88054 m .32585 .88009 L .3247 .8805 L .692 .759 .903 r
F
.32462 .88287 m .3269 .88032 L .32585 .88009 L F
.32606 .88056 m .32496 .88113 L .32605 .88126 L .734 .478 .541 r
F
.32521 .88052 m .32496 .88113 L .32606 .88056 L F
.32628 .82209 m .32619 .82612 L .32626 .82613 L F
.32619 .82612 m .32496 .88113 L .32626 .82613 L F
.127 .923 .03 r
.33607 1.2156 m
.33732 1.23009 L
s
.32628 .82209 m .32519 .82196 L .32496 .88113 L .734 .478 .541 r
F
.73534 .81447 m .72201 .81355 L .73399 .81623 L .645 .732 .913 r
F
.5923 .91571 m .59203 .91352 L .59168 .91136 L .752 .537 0 r
F
.127 .923 .03 r
.59319 .93868 m
.59472 .87645 L
s
.58799 1.1516 m
.59319 .93868 L
s
0 g
.59149 .91572 m
.592 .91364 L
s
.5876 .91376 m .59197 .91352 L .59162 .91138 L .692 .759 .904 r
F
.39768 .45467 m .40508 .47468 L .42041 .47142 L .654 .726 .902 r
F
.38951 .45493 m .40508 .47468 L .39768 .45467 L F
.40579 .44575 m .42085 .46414 L .43413 .45838 L F
.39813 .44738 m .42085 .46414 L .40579 .44575 L F
.58755 .91742 m .5923 .91571 L .58791 .91595 L .692 .759 .904 r
F
.58334 .91693 m .58755 .91742 L .58791 .91595 L F
.58287 .91763 m .58755 .91742 L .58334 .91693 L F
.32316 .82604 m .32211 .82069 L .31905 .82128 L .644 .733 .913 r
F
.32509 .82827 m .3242 .826 L .32316 .82604 L F
.3242 .826 m .32211 .82069 L .32316 .82604 L F
.32519 .82196 m .3241 .82205 L .32408 .826 L .66 .417 .541 r
F
.3251 .82597 m .32408 .826 L .32387 .88122 L F
.32519 .82196 m .32408 .826 L .3251 .82597 L F
.127 .923 .03 r
.33454 1.19771 m
.33607 1.2156 L
s
.17654 .57261 m .1784 .57876 L .17869 .58443 L .845 .639 .097 r
F
.17654 .57261 m .17625 .56693 L .1784 .57876 L F
0 g
.1784 .57876 m
.18176 .58388 L
s
.127 .923 .03 r
.66863 .58081 m
.66866 .57958 L
s
0 g
.32166 .8787 m
.32186 .82693 L
s
.32509 .82827 m .32537 .82062 L .32211 .82069 L .644 .733 .913 r
F
.32509 .82827 m .32862 .82107 L .32537 .82062 L F
.20168 .56647 m .17877 .57869 L .2031 .57431 L .673 .757 .914 r
F
.20168 .56647 m .17663 .56692 L .17877 .57869 L F
.127 .923 .03 r
.73378 .82335 m
.73384 .8217 L
s
.50675 .69544 m .50619 .70672 L .51597 .70543 L .683 .77 .917 r
F
.127 .923 .03 r
.52391 .63067 m
.52397 .62633 L
s
.5019 .69531 m .50619 .70672 L .50675 .69544 L .683 .77 .917 r
F
.5019 .69531 m .49649 .70647 L .50619 .70672 L F
.75816 .81765 m .76806 .81257 L .75701 .81574 L .645 .732 .913 r
F
.75816 .81765 m .77036 .81639 L .76806 .81257 L F
.33766 .82901 m .34953 .82574 L .33731 .827 L .644 .733 .913 r
F
.33766 .82901 m .35024 .82975 L .34953 .82574 L F
.32354 .87858 m .32447 .87788 L .32333 .87803 L .692 .759 .903 r
F
.32437 .88067 m .32444 .87845 L .32354 .87858 L F
.32519 .82196 m .32393 .87852 L .32497 .87837 L .66 .417 .541 r
F
.32444 .87845 m .32447 .87788 L .32354 .87858 L .692 .759 .903 r
F
.32437 .88067 m .32559 .87791 L .32447 .87788 L F
.32393 .87852 m .32387 .88122 L .32497 .87837 L .66 .417 .541 r
F
.32376 .88069 m .32472 .88006 L .32358 .88022 L .692 .759 .903 r
F
.32462 .88287 m .3247 .88055 L .32376 .88069 L F
.32497 .87837 m .32409 .88064 L .32497 .88051 L .66 .417 .541 r
F
.3247 .88055 m .32472 .88006 L .32376 .88069 L .692 .759 .903 r
F
.32497 .88051 m .32387 .88122 L .32496 .88113 L .66 .417 .541 r
F
.32409 .88064 m .32387 .88122 L .32497 .88051 L F
.35024 .82975 m .36176 .82447 L .34953 .82574 L .644 .733 .913 r
F
.35024 .82975 m .36281 .83048 L .36176 .82447 L F
.127 .923 .03 r
.43121 .45708 m
.43123 .45317 L
s
.72754 .57638 m .73973 .56099 L .74007 .56666 L .391 .238 .55 r
F
.72788 .58206 m .72754 .57638 L .74007 .56666 L F
.71036 .56589 m .72754 .57638 L .74007 .56666 L .673 .757 .914 r
F
.69967 .57095 m .72754 .57638 L .71036 .56589 L F
0 g
.71913 .58035 m
.72754 .57638 L
s
.51574 .68885 m .52467 .69813 L .53264 .69413 L .683 .77 .917 r
F
.36281 .83048 m .36202 .8207 L .36176 .82447 L .931 .755 .276 r
F
0 g
.36129 .83634 m
.36281 .83048 L
s
.3146 .82004 m .3012 .81911 L .31328 .82181 L .644 .733 .913 r
F
.47276 .59255 m .44302 .59178 L .46446 .59903 L .673 .758 .914 r
F
.5876 .91376 m .59162 .91138 L .58737 .91233 L .692 .759 .904 r
F
.58324 .914 m .5876 .91376 L .58737 .91233 L F
.59201 .92011 m .5923 .91571 L .59256 .91791 L 0 0 .388 r
F
.58781 .91962 m .59201 .92011 L .59256 .91791 L .692 .759 .904 r
F
0 g
.59061 .92222 m
.59201 .92011 L
s
.32484 .58746 m .3276 .56986 L .3279 .57554 L 0 0 .314 r
F
.30069 .58394 m .32484 .58746 L .3279 .57554 L .673 .757 .914 r
F
0 g
.31685 .59864 m
.32484 .58746 L
s
.31492 .81629 m .30422 .81185 L .30159 .81537 L .644 .733 .913 r
F
.31696 .81483 m .30422 .81185 L .31492 .81629 L F
.33757 .82323 m .34742 .81813 L .33638 .82131 L F
.33757 .82323 m .34979 .82197 L .34742 .81813 L F
.5794 .91863 m .57927 .92144 L .58041 .92128 L .692 .759 .904 r
F
.5794 .91863 m .57814 .9214 L .57927 .92144 L F
0 g
.30035 .43268 m
.30336 .43781 L
s
.33659 .81756 m .34371 .811 L .33466 .81587 L .644 .733 .913 r
F
.33659 .81756 m .34757 .81439 L .34371 .811 L F
.30422 .81185 m .28957 .81269 L .30159 .81537 L F
.5794 .91863 m .58041 .92128 L .58148 .92094 L .692 .759 .904 r
F
0 g
.58087 .91952 m
.5819 .91909 L
s
.51164 .69479 m .51597 .70543 L .52516 .7027 L .683 .77 .917 r
F
.50675 .69544 m .51597 .70543 L .51164 .69479 L F
.56623 .91935 m .56632 .91931 L .56658 .9215 L .754 .539 0 r
F
.56623 .91935 m .56597 .91715 L .56632 .91931 L F
.57036 .91691 m .56632 .91931 L .57059 .91835 L .692 .759 .904 r
F
.57036 .91691 m .56597 .91715 L .56632 .91931 L F
0 g
.56632 .91931 m
.56755 .92126 L
s
.127 .923 .03 r
.56605 .8551 m
.5661 .85295 L
s
.58324 .914 m .58737 .91233 L .58312 .91328 L .692 .759 .904 r
F
.5794 .91863 m .57709 .92118 L .57814 .9214 L F
0 g
.57673 .91899 m
.57771 .91946 L
s
.127 .923 .03 r
.66856 .5808 m
.66862 .57913 L
s
.34993 .81821 m .35855 .81122 L .34757 .81439 L .644 .733 .913 r
F
.34993 .81821 m .36209 .81695 L .35855 .81122 L F
0 g
.74882 .82192 m
.74883 .82332 L
s
.5794 .91863 m .58148 .92094 L .58241 .92044 L .692 .759 .904 r
F
0 g
.74258 .88007 m
.74258 .88051 L
s
.74257 .87793 m
.74258 .87921 L
s
.74228 .82155 m
.74228 .82265 L
s
.47414 .69717 m .46621 .7102 L .4799 .70152 L .683 .77 .917 r
F
.47414 .69717 m .45757 .70367 L .46621 .7102 L F
0 g
.46621 .7102 m
.47764 .71496 L
s
.127 .923 .03 r
.46289 .80987 m
.46353 .73127 L
s
.46353 .73127 m
.46371 .70832 L
s
.4713 .46207 m .47173 .45479 L .48175 .4406 L .067 0 .393 r
F
0 g
.46323 .46127 m
.47173 .45479 L
s
.57512 .91959 m .57167 .92185 L .57553 .92024 L .692 .759 .904 r
F
.57512 .91959 m .57085 .92055 L .57167 .92185 L F
.5794 .91863 m .5762 .92078 L .57709 .92118 L F
0 g
.57607 .91841 m
.57673 .91899 L
s
.2279 .58131 m .20819 .59299 L .23028 .58496 L .673 .757 .914 r
F
.2279 .58131 m .20343 .58571 L .20819 .59299 L F
.44463 .4431 m .47133 .45461 L .4813 .4405 L .654 .726 .902 r
F
.43435 .45094 m .47133 .45461 L .44463 .4431 L F
.57474 .91667 m .57059 .91835 L .57486 .91739 L .692 .759 .904 r
F
.57474 .91667 m .57036 .91691 L .57059 .91835 L F
.58334 .91693 m .58791 .91595 L .58352 .91619 L F
.57468 .91374 m .57014 .91471 L .5745 .91447 L F
.5794 .91863 m .58241 .92044 L .58313 .91983 L F
0 g
.5819 .91909 m
.58261 .91853 L
s
.4723 .5813 m .4551 .57086 L .44272 .58054 L .673 .757 .914 r
F
.4829 .57628 m .4551 .57086 L .4723 .5813 L F
0 g
.58261 .91853 m
.58305 .91785 L
s
.57569 .91772 m
.57607 .91841 L
s
.20921 .4755 m .18741 .46 L .17203 .47181 L .654 .726 .902 r
F
0 g
.16217 .48598 m
.17203 .47181 L
s
.22244 .46974 m .18741 .46 L .20921 .4755 L .654 .726 .902 r
F
.5923 .91571 m .59168 .91136 L .59195 .91356 L .752 .537 0 r
F
.59256 .91791 m .5923 .91571 L .59195 .91356 L F
0 g
.59175 .91792 m
.59227 .91583 L
s
.58791 .91595 m .5923 .91571 L .59195 .91356 L .692 .759 .904 r
F
0 0 0 r
2.5 Mabswid
.73335 .82617 Mdot
.58312 .91328 m .58656 .91103 L .58271 .91263 L .692 .759 .904 r
F
0 g
.5 Mabswid
.58262 .86089 m
.58271 .91263 L
s
.58271 .91297 m
.58272 .9146 L
s
.58312 .91328 m .58737 .91233 L .58656 .91103 L .692 .759 .904 r
F
.58781 .91962 m .59256 .91791 L .58817 .91815 L F
.5836 .91912 m .58781 .91962 L .58817 .91815 L F
.58313 .91983 m .58781 .91962 L .5836 .91912 L F
.5705 .91325 m .56577 .91495 L .57014 .91471 L F
.57468 .91374 m .5705 .91325 L .57014 .91471 L F
.60932 .56904 m .62049 .57265 L .62082 .57833 L .933 .657 .494 r
F
.60932 .56904 m .60899 .56336 L .62049 .57265 L F
0 g
.62049 .57265 m
.626 .57518 L
s
.54361 .58558 m .54667 .56743 L .53342 .58091 L .673 .757 .914 r
F
.54361 .58558 m .56194 .57444 L .54667 .56743 L F
.5794 .91863 m .57553 .92024 L .5762 .92078 L .692 .759 .904 r
F
.29816 .48015 m .30168 .45629 L .28535 .47303 L .654 .726 .902 r
F
.29816 .48015 m .3209 .46699 L .30168 .45629 L F
.49741 .69442 m .49649 .70647 L .5019 .69531 L .683 .77 .917 r
F
.49741 .69442 m .48752 .70469 L .49649 .70647 L F
.58791 .91595 m .59195 .91356 L .58768 .91452 L .692 .759 .904 r
F
.58352 .91619 m .58791 .91595 L .58768 .91452 L F
.55487 .69391 m .56043 .68088 L .56093 .68545 L .203 .117 .53 r
F
.55536 .69848 m .55487 .69391 L .56093 .68545 L F
.53886 .68913 m .55487 .69391 L .56093 .68545 L .683 .77 .917 r
F
.53264 .69413 m .55487 .69391 L .53886 .68913 L F
0 g
.54909 .69855 m
.55487 .69391 L
s
.63141 .55523 m .62077 .57248 L .63904 .5614 L .673 .757 .914 r
F
.63141 .55523 m .60933 .56324 L .62077 .57248 L F
.5705 .91325 m .56631 .91276 L .56577 .91495 L .692 .759 .904 r
F
.56651 .91495 m .5657 .91496 L .56597 .91715 L 0 0 .387 r
F
0 g
.56603 .91691 m
.56606 .91711 L
s
.56651 .91495 m .56625 .91275 L .5657 .91496 L 0 0 .387 r
F
.67714 .55714 m .67509 .56956 L .68697 .5684 L .673 .757 .914 r
F
.67764 .55417 m .68697 .5684 L .6813 .55381 L F
.67479 .55445 m .67714 .55714 L .67764 .55417 L F
.67714 .55714 m .68697 .5684 L .67764 .55417 L F
.6798 .51219 m .67992 .51137 L .68003 .53965 L 0 0 .152 r
F
.67512 .5602 m .67429 .5755 L .68736 .57422 L .673 .757 .914 r
F
.67479 .55445 m .67509 .56956 L .67714 .55714 L F
.67512 .5602 m .68736 .57422 L .68167 .55956 L F
.67546 .56588 m .67462 .58118 L .6877 .5799 L .673 .758 .914 r
F
.67546 .56588 m .6877 .5799 L .682 .56524 L F
.67865 .51344 m .6791 .54131 L .67876 .54157 L .359 .181 .499 r
F
.67603 .51409 m .6769 .54212 L .67614 .54224 L .641 .401 .54 r
F
.68198 .54136 m .69275 .54966 L .6969 .54643 L .673 .757 .914 r
F
.67446 .51383 m .67603 .51409 L .67614 .54224 L .751 .491 .538 r
F
.67865 .51344 m .67936 .51287 L .67947 .54103 L .359 .181 .499 r
F
.67746 .54393 m .67479 .55445 L .6813 .55381 L .673 .757 .914 r
F
.67705 .54286 m .6766 .54517 L .67746 .54393 L F
.6766 .54517 m .67479 .55445 L .67746 .54393 L F
.67853 .54239 m .6813 .55381 L .68613 .55252 L F
.67854 .54772 m .68441 .55417 L .67915 .54683 L F
.6813 .55381 m .69921 .56514 L .68743 .55218 L F
.68441 .55417 m .68782 .55792 L .68368 .55262 L F
.68441 .55417 m .68368 .55262 L .67915 .54683 L F
.68002 .56986 m .68002 .56988 L .68003 .57099 L .082 0 .419 r
F
.67762 .51388 m .67822 .54179 L .67773 .542 L .517 .303 .528 r
F
.67603 .51409 m .67762 .51388 L .67773 .542 L .641 .401 .54 r
F
.67603 .51409 m .67773 .542 L .6769 .54212 L F
.67936 .51287 m .6798 .51219 L .67991 .54039 L .082 0 .419 r
F
.67936 .51287 m .67991 .54039 L .67968 .54072 L F
.67992 .51137 m .67948 .51032 L .67959 .53872 L .982 .725 .331 r
F
.67805 .54187 m .68743 .55218 L .67919 .54138 L .673 .757 .914 r
F
.67773 .55424 m .67546 .56588 L .67753 .56568 L .673 .758 .914 r
F
.67892 .5573 m .67753 .56568 L .682 .56524 L F
.67479 .55445 m .67396 .56967 L .67509 .56956 L .673 .757 .914 r
F
.66834 .55405 m .67396 .56967 L .67416 .56607 L F
.67342 .55436 m .67416 .56607 L .67479 .55445 L F
.66834 .55405 m .67416 .56607 L .67342 .55436 L F
.6724 .51124 m .67244 .51205 L .67255 .54052 L .772 .616 .051 r
F
.67546 .54216 m .67479 .55445 L .67684 .54232 L .673 .757 .914 r
F
.67244 .51205 m .67282 .51275 L .67292 .54114 L .988 .719 .38 r
F
.6724 .51124 m .67252 .54014 L .6725 .53978 L .772 .616 .051 r
F
.6724 .51124 m .67255 .54052 L .67252 .54014 L F
.67293 .5102 m .6724 .51124 L .6725 .53978 L 0 0 .382 r
F
.67376 .54252 m .6681 .54755 L .67389 .54274 L .673 .757 .914 r
F
.6681 .54755 m .66238 .55263 L .66791 .54788 L F
.6681 .54755 m .66791 .54788 L .67389 .54274 L F
.67336 .54187 m .66238 .55263 L .67376 .54252 L F
.67563 .5509 m .66864 .5598 L .67512 .5602 L F
.67575 .54866 m .67499 .54985 L .67563 .5509 L F
.67541 .54309 m .66834 .55405 L .67479 .55445 L F
.67457 .54205 m .67548 .54747 L .67459 .54737 L .751 .491 .538 r
F
.67446 .51383 m .67532 .54214 L .67457 .54205 L F
.67546 .54216 m .67419 .54213 L .67541 .54309 L .673 .757 .914 r
F
.67425 .54201 m .67419 .54213 L .67546 .54216 L F
.67532 .54214 m .67548 .54747 L .67457 .54205 L .751 .491 .538 r
F
.67563 .5392 m .67425 .54201 L .67546 .54216 L .673 .757 .914 r
F
.67419 .54213 m .66834 .55405 L .67541 .54309 L F
.67499 .54985 m .66864 .5598 L .67563 .5509 L F
.67546 .54843 m .6748 .54953 L .67575 .54866 L F
.6748 .54953 m .66864 .5598 L .67499 .54985 L F
.6748 .54953 m .67499 .54985 L .67575 .54866 L F
.66864 .5598 m .67429 .5755 L .67512 .5602 L F
.67304 .55835 m .66897 .56548 L .67351 .56576 L .673 .758 .914 r
F
.66897 .56548 m .67462 .58118 L .67546 .56588 L F
.67273 .54082 m .67292 .54114 L .67294 .54646 L .988 .719 .38 r
F
.67522 .55276 m .67494 .55333 L .67617 .55287 L .673 .758 .914 r
F
.66834 .55405 m .66106 .56887 L .67396 .56967 L .673 .757 .914 r
F
.66238 .55263 m .66106 .56887 L .66834 .55405 L F
.67418 .54851 m .66265 .55838 L .66864 .5598 L F
.67244 .51205 m .67292 .54114 L .67273 .54082 L .988 .719 .38 r
F
.67347 .51335 m .67405 .54185 L .67358 .54165 L .845 .571 .523 r
F
.67282 .51275 m .67347 .51335 L .67358 .54165 L .93 .648 .486 r
F
.67282 .51275 m .67358 .54165 L .67348 .54157 L F
.67337 .54149 m .65733 .55031 L .66238 .55263 L .673 .757 .914 r
F
.67563 .5392 m .67271 .54097 L .67337 .54149 L F
.67271 .54097 m .65733 .55031 L .67337 .54149 L F
.67324 .54139 m .6736 .54697 L .67332 .54675 L .93 .648 .486 r
F
.67282 .51275 m .67348 .54157 L .67324 .54139 L F
.67337 .54149 m .67331 .54155 L .67358 .54165 L .673 .757 .914 r
F
.67389 .54274 m .67275 .54372 L .67282 .54491 L F
.67348 .54157 m .6736 .54697 L .67324 .54139 L .93 .648 .486 r
F
.67278 .53929 m .67275 .5447 L .67304 .53883 L 0 0 .382 r
F
.67377 .54711 m .67271 .54818 L .67456 .54773 L .673 .757 .914 r
F
.67271 .54818 m .66265 .55838 L .67279 .54932 L F
.67271 .54818 m .67279 .54932 L .67456 .54773 L F
.67252 .54014 m .67255 .54552 L .6725 .53978 L .772 .616 .051 r
F
.67472 .54742 m .66864 .5598 L .6758 .54786 L .673 .757 .914 r
F
.67296 .55178 m .67263 .55189 L .67355 .55223 L .673 .758 .914 r
F
.66816 .5528 m .65757 .55604 L .66265 .55838 L .673 .757 .914 r
F
.66238 .55263 m .64915 .56605 L .66106 .56887 L F
.67263 .55189 m .65407 .55862 L .67267 .55252 L .673 .758 .914 r
F
.67263 .55189 m .67267 .55252 L .67355 .55223 L F
.67263 .5469 m .6709 .54795 L .67267 .54741 L .673 .757 .914 r
F
.67255 .54552 m .67257 .55091 L .67253 .54523 L .772 .616 .051 r
F
.67447 .55428 m .6665 .56106 L .66897 .56548 L .673 .758 .914 r
F
.66726 .54902 m .66488 .55322 L .66834 .55405 L .673 .757 .914 r
F
.67031 .549 m .65757 .55604 L .66816 .5528 L F
.65733 .55031 m .64915 .56605 L .66238 .55263 L F
.65733 .55031 m .63904 .5614 L .64915 .56605 L F
.67146 .55232 m .65175 .55497 L .65407 .55862 L .673 .758 .914 r
F
.6734 .55212 m .67319 .55196 L .67306 .54655 L .93 .648 .486 r
F
.67316 .54663 m .67306 .54655 L .67292 .54114 L F
.67295 .54671 m .67263 .5469 L .67369 .54704 L .673 .757 .914 r
F
.6734 .55212 m .67306 .54655 L .67316 .54663 L .93 .648 .486 r
F
.6736 .54697 m .67369 .54704 L .67382 .54706 L .673 .757 .914 r
F
.67295 .54671 m .67369 .54704 L .6736 .54697 L F
.67459 .54737 m .67494 .55273 L .67461 .55269 L .751 .491 .538 r
F
.6763 .55057 m .67202 .55133 L .67146 .55232 L .673 .758 .914 r
F
.67401 .54822 m .66265 .55838 L .67418 .54851 L .673 .757 .914 r
F
.67202 .55133 m .65175 .55497 L .67146 .55232 L .673 .758 .914 r
F
.67257 .55091 m .67256 .55068 L .67253 .54523 L .772 .616 .051 r
F
.67255 .54552 m .67259 .55116 L .67257 .55091 L F
.67256 .54565 m .67259 .55116 L .67255 .54552 L F
.67382 .54706 m .67031 .549 L .66816 .5528 L .673 .757 .914 r
F
.67263 .54595 m .67272 .55137 L .67257 .54584 L .988 .719 .38 r
F
.67252 .5451 m .67256 .55068 L .67254 .55042 L .772 .616 .051 r
F
.6725 .53978 m .67253 .54523 L .67252 .5451 L F
.67253 .54523 m .67256 .55068 L .67252 .5451 L F
.66726 .54902 m .66238 .55263 L .66488 .55322 L .673 .757 .914 r
F
.67263 .5469 m .65374 .55294 L .65757 .55604 L F
.67358 .54165 m .67377 .54704 L .6736 .54697 L .845 .571 .523 r
F
.67596 .54488 m .67258 .54611 L .67263 .5469 L .673 .757 .914 r
F
.67331 .54155 m .66238 .55263 L .67358 .54165 L F
.67258 .54611 m .65374 .55294 L .67263 .5469 L F
.67275 .5447 m .67252 .5451 L .67254 .55042 L 0 0 .382 r
F
.67257 .55091 m .67266 .57086 L .67256 .55068 L .772 .616 .051 r
F
.67259 .55116 m .67304 .57155 L .67266 .57086 L .988 .719 .38 r
F
.67254 .55042 m .67266 .57086 L .67261 .57004 L .772 .616 .051 r
F
.67256 .55068 m .67266 .57086 L .67254 .55042 L F
.67257 .55091 m .67259 .55116 L .67266 .57086 L F
.67282 .54491 m .66726 .54902 L .66834 .55405 L .673 .757 .914 r
F
.6709 .54795 m .65757 .55604 L .67031 .549 L F
.67202 .55133 m .65111 .55102 L .65175 .55497 L .673 .758 .914 r
F
.67332 .54675 m .6736 .54697 L .67362 .55229 L .93 .648 .486 r
F
.67617 .55287 m .67304 .55835 L .67546 .56588 L .673 .758 .914 r
F
.6734 .55212 m .67362 .55229 L .67369 .57215 L .93 .648 .486 r
F
.67332 .54675 m .67362 .55229 L .6734 .55212 L F
.67298 .55733 m .67304 .55835 L .67561 .55385 L .673 .758 .914 r
F
.67304 .55835 m .67351 .56576 L .67546 .56588 L F
.67362 .55229 m .67468 .57263 L .67369 .57215 L .845 .571 .523 r
F
.6736 .54697 m .67383 .55237 L .67362 .55229 L F
.67383 .55237 m .67468 .57263 L .67362 .55229 L F
.67282 .51275 m .67324 .54139 L .67292 .54114 L .93 .648 .486 r
F
.67238 .54117 m .65351 .54722 L .65733 .55031 L .673 .757 .914 r
F
.67563 .5392 m .67135 .54076 L .67238 .54117 L F
.67135 .54076 m .65351 .54722 L .67238 .54117 L F
.67347 .51335 m .67446 .51383 L .67457 .54205 L .845 .571 .523 r
F
.67441 .54199 m .67457 .54205 L .67459 .54737 L F
.67347 .51335 m .67457 .54205 L .67441 .54199 L F
.67275 .54372 m .66238 .55263 L .67282 .54491 L .673 .757 .914 r
F
.67199 .54632 m .65142 .54929 L .65374 .55294 L F
.67416 .5472 m .67377 .54704 L .67358 .54165 L .845 .571 .523 r
F
.67273 .54082 m .67294 .54646 L .67278 .54619 L .988 .719 .38 r
F
.67596 .54488 m .67074 .54582 L .67199 .54632 L .673 .757 .914 r
F
.67074 .54582 m .65142 .54929 L .67199 .54632 L F
.67358 .54165 m .67336 .54187 L .67419 .54213 L F
.67336 .54187 m .67376 .54252 L .67419 .54213 L F
.67419 .54213 m .67376 .54252 L .67389 .54274 L F
.67405 .54185 m .67416 .5472 L .67358 .54165 L .845 .571 .523 r
F
.67494 .55333 m .67298 .55733 L .67561 .55385 L .673 .758 .914 r
F
.67417 .55272 m .67369 .55298 L .67378 .55312 L F
.67377 .54704 m .67468 .57263 L .6736 .54697 L .845 .571 .523 r
F
.67272 .55137 m .67267 .55129 L .67257 .54584 L .988 .719 .38 r
F
.67257 .54584 m .67267 .55129 L .67259 .55116 L F
.67278 .54619 m .67284 .55157 L .67263 .54595 L F
.67298 .55733 m .66897 .56548 L .67304 .55835 L .673 .758 .914 r
F
.67284 .55157 m .67304 .57155 L .67272 .55137 L .988 .719 .38 r
F
.67284 .55157 m .67272 .55137 L .67263 .54595 L F
.67244 .51205 m .67273 .54082 L .67255 .54052 L F
.67135 .54076 m .65121 .54359 L .65351 .54722 L .673 .757 .914 r
F
.67406 .50942 m .67293 .5102 L .67304 .53883 L .402 .214 .508 r
F
.66706 .54648 m .65077 .54534 L .65142 .54929 L .673 .757 .914 r
F
.67416 .5472 m .67427 .55255 L .67377 .54704 L .845 .571 .523 r
F
.67427 .55255 m .67396 .55243 L .67377 .54704 L F
.67129 .55066 m .66537 .54897 L .66964 .55069 L .673 .758 .914 r
F
.67319 .55196 m .6731 .55188 L .67294 .54646 L .93 .648 .486 r
F
.6763 .55057 m .6723 .54998 L .67129 .55066 L .673 .758 .914 r
F
.6723 .54998 m .66537 .54897 L .67129 .55066 L F
.67046 .54587 m .65646 .54524 L .66706 .54648 L .673 .757 .914 r
F
.67184 .54496 m .65646 .54524 L .67046 .54587 L F
.67131 .53998 m .65057 .53966 L .65121 .54359 L F
.67563 .5392 m .67239 .53926 L .67131 .53998 L F
.67239 .53926 m .65057 .53966 L .67131 .53998 L F
.67563 .5392 m .67337 .54149 L .67419 .54213 L F
.67417 .53808 m .67354 .54383 L .67419 .5434 L .402 .214 .508 r
F
.67347 .51335 m .67441 .54199 L .67405 .54185 L .845 .571 .523 r
F
.67406 .50942 m .67362 .53845 L .67417 .53808 L .402 .214 .508 r
F
.67348 .54157 m .67358 .54165 L .6736 .54697 L .93 .648 .486 r
F
.67362 .53845 m .67354 .54383 L .67417 .53808 L .402 .214 .508 r
F
.67105 .54497 m .65185 .54136 L .65077 .54534 L .673 .757 .914 r
F
.67332 .54675 m .67316 .54663 L .67292 .54114 L .93 .648 .486 r
F
.67292 .54114 m .67306 .54655 L .67294 .54646 L F
.67024 .5393 m .65163 .5357 L .65057 .53966 L .673 .757 .914 r
F
.67293 .5102 m .6725 .53978 L .67278 .53929 L 0 0 .382 r
F
.67563 .5392 m .67218 .5387 L .67024 .5393 L .673 .757 .914 r
F
.67218 .5387 m .65163 .5357 L .67024 .5393 L F
.67517 .50908 m .67406 .50942 L .67417 .53808 L .568 .343 .534 r
F
.67434 .53803 m .67417 .53808 L .67419 .5434 L F
.67517 .50908 m .67417 .53808 L .67434 .53803 L F
.67456 .54773 m .67401 .54822 L .67418 .54851 L .673 .757 .914 r
F
.67416 .5472 m .67459 .54737 L .67468 .57263 L .845 .571 .523 r
F
.6763 .55057 m .67376 .54902 L .67307 .54947 L .673 .758 .914 r
F
.67405 .54185 m .67459 .54737 L .67416 .5472 L .845 .571 .523 r
F
.67441 .54199 m .67459 .54737 L .67405 .54185 L F
.67427 .55255 m .67468 .57263 L .67396 .55243 L F
.67596 .54488 m .67295 .54671 L .67382 .54706 L .673 .757 .914 r
F
.6763 .55057 m .67296 .55178 L .67355 .55223 L .673 .758 .914 r
F
.67 .54021 m .65121 .54359 L .67135 .54076 L .673 .757 .914 r
F
.67252 .54014 m .67256 .54565 L .67255 .54552 L .772 .616 .051 r
F
.67255 .54052 m .67263 .54595 L .67257 .54584 L .988 .719 .38 r
F
.67278 .54619 m .67263 .54595 L .67255 .54052 L F
.67248 .54438 m .65456 .53762 L .65185 .54136 L .673 .757 .914 r
F
.67252 .54014 m .67257 .54584 L .67256 .54565 L .772 .616 .051 r
F
.67461 .55269 m .67625 .57289 L .67468 .57263 L .751 .491 .538 r
F
.67704 .54766 m .67512 .5602 L .68167 .55956 L .673 .757 .914 r
F
.67494 .55273 m .67625 .57289 L .67461 .55269 L .751 .491 .538 r
F
.67243 .54369 m .65456 .53762 L .67248 .54438 L .673 .757 .914 r
F
.67278 .54619 m .67294 .54646 L .67296 .55178 L .988 .719 .38 r
F
.67278 .54619 m .67296 .55178 L .67284 .55157 L F
.67272 .5501 m .67289 .5498 L .67297 .54432 L 0 0 .382 r
F
.67263 .5469 m .67267 .54741 L .67382 .54706 L .673 .757 .914 r
F
.67306 .54655 m .67319 .55196 L .67294 .54646 L .93 .648 .486 r
F
.67255 .54552 m .67253 .54523 L .6725 .53978 L .772 .616 .051 r
F
.67563 .5392 m .67131 .53998 L .67135 .54076 L .673 .757 .914 r
F
.67273 .54082 m .67278 .54619 L .67255 .54052 L .988 .719 .38 r
F
.67278 .53929 m .67252 .5451 L .67275 .5447 L 0 0 .382 r
F
.67218 .5387 m .65434 .53197 L .65163 .5357 L .673 .757 .914 r
F
.67563 .5392 m .67321 .53838 L .67218 .5387 L F
.67321 .53838 m .65434 .53197 L .67218 .5387 L F
.67528 .53774 m .67466 .54326 L .6753 .54306 L .568 .343 .534 r
F
.67446 .51383 m .67614 .54224 L .67532 .54214 L .751 .491 .538 r
F
.67517 .50908 m .67474 .53791 L .67528 .53774 L .568 .343 .534 r
F
.67474 .53791 m .67466 .54326 L .67528 .53774 L F
.67171 .54344 m .65874 .53437 L .65456 .53762 L .673 .757 .914 r
F
.67596 .54488 m .67331 .54327 L .67171 .54344 L F
.67331 .54327 m .65874 .53437 L .67171 .54344 L F
.67627 .50899 m .67517 .50908 L .6753 .54306 L .66 .416 .54 r
F
.67532 .54214 m .67616 .54755 L .67548 .54747 L .751 .491 .538 r
F
.6763 .55057 m .67355 .55223 L .67417 .55272 L .673 .758 .914 r
F
.67578 .54814 m .67512 .5602 L .67702 .54762 L .673 .757 .914 r
F
.67494 .55333 m .67561 .55385 L .67617 .55287 L .673 .758 .914 r
F
.6758 .54786 m .67546 .54843 L .67575 .54866 L .673 .757 .914 r
F
.67596 .54488 m .67472 .54742 L .6758 .54786 L F
.67548 .54747 m .67625 .57289 L .67459 .54737 L .751 .491 .538 r
F
.67576 .54301 m .6753 .54306 L .67539 .56788 L .66 .416 .54 r
F
.67627 .50899 m .67545 .53772 L .67584 .53768 L F
.67474 .53791 m .67419 .5434 L .67466 .54326 L .568 .343 .534 r
F
.67517 .50908 m .67434 .53803 L .67474 .53791 L F
.67434 .53803 m .67419 .5434 L .67474 .53791 L F
.67321 .53838 m .65849 .52874 L .65434 .53197 L .673 .757 .914 r
F
.67563 .5392 m .67392 .53816 L .67321 .53838 L F
.67293 .5102 m .67278 .53929 L .67304 .53883 L 0 0 .382 r
F
.67392 .53816 m .65849 .52874 L .67321 .53838 L .673 .757 .914 r
F
.67406 .50942 m .67304 .53883 L .67362 .53845 L .402 .214 .508 r
F
.67507 .53776 m .67646 .52394 L .66994 .52458 L .673 .757 .914 r
F
.67563 .5392 m .67571 .53769 L .67507 .53776 L F
.67571 .53769 m .67646 .52394 L .67507 .53776 L F
.67563 .5392 m .67546 .54216 L .67684 .54232 L F
.67584 .53768 m .6753 .54306 L .67576 .54301 L .66 .416 .54 r
F
.67545 .53772 m .6753 .54306 L .67584 .53768 L F
.67359 .54891 m .66442 .53752 L .65907 .54005 L .673 .758 .914 r
F
.6763 .55057 m .67453 .54862 L .67359 .54891 L F
.6709 .54795 m .67031 .549 L .67382 .54706 L .673 .757 .914 r
F
.67256 .54565 m .67257 .54584 L .67259 .55116 L .772 .616 .051 r
F
.67332 .54675 m .6734 .55212 L .67316 .54663 L .93 .648 .486 r
F
.67453 .54862 m .66442 .53752 L .67359 .54891 L .673 .758 .914 r
F
.67532 .54838 m .67428 .56822 L .67539 .56788 L .568 .343 .534 r
F
.6753 .54306 m .67508 .54845 L .67532 .54838 L F
.67508 .54845 m .67428 .56822 L .67532 .54838 L F
.6763 .55057 m .67378 .55312 L .67447 .55428 L .673 .758 .914 r
F
.67596 .54488 m .67377 .54711 L .67456 .54773 L .673 .757 .914 r
F
.67252 .54014 m .67255 .54052 L .67257 .54584 L .772 .616 .051 r
F
.67278 .53929 m .6725 .53978 L .67252 .5451 L 0 0 .382 r
F
.67283 .54382 m .67243 .54369 L .67245 .54394 L .673 .757 .914 r
F
.67283 .54382 m .67245 .54394 L .67248 .54438 L F
.67596 .54488 m .6715 .54423 L .67105 .54497 L F
.6715 .54423 m .66978 .54398 L .6705 .54454 L F
.6715 .54423 m .6705 .54454 L .67105 .54497 L F
.67345 .54922 m .67397 .54888 L .67419 .5434 L .402 .214 .508 r
F
.67596 .54488 m .67184 .54496 L .67046 .54587 L .673 .757 .914 r
F
.67362 .53845 m .67308 .54947 L .67345 .54922 L .402 .214 .508 r
F
.67131 .53998 m .67 .54021 L .6706 .54045 L .673 .757 .914 r
F
.67131 .53998 m .6706 .54045 L .67135 .54076 L F
.67275 .5447 m .67272 .5501 L .67297 .54432 L 0 0 .382 r
F
.67304 .53883 m .67289 .5498 L .67308 .54947 L F
.67324 .54139 m .67332 .54675 L .67292 .54114 L .93 .648 .486 r
F
.67275 .5447 m .67297 .54432 L .67304 .53883 L 0 0 .382 r
F
.67387 .54361 m .66409 .53183 L .65874 .53437 L .673 .757 .914 r
F
.67596 .54488 m .67445 .54323 L .67387 .54361 L F
.67362 .53845 m .67306 .54415 L .67335 .54396 L .402 .214 .508 r
F
.67445 .54323 m .66409 .53183 L .67387 .54361 L .673 .757 .914 r
F
.67362 .53845 m .67304 .53883 L .67306 .54415 L .402 .214 .508 r
F
.67335 .54396 m .67306 .54415 L .67308 .54947 L F
.67453 .54862 m .67058 .53587 L .66442 .53752 L .673 .758 .914 r
F
.6763 .55057 m .67543 .54834 L .67453 .54862 L F
.67596 .54488 m .67283 .54382 L .67248 .54438 L .673 .757 .914 r
F
.67354 .54383 m .67345 .54922 L .67419 .5434 L .402 .214 .508 r
F
.67419 .5434 m .67397 .54888 L .67421 .54872 L F
.67543 .54834 m .67058 .53587 L .67453 .54862 L .673 .758 .914 r
F
.67466 .54326 m .67458 .54861 L .6753 .54306 L .568 .343 .534 r
F
.67458 .54861 m .67428 .56822 L .67508 .54845 L F
.67458 .54861 m .67508 .54845 L .6753 .54306 L F
.67466 .54326 m .67419 .5434 L .67428 .56822 L F
.66978 .54398 m .65185 .54136 L .67105 .54497 L .673 .757 .914 r
F
.67307 .54947 m .65907 .54005 L .6549 .5433 L .673 .758 .914 r
F
.67275 .5447 m .67254 .55042 L .67272 .5501 L 0 0 .382 r
F
.67376 .54902 m .65907 .54005 L .67307 .54947 L .673 .758 .914 r
F
.67294 .54646 m .6731 .55188 L .67296 .55178 L .93 .648 .486 r
F
.6763 .55057 m .67286 .54962 L .6723 .54998 L .673 .758 .914 r
F
.6763 .55057 m .67242 .55064 L .67214 .55113 L F
.6763 .55057 m .67214 .55113 L .67233 .55128 L F
.67319 .55196 m .67369 .57215 L .6731 .55188 L .93 .648 .486 r
F
.67296 .55178 m .67369 .57215 L .67304 .57155 L F
.67355 .55223 m .67329 .55232 L .67332 .55237 L .673 .758 .914 r
F
.6734 .55212 m .67369 .57215 L .67319 .55196 L .93 .648 .486 r
F
.67345 .54922 m .67315 .56901 L .67397 .54888 L .402 .214 .508 r
F
.67421 .54872 m .67315 .56901 L .67428 .56822 L F
.67397 .54888 m .67315 .56901 L .67421 .54872 L F
.65646 .54524 m .65077 .54534 L .66706 .54648 L .673 .757 .914 r
F
.67532 .54214 m .67614 .54224 L .67616 .54755 L .751 .491 .538 r
F
.67548 .54747 m .67616 .54755 L .67625 .57289 L F
.6723 .54998 m .65408 .54443 L .66537 .54897 L .673 .758 .914 r
F
.67286 .54962 m .65408 .54443 L .6723 .54998 L F
.6731 .55188 m .67369 .57215 L .67296 .55178 L .93 .648 .486 r
F
.67345 .54922 m .67308 .54947 L .67315 .56901 L .402 .214 .508 r
F
.67141 .54922 m .6549 .5433 L .65408 .54443 L .673 .758 .914 r
F
.6763 .55057 m .67118 .54883 L .67141 .54922 L F
.67118 .54883 m .6549 .5433 L .67141 .54922 L F
.66537 .54897 m .65408 .54443 L .65218 .54704 L F
.66964 .55069 m .65218 .54704 L .65111 .55102 L F
.66537 .54897 m .65218 .54704 L .66964 .55069 L F
.67233 .55128 m .67214 .55113 L .67202 .55133 L F
.67242 .55064 m .65111 .55102 L .67202 .55133 L F
.67267 .55129 m .67304 .57155 L .67259 .55116 L .988 .719 .38 r
F
.67272 .5501 m .67261 .57004 L .67289 .5498 L 0 0 .382 r
F
.67272 .5501 m .67254 .55042 L .67261 .57004 L F
.67272 .55137 m .67304 .57155 L .67267 .55129 L .988 .719 .38 r
F
.67332 .55237 m .65407 .55862 L .6579 .56172 L .673 .758 .914 r
F
.67329 .55232 m .65407 .55862 L .67332 .55237 L F
.66265 .55838 m .66132 .5747 L .66864 .5598 L .673 .757 .914 r
F
.67378 .55312 m .6579 .56172 L .66298 .56406 L .673 .758 .914 r
F
.67369 .55298 m .6579 .56172 L .67378 .55312 L F
.67355 .55223 m .6579 .56172 L .67417 .55272 L F
.67284 .55157 m .67296 .55178 L .67304 .57155 L .988 .719 .38 r
F
.67308 .54947 m .67261 .57004 L .67315 .56901 L 0 0 .382 r
F
.67289 .5498 m .67261 .57004 L .67308 .54947 L F
.6665 .56106 m .66298 .56406 L .66459 .56444 L .673 .758 .914 r
F
.6665 .56106 m .66459 .56444 L .66897 .56548 L F
.67378 .55312 m .66298 .56406 L .67447 .55428 L F
.6763 .55057 m .67522 .55276 L .67617 .55287 L F
.67702 .54762 m .67702 .54766 L .67704 .54766 L .673 .757 .914 r
F
.67702 .54766 m .67512 .5602 L .67704 .54766 L F
.67673 .5431 m .67479 .55445 L .67705 .54286 L F
.67683 .54238 m .67479 .55445 L .67685 .54237 L F
.67596 .55679 m .67546 .56588 L .67773 .55424 L .673 .758 .914 r
F
.67616 .54755 m .67785 .57268 L .67625 .57289 L .641 .401 .54 r
F
.67614 .54224 m .67643 .54751 L .67616 .54755 L F
.67581 .54761 m .67578 .54814 L .67695 .54744 L .673 .757 .914 r
F
.67714 .55273 m .67596 .55679 L .67773 .55424 L .673 .758 .914 r
F
.67673 .55279 m .67651 .55282 L .67616 .54755 L .641 .401 .54 r
F
.67695 .54744 m .67578 .54814 L .67702 .54762 L .673 .757 .914 r
F
.67685 .54237 m .67673 .5431 L .67705 .54286 L F
.67684 .54232 m .67683 .54238 L .67685 .54237 L F
.6769 .54212 m .67706 .54742 L .67614 .54224 L .641 .401 .54 r
F
.68743 .55218 m .69921 .56514 L .70985 .56011 L .673 .757 .914 r
F
.68782 .55792 m .71036 .56589 L .69317 .55539 L F
.68097 .55215 m .69351 .56107 L .69768 .55783 L .673 .758 .914 r
F
.6772 .54808 m .68167 .55956 L .67819 .54733 L .673 .757 .914 r
F
.6788 .5522 m .67959 .57167 L .67888 .57224 L .359 .181 .499 r
F
.67878 .54688 m .67895 .55209 L .6788 .5522 L F
.67895 .55209 m .67959 .57167 L .6788 .5522 L F
.67835 .54265 m .6813 .55381 L .67853 .54239 L .673 .757 .914 r
F
.67973 .54616 m .67951 .54705 L .68148 .54676 L F
.67811 .54194 m .67814 .54204 L .67818 .54201 L F
.67677 .54214 m .6813 .55381 L .67811 .54194 L F
.68159 .54571 m .69735 .55215 L .70007 .54841 L F
.67834 .54707 m .67809 .54717 L .67773 .542 L .517 .303 .528 r
F
.67822 .54179 m .67878 .54688 L .67834 .54707 L F
.6791 .54131 m .67947 .54103 L .67949 .54635 L .359 .181 .499 r
F
.67912 .55061 m .68167 .55956 L .67944 .5487 L .673 .757 .914 r
F
.67762 .51388 m .67865 .51344 L .67876 .54157 L .517 .303 .528 r
F
.67762 .51388 m .67876 .54157 L .67822 .54179 L F
.67936 .51287 m .67968 .54072 L .67947 .54103 L .082 0 .419 r
F
.67865 .51344 m .67947 .54103 L .6791 .54131 L .359 .181 .499 r
F
.6816 .54008 m .6969 .54643 L .69961 .54271 L .673 .757 .914 r
F
.67563 .5392 m .68505 .54241 L .6816 .54008 L F
.68505 .54241 m .6969 .54643 L .6816 .54008 L F
.67813 .55271 m .682 .56524 L .6782 .55266 L .673 .758 .914 r
F
.67898 .54673 m .67951 .54705 L .67973 .54616 L .673 .757 .914 r
F
.67918 .54658 m .67949 .54635 L .67951 .55166 L .359 .181 .499 r
F
.67719 .55288 m .682 .56524 L .67807 .55251 L .673 .758 .914 r
F
.67927 .55185 m .67951 .55166 L .67959 .57167 L .359 .181 .499 r
F
.67918 .54658 m .67951 .55166 L .67927 .55185 L F
.68167 .55956 m .68736 .57422 L .69967 .57095 L .673 .757 .914 r
F
.67852 .55309 m .682 .56524 L .68658 .56402 L .673 .758 .914 r
F
.6782 .55266 m .67839 .55328 L .67852 .55309 L F
.67839 .55328 m .682 .56524 L .67852 .55309 L F
.67853 .54239 m .68613 .55252 L .68438 .54882 L .673 .757 .914 r
F
.6798 .51219 m .68003 .53965 L .67997 .54004 L 0 0 .152 r
F
.6798 .51219 m .67997 .54004 L .67991 .54039 L F
.68018 .53912 m .69961 .54271 L .70068 .53875 L .673 .757 .914 r
F
.67563 .5392 m .6816 .54008 L .68018 .53912 L F
.6816 .54008 m .69961 .54271 L .68018 .53912 L F
.67948 .51032 m .67843 .5095 L .67854 .53801 L .91 .629 .497 r
F
.67818 .54201 m .67835 .54265 L .67853 .54239 L .673 .757 .914 r
F
.67822 .54179 m .67876 .54157 L .67878 .54688 L .517 .303 .528 r
F
.67814 .54204 m .6813 .55381 L .67818 .54201 L .673 .757 .914 r
F
.67596 .54488 m .67973 .54616 L .68038 .54567 L F
.68031 .54552 m .68038 .54567 L .68054 .54555 L F
.67918 .54658 m .6789 .54679 L .67876 .54157 L .359 .181 .499 r
F
.67596 .54488 m .68038 .54567 L .68031 .54552 L .673 .757 .914 r
F
.67974 .54598 m .6798 .55125 L .67964 .54614 L .082 0 .419 r
F
.6798 .54444 m .67963 .54936 L .67978 .54967 L .982 .725 .331 r
F
.67968 .54072 m .67991 .54039 L .67993 .54571 L .082 0 .419 r
F
.67982 .5392 m .67972 .54428 L .6798 .54444 L .982 .725 .331 r
F
.67972 .54428 m .67963 .54936 L .6798 .54444 L F
.67819 .54733 m .67912 .55061 L .67944 .5487 L .673 .757 .914 r
F
.67834 .54707 m .67878 .54688 L .6788 .5522 L .517 .303 .528 r
F
.67845 .55235 m .6788 .5522 L .67888 .57224 L F
.67834 .54707 m .6788 .5522 L .67845 .55235 L F
.68743 .55218 m .70985 .56011 L .69275 .54966 L .673 .757 .914 r
F
.68148 .54676 m .69317 .55539 L .69735 .55215 L F
.68438 .54882 m .68613 .55252 L .68743 .55218 L F
.67969 .54716 m .68782 .55792 L .69317 .55539 L F
.67915 .54683 m .67964 .54746 L .67969 .54716 L F
.67964 .54746 m .68782 .55792 L .67969 .54716 L F
.67993 .54571 m .67999 .55077 L .67995 .55103 L 0 0 .152 r
F
.67991 .54039 m .67995 .54558 L .67993 .54571 L F
.67995 .54558 m .67999 .55077 L .67993 .54571 L F
.68105 .55126 m .69768 .55783 L .7004 .55409 L .673 .758 .914 r
F
.67918 .54658 m .67927 .55185 L .6789 .54679 L .359 .181 .499 r
F
.67888 .55214 m .67931 .5524 L .67952 .55166 L .673 .758 .914 r
F
.67927 .55185 m .67959 .57167 L .67905 .55202 L .359 .181 .499 r
F
.67927 .55185 m .67905 .55202 L .6789 .54679 L F
.6813 .55381 m .68697 .5684 L .69921 .56514 L .673 .757 .914 r
F
.67944 .5487 m .68167 .55956 L .68782 .55792 L F
.68021 .55114 m .67984 .55177 L .68105 .55126 L .673 .758 .914 r
F
.6763 .55057 m .67952 .55166 L .68021 .55114 L F
.67952 .55166 m .67984 .55177 L .68021 .55114 L F
.67984 .55177 m .69768 .55783 L .68105 .55126 L F
.67876 .54157 m .6789 .54679 L .67878 .54688 L .359 .181 .499 r
F
.68074 .5448 m .70007 .54841 L .70115 .54443 L .673 .757 .914 r
F
.67974 .54598 m .67964 .54614 L .67947 .54103 L .082 0 .419 r
F
.67968 .54072 m .67974 .54598 L .67947 .54103 L F
.67563 .5392 m .67971 .5417 L .68198 .54136 L .673 .757 .914 r
F
.67982 .5392 m .67959 .53872 L .67961 .54404 L .982 .725 .331 r
F
.6798 .55125 m .67966 .55144 L .67947 .54103 L .082 0 .419 r
F
.67972 .54428 m .67961 .54404 L .67963 .54936 L .982 .725 .331 r
F
.67968 .54072 m .67995 .55103 L .6798 .55124 L .082 0 .419 r
F
.67982 .5392 m .67961 .54404 L .67972 .54428 L .982 .725 .331 r
F
.67998 .54481 m .68222 .5458 L .68074 .5448 L .673 .757 .914 r
F
.67596 .54488 m .68031 .54552 L .67998 .54481 L F
.68031 .54552 m .68222 .5458 L .67998 .54481 L F
.67971 .5417 m .69275 .54966 L .68198 .54136 L F
.68222 .5458 m .70007 .54841 L .68074 .5448 L F
.67908 .53838 m .67854 .53801 L .67856 .54333 L .91 .629 .497 r
F
.67845 .55235 m .67813 .55248 L .67773 .542 L .517 .303 .528 r
F
.6763 .55057 m .67888 .55214 L .67952 .55166 L .673 .758 .914 r
F
.68129 .55048 m .7004 .55409 L .70148 .55011 L F
.6763 .55057 m .68284 .55152 L .68129 .55048 L F
.67951 .54705 m .69317 .55539 L .68148 .54676 L .673 .757 .914 r
F
.68284 .55152 m .7004 .55409 L .68129 .55048 L .673 .758 .914 r
F
.679 .54363 m .67856 .54333 L .67858 .54865 L .91 .629 .497 r
F
.69275 .54966 m .71816 .55366 L .6969 .54643 L .673 .757 .914 r
F
.68035 .54984 m .70148 .55011 L .70085 .54616 L .673 .758 .914 r
F
.67919 .54138 m .68357 .54712 L .68153 .54281 L .673 .757 .914 r
F
.68033 .5433 m .68115 .54395 L .68203 .54268 L F
.68 .54529 m .67997 .54547 L .67991 .54039 L 0 0 .152 r
F
.67968 .54072 m .67993 .54571 L .67982 .54588 L .082 0 .419 r
F
.67997 .54004 m .68005 .54497 L .68 .54529 L 0 0 .152 r
F
.67773 .55424 m .67753 .56568 L .67892 .5573 L .673 .758 .914 r
F
.67845 .55235 m .67888 .57224 L .67813 .55248 L .517 .303 .528 r
F
.67777 .55263 m .67888 .57224 L .67785 .57268 L F
.67905 .54677 m .67854 .54772 L .67915 .54683 L .673 .757 .914 r
F
.6769 .54212 m .67773 .542 L .67777 .55263 L .641 .401 .54 r
F
.67714 .55273 m .67719 .55288 L .67777 .55263 L .673 .758 .914 r
F
.67723 .55272 m .67777 .55263 L .67785 .57268 L .641 .401 .54 r
F
.67812 .54726 m .6772 .54808 L .67819 .54733 L .673 .757 .914 r
F
.67706 .54742 m .67643 .54751 L .67614 .54224 L .641 .401 .54 r
F
.67596 .54488 m .67695 .54744 L .67812 .54726 L .673 .757 .914 r
F
.67695 .54744 m .6772 .54808 L .67812 .54726 L F
.67706 .54742 m .67777 .55263 L .67723 .55272 L .641 .401 .54 r
F
.6769 .54212 m .67734 .54738 L .67706 .54742 L F
.67734 .54738 m .67777 .55263 L .67706 .54742 L F
.67706 .54742 m .67723 .55272 L .67643 .54751 L F
.6763 .55057 m .67714 .55273 L .67807 .55251 L .673 .758 .914 r
F
.67714 .55273 m .67777 .55263 L .67807 .55251 L F
.67596 .54488 m .67806 .54719 L .67905 .54677 L .673 .757 .914 r
F
.67806 .54719 m .67854 .54772 L .67905 .54677 L F
.67775 .54732 m .67813 .55248 L .67777 .55263 L .517 .303 .528 r
F
.67773 .542 m .67793 .54724 L .67775 .54732 L F
.67793 .54724 m .67813 .55248 L .67775 .54732 L F
.67807 .55251 m .67813 .55271 L .6782 .55266 L .673 .758 .914 r
F
.67813 .55248 m .67888 .57224 L .67777 .55263 L .517 .303 .528 r
F
.6789 .55216 m .67855 .55305 L .67909 .55227 L .673 .758 .914 r
F
.67723 .55272 m .67673 .55279 L .67643 .54751 L .641 .401 .54 r
F
.6763 .55057 m .67807 .55251 L .6789 .55216 L .673 .758 .914 r
F
.67807 .55251 m .67855 .55305 L .6789 .55216 L F
.67856 .54333 m .67835 .54858 L .67858 .54865 L .81 .54 .531 r
F
.67997 .54004 m .68003 .53965 L .68005 .54497 L 0 0 .152 r
F
.68003 .53965 m .67998 .54481 L .68005 .54497 L .982 .725 .331 r
F
.67951 .5436 m .68024 .54381 L .68033 .5433 L .673 .757 .914 r
F
.68019 .54412 m .68115 .54395 L .68033 .5433 L F
.67947 .54103 m .67957 .54624 L .67949 .54635 L .082 0 .419 r
F
.67959 .53872 m .67926 .54911 L .67963 .54936 L .91 .629 .497 r
F
.6791 .54131 m .67918 .54658 L .67876 .54157 L .359 .181 .499 r
F
.679 .54363 m .67926 .5438 L .67959 .53872 L .91 .629 .497 r
F
.67982 .5392 m .6798 .54444 L .68003 .53965 L .982 .725 .331 r
F
.67982 .54588 m .67993 .54571 L .67995 .55103 L .082 0 .419 r
F
.67952 .55166 m .67931 .5524 L .68096 .55216 L .673 .758 .914 r
F
.6798 .55124 m .67995 .55103 L .68002 .56988 L .082 0 .419 r
F
.68167 .55956 m .69967 .57095 L .68782 .55792 L .673 .757 .914 r
F
.68179 .55392 m .68816 .5636 L .69351 .56107 L .673 .758 .914 r
F
.68 .54529 m .68005 .54497 L .68007 .55029 L 0 0 .152 r
F
.68003 .55054 m .68007 .55029 L .68015 .57018 L F
.68 .54529 m .68007 .55029 L .68003 .55054 L F
.67969 .55264 m .6838 .55816 L .68179 .55392 L .673 .758 .914 r
F
.67909 .55227 m .67963 .55295 L .67969 .55264 L F
.67963 .55295 m .6838 .55816 L .67969 .55264 L F
.6838 .55816 m .68816 .5636 L .68179 .55392 L F
.6798 .54444 m .67978 .54967 L .67998 .54481 L .982 .725 .331 r
F
.6798 .55125 m .68003 .57099 L .67966 .55144 L .082 0 .419 r
F
.67978 .54967 m .67971 .56913 L .67992 .54996 L .982 .725 .331 r
F
.67978 .54967 m .67992 .54996 L .67998 .54481 L F
.67997 .54004 m .68 .54529 L .67991 .54039 L 0 0 .152 r
F
.68003 .55054 m .67999 .55077 L .67991 .54039 L F
.6798 .54444 m .67998 .54481 L .68003 .53965 L .982 .725 .331 r
F
.67998 .53842 m .70068 .53875 L .70005 .53482 L .673 .757 .914 r
F
.67563 .5392 m .6823 .53908 L .67998 .53842 L F
.6823 .53908 m .70068 .53875 L .67998 .53842 L F
.67563 .5392 m .67805 .54187 L .67919 .54138 L F
.67854 .53801 m .67794 .54315 L .67856 .54333 L .81 .54 .531 r
F
.67843 .5095 m .67801 .53786 L .67854 .53801 L F
.67801 .53786 m .67794 .54315 L .67854 .53801 L F
.67948 .51032 m .67854 .53801 L .67908 .53838 L .91 .629 .497 r
F
.67948 .51032 m .67908 .53838 L .67959 .53872 L F
.67992 .51137 m .67959 .53872 L .67982 .5392 L .982 .725 .331 r
F
.67992 .51137 m .67982 .5392 L .68003 .53965 L F
.6779 .53783 m .69775 .53118 L .69394 .52809 L .673 .757 .914 r
F
.67563 .5392 m .67875 .53807 L .6779 .53783 L F
.67875 .53807 m .69775 .53118 L .6779 .53783 L F
.67843 .5095 m .67735 .50912 L .67746 .5377 L .81 .54 .531 r
F
.67938 .53784 m .70005 .53482 L .69775 .53118 L .673 .757 .914 r
F
.67563 .5392 m .6821 .53804 L .67938 .53784 L F
.6821 .53804 m .70005 .53482 L .67938 .53784 L F
.67801 .53786 m .67746 .5377 L .67748 .54302 L .81 .54 .531 r
F
.67596 .54488 m .67854 .54332 L .67804 .54318 L .673 .757 .914 r
F
.6805 .54324 m .6982 .53682 L .67887 .54312 L F
.67968 .54072 m .67974 .54598 L .67974 .54598 L .082 0 .419 r
F
.67596 .54488 m .68056 .5448 L .68062 .54472 L .673 .757 .914 r
F
.67983 .54419 m .68062 .54472 L .68115 .54395 L F
.6791 .54131 m .67949 .54635 L .67918 .54658 L .359 .181 .499 r
F
.67596 .54488 m .68062 .54472 L .67983 .54419 L .673 .757 .914 r
F
.67893 .54888 m .67926 .54911 L .67943 .54391 L .91 .629 .497 r
F
.67926 .5438 m .67943 .54391 L .67959 .53872 L F
.67893 .54888 m .67943 .54391 L .67926 .5438 L F
.67794 .54315 m .67748 .54302 L .6775 .54834 L .81 .54 .531 r
F
.68115 .54395 m .70115 .54443 L .70051 .54048 L .673 .757 .914 r
F
.68056 .5448 m .70115 .54443 L .68115 .54395 L F
.68316 .54641 m .69854 .54251 L .69471 .5394 L .673 .758 .914 r
F
.68 .54529 m .68003 .55054 L .67997 .54547 L 0 0 .152 r
F
.67992 .54996 m .67998 .55009 L .68005 .54497 L .982 .725 .331 r
F
.6763 .55057 m .68161 .54864 L .68316 .54641 L .673 .758 .914 r
F
.68357 .54712 m .68743 .55218 L .68153 .54281 L .673 .757 .914 r
F
.68161 .54864 m .69854 .54251 L .68316 .54641 L .673 .758 .914 r
F
.67974 .54598 m .6798 .55124 L .67974 .54598 L .082 0 .419 r
F
.6798 .55124 m .68002 .56988 L .6798 .55124 L F
.6798 .55124 m .6798 .55124 L .67974 .54598 L F
.67974 .54598 m .6798 .55124 L .6798 .55125 L F
.68161 .54864 m .70085 .54616 L .69854 .54251 L .673 .758 .914 r
F
.67949 .54635 m .6796 .55153 L .67951 .55166 L .082 0 .419 r
F
.6763 .55057 m .68545 .54892 L .68161 .54864 L .673 .758 .914 r
F
.68153 .54281 m .68743 .55218 L .69275 .54966 L .673 .757 .914 r
F
.68015 .54631 m .69735 .55215 L .68159 .54571 L F
.68545 .54892 m .70085 .54616 L .68161 .54864 L .673 .758 .914 r
F
.67685 .54297 m .67678 .54829 L .67729 .54301 L .734 .477 .539 r
F
.67673 .55279 m .67785 .57268 L .67651 .55282 L .641 .401 .54 r
F
.67678 .54829 m .67649 .56779 L .67712 .54831 L .734 .477 .539 r
F
.67678 .54829 m .67712 .54831 L .67729 .54301 L F
.67786 .54844 m .6775 .54834 L .67758 .56792 L .81 .54 .531 r
F
.67794 .54315 m .6775 .54834 L .67786 .54844 L F
.67828 .54856 m .68316 .54641 L .68962 .53706 L .673 .758 .914 r
F
.67834 .54707 m .67845 .55235 L .67809 .54717 L .517 .303 .528 r
F
.6763 .55057 m .67918 .54882 L .67828 .54856 L .673 .758 .914 r
F
.67918 .54882 m .68316 .54641 L .67828 .54856 L F
.68256 .54192 m .6982 .53682 L .6838 .54013 L .673 .757 .914 r
F
.68203 .54268 m .70051 .54048 L .6982 .53682 L F
.68115 .54395 m .70051 .54048 L .68203 .54268 L F
.68316 .54641 m .69471 .5394 L .68963 .53706 L .673 .758 .914 r
F
.68316 .54641 m .68963 .53706 L .68962 .53706 L F
.6798 .55125 m .68002 .56988 L .68002 .56986 L .082 0 .419 r
F
.6798 .55124 m .68002 .56988 L .6798 .55125 L F
.6838 .54013 m .6982 .53682 L .69437 .53372 L .673 .757 .914 r
F
.67887 .54312 m .68256 .54192 L .6838 .54013 L F
.67822 .54179 m .67834 .54707 L .67773 .542 L .517 .303 .528 r
F
.67596 .54488 m .6805 .54324 L .67887 .54312 L .673 .757 .914 r
F
.67693 .53766 m .67685 .54297 L .67746 .5377 L .734 .477 .539 r
F
.67563 .5392 m .67677 .54214 L .67811 .54194 L .673 .757 .914 r
F
.67685 .54297 m .67729 .54301 L .67746 .5377 L .734 .477 .539 r
F
.67801 .53786 m .67748 .54302 L .67794 .54315 L .81 .54 .531 r
F
.67804 .54318 m .67854 .54332 L .67818 .54307 L .673 .757 .914 r
F
.67854 .54332 m .67854 .54332 L .67804 .54318 L F
.67778 .54304 m .67818 .54307 L .67792 .5429 L F
.67596 .54488 m .67818 .54307 L .67778 .54304 L F
.6763 .55057 m .67828 .54856 L .6775 .54834 L .673 .758 .914 r
F
.67748 .54302 m .67727 .54832 L .6775 .54834 L .734 .477 .539 r
F
.67739 .54833 m .6775 .54834 L .6774 .54831 L .673 .758 .914 r
F
.6763 .55057 m .6775 .54834 L .67739 .54833 L F
.67723 .55272 m .67785 .57268 L .67673 .55279 L .641 .401 .54 r
F
.6775 .54834 m .67649 .56779 L .67758 .56792 L .734 .477 .539 r
F
.67727 .54832 m .67649 .56779 L .6775 .54834 L F
.67746 .5377 m .67729 .54301 L .67748 .54302 L F
.67729 .54301 m .67649 .56779 L .67748 .54302 L F
.67735 .50912 m .67693 .53766 L .67746 .5377 L F
.67843 .5095 m .67746 .5377 L .67801 .53786 L .81 .54 .531 r
F
.6787 .54211 m .69437 .53372 L .68929 .53138 L .673 .757 .914 r
F
.67792 .5429 m .67883 .54239 L .6787 .54211 L F
.67883 .54239 m .69437 .53372 L .6787 .54211 L F
.67854 .54332 m .69437 .53372 L .67792 .5429 L F
.67908 .53838 m .679 .54363 L .67959 .53872 L .91 .629 .497 r
F
.679 .54363 m .67893 .54888 L .67926 .5438 L F
.67893 .54888 m .67865 .5683 L .67926 .54911 L F
.67757 .54797 m .68962 .53706 L .68363 .53564 L .673 .758 .914 r
F
.6774 .54831 m .67769 .54805 L .67757 .54797 L F
.67769 .54805 m .68962 .53706 L .67757 .54797 L F
.6789 .54679 m .67959 .57167 L .67878 .54688 L .359 .181 .499 r
F
.679 .54363 m .67858 .54865 L .67893 .54888 L .91 .629 .497 r
F
.68054 .54555 m .68015 .54631 L .68159 .54571 L .673 .757 .914 r
F
.67973 .54616 m .68015 .54631 L .68054 .54555 L F
.67998 .54481 m .67992 .54996 L .68005 .54497 L .982 .725 .331 r
F
.67828 .54856 m .68962 .53706 L .6774 .54831 L .673 .758 .914 r
F
.67858 .54865 m .67758 .56792 L .67865 .5683 L .81 .54 .531 r
F
.67835 .54858 m .67758 .56792 L .67858 .54865 L F
.67596 .54488 m .67898 .54673 L .67973 .54616 L .673 .757 .914 r
F
.67794 .54315 m .67758 .56792 L .67856 .54333 L .81 .54 .531 r
F
.67596 .54488 m .68019 .54412 L .68024 .54381 L .673 .757 .914 r
F
.67596 .54488 m .68024 .54381 L .67951 .5436 L F
.68003 .55054 m .68015 .57018 L .67999 .55077 L 0 0 .152 r
F
.68014 .54988 m .68129 .55048 L .68035 .54984 L .673 .758 .914 r
F
.6763 .55057 m .68004 .5505 L .68014 .54988 L F
.68004 .5505 m .68129 .55048 L .68014 .54988 L F
.68129 .55048 m .70148 .55011 L .68035 .54984 L F
.67963 .54936 m .67865 .5683 L .67971 .56913 L .91 .629 .497 r
F
.67926 .54911 m .67865 .5683 L .67963 .54936 L F
.67893 .54888 m .67858 .54865 L .67865 .5683 L F
.67908 .53838 m .67856 .54333 L .679 .54363 L F
.67855 .55305 m .68816 .5636 L .67909 .55227 L .673 .758 .914 r
F
.67951 .55166 m .68003 .57099 L .67959 .57167 L .082 0 .419 r
F
.6796 .55153 m .68003 .57099 L .67951 .55166 L F
.67957 .54624 m .67966 .55144 L .67949 .54635 L F
.67966 .55144 m .68003 .57099 L .6796 .55153 L F
.67966 .55144 m .6796 .55153 L .67949 .54635 L F
.67855 .55305 m .68658 .56402 L .68445 .55953 L .673 .758 .914 r
F
.6782 .55266 m .67852 .55309 L .67855 .55305 L F
.67852 .55309 m .68658 .56402 L .67855 .55305 L F
.67978 .54967 m .67963 .54936 L .67971 .56913 L .982 .725 .331 r
F
.68445 .55953 m .68658 .56402 L .68816 .5636 L .673 .758 .914 r
F
.67992 .54996 m .67971 .56913 L .67998 .55009 L .982 .725 .331 r
F
.68095 .55215 m .68096 .55216 L .68097 .55215 L .673 .758 .914 r
F
.67952 .55166 m .68096 .55216 L .68095 .55215 L F
.67931 .5524 m .69351 .56107 L .68097 .55215 L F
.6763 .55057 m .67617 .55287 L .67714 .55273 L F
.67617 .55287 m .67596 .55679 L .67714 .55273 L F
.67643 .54751 m .67673 .55279 L .67616 .54755 L .641 .401 .54 r
F
.67596 .54488 m .67581 .54761 L .67695 .54744 L .673 .757 .914 r
F
.67995 .55103 m .68015 .57018 L .68003 .57099 L 0 0 .152 r
F
.67999 .55077 m .68015 .57018 L .67995 .55103 L F
.68005 .54497 m .67971 .56913 L .68015 .57018 L .982 .725 .331 r
F
.5794 .91863 m .58313 .91983 L .5836 .91912 L .692 .759 .904 r
F
.72142 .82106 m .70778 .82423 L .72035 .82497 L .645 .732 .913 r
F
.72142 .82106 m .70937 .81837 L .70778 .82423 L F
0 g
.70778 .82423 m
.70875 .83024 L
s
.51917 .68224 m .53202 .68948 L .5382 .68451 L .683 .77 .917 r
F
.57345 .58372 m .56162 .56876 L .56194 .57444 L .932 .657 .494 r
F
.127 .923 .03 r
.56772 .56961 m
.5689 .51157 L
s
.57378 .5894 m .57345 .58372 L .56194 .57444 L .932 .657 .494 r
F
0 g
.57345 .58372 m
.58043 .59464 L
s
.73346 .82376 m .72035 .82497 L .73293 .82571 L .645 .732 .913 r
F
.73346 .82376 m .72142 .82106 L .72035 .82497 L F
.7466 .82429 m .75215 .8202 L .74916 .81925 L F
.74551 .82645 m .74764 .82444 L .7466 .82429 L F
.74764 .82444 m .75215 .8202 L .7466 .82429 L F
.74671 .82431 m .74596 .87655 L .74699 .8766 L .734 .478 .541 r
F
.74631 .87657 m .74757 .87631 L .74653 .87609 L .692 .759 .904 r
F
.74526 .87886 m .7473 .87661 L .74631 .87657 L F
.7473 .87661 m .74757 .87631 L .74631 .87657 L F
.74596 .87655 m .74592 .87931 L .74699 .8766 L .734 .478 .541 r
F
.74565 .87868 m .74681 .87828 L .74568 .87824 L .692 .759 .904 r
F
.74553 .88105 m .7466 .87872 L .74565 .87868 L F
.74699 .8766 m .74616 .87871 L .747 .87874 L .734 .478 .541 r
F
.7466 .87872 m .74681 .87828 L .74565 .87868 L .692 .759 .904 r
F
.74553 .88105 m .74785 .8785 L .74681 .87828 L F
.747 .87874 m .74592 .87931 L .74701 .87944 L .734 .478 .541 r
F
.74616 .87871 m .74592 .87931 L .747 .87874 L F
.74669 .82027 m .74664 .8243 L .74671 .82431 L F
.74664 .8243 m .74592 .87931 L .74671 .82431 L F
.74669 .82027 m .74561 .82015 L .74592 .87931 L F
.57062 .91911 m .56658 .9215 L .57085 .92055 L .692 .759 .904 r
F
.57062 .91911 m .56623 .91935 L .56658 .9215 L F
0 g
.56658 .9215 m
.56781 .92346 L
s
.57515 .91305 m .5705 .91325 L .57468 .91374 L .692 .759 .904 r
F
.58352 .91619 m .58768 .91452 L .5834 .91548 L F
0 g
.58305 .91785 m
.58316 .91705 L
s
.58737 .91233 m .5904 .90943 L .58656 .91103 L .692 .759 .904 r
F
.58737 .91233 m .59162 .91138 L .5904 .90943 L F
.74551 .82645 m .74265 .81887 L .73957 .81946 L .645 .732 .913 r
F
0 g
.7423 .82511 m
.74256 .87689 L
s
.74551 .82645 m .74592 .8188 L .74265 .81887 L .645 .732 .913 r
F
.74551 .82645 m .74916 .81925 L .74592 .8188 L F
0 g
.74884 .82548 m
.74912 .87725 L
s
.75808 .82719 m .77002 .82392 L .75776 .82518 L .645 .732 .913 r
F
.75808 .82719 m .77066 .82793 L .77002 .82392 L F
.74447 .87676 m .7454 .87606 L .74427 .87621 L .692 .759 .904 r
F
.74526 .87886 m .74538 .87663 L .74447 .87676 L F
.74561 .82015 m .74486 .8767 L .74591 .87655 L .66 .418 .542 r
F
.74538 .87663 m .7454 .87606 L .74447 .87676 L .692 .759 .904 r
F
.74526 .87886 m .74653 .87609 L .7454 .87606 L F
.74486 .8767 m .74482 .8794 L .74591 .87655 L .66 .418 .542 r
F
.74471 .87887 m .74568 .87824 L .74453 .8784 L .692 .759 .904 r
F
.74526 .87886 m .74512 .88165 L .74626 .8815 L F
.74553 .88105 m .74565 .87873 L .74471 .87887 L F
.74591 .87655 m .74504 .87882 L .74592 .8787 L .66 .418 .542 r
F
.74565 .87873 m .74568 .87824 L .74471 .87887 L .692 .759 .904 r
F
.74592 .8787 m .74482 .8794 L .74592 .87931 L .66 .418 .542 r
F
.74504 .87882 m .74482 .8794 L .74592 .8787 L F
0 g
.57564 .91691 m
.57569 .91772 L
s
.77066 .82793 m .78227 .82265 L .77002 .82392 L .645 .732 .913 r
F
.77066 .82793 m .78323 .82866 L .78227 .82265 L F
.78323 .82866 m .78251 .81888 L .78227 .82265 L .917 .743 .253 r
F
0 g
.78162 .83452 m
.78323 .82866 L
s
.73505 .81822 m .72165 .81729 L .7337 .81999 L .645 .732 .913 r
F
.58271 .91263 m .58522 .90995 L .58204 .91209 L .692 .759 .904 r
F
.58271 .91263 m .58656 .91103 L .58522 .90995 L F
.57913 .91643 m .57539 .91524 L .57493 .91594 L F
0 g
.57618 .91545 m
.57618 .91589 L
s
.73534 .81447 m .7247 .81002 L .72201 .81355 L .645 .732 .913 r
F
.73741 .81301 m .7247 .81002 L .73534 .81447 L F
.5794 .91863 m .57512 .91959 L .57553 .92024 L .692 .759 .904 r
F
.31696 .81483 m .30832 .80893 L .30422 .81185 L .644 .733 .913 r
F
.3196 .81377 m .30832 .80893 L .31696 .81483 L F
.75799 .82141 m .76794 .81631 L .75684 .81949 L .645 .732 .913 r
F
.75799 .82141 m .77025 .82015 L .76794 .81631 L F
.33466 .81587 m .33862 .80828 L .33211 .81451 L .644 .733 .913 r
F
.33466 .81587 m .34371 .811 L .33862 .80828 L F
.75701 .81574 m .76425 .80918 L .75511 .81405 L .645 .732 .913 r
F
.75701 .81574 m .76806 .81257 L .76425 .80918 L F
.7247 .81002 m .71003 .81087 L .72201 .81355 L F
.31434 .82381 m .30094 .82288 L .31301 .82558 L .644 .733 .913 r
F
.57501 .91887 m .57085 .92055 L .57512 .91959 L .692 .759 .904 r
F
.57501 .91887 m .57062 .91911 L .57085 .92055 L F
.5836 .91912 m .58817 .91815 L .58378 .91839 L F
.5794 .91863 m .5836 .91912 L .58378 .91839 L F
.57493 .91594 m .57036 .91691 L .57474 .91667 L F
.59195 .91356 m .59168 .91136 L .59046 .9094 L .974 .672 .302 r
F
0 g
.59168 .91136 m
.59203 .91352 L
s
.3146 .82004 m .30385 .81557 L .3012 .81911 L .644 .733 .913 r
F
.31666 .81857 m .30385 .81557 L .3146 .82004 L F
.49311 .68826 m .47941 .69695 L .48703 .70012 L .683 .77 .917 r
F
.33731 .827 m .34716 .8219 L .33612 .82509 L .644 .733 .913 r
F
.33731 .827 m .34953 .82574 L .34716 .8219 L F
0 0 0 r
2.5 Mabswid
.7337 .82524 Mdot
.127 .923 .03 r
.5 Mabswid
.40291 8.8267 m
.59706 4.13035 L
s
.77036 .81639 m .7791 .8094 L .76806 .81257 L .645 .732 .913 r
F
.77036 .81639 m .78255 .81513 L .7791 .8094 L F
.64927 .46853 m .61576 .46642 L .6459 .47325 L .654 .726 .902 r
F
.33638 .82131 m .34354 .81473 L .33444 .81961 L .644 .733 .913 r
F
.33638 .82131 m .34742 .81813 L .34354 .81473 L F
.30385 .81557 m .28913 .81642 L .3012 .81911 L F
.36367 .42875 m .34584 .44631 L .36849 .43319 L .654 .726 .902 r
F
.36367 .42875 m .33619 .43743 L .34584 .44631 L F
.57515 .91305 m .57143 .91186 L .5705 .91325 L .692 .759 .904 r
F
.57587 .91243 m .57143 .91186 L .57515 .91305 L F
.70666 .47643 m .7315 .46266 L .70375 .47138 L .654 .726 .902 r
F
.70666 .47643 m .7373 .47277 L .7315 .46266 L F
.51624 .69343 m .52516 .7027 L .53314 .6987 L .683 .77 .917 r
F
.51164 .69479 m .52516 .7027 L .51624 .69343 L F
.59256 .91791 m .59195 .91356 L .59221 .91576 L .752 .537 0 r
F
.58817 .91815 m .59256 .91791 L .59221 .91576 L .692 .759 .904 r
F
0 g
.59201 .92011 m
.59256 .91791 L
s
.5834 .91548 m .58686 .91321 L .583 .91482 L .692 .759 .904 r
F
.5834 .91548 m .58768 .91452 L .58686 .91321 L F
.30422 .81185 m .29352 .8074 L .28957 .81269 L .644 .733 .913 r
F
.57072 .91544 m .56597 .91715 L .57036 .91691 L .692 .759 .904 r
F
.57493 .91594 m .57072 .91544 L .57036 .91691 L F
.2931 .81111 m .28939 .81265 L .28913 .81642 L .074 0 .4 r
F
.2931 .81111 m .29336 .80734 L .28939 .81265 L F
0 g
.28789 .81851 m
.28939 .81265 L
s
.34979 .82197 m .35846 .81495 L .34742 .81813 L .644 .733 .913 r
F
.34979 .82197 m .36202 .8207 L .35846 .81495 L F
.41277 .43551 m .43435 .45094 L .44463 .4431 L .654 .726 .902 r
F
.40616 .43838 m .43435 .45094 L .41277 .43551 L F
.58204 .91209 m .58345 .90916 L .58116 .9117 L .692 .759 .904 r
F
.58204 .91209 m .58522 .90995 L .58345 .90916 L F
.3004 .57826 m .3276 .56986 L .30243 .57032 L .673 .757 .914 r
F
.27624 .57475 m .3004 .57826 L .30243 .57032 L F
.27358 .57848 m .3004 .57826 L .27624 .57475 L F
.57143 .91186 m .56631 .91276 L .5705 .91325 L .692 .759 .904 r
F
.58817 .91815 m .59221 .91576 L .58794 .91671 L F
.58378 .91839 m .58817 .91815 L .58794 .91671 L F
.5794 .91863 m .57501 .91887 L .57512 .91959 L F
.56677 .91715 m .56597 .91715 L .56623 .91935 L 0 0 .387 r
F
0 g
.56629 .91911 m
.56632 .91931 L
s
.57072 .91544 m .56651 .91495 L .56597 .91715 L .692 .759 .904 r
F
.56677 .91715 m .56651 .91495 L .56597 .91715 L 0 0 .387 r
F
.127 .923 .03 r
.56451 .92882 m
.56605 .8551 L
s
.36202 .8207 m .36228 .81693 L .35872 .81117 L .989 .751 .48 r
F
0 g
.36228 .81693 m
.36333 .82294 L
s
.17682 .57829 m .17869 .58443 L .17897 .59011 L .845 .639 .097 r
F
.17682 .57829 m .17654 .57261 L .17869 .58443 L F
.20172 .57215 m .17869 .58443 L .20315 .58003 L .673 .757 .914 r
F
.20172 .57215 m .17654 .57261 L .17869 .58443 L F
0 g
.17869 .58443 m
.18204 .58956 L
s
.57587 .91243 m .57287 .91062 L .57143 .91186 L .692 .759 .904 r
F
.57679 .91194 m .57287 .91062 L .57587 .91243 L F
.58378 .91839 m .58794 .91671 L .58367 .91767 L F
.5794 .91863 m .58378 .91839 L .58367 .91767 L F
.57539 .91524 m .57072 .91544 L .57493 .91594 L F
.58768 .91452 m .59072 .9116 L .58686 .91321 L F
.58768 .91452 m .59195 .91356 L .59072 .9116 L F
.72788 .58206 m .74007 .56666 L .74042 .57234 L .391 .238 .55 r
F
.7107 .57157 m .72788 .58206 L .74042 .57234 L .673 .758 .914 r
F
.70001 .57662 m .72788 .58206 L .7107 .57157 L F
0 g
.71184 .58963 m
.72788 .58206 L
s
.58116 .9117 m .58137 .90872 L .58012 .91148 L .692 .759 .904 r
F
.58116 .9117 m .58345 .90916 L .58137 .90872 L F
.64968 .46124 m .6229 .44968 L .61617 .45913 L .654 .726 .902 r
F
.65487 .45731 m .6229 .44968 L .64968 .46124 L F
.58656 .91103 m .5884 .90781 L .58522 .90995 L .692 .759 .904 r
F
.58656 .91103 m .5904 .90943 L .5884 .90781 L F
.65539 .4501 m .63391 .43467 L .62358 .44251 L .654 .726 .902 r
F
.66202 .44723 m .63391 .43467 L .65539 .4501 L F
.583 .91482 m .58552 .91213 L .58232 .91428 L .692 .759 .904 r
F
.583 .91482 m .58686 .91321 L .58552 .91213 L F
.5794 .91863 m .57519 .91814 L .57501 .91887 L F
.5794 .91863 m .57566 .91743 L .57519 .91814 L F
.5794 .91863 m .57638 .91682 L .57566 .91743 L F
0 g
.57564 .91691 m
.57618 .91589 L
s
.5794 .91863 m .57731 .91632 L .57638 .91682 L .692 .759 .904 r
F
.5794 .91863 m .57838 .91598 L .57731 .91632 L F
.5794 .91863 m .57952 .91582 L .57838 .91598 L F
.5794 .91863 m .58065 .91586 L .57952 .91582 L F
.5794 .91863 m .5817 .91608 L .58065 .91586 L F
.5794 .91863 m .58259 .91648 L .5817 .91608 L F
.5794 .91863 m .58326 .91702 L .58259 .91648 L F
0 g
.58272 .91601 m
.5831 .91689 L
s
.5794 .91863 m .58367 .91767 L .58326 .91702 L .692 .759 .904 r
F
.70415 .46409 m .72231 .44645 L .69936 .45963 L .654 .726 .902 r
F
.70415 .46409 m .73189 .45538 L .72231 .44645 L F
.69964 .45242 m .70982 .4322 L .69332 .44887 L F
.69964 .45242 m .72248 .4393 L .70982 .4322 L F
.33546 .48036 m .32136 .4597 L .3209 .46699 L .927 .669 .527 r
F
0 g
.33546 .48036 m
.34397 .49486 L
s
.127 .923 .03 r
.54093 6.68685 m
.64508 1.70695 L
s
.49676 8.79933 m
.54093 6.68685 L
s
.57679 .91194 m .57472 .90964 L .57287 .91062 L .692 .759 .904 r
F
.57786 .9116 m .57472 .90964 L .57679 .91194 L F
.3196 .81377 m .31359 .80681 L .30832 .80893 L .644 .733 .913 r
F
.32265 .81319 m .31359 .80681 L .3196 .81377 L F
.6229 .44968 m .58602 .45229 L .61617 .45913 L .654 .726 .902 r
F
.33211 .81451 m .33264 .8064 L .32913 .81357 L .644 .733 .913 r
F
.33211 .81451 m .33862 .80828 L .33264 .8064 L F
.58012 .91148 m .57912 .90865 L .57899 .91144 L .692 .759 .904 r
F
.58012 .91148 m .58137 .90872 L .57912 .90865 L F
.23875 .45212 m .23127 .43219 L .20843 .43706 L .654 .726 .902 r
F
.255 .45159 m .23127 .43219 L .23875 .45212 L F
.57519 .91814 m .57062 .91911 L .57501 .91887 L .692 .759 .904 r
F
.59195 .91356 m .59046 .9094 L .59072 .9116 L .974 .672 .302 r
F
.59221 .91576 m .59195 .91356 L .59072 .9116 L F
0 g
.59195 .91356 m
.5923 .91571 L
s
.58166 .9152 m
.58272 .91601 L
s
.58272 .91601 m
.58272 .91601 L
s
.22674 .56601 m .2031 .57431 L .22744 .56993 L .673 .757 .914 r
F
.22674 .56601 m .20168 .56647 L .2031 .57431 L F
.27115 .45381 m .25566 .4314 L .255 .45159 L .654 .726 .902 r
F
.27115 .45381 m .2799 .43473 L .25566 .4314 L F
.57786 .9116 m .57685 .90897 L .57472 .90964 L .692 .759 .904 r
F
.57899 .91144 m .57685 .90897 L .57786 .9116 L F
0 g
.57618 .91589 m
.57618 .91589 L
s
.57618 .91589 m
.5773 .91512 L
s
.57899 .91144 m .57912 .90865 L .57685 .90897 L .692 .759 .904 r
F
.57539 .91524 m .57166 .91404 L .57072 .91544 L F
.57612 .91462 m .57166 .91404 L .57539 .91524 L F
.22291 .46246 m .20773 .44407 L .18788 .45272 L .654 .726 .902 r
F
.23821 .4592 m .20773 .44407 L .22291 .46246 L F
.57143 .91186 m .56771 .91067 L .56631 .91276 L .692 .759 .904 r
F
.73769 .46549 m .75966 .44666 L .73189 .45538 L .654 .726 .902 r
F
.73769 .46549 m .76834 .46183 L .75966 .44666 L F
.56792 .91285 m .56625 .91275 L .56651 .91495 L .192 .102 .516 r
F
.56792 .91285 m .56765 .91065 L .56625 .91275 L F
0 g
.5657 .91496 m
.56625 .91275 L
s
.58367 .91767 m .58712 .91541 L .58326 .91702 L .692 .759 .904 r
F
.58367 .91767 m .58794 .91671 L .58712 .91541 L F
.57098 .91764 m .56623 .91935 L .57062 .91911 L F
.57519 .91814 m .57098 .91764 L .57062 .91911 L F
.45515 .57639 m .4424 .58043 L .44271 .5861 L .387 .234 .548 r
F
.45515 .57639 m .45484 .57071 L .4424 .58043 L F
0 g
.43436 .59162 m
.4424 .58043 L
s
.73741 .81301 m .72885 .8071 L .7247 .81002 L .645 .732 .913 r
F
.74007 .81195 m .72885 .8071 L .73741 .81301 L F
.55536 .69848 m .56093 .68545 L .56142 .69002 L .203 .117 .53 r
F
.53935 .69371 m .55536 .69848 L .56142 .69002 L .683 .77 .917 r
F
.53314 .6987 m .55536 .69848 L .53935 .69371 L F
0 g
.54604 .70597 m
.55536 .69848 L
s
.28581 .46575 m .27957 .44173 L .27078 .4609 L .654 .726 .902 r
F
.28581 .46575 m .30214 .44901 L .27957 .44173 L F
.51973 .68685 m .53264 .69413 L .53886 .68913 L .683 .77 .917 r
F
.75511 .81405 m .7592 .80646 L .75258 .81268 L .645 .732 .913 r
F
.75511 .81405 m .76425 .80918 L .7592 .80646 L F
.58232 .91428 m .58374 .91133 L .58143 .91388 L .692 .759 .904 r
F
.58232 .91428 m .58552 .91213 L .58374 .91133 L F
.73482 .82199 m .72142 .82106 L .73346 .82376 L .645 .732 .913 r
F
.57166 .91404 m .56651 .91495 L .57072 .91544 L .692 .759 .904 r
F
.73505 .81822 m .72436 .81375 L .72165 .81729 L .645 .732 .913 r
F
.73713 .81675 m .72436 .81375 L .73505 .81822 L F
.57098 .91764 m .56677 .91715 L .56623 .91935 L .692 .759 .904 r
F
.127 .923 .03 r
.66184 .78829 m
.66191 .78612 L
s
0 g
.56623 .91935 m
.56658 .9215 L
s
.36748 .44782 m .3575 .46813 L .37388 .45139 L .654 .726 .902 r
F
.36748 .44782 m .34471 .46101 L .3575 .46813 L F
.75776 .82518 m .7677 .82008 L .7566 .82327 L .645 .732 .913 r
F
.75776 .82518 m .77002 .82392 L .7677 .82008 L F
.31666 .81857 m .30797 .81264 L .30385 .81557 L .644 .733 .913 r
F
.31931 .81751 m .30797 .81264 L .31666 .81857 L F
.57287 .91062 m .56771 .91067 L .57143 .91186 L .692 .759 .904 r
F
.47244 .58687 m .45515 .57639 L .44271 .5861 L .673 .757 .914 r
F
.48309 .58183 m .45515 .57639 L .47244 .58687 L F
.75684 .81949 m .76411 .81291 L .75492 .81779 L .645 .732 .913 r
F
.75684 .81949 m .76794 .81631 L .76411 .81291 L F
.33444 .81961 m .33843 .81199 L .33189 .81825 L .644 .733 .913 r
F
.33444 .81961 m .34354 .81473 L .33843 .81199 L F
.72436 .81375 m .70961 .8146 L .72165 .81729 L .645 .732 .913 r
F
.53297 .57537 m .52825 .55772 L .52104 .57255 L .673 .757 .914 r
F
.127 .923 .03 r
.52517 .54815 m
.52554 .52332 L
s
.53297 .57537 m .54614 .56196 L .52825 .55772 L .673 .757 .914 r
F
.40535 .45304 m .42041 .47142 L .43369 .46566 L .654 .726 .902 r
F
.39768 .45467 m .42041 .47142 L .40535 .45304 L F
.57612 .91462 m .5731 .9128 L .57166 .91404 L .692 .759 .904 r
F
.57705 .91412 m .5731 .9128 L .57612 .91462 L F
.32265 .81319 m .31968 .80564 L .31359 .80681 L .644 .733 .913 r
F
.3259 .81312 m .31968 .80564 L .32265 .81319 L F
.31434 .82381 m .30359 .81934 L .30094 .82288 L F
.3164 .82234 m .30359 .81934 L .31434 .82381 L F
.57566 .91743 m .57098 .91764 L .57519 .91814 L .692 .759 .904 r
F
.60965 .57472 m .62082 .57833 L .62115 .58401 L .933 .657 .494 r
F
.60965 .57472 m .60932 .56904 L .62082 .57833 L F
.63152 .56099 m .62082 .57833 L .63919 .56719 L .673 .757 .914 r
F
.63152 .56099 m .60932 .56904 L .62082 .57833 L F
0 g
.62082 .57833 m
.62634 .58086 L
s
.7247 .81002 m .71406 .80558 L .71003 .81087 L .645 .732 .913 r
F
.58794 .91671 m .59099 .9138 L .58712 .91541 L .692 .759 .904 r
F
.58794 .91671 m .59221 .91576 L .59099 .9138 L F
.54393 .59126 m .54699 .57311 L .53374 .58659 L .673 .758 .914 r
F
.54393 .59126 m .56226 .58012 L .54699 .57311 L F
.32913 .81357 m .32618 .8055 L .3259 .81312 L .644 .733 .913 r
F
.32913 .81357 m .33264 .8064 L .32618 .8055 L F
.66864 .5598 m .66132 .5747 L .67429 .5755 L .673 .757 .914 r
F
.71367 .80929 m .70984 .81083 L .70961 .8146 L .092 0 .411 r
F
.71367 .80929 m .7139 .80551 L .70984 .81083 L F
0 g
.70825 .81669 m
.70984 .81083 L
s
.58059 .91482 m
.58166 .9152 L
s
.77025 .82015 m .77904 .81312 L .76794 .81631 L .645 .732 .913 r
F
.77025 .82015 m .78251 .81888 L .77904 .81312 L F
.33612 .82509 m .34328 .8185 L .33418 .82338 L .644 .733 .913 r
F
.33612 .82509 m .34716 .8219 L .34328 .8185 L F
.30359 .81934 m .28886 .82019 L .30094 .82288 L F
0 g
.5773 .91512 m
.57841 .91478 L
s
.58143 .91388 m .58165 .91089 L .58039 .91366 L .692 .759 .904 r
F
.58143 .91388 m .58374 .91133 L .58165 .91089 L F
.59072 .9116 m .59046 .9094 L .58844 .90777 L .934 .633 .448 r
F
.127 .923 .03 r
.60683 2.48696 m
.66184 .78829 L
s
.40156 8.82534 m
.60683 2.48696 L
s
0 g
.59046 .9094 m
.59168 .91136 L
s
.58686 .91321 m .58871 .90997 L .58552 .91213 L .692 .759 .904 r
F
.58686 .91321 m .59072 .9116 L .58871 .90997 L F
.30832 .80893 m .29352 .8074 L .30422 .81185 L .644 .733 .913 r
F
.62358 .44251 m .59692 .43099 L .58689 .44512 L .654 .726 .902 r
F
.58522 .90995 m .58574 .90662 L .58345 .90916 L .692 .759 .904 r
F
.58522 .90995 m .5884 .90781 L .58574 .90662 L F
.58326 .91702 m .58578 .91432 L .58259 .91648 L F
.58326 .91702 m .58712 .91541 L .58578 .91432 L F
.127 .923 .03 r
.43118 .46454 m
.4312 .46032 L
s
.29283 .81488 m .28913 .81642 L .28886 .82019 L .074 0 .4 r
F
.30385 .81557 m .2931 .81111 L .28913 .81642 L .644 .733 .913 r
F
.29283 .81488 m .2931 .81111 L .28913 .81642 L .074 0 .4 r
F
0 g
.28763 .82228 m
.28913 .81642 L
s
.29989 .43996 m
.30053 .44105 L
s
.34953 .82574 m .3582 .81872 L .34716 .8219 L .644 .733 .913 r
F
.34953 .82574 m .36176 .82447 L .3582 .81872 L F
.59611 .4381 m .58644 .44501 L .58602 .45229 L .071 0 .396 r
F
.59619 .43661 m .59652 .43082 L .59413 .43952 L F
.59413 .43952 m .59652 .43082 L .58644 .44501 L F
.63391 .43467 m .59692 .43099 L .62358 .44251 L .654 .726 .902 r
F
.59759 .42926 m .59763 .42855 L .6129 .42805 L .667 .431 .554 r
F
.60779 .42971 m .59759 .42926 L .6129 .42805 L F
.58928 .40832 m .58838 .42855 L .61279 .42775 L .654 .726 .902 r
F
.60556 .40779 m .61279 .42775 L .63572 .42288 L F
.58928 .40832 m .61279 .42775 L .60556 .40779 L F
.61281 .42954 m .61242 .41922 L .59821 .43002 L F
.62618 .42911 m .6236 .42725 L .61281 .42954 L F
.61281 .42954 m .6129 .42805 L .63114 .42565 L .592 .367 .545 r
F
.6236 .42725 m .61242 .41922 L .61281 .42954 L .654 .726 .902 r
F
.63114 .42565 m .6129 .42805 L .63595 .42316 L .592 .367 .545 r
F
.63391 .43467 m .62618 .42911 L .59692 .43099 L .654 .726 .902 r
F
.65178 .41776 m .63595 .42316 L .65596 .41449 L .493 .286 .527 r
F
.63586 .42465 m .63595 .42316 L .65178 .41776 L F
.63114 .42565 m .63595 .42316 L .63586 .42465 L .592 .367 .545 r
F
.62086 .40454 m .63572 .42288 L .65564 .41426 L .654 .726 .902 r
F
.60556 .40779 m .63572 .42288 L .62086 .40454 L F
.6343 .42533 m .63233 .41059 L .61242 .41922 L F
.64718 .42892 m .64168 .42213 L .6343 .42533 L F
.64168 .42213 m .63233 .41059 L .6343 .42533 L F
.66248 .42568 m .63233 .41059 L .64718 .42892 L F
.65178 .41776 m .65596 .41449 L .65588 .41598 L .493 .286 .527 r
F
.63414 .39878 m .65564 .41426 L .67117 .40246 L .654 .726 .902 r
F
.62086 .40454 m .65564 .41426 L .63414 .39878 L F
.6508 .41983 m .65528 .40571 L .63233 .41059 L F
.66248 .42568 m .65832 .41413 L .6508 .41983 L F
.65832 .41413 m .65528 .40571 L .6508 .41983 L F
.66829 .40656 m .65596 .41449 L .67054 .40342 L .342 .164 .489 r
F
.65588 .41598 m .65596 .41449 L .66829 .40656 L F
.67876 .42515 m .66204 .4113 L .66248 .42568 L .654 .726 .902 r
F
.66204 .4113 m .65528 .40571 L .65832 .41413 L F
.66204 .4113 m .65832 .41413 L .66248 .42568 L F
.67876 .42515 m .67972 .40491 L .67072 .40521 L F
.66477 .41356 m .67072 .40521 L .65528 .40571 L F
.67876 .42515 m .67072 .40521 L .66477 .41356 L F
.67955 .39281 m .67157 .40264 L .68171 .3884 L .074 0 .397 r
F
.67933 .4119 m .67974 .40461 L .67046 .40491 L .667 .431 .554 r
F
.66829 .40656 m .67149 .40413 L .67117 .40992 L .342 .164 .489 r
F
.6702 .40944 m .67046 .40491 L .65518 .40541 L .667 .431 .554 r
F
.67933 .4119 m .67046 .40491 L .6702 .40944 L F
.65555 .42177 m .66829 .40656 L .67024 .40884 L .342 .164 .489 r
F
.67933 .4119 m .6702 .40944 L .67005 .4122 L .667 .431 .554 r
F
.67013 .41071 m .67024 .40884 L .67117 .40992 L .342 .164 .489 r
F
.65555 .42177 m .67024 .40884 L .67013 .41071 L F
.67117 .40992 m .67149 .40413 L .67955 .39281 L .074 0 .397 r
F
.67149 .40413 m .67157 .40264 L .67955 .39281 L F
.66829 .40656 m .67157 .40264 L .67149 .40413 L .342 .164 .489 r
F
.65555 .42177 m .65588 .41598 L .66829 .40656 L F
.667 .41081 m .65518 .40541 L .65485 .4112 L .667 .431 .554 r
F
.65013 .41221 m .65518 .40541 L .6321 .41031 L .591 .367 .545 r
F
.65178 .41776 m .65588 .41598 L .65555 .42177 L .493 .286 .527 r
F
.65485 .4112 m .65555 .42177 L .67013 .41071 L .654 .726 .902 r
F
.65013 .41221 m .6321 .41031 L .63178 .41611 L .591 .367 .545 r
F
.64147 .41164 m .64405 .4135 L .65485 .4112 L .654 .726 .902 r
F
.64405 .4135 m .65555 .42177 L .65485 .4112 L F
.63554 .43044 m .65178 .41776 L .65555 .42177 L .493 .286 .527 r
F
.63554 .43044 m .63586 .42465 L .65178 .41776 L F
.6343 .42533 m .63359 .42513 L .63361 .42562 L .654 .726 .902 r
F
.63359 .42513 m .61242 .41922 L .6236 .42725 L F
.6343 .42533 m .63361 .42562 L .63391 .43467 L F
.63114 .42565 m .63586 .42465 L .63554 .43044 L .592 .367 .545 r
F
.63314 .41551 m .63554 .43044 L .65555 .42177 L .654 .726 .902 r
F
.62768 .41788 m .6321 .41031 L .6121 .41898 L .492 .285 .527 r
F
.62596 .41863 m .63554 .43044 L .63314 .41551 L .654 .726 .902 r
F
.63169 .4176 m .63178 .41611 L .62768 .41788 L .492 .285 .527 r
F
.63178 .41611 m .6321 .41031 L .62768 .41788 L F
.62768 .41788 m .6121 .41898 L .61177 .42478 L F
.60522 .41528 m .61844 .42189 L .6206 .41201 L .654 .726 .902 r
F
.63359 .42513 m .6236 .42725 L .63391 .43467 L F
.61248 .43533 m .63114 .42565 L .63554 .43044 L .592 .367 .545 r
F
.61248 .43533 m .61281 .42954 L .63114 .42565 L F
.61844 .42189 m .63554 .43044 L .62596 .41863 L .654 .726 .902 r
F
.61844 .42189 m .62596 .41863 L .6206 .41201 L F
.6206 .41201 m .62596 .41863 L .63314 .41551 L F
.62618 .42911 m .59821 .43002 L .59692 .43099 L F
.61671 .42102 m .61248 .43533 L .63554 .43044 L F
.60879 .42704 m .6121 .41898 L .59755 .43004 L .342 .163 .488 r
F
.61177 .42478 m .6121 .41898 L .60879 .42704 L F
.60522 .41528 m .60933 .42663 L .61671 .42102 L .654 .726 .902 r
F
.60933 .42663 m .61248 .43533 L .61671 .42102 L F
.61168 .42627 m .61177 .42478 L .60879 .42704 L .342 .163 .488 r
F
.63169 .4176 m .62768 .41788 L .61168 .42627 L .492 .285 .527 r
F
.62768 .41788 m .61177 .42478 L .61168 .42627 L F
.6206 .41201 m .65555 .42177 L .63394 .40623 L .654 .726 .902 r
F
.65477 .4127 m .65013 .41221 L .63169 .4176 L .591 .367 .545 r
F
.65013 .41221 m .63178 .41611 L .63169 .4176 L F
.65477 .4127 m .65485 .4112 L .65013 .41221 L F
.65485 .4112 m .65518 .40541 L .65013 .41221 L F
.63394 .40623 m .64147 .41164 L .65703 .41074 L .654 .726 .902 r
F
.66415 .40923 m .65703 .41074 L .67117 .40992 L F
.63394 .40623 m .65703 .41074 L .66415 .40923 L F
.64147 .41164 m .67013 .41071 L .67117 .40992 L F
.67005 .4122 m .667 .41081 L .65477 .4127 L .667 .431 .554 r
F
.667 .41081 m .65485 .4112 L .65477 .4127 L F
.6702 .40944 m .65518 .40541 L .67005 .4122 L F
.67051 .4039 m .67054 .40342 L .67157 .40264 L .342 .164 .489 r
F
.66829 .40656 m .67054 .40342 L .67051 .4039 L F
.64718 .42892 m .6343 .42533 L .63391 .43467 L .654 .726 .902 r
F
.59752 .43052 m .59755 .43004 L .59652 .43082 L .342 .163 .488 r
F
.59713 .43732 m .59652 .43082 L .59611 .4381 L F
.59738 .43308 m .59755 .43004 L .60779 .42971 L .667 .431 .554 r
F
.60879 .42704 m .59755 .43004 L .60858 .4272 L .342 .163 .488 r
F
.58885 .41581 m .60548 .42955 L .60522 .41528 L .654 .726 .902 r
F
.59722 .43583 m .6129 .42805 L .61248 .43533 L .667 .431 .554 r
F
.58795 .43613 m .59738 .43308 L .59722 .43583 L F
.59738 .43308 m .6129 .42805 L .59722 .43583 L F
.60548 .42955 m .61248 .43533 L .60933 .42663 L .654 .726 .902 r
F
.60548 .42955 m .59722 .43583 L .61248 .43533 L F
.63073 .43293 m .61248 .43533 L .63554 .43044 L .592 .367 .545 r
F
.63329 .44179 m .62577 .43639 L .61022 .43729 L .654 .726 .902 r
F
.63329 .44179 m .61022 .43729 L .60311 .4388 L F
.63329 .44179 m .59611 .4381 L .6229 .44968 L F
.6124 .43683 m .61248 .43533 L .63073 .43293 L .592 .367 .545 r
F
.66202 .44723 m .64718 .42892 L .63391 .43467 L .654 .726 .902 r
F
.65137 .42504 m .63554 .43044 L .65555 .42177 L .493 .286 .527 r
F
.63545 .43193 m .63554 .43044 L .65137 .42504 L F
.63073 .43293 m .63554 .43044 L .63545 .43193 L .592 .367 .545 r
F
.63409 .43252 m .63169 .4176 L .61168 .42627 L .654 .726 .902 r
F
.64662 .43602 m .64127 .42941 L .63409 .43252 L F
.64127 .42941 m .63169 .4176 L .63409 .43252 L F
.66966 .44561 m .64718 .42892 L .66202 .44723 L F
.66966 .44561 m .66248 .42568 L .64718 .42892 L F
.662 .43276 m .63169 .4176 L .64662 .43602 L F
.65137 .42504 m .65555 .42177 L .65547 .42327 L .493 .286 .527 r
F
.65052 .42702 m .65477 .4127 L .63169 .4176 L .654 .726 .902 r
F
.662 .43276 m .65791 .42141 L .65052 .42702 L F
.65791 .42141 m .65477 .4127 L .65052 .42702 L F
.66788 .41384 m .65555 .42177 L .67013 .41071 L .342 .164 .489 r
F
.65547 .42327 m .65555 .42177 L .66788 .41384 L F
.6778 .44535 m .66248 .42568 L .66966 .44561 L .654 .726 .902 r
F
.6778 .44535 m .67876 .42515 L .66248 .42568 L F
.67836 .43223 m .66176 .41849 L .662 .43276 L F
.66176 .41849 m .65477 .4127 L .65791 .42141 L F
.66176 .41849 m .65791 .42141 L .662 .43276 L F
.67836 .43223 m .67933 .4119 L .67054 .41218 L F
.66446 .42071 m .67054 .41218 L .65477 .4127 L F
.67836 .43223 m .67054 .41218 L .66446 .42071 L F
.67915 .4001 m .67117 .40992 L .68131 .39569 L .074 0 .397 r
F
.67893 .41918 m .67933 .4119 L .67005 .4122 L .667 .431 .554 r
F
.66788 .41384 m .67108 .41142 L .67076 .41721 L .342 .164 .489 r
F
.6698 .41673 m .67005 .4122 L .65477 .4127 L .667 .431 .554 r
F
.67893 .41918 m .67005 .4122 L .6698 .41673 L F
.65514 .42906 m .66788 .41384 L .66983 .41613 L .342 .164 .489 r
F
.67893 .41918 m .6698 .41673 L .66965 .41949 L .667 .431 .554 r
F
.66973 .41799 m .66983 .41613 L .67076 .41721 L .342 .164 .489 r
F
.65514 .42906 m .66983 .41613 L .66973 .41799 L F
.67076 .41721 m .67108 .41142 L .67915 .4001 L .074 0 .397 r
F
.67108 .41142 m .67117 .40992 L .67915 .4001 L F
.66788 .41384 m .67117 .40992 L .67108 .41142 L .342 .164 .489 r
F
.65514 .42906 m .65547 .42327 L .66788 .41384 L F
.6666 .4181 m .65477 .4127 L .65444 .41849 L .667 .431 .554 r
F
.64972 .4195 m .65477 .4127 L .63169 .4176 L .591 .367 .545 r
F
.65137 .42504 m .65547 .42327 L .65514 .42906 L .493 .286 .527 r
F
.65444 .41849 m .65514 .42906 L .66973 .41799 L .654 .726 .902 r
F
.64972 .4195 m .63169 .4176 L .63137 .42339 L .591 .367 .545 r
F
.64106 .41893 m .64364 .42079 L .65444 .41849 L .654 .726 .902 r
F
.64364 .42079 m .65514 .42906 L .65444 .41849 L F
.63513 .43772 m .65137 .42504 L .65514 .42906 L .493 .286 .527 r
F
.63513 .43772 m .63545 .43193 L .65137 .42504 L F
.63409 .43252 m .63347 .43235 L .63346 .43279 L .654 .726 .902 r
F
.63409 .43252 m .63346 .43279 L .63329 .44179 L F
.63347 .43235 m .61168 .42627 L .62319 .43454 L F
.63073 .43293 m .63545 .43193 L .63513 .43772 L .592 .367 .545 r
F
.63273 .4228 m .63513 .43772 L .65514 .42906 L .654 .726 .902 r
F
.62727 .42517 m .63169 .4176 L .61168 .42627 L .492 .285 .527 r
F
.62555 .42591 m .63513 .43772 L .63273 .4228 L .654 .726 .902 r
F
.63128 .42489 m .63137 .42339 L .62727 .42517 L .492 .285 .527 r
F
.63137 .42339 m .63169 .4176 L .62727 .42517 L F
.60737 .43699 m .58795 .43613 L .61248 .43533 L .667 .431 .554 r
F
.62577 .43639 m .61168 .42627 L .59713 .43732 L .654 .726 .902 r
F
.62727 .42517 m .61168 .42627 L .61135 .43206 L .492 .285 .527 r
F
.6048 .42257 m .61802 .42917 L .62019 .4193 L .654 .726 .902 r
F
.63347 .43235 m .62319 .43454 L .63329 .44179 L F
.61207 .44262 m .63073 .43293 L .63513 .43772 L .592 .367 .545 r
F
.61207 .44262 m .6124 .43683 L .63073 .43293 L F
.61802 .42917 m .63513 .43772 L .62555 .42591 L .654 .726 .902 r
F
.61802 .42917 m .62555 .42591 L .62019 .4193 L F
.62019 .4193 m .62555 .42591 L .63273 .4228 L F
.62577 .43639 m .59713 .43732 L .59611 .4381 L F
.61629 .42831 m .61207 .44262 L .63513 .43772 L F
.60837 .43433 m .61168 .42627 L .59713 .43732 L .342 .163 .488 r
F
.61135 .43206 m .61168 .42627 L .60837 .43433 L F
.60548 .42955 m .60933 .42663 L .60522 .41528 L .654 .726 .902 r
F
.61168 .42627 m .60879 .42704 L .60858 .4272 L .342 .163 .488 r
F
.6048 .42257 m .60892 .43391 L .61629 .42831 L .654 .726 .902 r
F
.60892 .43391 m .61207 .44262 L .61629 .42831 L F
.61127 .43355 m .61135 .43206 L .60837 .43433 L .342 .163 .488 r
F
.63128 .42489 m .62727 .42517 L .61127 .43355 L .492 .285 .527 r
F
.62727 .42517 m .61135 .43206 L .61127 .43355 L F
.62019 .4193 m .65514 .42906 L .63353 .41351 L .654 .726 .902 r
F
.65436 .41998 m .64972 .4195 L .63128 .42489 L .591 .367 .545 r
F
.64972 .4195 m .63137 .42339 L .63128 .42489 L F
.65436 .41998 m .65444 .41849 L .64972 .4195 L F
.65444 .41849 m .65477 .4127 L .64972 .4195 L F
.63353 .41351 m .64106 .41893 L .65663 .41803 L .654 .726 .902 r
F
.66375 .41651 m .65663 .41803 L .67076 .41721 L F
.63353 .41351 m .65663 .41803 L .66375 .41651 L F
.64106 .41893 m .66973 .41799 L .67076 .41721 L F
.66965 .41949 m .6666 .4181 L .65436 .41998 L .667 .431 .554 r
F
.6666 .4181 m .65444 .41849 L .65436 .41998 L F
.6698 .41673 m .65477 .4127 L .66965 .41949 L F
.67011 .41119 m .67013 .41071 L .67117 .40992 L .342 .164 .489 r
F
.66788 .41384 m .67013 .41071 L .67011 .41119 L F
.64662 .43602 m .63409 .43252 L .63329 .44179 L .654 .726 .902 r
F
.60311 .4388 m .61022 .43729 L .59611 .4381 L F
.59711 .4378 m .59713 .43732 L .59611 .4381 L .342 .163 .488 r
F
.59611 .4381 m .59619 .43661 L .59413 .43952 L .071 0 .396 r
F
.6229 .44968 m .59611 .4381 L .58602 .45229 L .654 .726 .902 r
F
.59659 .44328 m .59611 .4381 L .59578 .4439 L .342 .163 .488 r
F
.58753 .44342 m .58787 .43762 L .59713 .43732 L .667 .431 .554 r
F
.59711 .4378 m .59611 .4381 L .59672 .44461 L .342 .163 .488 r
F
.58753 .44342 m .59713 .43732 L .59696 .44036 L .667 .431 .554 r
F
.58787 .43762 m .58795 .43613 L .60737 .43699 L F
.58795 .43613 m .58828 .43034 L .59755 .43004 L F
.59752 .43052 m .59652 .43082 L .59713 .43732 L .342 .163 .488 r
F
.58795 .43613 m .59755 .43004 L .59738 .43308 L .667 .431 .554 r
F
.58828 .43034 m .58837 .42885 L .60779 .42971 L F
.59569 .44539 m .59611 .4381 L .58602 .45229 L .071 0 .396 r
F
.58753 .44342 m .61248 .43533 L .61207 .44262 L .667 .431 .554 r
F
.58844 .4231 m .58753 .44342 L .5968 .44312 L .654 .726 .902 r
F
.60507 .43684 m .5968 .44312 L .61207 .44262 L F
.59696 .44036 m .59713 .43732 L .60737 .43699 L .667 .431 .554 r
F
.61127 .43355 m .60816 .43449 L .59672 .44461 L .342 .163 .488 r
F
.60816 .43449 m .59711 .4378 L .5968 .44312 L F
.60816 .43449 m .5968 .44312 L .59672 .44461 L F
.61168 .42627 m .60858 .4272 L .59713 .43732 L F
.60858 .4272 m .59752 .43052 L .59722 .43583 L F
.60858 .4272 m .59722 .43583 L .59713 .43732 L F
.60279 .42733 m .59674 .43585 L .59722 .43583 L .654 .726 .902 r
F
.60279 .42733 m .59722 .43583 L .60548 .42955 L F
.60858 .4272 m .59755 .43004 L .59752 .43052 L .342 .163 .488 r
F
.58885 .41581 m .58795 .43613 L .59674 .43585 L .654 .726 .902 r
F
.59759 .42926 m .58837 .42885 L .59763 .42855 L .667 .431 .554 r
F
.58885 .41581 m .59674 .43585 L .60279 .42733 L .654 .726 .902 r
F
.58844 .4231 m .60507 .43684 L .6048 .42257 L F
.60507 .43684 m .61207 .44262 L .60892 .43391 L F
.60507 .43684 m .60892 .43391 L .6048 .42257 L F
.61127 .43355 m .59713 .43732 L .59711 .4378 L .342 .163 .488 r
F
.58844 .4231 m .5968 .44312 L .60507 .43684 L .654 .726 .902 r
F
.59672 .44461 m .59659 .44328 L .59569 .44539 L .342 .163 .488 r
F
.59659 .44328 m .59578 .4439 L .59569 .44539 L F
0 g
.58253 .46059 m
.58644 .44501 L
s
.58644 .44501 m
.58757 .44342 L
s
.3259 .81312 m .32618 .8055 L .31968 .80564 L .644 .733 .913 r
F
.4936 .69284 m .48752 .70469 L .49741 .69442 L .683 .77 .917 r
F
.4936 .69284 m .4799 .70152 L .48752 .70469 L F
.78251 .81888 m .78274 .81511 L .77927 .80935 L .991 .751 .471 r
F
0 g
.78274 .81511 m
.78369 .82112 L
s
.57378 .5894 m .56194 .57444 L .56226 .58012 L .932 .657 .494 r
F
0 g
.57378 .5894 m
.58075 .60032 L
s
.127 .923 .03 r
.56761 .57498 m
.56772 .56961 L
s
.56446 .72997 m
.5675 .58035 L
s
.5675 .58035 m
.56761 .57498 L
s
.48982 .68148 m .47906 .69229 L .49269 .68365 L .683 .77 .917 r
F
.48982 .68148 m .47333 .68795 L .47906 .69229 L F
.34757 .81439 m .35277 .80614 L .34371 .811 L .644 .733 .913 r
F
.34757 .81439 m .35855 .81122 L .35277 .80614 L F
.57705 .91412 m .57496 .91181 L .5731 .9128 L .692 .759 .904 r
F
.57812 .91378 m .57496 .91181 L .57705 .91412 L F
.45183 .69123 m .45659 .69453 L .45708 .6991 L .981 .69 .34 r
F
.45183 .69123 m .45134 .68666 L .45659 .69453 L F
0 g
.45659 .69453 m
.46074 .69766 L
s
.5795 .91469 m
.58059 .91482 L
s
.57841 .91478 m
.5795 .91469 L
s
.46985 .68273 m .45684 .69443 L .47333 .68795 L .683 .77 .917 r
F
.46985 .68273 m .45161 .6866 L .45684 .69443 L F
.58039 .91366 m .57938 .91082 L .57926 .91363 L .692 .759 .904 r
F
.58039 .91366 m .58165 .91089 L .57938 .91082 L F
.59221 .91576 m .59072 .9116 L .59099 .9138 L .974 .672 .302 r
F
0 g
.59221 .91576 m
.59256 .91791 L
s
.36202 .8207 m .35872 .81117 L .35846 .81495 L .989 .751 .48 r
F
.36176 .82447 m .36202 .8207 L .35846 .81495 L F
0 g
.36202 .8207 m
.36307 .82671 L
s
.57812 .91378 m .5771 .91114 L .57496 .91181 L .692 .759 .904 r
F
.57926 .91363 m .5771 .91114 L .57812 .91378 L F
.57926 .91363 m .57938 .91082 L .5771 .91114 L F
.57566 .91743 m .57192 .91624 L .57098 .91764 L F
.57638 .91682 m .57192 .91624 L .57566 .91743 L F
.255 .45159 m .25566 .4314 L .23127 .43219 L .654 .726 .902 r
F
.4713 .46207 m .48175 .4406 L .48132 .44788 L .067 0 .393 r
F
.47086 .46935 m .4713 .46207 L .48132 .44788 L F
.44446 .4505 m .4713 .46207 L .48132 .44788 L .654 .726 .902 r
F
.43413 .45838 m .4713 .46207 L .44446 .4505 L F
0 g
.46279 .46855 m
.4713 .46207 L
s
.56818 .91504 m .56651 .91495 L .56677 .91715 L .192 .102 .516 r
F
.57166 .91404 m .56792 .91285 L .56651 .91495 L .692 .759 .904 r
F
.56818 .91504 m .56792 .91285 L .56651 .91495 L .192 .102 .516 r
F
0 g
.56597 .91715 m
.56651 .91495 L
s
.76834 .46183 m .76873 .45455 L .76005 .43938 L .991 .743 .451 r
F
0 g
.76873 .45455 m
.77115 .47046 L
s
.58259 .91648 m .584 .91353 L .5817 .91608 L .692 .759 .904 r
F
.58259 .91648 m .58578 .91432 L .584 .91353 L F
.74007 .81195 m .73416 .80499 L .72885 .8071 L .645 .732 .913 r
F
.74313 .81137 m .73416 .80499 L .74007 .81195 L F
.27583 .56905 m .30188 .56464 L .27683 .5651 L .673 .757 .914 r
F
.75258 .81268 m .75324 .80458 L .7496 .81175 L .645 .732 .913 r
F
.75258 .81268 m .7592 .80646 L .75324 .80458 L F
.57287 .91062 m .56987 .90882 L .56771 .91067 L .692 .759 .904 r
F
.57472 .90964 m .56987 .90882 L .57287 .91062 L F
.57192 .91624 m .56677 .91715 L .57098 .91764 L F
.5731 .9128 m .56792 .91285 L .57166 .91404 L F
.31931 .81751 m .31327 .81051 L .30797 .81264 L .644 .733 .913 r
F
.32237 .81692 m .31327 .81051 L .31931 .81751 L F
.33189 .81825 m .33242 .8101 L .32888 .8173 L F
.33189 .81825 m .33843 .81199 L .33242 .8101 L F
.57638 .91682 m .57336 .915 L .57192 .91624 L .692 .759 .904 r
F
.57731 .91632 m .57336 .915 L .57638 .91682 L F
.58345 .90916 m .58262 .90596 L .58137 .90872 L F
.58345 .90916 m .58574 .90662 L .58262 .90596 L F
.30069 .58394 m .3279 .57554 L .30273 .576 L .673 .757 .914 r
F
.27654 .58043 m .30069 .58394 L .30273 .576 L F
.27388 .58416 m .30069 .58394 L .27654 .58043 L F
.5817 .91608 m .58191 .91308 L .58065 .91586 L .692 .759 .904 r
F
.5817 .91608 m .584 .91353 L .58191 .91308 L F
.59072 .9116 m .58844 .90777 L .58871 .90997 L .934 .633 .448 r
F
.59099 .9138 m .59072 .9116 L .58871 .90997 L F
0 g
.59072 .9116 m
.59195 .91356 L
s
.58712 .91541 m .58897 .91217 L .58578 .91432 L .692 .759 .904 r
F
.58712 .91541 m .59099 .9138 L .58897 .91217 L F
.58552 .91213 m .58604 .90878 L .58374 .91133 L F
.58552 .91213 m .58871 .90997 L .58604 .90878 L F
.57009 .91099 m .56765 .91065 L .56792 .91285 L .394 .242 .554 r
F
.57009 .91099 m .56982 .90879 L .56765 .91065 L F
0 g
.56625 .91275 m
.56765 .91065 L
s
.73713 .81675 m .72853 .81082 L .72436 .81375 L .645 .732 .913 r
F
.7398 .81569 m .72853 .81082 L .73713 .81675 L F
.20201 .57783 m .17897 .59011 L .20343 .58571 L .673 .757 .914 r
F
.20201 .57783 m .17682 .57829 L .17897 .59011 L F
0 g
.17897 .59011 m
.18612 .60103 L
s
.75492 .81779 m .75903 .81017 L .75238 .81642 L .645 .732 .913 r
F
.75492 .81779 m .76411 .81291 L .75903 .81017 L F
.57731 .91632 m .57522 .91401 L .57336 .915 L .692 .759 .904 r
F
.57838 .91598 m .57522 .91401 L .57731 .91632 L F
.66265 .55838 m .64935 .57186 L .66132 .5747 L .673 .757 .914 r
F
.58065 .91586 m .57964 .91302 L .57952 .91582 L .692 .759 .904 r
F
.58065 .91586 m .58191 .91308 L .57964 .91302 L F
.74313 .81137 m .74028 .80382 L .73416 .80499 L .645 .732 .913 r
F
.74638 .8113 m .74028 .80382 L .74313 .81137 L F
.73482 .82199 m .72413 .81752 L .72142 .82106 L F
.7369 .82052 m .72413 .81752 L .73482 .82199 L F
.57472 .90964 m .57264 .90734 L .56987 .90882 L .692 .759 .904 r
F
.57685 .90897 m .57264 .90734 L .57472 .90964 L F
.3164 .82234 m .3077 .81641 L .30359 .81934 L .644 .733 .913 r
F
.31905 .82128 m .3077 .81641 L .3164 .82234 L F
.7496 .81175 m .74679 .80368 L .74638 .8113 L .645 .732 .913 r
F
.7496 .81175 m .75324 .80458 L .74679 .80368 L F
.4829 .57628 m .471 .56332 L .4551 .57086 L .673 .757 .914 r
F
.49512 .57302 m .471 .56332 L .4829 .57628 L F
.7566 .82327 m .76388 .81668 L .75469 .82156 L .645 .732 .913 r
F
.7566 .82327 m .7677 .82008 L .76388 .81668 L F
.33418 .82338 m .33816 .81576 L .33162 .82202 L .644 .733 .913 r
F
.33418 .82338 m .34328 .8185 L .33816 .81576 L F
.72413 .81752 m .70937 .81837 L .72142 .82106 L .645 .732 .913 r
F
.57838 .91598 m .57736 .91333 L .57522 .91401 L .692 .759 .904 r
F
.57952 .91582 m .57736 .91333 L .57838 .91598 L F
.52023 .69142 m .53314 .6987 L .53935 .69371 L .683 .77 .917 r
F
.51624 .69343 m .53314 .6987 L .52023 .69142 L F
.57952 .91582 m .57964 .91302 L .57736 .91333 L .692 .759 .904 r
F
.58137 .90872 m .57924 .90586 L .57912 .90865 L F
.58137 .90872 m .58262 .90596 L .57924 .90586 L F
.72885 .8071 m .71406 .80558 L .7247 .81002 L .645 .732 .913 r
F
.57192 .91624 m .56818 .91504 L .56677 .91715 L .692 .759 .904 r
F
0 g
.56623 .91935 m
.56677 .91715 L
s
.32237 .81692 m .31939 .80934 L .31327 .81051 L .644 .733 .913 r
F
.32564 .81685 m .31939 .80934 L .32237 .81692 L F
.71343 .81306 m .70961 .8146 L .70937 .81837 L .092 0 .411 r
F
.72436 .81375 m .71367 .80929 L .70961 .8146 L .645 .732 .913 r
F
.71343 .81306 m .71367 .80929 L .70961 .8146 L .092 0 .411 r
F
0 g
.70801 .82046 m
.70961 .8146 L
s
.77002 .82392 m .77881 .8169 L .7677 .82008 L .645 .732 .913 r
F
.77002 .82392 m .78227 .82265 L .77881 .8169 L F
.32888 .8173 m .32592 .8092 L .32564 .81685 L .644 .733 .913 r
F
.32888 .8173 m .33242 .8101 L .32592 .8092 L F
.74638 .8113 m .74679 .80368 L .74028 .80382 L .645 .732 .913 r
F
.58871 .90997 m .58844 .90777 L .58578 .90659 L .861 .577 .507 r
F
0 g
.58844 .90777 m
.59046 .9094 L
s
.76806 .81257 m .77339 .80432 L .76425 .80918 L .645 .732 .913 r
F
.76806 .81257 m .7791 .8094 L .77339 .80432 L F
.36308 .43607 m .34516 .45372 L .36793 .44054 L .654 .726 .902 r
F
.36308 .43607 m .33546 .4448 L .34516 .45372 L F
.2269 .57169 m .20315 .58003 L .22761 .57563 L .673 .757 .914 r
F
.2269 .57169 m .20172 .57215 L .20315 .58003 L F
.57685 .90897 m .57584 .90633 L .57264 .90734 L .692 .759 .904 r
F
.57912 .90865 m .57584 .90633 L .57685 .90897 L F
.5731 .9128 m .57009 .91099 L .56792 .91285 L F
.57496 .91181 m .57009 .91099 L .5731 .9128 L F
.30797 .81264 m .2931 .81111 L .30385 .81557 L .644 .733 .913 r
F
.30359 .81934 m .29283 .81488 L .28886 .82019 L F
0 g
.28736 .82605 m
.28886 .82019 L
s
.57912 .90865 m .57924 .90586 L .57584 .90633 L .692 .759 .904 r
F
.78251 .81888 m .77927 .80935 L .77904 .81312 L .991 .751 .471 r
F
.78227 .82265 m .78251 .81888 L .77904 .81312 L F
0 g
.78251 .81888 m
.78346 .82489 L
s
.32564 .81685 m .32592 .8092 L .31939 .80934 L .644 .733 .913 r
F
.69332 .44887 m .69491 .42737 L .68587 .44646 L .654 .726 .902 r
F
.69332 .44887 m .70982 .4322 L .69491 .42737 L F
.57336 .915 m .56818 .91504 L .57192 .91624 L .692 .759 .904 r
F
.5382 .68451 m .56016 .68085 L .54222 .6789 L .683 .77 .917 r
F
.52227 .67976 m .5382 .68451 L .54222 .6789 L F
.41243 .44287 m .43413 .45838 L .44446 .4505 L .654 .726 .902 r
F
.40579 .44575 m .43413 .45838 L .41243 .44287 L F
.34742 .81813 m .35265 .80984 L .34354 .81473 L .644 .733 .913 r
F
.34742 .81813 m .35846 .81495 L .35265 .80984 L F
.45546 .58207 m .44271 .5861 L .44302 .59178 L .387 .234 .548 r
F
.45546 .58207 m .45515 .57639 L .44271 .5861 L F
0 g
.43467 .5973 m
.44271 .5861 L
s
.58374 .91133 m .5829 .90811 L .58165 .91089 L .692 .759 .904 r
F
.58374 .91133 m .58604 .90878 L .5829 .90811 L F
.36176 .82447 m .35846 .81495 L .3582 .81872 L .989 .751 .48 r
F
0 g
.36176 .82447 m
.36281 .83048 L
s
.49023 .68608 m .47941 .69695 L .49311 .68826 L .683 .77 .917 r
F
.49023 .68608 m .47365 .69259 L .47941 .69695 L F
.45232 .69581 m .45708 .6991 L .45757 .70367 L .981 .69 .34 r
F
.45232 .69581 m .45183 .69123 L .45708 .6991 L F
.47015 .68735 m .45708 .6991 L .47365 .69259 L .683 .77 .917 r
F
.47015 .68735 m .45183 .69123 L .45708 .6991 L F
0 g
.45708 .6991 m
.46123 .70224 L
s
.59099 .9138 m .58871 .90997 L .58897 .91217 L .934 .633 .448 r
F
0 g
.59099 .9138 m
.59221 .91576 L
s
.58578 .91432 m .5863 .91098 L .584 .91353 L .692 .759 .904 r
F
.58578 .91432 m .58897 .91217 L .5863 .91098 L F
.47276 .59255 m .45546 .58207 L .44302 .59178 L .673 .758 .914 r
F
0 g
.43498 .60298 m
.44302 .59178 L
s
.48341 .5875 m .45546 .58207 L .47276 .59255 L .673 .758 .914 r
F
.57035 .91319 m .56792 .91285 L .56818 .91504 L .394 .242 .554 r
F
.57035 .91319 m .57009 .91099 L .56792 .91285 L F
0 g
.56651 .91495 m
.56792 .91285 L
s
.7398 .81569 m .73387 .80869 L .72853 .81082 L .645 .732 .913 r
F
.74288 .8151 m .73387 .80869 L .7398 .81569 L F
.63185 .56667 m .62115 .58401 L .63952 .57287 L .673 .758 .914 r
F
.63185 .56667 m .60965 .57472 L .62115 .58401 L F
0 g
.62115 .58401 m
.63639 .59101 L
s
.53342 .58091 m .52867 .56318 L .52144 .57807 L .673 .757 .914 r
F
.53342 .58091 m .54667 .56743 L .52867 .56318 L F
.66897 .56548 m .66165 .58037 L .67462 .58118 L .673 .758 .914 r
F
.75238 .81642 m .75304 .80828 L .74939 .81548 L .645 .732 .913 r
F
.75238 .81642 m .75903 .81017 L .75304 .80828 L F
.57496 .91181 m .57287 .9095 L .57009 .91099 L .692 .759 .904 r
F
.5771 .91114 m .57287 .9095 L .57496 .91181 L F
.64927 .46853 m .62249 .45696 L .61576 .46642 L .654 .726 .902 r
F
.65446 .46459 m .62249 .45696 L .64927 .46853 L F
.31905 .82128 m .313 .81428 L .3077 .81641 L .644 .733 .913 r
F
.32211 .82069 m .313 .81428 L .31905 .82128 L F
.74007 .56666 m .73973 .56099 L .74791 .54977 L .176 .079 .499 r
F
0 g
.73266 .56647 m
.73973 .56099 L
s
.33162 .82202 m .33215 .81388 L .32862 .82107 L .644 .733 .913 r
F
.33162 .82202 m .33816 .81576 L .33215 .81388 L F
.57287 .9095 m .56982 .90879 L .57009 .91099 L .515 .327 .565 r
F
.57287 .9095 m .57261 .9073 L .56982 .90879 L F
0 g
.56765 .91065 m
.56982 .90879 L
s
.65487 .45731 m .63329 .44179 L .6229 .44968 L .654 .726 .902 r
F
.66154 .45442 m .63329 .44179 L .65487 .45731 L F
.70375 .47138 m .72191 .45374 L .69896 .46692 L F
.70375 .47138 m .7315 .46266 L .72191 .45374 L F
.58165 .91089 m .57951 .90801 L .57938 .91082 L .692 .759 .904 r
F
.58165 .91089 m .5829 .90811 L .57951 .90801 L F
.20773 .44407 m .18836 .44544 L .18788 .45272 L .49 .282 .525 r
F
.20773 .44407 m .2082 .43678 L .18836 .44544 L F
0 g
.17298 .45725 m
.18836 .44544 L
s
.71816 .55366 m .73941 .56088 L .74755 .54972 L .673 .757 .914 r
F
.70985 .56011 m .73941 .56088 L .71816 .55366 L F
.69936 .45963 m .70959 .43932 L .693 .45607 L .654 .726 .902 r
F
.69936 .45963 m .72231 .44645 L .70959 .43932 L F
.3276 .56986 m .3273 .56418 L .32522 .55235 L .838 .633 .087 r
F
0 g
.32584 .56989 m
.327 .56539 L
s
.30188 .56464 m .32693 .56419 L .32485 .55241 L .673 .757 .914 r
F
.62249 .45696 m .5856 .45958 L .61576 .46642 L .654 .726 .902 r
F
.58871 .90997 m .58578 .90659 L .58604 .90878 L .861 .577 .507 r
F
.58897 .91217 m .58871 .90997 L .58604 .90878 L F
0 g
.58871 .90997 m
.59072 .9116 L
s
.57336 .915 m .57035 .91319 L .56818 .91504 L .692 .759 .904 r
F
.127 .923 .03 r
.56818 .96053 m
.56916 .85593 L
s
.56574 .95439 m
.56863 .81718 L
s
0 g
.56677 .91715 m
.56818 .91504 L
s
.57522 .91401 m .57035 .91319 L .57336 .915 L .692 .759 .904 r
F
.5771 .91114 m .57608 .90849 L .57287 .9095 L F
.57938 .91082 m .57608 .90849 L .5771 .91114 L F
.7369 .82052 m .72829 .81459 L .72413 .81752 L .645 .732 .913 r
F
.73957 .81946 m .72829 .81459 L .7369 .82052 L F
.57938 .91082 m .57951 .90801 L .57608 .90849 L .692 .759 .904 r
F
0 g
.3026 .44172 m
.30764 .44453 L
s
.75469 .82156 m .7588 .81394 L .75215 .8202 L .645 .732 .913 r
F
.75469 .82156 m .76388 .81668 L .7588 .81394 L F
.22244 .46974 m .20726 .45135 L .18741 .46 L .654 .726 .902 r
F
.23774 .46648 m .20726 .45135 L .22244 .46974 L F
.682 .56524 m .6877 .5799 L .70001 .57662 L .673 .758 .914 r
F
.23821 .4592 m .23069 .43917 L .20773 .44407 L .654 .726 .902 r
F
.25454 .45867 m .23069 .43917 L .23821 .4592 L F
.68782 .55792 m .69967 .57095 L .71036 .56589 L .673 .757 .914 r
F
.58604 .90878 m .58578 .90659 L .58264 .90592 L .793 .527 .535 r
F
0 g
.58578 .90659 m
.58844 .90777 L
s
.7373 .47277 m .75926 .45395 L .7315 .46266 L .654 .726 .902 r
F
.7373 .47277 m .76795 .46912 L .75926 .45395 L F
.27078 .4609 m .2552 .43838 L .25454 .45867 L F
.27078 .4609 m .27957 .44173 L .2552 .43838 L F
.127 .923 .03 r
.58895 .41577 m
.58908 .40996 L
s
.52104 .57255 m .50887 .55652 L .50813 .57174 L .673 .757 .914 r
F
.52104 .57255 m .52825 .55772 L .50887 .55652 L F
.30832 .80893 m .29966 .80302 L .29352 .8074 L .644 .733 .913 r
F
.31359 .80681 m .29966 .80302 L .30832 .80893 L F
.74288 .8151 m .74002 .80752 L .73387 .80869 L .645 .732 .913 r
F
.74615 .81503 m .74002 .80752 L .74288 .8151 L F
.584 .91353 m .58316 .91031 L .58191 .91308 L .692 .759 .904 r
F
.584 .91353 m .5863 .91098 L .58316 .91031 L F
.28535 .47303 m .27911 .44902 L .27031 .46819 L .654 .726 .902 r
F
.28535 .47303 m .30168 .45629 L .27911 .44902 L F
.74939 .81548 m .74656 .80738 L .74615 .81503 L .645 .732 .913 r
F
.74939 .81548 m .75304 .80828 L .74656 .80738 L F
.27624 .57475 m .30243 .57032 L .27726 .57078 L .673 .757 .914 r
F
.34371 .811 m .34513 .80205 L .33862 .80828 L .644 .733 .913 r
F
.34371 .811 m .35277 .80614 L .34513 .80205 L F
.56093 .68545 m .56043 .68088 L .5628 .672 L 0 0 .391 r
F
0 g
.55664 .68616 m
.56043 .68088 L
s
.72853 .81082 m .71367 .80929 L .72436 .81375 L .645 .732 .913 r
F
.32211 .82069 m .31913 .81311 L .313 .81428 L .644 .733 .913 r
F
.32537 .82062 m .31913 .81311 L .32211 .82069 L F
.72413 .81752 m .71343 .81306 L .70937 .81837 L .645 .732 .913 r
F
0 g
.70778 .82423 m
.70937 .81837 L
s
.32862 .82107 m .32566 .81297 L .32537 .82062 L .644 .733 .913 r
F
.32862 .82107 m .33215 .81388 L .32566 .81297 L F
.54222 .6789 m .56016 .68085 L .56252 .67202 L .683 .77 .917 r
F
.74615 .81503 m .74656 .80738 L .74002 .80752 L .645 .732 .913 r
F
.76794 .81631 m .7733 .80802 L .76411 .81291 L F
.76794 .81631 m .77904 .81312 L .7733 .80802 L F
.3077 .81641 m .29283 .81488 L .30359 .81934 L .644 .733 .913 r
F
.57522 .91401 m .57313 .9117 L .57035 .91319 L .692 .759 .904 r
F
.57736 .91333 m .57313 .9117 L .57522 .91401 L F
.78227 .82265 m .77904 .81312 L .77881 .8169 L .991 .751 .471 r
F
0 g
.78227 .82265 m
.78323 .82866 L
s
.32537 .82062 m .32566 .81297 L .31913 .81311 L .644 .733 .913 r
F
.30188 .56464 m .32485 .55241 L .30049 .55679 L .673 .757 .914 r
F
.27683 .5651 m .30188 .56464 L .30049 .55679 L F
.68587 .44646 m .67876 .42515 L .6778 .44535 L .654 .726 .902 r
F
.68587 .44646 m .69491 .42737 L .67876 .42515 L F
.34716 .8219 m .35239 .81361 L .34328 .8185 L .644 .733 .913 r
F
.34716 .8219 m .3582 .81872 L .35239 .81361 L F
.57608 .90849 m .57261 .9073 L .57287 .9095 L .6 .388 .565 r
F
.57608 .90849 m .57582 .90629 L .57261 .9073 L F
0 g
.56982 .90879 m
.57261 .9073 L
s
.57313 .9117 m .57009 .91099 L .57035 .91319 L .515 .327 .565 r
F
0 g
.56818 .91504 m
.57035 .91319 L
s
.57313 .9117 m .57287 .9095 L .57009 .91099 L .515 .327 .565 r
F
0 g
.56792 .91285 m
.57009 .91099 L
s
.127 .923 .03 r
.56939 .98587 m
.57102 .81617 L
s
.29927 .8067 m .29336 .80734 L .2931 .81111 L .349 .175 .499 r
F
.127 .923 .03 r
.31602 .98224 m
.33454 1.19771 L
s
.29927 .8067 m .29953 .80293 L .29336 .80734 L .349 .175 .499 r
F
0 g
.28939 .81265 m
.29336 .80734 L
s
.59569 .44539 m .58602 .45229 L .5856 .45958 L .071 0 .396 r
F
0 g
.58211 .46787 m
.58602 .45229 L
s
.58191 .91308 m .57977 .91021 L .57964 .91302 L .692 .759 .904 r
F
.58191 .91308 m .58316 .91031 L .57977 .91021 L F
.53886 .68913 m .56093 .68545 L .54289 .68349 L .683 .77 .917 r
F
.52284 .68435 m .53886 .68913 L .54289 .68349 L F
.66298 .56406 m .66165 .58037 L .66897 .56548 L .673 .758 .914 r
F
.66298 .56406 m .64968 .57754 L .66165 .58037 L F
.58897 .91217 m .58604 .90878 L .5863 .91098 L .861 .577 .507 r
F
0 g
.58897 .91217 m
.59099 .9138 L
s
.5829 .90811 m .58264 .90592 L .57924 .90582 L .731 .482 .551 r
F
.58604 .90878 m .58264 .90592 L .5829 .90811 L .793 .527 .535 r
F
0 g
.58264 .90592 m
.58578 .90659 L
s
.49512 .57302 m .48934 .55843 L .471 .56332 L .673 .757 .914 r
F
.50813 .57174 m .48934 .55843 L .49512 .57302 L F
.35846 .81495 m .35872 .81117 L .35291 .80607 L .925 .676 .544 r
F
0 g
.35872 .81117 m
.36228 .81693 L
s
.57736 .91333 m .57635 .91068 L .57313 .9117 L .692 .759 .904 r
F
.57964 .91302 m .57635 .91068 L .57736 .91333 L F
.57964 .91302 m .57977 .91021 L .57635 .91068 L F
.49072 .69066 m .4799 .70152 L .4936 .69284 L .683 .77 .917 r
F
.49072 .69066 m .47414 .69717 L .4799 .70152 L F
.48309 .58183 m .47113 .56881 L .45515 .57639 L .673 .757 .914 r
F
.49538 .57855 m .47113 .56881 L .48309 .58183 L F
.73957 .81946 m .73363 .81246 L .72829 .81459 L .645 .732 .913 r
F
.74265 .81887 m .73363 .81246 L .73957 .81946 L F
.47086 .46935 m .48132 .44788 L .48089 .45517 L .067 0 .393 r
F
.44402 .45778 m .47086 .46935 L .48089 .45517 L .654 .726 .902 r
F
.43369 .46566 m .47086 .46935 L .44402 .45778 L F
0 g
.45536 .48116 m
.47086 .46935 L
s
.5863 .91098 m .58604 .90878 L .5829 .90811 L .793 .527 .535 r
F
0 g
.58604 .90878 m
.58871 .90997 L
s
.75215 .8202 m .75281 .81205 L .74916 .81925 L .645 .732 .913 r
F
.75215 .8202 m .7588 .81394 L .75281 .81205 L F
.76834 .46183 m .76005 .43938 L .75966 .44666 L .991 .743 .451 r
F
.76795 .46912 m .76834 .46183 L .75966 .44666 L F
0 g
.76834 .46183 m
.77076 .47774 L
s
.47064 .69192 m .45757 .70367 L .47414 .69717 L .683 .77 .917 r
F
.47064 .69192 m .45232 .69581 L .45757 .70367 L F
0 g
.45757 .70367 m
.46621 .7102 L
s
.25454 .45867 m .2552 .43838 L .23069 .43917 L .654 .726 .902 r
F
.22719 .57737 m .20343 .58571 L .2279 .58131 L .673 .757 .914 r
F
.22719 .57737 m .20201 .57783 L .20343 .58571 L F
.57951 .90801 m .57582 .90629 L .57608 .90849 L .669 .437 .561 r
F
.57951 .90801 m .57924 .90582 L .57582 .90629 L F
0 g
.57261 .9073 m
.57582 .90629 L
s
.73201 .44818 m .74533 .42617 L .72248 .4393 L .654 .726 .902 r
F
.73201 .44818 m .75963 .43951 L .74533 .42617 L F
.5829 .90811 m .57924 .90582 L .57951 .90801 L .731 .482 .551 r
F
0 g
.57582 .90629 m
.57924 .90582 L
s
.57924 .90582 m
.58264 .90592 L
s
.27683 .5651 m .30049 .55679 L .27614 .56118 L .673 .757 .914 r
F
.50813 .57174 m .50887 .55652 L .48934 .55843 L F
.72885 .8071 m .72028 .8012 L .71406 .80558 L .645 .732 .913 r
F
.73416 .80499 m .72028 .8012 L .72885 .8071 L F
.65757 .55604 m .64935 .57186 L .66265 .55838 L .673 .757 .914 r
F
.65757 .55604 m .63919 .56719 L .64935 .57186 L F
.56194 .57444 m .56162 .56876 L .54634 .56175 L .86 .596 .539 r
F
0 g
.56162 .56876 m
.57313 .57805 L
s
.76425 .80918 m .76581 .80023 L .7592 .80646 L .645 .732 .913 r
F
.76425 .80918 m .77339 .80432 L .76581 .80023 L F
.57635 .91068 m .57287 .9095 L .57313 .9117 L .6 .388 .565 r
F
.57635 .91068 m .57608 .90849 L .57287 .9095 L F
0 g
.57009 .91099 m
.57287 .9095 L
s
.57035 .91319 m
.57313 .9117 L
s
.74265 .81887 m .73978 .81129 L .73363 .81246 L .645 .732 .913 r
F
.74592 .8188 m .73978 .81129 L .74265 .81887 L F
.74916 .81925 m .74633 .81115 L .74592 .8188 L F
.74916 .81925 m .75281 .81205 L .74633 .81115 L F
.30797 .81264 m .29927 .8067 L .2931 .81111 L .644 .733 .913 r
F
.31327 .81051 m .29927 .8067 L .30797 .81264 L F
.53374 .58659 m .52899 .56886 L .52175 .58375 L .673 .758 .914 r
F
.53374 .58659 m .54699 .57311 L .52899 .56886 L F
.69275 .54966 m .70985 .56011 L .71816 .55366 L .673 .757 .914 r
F
.34354 .81473 m .34497 .80573 L .33843 .81199 L .644 .733 .913 r
F
.34354 .81473 m .35265 .80984 L .34497 .80573 L F
.72829 .81459 m .71343 .81306 L .72413 .81752 L .645 .732 .913 r
F
.58316 .91031 m .5829 .90811 L .57951 .90801 L .731 .482 .551 r
F
.5863 .91098 m .5829 .90811 L .58316 .91031 L .793 .527 .535 r
F
0 g
.5829 .90811 m
.58604 .90878 L
s
.5863 .91098 m
.58897 .91217 L
s
.48808 .67887 m .47333 .68795 L .48982 .68148 L .683 .77 .917 r
F
.48808 .67887 m .46985 .68273 L .47333 .68795 L F
.74592 .8188 m .74633 .81115 L .73978 .81129 L .645 .732 .913 r
F
.74007 .56666 m .74791 .54977 L .74825 .55545 L .176 .079 .499 r
F
.74042 .57234 m .74007 .56666 L .74825 .55545 L F
.71872 .55941 m .74007 .56666 L .74825 .55545 L .673 .757 .914 r
F
.71036 .56589 m .74007 .56666 L .71872 .55941 L F
0 g
.733 .57215 m
.74007 .56666 L
s
.7677 .82008 m .77307 .81179 L .76388 .81668 L .645 .732 .913 r
F
.7677 .82008 m .77881 .8169 L .77307 .81179 L F
.71992 .80488 m .7139 .80551 L .71367 .80929 L .356 .182 .503 r
F
.71992 .80488 m .72015 .80111 L .7139 .80551 L F
0 g
.70984 .81083 m
.7139 .80551 L
s
.25179 .56556 m .23976 .55259 L .23448 .55511 L .673 .757 .914 r
F
.25179 .56556 m .24586 .55096 L .23976 .55259 L F
.25179 .56556 m .25237 .55032 L .24586 .55096 L F
0 g
.24918 .56811 m
.24919 .56518 L
s
.56093 .68545 m .5628 .672 L .5633 .67658 L 0 0 .391 r
F
.56142 .69002 m .56093 .68545 L .5633 .67658 L F
.54289 .68349 m .56093 .68545 L .5633 .67658 L .683 .77 .917 r
F
0 g
.55714 .69074 m
.56093 .68545 L
s
.3276 .56986 m .32522 .55235 L .32552 .55802 L .838 .633 .087 r
F
.30243 .57032 m .3276 .56986 L .32552 .55802 L .673 .757 .914 r
F
.3279 .57554 m .3276 .56986 L .32552 .55802 L .838 .633 .087 r
F
0 g
.32614 .57557 m
.3273 .57106 L
s
.36263 .44336 m .34471 .46101 L .36748 .44782 L .654 .726 .902 r
F
.36263 .44336 m .33501 .45208 L .34471 .46101 L F
.57977 .91021 m .57608 .90849 L .57635 .91068 L .669 .437 .561 r
F
.57977 .91021 m .57951 .90801 L .57608 .90849 L F
0 g
.57287 .9095 m
.57608 .90849 L
s
.299 .81048 m .2931 .81111 L .29283 .81488 L .349 .175 .499 r
F
.299 .81048 m .29927 .8067 L .2931 .81111 L F
0 g
.28913 .81642 m
.2931 .81111 L
s
.31359 .80681 m .30757 .79985 L .29966 .80302 L .644 .733 .913 r
F
.31968 .80564 m .30757 .79985 L .31359 .80681 L F
.58316 .91031 m .57951 .90801 L .57977 .91021 L .731 .482 .551 r
F
0 g
.57608 .90849 m
.57951 .90801 L
s
.57951 .90801 m
.5829 .90811 L
s
.58316 .91031 m
.5863 .91098 L
s
.77904 .81312 m .77927 .80935 L .77353 .80425 L .927 .677 .54 r
F
0 g
.77927 .80935 m
.78274 .81511 L
s
.66154 .45442 m .64662 .43602 L .63329 .44179 L .654 .726 .902 r
F
.66922 .45279 m .64662 .43602 L .66154 .45442 L F
.33862 .80828 m .33616 .79924 L .33264 .8064 L .644 .733 .913 r
F
.33862 .80828 m .34513 .80205 L .33616 .79924 L F
.68816 .5636 m .70001 .57662 L .7107 .57157 L .673 .758 .914 r
F
.682 .56524 m .70001 .57662 L .68816 .5636 L F
.41199 .45015 m .43369 .46566 L .44402 .45778 L .654 .726 .902 r
F
.40535 .45304 m .43369 .46566 L .41199 .45015 L F
.693 .45607 m .6946 .43446 L .68551 .45365 L F
.693 .45607 m .70959 .43932 L .6946 .43446 L F
.36072 .42371 m .33619 .43743 L .36367 .42875 L F
.36072 .42371 m .33028 .42736 L .33619 .43743 L F
.35846 .81495 m .35291 .80607 L .35265 .80984 L .925 .676 .544 r
F
.3582 .81872 m .35846 .81495 L .35265 .80984 L F
0 g
.35846 .81495 m
.36202 .8207 L
s
.27654 .58043 m .30273 .576 L .27755 .57645 L .673 .757 .914 r
F
.39245 .42353 m .39041 .44027 L .39118 .44024 L .654 .726 .902 r
F
.3933 .42583 m .39118 .44024 L .39854 .44 L F
.39245 .42353 m .39118 .44024 L .3933 .42583 L F
.38977 .43735 m .38971 .4345 L .39462 .4341 L .665 .424 .546 r
F
.39136 .43972 m .38996 .44765 L .39112 .44761 L .654 .726 .902 r
F
.38987 .43026 m .38971 .43444 L .3946 .43404 L .675 .735 .895 r
F
.38977 .43735 m .39462 .4341 L .39467 .43694 L .665 .424 .546 r
F
.38992 .43315 m .38977 .43735 L .39467 .43694 L .675 .735 .895 r
F
.39166 .42989 m .39071 .43974 L .39136 .43972 L .654 .726 .902 r
F
.39071 .43974 m .38996 .44765 L .39136 .43972 L F
.39049 .43974 m .38977 .43735 L .39467 .43694 L .665 .424 .546 r
F
.38867 .40971 m .39024 .40998 L .39021 .42297 L .751 .491 .538 r
F
.38702 .40864 m .38768 .40924 L .38765 .42217 L .929 .648 .488 r
F
.38658 .40712 m .38664 .40794 L .3866 .42089 L .79 .631 .071 r
F
.38743 .43278 m .38233 .43915 L .38792 .43992 L .654 .726 .902 r
F
.38992 .42684 m .38731 .43108 L .39085 .4285 L F
.38731 .43108 m .38233 .43915 L .38743 .43278 L F
.38731 .43108 m .38743 .43278 L .39085 .4285 L F
.39052 .42473 m .38962 .4263 L .39097 .42514 L F
.38962 .4263 m .38233 .43915 L .38992 .42684 L F
.38962 .4263 m .38992 .42684 L .39097 .42514 L F
.39074 .4237 m .39029 .42453 L .39102 .42384 L F
.39029 .42453 m .38233 .43915 L .39052 .42473 L F
.39029 .42453 m .39052 .42473 L .39102 .42384 L F
.39094 .42311 m .39065 .42365 L .39105 .42313 L F
.39065 .42365 m .38233 .43915 L .39074 .4237 L F
.39065 .42365 m .39074 .4237 L .39105 .42313 L F
.3898 .423 m .38233 .43915 L .39094 .42311 L F
.39021 .42297 m .39094 .42311 L .39106 .42289 L F
.3898 .423 m .39094 .42311 L .39021 .42297 L F
.39116 .42006 m .38081 .43065 L .38233 .43915 L F
.38081 .43065 m .37486 .43674 L .3771 .43747 L F
.38081 .43065 m .3771 .43747 L .38233 .43915 L F
.38664 .40794 m .38669 .42104 L .3866 .42089 L .989 .72 .388 r
F
.38658 .40712 m .38656 .42028 L .38655 .42011 L .79 .631 .071 r
F
.38658 .40712 m .3866 .42089 L .38656 .42028 L F
.38664 .40794 m .38702 .40864 L .38698 .42158 L .989 .72 .388 r
F
.38711 .40608 m .38658 .40712 L .38655 .42011 L 0 0 .372 r
F
.38081 .43065 m .36849 .43319 L .37486 .43674 L .654 .726 .902 r
F
.39116 .42006 m .38446 .42394 L .38081 .43065 L F
.38446 .42394 m .36849 .43319 L .38081 .43065 L F
.38743 .43278 m .38792 .43992 L .39041 .44027 L F
.39085 .4285 m .38743 .43278 L .39041 .44027 L F
.38981 .43977 m .38977 .43735 L .39049 .43974 L .665 .424 .546 r
F
.38709 .43939 m .38184 .44653 L .39025 .43983 L .654 .726 .902 r
F
.38494 .43974 m .38595 .43924 L .38982 .44019 L .731 .477 .544 r
F
.38595 .43924 m .38977 .43735 L .38981 .43977 L F
.38595 .43924 m .38981 .43977 L .38982 .44019 L F
.39025 .43983 m .38184 .44653 L .38996 .44765 L .654 .726 .902 r
F
.39044 .43484 m .38709 .43939 L .39025 .43983 L F
.39008 .42446 m .3884 .42592 L .39002 .42607 L .675 .735 .895 r
F
.38899 .42273 m .39021 .42297 L .39021 .42448 L .751 .491 .538 r
F
.38899 .42273 m .39021 .42448 L .38925 .42433 L F
.39018 .42189 m .38911 .42431 L .39008 .42446 L .675 .735 .895 r
F
.38911 .42431 m .3884 .42592 L .39008 .42446 L F
.3884 .42592 m .38987 .43026 L .39002 .42607 L F
.39014 .42729 m .38845 .42879 L .39008 .42894 L F
.38925 .42433 m .3902 .4273 L .38973 .42722 L .751 .491 .538 r
F
.39023 .42474 m .38918 .42714 L .39014 .42729 L .675 .735 .895 r
F
.38918 .42714 m .38845 .42879 L .39014 .42729 L F
.38925 .42433 m .39021 .42448 L .3902 .4273 L .751 .491 .538 r
F
.39097 .42514 m .38992 .42684 L .39085 .4285 L .654 .726 .902 r
F
.39209 .42406 m .39041 .44027 L .39245 .42353 L F
.39216 .42293 m .39041 .44027 L .39221 .42289 L F
.3918 .42282 m .39041 .44027 L .39217 .42279 L F
.39106 .42289 m .39105 .42311 L .3918 .42282 L F
.39105 .42311 m .39041 .44027 L .3918 .42282 L F
.39002 .42607 m .39312 .42999 L .39165 .42594 L .675 .735 .895 r
F
.39206 .42696 m .39171 .42881 L .39325 .4284 L F
.39105 .42313 m .39074 .4237 L .39102 .42384 L .654 .726 .902 r
F
.39106 .42289 m .39094 .42311 L .39105 .42313 L F
.39209 .42422 m .39165 .42594 L .39318 .42553 L .675 .735 .895 r
F
.39057 .42293 m .3918 .42282 L .3918 .42426 L .641 .4 .539 r
F
.39057 .42293 m .3918 .42426 L .39099 .42437 L F
.39018 .42189 m .39108 .42436 L .39209 .42422 L .675 .735 .895 r
F
.39108 .42436 m .39165 .42594 L .39209 .42422 L F
.39099 .42437 m .3918 .42426 L .39179 .42707 L .641 .4 .539 r
F
.39112 .42717 m .39118 .42734 L .39179 .42707 L .675 .735 .895 r
F
.39118 .42734 m .39171 .42881 L .39206 .42696 L F
.39002 .42607 m .38987 .43026 L .39312 .42999 L F
.39112 .42717 m .39008 .42894 L .39171 .42881 L F
.39021 .42448 m .39035 .42727 L .3902 .4273 L .641 .4 .539 r
F
.39021 .42297 m .39026 .42447 L .39021 .42448 L F
.39102 .42384 m .39052 .42473 L .39097 .42514 L .654 .726 .902 r
F
.39008 .4245 m .39002 .42607 L .39108 .42436 L .675 .735 .895 r
F
.39026 .42447 m .39035 .42727 L .39021 .42448 L .641 .4 .539 r
F
.39108 .42436 m .39002 .42607 L .39165 .42594 L .675 .735 .895 r
F
.39014 .4273 m .39008 .42894 L .39112 .42717 L F
.39008 .42894 m .38992 .43315 L .39319 .43288 L F
.39062 .42998 m .38996 .44765 L .39166 .42989 L .654 .726 .902 r
F
.39057 .42293 m .39074 .42997 L .39021 .42297 L .641 .4 .539 r
F
.39136 .43972 m .39112 .44761 L .39228 .43969 L .654 .726 .902 r
F
.38982 .44019 m .39049 .43974 L .39473 .43979 L .665 .424 .546 r
F
.39228 .43969 m .39112 .44761 L .39525 .43959 L .654 .726 .902 r
F
.3912 .43714 m .38951 .45493 L .39107 .45488 L F
.39297 .44193 m .39107 .45488 L .39768 .45467 L F
.38982 .44019 m .38981 .43977 L .39049 .43974 L .665 .424 .546 r
F
.38992 .43315 m .39467 .43694 L .39319 .43288 L .675 .735 .895 r
F
.38987 .43026 m .3946 .43404 L .39312 .42999 L F
.39008 .42894 m .39319 .43288 L .39171 .42881 L F
.39167 .42992 m .39136 .43972 L .39313 .43388 L .654 .726 .902 r
F
.39049 .43974 m .39467 .43694 L .39473 .43961 L .665 .424 .546 r
F
.39049 .43974 m .39473 .43961 L .39473 .43979 L F
.38998 .43599 m .38982 .44019 L .39228 .43999 L .675 .735 .895 r
F
.39313 .43388 m .39228 .43969 L .39525 .43959 L .654 .726 .902 r
F
.39255 .43805 m .39228 .43999 L .39473 .43979 L .675 .735 .895 r
F
.38998 .43599 m .39228 .43999 L .39255 .43805 L F
.39386 .42199 m .40616 .43838 L .41277 .43551 L .654 .726 .902 r
F
.39286 .40933 m .39299 .42232 L .39283 .42244 L .354 .175 .495 r
F
.39116 .42006 m .39369 .42315 L .39386 .42199 L .654 .726 .902 r
F
.3933 .42583 m .39854 .44 L .39369 .42315 L F
.39525 .43959 m .39112 .44761 L .39813 .44738 L F
.39397 .42127 m .41277 .43551 L .4179 .43158 L F
.39116 .42006 m .39361 .42181 L .39397 .42127 L F
.39361 .42181 m .41277 .43551 L .39397 .42127 L F
.39357 .40876 m .394 .40807 L .39397 .42127 L .069 0 .411 r
F
.39369 .42315 m .39854 .44 L .40236 .43919 L .654 .726 .902 r
F
.39369 .42315 m .3971 .42731 L .39386 .42199 L F
.39354 .42322 m .3945 .42487 L .39553 .42401 L .675 .735 .895 r
F
.39304 .42236 m .3933 .42583 L .39369 .42315 L .654 .726 .902 r
F
.39183 .40977 m .39283 .42244 L .39203 .42274 L .515 .301 .526 r
F
.39116 .42006 m .39214 .4227 L .39304 .42236 L .654 .726 .902 r
F
.39214 .4227 m .3933 .42583 L .39304 .42236 L F
.39183 .40977 m .39286 .40933 L .39283 .42244 L .515 .301 .526 r
F
.39217 .42279 m .39216 .42293 L .39221 .42289 L .654 .726 .902 r
F
.39203 .42274 m .39283 .42244 L .39282 .42381 L .515 .301 .526 r
F
.39221 .42289 m .39209 .42406 L .39245 .42353 L .654 .726 .902 r
F
.39018 .42189 m .39291 .42377 L .39354 .42322 L .675 .735 .895 r
F
.39291 .42377 m .3931 .42391 L .3933 .4236 L F
.3949 .42091 m .4179 .43158 L .42122 .42687 L .654 .726 .902 r
F
.39286 .40933 m .39353 .42191 L .39347 .42196 L .354 .175 .495 r
F
.39116 .42006 m .39425 .42139 L .3949 .42091 L .654 .726 .902 r
F
.39425 .42139 m .4179 .43158 L .3949 .42091 L F
.39286 .40933 m .39357 .40876 L .39353 .42191 L .354 .175 .495 r
F
.39347 .42196 m .39353 .42191 L .39353 .42324 L F
.39291 .42377 m .3933 .4236 L .39353 .42324 L .675 .735 .895 r
F
.39291 .42377 m .39353 .42324 L .39343 .42332 L F
.39396 .42259 m .39553 .42401 L .39619 .42301 L F
.39018 .42189 m .39385 .42335 L .39396 .42259 L F
.39385 .42335 m .39553 .42401 L .39396 .42259 L F
.39369 .42315 m .40236 .43919 L .3971 .42731 L .654 .726 .902 r
F
.39318 .42553 m .39618 .42917 L .39883 .42786 L .675 .735 .895 r
F
.39384 .42617 m .39458 .42774 L .39561 .42687 L F
.39203 .42274 m .39282 .42381 L .39205 .42415 L .515 .301 .526 r
F
.39018 .42189 m .39318 .42553 L .3945 .42487 L .675 .735 .895 r
F
.39205 .42415 m .39282 .42381 L .39282 .42663 L .515 .301 .526 r
F
.3931 .42391 m .3945 .42487 L .39354 .42322 L .675 .735 .895 r
F
.39398 .42522 m .39397 .4253 L .39397 .42253 L 0 0 .133 r
F
.39397 .42251 m .39397 .42253 L .39397 .42127 L F
.39398 .42521 m .39397 .42253 L .39397 .42251 L F
.39318 .42553 m .39883 .42786 L .3945 .42487 L .675 .735 .895 r
F
.39449 .42553 m .39561 .42687 L .39628 .42586 L F
.393 .42367 m .39353 .42324 L .39352 .42605 L .354 .175 .495 r
F
.39185 .42589 m .39618 .42917 L .39318 .42553 L .675 .735 .895 r
F
.39165 .42594 m .39177 .42602 L .39185 .42589 L F
.39177 .42602 m .39618 .42917 L .39185 .42589 L F
.39329 .42642 m .39371 .42714 L .39384 .42618 L F
.39291 .42659 m .3931 .42672 L .39329 .42642 L F
.3931 .42672 m .39371 .42714 L .39329 .42642 L F
.39165 .42594 m .39312 .42999 L .39618 .42917 L F
.39312 .42999 m .3946 .43404 L .39918 .43281 L F
.39171 .42881 m .39319 .43288 L .39627 .43206 L F
.39171 .42881 m .39627 .43206 L .39325 .4284 L F
.39179 .42707 m .39214 .42974 L .39179 .42987 L .515 .301 .526 r
F
.39183 .42946 m .39331 .43125 L .39082 .42796 L .675 .735 .895 r
F
.39214 .42974 m .39214 .42974 L .39204 .42978 L .515 .301 .526 r
F
.39214 .42974 m .39204 .42978 L .39179 .42987 L F
.39363 .42177 m .39365 .42585 L .39353 .42191 L .069 0 .411 r
F
.3931 .42672 m .39325 .4284 L .39458 .42774 L .675 .735 .895 r
F
.39367 .42864 m .39358 .42877 L .39353 .42191 L .069 0 .411 r
F
.39415 .42121 m .39645 .42193 L .39628 .42084 L .675 .735 .895 r
F
.39404 .42076 m .39406 .42185 L .39405 .42197 L 0 0 .133 r
F
.39382 .4215 m .39397 .42127 L .39396 .42256 L .069 0 .411 r
F
.39018 .42189 m .39405 .42191 L .39415 .42121 L .675 .735 .895 r
F
.39405 .42191 m .39645 .42193 L .39415 .42121 L F
.39404 .42076 m .39408 .42049 L .39406 .42185 L 0 0 .133 r
F
.3971 .42731 m .39601 .42485 L .39386 .42199 L .654 .726 .902 r
F
.39405 .42191 m .39619 .42301 L .39645 .42193 L .675 .735 .895 r
F
.39399 .42236 m .39397 .42248 L .39397 .42127 L 0 0 .133 r
F
.39382 .4215 m .39396 .42256 L .39384 .42275 L .069 0 .411 r
F
.39024 .40998 m .3918 .42282 L .39057 .42293 L .641 .4 .539 r
F
.39116 .42006 m .3898 .423 L .39106 .42289 L .654 .726 .902 r
F
.39116 .42006 m .39106 .42289 L .39217 .42279 L F
.39018 .42189 m .39396 .42259 L .39405 .42191 L .675 .735 .895 r
F
.39396 .42259 m .39619 .42301 L .39405 .42191 L F
.39399 .4211 m .39399 .42236 L .39397 .42127 L 0 0 .133 r
F
.39399 .42236 m .39399 .42513 L .39397 .42248 L F
.39405 .42197 m .39406 .42185 L .39405 .42299 L F
.39023 .42474 m .39353 .42605 L .3939 .42575 L .675 .735 .895 r
F
.39395 .42543 m .3939 .42575 L .39423 .42548 L F
.393 .42367 m .39325 .42627 L .39303 .42646 L .354 .175 .495 r
F
.393 .42367 m .39352 .42605 L .39325 .42627 L F
.39203 .42274 m .39214 .42974 L .3918 .42282 L .515 .301 .526 r
F
.39023 .42474 m .3939 .42575 L .39395 .42543 L .675 .735 .895 r
F
.39405 .42468 m .39407 .42456 L .39406 .42738 L 0 0 .133 r
F
.39405 .42453 m .39407 .42456 L .39405 .42468 L F
.39408 .42049 m .39403 .42447 L .39407 .42456 L .985 .728 .342 r
F
.39404 .42076 m .39405 .42468 L .39399 .4211 L 0 0 .133 r
F
.39405 .42468 m .39406 .42738 L .39403 .42482 L F
.39405 .42468 m .39403 .42482 L .39399 .4211 L F
.39384 .42275 m .39395 .42832 L .39364 .42307 L .069 0 .411 r
F
.39364 .42307 m .39379 .42563 L .39365 .42585 L F
.39363 .42177 m .39384 .42275 L .39364 .42307 L F
.39357 .40876 m .39382 .4215 L .39363 .42177 L F
.39382 .4215 m .39384 .42275 L .39363 .42177 L F
.39466 .42024 m .42122 .42687 L .42249 .4217 L .654 .726 .902 r
F
.39286 .40933 m .39353 .42324 L .393 .42367 L .354 .175 .495 r
F
.39365 .42585 m .39361 .42591 L .39353 .42191 L .069 0 .411 r
F
.39342 .43183 m .39343 .43186 L .39343 .43184 L .654 .726 .902 r
F
.39307 .43131 m .39632 .4349 L .39331 .43125 L .675 .735 .895 r
F
.39343 .43186 m .39396 .43263 L .39343 .43184 L .654 .726 .902 r
F
.39216 .42973 m .39331 .43125 L .39291 .4294 L .675 .735 .895 r
F
.3921 .43107 m .39813 .44738 L .39342 .43183 L .654 .726 .902 r
F
.39251 .43047 m .39342 .43183 L .39285 .42995 L F
.3921 .43107 m .39342 .43183 L .39251 .43047 L F
.39467 .43694 m .39922 .43286 L .39928 .43571 L .591 .366 .543 r
F
.39467 .43694 m .39462 .4341 L .39922 .43286 L F
.39319 .43288 m .39467 .43694 L .39928 .43571 L .675 .735 .895 r
F
.39561 .43509 m .39934 .43856 L .39632 .4349 L F
.39319 .43288 m .39928 .43571 L .39627 .43206 L F
.39472 .43376 m .39632 .4349 L .39307 .43131 L F
.39805 .4389 m .39813 .44738 L .40245 .44647 L .654 .726 .902 r
F
.395 .43955 m .39467 .43694 L .39928 .43571 L .591 .366 .543 r
F
.39815 .43888 m .39928 .43571 L .39934 .43856 L F
.39586 .43936 m .39813 .44738 L .39805 .4389 L .654 .726 .902 r
F
.39473 .43979 m .395 .43955 L .39815 .43888 L .591 .366 .543 r
F
.395 .43955 m .39928 .43571 L .39815 .43888 L F
.39731 .43762 m .39934 .43856 L .39561 .43509 L .675 .735 .895 r
F
.39285 .42995 m .39805 .4389 L .39781 .43601 L .654 .726 .902 r
F
.39805 .4389 m .40245 .44647 L .399 .4387 L F
.39731 .43762 m .39815 .43888 L .39934 .43856 L .675 .735 .895 r
F
.39805 .4389 m .399 .4387 L .39781 .43601 L .654 .726 .902 r
F
.39729 .4376 m .39586 .43936 L .39805 .4389 L F
.39473 .43979 m .39473 .43961 L .395 .43955 L .591 .366 .543 r
F
.39473 .43961 m .39467 .43694 L .395 .43955 L F
.39343 .43186 m .39813 .44738 L .39396 .43263 L .654 .726 .902 r
F
.39325 .43573 m .39473 .43979 L .39815 .43888 L .675 .735 .895 r
F
.39396 .43263 m .39586 .43936 L .39729 .4376 L .654 .726 .902 r
F
.39325 .43573 m .39815 .43888 L .39731 .43762 L .675 .735 .895 r
F
.39354 .43113 m .39396 .43263 L .39729 .4376 L .654 .726 .902 r
F
.39325 .43573 m .39731 .43762 L .39561 .43509 L .675 .735 .895 r
F
.39177 .43166 m .39472 .43376 L .39307 .43131 L F
.39343 .43184 m .39396 .43263 L .39354 .43113 L .654 .726 .902 r
F
.39342 .43183 m .39343 .43184 L .39354 .43113 L F
.39298 .42972 m .39331 .43125 L .3931 .42953 L .675 .735 .895 r
F
.3971 .42731 m .40236 .43919 L .40616 .43838 L .654 .726 .902 r
F
.39934 .43856 m .39928 .43571 L .40327 .43373 L .495 .291 .533 r
F
.39934 .43856 m .40327 .43373 L .40333 .43658 L F
.39632 .4349 m .39934 .43856 L .40333 .43658 L .675 .735 .895 r
F
.39285 .42995 m .40579 .44575 L .393 .42973 L .654 .726 .902 r
F
.39312 .42999 m .39918 .43281 L .39618 .42917 L .675 .735 .895 r
F
.39325 .4284 m .39627 .43206 L .39893 .43074 L F
.39384 .429 m .39464 .43059 L .39567 .42972 L F
.3921 .42694 m .3928 .42945 L .39214 .42974 L .515 .301 .526 r
F
.39091 .4272 m .39179 .42707 L .39082 .42996 L .641 .4 .539 r
F
.39116 .42998 m .39013 .43179 L .39177 .43166 L .675 .735 .895 r
F
.39076 .42997 m .39082 .42996 L .3908 .43003 L .641 .4 .539 r
F
.39076 .42997 m .3908 .43003 L .39075 .43003 L F
.39074 .42997 m .39044 .42999 L .39021 .42297 L F
.3902 .4273 m .39044 .42999 L .3902 .43002 L F
.39035 .42727 m .39044 .42999 L .3902 .4273 L F
.39072 .42734 m .38954 .42989 L .39061 .4301 L .654 .726 .902 r
F
.39029 .42759 m .3902 .43011 L .39116 .42998 L .675 .735 .895 r
F
.38663 .42995 m .38971 .43444 L .38987 .43026 L F
.38845 .42879 m .38992 .43315 L .39008 .42894 L F
.39061 .4301 m .38869 .43172 L .39044 .43484 L .654 .726 .902 r
F
.3902 .43011 m .39013 .43179 L .39116 .42998 L .675 .735 .895 r
F
.39075 .43003 m .3908 .43003 L .39075 .43018 L .641 .4 .539 r
F
.39091 .4272 m .39082 .42996 L .39076 .42997 L F
.39272 .42979 m .3921 .43107 L .39285 .42995 L .654 .726 .902 r
F
.39214 .42974 m .39281 .42949 L .39214 .42974 L .515 .301 .526 r
F
.39082 .42796 m .39216 .42973 L .39291 .4294 L .675 .735 .895 r
F
.3912 .43714 m .39107 .45488 L .39297 .44193 L .654 .726 .902 r
F
.39114 .43698 m .39113 .43717 L .3912 .43714 L F
.39166 .42989 m .39166 .42992 L .39167 .42992 L F
.39166 .42992 m .39112 .44761 L .39167 .42992 L F
.39013 .43179 m .39325 .43573 L .39177 .43166 L .675 .735 .895 r
F
.39075 .43018 m .39179 .42707 L .39177 .43693 L .641 .4 .539 r
F
.39091 .437 m .39177 .43693 L .39169 .46845 L F
.39013 .43179 m .38998 .43599 L .39325 .43573 L .675 .735 .895 r
F
.39075 .43018 m .39177 .43693 L .39091 .437 L .641 .4 .539 r
F
.3931 .42953 m .39331 .43125 L .39464 .43059 L .675 .735 .895 r
F
.39367 .42864 m .3937 .43572 L .39358 .42877 L .069 0 .411 r
F
.39291 .4294 m .39298 .42972 L .3931 .42953 L .675 .735 .895 r
F
.39331 .43125 m .39898 .43358 L .39464 .43059 L F
.39281 .42949 m .39756 .43544 L .3934 .42926 L .654 .726 .902 r
F
.39399 .42805 m .39399 .43501 L .39397 .4282 L 0 0 .133 r
F
.39347 .43853 m .40249 .45365 L .39853 .44471 L .654 .726 .902 r
F
.39136 .43972 m .39228 .43969 L .39313 .43388 L F
.38998 .43599 m .39473 .43979 L .39325 .43573 L .675 .735 .895 r
F
.39256 .43742 m .39342 .43884 L .39347 .43853 L .654 .726 .902 r
F
.39342 .43884 m .40249 .45365 L .39347 .43853 L F
.39291 .4294 m .39464 .43059 L .39384 .429 L .675 .735 .895 r
F
.3934 .42926 m .39687 .43387 L .39548 .43075 L .654 .726 .902 r
F
.39399 .42791 m .39406 .42738 L .39405 .4346 L 0 0 .133 r
F
.39256 .43742 m .39853 .44471 L .39308 .43664 L .654 .726 .902 r
F
.39853 .44471 m .40535 .45304 L .39767 .44277 L F
.39853 .44471 m .39767 .44277 L .39308 .43664 L F
.39399 .42739 m .39391 .43428 L .39406 .42755 L .985 .728 .342 r
F
.39328 .43984 m .39768 .45467 L .39342 .43884 L .654 .726 .902 r
F
.39367 .42874 m .39395 .42832 L .39393 .43538 L .069 0 .411 r
F
.39355 .42892 m .39361 .43586 L .39352 .42896 L F
.39687 .43387 m .40579 .44575 L .39548 .43075 L .654 .726 .902 r
F
.39397 .4282 m .39397 .43513 L .39395 .42832 L 0 0 .133 r
F
.39781 .43601 m .40245 .44647 L .40579 .44575 L .654 .726 .902 r
F
.39321 .43646 m .3955 .43789 L .3935 .43602 L F
.3955 .43789 m .41344 .44905 L .39516 .4371 L F
.3955 .43789 m .39516 .4371 L .3935 .43602 L F
.39365 .42585 m .39367 .42864 L .39361 .42591 L .069 0 .411 r
F
.39365 .42585 m .39395 .42832 L .39367 .42874 L F
.3971 .42731 m .40616 .43838 L .39601 .42485 L .654 .726 .902 r
F
.39928 .43571 m .39922 .43286 L .40321 .43088 L .495 .291 .533 r
F
.39928 .43571 m .40321 .43088 L .40327 .43373 L F
.40333 .43658 m .40327 .43373 L .40637 .43114 L .354 .184 .507 r
F
.39618 .42917 m .39918 .43281 L .40315 .43084 L .675 .735 .895 r
F
.39627 .43206 m .40327 .43373 L .39893 .43074 L F
.40333 .43658 m .40637 .43114 L .40643 .43399 L .354 .184 .507 r
F
.39627 .43206 m .39928 .43571 L .40327 .43373 L .675 .735 .895 r
F
.39898 .43358 m .40333 .43658 L .40643 .43399 L F
.39898 .43358 m .40643 .43399 L .40105 .43185 L F
.39464 .43059 m .39898 .43358 L .40105 .43185 L F
.39464 .43059 m .40105 .43185 L .39567 .42972 L F
.39373 .42864 m .41243 .44287 L .4176 .43893 L .654 .726 .902 r
F
.39029 .42759 m .39291 .4294 L .39384 .429 L .675 .735 .895 r
F
.39352 .42887 m .39355 .42892 L .39352 .42896 L .069 0 .411 r
F
.39325 .4284 m .39893 .43074 L .39458 .42774 L .675 .735 .895 r
F
.3942 .42832 m .39567 .42972 L .39634 .42871 L F
.39296 .42694 m .39325 .4284 L .3931 .42672 L F
.3922 .42713 m .39325 .4284 L .39289 .42657 L F
.39303 .42646 m .3935 .42888 L .39305 .42925 L .354 .175 .495 r
F
.3921 .42694 m .39282 .42663 L .39281 .42949 L .515 .301 .526 r
F
.392 .42698 m .39214 .42974 L .39179 .42707 L F
.39029 .42759 m .39352 .42887 L .3942 .42832 L .675 .735 .895 r
F
.39352 .42887 m .39567 .42972 L .3942 .42832 L F
.39305 .42925 m .39352 .42896 L .39305 .42931 L .354 .175 .495 r
F
.3935 .42888 m .39352 .42896 L .39305 .42925 L F
.39355 .42882 m .39355 .42892 L .39352 .42887 L .069 0 .411 r
F
.39072 .42734 m .39334 .42922 L .39373 .42864 L .654 .726 .902 r
F
.39334 .42922 m .41243 .44287 L .39373 .42864 L F
.39291 .42659 m .39384 .42618 L .39384 .42617 L .675 .735 .895 r
F
.39356 .42599 m .39358 .42887 L .39352 .42605 L .069 0 .411 r
F
.39358 .42887 m .39363 .43582 L .39356 .42891 L F
.39358 .42887 m .39356 .42891 L .39352 .42605 L F
.39391 .42719 m .39361 .42652 L .39359 .43358 L .985 .728 .342 r
F
.3935 .43602 m .39381 .43622 L .39382 .43616 L .654 .726 .902 r
F
.39363 .43582 m .39386 .46675 L .39361 .43586 L .069 0 .411 r
F
.39361 .43586 m .39386 .46675 L .39358 .4359 L F
.39632 .4349 m .40333 .43658 L .39898 .43358 L .675 .735 .895 r
F
.39548 .43075 m .40579 .44575 L .41243 .44287 L .654 .726 .902 r
F
.39321 .43646 m .41199 .45015 L .41344 .44905 L F
.39308 .43664 m .41199 .45015 L .39321 .43646 L F
.3935 .43602 m .39386 .46675 L .39343 .46744 L .069 0 .411 r
F
.39358 .4359 m .39386 .46675 L .3935 .43602 L F
.39177 .43166 m .39325 .43573 L .39632 .4349 L .675 .735 .895 r
F
.39686 .43612 m .41715 .44621 L .42049 .44148 L .654 .726 .902 r
F
.39285 .42995 m .39342 .43183 L .39354 .43113 L F
.39305 .42931 m .39352 .42896 L .3935 .43602 L .354 .175 .495 r
F
.39312 .4363 m .3935 .43602 L .39343 .46744 L F
.39305 .42931 m .3935 .43602 L .39312 .4363 L F
.39418 .43551 m .40071 .43913 L .39686 .43612 L .654 .726 .902 r
F
.3926 .42964 m .39285 .42995 L .39281 .42949 L F
.39255 .42958 m .3926 .42964 L .39281 .42949 L F
.39214 .42974 m .39281 .42949 L .39279 .43654 L .515 .301 .526 r
F
.39213 .43689 m .39238 .43769 L .39256 .43742 L .654 .726 .902 r
F
.39224 .43675 m .39279 .43654 L .39272 .46801 L .515 .301 .526 r
F
.39166 .42989 m .3921 .43107 L .39244 .43037 L .654 .726 .902 r
F
.39209 .42985 m .39244 .43037 L .39272 .42979 L F
.39166 .42989 m .39244 .43037 L .39209 .42985 L F
.39067 .42723 m .39091 .4272 L .39075 .43003 L .641 .4 .539 r
F
.39074 .43003 m .39075 .43003 L .39075 .43018 L F
.39067 .42723 m .39075 .43003 L .39074 .43003 L F
.39072 .42734 m .39166 .42989 L .39272 .42979 L .654 .726 .902 r
F
.39029 .42759 m .39199 .42986 L .39183 .42946 L .675 .735 .895 r
F
.39199 .42986 m .39307 .43131 L .39209 .42985 L F
.39199 .42986 m .39209 .42985 L .39183 .42946 L F
.39072 .42734 m .39062 .42998 L .39166 .42989 L .654 .726 .902 r
F
.39029 .42759 m .39177 .43166 L .39307 .43131 L .675 .735 .895 r
F
.39183 .42946 m .39307 .43131 L .39331 .43125 L F
.39214 .42974 m .39279 .43654 L .39224 .43675 L .515 .301 .526 r
F
.39027 .43463 m .39314 .43641 L .3935 .43602 L .654 .726 .902 r
F
.39314 .43641 m .39321 .43646 L .39327 .43636 L F
.39314 .43641 m .39327 .43636 L .3935 .43602 L F
.39027 .43463 m .3935 .43602 L .39418 .43551 L F
.3935 .43602 m .40071 .43913 L .39418 .43551 L F
.39756 .43544 m .40579 .44575 L .39687 .43387 L F
.40071 .43913 m .41715 .44621 L .39686 .43612 L F
.39116 .42006 m .3943 .42077 L .39464 .42027 L F
.39116 .42006 m .39464 .42027 L .39461 .42024 L F
.39325 .42627 m .39352 .42896 L .39303 .42646 L .354 .175 .495 r
F
.39175 .43862 m .39768 .45467 L .39238 .43769 L .654 .726 .902 r
F
.39285 .42995 m .393 .42973 L .39281 .42949 L F
.40327 .43373 m .40321 .43088 L .40632 .42829 L .354 .184 .507 r
F
.40327 .43373 m .40632 .42829 L .40637 .43114 L F
.39893 .43074 m .40327 .43373 L .40637 .43114 L .675 .735 .895 r
F
.40643 .43399 m .40637 .43114 L .40838 .42811 L .112 .004 .44 r
F
.39618 .42917 m .40315 .43084 L .39883 .42786 L .675 .735 .895 r
F
.39893 .43074 m .40637 .43114 L .40099 .42901 L F
.39458 .42774 m .39893 .43074 L .40099 .42901 L F
.40105 .43185 m .40643 .43399 L .40843 .43096 L F
.40643 .43399 m .40838 .42811 L .40843 .43096 L .112 .004 .44 r
F
.40105 .43185 m .40843 .43096 L .40238 .42983 L .675 .735 .895 r
F
.39567 .42972 m .40105 .43185 L .40238 .42983 L F
.39567 .42972 m .40238 .42983 L .39634 .42871 L F
.39454 .42821 m .4176 .43893 L .42093 .43419 L .654 .726 .902 r
F
.39387 .4287 m .4176 .43893 L .39454 .42821 L F
.39504 .43488 m .42049 .44148 L .42176 .43628 L F
.39091 .437 m .39067 .43702 L .39044 .42999 L .641 .4 .539 r
F
.39027 .43463 m .39418 .43551 L .39504 .43488 L .654 .726 .902 r
F
.39418 .43551 m .42049 .44148 L .39504 .43488 L F
.39279 .43654 m .39343 .46744 L .39272 .46801 L .354 .175 .495 r
F
.39281 .42949 m .39292 .43644 L .39279 .43654 L F
.39292 .43644 m .39343 .46744 L .39279 .43654 L F
.39283 .42244 m .39292 .42941 L .39281 .42949 L F
.39397 .43513 m .39395 .43523 L .39395 .42832 L 0 0 .133 r
F
.39361 .43586 m .39358 .4359 L .39352 .42896 L .069 0 .411 r
F
.39367 .42874 m .39393 .43538 L .3937 .43572 L F
.39399 .42791 m .39405 .4346 L .39399 .43501 L 0 0 .133 r
F
.39399 .43501 m .39397 .43513 L .39397 .4282 L F
.3937 .43572 m .39363 .43582 L .39358 .42877 L .069 0 .411 r
F
.3943 .42077 m .42122 .42687 L .39466 .42024 L .654 .726 .902 r
F
.39395 .42832 m .39395 .43523 L .39393 .43538 L 0 0 .133 r
F
.39214 .42974 m .39224 .43675 L .39179 .42987 L .515 .301 .526 r
F
.39175 .43862 m .39238 .43769 L .39213 .43689 L .654 .726 .902 r
F
.39224 .43675 m .39272 .46801 L .39196 .43686 L .515 .301 .526 r
F
.39224 .43675 m .39196 .43686 L .39179 .42987 L F
.39314 .43641 m .39308 .43664 L .39321 .43646 L .654 .726 .902 r
F
.39027 .43463 m .39289 .4365 L .39314 .43641 L F
.39289 .4365 m .39308 .43664 L .39314 .43641 L F
.39256 .43742 m .39328 .43984 L .39342 .43884 L F
.39289 .42657 m .39296 .42694 L .3931 .42672 L .675 .735 .895 r
F
.39299 .42232 m .39305 .42931 L .39283 .42244 L .354 .175 .495 r
F
.39883 .42786 m .40315 .43084 L .40624 .42826 L .675 .735 .895 r
F
.40637 .43114 m .40632 .42829 L .40832 .42526 L .112 .004 .44 r
F
.40099 .42901 m .40637 .43114 L .40838 .42811 L .675 .735 .895 r
F
.39883 .42786 m .40624 .42826 L .40088 .42614 L F
.40637 .43114 m .40832 .42526 L .40838 .42811 L .112 .004 .44 r
F
.40099 .42901 m .40838 .42811 L .40233 .42699 L .675 .735 .895 r
F
.39458 .42774 m .40099 .42901 L .39561 .42687 L F
.40843 .43096 m .40838 .42811 L .40914 .42485 L 0 0 .249 r
F
.40843 .43096 m .40914 .42485 L .4092 .4277 L F
.40238 .42983 m .40843 .43096 L .4092 .4277 L .675 .735 .895 r
F
.40238 .42983 m .4092 .4277 L .4029 .42766 L F
.39561 .42687 m .40099 .42901 L .40233 .42699 L F
.39634 .42871 m .40238 .42983 L .4029 .42766 L F
.39634 .42871 m .4029 .42766 L .39659 .42763 L F
.39538 .42759 m .42093 .43419 L .42221 .42899 L .654 .726 .902 r
F
.39431 .42761 m .39634 .42871 L .39659 .42763 L .675 .735 .895 r
F
.3939 .42826 m .39634 .42871 L .39431 .42761 L F
.39454 .42821 m .42093 .43419 L .39538 .42759 L .654 .726 .902 r
F
.40088 .42614 m .40624 .42826 L .40823 .42524 L .675 .735 .895 r
F
.40838 .42811 m .40832 .42526 L .40909 .422 L 0 0 .249 r
F
.40838 .42811 m .40909 .422 L .40914 .42485 L F
.40233 .42699 m .40838 .42811 L .40914 .42485 L .675 .735 .895 r
F
.3945 .42487 m .39883 .42786 L .40088 .42614 L F
.39561 .42687 m .40233 .42699 L .39628 .42586 L F
.4029 .42766 m .4092 .4277 L .40868 .42443 L F
.40088 .42614 m .40823 .42524 L .40221 .42413 L F
.40233 .42699 m .40914 .42485 L .40284 .42481 L F
.4029 .42766 m .40868 .42443 L .40255 .42548 L F
.39659 .42763 m .4029 .42766 L .40255 .42548 L F
.39553 .42401 m .40088 .42614 L .40221 .42413 L F
.39628 .42586 m .40233 .42699 L .40284 .42481 L F
.39659 .42763 m .40255 .42548 L .39642 .42654 L F
.39414 .42693 m .42221 .42899 L .42133 .42367 L .654 .726 .902 r
F
.39325 .42627 m .39352 .42605 L .39352 .42896 L .354 .175 .495 r
F
.39371 .42714 m .39458 .42774 L .39384 .42617 L .675 .735 .895 r
F
.39399 .42805 m .39397 .4282 L .39397 .4253 L 0 0 .133 r
F
.39433 .42689 m .39659 .42763 L .39642 .42654 L .675 .735 .895 r
F
.39029 .42759 m .39529 .42762 L .39433 .42689 L F
.39529 .42762 m .39659 .42763 L .39433 .42689 L F
.39366 .4062 m .3926 .40537 L .39257 .41864 L .909 .63 .5 r
F
.39411 .40725 m .39366 .4062 L .39363 .41947 L .985 .728 .342 r
F
.394 .40807 m .39411 .40725 L .39408 .42049 L 0 0 .133 r
F
.39072 .42734 m .39494 .42756 L .39414 .42693 L .654 .726 .902 r
F
.39177 .43693 m .39272 .46801 L .39169 .46845 L .515 .301 .526 r
F
.39196 .43686 m .39272 .46801 L .39177 .43693 L F
.39432 .43414 m .42176 .43628 L .42089 .43096 L .654 .726 .902 r
F
.39179 .42987 m .39196 .43686 L .39177 .43693 L .515 .301 .526 r
F
.39027 .43463 m .39528 .43489 L .39432 .43414 L .654 .726 .902 r
F
.39528 .43489 m .42176 .43628 L .39432 .43414 L F
.39305 .42931 m .39292 .42941 L .39283 .42244 L .354 .175 .495 r
F
.39352 .42605 m .39355 .42882 L .39352 .42887 L .069 0 .411 r
F
.39029 .42759 m .3939 .42826 L .39431 .42761 L .675 .735 .895 r
F
.39072 .42734 m .39387 .4287 L .39454 .42821 L .654 .726 .902 r
F
.3928 .42945 m .39281 .42949 L .39214 .42974 L .515 .301 .526 r
F
.39325 .42607 m .39255 .42554 L .39253 .43275 L .909 .63 .5 r
F
.39312 .4363 m .39301 .43638 L .39292 .42941 L .354 .175 .495 r
F
.39301 .43638 m .39292 .43644 L .39281 .42949 L F
.3931 .43319 m .39253 .43275 L .39246 .46405 L .909 .63 .5 r
F
.39305 .42931 m .39312 .4363 L .39292 .42941 L .354 .175 .495 r
F
.39292 .42941 m .39301 .43638 L .39281 .42949 L F
.39325 .42607 m .39253 .43275 L .3931 .43319 L .909 .63 .5 r
F
.39253 .43275 m .39138 .46367 L .39246 .46405 L .81 .54 .531 r
F
.39023 .42474 m .3936 .42348 L .39339 .42301 L .675 .735 .895 r
F
.39023 .42474 m .39414 .42407 L .39416 .42394 L F
.39399 .42513 m .39398 .42521 L .39397 .42127 L 0 0 .133 r
F
.39023 .42474 m .39416 .42394 L .39357 .42349 L .675 .735 .895 r
F
.39353 .42191 m .39356 .42599 L .39352 .42605 L .069 0 .411 r
F
.39398 .42522 m .39397 .42253 L .39398 .42521 L 0 0 .133 r
F
.39023 .42474 m .39404 .42476 L .39407 .42456 L .675 .735 .895 r
F
.3939 .42575 m .39497 .42662 L .39423 .42548 L F
.39353 .42605 m .39384 .42617 L .3939 .42575 L F
.39384 .42617 m .39497 .42662 L .3939 .42575 L F
.39396 .42537 m .39397 .4282 L .39395 .42832 L 0 0 .133 r
F
.39397 .42127 m .39397 .4253 L .39396 .42537 L F
.39397 .4253 m .39397 .4282 L .39396 .42537 L F
.39399 .42805 m .39398 .42522 L .39398 .42521 L F
.39399 .42805 m .39397 .4253 L .39398 .42522 L F
.39399 .42513 m .39399 .42805 L .39398 .42521 L F
.39399 .4211 m .39406 .42738 L .39399 .42791 L F
.39391 .42704 m .394 .42722 L .39403 .42447 L .985 .728 .342 r
F
.39497 .42662 m .39561 .42687 L .39449 .42553 L .675 .735 .895 r
F
.39361 .42635 m .39642 .42654 L .39583 .42552 L F
.39384 .42275 m .39396 .42256 L .39395 .42832 L .069 0 .411 r
F
.39023 .42474 m .39407 .42456 L .39387 .42411 L .675 .735 .895 r
F
.3933 .42329 m .39325 .42607 L .39348 .42342 L .909 .63 .5 r
F
.39325 .42607 m .3931 .43319 L .39337 .42616 L F
.39023 .42474 m .39449 .42553 L .39416 .42476 L .675 .735 .895 r
F
.39325 .42607 m .39337 .42616 L .39348 .42342 L .909 .63 .5 r
F
.39029 .42759 m .39389 .42697 L .39361 .42635 L .675 .735 .895 r
F
.39379 .42563 m .39395 .42832 L .39365 .42585 L .069 0 .411 r
F
.39407 .42456 m .39399 .42739 L .39406 .42755 L .985 .728 .342 r
F
.39389 .42697 m .39642 .42654 L .39361 .42635 L .675 .735 .895 r
F
.39391 .42719 m .39399 .42739 L .394 .42722 L .985 .728 .342 r
F
.39391 .42719 m .394 .42722 L .39391 .42704 L F
.39398 .42436 m .39403 .42447 L .39408 .42049 L F
.39391 .42703 m .39403 .42447 L .39398 .42436 L F
.39449 .42553 m .39628 .42586 L .39416 .42476 L .675 .735 .895 r
F
.39394 .42426 m .39391 .42719 L .39398 .42436 L .985 .728 .342 r
F
.39403 .42447 m .39399 .42739 L .39407 .42456 L F
.3933 .42564 m .39583 .42552 L .39486 .42464 L .675 .735 .895 r
F
.39255 .42554 m .39203 .43256 L .39253 .43275 L .81 .54 .531 r
F
.39256 .42273 m .39241 .42549 L .39255 .42554 L F
.39023 .42474 m .3922 .42713 L .39289 .42657 L .675 .735 .895 r
F
.39205 .42415 m .39282 .42663 L .3921 .42694 L .515 .301 .526 r
F
.39057 .42293 m .39179 .42707 L .39067 .42723 L .641 .4 .539 r
F
.39112 .42717 m .39179 .42707 L .39206 .42696 L .675 .735 .895 r
F
.39029 .42759 m .39361 .42635 L .39338 .42582 L F
.39241 .42549 m .39203 .43256 L .39255 .42554 L .81 .54 .531 r
F
.39315 .42574 m .39338 .42582 L .3933 .42564 L .675 .735 .895 r
F
.39029 .42759 m .39338 .42582 L .39315 .42574 L F
.39391 .42704 m .39403 .42447 L .39391 .42703 L .985 .728 .342 r
F
.39394 .42426 m .39361 .42652 L .39391 .42719 L F
.39423 .42548 m .39497 .42662 L .39449 .42553 L .675 .735 .895 r
F
.39361 .42635 m .39583 .42552 L .3933 .42564 L F
.39391 .42719 m .39391 .42704 L .39391 .42703 L .985 .728 .342 r
F
.39416 .42476 m .39628 .42586 L .39654 .42478 L .675 .735 .895 r
F
.39387 .42411 m .39407 .42456 L .39414 .42407 L F
.39398 .42026 m .39377 .42387 L .39394 .42426 L .985 .728 .342 r
F
.39377 .42387 m .39362 .42637 L .39394 .42426 L F
.3929 .42472 m .39486 .42464 L .39358 .42397 L .675 .735 .895 r
F
.39023 .42474 m .39339 .42301 L .39308 .4229 L F
.39224 .42262 m .39218 .42542 L .39256 .42273 L .81 .54 .531 r
F
.39072 .42734 m .39255 .42958 L .3934 .42926 L .654 .726 .902 r
F
.3918 .42282 m .392 .42698 L .39179 .42707 L .515 .301 .526 r
F
.39023 .42474 m .39291 .42659 L .39384 .42617 L .675 .735 .895 r
F
.39218 .42542 m .39203 .43256 L .39241 .42549 L .81 .54 .531 r
F
.39218 .42542 m .39241 .42549 L .39256 .42273 L F
.39357 .40876 m .39363 .42177 L .39353 .42191 L .069 0 .411 r
F
.39366 .4062 m .39339 .41929 L .39363 .41947 L .909 .63 .5 r
F
.39357 .40876 m .39397 .42127 L .39382 .4215 L .069 0 .411 r
F
.394 .40807 m .39404 .42076 L .39399 .4211 L 0 0 .133 r
F
.394 .40807 m .39399 .4211 L .39397 .42127 L F
.39411 .40725 m .39363 .41947 L .39398 .42026 L .985 .728 .342 r
F
.394 .40807 m .39408 .42049 L .39404 .42076 L 0 0 .133 r
F
.39411 .40725 m .39398 .42026 L .39408 .42049 L .985 .728 .342 r
F
.3926 .40537 m .39152 .40499 L .39149 .41824 L .81 .54 .531 r
F
.39183 .40977 m .39203 .42274 L .3918 .42282 L .515 .301 .526 r
F
.39116 .42006 m .39255 .41864 L .39193 .41841 L .654 .726 .902 r
F
.39029 .42759 m .39315 .42574 L .39224 .42544 L .675 .735 .895 r
F
.39352 .42896 m .39358 .4359 L .3935 .43602 L .069 0 .411 r
F
.39027 .43463 m .39581 .43397 L .39423 .43338 L .654 .726 .902 r
F
.39494 .42756 m .42221 .42899 L .39414 .42693 L F
.40221 .42413 m .40823 .42524 L .40899 .422 L .675 .735 .895 r
F
.40284 .42481 m .40914 .42485 L .40862 .42158 L F
.4092 .4277 m .40862 .42158 L .40868 .42443 L .858 .659 .124 r
F
.39362 .42637 m .39361 .42652 L .39363 .42639 L .985 .728 .342 r
F
.40272 .42196 m .40899 .422 L .40847 .41875 L .675 .735 .895 r
F
.40914 .42485 m .40909 .422 L .40856 .41873 L .858 .659 .124 r
F
.3951 .41959 m .42249 .4217 L .42162 .41641 L .654 .726 .902 r
F
.39116 .42006 m .39723 .42038 L .3951 .41959 L F
.39723 .42038 m .42249 .4217 L .3951 .41959 L F
.39461 .42024 m .39464 .42027 L .39466 .42024 L F
.3941 .42043 m .39628 .42084 L .39569 .41983 L .675 .735 .895 r
F
.39336 .42052 m .39255 .42554 L .39325 .42607 L .909 .63 .5 r
F
.39339 .41929 m .39324 .42042 L .39336 .42052 L F
.39289 .42298 m .39296 .42303 L .39336 .42052 L F
.3933 .42329 m .39348 .42342 L .39363 .41947 L F
.39018 .42189 m .39386 .42126 L .39353 .42064 L .675 .735 .895 r
F
.39398 .42026 m .39362 .42353 L .39377 .42387 L .985 .728 .342 r
F
.39386 .42126 m .39425 .42119 L .39362 .42072 L .675 .735 .895 r
F
.39386 .42126 m .39362 .42072 L .39353 .42064 L F
.39398 .42026 m .39363 .41947 L .39362 .42072 L .985 .728 .342 r
F
.39387 .42127 m .39362 .42072 L .39362 .42353 L F
.39398 .42026 m .39362 .42072 L .39387 .42127 L F
.39377 .42387 m .39362 .42353 L .39361 .42652 L F
.39398 .42026 m .39394 .42426 L .39408 .42049 L F
.39287 .42183 m .3948 .42179 L .39352 .42112 L .675 .735 .895 r
F
.39275 .41843 m .41386 .40691 L .40749 .40336 L .654 .726 .902 r
F
.39116 .42006 m .39373 .41857 L .39275 .41843 L F
.39373 .41857 m .41386 .40691 L .39275 .41843 L F
.39024 .40998 m .39183 .40977 L .3918 .42282 L .641 .4 .539 r
F
.39116 .42006 m .39202 .41822 L .39125 .41762 L .654 .726 .902 r
F
.39027 .43463 m .39114 .43698 L .39213 .43689 L F
.39091 .437 m .39169 .46845 L .39067 .43702 L .641 .4 .539 r
F
.39113 .43717 m .38951 .45493 L .3912 .43714 L .654 .726 .902 r
F
.39018 .43707 m .38951 .45493 L .39114 .43698 L F
.3902 .43002 m .39169 .46845 L .3901 .46866 L .641 .4 .539 r
F
.39116 .42006 m .41868 .41136 L .41386 .40691 L .654 .726 .902 r
F
.39116 .42006 m .42162 .41641 L .41868 .41136 L F
.39023 .42474 m .39292 .423 L .39256 .42273 L .675 .735 .895 r
F
.39256 .41991 m .39224 .42262 L .39256 .42273 L .81 .54 .531 r
F
.39218 .4226 m .39256 .42273 L .39226 .4225 L .675 .735 .895 r
F
.39023 .42474 m .39256 .42273 L .39218 .4226 L F
.39018 .42189 m .39288 .42015 L .39256 .41991 L F
.39018 .42189 m .39256 .41991 L .39211 .41976 L F
.39232 .41855 m .39224 .42262 L .39257 .41864 L .81 .54 .531 r
F
.39211 .41976 m .39256 .41991 L .39221 .41965 L .675 .735 .895 r
F
.39232 .41855 m .39149 .41824 L .39148 .41955 L .81 .54 .531 r
F
.39206 .41974 m .39148 .41955 L .39148 .42236 L F
.39232 .41855 m .39148 .41955 L .39206 .41974 L F
.39207 .42256 m .39147 .42518 L .3919 .42532 L F
.39289 .42298 m .39255 .42554 L .39296 .42303 L .909 .63 .5 r
F
.39136 .42514 m .39358 .42397 L .39207 .42354 L .675 .735 .895 r
F
.39023 .42474 m .39112 .42717 L .39206 .42696 L F
.39029 .42759 m .39224 .42544 L .39136 .42514 L F
.39343 .42332 m .39353 .42324 L .39354 .42322 L F
.39336 .42633 m .39345 .4264 L .39363 .41947 L .909 .63 .5 r
F
.39224 .42544 m .39358 .42397 L .39136 .42514 L .675 .735 .895 r
F
.39207 .42256 m .39148 .42236 L .39147 .42518 L .81 .54 .531 r
F
.3919 .42532 m .39147 .42518 L .39145 .43235 L F
.39301 .42006 m .39569 .41983 L .39472 .41896 L .675 .735 .895 r
F
.39018 .42189 m .3941 .42043 L .39301 .42006 L F
.3941 .42043 m .39569 .41983 L .39301 .42006 L F
.39224 .4198 m .39148 .42236 L .39207 .42256 L .81 .54 .531 r
F
.39232 .41855 m .39206 .41974 L .39224 .4198 L F
.39206 .41974 m .39148 .42236 L .39224 .4198 L F
.39018 .42189 m .39008 .4245 L .39108 .42436 L .675 .735 .895 r
F
.39023 .42474 m .39014 .4273 L .39112 .42717 L F
.39029 .42759 m .39135 .42517 L .39038 .42507 L F
.39072 .42734 m .39165 .42532 L .3908 .4252 L .654 .726 .902 r
F
.39029 .42759 m .39183 .42946 L .39082 .42796 L .675 .735 .895 r
F
.39044 .42999 m .39169 .46845 L .3902 .43002 L .641 .4 .539 r
F
.39027 .43463 m .39018 .43707 L .39114 .43698 L .654 .726 .902 r
F
.39074 .42997 m .39091 .437 L .39044 .42999 L .641 .4 .539 r
F
.38867 .40971 m .38899 .42273 L .38864 .42266 L .751 .491 .538 r
F
.38768 .40924 m .38787 .42228 L .38765 .42217 L .845 .571 .524 r
F
.38768 .40924 m .38867 .40971 L .38864 .42266 L F
.38768 .40924 m .38864 .42266 L .38787 .42228 L F
.39116 .42006 m .38022 .42352 L .36849 .43319 L .654 .726 .902 r
F
.38022 .42352 m .36367 .42875 L .36709 .43191 L F
.38022 .42352 m .36709 .43191 L .36849 .43319 L F
.38823 .40529 m .38711 .40608 L .38708 .41914 L .398 .209 .505 r
F
.38729 .42376 m .38467 .42395 L .38563 .42482 L .675 .735 .895 r
F
.38787 .42228 m .38864 .42266 L .38864 .42424 L .845 .571 .524 r
F
.38146 .43798 m .38034 .43853 L .38523 .4392 L .654 .726 .902 r
F
.38043 .43845 m .38163 .43803 L .38494 .43974 L .794 .529 .536 r
F
.38163 .43803 m .38489 .43689 L .38493 .4391 L F
.38163 .43803 m .38493 .4391 L .38494 .43974 L F
.38523 .4392 m .38034 .43853 L .38184 .44653 L .654 .726 .902 r
F
.38709 .43519 m .38146 .43798 L .38523 .4392 L F
.38663 .42995 m .38486 .43398 L .38971 .43444 L .675 .735 .895 r
F
.38489 .43689 m .38483 .43404 L .38971 .4345 L .731 .477 .544 r
F
.38667 .43284 m .38977 .43735 L .38992 .43315 L .675 .735 .895 r
F
.38869 .43172 m .38695 .43314 L .38709 .43519 L .654 .726 .902 r
F
.38038 .4356 m .38483 .43404 L .38489 .43689 L .794 .529 .536 r
F
.38366 .43198 m .38489 .43689 L .38667 .43284 L .675 .735 .895 r
F
.38695 .43314 m .38034 .43853 L .38709 .43519 L .654 .726 .902 r
F
.38665 .42321 m .38408 .42294 L .38467 .42395 L .675 .735 .895 r
F
.38845 .42879 m .38667 .43284 L .38992 .43315 L F
.38845 .43129 m .38691 .43266 L .38869 .43172 L .654 .726 .902 r
F
.38691 .43266 m .38034 .43853 L .38695 .43314 L F
.38691 .43266 m .38695 .43314 L .38869 .43172 L F
.38904 .43048 m .3869 .43246 L .3892 .43062 L F
.3869 .43246 m .38034 .43853 L .38691 .43266 L F
.3869 .43246 m .38691 .43266 L .3892 .43062 L F
.3866 .42251 m .38408 .42294 L .38665 .42321 L .675 .735 .895 r
F
.3866 .42251 m .38391 .42186 L .38408 .42294 L F
.38669 .42268 m .38663 .42257 L .3866 .42089 L .989 .72 .388 r
F
.39018 .42189 m .38656 .42187 L .3866 .42251 L .675 .735 .895 r
F
.38656 .42187 m .38391 .42186 L .3866 .42251 L F
.38702 .40864 m .38713 .42171 L .38698 .42158 L .929 .648 .488 r
F
.38664 .40794 m .38698 .42158 L .38669 .42104 L .989 .72 .388 r
F
.38702 .40864 m .38765 .42217 L .38713 .42171 L .929 .648 .488 r
F
.38867 .40971 m .39021 .42297 L .38899 .42273 L .751 .491 .538 r
F
.38022 .42352 m .36072 .42371 L .36367 .42875 L .654 .726 .902 r
F
.39116 .42006 m .38436 .42087 L .38022 .42352 L F
.38436 .42087 m .36072 .42371 L .38022 .42352 L F
.38693 .42311 m .38467 .42395 L .38729 .42376 L .675 .735 .895 r
F
.38581 .42392 m .38485 .42261 L .38418 .42362 L F
.38669 .42104 m .38698 .42158 L .38698 .4232 L .989 .72 .388 r
F
.38774 .42457 m .38563 .42482 L .38691 .4255 L .675 .735 .895 r
F
.38787 .42228 m .38864 .42424 L .38789 .42389 L .845 .571 .524 r
F
.39018 .42189 m .38729 .42376 L .38774 .42457 L .675 .735 .895 r
F
.38729 .42376 m .38563 .42482 L .38774 .42457 L F
.38675 .42279 m .38697 .42601 L .38686 .42582 L .989 .72 .388 r
F
.38669 .42104 m .38679 .42286 L .38675 .42279 L F
.38679 .42286 m .38697 .42601 L .38675 .42279 L F
.38679 .42286 m .38698 .4232 L .38697 .42601 L F
.38669 .42104 m .38698 .4232 L .38679 .42286 L F
.38742 .42367 m .38718 .42357 L .38729 .42376 L .675 .735 .895 r
F
.37402 .42211 m .35984 .41842 L .36072 .42371 L .654 .726 .902 r
F
.39116 .42006 m .38346 .41966 L .37402 .42211 L F
.38346 .41966 m .35984 .41842 L .37402 .42211 L F
.38934 .40495 m .38823 .40529 L .3882 .41842 L .567 .342 .533 r
F
.37654 .43358 m .38032 .43276 L .38038 .4356 L .861 .586 .519 r
F
.37654 .43358 m .37648 .43073 L .38032 .43276 L F
.37777 .43617 m .37654 .43358 L .38038 .4356 L F
.38038 .4356 m .38032 .43276 L .38483 .43404 L .794 .529 .536 r
F
.37777 .43617 m .38038 .4356 L .38042 .43764 L .861 .586 .519 r
F
.38364 .4291 m .38037 .4327 L .38486 .43398 L .675 .735 .895 r
F
.3811 .43063 m .38038 .4356 L .38366 .43198 L F
.38384 .43209 m .37699 .43573 L .38104 .43724 L .654 .726 .902 r
F
.37699 .43573 m .36793 .44054 L .38011 .43747 L F
.37699 .43573 m .38011 .43747 L .38104 .43724 L F
.37659 .43643 m .37777 .43617 L .38043 .43845 L .861 .586 .519 r
F
.37777 .43617 m .38042 .43764 L .38043 .43845 L F
.37659 .43643 m .37657 .4355 L .37777 .43617 L F
.37657 .4355 m .37654 .43358 L .37777 .43617 L F
.3811 .43063 m .37654 .43358 L .38038 .4356 L .675 .735 .895 r
F
.38446 .43097 m .3783 .43179 L .37496 .4346 L .654 .726 .902 r
F
.3766 .43552 m .37496 .4346 L .36793 .44054 L F
.37368 .4338 m .37464 .43372 L .37659 .43643 L .933 .65 .482 r
F
.37464 .43372 m .37654 .43358 L .37657 .4355 L F
.37541 .43443 m .37496 .4346 L .37657 .4355 L .654 .726 .902 r
F
.37464 .43372 m .37657 .4355 L .37659 .43643 L .933 .65 .482 r
F
.38446 .43097 m .37541 .43443 L .3766 .43552 L .654 .726 .902 r
F
.37541 .43443 m .37657 .4355 L .3766 .43552 L F
.38364 .4291 m .38486 .43398 L .38663 .42995 L .675 .735 .895 r
F
.38695 .42836 m .38366 .43198 L .38667 .43284 L F
.38755 .42918 m .38505 .42988 L .38446 .43097 L .654 .726 .902 r
F
.38567 .42769 m .3811 .43063 L .38366 .43198 L .675 .735 .895 r
F
.38505 .42988 m .3783 .43179 L .38446 .43097 L .654 .726 .902 r
F
.38693 .42311 m .3866 .42251 L .38665 .42321 L .675 .735 .895 r
F
.38656 .42028 m .3866 .42089 L .3866 .42251 L .79 .631 .071 r
F
.38657 .42211 m .3866 .42251 L .38659 .42533 L F
.38656 .42028 m .3866 .42251 L .38657 .42211 L F
.38691 .4255 m .38364 .4291 L .38663 .42995 L .675 .735 .895 r
F
.38691 .4255 m .38663 .42995 L .3884 .42592 L F
.38828 .42689 m .38567 .42769 L .38695 .42836 L F
.38595 .43924 m .38489 .43689 L .38977 .43735 L .731 .477 .544 r
F
.38526 .43914 m .38184 .44653 L .38709 .43939 L .654 .726 .902 r
F
.38494 .43974 m .38493 .4391 L .38595 .43924 L .731 .477 .544 r
F
.38493 .4391 m .38489 .43689 L .38595 .43924 L F
.38489 .43689 m .38971 .4345 L .38977 .43735 L F
.38667 .43284 m .38489 .43689 L .38977 .43735 L .675 .735 .895 r
F
.38869 .43172 m .38526 .43914 L .39044 .43484 L .654 .726 .902 r
F
.38526 .43914 m .38709 .43939 L .39044 .43484 L F
.38673 .43569 m .38982 .44019 L .38998 .43599 L .675 .735 .895 r
F
.38916 .43704 m .38821 .43793 L .3885 .43846 L .654 .726 .902 r
F
.39016 .43753 m .38713 .44316 L .38951 .45493 L F
.3886 .43676 m .3901 .46866 L .38853 .46839 L .751 .491 .538 r
F
.3892 .43062 m .38845 .43129 L .38869 .43172 L .654 .726 .902 r
F
.38109 .42776 m .38037 .4327 L .38364 .4291 L .675 .735 .895 r
F
.38109 .42776 m .37655 .43069 L .38037 .4327 L F
.37363 .43095 m .37648 .43073 L .37654 .43358 L .933 .65 .482 r
F
.37363 .43095 m .37357 .4281 L .37648 .43073 L F
.37916 .42888 m .37654 .43358 L .3811 .43063 L .675 .735 .895 r
F
.37916 .42888 m .37363 .43095 L .37654 .43358 L F
.37206 .43009 m .36011 .43101 L .37362 .43274 L .654 .726 .902 r
F
.3719 .43075 m .37249 .43082 L .37368 .4338 L .987 .712 .384 r
F
.37249 .43082 m .37363 .43095 L .37366 .43282 L F
.37249 .43082 m .37366 .43282 L .37368 .4338 L F
.37362 .43274 m .36011 .43101 L .36308 .43607 L .654 .726 .902 r
F
.38528 .42906 m .37206 .43009 L .37362 .43274 L F
.38906 .42444 m .38691 .4255 L .3884 .42592 L .675 .735 .895 r
F
.39018 .42189 m .38822 .42405 L .38906 .42444 L F
.38822 .42405 m .38691 .4255 L .38906 .42444 L F
.38785 .42669 m .38778 .42666 L .3877 .4238 L .845 .571 .524 r
F
.38772 .42382 m .3877 .4238 L .38765 .42217 L F
.38785 .42669 m .3877 .4238 L .38772 .42382 L F
.3884 .42592 m .38663 .42995 L .38987 .43026 L .675 .735 .895 r
F
.38912 .42728 m .38695 .42836 L .38845 .42879 L F
.38909 .42713 m .3902 .43002 L .38916 .42982 L .751 .491 .538 r
F
.38899 .42273 m .38973 .42722 L .38909 .42713 L F
.38973 .42722 m .3902 .43002 L .38909 .42713 L F
.38918 .42714 m .38863 .42705 L .38912 .42728 L .675 .735 .895 r
F
.37916 .42601 m .37655 .43069 L .38109 .42776 L F
.37916 .42601 m .37365 .42807 L .37655 .43069 L F
.37185 .4279 m .37357 .4281 L .37363 .43095 L .987 .712 .384 r
F
.37798 .42685 m .37363 .43095 L .37916 .42888 L .675 .735 .895 r
F
.37798 .42685 m .37185 .4279 L .37363 .43095 L F
.37145 .42716 m .35923 .4257 L .37185 .4296 L .654 .726 .902 r
F
.37138 .42748 m .37153 .42761 L .3719 .43075 L .859 .661 .126 r
F
.37153 .42761 m .37185 .4279 L .37188 .42978 L F
.37153 .42761 m .37188 .42978 L .3719 .43075 L F
.37185 .4296 m .35923 .4257 L .36011 .43101 L .654 .726 .902 r
F
.38188 .4284 m .37145 .42716 L .37185 .4296 L F
.38916 .42982 m .38898 .42978 L .38864 .42266 L .751 .491 .538 r
F
.38863 .42705 m .38695 .42836 L .38912 .42728 L .675 .735 .895 r
F
.38828 .42689 m .38819 .42699 L .38863 .42705 L F
.38819 .42699 m .38695 .42836 L .38863 .42705 L F
.38863 .42705 m .38886 .42976 L .38862 .42971 L .751 .491 .538 r
F
.38864 .42266 m .38878 .42708 L .38863 .42705 L F
.38878 .42708 m .38886 .42976 L .38863 .42705 L F
.38797 .42939 m .38778 .42666 L .38785 .42669 L .845 .571 .524 r
F
.38697 .42601 m .38707 .42872 L .38697 .42863 L .929 .648 .488 r
F
.38552 .4265 m .38515 .42722 L .38567 .42769 L .675 .735 .895 r
F
.39018 .42189 m .38718 .42357 L .38742 .42367 L F
.39152 .40499 m .39043 .40486 L .3904 .41808 L .734 .477 .539 r
F
.38346 .41966 m .36777 .41475 L .35984 .41842 L .654 .726 .902 r
F
.39116 .42006 m .38621 .41894 L .38346 .41966 L F
.38621 .41894 m .36777 .41475 L .38346 .41966 L F
.38563 .42482 m .38109 .42776 L .38364 .4291 L .675 .735 .895 r
F
.3847 .42681 m .37916 .42888 L .3811 .43063 L F
.3841 .42579 m .37916 .42888 L .3847 .42681 L F
.38399 .42815 m .38262 .42692 L .38188 .4284 L .654 .726 .902 r
F
.38671 .42553 m .38697 .42863 L .38672 .42818 L .989 .72 .388 r
F
.38669 .42104 m .38686 .42582 L .38671 .42553 L F
.38752 .42649 m .38552 .4265 L .38567 .42769 L .675 .735 .895 r
F
.38686 .42582 m .38697 .42863 L .38671 .42553 L .989 .72 .388 r
F
.38563 .42482 m .38364 .4291 L .38691 .4255 L .675 .735 .895 r
F
.38695 .42597 m .3841 .42579 L .3847 .42681 L F
.38899 .42273 m .38916 .42982 L .38864 .42266 L .751 .491 .538 r
F
.38789 .42389 m .38864 .42424 L .38863 .42705 L .845 .571 .524 r
F
.38789 .42389 m .38862 .42971 L .38797 .42939 L F
.39023 .42474 m .38661 .42536 L .38695 .42597 L .675 .735 .895 r
F
.38661 .42536 m .3841 .42579 L .38695 .42597 L F
.38713 .42171 m .38719 .42883 L .38698 .42158 L .929 .648 .488 r
F
.3886 .43676 m .38839 .43697 L .38916 .43704 L .654 .726 .902 r
F
.38733 .42949 m .38475 .42966 L .38572 .43054 L .675 .735 .895 r
F
.38797 .42939 m .38786 .42933 L .38778 .42666 L .845 .571 .524 r
F
.3905 .42747 m .38652 .42867 L .38755 .42918 L .654 .726 .902 r
F
.39072 .42734 m .39046 .42742 L .3905 .42747 L F
.39046 .42742 m .38652 .42867 L .3905 .42747 L F
.39029 .42759 m .38697 .42883 L .38733 .42949 L .675 .735 .895 r
F
.38567 .42769 m .38366 .43198 L .38695 .42836 L F
.38652 .42867 m .37359 .43275 L .38755 .42918 L .654 .726 .902 r
F
.37359 .43275 m .36308 .43607 L .37389 .43303 L F
.37359 .43275 m .37389 .43303 L .38755 .42918 L F
.37464 .43372 m .37363 .43095 L .37654 .43358 L .933 .65 .482 r
F
.3783 .43179 m .36308 .43607 L .36656 .43928 L .654 .726 .902 r
F
.37368 .4338 m .37366 .43282 L .37464 .43372 L .933 .65 .482 r
F
.37366 .43282 m .37363 .43095 L .37464 .43372 L F
.38697 .42883 m .38475 .42966 L .38733 .42949 L .675 .735 .895 r
F
.38827 .42689 m .38863 .42705 L .38862 .42971 L .845 .571 .524 r
F
.38688 .42855 m .38518 .42801 L .38652 .42867 L .654 .726 .902 r
F
.38787 .42228 m .38797 .42939 L .38765 .42217 L .845 .571 .524 r
F
.39072 .42734 m .38614 .42789 L .38688 .42855 L .654 .726 .902 r
F
.38614 .42789 m .38518 .42801 L .38688 .42855 L F
.38713 .42171 m .38765 .42217 L .38763 .42922 L .929 .648 .488 r
F
.38673 .43569 m .38494 .43974 L .38982 .44019 L .675 .735 .895 r
F
.38839 .43697 m .38681 .43854 L .38882 .43735 L .654 .726 .902 r
F
.38681 .43854 m .38102 .4443 L .38685 .43911 L F
.38681 .43854 m .38685 .43911 L .38882 .43735 L F
.38655 .42743 m .38654 .43457 L .38654 .42728 L .79 .631 .071 r
F
.38825 .4367 m .38817 .43677 L .3886 .43676 L .654 .726 .902 r
F
.38695 .42836 m .38667 .43284 L .38845 .42879 L .675 .735 .895 r
F
.38755 .42918 m .36793 .44054 L .38847 .42964 L .654 .726 .902 r
F
.38775 .43002 m .38384 .43209 L .38787 .43025 L F
.3878 .43033 m .38572 .43054 L .387 .43121 L .675 .735 .895 r
F
.38847 .42964 m .38775 .43002 L .38787 .43025 L .654 .726 .902 r
F
.38851 .43164 m .38998 .43599 L .39013 .43179 L .675 .735 .895 r
F
.38851 .43164 m .38673 .43569 L .38998 .43599 L F
.38933 .4369 m .38909 .43686 L .38886 .42976 L .751 .491 .538 r
F
.38898 .42978 m .38886 .42976 L .38864 .42266 L F
.38933 .4369 m .38886 .42976 L .38898 .42978 L F
.38713 .42171 m .38763 .42922 L .38719 .42883 L .929 .648 .488 r
F
.37132 .42463 m .37179 .42505 L .37185 .4279 L .859 .661 .126 r
F
.37798 .42399 m .37365 .42807 L .37916 .42601 L .675 .735 .895 r
F
.37763 .42467 m .37185 .4279 L .37798 .42685 L F
.38262 .42692 m .35962 .42409 L .37113 .42632 L .654 .726 .902 r
F
.38747 .42652 m .38567 .42769 L .38806 .42696 L .675 .735 .895 r
F
.38764 .4266 m .38806 .42696 L .38828 .42689 L F
.38747 .42652 m .38806 .42696 L .38764 .4266 L F
.38719 .42883 m .38707 .42872 L .38704 .42607 L .929 .648 .488 r
F
.38712 .42614 m .38704 .42607 L .38698 .42158 L F
.38719 .42883 m .38704 .42607 L .38712 .42614 L F
.38552 .4265 m .3847 .42681 L .38515 .42722 L .675 .735 .895 r
F
.39018 .42189 m .3866 .42251 L .38693 .42311 L F
.38709 .42067 m .38585 .41891 L .38482 .41977 L F
.39018 .42189 m .38774 .42021 L .38709 .42067 L F
.38656 .42028 m .38656 .42191 L .38655 .42011 L .79 .631 .071 r
F
.38656 .42191 m .38655 .42177 L .38655 .42011 L F
.38696 .41935 m .38655 .42011 L .38654 .4217 L 0 0 .372 r
F
.38658 .42626 m .38659 .42608 L .38659 .42794 L .79 .631 .071 r
F
.38658 .42509 m .38659 .42608 L .38658 .42626 L F
.38658 .42509 m .38659 .42533 L .38659 .42608 L F
.38656 .42028 m .38659 .42533 L .38658 .42509 L F
.38656 .42191 m .38655 .42476 L .38655 .42177 L F
.38655 .42476 m .38655 .42743 L .38655 .42469 L F
.38655 .42476 m .38655 .42469 L .38655 .42177 L F
.38696 .41935 m .38669 .42422 L .38691 .4238 L 0 0 .372 r
F
.38707 .42349 m .38645 .42324 L .38676 .42409 L .675 .735 .895 r
F
.38645 .42324 m .38515 .42272 L .38649 .42387 L F
.38655 .42476 m .38659 .42794 L .38655 .42743 L .79 .631 .071 r
F
.38656 .42028 m .38658 .42509 L .38655 .42476 L F
.38658 .42509 m .38659 .42794 L .38655 .42476 L F
.38467 .42395 m .38109 .42776 L .38563 .42482 L .675 .735 .895 r
F
.38659 .42537 m .38393 .4247 L .3841 .42579 L F
.39023 .42474 m .38655 .42472 L .38659 .42537 L F
.38655 .42472 m .38393 .4247 L .38659 .42537 L F
.38659 .42395 m .38654 .42391 L .38654 .42452 L 0 0 .372 r
F
.38669 .42268 m .38671 .42553 L .38663 .42257 L .989 .72 .388 r
F
.38693 .42598 m .38552 .4265 L .38724 .42649 L .675 .735 .895 r
F
.38697 .42601 m .38724 .42649 L .38752 .42649 L F
.38693 .42598 m .38724 .42649 L .38697 .42601 L F
.38672 .42818 m .38664 .42805 L .38663 .42539 L .989 .72 .388 r
F
.38667 .42548 m .38663 .42539 L .3866 .42089 L F
.38672 .42818 m .38663 .42539 L .38667 .42548 L F
.38671 .42553 m .38672 .42818 L .38667 .42548 L F
.38671 .42553 m .38667 .42548 L .38663 .42257 L F
.38625 .42472 m .38418 .42362 L .38393 .4247 L .675 .735 .895 r
F
.38698 .42158 m .38704 .42607 L .38697 .42601 L .929 .648 .488 r
F
.39023 .42474 m .38633 .42402 L .38625 .42472 L .675 .735 .895 r
F
.38785 .42294 m .38706 .42619 L .3878 .42572 L .398 .209 .505 r
F
.39018 .42189 m .38709 .42067 L .38636 .42118 L .675 .735 .895 r
F
.39018 .42189 m .3866 .42251 L .3866 .42251 L F
.38539 .42186 m .38416 .42077 L .38391 .42186 L F
.38696 .41935 m .38694 .42093 L .38708 .41914 L 0 0 .372 r
F
.38694 .42093 m .38688 .42652 L .38703 .42075 L F
.38694 .42093 m .38703 .42075 L .38708 .41914 L F
.38646 .42187 m .38636 .42118 L .38539 .42186 L .675 .735 .895 r
F
.38669 .42104 m .38669 .42268 L .3866 .42089 L .989 .72 .388 r
F
.39018 .42189 m .38677 .42126 L .38646 .42187 L .675 .735 .895 r
F
.38677 .42126 m .38636 .42118 L .38646 .42187 L F
.38636 .42118 m .38416 .42077 L .38539 .42186 L F
.38792 .42008 m .3874 .42326 L .38785 .42294 L .398 .209 .505 r
F
.38795 .41858 m .38776 .42019 L .38792 .42008 L F
.38776 .42019 m .3874 .42326 L .38792 .42008 L F
.39023 .42474 m .38707 .42349 L .38676 .42409 L .675 .735 .895 r
F
.3878 .42572 m .38801 .42558 L .38808 .42278 L .398 .209 .505 r
F
.38795 .42287 m .38808 .42278 L .3882 .41842 L F
.39023 .42474 m .38756 .4229 L .38707 .42349 L .675 .735 .895 r
F
.38776 .42019 m .38707 .42068 L .38707 .42349 L .398 .209 .505 r
F
.3874 .42326 m .38707 .42349 L .38706 .42619 L F
.38776 .42019 m .38707 .42349 L .3874 .42326 L F
.38686 .42108 m .38654 .4217 L .38654 .42391 L 0 0 .372 r
F
.38695 .42371 m .38702 .42359 L .38708 .41914 L F
.38774 .42302 m .38722 .42108 L .38589 .42174 L .675 .735 .895 r
F
.39018 .42189 m .38693 .42311 L .38718 .42357 L F
.39023 .42474 m .38848 .42261 L .38774 .42302 L F
.38896 .42246 m .38818 .42547 L .38891 .42528 L .567 .342 .533 r
F
.38906 .4182 m .38853 .42259 L .38896 .42246 L F
.38853 .42259 m .38818 .42547 L .38896 .42246 L F
.39018 .42189 m .38845 .4198 L .38756 .42009 L .675 .735 .895 r
F
.38888 .41967 m .38819 .4227 L .38853 .42259 L .567 .342 .533 r
F
.38848 .42261 m .38842 .42254 L .38819 .4227 L .675 .735 .895 r
F
.38848 .42261 m .38819 .4227 L .38774 .42302 L F
.38842 .42254 m .38722 .42108 L .38774 .42302 L F
.38756 .4229 m .38742 .4228 L .38734 .42297 L F
.38756 .4229 m .38734 .42297 L .38707 .42349 L F
.38888 .41967 m .38819 .41988 L .38819 .4227 L .567 .342 .533 r
F
.38853 .42259 m .38819 .4227 L .38818 .42547 L F
.3878 .42572 m .38808 .42278 L .38795 .42287 L .398 .209 .505 r
F
.3874 .42326 m .38706 .42619 L .38785 .42294 L F
.38633 .42402 m .38581 .42392 L .38599 .42425 L .675 .735 .895 r
F
.38633 .42402 m .38599 .42425 L .38625 .42472 L F
.38581 .42392 m .38418 .42362 L .38625 .42472 L F
.38686 .42108 m .38654 .42391 L .38659 .42395 L 0 0 .372 r
F
.38645 .42324 m .38649 .42387 L .38676 .42409 L .675 .735 .895 r
F
.38686 .42108 m .38654 .42452 L .38669 .42422 L 0 0 .372 r
F
.38707 .42349 m .38637 .42208 L .38645 .42324 L .675 .735 .895 r
F
.38742 .4228 m .38637 .42208 L .38707 .42349 L F
.38655 .42011 m .38654 .42728 L .38653 .42716 L .79 .631 .071 r
F
.38655 .42743 m .38654 .42728 L .38655 .42011 L F
.3866 .42089 m .38664 .42805 L .38659 .42794 L .989 .72 .388 r
F
.38669 .42422 m .38654 .42452 L .38653 .42716 L 0 0 .372 r
F
.38696 .41935 m .38654 .4217 L .38686 .42108 L F
.38795 .41858 m .38707 .42068 L .38776 .42019 L .398 .209 .505 r
F
.38774 .42021 m .38743 .41999 L .38709 .42067 L .675 .735 .895 r
F
.38743 .41999 m .38585 .41891 L .38708 .42066 L F
.38743 .41999 m .38708 .42066 L .38709 .42067 L F
.38711 .40608 m .38655 .42011 L .38696 .41935 L 0 0 .372 r
F
.38374 .41837 m .3644 .40852 L .3611 .41324 L .654 .726 .902 r
F
.38823 .40529 m .38708 .41914 L .38795 .41858 L .398 .209 .505 r
F
.39116 .42006 m .38693 .41824 L .38374 .41837 L .654 .726 .902 r
F
.38693 .41824 m .3644 .40852 L .38374 .41837 L F
.39043 .40486 m .38934 .40495 L .3893 .41813 L .66 .416 .54 r
F
.38704 .42607 m .38707 .42872 L .38697 .42601 L .929 .648 .488 r
F
.38691 .4238 m .38653 .42716 L .38688 .42652 L 0 0 .372 r
F
.38686 .42582 m .38697 .42601 L .38697 .42863 L .989 .72 .388 r
F
.38783 .42932 m .38778 .4293 L .38765 .42217 L .845 .571 .524 r
F
.38765 .42217 m .38778 .4293 L .38763 .42922 L F
.39072 .42734 m .38552 .42616 L .38378 .42662 L .654 .726 .902 r
F
.38933 .4369 m .3901 .46866 L .38909 .43686 L .751 .491 .538 r
F
.38945 .43008 m .38942 .43011 L .38944 .43011 L .654 .726 .902 r
F
.38954 .42989 m .38869 .43172 L .39061 .4301 L F
.3902 .43011 m .38851 .43164 L .39013 .43179 L .675 .735 .895 r
F
.38916 .42982 m .3902 .43002 L .3902 .43011 L .751 .491 .538 r
F
.38916 .42982 m .3902 .43011 L .38918 .42996 L F
.38973 .42722 m .3902 .4273 L .3902 .43002 L F
.39029 .42759 m .38924 .42997 L .3902 .43011 L .675 .735 .895 r
F
.38944 .43011 m .38904 .43048 L .3892 .43062 L .654 .726 .902 r
F
.38924 .42997 m .38851 .43164 L .3902 .43011 L .675 .735 .895 r
F
.38918 .42996 m .3902 .43011 L .39018 .43707 L .751 .491 .538 r
F
.39018 .43707 m .38916 .43704 L .39016 .43753 L .654 .726 .902 r
F
.38923 .43688 m .38916 .43704 L .39018 .43707 L F
.38933 .4369 m .39018 .43707 L .3901 .46866 L .751 .491 .538 r
F
.38916 .42982 m .39018 .43707 L .38933 .4369 L F
.39027 .43463 m .38923 .43688 L .39018 .43707 L .654 .726 .902 r
F
.39027 .43463 m .3886 .43676 L .38923 .43688 L F
.39023 .42474 m .38863 .42705 L .38918 .42714 L .675 .735 .895 r
F
.38839 .43697 m .38882 .43735 L .38916 .43704 L .654 .726 .902 r
F
.38923 .43688 m .3886 .43676 L .38916 .43704 L F
.38909 .43686 m .3901 .46866 L .3886 .43676 L .751 .491 .538 r
F
.38916 .43704 m .38896 .43747 L .39016 .43753 L .654 .726 .902 r
F
.38778 .43717 m .38128 .44382 L .38793 .43743 L F
.38128 .44382 m .37388 .45139 L .38102 .4443 L F
.38128 .44382 m .38102 .4443 L .38793 .43743 L F
.3885 .43846 m .38139 .45382 L .38909 .43952 L F
.38713 .44316 m .38139 .45382 L .38794 .45472 L F
.38366 .43198 m .38038 .4356 L .38489 .43689 L .675 .735 .895 r
F
.38787 .43025 m .38384 .43209 L .38104 .43724 L .654 .726 .902 r
F
.38707 .42872 m .38715 .43586 L .38697 .42863 L .929 .648 .488 r
F
.38034 .43853 m .37686 .44492 L .38184 .44653 L .654 .726 .902 r
F
.38128 .44382 m .36748 .44782 L .37388 .45139 L F
.38817 .43677 m .38386 .43907 L .38128 .44382 L F
.38034 .43853 m .37433 .44411 L .37686 .44492 L F
.38386 .43907 m .36748 .44782 L .38128 .44382 L F
.38733 .42949 m .38572 .43054 L .3878 .43033 L .675 .735 .895 r
F
.38672 .42838 m .38665 .42826 L .38664 .42805 L .989 .72 .388 r
F
.38672 .42818 m .38697 .42863 L .38697 .42883 L F
.38672 .42818 m .38697 .42883 L .38672 .42839 L F
.38652 .42867 m .38188 .4284 L .38528 .42906 L .654 .726 .902 r
F
.3847 .42681 m .3811 .43063 L .38567 .42769 L .675 .735 .895 r
F
.38518 .42801 m .38188 .4284 L .38652 .42867 L .654 .726 .902 r
F
.39029 .42759 m .38416 .42864 L .38475 .42966 L .675 .735 .895 r
F
.38698 .42634 m .38688 .43354 L .38706 .42619 L 0 0 .372 r
F
.38812 .43673 m .36748 .44782 L .38817 .43677 L .654 .726 .902 r
F
.38751 .43622 m .36748 .44782 L .38832 .43662 L F
.38678 .44402 m .38687 .46732 L .38675 .44596 L .989 .72 .388 r
F
.38691 .43987 m .37388 .45139 L .38703 .44164 L .654 .726 .902 r
F
.38678 .44402 m .38675 .44596 L .38669 .43521 L .989 .72 .388 r
F
.38674 .43531 m .38678 .44402 L .38669 .43521 L F
.38102 .4443 m .38059 .44508 L .38882 .43735 L .654 .726 .902 r
F
.38059 .44508 m .38021 .44579 L .3885 .43846 L F
.38761 .43627 m .38853 .46839 L .38753 .46792 L .845 .571 .524 r
F
.38763 .42922 m .38779 .43636 L .38761 .43627 L F
.38779 .43636 m .38853 .46839 L .38761 .43627 L F
.38163 .43803 m .38038 .4356 L .38489 .43689 L .794 .529 .536 r
F
.38059 .4377 m .37433 .44411 L .38107 .43785 L .654 .726 .902 r
F
.38043 .43845 m .38042 .43764 L .38163 .43803 L .794 .529 .536 r
F
.38042 .43764 m .38038 .4356 L .38163 .43803 L F
.3879 .43022 m .38059 .4377 L .38945 .43008 L .654 .726 .902 r
F
.38059 .4377 m .38107 .43785 L .38945 .43008 L F
.38372 .43483 m .38043 .43845 L .38494 .43974 L .675 .735 .895 r
F
.38751 .43622 m .37958 .438 L .36748 .44782 L .654 .726 .902 r
F
.38797 .42939 m .3886 .43676 L .38807 .4365 L .845 .571 .524 r
F
.39027 .43463 m .38662 .43578 L .38751 .43622 L .654 .726 .902 r
F
.38372 .43483 m .38494 .43974 L .38673 .43569 L .675 .735 .895 r
F
.38662 .43578 m .37958 .438 L .38751 .43622 L .654 .726 .902 r
F
.38104 .43724 m .36793 .44054 L .37433 .44411 L F
.37958 .438 m .36263 .44336 L .36614 .44659 L F
.37958 .438 m .36614 .44659 L .36748 .44782 L F
.387 .43121 m .38673 .43569 L .38851 .43164 L .675 .735 .895 r
F
.38807 .4365 m .38801 .43647 L .38783 .42932 L .845 .571 .524 r
F
.38786 .42933 m .38783 .42932 L .38765 .42217 L F
.38807 .4365 m .38783 .42932 L .38786 .42933 L F
.38795 .41858 m .38792 .42008 L .3882 .41842 L .398 .209 .505 r
F
.38711 .40608 m .38696 .41935 L .38708 .41914 L 0 0 .372 r
F
.38693 .41824 m .36954 .40459 L .3644 .40852 L .654 .726 .902 r
F
.39116 .42006 m .38852 .41817 L .38693 .41824 L F
.38852 .41817 m .36954 .40459 L .38693 .41824 L F
.37763 .42182 m .37136 .42178 L .37189 .42503 L .675 .735 .895 r
F
.37814 .42249 m .37209 .42137 L .37132 .42463 L F
.3825 .42548 m .36294 .41701 L .378 .42446 L .654 .726 .902 r
F
.39072 .42734 m .38537 .42535 L .3825 .42548 L F
.38408 .42294 m .37798 .42399 L .37916 .42601 L .675 .735 .895 r
F
.37763 .42182 m .37189 .42503 L .37798 .42399 L F
.37814 .41966 m .37212 .41854 L .37136 .42178 L F
.37209 .42137 m .37203 .41852 L .37127 .42178 L 0 0 .247 r
F
.38408 .42294 m .37916 .42601 L .38467 .42395 L .675 .735 .895 r
F
.38418 .42362 m .37763 .42467 L .38393 .4247 L F
.38391 .42186 m .37798 .42399 L .38408 .42294 L F
.38418 .42362 m .37814 .42249 L .37763 .42467 L F
.38537 .42535 m .36294 .41701 L .3825 .42548 L .654 .726 .902 r
F
.38391 .42186 m .37763 .42182 L .37798 .42399 L .675 .735 .895 r
F
.38416 .42077 m .37814 .41966 L .37763 .42182 L F
.37947 .41765 m .37212 .41854 L .37814 .41966 L F
.38485 .42261 m .37814 .42249 L .38418 .42362 L F
.37947 .41765 m .37411 .41552 L .37212 .41854 L F
.37409 .41834 m .37203 .41852 L .37209 .42137 L .11 .002 .439 r
F
.37409 .41834 m .37403 .41549 L .37203 .41852 L F
.38416 .42077 m .37763 .42182 L .38391 .42186 L .675 .735 .895 r
F
.38485 .42261 m .37947 .42047 L .37814 .42249 L F
.37947 .42047 m .37409 .41834 L .37209 .42137 L F
.38603 .42532 m .37718 .4183 L .37449 .42035 L .654 .726 .902 r
F
.37724 .41859 m .37684 .41856 L .37414 .42119 L .354 .183 .507 r
F
.37684 .41856 m .37409 .41834 L .37413 .42063 L F
.37684 .41856 m .37413 .42063 L .37414 .42119 L F
.37449 .42035 m .36898 .4118 L .36382 .41575 L .654 .726 .902 r
F
.38154 .41874 m .37719 .41574 L .37409 .41834 L .675 .735 .895 r
F
.37724 .41859 m .37719 .41574 L .37409 .41834 L .354 .183 .507 r
F
.37718 .4183 m .36898 .4118 L .37449 .42035 L .654 .726 .902 r
F
.39023 .42474 m .38828 .42689 L .38863 .42705 L .675 .735 .895 r
F
.38789 .42389 m .38863 .42705 L .38827 .42689 L .845 .571 .524 r
F
.39023 .42474 m .38747 .42652 L .38828 .42689 L .675 .735 .895 r
F
.39023 .42474 m .38693 .42598 L .38752 .42649 L F
.38688 .42652 m .38698 .42634 L .38702 .42359 L 0 0 .372 r
F
.39072 .42734 m .38779 .42525 L .38603 .42532 L .654 .726 .902 r
F
.38669 .42422 m .38653 .42716 L .38691 .4238 L 0 0 .372 r
F
.38589 .42174 m .37947 .42047 L .38485 .42261 L .675 .735 .895 r
F
.38482 .41977 m .37947 .41765 L .37814 .41966 L F
.38154 .41874 m .37409 .41834 L .37947 .42047 L F
.37719 .41574 m .37403 .41549 L .37409 .41834 L .354 .183 .507 r
F
.38779 .42525 m .36898 .4118 L .38603 .42532 L .654 .726 .902 r
F
.39024 .40998 m .39057 .42293 L .39021 .42297 L .641 .4 .539 r
F
.39116 .42006 m .37615 .40172 L .36954 .40459 L .654 .726 .902 r
F
.39015 .41809 m .3893 .41813 L .3893 .41954 L .66 .416 .54 r
F
.38932 .41953 m .39033 .41771 L .3887 .41784 L .675 .735 .895 r
F
.39018 .42189 m .39027 .41945 L .38932 .41953 L F
.38934 .40495 m .3882 .41842 L .38906 .4182 L .567 .342 .533 r
F
.38823 .40529 m .38795 .41858 L .3882 .41842 L .398 .209 .505 r
F
.39116 .42006 m .38378 .40009 L .37615 .40172 L .654 .726 .902 r
F
.39015 .41809 m .39012 .41946 L .3904 .41808 L .66 .416 .54 r
F
.39012 .41946 m .39032 .41944 L .3904 .41808 L F
.39015 .41809 m .3893 .41954 L .38998 .41947 L F
.39027 .41945 m .39033 .41771 L .38932 .41953 L .675 .735 .895 r
F
.38998 .41947 m .3893 .41954 L .38929 .42518 L .66 .416 .54 r
F
.38936 .42235 m .39039 .42054 L .38875 .42067 L .675 .735 .895 r
F
.39023 .42474 m .39033 .42226 L .38936 .42235 L F
.39006 .42228 m .39016 .42227 L .39032 .41944 L .66 .416 .54 r
F
.38995 .42666 m .39038 .42507 L .3894 .42516 L .675 .735 .895 r
F
.39029 .42759 m .3903 .42719 L .38995 .42666 L F
.3903 .42719 m .39038 .42507 L .38995 .42666 L F
.39 .4251 m .38929 .42518 L .39 .42515 L .66 .416 .54 r
F
.38929 .42517 m .38929 .42518 L .39 .4251 L F
.38792 .42008 m .38785 .42294 L .38811 .41994 L .398 .209 .505 r
F
.38785 .42294 m .3878 .42572 L .38795 .42287 L F
.38785 .42294 m .38795 .42287 L .38811 .41994 L F
.3882 .41842 m .38801 .42558 L .38818 .42547 L F
.38842 .42254 m .38875 .42067 L .38722 .42108 L .675 .735 .895 r
F
.38688 .42652 m .38702 .42359 L .38695 .42371 L 0 0 .372 r
F
.38676 .42409 m .38515 .42272 L .38581 .42392 L .675 .735 .895 r
F
.38515 .42272 m .38485 .42261 L .38581 .42392 L F
.38645 .42324 m .38589 .42174 L .38485 .42261 L F
.38637 .42208 m .38589 .42174 L .38645 .42324 L F
.38708 .41914 m .38698 .42634 L .38706 .42619 L 0 0 .372 r
F
.38482 .41977 m .37814 .41966 L .38416 .42077 L .675 .735 .895 r
F
.38585 .41891 m .37947 .41765 L .38482 .41977 L F
.38585 .41891 m .38153 .41592 L .37947 .41765 L F
.38153 .41592 m .37411 .41552 L .37947 .41765 L F
.38589 .42174 m .38154 .41874 L .37947 .42047 L F
.38636 .42118 m .38482 .41977 L .38416 .42077 L F
.38722 .42108 m .38154 .41874 L .38589 .42174 L F
.38153 .41592 m .3772 .41294 L .37411 .41552 L F
.37719 .41574 m .37713 .41289 L .37403 .41549 L .354 .183 .507 r
F
.3842 .41742 m .37719 .41574 L .38154 .41874 L .675 .735 .895 r
F
.38417 .41461 m .3772 .41294 L .38153 .41592 L F
.3842 .41742 m .38118 .41376 L .37719 .41574 L F
.38118 .41376 m .37713 .41289 L .37719 .41574 L .495 .291 .532 r
F
.39012 .42692 m .38162 .41635 L .37772 .41805 L .654 .726 .902 r
F
.38123 .41661 m .38109 .41658 L .37724 .41859 L .495 .291 .532 r
F
.38109 .41658 m .37719 .41574 L .37724 .41825 L F
.38109 .41658 m .37724 .41825 L .37724 .41859 L F
.37772 .41805 m .37562 .40891 L .36898 .4118 L .654 .726 .902 r
F
.38109 .41658 m .38118 .41376 L .37719 .41574 L .495 .291 .532 r
F
.38123 .41661 m .38123 .41652 L .38109 .41658 L F
.38123 .41652 m .38118 .41376 L .38109 .41658 L F
.38169 .41632 m .37773 .40846 L .37562 .40891 L .654 .726 .902 r
F
.38709 .42067 m .38482 .41977 L .38636 .42118 L .675 .735 .895 r
F
.38722 .42108 m .3842 .41742 L .38154 .41874 L F
.38901 .42525 m .38271 .41588 L .38169 .41632 L .654 .726 .902 r
F
.38417 .41461 m .38117 .41097 L .3772 .41294 L .675 .735 .895 r
F
.38118 .41376 m .38112 .41091 L .37713 .41289 L .495 .291 .532 r
F
.38271 .41588 m .37773 .40846 L .38169 .41632 L .654 .726 .902 r
F
.38162 .41635 m .37562 .40891 L .37772 .41805 L F
.39072 .42734 m .38901 .42525 L .39012 .42692 L F
.38901 .42525 m .37562 .40891 L .39012 .42692 L F
.3885 .42542 m .38862 .42468 L .38727 .42393 L .675 .735 .895 r
F
.38862 .42468 m .38881 .42352 L .38799 .42374 L F
.38862 .42468 m .38799 .42374 L .38727 .42393 L F
.39029 .42759 m .3894 .42513 L .3885 .42542 L F
.38891 .42528 m .38901 .42526 L .38919 .42238 L .567 .342 .533 r
F
.3894 .42513 m .38881 .42352 L .3885 .42542 L .675 .735 .895 r
F
.38901 .42526 m .38911 .42523 L .38912 .42522 L .567 .342 .533 r
F
.38901 .42526 m .38912 .42522 L .38919 .42238 L F
.38906 .42242 m .38919 .42238 L .3893 .41813 L F
.38891 .42528 m .38919 .42238 L .38906 .42242 L F
.38848 .42261 m .38922 .42197 L .38842 .42254 L .675 .735 .895 r
F
.39023 .42474 m .38936 .42233 L .38848 .42261 L F
.38906 .4182 m .38902 .41962 L .3893 .41813 L .567 .342 .533 r
F
.38902 .41962 m .38891 .42528 L .38922 .41956 L F
.38902 .41962 m .38922 .41956 L .3893 .41813 L F
.39018 .42189 m .38932 .41953 L .3893 .41954 L .675 .735 .895 r
F
.38906 .4182 m .38819 .41988 L .38888 .41967 L .567 .342 .533 r
F
.38845 .4198 m .3893 .41954 L .38831 .41963 L .675 .735 .895 r
F
.39018 .42189 m .3893 .41954 L .38845 .4198 L F
.38936 .42233 m .38922 .42197 L .38848 .42261 L F
.38922 .42197 m .38875 .42067 L .38842 .42254 L F
.38795 .41858 m .38708 .41914 L .38707 .42068 L .398 .209 .505 r
F
.38756 .42009 m .38718 .41825 L .38585 .41891 L .675 .735 .895 r
F
.38718 .41825 m .38153 .41592 L .38585 .41891 L F
.38718 .41825 m .38417 .41461 L .38153 .41592 L F
.38875 .42067 m .3842 .41742 L .38722 .42108 L F
.38792 .42008 m .38811 .41994 L .3882 .41842 L .398 .209 .505 r
F
.38845 .4198 m .38718 .41825 L .38756 .42009 L .675 .735 .895 r
F
.3887 .41784 m .38417 .41461 L .38718 .41825 L F
.38875 .42067 m .38727 .4166 L .3842 .41742 L F
.38723 .41379 m .38117 .41097 L .38417 .41461 L F
.38881 .42352 m .38733 .41945 L .38425 .42027 L F
.38727 .4166 m .38118 .41376 L .3842 .41742 L F
.3887 .41784 m .38723 .41379 L .38417 .41461 L F
.38727 .4166 m .38579 .41253 L .38118 .41376 L F
.38579 .41253 m .38112 .41091 L .38118 .41376 L .591 .365 .543 r
F
.38723 .41379 m .38576 .40974 L .38117 .41097 L .675 .735 .895 r
F
.38579 .41253 m .38573 .40968 L .38112 .41091 L .591 .365 .543 r
F
.38733 .41945 m .38584 .41538 L .38123 .41661 L .675 .735 .895 r
F
.38584 .41538 m .38118 .41376 L .38123 .41652 L .591 .365 .543 r
F
.3829 .41616 m .38123 .41652 L .38123 .41661 L F
.38584 .41538 m .38123 .41652 L .3829 .41616 L F
.38301 .41614 m .3833 .40727 L .37773 .40846 L .654 .726 .902 r
F
.38733 .41945 m .38123 .41661 L .38425 .42027 L .675 .735 .895 r
F
.38905 .42492 m .38598 .41551 L .38301 .41614 L .654 .726 .902 r
F
.38584 .41538 m .38579 .41253 L .38118 .41376 L .591 .365 .543 r
F
.38598 .41551 m .3833 .40727 L .38301 .41614 L .654 .726 .902 r
F
.39072 .42734 m .38967 .42452 L .38905 .42492 L F
.38847 .41935 m .3882 .41938 L .38819 .41988 L .567 .342 .533 r
F
.38906 .4182 m .3882 .41938 L .38847 .41935 L F
.38906 .4182 m .3882 .41842 L .3882 .41938 L F
.38831 .41963 m .3887 .41784 L .38718 .41825 L .675 .735 .895 r
F
.38932 .41953 m .3887 .41784 L .38831 .41963 L F
.39012 .41946 m .39006 .42228 L .39032 .41944 L .66 .416 .54 r
F
.39039 .42054 m .38727 .4166 L .38875 .42067 L .675 .735 .895 r
F
.3906 .41918 m .38584 .41538 L .38733 .41945 L F
.38967 .42452 m .3833 .40727 L .38905 .42492 L .654 .726 .902 r
F
.39072 .42734 m .37773 .40846 L .38901 .42525 L F
.39015 .41809 m .38929 .42517 L .39 .4251 L .66 .416 .54 r
F
.3894 .42516 m .39044 .42338 L .38881 .42352 L .675 .735 .895 r
F
.39 .42515 m .39021 .42514 L .3904 .41808 L .66 .416 .54 r
F
.39038 .42507 m .39044 .42338 L .3894 .42516 L .675 .735 .895 r
F
.39033 .42226 m .39039 .42054 L .38936 .42235 L F
.39006 .42228 m .39 .42515 L .39016 .42227 L .66 .416 .54 r
F
.38896 .43747 m .38979 .43822 L .39016 .43753 L .654 .726 .902 r
F
.38817 .43677 m .38778 .43717 L .38839 .43697 L F
.38778 .43717 m .38793 .43743 L .38839 .43697 L F
.38821 .43793 m .38686 .4392 L .3885 .43846 L F
.38807 .4365 m .38814 .44148 L .38801 .43647 L .845 .571 .524 r
F
.38814 .44148 m .38813 .44736 L .38792 .43642 L F
.38814 .44148 m .38792 .43642 L .38801 .43647 L F
.38942 .43011 m .38034 .43853 L .38944 .43011 L .654 .726 .902 r
F
.38778 .4293 m .38792 .43642 L .38763 .42922 L .845 .571 .524 r
F
.38713 .44316 m .38794 .45472 L .38951 .45493 L .654 .726 .902 r
F
.38792 .43642 m .38853 .46839 L .38779 .43636 L .845 .571 .524 r
F
.38792 .43642 m .38779 .43636 L .38763 .42922 L F
.38662 .43578 m .38362 .43543 L .37958 .438 L .654 .726 .902 r
F
.38719 .42883 m .38761 .43627 L .38726 .43595 L .929 .648 .488 r
F
.39027 .43463 m .38545 .43521 L .38662 .43578 L .654 .726 .902 r
F
.38545 .43521 m .38362 .43543 L .38662 .43578 L F
.38116 .43348 m .38043 .43845 L .38372 .43483 L .675 .735 .895 r
F
.38116 .43348 m .37659 .43643 L .38043 .43845 L F
.38362 .43543 m .38178 .43418 L .37139 .43689 L .654 .726 .902 r
F
.387 .43121 m .38372 .43483 L .38673 .43569 L .675 .735 .895 r
F
.39027 .43463 m .38528 .43437 L .38362 .43543 L .654 .726 .902 r
F
.38572 .43054 m .38116 .43348 L .38372 .43483 L .675 .735 .895 r
F
.38528 .43437 m .38178 .43418 L .38362 .43543 L .654 .726 .902 r
F
.38672 .42818 m .38672 .42838 L .38664 .42805 L .989 .72 .388 r
F
.38614 .42789 m .38541 .42724 L .38399 .42815 L .654 .726 .902 r
F
.39029 .42759 m .38399 .42755 L .38416 .42864 L .675 .735 .895 r
F
.38801 .42558 m .38782 .43275 L .38818 .42547 L .398 .209 .505 r
F
.38686 .4392 m .3869 .4398 L .3885 .43846 L .654 .726 .902 r
F
.3885 .43846 m .38691 .43987 L .38703 .44164 L F
.38726 .43595 m .38761 .43627 L .38753 .46792 L .929 .648 .488 r
F
.38801 .43647 m .38792 .43642 L .38778 .4293 L .845 .571 .524 r
F
.36485 .4333 m .36004 .42778 L .35878 .43298 L .654 .726 .902 r
F
.39072 .42734 m .38602 .42685 L .38566 .42708 L F
.38602 .42685 m .38378 .42662 L .38566 .42708 L F
.39072 .42734 m .38566 .42708 L .38541 .42724 L F
.39072 .42734 m .38541 .42724 L .38614 .42789 L F
.38566 .42708 m .38262 .42692 L .38399 .42815 L F
.39029 .42759 m .38424 .42647 L .38399 .42755 L .675 .735 .895 r
F
.38911 .42523 m .38893 .43233 L .38929 .42518 L .567 .342 .533 r
F
.37113 .42632 m .35962 .42409 L .35923 .4257 L .654 .726 .902 r
F
.38188 .4284 m .37178 .42961 L .38528 .42906 L F
.37178 .42961 m .36011 .43101 L .37206 .43009 L F
.37249 .43082 m .37185 .4279 L .37363 .43095 L .987 .712 .384 r
F
.37178 .42961 m .37206 .43009 L .38528 .42906 L .654 .726 .902 r
F
.3719 .43075 m .37188 .42978 L .37249 .43082 L .987 .712 .384 r
F
.37188 .42978 m .37185 .4279 L .37249 .43082 L F
.37768 .42752 m .37138 .42748 L .3719 .43075 L .675 .735 .895 r
F
.38125 .43259 m .36337 .42304 L .36004 .42778 L .654 .726 .902 r
F
.38715 .43586 m .38707 .43579 L .38697 .42863 L .929 .648 .488 r
F
.38697 .42863 m .38707 .43579 L .38695 .43568 L F
.38726 .43595 m .38715 .43586 L .38707 .42872 L F
.39053 .42753 m .38755 .42918 L .38847 .42964 L .654 .726 .902 r
F
.39072 .42734 m .3905 .42747 L .39053 .42753 L F
.3905 .42747 m .38755 .42918 L .39053 .42753 L F
.39029 .42759 m .38733 .42949 L .3878 .43033 L .675 .735 .895 r
F
.38891 .42528 m .38818 .42547 L .38816 .43252 L .567 .342 .533 r
F
.38832 .43662 m .38812 .43673 L .38817 .43677 L .654 .726 .902 r
F
.38817 .43677 m .38839 .43697 L .3886 .43676 L F
.38832 .43662 m .38825 .4367 L .3886 .43676 L F
.38807 .4365 m .3886 .43676 L .38853 .46839 L .845 .571 .524 r
F
.38814 .44148 m .38853 .46839 L .38813 .44736 L F
.37132 .42463 m .37127 .42178 L .37179 .42505 L .859 .661 .126 r
F
.37209 .42137 m .37127 .42178 L .37132 .42463 L 0 0 .247 r
F
.37814 .42249 m .37132 .42463 L .37763 .42467 L .675 .735 .895 r
F
.37233 .42318 m .36294 .41701 L .36049 .42049 L .654 .726 .902 r
F
.378 .42446 m .37313 .42205 L .37233 .42318 L F
.37371 .42123 m .37209 .42137 L .37213 .42347 L .11 .002 .439 r
F
.37313 .42205 m .36294 .41701 L .37233 .42318 L .654 .726 .902 r
F
.37414 .42119 m .37371 .42123 L .37214 .42422 L .11 .002 .439 r
F
.37371 .42123 m .37213 .42347 L .37214 .42422 L F
.38659 .42794 m .38665 .43515 L .38657 .435 L .989 .72 .388 r
F
.37798 .42399 m .37189 .42503 L .37365 .42807 L .675 .735 .895 r
F
.37185 .4279 m .37179 .42505 L .37357 .4281 L .987 .712 .384 r
F
.37763 .42467 m .37132 .42463 L .37185 .4279 L .675 .735 .895 r
F
.38393 .4247 m .37763 .42467 L .37798 .42685 L F
.38378 .42662 m .37167 .42535 L .38262 .42692 L .654 .726 .902 r
F
.37167 .42535 m .35962 .42409 L .37161 .42556 L F
.37167 .42535 m .37161 .42556 L .38262 .42692 L F
.37192 .42433 m .37132 .42463 L .37136 .42659 L 0 0 .247 r
F
.38378 .42662 m .36049 .42049 L .35962 .42409 L .654 .726 .902 r
F
.37153 .42761 m .37132 .42463 L .37185 .4279 L .859 .661 .126 r
F
.37138 .42748 m .37136 .42659 L .37153 .42761 L F
.37136 .42659 m .37132 .42463 L .37153 .42761 L F
.37113 .42632 m .35923 .4257 L .37145 .42716 L .654 .726 .902 r
F
.37132 .42636 m .37145 .42716 L .38188 .4284 L F
.37113 .42632 m .37145 .42716 L .37132 .42636 L F
.37214 .42422 m .37192 .42433 L .37138 .42748 L 0 0 .247 r
F
.37192 .42433 m .37136 .42659 L .37138 .42748 L F
.38467 .42395 m .37916 .42601 L .38109 .42776 L .675 .735 .895 r
F
.38393 .4247 m .37798 .42685 L .3841 .42579 L F
.38552 .42616 m .37221 .42315 L .38378 .42662 L .654 .726 .902 r
F
.37192 .42433 m .37209 .42137 L .37132 .42463 L 0 0 .247 r
F
.37221 .42315 m .36049 .42049 L .37211 .42355 L .654 .726 .902 r
F
.37221 .42315 m .37211 .42355 L .38378 .42662 L F
.37214 .42422 m .37213 .42347 L .37192 .42433 L 0 0 .247 r
F
.37213 .42347 m .37209 .42137 L .37192 .42433 L F
.38674 .43531 m .38669 .43521 L .38664 .42805 L .989 .72 .388 r
F
.38654 .43457 m .38653 .43445 L .38654 .42728 L .79 .631 .071 r
F
.3841 .42579 m .37798 .42685 L .37916 .42888 L .675 .735 .895 r
F
.38262 .42692 m .37113 .42632 L .37904 .42785 L .654 .726 .902 r
F
.38653 .43445 m .38652 .43435 L .38653 .42716 L .79 .631 .071 r
F
.38672 .42818 m .38695 .43568 L .38674 .43531 L .989 .72 .388 r
F
.38572 .43054 m .38372 .43483 L .387 .43121 L .675 .735 .895 r
F
.38475 .42966 m .38116 .43348 L .38572 .43054 L F
.38416 .42864 m .37922 .43173 L .38475 .42966 L F
.38416 .42864 m .37803 .42969 L .37922 .43173 L F
.38262 .42692 m .37904 .42785 L .38188 .4284 L .654 .726 .902 r
F
.38399 .42755 m .37768 .42752 L .37803 .42969 L .675 .735 .895 r
F
.37819 .42534 m .37138 .42748 L .37768 .42752 L F
.37819 .42534 m .37214 .42422 L .37138 .42748 L F
.38704 .43324 m .36853 .41909 L .36337 .42304 L .654 .726 .902 r
F
.38797 .42939 m .38862 .42971 L .38862 .42987 L .845 .571 .524 r
F
.38917 .43013 m .387 .43121 L .38851 .43164 L .675 .735 .895 r
F
.38834 .42974 m .387 .43121 L .38917 .43013 L F
.38798 .42958 m .38862 .42987 L .3886 .43676 L .845 .571 .524 r
F
.38797 .42939 m .38862 .42987 L .38798 .42958 L F
.39072 .42734 m .3879 .43022 L .38945 .43008 L .654 .726 .902 r
F
.39029 .42759 m .38834 .42974 L .38917 .43013 L .675 .735 .895 r
F
.39027 .43463 m .38772 .43281 L .38704 .43324 L .654 .726 .902 r
F
.38655 .42743 m .38657 .435 L .38654 .43457 L .79 .631 .071 r
F
.38772 .43281 m .36853 .41909 L .38704 .43324 L .654 .726 .902 r
F
.39072 .42734 m .38603 .42532 L .38537 .42535 L F
.38719 .42883 m .38726 .43595 L .38707 .42872 L .929 .648 .488 r
F
.3878 .42572 m .38706 .42619 L .38704 .43324 L .398 .209 .505 r
F
.39027 .43463 m .38643 .43297 L .38556 .4332 L .654 .726 .902 r
F
.3858 .43361 m .38556 .4332 L .38482 .43339 L F
.39027 .43463 m .38556 .4332 L .3858 .43361 L F
.38664 .42805 m .38669 .43521 L .38659 .42794 L .989 .72 .388 r
F
.38669 .43521 m .38674 .44392 L .38665 .43515 L F
.38669 .43521 m .38665 .43515 L .38659 .42794 L F
.38715 .43586 m .38753 .46792 L .38707 .43579 L .929 .648 .488 r
F
.38695 .43568 m .38753 .46792 L .38687 .46732 L F
.38707 .43579 m .38753 .46792 L .38695 .43568 L F
.38726 .43595 m .38753 .46792 L .38715 .43586 L F
.38764 .43286 m .38704 .43324 L .38696 .46476 L .398 .209 .505 r
F
.38719 .42883 m .38763 .42922 L .38761 .43627 L .929 .648 .488 r
F
.3878 .42572 m .38704 .43324 L .38764 .43286 L .398 .209 .505 r
F
.37814 .41966 m .37136 .42178 L .37763 .42182 L .675 .735 .895 r
F
.37947 .42047 m .37209 .42137 L .37814 .42249 L F
.37383 .42106 m .36382 .41575 L .36294 .41701 L .654 .726 .902 r
F
.38537 .42535 m .37428 .42041 L .37383 .42106 L F
.37371 .42123 m .37409 .41834 L .37209 .42137 L .11 .002 .439 r
F
.37428 .42041 m .36382 .41575 L .37383 .42106 L .654 .726 .902 r
F
.37414 .42119 m .37413 .42063 L .37371 .42123 L .11 .002 .439 r
F
.37413 .42063 m .37409 .41834 L .37371 .42123 L F
.38603 .42532 m .36382 .41575 L .38537 .42535 L .654 .726 .902 r
F
.38688 .43354 m .38695 .43342 L .38706 .42619 L 0 0 .372 r
F
.38706 .42619 m .38695 .43342 L .38704 .43324 L F
.38672 .42838 m .38674 .43531 L .38665 .42826 L .989 .72 .388 r
F
.38672 .42839 m .38697 .42883 L .38695 .43568 L F
.38688 .42652 m .38651 .43421 L .3868 .43369 L 0 0 .372 r
F
.3868 .43369 m .38688 .43354 L .38698 .42634 L F
.38653 .42716 m .38652 .43435 L .38651 .43421 L .79 .631 .071 r
F
.38655 .42743 m .38659 .42794 L .38657 .435 L F
.38399 .42755 m .37803 .42969 L .38416 .42864 L .675 .735 .895 r
F
.38566 .42708 m .38378 .42662 L .38262 .42692 L .654 .726 .902 r
F
.38424 .42647 m .37768 .42752 L .38399 .42755 L .675 .735 .895 r
F
.38424 .42647 m .37819 .42534 L .37768 .42752 L F
.38491 .42546 m .37819 .42534 L .38424 .42647 L F
.38491 .42546 m .37952 .42332 L .37819 .42534 L F
.37952 .42332 m .37214 .42422 L .37819 .42534 L F
.37952 .42332 m .37414 .42119 L .37214 .42422 L F
.38159 .42159 m .37414 .42119 L .37952 .42332 L F
.38159 .42159 m .37724 .41859 L .37414 .42119 L F
.39027 .43463 m .37517 .4162 L .36853 .41909 L .654 .726 .902 r
F
.38876 .43237 m .38816 .43252 L .38809 .46397 L .567 .342 .533 r
F
.38891 .42528 m .38816 .43252 L .38876 .43237 L F
.38482 .43339 m .38514 .43242 L .38125 .43259 L .654 .726 .902 r
F
.38643 .43297 m .38514 .43242 L .38482 .43339 L F
.38475 .42966 m .37922 .43173 L .38116 .43348 L .675 .735 .895 r
F
.37768 .42752 m .3719 .43075 L .37803 .42969 L F
.38514 .43242 m .36337 .42304 L .38125 .43259 L .654 .726 .902 r
F
.39 .42515 m .38929 .42518 L .38927 .43224 L .66 .416 .54 r
F
.38985 .43221 m .38927 .43224 L .38919 .46363 L F
.39 .42515 m .38927 .43224 L .38985 .43221 L F
.38893 .43233 m .38809 .46397 L .38907 .43229 L .567 .342 .533 r
F
.38916 .42982 m .38933 .4369 L .38898 .42978 L .751 .491 .538 r
F
.38893 .43233 m .38907 .43229 L .38929 .42518 L .567 .342 .533 r
F
.3783 .43179 m .36656 .43928 L .36793 .44054 L .654 .726 .902 r
F
.37922 .43173 m .37659 .43643 L .38116 .43348 L .675 .735 .895 r
F
.37922 .43173 m .37368 .4338 L .37659 .43643 L F
.38178 .43418 m .38125 .43259 L .36485 .4333 L .654 .726 .902 r
F
.38862 .42971 m .38909 .43686 L .3886 .43676 L .751 .491 .538 r
F
.39027 .43463 m .38482 .43339 L .38178 .43418 L .654 .726 .902 r
F
.38482 .43339 m .38125 .43259 L .38178 .43418 L F
.37803 .42969 m .37368 .4338 L .37922 .43173 L .675 .735 .895 r
F
.37803 .42969 m .3719 .43075 L .37368 .4338 L F
.38125 .43259 m .36004 .42778 L .36485 .4333 L .654 .726 .902 r
F
.39029 .42759 m .38727 .42393 L .38594 .42459 L .675 .735 .895 r
F
.39021 .42514 m .39002 .4322 L .39038 .42514 L .66 .416 .54 r
F
.39002 .4322 m .38919 .46363 L .39016 .4322 L F
.39002 .4322 m .39016 .4322 L .39038 .42514 L F
.38782 .43275 m .38696 .46476 L .38796 .43265 L .398 .209 .505 r
F
.38797 .42939 m .38807 .4365 L .38786 .42933 L .845 .571 .524 r
F
.38801 .43647 m .38778 .4293 L .38783 .42932 L F
.38782 .43275 m .38796 .43265 L .38818 .42547 L .398 .209 .505 r
F
.38896 .43747 m .3885 .43846 L .38979 .43822 L .654 .726 .902 r
F
.3885 .43846 m .38909 .43952 L .38979 .43822 L F
.38927 .43224 m .38809 .46397 L .38919 .46363 L .567 .342 .533 r
F
.38929 .42518 m .38907 .43229 L .38927 .43224 L F
.39027 .43463 m .38832 .43662 L .3886 .43676 L .654 .726 .902 r
F
.38907 .43229 m .38809 .46397 L .38927 .43224 L .567 .342 .533 r
F
.37139 .43689 m .36485 .4333 L .35966 .4383 L .654 .726 .902 r
F
.38178 .43418 m .36485 .4333 L .37139 .43689 L F
.36011 .43101 m .33546 .4448 L .36308 .43607 L F
.36485 .4333 m .35878 .43298 L .35888 .43356 L F
.36485 .4333 m .35888 .43356 L .35966 .4383 L F
.39029 .42759 m .38491 .42546 L .38424 .42647 L .675 .735 .895 r
F
.39 .42515 m .38985 .43221 L .39021 .42514 L .66 .416 .54 r
F
.38985 .43221 m .38919 .46363 L .39002 .4322 L F
.38985 .43221 m .39002 .4322 L .39021 .42514 L F
.38816 .43252 m .38696 .46476 L .38809 .46397 L .398 .209 .505 r
F
.38818 .42547 m .38796 .43265 L .38816 .43252 L F
.38796 .43265 m .38696 .46476 L .38816 .43252 L F
.37958 .438 m .37139 .43689 L .36263 .44336 L .654 .726 .902 r
F
.38362 .43543 m .37139 .43689 L .37958 .438 L F
.37139 .43689 m .35966 .4383 L .3605 .43973 L F
.37139 .43689 m .3605 .43973 L .36263 .44336 L F
.38891 .42528 m .38876 .43237 L .38911 .42523 L .567 .342 .533 r
F
.39027 .43463 m .38751 .43622 L .38832 .43662 L .654 .726 .902 r
F
.38876 .43237 m .38809 .46397 L .38893 .43233 L .567 .342 .533 r
F
.38886 .42976 m .38909 .43686 L .38862 .42971 L .751 .491 .538 r
F
.38876 .43237 m .38893 .43233 L .38911 .42523 L .567 .342 .533 r
F
.39038 .42514 m .38919 .46363 L .39029 .46354 L .66 .416 .54 r
F
.39043 .40486 m .39015 .41809 L .3904 .41808 L F
.39043 .40486 m .3893 .41813 L .39015 .41809 L F
.38934 .40495 m .38906 .4182 L .3893 .41813 L .567 .342 .533 r
F
.39152 .40499 m .3904 .41808 L .39124 .41821 L .734 .477 .539 r
F
.39116 .42006 m .39192 .39982 L .38378 .40009 L .654 .726 .902 r
F
.39124 .41821 m .3904 .41808 L .3904 .41943 L .734 .477 .539 r
F
.39027 .41942 m .39195 .41786 L .39033 .41771 L .675 .735 .895 r
F
.39018 .42189 m .39122 .41952 L .3904 .41943 L F
.3904 .41943 m .39029 .42226 L .39039 .42225 L .66 .416 .54 r
F
.3904 .41808 m .39036 .41944 L .3904 .41943 L F
.39036 .41944 m .39029 .42226 L .3904 .41943 L F
.39027 .41945 m .3904 .41943 L .39027 .41942 L .675 .735 .895 r
F
.39018 .42189 m .3904 .41943 L .39027 .41945 L F
.39124 .41821 m .3904 .41943 L .39097 .41949 L .734 .477 .539 r
F
.39121 .41952 m .39039 .42225 L .39115 .42233 L F
.39124 .41821 m .39097 .41949 L .39121 .41952 L F
.39018 .42189 m .39223 .41963 L .39122 .41952 L .675 .735 .895 r
F
.39097 .41949 m .39039 .42225 L .39121 .41952 L .734 .477 .539 r
F
.3926 .40537 m .39149 .41824 L .39232 .41855 L .81 .54 .531 r
F
.39193 .41841 m .39255 .41864 L .39202 .41822 L .654 .726 .902 r
F
.3926 .40537 m .39232 .41855 L .39257 .41864 L .81 .54 .531 r
F
.39255 .41864 m .39255 .41864 L .39193 .41841 L .654 .726 .902 r
F
.39122 .41952 m .39345 .41829 L .39195 .41786 L .675 .735 .895 r
F
.39229 .41982 m .39145 .43235 L .39203 .43256 L .81 .54 .531 r
F
.39232 .41855 m .39224 .4198 L .39229 .41982 L F
.39189 .42545 m .39192 .42546 L .39229 .41982 L F
.39148 .42236 m .39131 .42516 L .39147 .42518 L .734 .477 .539 r
F
.39124 .41821 m .39115 .42233 L .39149 .41824 L F
.39023 .42474 m .39231 .42245 L .39129 .42234 L .675 .735 .895 r
F
.39363 .41947 m .39345 .4264 L .39361 .42652 L .909 .63 .5 r
F
.39307 .42228 m .3948 .42179 L .39287 .42183 L .675 .735 .895 r
F
.39339 .41929 m .3933 .42329 L .39363 .41947 L .909 .63 .5 r
F
.39292 .423 m .3948 .42179 L .39226 .4225 L .675 .735 .895 r
F
.39353 .42064 m .39566 .42095 L .3941 .42043 L F
.39425 .42119 m .39566 .42095 L .39353 .42064 L F
.39566 .42095 m .39628 .42084 L .3941 .42043 L F
.39255 .41864 m .40749 .40336 L .39202 .41822 L .654 .726 .902 r
F
.39308 .4229 m .39339 .42301 L .39329 .42277 L .675 .735 .895 r
F
.3936 .42348 m .39426 .42324 L .39329 .42277 L F
.39394 .42426 m .39398 .42436 L .39408 .42049 L .985 .728 .342 r
F
.39426 .42324 m .39433 .42275 L .39329 .42277 L .675 .735 .895 r
F
.39329 .42277 m .39564 .42272 L .3948 .42179 L F
.39628 .42084 m .4012 .41777 L .39569 .41983 L F
.39569 .41983 m .39927 .41603 L .39472 .41896 L F
.39569 .41983 m .4012 .41777 L .39927 .41603 L F
.39472 .41896 m .39927 .41603 L .39672 .41468 L F
.4012 .41777 m .40381 .41309 L .39927 .41603 L F
.3948 .42179 m .39681 .41749 L .39352 .42112 L F
.3948 .42179 m .39937 .41885 L .39681 .41749 L F
.39927 .41603 m .39999 .41108 L .39672 .41468 L F
.39927 .41603 m .40381 .41309 L .39999 .41108 L F
.39286 .42014 m .39256 .41991 L .39256 .42273 L .909 .63 .5 r
F
.3927 .42284 m .39256 .42273 L .39255 .42554 L F
.39286 .42014 m .39256 .42273 L .3927 .42284 L F
.39231 .42245 m .39352 .42112 L .39173 .4221 L .675 .735 .895 r
F
.39217 .42244 m .39173 .4221 L .39129 .42234 L F
.39231 .42245 m .39173 .4221 L .39217 .42244 L F
.39226 .4225 m .39307 .42228 L .39287 .42183 L F
.39324 .42042 m .39289 .42298 L .39336 .42052 L .909 .63 .5 r
F
.39358 .42397 m .39385 .41949 L .39207 .42354 L .675 .735 .895 r
F
.39358 .42397 m .39686 .42034 L .39385 .41949 L F
.39937 .41885 m .4001 .41387 L .39681 .41749 L F
.39937 .41885 m .40394 .4159 L .4001 .41387 L F
.4012 .41777 m .40671 .41571 L .40381 .41309 L F
.40394 .4159 m .40388 .41305 L .40004 .41102 L .861 .585 .519 r
F
.39681 .41749 m .4001 .41387 L .39558 .41258 L .675 .735 .895 r
F
.40394 .4159 m .40004 .41102 L .4001 .41387 L .861 .585 .519 r
F
.39202 .41822 m .40749 .40336 L .40001 .40094 L .654 .726 .902 r
F
.39672 .41468 m .39999 .41108 L .3955 .40979 L .675 .735 .895 r
F
.4001 .41387 m .40004 .41102 L .39553 .40973 L .794 .529 .536 r
F
.39472 .41896 m .39672 .41468 L .39345 .41829 L .675 .735 .895 r
F
.39352 .42112 m .39681 .41749 L .3938 .41664 L F
.39686 .42034 m .39564 .41543 L .39385 .41949 L F
.39686 .42034 m .40015 .41672 L .39564 .41543 L F
.40015 .41672 m .4001 .41387 L .39558 .41258 L .794 .529 .536 r
F
.40015 .41672 m .39558 .41258 L .39564 .41543 L F
.39165 .42532 m .40713 .41056 L .39961 .40813 L .654 .726 .902 r
F
.39224 .42544 m .39247 .42548 L .39231 .42536 L .675 .735 .895 r
F
.39072 .42734 m .39256 .42546 L .39165 .42532 L .654 .726 .902 r
F
.39357 .42349 m .39416 .42394 L .39426 .42324 L .675 .735 .895 r
F
.39426 .42324 m .39564 .42272 L .39433 .42275 L F
.39564 .42272 m .39571 .42261 L .3948 .42179 L F
.39628 .42084 m .40237 .4198 L .4012 .41777 L F
.39645 .42193 m .40237 .4198 L .39628 .42084 L F
.39577 .42267 m .39937 .41885 L .3948 .42179 L F
.39577 .42267 m .40131 .4206 L .39937 .41885 L F
.39943 .42169 m .40015 .41672 L .39686 .42034 L F
.39256 .42546 m .40713 .41056 L .39165 .42532 L .654 .726 .902 r
F
.39115 .42233 m .39109 .42524 L .39138 .42235 L .734 .477 .539 r
F
.39231 .42536 m .3933 .42564 L .3929 .42472 L .675 .735 .895 r
F
.39564 .42272 m .39577 .42267 L .39571 .42261 L F
.39426 .42324 m .39636 .42369 L .39577 .42267 L F
.39414 .42407 m .39636 .42369 L .39426 .42324 L F
.40237 .4198 m .40671 .41571 L .4012 .41777 L F
.40237 .4198 m .40847 .41875 L .40671 .41571 L F
.39619 .42301 m .40272 .42196 L .39645 .42193 L F
.39636 .42369 m .40131 .4206 L .39577 .42267 L F
.40131 .4206 m .40394 .4159 L .39937 .41885 L F
.40131 .4206 m .40685 .41853 L .40394 .4159 L F
.40685 .41853 m .40679 .41568 L .40388 .41305 L .933 .65 .481 r
F
.39486 .42464 m .39686 .42034 L .39358 .42397 L .675 .735 .895 r
F
.39404 .42476 m .39654 .42478 L .39414 .42407 L F
.39486 .42464 m .39943 .42169 L .39686 .42034 L F
.40685 .41853 m .40388 .41305 L .40394 .4159 L .933 .65 .481 r
F
.4069 .42138 m .40685 .41853 L .40394 .4159 L F
.39943 .42169 m .404 .41875 L .40015 .41672 L .675 .735 .895 r
F
.4069 .42138 m .40394 .4159 L .404 .41875 L .933 .65 .481 r
F
.404 .41875 m .40394 .4159 L .4001 .41387 L .861 .585 .519 r
F
.404 .41875 m .4001 .41387 L .40015 .41672 L F
.39256 .42546 m .41353 .41413 L .40713 .41056 L .654 .726 .902 r
F
.39247 .42548 m .3933 .42564 L .39231 .42536 L .675 .735 .895 r
F
.39315 .42574 m .3933 .42564 L .39224 .42544 L F
.39072 .42734 m .39369 .42562 L .39256 .42546 L .654 .726 .902 r
F
.3933 .42564 m .39486 .42464 L .3929 .42472 L .675 .735 .895 r
F
.3945 .42487 m .40088 .42614 L .39553 .42401 L F
.39414 .42407 m .39654 .42478 L .39636 .42369 L F
.39645 .42193 m .40272 .42196 L .40237 .4198 L F
.39636 .42369 m .40249 .42263 L .40131 .4206 L F
.40136 .42345 m .404 .41875 L .39943 .42169 L F
.39369 .42562 m .41353 .41413 L .39256 .42546 L .654 .726 .902 r
F
.39023 .42474 m .39137 .42216 L .39033 .42226 L .675 .735 .895 r
F
.39115 .42233 m .39039 .42225 L .39038 .42514 L .734 .477 .539 r
F
.39362 .42637 m .39363 .42639 L .39394 .42426 L .985 .728 .342 r
F
.40221 .42413 m .40899 .422 L .40272 .42196 L .675 .735 .895 r
F
.39619 .42301 m .40221 .42413 L .40272 .42196 L F
.39553 .42401 m .40221 .42413 L .39619 .42301 L F
.40272 .42196 m .40847 .41875 L .40237 .4198 L F
.39654 .42478 m .40284 .42481 L .40249 .42263 L F
.39654 .42478 m .40249 .42263 L .39636 .42369 L F
.40862 .42158 m .40856 .41873 L .40679 .41568 L .987 .712 .383 r
F
.40249 .42263 m .40685 .41853 L .40131 .4206 L .675 .735 .895 r
F
.40249 .42263 m .40862 .42158 L .40685 .41853 L F
.40862 .42158 m .40679 .41568 L .40685 .41853 L .987 .712 .383 r
F
.40868 .42443 m .40862 .42158 L .40685 .41853 L F
.39583 .42552 m .39943 .42169 L .39486 .42464 L .675 .735 .895 r
F
.39583 .42552 m .40136 .42345 L .39943 .42169 L F
.40868 .42443 m .40685 .41853 L .4069 .42138 L .987 .712 .383 r
F
.40136 .42345 m .4069 .42138 L .404 .41875 L .675 .735 .895 r
F
.39072 .42734 m .41838 .41861 L .41353 .41413 L .654 .726 .902 r
F
.39628 .42586 m .40284 .42481 L .39654 .42478 L .675 .735 .895 r
F
.40914 .42485 m .40856 .41873 L .40862 .42158 L .858 .659 .124 r
F
.4092 .4277 m .40914 .42485 L .40862 .42158 L F
.40284 .42481 m .40862 .42158 L .40249 .42263 L .675 .735 .895 r
F
.39642 .42654 m .40136 .42345 L .39583 .42552 L F
.39642 .42654 m .40255 .42548 L .40136 .42345 L F
.40255 .42548 m .4069 .42138 L .40136 .42345 L F
.40255 .42548 m .40868 .42443 L .4069 .42138 L F
.39352 .42646 m .42133 .42367 L .41838 .41861 L .654 .726 .902 r
F
.39414 .42693 m .42133 .42367 L .39352 .42646 L F
.39072 .42734 m .39454 .42821 L .39538 .42759 L F
.39345 .4264 m .39326 .43332 L .39361 .42652 L .909 .63 .5 r
F
.3931 .43319 m .39345 .4264 L .39336 .42633 L F
.39391 .42719 m .39384 .43412 L .39399 .42739 L .985 .728 .342 r
F
.39133 .43233 m .40669 .41785 L .39916 .41542 L .654 .726 .902 r
F
.39027 .43463 m .39237 .43248 L .39133 .43233 L F
.39363 .43582 m .39361 .43586 L .39352 .42605 L .069 0 .411 r
F
.39361 .42652 m .39326 .43332 L .39359 .43358 L .909 .63 .5 r
F
.3931 .43319 m .39326 .43332 L .39345 .4264 L F
.39237 .43248 m .40669 .41785 L .39133 .43233 L .654 .726 .902 r
F
.39109 .42524 m .39038 .42514 L .39036 .43219 L .734 .477 .539 r
F
.39331 .43125 m .39632 .4349 L .39898 .43358 L .675 .735 .895 r
F
.39391 .42719 m .39359 .43358 L .39384 .43412 L .985 .728 .342 r
F
.39237 .43248 m .41309 .42142 L .40669 .41785 L .654 .726 .902 r
F
.39027 .43463 m .39365 .43267 L .39237 .43248 L F
.39391 .43428 m .39396 .43441 L .39406 .42755 L .985 .728 .342 r
F
.39406 .42755 m .39396 .43441 L .39405 .4346 L F
.39384 .43412 m .39391 .43428 L .39399 .42739 L F
.39365 .43267 m .41309 .42142 L .39237 .43248 L .654 .726 .902 r
F
.39109 .42524 m .39095 .43227 L .3913 .42527 L .734 .477 .539 r
F
.39095 .43227 m .39029 .46354 L .39112 .4323 L F
.39095 .43227 m .39112 .4323 L .3913 .42527 L F
.39095 .43227 m .39036 .43219 L .39029 .46354 L F
.39109 .42524 m .39036 .43219 L .39095 .43227 L F
.39115 .42233 m .39038 .42514 L .39109 .42524 L F
.39109 .42524 m .3913 .42527 L .39138 .42235 L F
.39115 .42233 m .39138 .42235 L .39149 .41824 L F
.39137 .42216 m .39202 .42069 L .39034 .42225 L .675 .735 .895 r
F
.39039 .42225 m .39034 .42225 L .39033 .42226 L F
.39137 .42216 m .39034 .42225 L .39039 .42225 L F
.39135 .42517 m .39207 .42354 L .39038 .42507 L F
.39131 .42516 m .3913 .42527 L .39147 .42518 L .734 .477 .539 r
F
.39293 .41893 m .3927 .42284 L .39339 .41929 L .909 .63 .5 r
F
.3927 .42284 m .39255 .42554 L .39289 .42298 L F
.3927 .42284 m .39289 .42298 L .39339 .41929 L F
.39148 .42191 m .39352 .42112 L .39202 .42069 L .675 .735 .895 r
F
.39129 .42234 m .39173 .4221 L .39148 .42191 L F
.39224 .4198 m .39189 .42545 L .39229 .41982 L .81 .54 .531 r
F
.39173 .4221 m .39352 .42112 L .39148 .42191 L .675 .735 .895 r
F
.39165 .42532 m .39961 .40813 L .39086 .42507 L .654 .726 .902 r
F
.39147 .4253 m .39086 .42507 L .3908 .4252 L F
.39147 .42518 m .3913 .42527 L .39147 .4253 L .734 .477 .539 r
F
.39165 .42532 m .39086 .42507 L .39147 .4253 L .654 .726 .902 r
F
.39189 .42545 m .39145 .43235 L .39192 .42546 L .81 .54 .531 r
F
.39223 .41963 m .39345 .41829 L .39129 .41948 L .675 .735 .895 r
F
.39148 .41955 m .39129 .41948 L .39122 .41952 L F
.39223 .41963 m .39129 .41948 L .39148 .41955 L F
.39122 .41952 m .39195 .41786 L .39027 .41942 L F
.39097 .41949 m .3904 .41943 L .39039 .42225 L .734 .477 .539 r
F
.39149 .41824 m .39138 .42235 L .39148 .42236 L F
.39033 .42224 m .39202 .42069 L .39039 .42054 L .675 .735 .895 r
F
.39033 .42226 m .39034 .42225 L .39033 .42224 L F
.39034 .42225 m .39202 .42069 L .39033 .42224 L F
.39039 .42225 m .39021 .42514 L .39038 .42514 L .66 .416 .54 r
F
.39029 .42226 m .39021 .42514 L .39039 .42225 L F
.3878 .42572 m .38764 .43286 L .38801 .42558 L .398 .209 .505 r
F
.38764 .43286 m .38696 .46476 L .38782 .43275 L F
.38764 .43286 m .38782 .43275 L .38801 .42558 L F
.38688 .43354 m .38643 .4658 L .38695 .43342 L 0 0 .372 r
F
.38674 .43531 m .38695 .43568 L .38687 .46732 L .989 .72 .388 r
F
.38674 .44392 m .38687 .46732 L .3865 .46078 L F
.3865 .46078 m .38687 .46732 L .38649 .46662 L F
.38704 .43324 m .38643 .4658 L .38696 .46476 L 0 0 .372 r
F
.38695 .43342 m .38643 .4658 L .38704 .43324 L F
.38657 .435 m .38674 .44392 L .3865 .46078 L .989 .72 .388 r
F
.38665 .43515 m .38674 .44392 L .38657 .435 L F
.3893 .41813 m .38911 .42523 L .38929 .42518 L .567 .342 .533 r
F
.38654 .43457 m .38649 .46662 L .38653 .43445 L .79 .631 .071 r
F
.38654 .42728 m .38653 .43445 L .38653 .42716 L F
.38688 .42652 m .38653 .42716 L .38651 .43421 L 0 0 .372 r
F
.38653 .43445 m .38649 .46662 L .38652 .43435 L .79 .631 .071 r
F
.38651 .43421 m .38649 .46662 L .38643 .4658 L F
.38652 .43435 m .38649 .46662 L .38651 .43421 L F
.38654 .43457 m .38657 .435 L .38649 .46662 L F
.3868 .43369 m .38651 .43421 L .38643 .4658 L 0 0 .372 r
F
.38102 .4443 m .37388 .45139 L .38059 .44508 L .654 .726 .902 r
F
.36777 .41475 m .3611 .41324 L .36097 .41375 L F
.36777 .41475 m .36097 .41375 L .35984 .41842 L F
.38686 .4392 m .38059 .44508 L .3869 .4398 L F
.38059 .44508 m .37388 .45139 L .38021 .44579 L F
.38688 .42652 m .3868 .43369 L .38698 .42634 L 0 0 .372 r
F
.3868 .43369 m .38643 .4658 L .38688 .43354 L F
.38703 .44164 m .37388 .45139 L .38139 .45382 L .654 .726 .902 r
F
.39038 .42507 m .39207 .42354 L .39044 .42338 L .675 .735 .895 r
F
.39138 .42235 m .3913 .42527 L .39148 .42236 L .734 .477 .539 r
F
.39152 .40499 m .39124 .41821 L .39149 .41824 L F
.39293 .41893 m .39257 .41864 L .39256 .41991 L .909 .63 .5 r
F
.39293 .41893 m .39256 .41991 L .39286 .42014 L F
.39257 .41864 m .39246 .41988 L .39256 .41991 L .81 .54 .531 r
F
.39221 .41965 m .39472 .41896 L .39345 .41829 L .675 .735 .895 r
F
.39288 .42015 m .39472 .41896 L .39221 .41965 L F
.39246 .41988 m .39224 .42262 L .39256 .41991 L .81 .54 .531 r
F
.39366 .4062 m .39293 .41893 L .39339 .41929 L .909 .63 .5 r
F
.39366 .4062 m .39257 .41864 L .39293 .41893 L F
.39202 .41822 m .40001 .40094 L .39125 .41762 L .654 .726 .902 r
F
.39345 .41829 m .39372 .41383 L .39195 .41786 L .675 .735 .895 r
F
.39345 .41829 m .39672 .41468 L .39372 .41383 L F
.39125 .41762 m .40001 .40094 L .39192 .39982 L .654 .726 .902 r
F
.39195 .41786 m .39372 .41383 L .39049 .41352 L .675 .735 .895 r
F
.39352 .42112 m .3938 .41664 L .39202 .42069 L F
.39202 .42069 m .3938 .41664 L .39054 .41633 L F
.39672 .41468 m .3955 .40979 L .39372 .41383 L F
.39207 .42354 m .3906 .41918 L .39044 .42338 L F
.39207 .42354 m .39385 .41949 L .3906 .41918 L F
.39372 .41383 m .39064 .40934 L .39049 .41352 L F
.39372 .41383 m .3955 .40979 L .39064 .40934 L F
.39681 .41749 m .39558 .41258 L .3938 .41664 L F
.39195 .41786 m .39049 .41352 L .39033 .41771 L F
.3938 .41664 m .3907 .41212 L .39054 .41633 L F
.3938 .41664 m .39558 .41258 L .3907 .41212 L F
.39202 .42069 m .39054 .41633 L .39039 .42054 L F
.39385 .41949 m .39076 .41497 L .3906 .41918 L F
.39385 .41949 m .39564 .41543 L .39076 .41497 L F
.39558 .41258 m .39553 .40973 L .39065 .40928 L .731 .477 .544 r
F
.4001 .41387 m .39553 .40973 L .39558 .41258 L .794 .529 .536 r
F
.39558 .41258 m .39065 .40928 L .3907 .41212 L .731 .477 .544 r
F
.39564 .41543 m .39558 .41258 L .3907 .41212 L F
.39564 .41543 m .3907 .41212 L .39076 .41497 L F
.3908 .4252 m .39961 .40813 L .39148 .40701 L .654 .726 .902 r
F
.39147 .4253 m .39125 .43232 L .39145 .43235 L .734 .477 .539 r
F
.39072 .42734 m .39414 .42693 L .39352 .42646 L .654 .726 .902 r
F
.39036 .43219 m .39916 .41542 L .39103 .4143 L F
.39027 .43463 m .39133 .43233 L .39036 .43219 L F
.39133 .43233 m .39916 .41542 L .39036 .43219 L F
.39145 .43235 m .39029 .46354 L .39138 .46367 L .734 .477 .539 r
F
.39125 .43232 m .39029 .46354 L .39145 .43235 L F
.3913 .42527 m .39029 .46354 L .39147 .4253 L F
.39313 .43297 m .39918 .43181 L .41309 .42142 L .654 .726 .902 r
F
.39027 .43463 m .39423 .43338 L .39313 .43297 L F
.39423 .43338 m .39918 .43181 L .39313 .43297 L F
.39114 .43698 m .39175 .43862 L .39213 .43689 L F
.39203 .43256 m .39145 .43235 L .39138 .46367 L .81 .54 .531 r
F
.39027 .43463 m .39256 .43742 L .39308 .43664 L .654 .726 .902 r
F
.39203 .43256 m .39138 .46367 L .39253 .43275 L .81 .54 .531 r
F
.39756 .43544 m .39687 .43387 L .3934 .42926 L .654 .726 .902 r
F
.39423 .43338 m .39637 .4339 L .39918 .43181 L F
.39581 .43397 m .39637 .4339 L .39423 .43338 L F
.39918 .43181 m .42089 .43096 L .41793 .42589 L F
.39637 .4339 m .42089 .43096 L .39918 .43181 L F
.39312 .4363 m .39343 .46744 L .39301 .43638 L .354 .175 .495 r
F
.39918 .43181 m .41793 .42589 L .41315 .42148 L .654 .726 .902 r
F
.39918 .43181 m .41315 .42148 L .41309 .42142 L F
.39301 .43638 m .39343 .46744 L .39292 .43644 L .354 .175 .495 r
F
.3931 .43319 m .39246 .46405 L .39326 .43332 L .909 .63 .5 r
F
.39384 .43412 m .39359 .43358 L .39352 .46488 L .985 .728 .342 r
F
.39397 .43513 m .39397 .46593 L .39395 .43523 L 0 0 .133 r
F
.39382 .43616 m .41344 .44905 L .40071 .43913 L .654 .726 .902 r
F
.39381 .43622 m .41344 .44905 L .39382 .43616 L F
.40071 .43913 m .41344 .44905 L .41715 .44621 L F
.39359 .43358 m .39246 .46405 L .39352 .46488 L .909 .63 .5 r
F
.39326 .43332 m .39246 .46405 L .39359 .43358 L F
.3937 .43572 m .39393 .43538 L .39386 .46675 L .069 0 .411 r
F
.39391 .43428 m .39352 .46488 L .39396 .43441 L .985 .728 .342 r
F
.39399 .43501 m .39405 .4346 L .39397 .46593 L 0 0 .133 r
F
.39399 .43501 m .39397 .46593 L .39397 .43513 L F
.39393 .43538 m .39397 .46593 L .39386 .46675 L F
.39395 .43523 m .39397 .46593 L .39393 .43538 L F
.39405 .4346 m .39352 .46488 L .39397 .46593 L .985 .728 .342 r
F
.39396 .43441 m .39352 .46488 L .39405 .4346 L F
.39582 .43859 m .40535 .45304 L .41199 .45015 L .654 .726 .902 r
F
.39308 .43664 m .39767 .44277 L .39582 .43859 L F
.39767 .44277 m .40535 .45304 L .39582 .43859 L F
.39342 .43884 m .39768 .45467 L .40249 .45365 L F
.39853 .44471 m .40249 .45365 L .40535 .45304 L F
.3937 .43572 m .39386 .46675 L .39363 .43582 L .069 0 .411 r
F
.39384 .43412 m .39352 .46488 L .39391 .43428 L .985 .728 .342 r
F
.39238 .43769 m .39768 .45467 L .39256 .43742 L .654 .726 .902 r
F
.52144 .57807 m .5092 .56197 L .50846 .57727 L .673 .757 .914 r
F
.52144 .57807 m .52867 .56318 L .5092 .56197 L F
.53935 .69371 m .56142 .69002 L .54339 .68806 L .683 .77 .917 r
F
.52333 .68893 m .53935 .69371 L .54339 .68806 L F
.52023 .69142 m .53935 .69371 L .52333 .68893 L F
0 g
.57313 .9117 m
.57635 .91068 L
s
.44463 .4431 m .4813 .4405 L .45127 .43369 L .654 .726 .902 r
F
.4179 .43158 m .44463 .4431 L .45127 .43369 L F
.41277 .43551 m .44463 .4431 L .4179 .43158 L F
.22774 .56205 m .20168 .56647 L .22674 .56601 L .673 .757 .914 r
F
0 g
.57977 .91021 m
.58316 .91031 L
s
.30243 .57032 m .32552 .55802 L .30103 .56243 L .673 .757 .914 r
F
.27726 .57078 m .30243 .57032 L .30103 .56243 L F
.65446 .46459 m .63288 .44908 L .62249 .45696 L .654 .726 .902 r
F
.66113 .46171 m .63288 .44908 L .65446 .46459 L F
.20726 .45135 m .18788 .45272 L .18741 .46 L .49 .282 .525 r
F
0 g
.17203 .47181 m
.18741 .46 L
s
.20726 .45135 m .20773 .44407 L .18788 .45272 L .49 .282 .525 r
F
0 g
.17251 .46453 m
.18788 .45272 L
s
.69896 .46692 m .70919 .4466 L .6926 .46335 L .654 .726 .902 r
F
.69896 .46692 m .72191 .45374 L .70919 .4466 L F
.72853 .81082 m .71992 .80488 L .71367 .80929 L .645 .732 .913 r
F
.73387 .80869 m .71992 .80488 L .72853 .81082 L F
0 g
.57635 .91068 m
.57977 .91021 L
s
.76411 .81291 m .76568 .80391 L .75903 .81017 L .645 .732 .913 r
F
.76411 .81291 m .7733 .80802 L .76568 .80391 L F
.3077 .81641 m .299 .81048 L .29283 .81488 L .644 .733 .913 r
F
0 g
.28886 .82019 m
.29283 .81488 L
s
.313 .81428 m .299 .81048 L .3077 .81641 L .644 .733 .913 r
F
.3209 .46699 m .32136 .4597 L .30214 .44901 L .858 .601 .55 r
F
0 g
.32136 .4597 m
.33591 .47308 L
s
.127 .923 .03 r
.32077 .46686 m
.32077 .46691 L
s
.48341 .5875 m .47145 .57449 L .45546 .58207 L .673 .758 .914 r
F
.4957 .58423 m .47145 .57449 L .48341 .5875 L F
.23774 .46648 m .23022 .44646 L .20726 .45135 L .654 .726 .902 r
F
.25407 .46595 m .23022 .44646 L .23774 .46648 L F
.49538 .57855 m .48957 .56389 L .47113 .56881 L .673 .757 .914 r
F
.50846 .57727 m .48957 .56389 L .49538 .57855 L F
.27031 .46819 m .25474 .44566 L .25407 .46595 L .654 .726 .902 r
F
.27031 .46819 m .27911 .44902 L .25474 .44566 L F
.34328 .8185 m .34471 .8095 L .33816 .81576 L .644 .733 .913 r
F
.34328 .8185 m .35239 .81361 L .34471 .8095 L F
.20368 .55855 m .17663 .56692 L .20168 .56647 L .673 .757 .914 r
F
.22774 .56205 m .20368 .55855 L .20168 .56647 L F
.31968 .80564 m .31672 .7981 L .30757 .79985 L .644 .733 .913 r
F
.32618 .8055 m .31672 .7981 L .31968 .80564 L F
.60235 .55811 m .60899 .56336 L .60932 .56904 L .986 .711 .378 r
F
.60235 .55811 m .60203 .55243 L .60899 .56336 L F
0 g
.60899 .56336 m
.61395 .56737 L
s
.71968 .80865 m .71367 .80929 L .71343 .81306 L .356 .182 .503 r
F
.71968 .80865 m .71992 .80488 L .71367 .80929 L F
0 g
.70961 .8146 m
.71367 .80929 L
s
.73416 .80499 m .72825 .79802 L .72028 .8012 L .645 .732 .913 r
F
.74028 .80382 m .72825 .79802 L .73416 .80499 L F
.27726 .57078 m .30103 .56243 L .27655 .56683 L .673 .757 .914 r
F
.33264 .8064 m .32647 .79789 L .32618 .8055 L .644 .733 .913 r
F
.33264 .8064 m .33616 .79924 L .32647 .79789 L F
.48848 .68346 m .47365 .69259 L .49023 .68608 L .683 .77 .917 r
F
.48848 .68346 m .47015 .68735 L .47365 .69259 L F
.6268 .54798 m .60933 .56324 L .63141 .55523 L .673 .757 .914 r
F
.6268 .54798 m .60239 .55236 L .60933 .56324 L F
.7592 .80646 m .75688 .79741 L .75324 .80458 L .645 .732 .913 r
F
.7592 .80646 m .76581 .80023 L .75688 .79741 L F
.54222 .6789 m .56252 .67202 L .54379 .67301 L .683 .77 .917 r
F
.52427 .67695 m .54222 .6789 L .54379 .67301 L F
.52227 .67976 m .54222 .6789 L .52427 .67695 L F
.77904 .81312 m .77353 .80425 L .7733 .80802 L .927 .677 .54 r
F
.77881 .8169 m .77904 .81312 L .7733 .80802 L F
0 g
.77904 .81312 m
.78251 .81888 L
s
.50846 .57727 m .5092 .56197 L .48957 .56389 L .673 .757 .914 r
F
.6579 .56172 m .64968 .57754 L .66298 .56406 L .673 .758 .914 r
F
.6579 .56172 m .63952 .57287 L .64968 .57754 L F
.31327 .81051 m .30722 .80351 L .29927 .8067 L .644 .733 .913 r
F
.31939 .80934 m .30722 .80351 L .31327 .81051 L F
.56194 .57444 m .54634 .56175 L .54667 .56743 L .86 .596 .539 r
F
.56226 .58012 m .56194 .57444 L .54667 .56743 L F
0 g
.56194 .57444 m
.57345 .58372 L
s
.56142 .69002 m .5633 .67658 L .5638 .68115 L 0 0 .391 r
F
.54339 .68806 m .56142 .69002 L .5638 .68115 L .683 .77 .917 r
F
0 g
.55536 .69848 m
.56142 .69002 L
s
.33843 .81199 m .33595 .8029 L .33242 .8101 L .644 .733 .913 r
F
.33843 .81199 m .34497 .80573 L .33595 .8029 L F
.65351 .54722 m .63904 .5614 L .65733 .55031 L .673 .757 .914 r
F
.65351 .54722 m .63141 .55523 L .63904 .5614 L F
.66922 .45279 m .662 .43276 L .64662 .43602 L .654 .726 .902 r
F
.6774 .45253 m .662 .43276 L .66922 .45279 L F
.62249 .45696 m .59569 .44539 L .5856 .45958 L F
0 g
.58602 .45229 m
.59244 .44326 L
s
.58169 .47515 m
.5856 .45958 L
s
.68551 .45365 m .67836 .43223 L .6774 .45253 L .654 .726 .902 r
F
.68551 .45365 m .6946 .43446 L .67836 .43223 L F
.69317 .55539 m .71036 .56589 L .71872 .55941 L .673 .757 .914 r
F
.3582 .81872 m .35265 .80984 L .35239 .81361 L .925 .676 .544 r
F
0 g
.3582 .81872 m
.36176 .82447 L
s
.32618 .8055 m .32647 .79789 L .31672 .7981 L .644 .733 .913 r
F
.74042 .57234 m .74825 .55545 L .74859 .56113 L .176 .079 .499 r
F
.71906 .56509 m .74042 .57234 L .74859 .56113 L .673 .758 .914 r
F
.7107 .57157 m .74042 .57234 L .71906 .56509 L F
0 g
.72788 .58206 m
.74042 .57234 L
s
.20368 .55855 m .17961 .55505 L .17663 .56692 L .673 .757 .914 r
F
.76795 .46912 m .75966 .44666 L .75926 .45395 L .991 .743 .451 r
F
0 g
.76795 .46912 m
.77037 .48502 L
s
.17953 .56068 m .17625 .56693 L .17654 .57261 L 0 0 .307 r
F
0 g
.17697 .57088 m
.17728 .57259 L
s
.17953 .56068 m .17925 .555 L .17625 .56693 L 0 0 .307 r
F
.25208 .57123 m .24613 .55657 L .23999 .55821 L .673 .757 .914 r
F
.25208 .57123 m .25267 .55593 L .24613 .55657 L F
.3279 .57554 m .32552 .55802 L .32582 .5637 L .838 .633 .087 r
F
.30273 .576 m .3279 .57554 L .32582 .5637 L .673 .757 .914 r
F
0 g
.32484 .58746 m
.3279 .57554 L
s
.25407 .46595 m .25474 .44566 L .23022 .44646 L .654 .726 .902 r
F
.6774 .45253 m .67836 .43223 L .662 .43276 L F
.73189 .45538 m .74528 .43326 L .72231 .44645 L F
.73189 .45538 m .75966 .44666 L .74528 .43326 L F
.72829 .81459 m .71968 .80865 L .71343 .81306 L .645 .732 .913 r
F
0 g
.70937 .81837 m
.71343 .81306 L
s
.73363 .81246 m .71968 .80865 L .72829 .81459 L .645 .732 .913 r
F
.76388 .81668 m .76545 .80768 L .7588 .81394 L F
.76388 .81668 m .77307 .81179 L .76545 .80768 L F
.47113 .56881 m .45484 .57071 L .45515 .57639 L .515 .33 .567 r
F
.47113 .56881 m .47082 .56313 L .45484 .57071 L F
0 g
.4424 .58043 m
.45484 .57071 L
s
.27614 .56118 m .29578 .54954 L .27378 .55755 L .673 .757 .914 r
F
.27614 .56118 m .30049 .55679 L .29578 .54954 L F
.52175 .58375 m .50952 .56765 L .50878 .58295 L .673 .758 .914 r
F
.52175 .58375 m .52899 .56886 L .50952 .56765 L F
.30722 .80351 m .29953 .80293 L .29927 .8067 L .499 .299 .539 r
F
.30722 .80351 m .30748 .79974 L .29953 .80293 L F
0 g
.29336 .80734 m
.29953 .80293 L
s
.74028 .80382 m .73743 .79627 L .72825 .79802 L .645 .732 .913 r
F
.74679 .80368 m .73743 .79627 L .74028 .80382 L F
.75324 .80458 m .7472 .79606 L .74679 .80368 L F
.75324 .80458 m .75688 .79741 L .7472 .79606 L F
.35265 .80984 m .35291 .80607 L .34523 .80196 L .856 .609 .565 r
F
0 g
.35291 .80607 m
.35872 .81117 L
s
.45032 .68257 m .45134 .68666 L .45183 .69123 L .778 .563 0 r
F
.45032 .68257 m .44983 .67799 L .45134 .68666 L F
0 g
.45134 .68666 m
.45408 .69076 L
s
.46885 .67698 m .45161 .6866 L .46985 .68273 L .683 .77 .917 r
F
.46885 .67698 m .45011 .67798 L .45161 .6866 L F
.22791 .56772 m .20172 .57215 L .2269 .57169 L .673 .757 .914 r
F
.30273 .576 m .32582 .5637 L .30133 .56811 L F
.27755 .57645 m .30273 .576 L .30133 .56811 L F
.31939 .80934 m .31641 .80175 L .30722 .80351 L .644 .733 .913 r
F
.32592 .8092 m .31641 .80175 L .31939 .80934 L F
.73387 .80869 m .72793 .80169 L .71992 .80488 L .645 .732 .913 r
F
.74002 .80752 m .72793 .80169 L .73387 .80869 L F
.33242 .8101 m .32621 .80154 L .32592 .8092 L .644 .733 .913 r
F
.33242 .8101 m .33595 .8029 L .32621 .80154 L F
.75903 .81017 m .7567 .80108 L .75304 .80828 L .645 .732 .913 r
F
.75903 .81017 m .76568 .80391 L .7567 .80108 L F
.77881 .8169 m .7733 .80802 L .77307 .81179 L .927 .677 .54 r
F
0 g
.77881 .8169 m
.78227 .82265 L
s
0 0 0 r
2.5 Mabswid
.32078 .46843 Mdot
.127 .923 .03 r
.5 Mabswid
.32078 .46843 m
.32095 .48714 L
s
.36621 5.57987 m
.38318 7.48959 L
s
.38318 7.48959 m
.39505 8.82459 L
s
.313 .81428 m .30696 .80729 L .299 .81048 L .644 .733 .913 r
F
.31913 .81311 m .30696 .80729 L .313 .81428 L F
.74679 .80368 m .7472 .79606 L .73743 .79627 L .645 .732 .913 r
F
.48897 .68803 m .47414 .69717 L .49072 .69066 L .683 .77 .917 r
F
.48897 .68803 m .47064 .69192 L .47414 .69717 L F
.33816 .81576 m .33569 .80667 L .33215 .81388 L .644 .733 .913 r
F
.33816 .81576 m .34471 .8095 L .33569 .80667 L F
.54289 .68349 m .5633 .67658 L .54447 .67758 L .683 .77 .917 r
F
.52486 .68153 m .54289 .68349 L .54447 .67758 L F
.52284 .68435 m .54289 .68349 L .52486 .68153 L F
0 0 0 r
2.5 Mabswid
.52062 .58298 Mdot
.66113 .46171 m .64622 .44331 L .63288 .44908 L .654 .726 .902 r
F
.66882 .46008 m .64622 .44331 L .66113 .46171 L F
.4957 .58423 m .48989 .56957 L .47145 .57449 L .673 .758 .914 r
F
.50878 .58295 m .48989 .56957 L .4957 .58423 L F
.36011 .43101 m .32952 .43468 L .33546 .4448 L .654 .726 .902 r
F
.6926 .46335 m .69419 .44175 L .6851 .46093 L F
.6926 .46335 m .70919 .4466 L .69419 .44175 L F
.32592 .8092 m .32621 .80154 L .31641 .80175 L .644 .733 .913 r
F
.44446 .4505 m .48132 .44788 L .45113 .44104 L .654 .726 .902 r
F
.4176 .43893 m .44446 .4505 L .45113 .44104 L F
.41243 .44287 m .44446 .4505 L .4176 .43893 L F
.60268 .56379 m .60932 .56904 L .60965 .57472 L .986 .711 .378 r
F
.60268 .56379 m .60235 .55811 L .60932 .56904 L F
.62688 .5537 m .60932 .56904 L .63152 .56099 L .673 .757 .914 r
F
.62688 .5537 m .60235 .55811 L .60932 .56904 L F
0 g
.5 Mabswid
.60932 .56904 m
.61428 .57305 L
s
.20372 .5642 m .17654 .57261 L .20172 .57215 L .673 .757 .914 r
F
.22791 .56772 m .20372 .5642 L .20172 .57215 L F
.27755 .57645 m .30133 .56811 L .27685 .57251 L F
.29626 .4224 m .29939 .43106 L .29894 .43834 L .926 .745 .261 r
F
.29626 .4224 m .29672 .41512 L .29939 .43106 L F
0 g
.29939 .43106 m
.30035 .43268 L
s
.32851 .41678 m .29985 .43101 L .33028 .42736 L .654 .726 .902 r
F
.32851 .41678 m .29719 .41514 L .29985 .43101 L F
.50878 .58295 m .50952 .56765 L .48989 .56957 L .673 .758 .914 r
F
.65374 .55294 m .63919 .56719 L .65757 .55604 L .673 .757 .914 r
F
.65374 .55294 m .63152 .56099 L .63919 .56719 L F
.56226 .58012 m .54667 .56743 L .54699 .57311 L .86 .596 .539 r
F
0 g
.56226 .58012 m
.57378 .5894 L
s
.72793 .80169 m .72015 .80111 L .71992 .80488 L .502 .301 .541 r
F
.72793 .80169 m .72816 .79792 L .72015 .80111 L F
0 g
.7139 .80551 m
.72015 .80111 L
s
.23038 .55834 m .20368 .55855 L .22774 .56205 L .673 .757 .914 r
F
.48132 .44788 m .48175 .4406 L .48561 .425 L 0 0 .141 r
F
0 g
.47726 .44696 m
.48175 .4406 L
s
.69351 .56107 m .7107 .57157 L .71906 .56509 L .673 .758 .914 r
F
.68816 .5636 m .7107 .57157 L .69351 .56107 L F
.45127 .43369 m .4813 .4405 L .48514 .42497 L .654 .726 .902 r
F
.7733 .80802 m .77353 .80425 L .76591 .80014 L .857 .609 .563 r
F
0 g
.77353 .80425 m
.77927 .80935 L
s
.30696 .80729 m .29927 .8067 L .299 .81048 L .499 .299 .539 r
F
0 g
.29283 .81488 m
.299 .81048 L
s
.30696 .80729 m .30722 .80351 L .29927 .8067 L .499 .299 .539 r
F
0 g
.2931 .81111 m
.29927 .8067 L
s
.3209 .46699 m .30214 .44901 L .30168 .45629 L .858 .601 .55 r
F
0 g
.3209 .46699 m
.33546 .48036 L
s
.35265 .80984 m .34523 .80196 L .34497 .80573 L .856 .609 .565 r
F
.35239 .81361 m .35265 .80984 L .34497 .80573 L F
0 g
.35265 .80984 m
.35846 .81495 L
s
.74002 .80752 m .73716 .79993 L .72793 .80169 L .645 .732 .913 r
F
.74656 .80738 m .73716 .79993 L .74002 .80752 L F
.75304 .80828 m .74697 .79972 L .74656 .80738 L F
.75304 .80828 m .7567 .80108 L .74697 .79972 L F
.17982 .56636 m .17654 .57261 L .17682 .57829 L 0 0 .307 r
F
0 g
.17726 .57656 m
.17757 .57827 L
s
.20372 .5642 m .17953 .56068 L .17654 .57261 L .673 .757 .914 r
F
.17982 .56636 m .17953 .56068 L .17654 .57261 L 0 0 .307 r
F
.25237 .57691 m .25296 .56161 L .24642 .56225 L .673 .757 .914 r
F
.25237 .57691 m .25946 .56201 L .25296 .56161 L F
.31913 .81311 m .31615 .80553 L .30696 .80729 L .644 .733 .913 r
F
.32566 .81297 m .31615 .80553 L .31913 .81311 L F
.73363 .81246 m .72769 .80546 L .71968 .80865 L .645 .732 .913 r
F
.73978 .81129 m .72769 .80546 L .73363 .81246 L F
.33215 .81388 m .32595 .80532 L .32566 .81297 L .644 .733 .913 r
F
.33215 .81388 m .33569 .80667 L .32595 .80532 L F
.7588 .81394 m .75647 .80485 L .75281 .81205 L .645 .732 .913 r
F
.7588 .81394 m .76545 .80768 L .75647 .80485 L F
.4508 .68714 m .45183 .69123 L .45232 .69581 L .778 .563 0 r
F
.4508 .68714 m .45032 .68257 L .45183 .69123 L F
.46915 .68157 m .45183 .69123 L .47015 .68735 L .683 .77 .917 r
F
.46915 .68157 m .45032 .68257 L .45183 .69123 L F
0 g
.45183 .69123 m
.45457 .69533 L
s
.48758 .67599 m .46985 .68273 L .48808 .67887 L .683 .77 .917 r
F
.48758 .67599 m .46885 .67698 L .46985 .68273 L F
.127 .923 .03 r
.66766 .40211 m
.66771 .40064 L
s
.74656 .80738 m .74697 .79972 L .73716 .79993 L .645 .732 .913 r
F
.47145 .57449 m .45515 .57639 L .45546 .58207 L .515 .33 .567 r
F
0 g
.44302 .59178 m
.45546 .58207 L
s
.47145 .57449 m .47113 .56881 L .45515 .57639 L .515 .33 .567 r
F
0 g
.44271 .5861 m
.45515 .57639 L
s
.71816 .55366 m .74755 .54972 L .72358 .54622 L .673 .757 .914 r
F
.6969 .54643 m .71816 .55366 L .72358 .54622 L F
.27655 .56683 m .2963 .55513 L .27418 .56319 L F
.27655 .56683 m .30103 .56243 L .2963 .55513 L F
.52427 .67695 m .54379 .67301 L .52506 .674 L .683 .77 .917 r
F
0 g
.67936 .47904 m
.67948 .51032 L
s
.32566 .81297 m .32595 .80532 L .31615 .80553 L .644 .733 .913 r
F
.66882 .46008 m .66159 .44005 L .64622 .44331 L .654 .726 .902 r
F
.67699 .45981 m .66159 .44005 L .66882 .46008 L F
.6851 .46093 m .67796 .43951 L .67699 .45981 L F
.6851 .46093 m .69419 .44175 L .67796 .43951 L F
0 g
.67282 .4787 m
.67293 .5102 L
s
.54339 .68806 m .5638 .68115 L .54497 .68215 L .683 .77 .917 r
F
.52535 .6861 m .54339 .68806 L .54497 .68215 L F
.52333 .68893 m .54339 .68806 L .52535 .6861 L F
.2282 .5734 m .20201 .57783 L .22719 .57737 L .673 .757 .914 r
F
.30049 .55679 m .3178 .54152 L .29578 .54954 L F
.30049 .55679 m .32485 .55241 L .3178 .54152 L F
.23069 .43917 m .2082 .43678 L .20773 .44407 L .591 .366 .544 r
F
.23069 .43917 m .23116 .43189 L .2082 .43678 L F
0 g
.18836 .44544 m
.2082 .43678 L
s
.25018 .67695 m .24971 .67238 L .26438 .67045 L .673 .453 .579 r
F
.2356 .67657 m .24971 .67238 L .25018 .67695 L .733 .497 .571 r
F
.2356 .67657 m .23513 .672 L .24971 .67238 L F
.63288 .44908 m .59569 .44539 L .62249 .45696 L .654 .726 .902 r
F
.25016 .66096 m .24972 .67221 L .26432 .67029 L .683 .77 .917 r
F
.24048 .66071 m .24972 .67221 L .25016 .66096 L F
.24048 .66071 m .23521 .67183 L .24972 .67221 L F
0 g
.29983 .44083 m
.3026 .44172 L
s
.72769 .80546 m .71992 .80488 L .71968 .80865 L .502 .301 .541 r
F
0 g
.71343 .81306 m
.71968 .80865 L
s
.72769 .80546 m .72793 .80169 L .71992 .80488 L .502 .301 .541 r
F
0 g
.71367 .80929 m
.71992 .80488 L
s
.67699 .45981 m .67796 .43951 L .66159 .44005 L .654 .726 .902 r
F
.7315 .46266 m .74489 .44054 L .72191 .45374 L F
.7315 .46266 m .75926 .45395 L .74489 .44054 L F
.7733 .80802 m .76591 .80014 L .76568 .80391 L .857 .609 .563 r
F
.77307 .81179 m .7733 .80802 L .76568 .80391 L F
0 g
.7733 .80802 m
.77904 .81312 L
s
.26486 .67502 m .26438 .67045 L .27815 .66634 L .606 .404 .582 r
F
.25018 .67695 m .26438 .67045 L .26486 .67502 L .673 .453 .579 r
F
0 g
.24971 .67238 m
.26438 .67045 L
s
.67948 .51032 m
.67958 .5368 L
s
.72248 .4393 m .72634 .41551 L .70982 .4322 L .654 .726 .902 r
F
.72248 .4393 m .74533 .42617 L .72634 .41551 L F
0 g
.67293 .5102 m
.67299 .52428 L
s
.67302 .53249 m
.67304 .53762 L
s
.31641 .80175 m .30748 .79974 L .30722 .80351 L .597 .38 .558 r
F
.31641 .80175 m .31667 .79798 L .30748 .79974 L F
0 g
.29953 .80293 m
.30748 .79974 L
s
.5633 .67658 m .5628 .672 L .56133 .66333 L .772 .558 0 r
F
0 g
.56155 .67667 m
.56269 .67244 L
s
.54379 .67301 m .56252 .67202 L .56105 .66339 L .683 .77 .917 r
F
.25989 .65968 m .26432 .67029 L .27801 .6662 L F
.25016 .66096 m .26432 .67029 L .25989 .65968 L F
.27378 .55755 m .28807 .54337 L .26992 .55447 L .673 .757 .914 r
F
.27378 .55755 m .29578 .54954 L .28807 .54337 L F
.35239 .81361 m .34497 .80573 L .34471 .8095 L .856 .609 .565 r
F
0 g
.35239 .81361 m
.3582 .81872 L
s
.127 .923 .03 r
.34645 .77463 m
.35725 2.54738 L
s
.73978 .81129 m .73692 .8037 L .72769 .80546 L .645 .732 .913 r
F
.74633 .81115 m .73692 .8037 L .73978 .81129 L F
.75281 .81205 m .74674 .80349 L .74633 .81115 L F
.75281 .81205 m .75647 .80485 L .74674 .80349 L F
.62721 .55938 m .60965 .57472 L .63185 .56667 L .673 .758 .914 r
F
.62721 .55938 m .60268 .56379 L .60965 .57472 L F
0 g
.60965 .57472 m
.62115 .58401 L
s
.20401 .56988 m .17682 .57829 L .20201 .57783 L .673 .757 .914 r
F
.2282 .5734 m .20401 .56988 L .20201 .57783 L F
.34497 .80573 m .34523 .80196 L .33621 .79913 L .793 .551 .572 r
F
0 g
.34523 .80196 m
.35291 .80607 L
s
.127 .923 .03 r
.66829 .53472 m
.67007 .47928 L
s
.6689 .5351 m
.67007 .47928 L
s
.65407 .55862 m .63952 .57287 L .6579 .56172 L .673 .758 .914 r
F
.65407 .55862 m .63185 .56667 L .63952 .57287 L F
.54667 .56743 m .54634 .56175 L .52835 .5575 L .794 .544 .559 r
F
0 g
.54634 .56175 m
.56162 .56876 L
s
.23056 .56398 m .20372 .5642 L .22791 .56772 L .673 .757 .914 r
F
.5636 .43278 m .58837 .42885 L .58795 .43613 L .732 .487 .558 r
F
.5636 .43278 m .56402 .4255 L .58837 .42885 L F
.74633 .81115 m .74674 .80349 L .73692 .8037 L .645 .732 .913 r
F
.46964 .68614 m .45232 .69581 L .47064 .69192 L .683 .77 .917 r
F
.46964 .68614 m .4508 .68714 L .45232 .69581 L F
0 g
.45232 .69581 m
.45757 .70367 L
s
.48798 .68057 m .47015 .68735 L .48848 .68346 L .683 .77 .917 r
F
.48798 .68057 m .46915 .68157 L .47015 .68735 L F
.57312 .4061 m .58838 .42855 L .58928 .40832 L .654 .726 .902 r
F
.57312 .4061 m .56416 .42521 L .58838 .42855 L F
.67735 .50912 m .67637 .53762 L .67693 .53766 L .734 .477 .539 r
F
.67563 .5392 m .69394 .52809 L .68888 .52576 L .673 .757 .914 r
F
.67637 .53762 m .67539 .56788 L .67649 .56779 L .66 .416 .54 r
F
.67627 .50899 m .67584 .53768 L .67637 .53762 L F
.67563 .5392 m .6764 .53762 L .67637 .53762 L .673 .757 .914 r
F
.67563 .5392 m .67637 .53762 L .67571 .53769 L F
.67584 .53768 m .67576 .54301 L .67637 .53762 L .66 .416 .54 r
F
.67596 .54488 m .67607 .54298 L .67525 .54306 L .673 .757 .914 r
F
.67576 .54301 m .67568 .54834 L .67603 .54298 L .66 .416 .54 r
F
.67576 .54301 m .67603 .54298 L .67637 .53762 L F
.67525 .54306 m .6768 .52955 L .67025 .53019 L .673 .757 .914 r
F
.67571 .53769 m .67637 .53762 L .67572 .53757 L F
.67563 .5392 m .68888 .52576 L .68292 .52435 L F
.67607 .54298 m .6768 .52955 L .67525 .54306 L F
.67544 .54836 m .67714 .53523 L .67058 .53587 L .673 .758 .914 r
F
.6763 .55057 m .67642 .54826 L .67544 .54836 L F
.67568 .54834 m .67603 .5483 L .6762 .54296 L .66 .416 .54 r
F
.67603 .54298 m .6762 .54296 L .67637 .53762 L F
.6764 .53762 m .68292 .52435 L .67572 .53757 L .673 .757 .914 r
F
.67596 .54488 m .68329 .52995 L .6768 .52955 L F
.67568 .54834 m .6762 .54296 L .67603 .54298 L .66 .416 .54 r
F
.67694 .54288 m .68929 .53138 L .68329 .52995 L .673 .757 .914 r
F
.67596 .54488 m .67805 .54276 L .67694 .54288 L F
.67805 .54276 m .68929 .53138 L .67694 .54288 L F
.67642 .54826 m .67714 .53523 L .67544 .54836 L .673 .758 .914 r
F
.67568 .54834 m .67539 .56788 L .67603 .5483 L .66 .416 .54 r
F
.67572 .53757 m .68292 .52435 L .67646 .52394 L .673 .757 .914 r
F
.67735 .50912 m .67627 .50899 L .67637 .53762 L .734 .477 .539 r
F
.67693 .53766 m .67641 .54826 L .67678 .54829 L F
.67642 .54826 m .68363 .53564 L .67714 .53523 L .673 .758 .914 r
F
.6763 .55057 m .67739 .54833 L .67642 .54826 L F
.67739 .54833 m .68363 .53564 L .67642 .54826 L F
.67693 .53766 m .67637 .53762 L .67641 .54826 L .734 .477 .539 r
F
.67678 .54829 m .67641 .54826 L .67649 .56779 L F
.54379 .67301 m .56105 .66339 L .54281 .66726 L .683 .77 .917 r
F
.52506 .674 m .54379 .67301 L .54281 .66726 L F
.35966 .4383 m .33501 .45208 L .36263 .44336 L .654 .726 .902 r
F
.35966 .4383 m .32906 .44196 L .33501 .45208 L F
.52486 .68153 m .54447 .67758 L .52564 .67857 L .683 .77 .917 r
F
.20401 .56988 m .17982 .56636 L .17682 .57829 L .673 .757 .914 r
F
0 g
.17682 .57829 m
.17897 .59011 L
s
.44402 .45778 m .48089 .45517 L .45069 .44832 L .654 .726 .902 r
F
.41715 .44621 m .44402 .45778 L .45069 .44832 L F
.41199 .45015 m .44402 .45778 L .41715 .44621 L F
.74825 .55545 m .74791 .54977 L .75117 .53783 L 0 0 .334 r
F
0 g
.74328 .55612 m
.74791 .54977 L
s
.2958 .42969 m .29626 .4224 L .29894 .43834 L .926 .745 .261 r
F
.32774 .42405 m .29894 .43834 L .32952 .43468 L .654 .726 .902 r
F
.32774 .42405 m .29626 .4224 L .29894 .43834 L F
0 g
.29894 .43834 m
.29989 .43996 L
s
.72358 .54622 m .74755 .54972 L .75079 .53784 L .673 .757 .914 r
F
.2221 .6739 m .23513 .672 L .2356 .67657 L .794 .542 .557 r
F
.2221 .6739 m .22163 .66933 L .23513 .672 L F
0 g
.23513 .672 m
.24971 .67238 L
s
.71872 .55941 m .74825 .55545 L .72416 .55193 L .673 .757 .914 r
F
.69735 .55215 m .71872 .55941 L .72416 .55193 L F
.69317 .55539 m .71872 .55941 L .69735 .55215 L F
.25066 .68152 m .25018 .67695 L .26486 .67502 L .673 .453 .579 r
F
.23607 .68114 m .25018 .67695 L .25066 .68152 L .733 .497 .571 r
F
.127 .923 .03 r
.24998 .67694 m
.24998 .67701 L
s
.23607 .68114 m .2356 .67657 L .25018 .67695 L .733 .497 .571 r
F
.25063 .66565 m .25018 .67695 L .26486 .67502 L .683 .77 .917 r
F
.2409 .66539 m .25018 .67695 L .25063 .66565 L F
.2409 .66539 m .2356 .67657 L .25018 .67695 L F
.23152 .65894 m .23521 .67183 L .24048 .66071 L F
.127 .923 .03 r
.23596 .6018 m
.23781 .66018 L
s
.23596 .6018 m
.23707 .66003 L
s
.23152 .65894 m .22178 .66918 L .23521 .67183 L .683 .77 .917 r
F
.27685 .57251 m .2966 .56082 L .27448 .56887 L .673 .757 .914 r
F
.27685 .57251 m .30133 .56811 L .2966 .56082 L F
.23038 .55834 m .20896 .55111 L .20368 .55855 L F
.23448 .55511 m .20896 .55111 L .23038 .55834 L F
.73716 .79993 m .72816 .79792 L .72793 .80169 L .597 .381 .558 r
F
.73716 .79993 m .73739 .79616 L .72816 .79792 L F
0 g
.72015 .80111 m
.72816 .79792 L
s
.77307 .81179 m .76568 .80391 L .76545 .80768 L .857 .609 .563 r
F
0 g
.77307 .81179 m
.77881 .8169 L
s
.76568 .80391 m .76591 .80014 L .75693 .79731 L .793 .551 .571 r
F
0 g
.76591 .80014 m
.77353 .80425 L
s
.48132 .44788 m .48561 .425 L .48518 .43228 L 0 0 .141 r
F
.48089 .45517 m .48132 .44788 L .48518 .43228 L F
.45113 .44104 m .48132 .44788 L .48518 .43228 L .654 .726 .902 r
F
0 g
.47682 .45425 m
.48132 .44788 L
s
.75966 .44666 m .76005 .43938 L .74567 .42597 L .93 .67 .523 r
F
0 g
.76005 .43938 m
.76873 .45455 L
s
.31615 .80553 m .30722 .80351 L .30696 .80729 L .597 .38 .558 r
F
0 g
.299 .81048 m
.30696 .80729 L
s
.31615 .80553 m .31641 .80175 L .30722 .80351 L .597 .38 .558 r
F
0 g
.29927 .8067 m
.30722 .80351 L
s
.65121 .54359 m .63141 .55523 L .65351 .54722 L .673 .757 .914 r
F
.65121 .54359 m .6268 .54798 L .63141 .55523 L F
.52506 .674 m .54281 .66726 L .52456 .67113 L .683 .77 .917 r
F
.34497 .80573 m .33621 .79913 L .33595 .8029 L .793 .551 .572 r
F
.34471 .8095 m .34497 .80573 L .33595 .8029 L F
0 g
.34497 .80573 m
.35265 .80984 L
s
.26486 .67502 m .27815 .66634 L .27862 .67091 L .606 .404 .582 r
F
.26533 .67959 m .26486 .67502 L .27862 .67091 L F
.25066 .68152 m .26486 .67502 L .26533 .67959 L .673 .453 .579 r
F
.26041 .66436 m .26486 .67502 L .27862 .67091 L .683 .77 .917 r
F
.25063 .66565 m .26486 .67502 L .26041 .66436 L F
0 g
.25018 .67695 m
.26486 .67502 L
s
.30103 .56243 m .31843 .54708 L .2963 .55513 L .673 .757 .914 r
F
.30103 .56243 m .32552 .55802 L .31843 .54708 L F
.5633 .67658 m .56133 .66333 L .56183 .6679 L .772 .558 0 r
F
.54447 .67758 m .5633 .67658 L .56183 .6679 L .683 .77 .917 r
F
.5638 .68115 m .5633 .67658 L .56183 .6679 L .772 .558 0 r
F
0 g
.56205 .68124 m
.56318 .67702 L
s
.32621 .80154 m .31667 .79798 L .31641 .80175 L .67 .443 .567 r
F
.32621 .80154 m .32647 .79777 L .31667 .79798 L F
0 g
.30748 .79974 m
.31667 .79798 L
s
.33595 .8029 m .33621 .79913 L .32647 .79777 L .733 .498 .572 r
F
0 g
.33621 .79913 m
.34523 .80196 L
s
.54109 .4255 m .56402 .4255 L .5636 .43278 L .794 .542 .557 r
F
.54109 .4255 m .54151 .41822 L .56402 .4255 L F
0 g
.56402 .4255 m
.58818 .42882 L
s
.35984 .41842 m .33028 .42736 L .36072 .42371 L .654 .726 .902 r
F
.35984 .41842 m .32851 .41678 L .33028 .42736 L F
.32552 .55802 m .32522 .55235 L .31813 .5414 L .987 .712 .386 r
F
0 g
.32522 .55235 m
.3273 .56418 L
s
.27862 .67091 m .27815 .66634 L .29007 .66033 L .522 .343 .58 r
F
0 g
.27146 .66833 m
.27815 .66634 L
s
.127 .923 .03 r
.2825 .601 m
.28314 .64762 L
s
.28339 .60234 m
.28844 .66115 L
s
.27418 .56319 m .28855 .54893 L .2703 .56009 L .673 .757 .914 r
F
.27418 .56319 m .2963 .55513 L .28855 .54893 L F
.55818 .40126 m .56416 .42521 L .57312 .4061 L .654 .726 .902 r
F
.55818 .40126 m .54176 .41796 L .56416 .42521 L F
.20896 .55111 m .17961 .55505 L .20368 .55855 L .673 .757 .914 r
F
.45127 .43369 m .48514 .42497 L .45381 .42334 L .654 .726 .902 r
F
.42122 .42687 m .45127 .43369 L .45381 .42334 L F
.4179 .43158 m .45127 .43369 L .42122 .42687 L F
.48847 .68514 m .47064 .69192 L .48897 .68803 L .683 .77 .917 r
F
.48847 .68514 m .46964 .68614 L .47064 .69192 L F
.26903 .65695 m .27801 .6662 L .28988 .66022 L F
.127 .923 .03 r
.2885 .66178 m
.28926 .6707 L
s
.28314 .64762 m
.28329 .65919 L
s
.25989 .65968 m .27801 .6662 L .26903 .65695 L .683 .77 .917 r
F
.50632 .675 m .502 .66439 L .49743 .66575 L F
.54447 .67758 m .56183 .6679 L .54349 .67179 L F
.52564 .67857 m .54447 .67758 L .54349 .67179 L F
.48957 .56389 m .47082 .56313 L .47113 .56881 L .603 .396 .574 r
F
.48957 .56389 m .48925 .55821 L .47082 .56313 L F
0 g
.45484 .57071 m
.47082 .56313 L
s
.52535 .6861 m .54497 .68215 L .52614 .68315 L .683 .77 .917 r
F
.54667 .56743 m .52835 .5575 L .52867 .56318 L .794 .544 .559 r
F
.54699 .57311 m .54667 .56743 L .52867 .56318 L F
0 g
.54667 .56743 m
.56194 .57444 L
s
.33595 .8029 m .32647 .79777 L .32621 .80154 L .733 .498 .572 r
F
0 g
.32647 .79777 m
.33621 .79913 L
s
.127 .923 .03 r
.33541 .79315 m
.33555 .80025 L
s
.33372 .79363 m
.33377 .80075 L
s
0 g
.31667 .79798 m
.32647 .79777 L
s
.23022 .44646 m .20773 .44407 L .20726 .45135 L .591 .366 .544 r
F
0 g
.18741 .46 m
.20726 .45135 L
s
.23022 .44646 m .23069 .43917 L .20773 .44407 L .591 .366 .544 r
F
0 g
.18788 .45272 m
.20773 .44407 L
s
.23085 .56966 m .20401 .56988 L .2282 .5734 L .673 .757 .914 r
F
.26992 .55447 m .27787 .53871 L .26482 .55214 L F
.26992 .55447 m .28807 .54337 L .27787 .53871 L F
.73692 .8037 m .72793 .80169 L .72769 .80546 L .597 .381 .558 r
F
0 g
.71968 .80865 m
.72769 .80546 L
s
.73692 .8037 m .73716 .79993 L .72793 .80169 L .597 .381 .558 r
F
0 g
.71992 .80488 m
.72793 .80169 L
s
.30214 .44901 m .28004 .43445 L .27957 .44173 L .794 .542 .557 r
F
.30168 .45629 m .30214 .44901 L .27957 .44173 L F
0 g
.30214 .44901 m
.32136 .4597 L
s
.29937 .44811 m
.30214 .44901 L
s
.29865 .44788 m
.29937 .44811 L
s
.22257 .67848 m .2356 .67657 L .23607 .68114 L .794 .542 .557 r
F
.22257 .67848 m .2221 .6739 L .2356 .67657 L F
.2319 .66362 m .2356 .67657 L .2409 .66539 L .683 .77 .917 r
F
.2319 .66362 m .2221 .6739 L .2356 .67657 L F
0 g
.2356 .67657 m
.25018 .67695 L
s
.76568 .80391 m .75693 .79731 L .7567 .80108 L .793 .551 .571 r
F
.76545 .80768 m .76568 .80391 L .7567 .80108 L F
0 g
.76568 .80391 m
.7733 .80802 L
s
.2511 .67022 m .25066 .68152 L .26533 .67959 L .683 .77 .917 r
F
.127 .923 .03 r
.25158 .73029 m
.25537 .85585 L
s
.25011 .68151 m
.25158 .73029 L
s
.24137 .66997 m .25066 .68152 L .2511 .67022 L .683 .77 .917 r
F
.24137 .66997 m .23607 .68114 L .25066 .68152 L F
.34471 .8095 m .33595 .8029 L .33569 .80667 L .793 .551 .572 r
F
0 g
.34471 .8095 m
.35239 .81361 L
s
.48836 .67305 m .46885 .67698 L .48758 .67599 L .683 .77 .917 r
F
.72231 .44645 m .72619 .42254 L .70959 .43932 L .654 .726 .902 r
F
.72231 .44645 m .74528 .43326 L .72619 .42254 L F
.74825 .55545 m .75117 .53783 L .75151 .54351 L 0 0 .334 r
F
.74859 .56113 m .74825 .55545 L .75151 .54351 L F
.72416 .55193 m .74825 .55545 L .75151 .54351 L .673 .757 .914 r
F
0 g
.74362 .5618 m
.74825 .55545 L
s
.74697 .79972 m .73739 .79616 L .73716 .79993 L .67 .443 .568 r
F
.74697 .79972 m .7472 .79595 L .73739 .79616 L F
0 g
.72816 .79792 m
.73739 .79616 L
s
.52564 .67857 m .54349 .67179 L .52515 .67568 L .683 .77 .917 r
F
.7567 .80108 m .75693 .79731 L .7472 .79595 L .733 .498 .572 r
F
0 g
.75693 .79731 m
.76591 .80014 L
s
.127 .923 .03 r
.73398 1.45167 m
.78829 1.85904 L
s
0 0 0 r
2.5 Mabswid
.61651 .57054 Mdot
.26533 .67959 m .27862 .67091 L .2791 .67549 L .606 .404 .582 r
F
.26089 .66894 m .26533 .67959 L .2791 .67549 L .683 .77 .917 r
F
.2511 .67022 m .26533 .67959 L .26089 .66894 L F
0 g
.5 Mabswid
.25066 .68152 m
.26533 .67959 L
s
.71906 .56509 m .74859 .56113 L .7245 .55761 L .673 .758 .914 r
F
.69768 .55783 m .71906 .56509 L .7245 .55761 L F
.69351 .56107 m .71906 .56509 L .69768 .55783 L F
.32595 .80532 m .31641 .80175 L .31615 .80553 L .67 .443 .567 r
F
0 g
.30696 .80729 m
.31615 .80553 L
s
.32595 .80532 m .32621 .80154 L .31641 .80175 L .67 .443 .567 r
F
0 g
.30722 .80351 m
.31641 .80175 L
s
.5638 .68115 m .56183 .6679 L .56233 .67248 L .772 .558 0 r
F
.54497 .68215 m .5638 .68115 L .56233 .67248 L .683 .77 .917 r
F
0 g
.56142 .69002 m
.5638 .68115 L
s
.33569 .80667 m .33595 .8029 L .32621 .80154 L .733 .498 .572 r
F
0 g
.33595 .8029 m
.34497 .80573 L
s
.23056 .56398 m .20903 .55672 L .20372 .5642 L .673 .757 .914 r
F
.23468 .56074 m .20903 .55672 L .23056 .56398 L F
.56318 .44006 m .58795 .43613 L .58753 .44342 L .732 .487 .558 r
F
.56318 .44006 m .5636 .43278 L .58795 .43613 L F
.57261 .41357 m .58795 .43613 L .58885 .41581 L .654 .726 .902 r
F
.57261 .41357 m .5636 .43278 L .58795 .43613 L F
.65142 .54929 m .63152 .56099 L .65374 .55294 L .673 .757 .914 r
F
.65142 .54929 m .62688 .5537 L .63152 .56099 L F
0 g
.39367 .40006 m
.3938 .34767 L
s
.23448 .55511 m .21716 .54465 L .20896 .55111 L .673 .757 .914 r
F
.23976 .55259 m .21716 .54465 L .23448 .55511 L F
0 g
.38713 .39998 m
.38726 .34755 L
s
.30133 .56811 m .31873 .55276 L .2966 .56082 L .673 .757 .914 r
F
.30133 .56811 m .32582 .5637 L .31873 .55276 L F
.4704 .67109 m .45011 .67798 L .46885 .67698 L .683 .77 .917 r
F
.48836 .67305 m .4704 .67109 L .46885 .67698 L F
.7567 .80108 m .7472 .79595 L .74697 .79972 L .733 .498 .572 r
F
0 g
.7472 .79595 m
.75693 .79731 L
s
.73739 .79616 m
.7472 .79595 L
s
.27862 .67091 m .29007 .66033 L .29055 .6649 L .522 .343 .58 r
F
.2791 .67549 m .27862 .67091 L .29055 .6649 L F
.26959 .66162 m .27862 .67091 L .29055 .6649 L .683 .77 .917 r
F
.127 .923 .03 r
.28968 .67551 m
.29128 .69423 L
s
.28926 .6707 m
.28968 .67551 L
s
.26041 .66436 m .27862 .67091 L .26959 .66162 L .683 .77 .917 r
F
0 g
.27193 .67291 m
.27862 .67091 L
s
.52456 .67113 m .53934 .66203 L .52283 .66852 L .683 .77 .917 r
F
.52456 .67113 m .54281 .66726 L .53934 .66203 L F
.33569 .80667 m .32621 .80154 L .32595 .80532 L .733 .498 .572 r
F
0 g
.32621 .80154 m
.33595 .8029 L
s
.33569 .80667 m
.34471 .8095 L
s
.31641 .80175 m
.32621 .80154 L
s
.32729 .43133 m .29848 .44563 L .32906 .44196 L .654 .726 .902 r
F
.32729 .43133 m .2958 .42969 L .29848 .44563 L F
0 g
.29848 .44563 m
.29943 .44724 L
s
.2552 .43838 m .23116 .43189 L .23069 .43917 L .667 .431 .554 r
F
0 g
.18036 .41158 m
.27898 .37529 L
s
.1128 .43644 m
.18036 .41158 L
s
.2552 .43838 m .25567 .43109 L .23116 .43189 L .667 .431 .554 r
F
0 g
.2082 .43678 m
.23116 .43189 L
s
.54497 .68215 m .56233 .67248 L .54398 .67637 L .683 .77 .917 r
F
.52614 .68315 m .54497 .68215 L .54398 .67637 L F
.27957 .44173 m .28004 .43445 L .25567 .43109 L .732 .487 .558 r
F
0 g
.28004 .43445 m
.29755 .44009 L
s
.32552 .55802 m .31813 .5414 L .31843 .54708 L .987 .712 .386 r
F
.32582 .5637 m .32552 .55802 L .31843 .54708 L F
0 g
.32552 .55802 m
.3276 .56986 L
s
.76545 .80768 m .7567 .80108 L .75647 .80485 L .793 .551 .571 r
F
0 g
.76545 .80768 m
.77307 .81179 L
s
.127 .923 .03 r
.75955 1.59204 m
.79881 .79307 L
s
0 0 0 r
2.5 Mabswid
.61463 .56933 Mdot
.127 .923 .03 r
.5 Mabswid
.61284 .6383 m
.61463 .56933 L
s
.40055 8.82506 m
.49974 4.99985 L
s
.27448 .56887 m .28884 .55462 L .2706 .56577 L .673 .757 .914 r
F
.27448 .56887 m .2966 .56082 L .28884 .55462 L F
.20903 .55672 m .17953 .56068 L .20372 .5642 L F
.23237 .66819 m .23607 .68114 L .24137 .66997 L .683 .77 .917 r
F
.23237 .66819 m .22257 .67848 L .23607 .68114 L F
0 g
.23607 .68114 m
.25066 .68152 L
s
.48089 .45517 m .48518 .43228 L .48475 .43957 L 0 0 .141 r
F
.45069 .44832 m .48089 .45517 L .48475 .43957 L .654 .726 .902 r
F
0 g
.47086 .46935 m
.48089 .45517 L
s
.75966 .44666 m .74567 .42597 L .74528 .43326 L .93 .67 .523 r
F
.75926 .45395 m .75966 .44666 L .74528 .43326 L F
0 g
.75966 .44666 m
.76834 .46183 L
s
.21059 .66914 m .22163 .66933 L .2221 .6739 L .859 .591 .532 r
F
.21059 .66914 m .21012 .66456 L .22163 .66933 L F
0 g
.22163 .66933 m
.22569 .67013 L
s
.32432 .89131 m .32407 .88911 L .32749 .88864 L .669 .437 .56 r
F
.32092 .89121 m .32407 .88911 L .32432 .89131 L .731 .482 .551 r
F
.32092 .89121 m .32067 .88901 L .32407 .88911 L F
.22389 .65577 m .22178 .66918 L .23152 .65894 L .683 .77 .917 r
F
.22389 .65577 m .21033 .66443 L .22178 .66918 L F
.32417 .88627 m .32407 .88907 L .32748 .8886 L .692 .759 .903 r
F
.32191 .8862 m .32069 .88897 L .32407 .88907 L F
.4704 .67109 m .45244 .66914 L .45011 .67798 L .683 .77 .917 r
F
.45265 .67369 m .44983 .67799 L .45032 .68257 L 0 0 .386 r
F
0 g
.4505 .68186 m
.45062 .68255 L
s
.45265 .67369 m .45217 .66911 L .44983 .67799 L 0 0 .386 r
F
.48989 .56957 m .47113 .56881 L .47145 .57449 L .603 .396 .574 r
F
0 g
.45546 .58207 m
.47145 .57449 L
s
.48989 .56957 m .48957 .56389 L .47113 .56881 L .603 .396 .574 r
F
0 g
.45515 .57639 m
.47113 .56881 L
s
.52867 .56318 m .52835 .5575 L .50888 .55629 L .733 .496 .569 r
F
0 g
.52835 .5575 m
.54634 .56175 L
s
.74674 .80349 m .73716 .79993 L .73692 .8037 L .67 .443 .568 r
F
0 g
.72769 .80546 m
.73692 .8037 L
s
.74674 .80349 m .74697 .79972 L .73716 .79993 L .67 .443 .568 r
F
0 g
.72793 .80169 m
.73716 .79993 L
s
.54699 .57311 m .52867 .56318 L .52899 .56886 L .794 .544 .559 r
F
0 g
.54699 .57311 m
.56226 .58012 L
s
.32774 .89083 m .32749 .88864 L .3307 .88762 L .6 .387 .565 r
F
.32432 .89131 m .32749 .88864 L .32774 .89083 L .669 .437 .56 r
F
0 g
.32407 .88911 m
.32749 .88864 L
s
.32644 .88596 m .32748 .8886 L .33067 .88759 L .692 .759 .903 r
F
.75647 .80485 m .7567 .80108 L .74697 .79972 L .733 .498 .572 r
F
0 g
.7567 .80108 m
.76568 .80391 L
s
.70982 .4322 m .70396 .40826 L .69491 .42737 L .654 .726 .902 r
F
.70982 .4322 m .72634 .41551 L .70396 .40826 L F
.48877 .67761 m .46915 .68157 L .48798 .68057 L .683 .77 .917 r
F
0 g
.31615 .80553 m
.32595 .80532 L
s
.32595 .80532 m
.33569 .80667 L
s
.26482 .55214 m .2659 .53588 L .25884 .55073 L .673 .757 .914 r
F
.26482 .55214 m .27787 .53871 L .2659 .53588 L F
.52614 .68315 m .54398 .67637 L .52564 .68026 L .683 .77 .917 r
F
.2703 .56009 m .2783 .54425 L .26518 .55775 L .673 .757 .914 r
F
.2703 .56009 m .28855 .54893 L .2783 .54425 L F
.31777 .89054 m .32067 .88901 L .32092 .89121 L .793 .528 .536 r
F
.31777 .89054 m .31752 .88834 L .32067 .88901 L F
0 g
.32067 .88901 m
.32407 .88911 L
s
.31982 .88576 m .32069 .88897 L .32191 .8862 L .692 .759 .903 r
F
.31982 .88576 m .31755 .8883 L .32069 .88897 L F
.127 .923 .03 r
.31635 .74558 m
.31683 .79569 L
s
.25232 .86393 m
.25242 .8695 L
s
.72358 .54622 m .75079 .53784 L .72574 .53829 L .673 .757 .914 r
F
.69961 .54271 m .72358 .54622 L .72574 .53829 L F
.6969 .54643 m .72358 .54622 L .69961 .54271 L F
.35923 .4257 m .32952 .43468 L .36011 .43101 L .654 .726 .902 r
F
.35923 .4257 m .32774 .42405 L .32952 .43468 L F
.54067 .43278 m .5636 .43278 L .56318 .44006 L .794 .542 .557 r
F
.54067 .43278 m .54109 .4255 L .5636 .43278 L F
.55759 .40871 m .5636 .43278 L .57261 .41357 L .654 .726 .902 r
F
.55759 .40871 m .54109 .4255 L .5636 .43278 L F
0 g
.5636 .43278 m
.58786 .43612 L
s
.6004 .54626 m .60203 .55243 L .60235 .55811 L .823 .62 .068 r
F
.6004 .54626 m .60007 .54058 L .60203 .55243 L F
0 g
.60203 .55243 m
.60531 .55758 L
s
.33095 .88982 m .3307 .88762 L .33348 .88613 L .514 .326 .564 r
F
.32774 .89083 m .3307 .88762 L .33095 .88982 L .6 .387 .565 r
F
0 g
.32749 .88864 m
.3307 .88762 L
s
.62551 .54011 m .60239 .55236 L .6268 .54798 L .673 .757 .914 r
F
.62551 .54011 m .60045 .54057 L .60239 .55236 L F
.32857 .88528 m .33067 .88759 L .33343 .8861 L .692 .759 .903 r
F
.45113 .44104 m .48518 .43228 L .45369 .43064 L .654 .726 .902 r
F
.42093 .43419 m .45113 .44104 L .45369 .43064 L F
.4176 .43893 m .45113 .44104 L .42093 .43419 L F
.74859 .56113 m .75151 .54351 L .75185 .54919 L 0 0 .334 r
F
.7245 .55761 m .74859 .56113 L .75185 .54919 L .673 .758 .914 r
F
0 g
.74042 .57234 m
.74859 .56113 L
s
.75647 .80485 m .74697 .79972 L .74674 .80349 L .733 .498 .572 r
F
0 g
.74697 .79972 m
.7567 .80108 L
s
.75647 .80485 m
.76545 .80768 L
s
.73716 .79993 m
.74697 .79972 L
s
.127 .923 .03 r
.28333 .66209 m
.28335 .66378 L
s
.4973 7.55955 m
.49875 6.36251 L
s
.4958 8.79919 m
.4973 7.55955 L
s
0 0 0 r
2.5 Mabswid
.50576 .57438 Mdot
.49037 .67023 m .4704 .67109 L .48836 .67305 L .683 .77 .917 r
F
.32457 .8935 m .32432 .89131 L .32774 .89083 L .669 .437 .56 r
F
.127 .923 .03 r
.5 Mabswid
.33133 1.23822 m
.3715 3.09034 L
s
.32117 .8934 m .32432 .89131 L .32457 .8935 L .731 .482 .551 r
F
.32117 .8934 m .32092 .89121 L .32432 .89131 L F
.32442 .8885 m .32432 .89131 L .32774 .89083 L .692 .759 .903 r
F
.127 .923 .03 r
.32319 .74002 m
.32321 .7422 L
s
.32215 .88843 m .32432 .89131 L .32442 .8885 L .692 .759 .903 r
F
.32215 .88843 m .32092 .89121 L .32432 .89131 L F
.47071 .67565 m .45032 .68257 L .46915 .68157 L .683 .77 .917 r
F
.48877 .67761 m .47071 .67565 L .46915 .68157 L F
.2791 .67549 m .29055 .6649 L .29102 .66948 L .522 .343 .58 r
F
.27007 .66619 m .2791 .67549 L .29102 .66948 L .683 .77 .917 r
F
.26089 .66894 m .2791 .67549 L .27007 .66619 L F
0 g
.26533 .67959 m
.2791 .67549 L
s
.328 .89303 m .32774 .89083 L .33095 .88982 L .6 .387 .565 r
F
.32457 .8935 m .32774 .89083 L .328 .89303 L .669 .437 .56 r
F
.3267 .88818 m .32774 .89083 L .33095 .88982 L .692 .759 .903 r
F
.32442 .8885 m .32774 .89083 L .3267 .88818 L F
0 g
.32432 .89131 m
.32774 .89083 L
s
.23976 .55259 m .22772 .53962 L .21716 .54465 L .673 .757 .914 r
F
.24586 .55096 m .22772 .53962 L .23976 .55259 L F
.23085 .56966 m .20932 .5624 L .20401 .56988 L F
.23497 .56642 m .20932 .5624 L .23085 .56966 L F
.29578 .54954 m .30623 .53226 L .28807 .54337 L F
.29578 .54954 m .3178 .54152 L .30623 .53226 L F
.50731 .68415 m .49438 .67686 L .49127 .67936 L .683 .77 .917 r
F
.50731 .68415 m .51272 .67297 L .50787 .67284 L F
.50731 .68415 m .5239 .67763 L .52102 .67545 L F
.52515 .67568 m .54 .66654 L .5234 .67306 L F
.52515 .67568 m .54349 .67179 L .54 .66654 L F
.31509 .88934 m .31752 .88834 L .31777 .89054 L .86 .578 .508 r
F
.31509 .88934 m .31483 .88715 L .31752 .88834 L F
0 g
.31752 .88834 m
.32067 .88901 L
s
.54281 .66726 m .55586 .65554 L .53934 .66203 L .683 .77 .917 r
F
.54281 .66726 m .56105 .66339 L .55586 .65554 L F
.5092 .56197 m .48925 .55821 L .48957 .56389 L .672 .449 .574 r
F
.5092 .56197 m .50888 .55629 L .48925 .55821 L F
0 g
.47082 .56313 m
.48925 .55821 L
s
.31804 .88497 m .31755 .8883 L .31982 .88576 L .692 .759 .903 r
F
.31804 .88497 m .31488 .88712 L .31755 .8883 L F
.127 .923 .03 r
.29814 .77411 m
.30331 .83429 L
s
.27957 .44173 m .25567 .43109 L .2552 .43838 L .732 .487 .558 r
F
0 g
.25567 .43109 m
.28004 .43445 L
s
.23116 .43189 m
.25567 .43109 L
s
.65175 .55497 m .63185 .56667 L .65407 .55862 L .673 .758 .914 r
F
.65175 .55497 m .62721 .55938 L .63185 .56667 L F
.30168 .45629 m .27957 .44173 L .27911 .44902 L .794 .542 .557 r
F
0 g
.30168 .45629 m
.3209 .46699 L
s
.74511 .88949 m .74484 .88729 L .74826 .88682 L .669 .437 .561 r
F
.74172 .88939 m .74484 .88729 L .74511 .88949 L .731 .482 .551 r
F
.74172 .88939 m .74145 .88719 L .74484 .88729 L F
.31802 .89273 m .32092 .89121 L .32117 .8934 L .793 .528 .536 r
F
.31802 .89273 m .31777 .89054 L .32092 .89121 L F
.32005 .88798 m .32092 .89121 L .32215 .88843 L .692 .759 .903 r
F
.32005 .88798 m .31777 .89054 L .32092 .89121 L F
0 g
.32092 .89121 m
.32432 .89131 L
s
.127 .923 .03 r
.25242 .8695 m
.25246 .87164 L
s
.31683 .79569 m
.31685 .79785 L
s
.74273 .88439 m .74484 .88725 L .74498 .88445 L .692 .759 .904 r
F
.74273 .88439 m .74146 .88715 L .74484 .88725 L F
.74853 .88902 m .74826 .88682 L .75148 .8858 L .6 .388 .565 r
F
.74511 .88949 m .74826 .88682 L .74853 .88902 L .669 .437 .561 r
F
0 g
.74484 .88729 m
.74826 .88682 L
s
.23468 .56074 m .21727 .55023 L .20903 .55672 L .673 .757 .914 r
F
.23999 .55821 m .21727 .55023 L .23468 .56074 L F
.74725 .88414 m .74825 .88678 L .75145 .88577 L .692 .759 .904 r
F
.63288 .44908 m .61127 .43355 L .59569 .44539 L .654 .726 .902 r
F
0 g
.5856 .45958 m
.59569 .44539 L
s
.64622 .44331 m .61127 .43355 L .63288 .44908 L .654 .726 .902 r
F
.2506 .6497 m .25016 .66096 L .25989 .65968 L .683 .77 .917 r
F
.2506 .6497 m .25989 .65968 L .25547 .64906 L F
.25107 .65434 m .25063 .66565 L .26041 .66436 L F
.25107 .65434 m .26041 .66436 L .25597 .65369 L F
.25061 .59896 m .25218 .59922 L .25195 .6413 L .751 .491 .539 r
F
.25234 .64155 m .2506 .6497 L .25547 .64906 L .683 .77 .917 r
F
.25224 .64133 m .25219 .64162 L .25234 .64155 L F
.25219 .64162 m .2506 .6497 L .25234 .64155 L F
.25263 .6457 m .25107 .65434 L .25597 .65369 L F
.25092 .64149 m .2506 .6497 L .2522 .64132 L F
.25195 .6413 m .2522 .64132 L .25221 .64125 L F
.25092 .64149 m .2522 .64132 L .25195 .6413 L F
.24895 .59789 m .24961 .59849 L .24938 .64081 L .927 .648 .491 r
F
.24576 .64958 m .25016 .66096 L .2506 .6497 L .683 .77 .917 r
F
.25137 .64656 m .24621 .65421 L .25107 .65434 L F
.2514 .64583 m .25108 .64635 L .25137 .64656 L F
.2485 .59638 m .24856 .5972 L .24833 .63973 L .798 .638 .081 r
F
.24984 .64098 m .24954 .6416 L .25093 .64137 L .683 .77 .917 r
F
.24954 .6416 m .24576 .64958 L .25017 .64258 L F
.24954 .6416 m .25017 .64258 L .25093 .64137 L F
.24883 .64597 m .24913 .64967 L .2506 .6497 L F
.25108 .64635 m .24621 .65421 L .25137 .64656 L F
.24864 .64351 m .24128 .64869 L .24576 .64958 L F
.24978 .6411 m .24853 .64221 L .24864 .64351 L F
.24853 .64221 m .24128 .64869 L .24864 .64351 L F
.25084 .64362 m .24883 .64597 L .2506 .6497 L F
.25023 .64573 m .24621 .65421 L .25098 .64627 L F
.25031 .6428 m .24576 .64958 L .25084 .64362 L F
.24128 .64869 m .24048 .66071 L .24576 .64958 L F
.24413 .65077 m .23787 .65173 L .2417 .65332 L F
.24893 .64065 m .24522 .64455 L .24984 .64098 L F
.24522 .64455 m .24128 .64869 L .24458 .64572 L F
.24522 .64455 m .24458 .64572 L .24984 .64098 L F
.24833 .64427 m .24753 .64458 L .24838 .6449 L F
.24522 .64455 m .23746 .64711 L .24128 .64869 L F
.25104 .63844 m .24725 .64086 L .24522 .64455 L F
.24725 .64086 m .23746 .64711 L .24522 .64455 L F
.2485 .59638 m .24831 .63953 L .24827 .639 L .798 .638 .081 r
F
.24856 .5972 m .24861 .64016 L .24833 .63973 L .989 .721 .393 r
F
.2485 .59638 m .24833 .63973 L .24831 .63953 L .798 .638 .081 r
F
.24856 .5972 m .24895 .59789 L .24871 .64033 L .989 .721 .393 r
F
.24856 .5972 m .24871 .64033 L .24861 .64016 L F
.24903 .59535 m .2485 .59638 L .24827 .639 L 0 0 .368 r
F
.24827 .639 m .24826 .64347 L .24825 .64329 L .798 .638 .081 r
F
.24753 .64458 m .24712 .64533 L .24838 .6449 L .683 .77 .917 r
F
.24826 .63903 m .23227 .63943 L .2328 .64231 L F
.24895 .59789 m .24938 .64081 L .24919 .64067 L .927 .648 .491 r
F
.25104 .63844 m .24851 .63857 L .24826 .63903 L .683 .77 .917 r
F
.24851 .63857 m .23227 .63943 L .24826 .63903 L F
.24831 .63953 m .24829 .64386 L .24827 .639 L .798 .638 .081 r
F
.24829 .64386 m .24827 .6436 L .24827 .639 L F
.24836 .63884 m .24825 .64329 L .24829 .64321 L 0 0 .368 r
F
.24903 .59535 m .24832 .63892 L .24836 .63884 L F
.24832 .63892 m .24825 .64329 L .24836 .63884 L F
.2482 .64265 m .2354 .63821 L .23341 .64105 L .683 .77 .917 r
F
.24833 .63973 m .24841 .64417 L .24831 .64401 L .989 .721 .393 r
F
.2509 .64192 m .25031 .6428 L .25084 .64362 L .683 .77 .917 r
F
.24919 .64067 m .24938 .64081 L .24936 .64509 L .927 .648 .491 r
F
.24883 .64597 m .24576 .64958 L .24913 .64967 L .683 .77 .917 r
F
.24927 .64933 m .24834 .64903 L .24841 .64987 L F
.24984 .64098 m .24973 .64107 L .24978 .6411 L F
.2501 .64107 m .25014 .64538 L .24938 .64081 L .844 .571 .525 r
F
.25004 .64963 m .24841 .64987 L .24852 .65123 L .683 .77 .917 r
F
.24621 .65421 m .25063 .66565 L .25107 .65434 L F
.25188 .65029 m .24668 .65878 L .25154 .65891 L F
.25139 .64625 m .25107 .65434 L .25263 .6457 L F
.2519 .64987 m .25169 .65022 L .25188 .65029 L F
.25169 .65022 m .24668 .65878 L .25188 .65029 L F
.24934 .64938 m .25029 .65789 L .24929 .65742 L .844 .571 .525 r
F
.25127 .64578 m .24621 .65421 L .2514 .64583 L .683 .77 .917 r
F
.25036 .64545 m .24375 .65145 L .24621 .65421 L F
.24844 .64422 m .24833 .64427 L .24879 .64476 L F
.24833 .64427 m .24838 .6449 L .24879 .64476 L F
.24922 .64542 m .24671 .64608 L .24413 .65077 L F
.24861 .64448 m .24862 .64881 L .24841 .64417 L .989 .721 .393 r
F
.24576 .64958 m .24048 .66071 L .25016 .66096 L .683 .77 .917 r
F
.24621 .65421 m .2409 .66539 L .25063 .66565 L F
.2417 .65332 m .2409 .66539 L .24621 .65421 L F
.25023 .65131 m .24217 .65789 L .24668 .65878 L F
.25035 .64545 m .25087 .64978 L .25033 .64974 L .751 .491 .539 r
F
.25014 .64538 m .25035 .64545 L .25033 .64974 L .844 .571 .525 r
F
.25088 .64993 m .24951 .65019 L .25023 .65131 L .683 .77 .917 r
F
.25095 .64979 m .24668 .65878 L .2519 .64987 L F
.25019 .64969 m .25033 .64974 L .25029 .65789 L .844 .571 .525 r
F
.25014 .64538 m .25033 .64974 L .25019 .64969 L F
.25036 .64545 m .25023 .64573 L .25141 .64554 L .683 .77 .917 r
F
.25075 .64549 m .25113 .6498 L .25035 .64545 L .751 .491 .539 r
F
.25113 .6498 m .25186 .65816 L .25087 .64978 L F
.25113 .6498 m .25087 .64978 L .25035 .64545 L F
.25199 .64759 m .25004 .64963 L .25033 .64974 L .683 .77 .917 r
F
.25095 .64979 m .25033 .64974 L .25088 .64993 L F
.25093 .64137 m .25068 .64176 L .2509 .64192 L F
.25023 .64573 m .25098 .64627 L .25141 .64554 L F
.2522 .64132 m .2506 .6497 L .25224 .64133 L F
.25141 .64554 m .25127 .64578 L .2514 .64583 L F
.2515 .64126 m .25186 .65816 L .25038 .64117 L .751 .491 .539 r
F
.25199 .64759 m .25033 .64974 L .25095 .64979 L .683 .77 .917 r
F
.25004 .64963 m .24951 .65019 L .25088 .64993 L F
.24951 .65019 m .24217 .65789 L .25023 .65131 L F
.24828 .64829 m .24862 .65683 L .24824 .65613 L .989 .721 .393 r
F
.24949 .64514 m .24946 .64517 L .25036 .64545 L .683 .77 .917 r
F
.24946 .64517 m .2417 .65332 L .25013 .64566 L F
.24946 .64517 m .25013 .64566 L .25036 .64545 L F
.24919 .64067 m .24922 .64499 L .24871 .64033 L .927 .648 .491 r
F
.24924 .64934 m .24841 .64987 L .24975 .64968 L .683 .77 .917 r
F
.24934 .64938 m .24975 .64968 L .25004 .64963 L F
.24924 .64934 m .24975 .64968 L .24934 .64938 L F
.24949 .64514 m .2489 .64493 L .24922 .64542 L F
.24922 .64499 m .24924 .64931 L .24886 .64473 L .927 .648 .491 r
F
.24924 .64931 m .24929 .65742 L .24901 .64914 L F
.24924 .64931 m .24901 .64914 L .24886 .64473 L F
.25068 .64176 m .24576 .64958 L .2509 .64192 L .683 .77 .917 r
F
.24922 .64499 m .24886 .64473 L .24871 .64033 L .927 .648 .491 r
F
.24831 .64401 m .24842 .6485 L .24828 .64829 L .989 .721 .393 r
F
.24375 .65145 m .24263 .6535 L .24621 .65421 L .683 .77 .917 r
F
.24841 .64987 m .23834 .6563 L .24852 .65123 L F
.24842 .6485 m .24862 .65683 L .24828 .64829 L .989 .721 .393 r
F
.24862 .64881 m .24862 .65683 L .24848 .6486 L F
.24862 .64881 m .24848 .6486 L .24841 .64417 L F
.24671 .64608 m .23787 .65173 L .24413 .65077 L .683 .77 .917 r
F
.24128 .64869 m .23152 .65894 L .24048 .66071 L F
.23746 .64711 m .23152 .65894 L .24128 .64869 L F
.24867 .6489 m .23365 .65149 L .23543 .65412 L F
.24936 .64509 m .24984 .64956 L .24934 .64938 L .844 .571 .525 r
F
.25019 .64969 m .24984 .64956 L .24961 .64519 L F
.25199 .64759 m .24833 .64837 L .24867 .6489 L .683 .77 .917 r
F
.24833 .64837 m .23365 .65149 L .24867 .6489 L F
.24861 .64016 m .24871 .64033 L .24869 .64461 L .989 .721 .393 r
F
.24861 .64448 m .24869 .64461 L .24862 .65683 L F
.24861 .64016 m .24869 .64461 L .24861 .64448 L F
.24844 .64422 m .23318 .64691 L .23496 .64954 L .683 .77 .917 r
F
.24938 .64081 m .24961 .64519 L .24936 .64509 L .844 .571 .525 r
F
.24919 .64067 m .24936 .64509 L .24922 .64499 L .927 .648 .491 r
F
.25151 .64301 m .24813 .64373 L .24844 .64422 L .683 .77 .917 r
F
.24813 .64373 m .23318 .64691 L .24844 .64422 L F
.24871 .64033 m .24886 .64473 L .24869 .64461 L .927 .648 .491 r
F
.24877 .64233 m .24818 .65531 L .24871 .65428 L 0 0 .368 r
F
.24861 .64016 m .24861 .64448 L .24833 .63973 L .989 .721 .393 r
F
.24861 .64448 m .24841 .64417 L .24833 .63973 L F
.24725 .64086 m .23457 .64493 L .23746 .64711 L .683 .77 .917 r
F
.24895 .59789 m .24919 .64067 L .24871 .64033 L .927 .648 .491 r
F
.25104 .63844 m .2479 .63968 L .24725 .64086 L .683 .77 .917 r
F
.2479 .63968 m .23457 .64493 L .24725 .64086 L F
.24879 .63805 m .24835 .64309 L .24877 .64233 L 0 0 .368 r
F
.24903 .59535 m .24842 .63874 L .24879 .63805 L F
.24842 .63874 m .24835 .64309 L .24879 .63805 L F
.24827 .6482 m .24824 .65613 L .24825 .64795 L .798 .638 .081 r
F
.24822 .64757 m .24824 .65613 L .24818 .65531 L F
.24879 .64476 m .24839 .64501 L .24922 .64542 L .683 .77 .917 r
F
.24839 .64501 m .24671 .64608 L .24844 .64563 L F
.24839 .64501 m .24844 .64563 L .24922 .64542 L F
.24831 .63953 m .24833 .63973 L .24831 .64401 L .798 .638 .081 r
F
.25199 .64759 m .24824 .64779 L .24833 .64837 L .683 .77 .917 r
F
.24824 .64779 m .24797 .6478 L .24828 .64829 L F
.24824 .64779 m .24828 .64829 L .24833 .64837 L F
.24829 .64386 m .24831 .64401 L .24828 .64829 L .798 .638 .081 r
F
.24827 .6482 m .24828 .64829 L .24824 .65613 L F
.24829 .64386 m .24828 .64829 L .24827 .6482 L F
.24831 .63953 m .24831 .64401 L .24829 .64386 L F
.24841 .64417 m .24848 .6486 L .24831 .64401 L .989 .721 .393 r
F
.24848 .6486 m .24862 .65683 L .24842 .6485 L F
.24848 .6486 m .24842 .6485 L .24831 .64401 L F
.24839 .64501 m .23496 .64954 L .23787 .65173 L .683 .77 .917 r
F
.24879 .64476 m .24838 .6449 L .24839 .64501 L F
.24838 .6449 m .23496 .64954 L .24839 .64501 L F
.24827 .6482 m .24825 .64795 L .24826 .64347 L .798 .638 .081 r
F
.24827 .6436 m .24826 .64347 L .24827 .639 L F
.24827 .6482 m .24826 .64347 L .24827 .6436 L F
.24833 .64837 m .23312 .64859 L .23365 .65149 L .683 .77 .917 r
F
.24797 .6478 m .23312 .64859 L .24833 .64837 L F
.24753 .64458 m .23496 .64954 L .24712 .64533 L F
.24973 .64107 m .24128 .64869 L .24978 .6411 L F
.2501 .64107 m .25035 .64545 L .25014 .64538 L .844 .571 .525 r
F
.24961 .59849 m .25029 .64114 L .2501 .64107 L F
.25029 .64114 m .25035 .64545 L .2501 .64107 L F
.2471 .63999 m .2328 .64231 L .23457 .64493 L .683 .77 .917 r
F
.25015 .59456 m .24903 .59535 L .24879 .63805 L .398 .209 .505 r
F
.24613 .64416 m .23265 .64401 L .23318 .64691 L .683 .77 .917 r
F
.25151 .64301 m .24748 .64323 L .24613 .64416 L F
.24748 .64323 m .23265 .64401 L .24613 .64416 L F
.2491 .63784 m .24879 .63805 L .24877 .64233 L .398 .209 .505 r
F
.24868 .6489 m .24834 .64903 L .24927 .64933 L .683 .77 .917 r
F
.24886 .64473 m .24901 .64914 L .24869 .64461 L .927 .648 .491 r
F
.2445 .64338 m .23341 .64105 L .23265 .64401 L .683 .77 .917 r
F
.25151 .64301 m .24703 .64253 L .2445 .64338 L F
.24703 .64253 m .23341 .64105 L .2445 .64338 L F
.24961 .59849 m .25061 .59896 L .25038 .64117 L .844 .571 .525 r
F
.24961 .59849 m .25038 .64117 L .25029 .64114 L F
.24565 .63872 m .23302 .63648 L .23227 .63943 L .683 .77 .917 r
F
.25104 .63844 m .24759 .63806 L .24565 .63872 L F
.24759 .63806 m .23302 .63648 L .24565 .63872 L F
.25125 .59423 m .25015 .59456 L .24991 .63728 L .567 .342 .533 r
F
.25104 .63844 m .24699 .6393 L .2471 .63999 L .683 .77 .917 r
F
.24961 .59849 m .2501 .64107 L .24938 .64081 L .844 .571 .525 r
F
.25001 .63724 m .24991 .63728 L .24989 .64156 L .567 .342 .533 r
F
.25125 .59423 m .24991 .63728 L .25001 .63724 L F
.25014 .64538 m .25019 .64969 L .24961 .64519 L .844 .571 .525 r
F
.25014 .64538 m .24961 .64519 L .24938 .64081 L F
.25038 .64117 m .25075 .64549 L .25035 .64545 L .751 .491 .539 r
F
.25151 .64301 m .2489 .64493 L .24949 .64514 L .683 .77 .917 r
F
.24586 .63954 m .2328 .64231 L .2471 .63999 L F
.24829 .64744 m .24856 .64695 L .24877 .64233 L 0 0 .368 r
F
.24901 .64914 m .2489 .64906 L .24869 .64461 L .927 .648 .491 r
F
.25151 .64301 m .24891 .64224 L .24829 .64266 L .683 .77 .917 r
F
.25151 .64301 m .24844 .64422 L .24879 .64476 L F
.249 .64218 m .24871 .65428 L .24989 .64156 L .398 .209 .505 r
F
.24814 .64201 m .2354 .63821 L .2482 .64265 L .683 .77 .917 r
F
.24829 .64386 m .24827 .6482 L .24827 .6436 L .798 .638 .081 r
F
.24826 .64347 m .24825 .64795 L .24825 .64329 L F
.24842 .63874 m .24832 .64315 L .24835 .64309 L 0 0 .368 r
F
.24884 .64222 m .23849 .63571 L .2354 .63821 L .683 .77 .917 r
F
.25029 .64114 m .25038 .64117 L .25035 .64545 L .844 .571 .525 r
F
.25151 .64301 m .24913 .64168 L .24884 .64222 L .683 .77 .917 r
F
.24829 .64321 m .24832 .64315 L .24842 .63874 L 0 0 .368 r
F
.24913 .64168 m .23849 .63571 L .24884 .64222 L .683 .77 .917 r
F
.24836 .63884 m .24829 .64321 L .24842 .63874 L 0 0 .368 r
F
.24829 .64321 m .24822 .64757 L .24832 .64315 L F
.24924 .64605 m .24294 .63828 L .23896 .64029 L .683 .77 .917 r
F
.25199 .64759 m .25018 .64573 L .24924 .64605 L F
.249 .64218 m .24875 .64662 L .24889 .64651 L .398 .209 .505 r
F
.24835 .64309 m .24829 .64744 L .24877 .64233 L 0 0 .368 r
F
.24832 .64315 m .24822 .64757 L .24835 .64309 L F
.24825 .64329 m .24825 .64795 L .24822 .64757 L .798 .638 .081 r
F
.24829 .64321 m .24825 .64329 L .24822 .64757 L 0 0 .368 r
F
.25018 .64573 m .24294 .63828 L .24924 .64605 L .683 .77 .917 r
F
.25011 .64148 m .24989 .64156 L .24987 .64584 L .567 .342 .533 r
F
.25001 .64579 m .24987 .64584 L .24982 .6535 L F
.25011 .64148 m .24987 .64584 L .25001 .64579 L F
.25104 .63844 m .24893 .64065 L .24984 .64098 L .683 .77 .917 r
F
.24759 .63806 m .235 .63366 L .23302 .63648 L F
.25104 .63844 m .24862 .63772 L .24759 .63806 L F
.24862 .63772 m .235 .63366 L .24759 .63806 L F
.25022 .63717 m .24989 .64156 L .25011 .64148 L .567 .342 .533 r
F
.25061 .59896 m .2515 .64126 L .25038 .64117 L .751 .491 .539 r
F
.25125 .59423 m .25001 .63724 L .25022 .63717 L .567 .342 .533 r
F
.25001 .63724 m .24989 .64156 L .25022 .63717 L F
.24874 .64662 m .23896 .64029 L .23587 .64279 L .683 .77 .917 r
F
.24961 .64519 m .24984 .64956 L .24936 .64509 L .844 .571 .525 r
F
.25199 .64759 m .24942 .64615 L .24874 .64662 L .683 .77 .917 r
F
.24835 .64309 m .24822 .64757 L .24829 .64744 L 0 0 .368 r
F
.24942 .64615 m .23896 .64029 L .24874 .64662 L .683 .77 .917 r
F
.249 .64218 m .24877 .64233 L .24875 .64662 L .398 .209 .505 r
F
.24869 .64461 m .24929 .65742 L .24862 .65683 L .927 .648 .491 r
F
.24889 .64651 m .24875 .64662 L .24871 .65428 L .398 .209 .505 r
F
.2491 .63784 m .24877 .64233 L .249 .64218 L F
.25015 .59456 m .24879 .63805 L .2491 .63784 L F
.24699 .6393 m .24586 .63954 L .24637 .63973 L .683 .77 .917 r
F
.24699 .6393 m .24637 .63973 L .2471 .63999 L F
.24842 .6472 m .23587 .64279 L .23388 .64562 L F
.25199 .64759 m .24874 .64662 L .24842 .6472 L F
.24874 .64662 m .23587 .64279 L .24842 .6472 L F
.24375 .65145 m .2417 .65332 L .24263 .6535 L F
.23787 .65173 m .2319 .66362 L .2417 .65332 L F
.24841 .64987 m .23543 .65412 L .23834 .6563 L F
.24829 .64744 m .24818 .65531 L .24856 .64695 L 0 0 .368 r
F
.25151 .64301 m .24949 .64514 L .25036 .64545 L .683 .77 .917 r
F
.24984 .64956 m .25029 .65789 L .24934 .64938 L .844 .571 .525 r
F
.25033 .64974 m .25186 .65816 L .25029 .65789 L .751 .491 .539 r
F
.25087 .64978 m .25186 .65816 L .25033 .64974 L F
.25141 .64554 m .25139 .64625 L .25261 .64564 L .683 .77 .917 r
F
.2516 .64556 m .25193 .64558 L .25186 .65816 L .751 .491 .539 r
F
.25199 .64759 m .25095 .64979 L .2519 .64987 L .683 .77 .917 r
F
.25199 .64759 m .24924 .64934 L .25004 .64963 L F
.25019 .64969 m .25029 .65789 L .24984 .64956 L .844 .571 .525 r
F
.25151 .64301 m .24879 .64476 L .2489 .64493 L .683 .77 .917 r
F
.24922 .64499 m .24936 .64509 L .24929 .65742 L .927 .648 .491 r
F
.25199 .64759 m .24868 .6489 L .24927 .64933 L .683 .77 .917 r
F
.24901 .64914 m .24929 .65742 L .2489 .64906 L .927 .648 .491 r
F
.24989 .64156 m .24871 .65428 L .24982 .6535 L .398 .209 .505 r
F
.24903 .59535 m .24827 .639 L .24832 .63892 L 0 0 .368 r
F
.24903 .59535 m .24836 .63884 L .24842 .63874 L F
.24908 .63785 m .23808 .63117 L .235 .63366 L .683 .77 .917 r
F
.25104 .63844 m .24949 .63757 L .24908 .63785 L F
.24949 .63757 m .23808 .63117 L .24908 .63785 L F
.24991 .63728 m .249 .64218 L .24989 .64156 L .398 .209 .505 r
F
.25015 .59456 m .2491 .63784 L .24991 .63728 L F
.2491 .63784 m .249 .64218 L .24991 .63728 L F
.24829 .64266 m .24814 .64201 L .2482 .64265 L .683 .77 .917 r
F
.24891 .64224 m .24814 .64201 L .24829 .64266 L F
.24834 .64903 m .23543 .65412 L .24841 .64987 L F
.24832 .63892 m .24827 .639 L .24825 .64329 L 0 0 .368 r
F
.24825 .64795 m .24824 .65613 L .24822 .64757 L .798 .638 .081 r
F
.24829 .64744 m .24822 .64757 L .24818 .65531 L 0 0 .368 r
F
.2417 .65332 m .2319 .66362 L .2409 .66539 L .683 .77 .917 r
F
.24305 .65698 m .23834 .6563 L .24217 .65789 L F
.24852 .65123 m .24534 .65282 L .24305 .65698 L F
.24534 .65282 m .23834 .6563 L .24305 .65698 L F
.25104 .63844 m .24984 .64098 L .25093 .64137 L F
.25151 .64301 m .25036 .64545 L .25141 .64554 L F
.2515 .64126 m .25195 .6413 L .25193 .64558 L .751 .491 .539 r
F
.2515 .64126 m .25193 .64558 L .2516 .64556 L F
.25261 .64564 m .25139 .64625 L .25263 .6457 L .683 .77 .917 r
F
.25151 .64301 m .25141 .64554 L .25261 .64564 L F
.25292 .64984 m .25154 .65891 L .25644 .65827 L F
.25188 .6503 m .25154 .65891 L .25292 .64984 L F
.25191 .64987 m .25345 .65795 L .25186 .65816 L .641 .401 .539 r
F
.25195 .6413 m .25271 .64972 L .25191 .64987 L F
.25286 .64969 m .25188 .6503 L .25292 .64984 L .683 .77 .917 r
F
.2519 .64987 m .25188 .6503 L .25286 .64969 L F
.25271 .64972 m .25345 .65795 L .25191 .64987 L .641 .401 .539 r
F
.25199 .64759 m .2519 .64987 L .25286 .64969 L .683 .77 .917 r
F
.2535 .64958 m .25448 .65751 L .25345 .65795 L .515 .301 .526 r
F
.25352 .6453 m .25385 .64942 L .2535 .64958 L F
.25389 .64962 m .25644 .65827 L .25393 .64959 L .683 .77 .917 r
F
.25452 .64912 m .25518 .65695 L .25448 .65751 L .353 .175 .495 r
F
.25597 .65369 m .26041 .66436 L .26959 .66162 L .683 .77 .917 r
F
.25521 .65091 m .25644 .65827 L .26103 .6569 L F
.25566 .64793 m .25572 .65545 L .25561 .65626 L 0 0 .125 r
F
.25547 .64092 m .26004 .6477 L .26399 .6457 L .683 .77 .917 r
F
.25377 .59902 m .25427 .64069 L .25355 .64101 L .515 .301 .526 r
F
.25377 .59902 m .25479 .59858 L .25457 .64056 L F
.25354 .64101 m .2552 .64272 L .25471 .64049 L .683 .77 .917 r
F
.25391 .64202 m .25547 .64906 L .25416 .64165 L F
.25258 .64212 m .25547 .64906 L .25374 .64121 L F
.25555 .63978 m .26399 .6457 L .26707 .64321 L F
.25104 .63844 m .25467 .64047 L .25555 .63978 L F
.2555 .59801 m .25593 .59733 L .2557 .63937 L .065 0 .408 r
F
.2552 .64272 m .25547 .64906 L .26004 .6477 L .683 .77 .917 r
F
.25416 .64165 m .25481 .64531 L .2552 .64272 L F
.25481 .64531 m .25547 .64906 L .2552 .64272 L F
.25593 .59733 m .25604 .59652 L .25581 .63863 L 0 0 .125 r
F
.2552 .64681 m .26056 .65232 L .25544 .64522 L .683 .77 .917 r
F
.26004 .6477 m .27694 .65296 L .26399 .6457 L F
.25534 .64415 m .26453 .65032 L .26762 .64781 L F
.25355 .64101 m .25378 .64518 L .25352 .6453 L .515 .301 .526 r
F
.25374 .64121 m .25391 .64202 L .25416 .64165 L .683 .77 .917 r
F
.25427 .64069 m .25433 .64494 L .25355 .64101 L .515 .301 .526 r
F
.25263 .6457 m .25597 .65369 L .25367 .64523 L .683 .77 .917 r
F
.25393 .64959 m .25411 .65022 L .25429 .64996 L F
.2535 .64958 m .25644 .65827 L .25386 .64951 L F
.25286 .64969 m .25292 .64984 L .2535 .64958 L F
.25292 .64984 m .25644 .65827 L .2535 .64958 L F
.25547 .64906 m .25989 .65968 L .26903 .65695 L F
.25383 .6454 m .25597 .65369 L .26056 .65232 L F
.2555 .59801 m .25558 .63955 L .25527 .64 L .065 0 .408 r
F
.25599 .63897 m .26707 .64321 L .26905 .6404 L .683 .77 .917 r
F
.25377 .59902 m .25457 .64056 L .25427 .64069 L .515 .301 .526 r
F
.25218 .59922 m .25377 .59902 L .25355 .64101 L .641 .401 .539 r
F
.25218 .59922 m .25355 .64101 L .2534 .64104 L F
.25218 .59922 m .25352 .6453 L .25339 .64532 L F
.25488 .64059 m .26399 .6457 L .25527 .64 L .683 .77 .917 r
F
.25544 .64522 m .26055 .65232 L .25756 .6464 L F
.2552 .64272 m .26004 .6477 L .25547 .64092 L F
.25527 .64 m .26399 .6457 L .25555 .63978 L F
.25687 .64188 m .27038 .64202 L .26985 .63912 L F
.25559 .64378 m .25543 .64401 L .25527 .64 L .065 0 .408 r
F
.25558 .63955 m .25568 .64365 L .25559 .64378 L F
.25467 .64047 m .25488 .64059 L .25527 .64 L .683 .77 .917 r
F
.25507 .64016 m .2551 .6444 L .25457 .64056 L .353 .175 .495 r
F
.25467 .64478 m .25502 .64463 L .25525 .64428 L .683 .77 .917 r
F
.25467 .64478 m .25525 .64428 L .25494 .64453 L F
.25433 .64494 m .25378 .64518 L .25355 .64101 L .515 .301 .526 r
F
.25485 .64488 m .2552 .64681 L .25544 .64522 L .683 .77 .917 r
F
.25151 .64301 m .25423 .64581 L .25485 .64488 L F
.25423 .64581 m .2552 .64681 L .25485 .64488 L F
.25525 .64428 m .25544 .64824 L .25523 .64857 L .065 0 .408 r
F
.25527 .64 m .25536 .64412 L .25525 .64428 L F
.25536 .64412 m .25544 .64824 L .25525 .64428 L F
.2551 .6444 m .25513 .64865 L .25485 .6446 L .353 .175 .495 r
F
.2551 .6444 m .25485 .6446 L .25457 .64056 L F
.25471 .64049 m .2552 .64272 L .25547 .64092 L .683 .77 .917 r
F
.25507 .64016 m .25525 .64428 L .2551 .6444 L .353 .175 .495 r
F
.25479 .59858 m .25521 .64005 L .25507 .64016 L F
.25521 .64005 m .25525 .64428 L .25507 .64016 L F
.25957 .63663 m .26981 .63744 L .26928 .63456 L .683 .77 .917 r
F
.25558 .63955 m .2557 .63937 L .25568 .64365 L .065 0 .408 r
F
.25578 .63884 m .25581 .63863 L .25579 .64291 L 0 0 .125 r
F
.25578 .63884 m .25579 .64291 L .25577 .64307 L F
.25578 .63884 m .25577 .64307 L .2557 .63937 L F
.25485 .64488 m .25544 .64522 L .25534 .64415 L .683 .77 .917 r
F
.25544 .64522 m .26453 .65032 L .25558 .64431 L F
.25544 .64522 m .25558 .64431 L .25534 .64415 L F
.25568 .64365 m .25575 .6473 L .25566 .64793 L 0 0 .125 r
F
.2557 .63937 m .25573 .64333 L .25568 .64365 L F
.25573 .64333 m .25575 .6473 L .25568 .64365 L F
.25577 .64307 m .25575 .6473 L .25573 .64333 L F
.25577 .64307 m .25573 .64333 L .2557 .63937 L F
.26153 .63958 m .26905 .6404 L .26963 .63812 L .683 .77 .917 r
F
.26153 .63958 m .26963 .63812 L .26981 .63744 L F
.25604 .64123 m .26985 .63912 L .26807 .63648 L F
.2534 .64104 m .25355 .64101 L .25352 .6453 L .641 .401 .539 r
F
.25427 .64069 m .25457 .64056 L .25455 .64484 L .515 .301 .526 r
F
.25494 .64453 m .25525 .64428 L .25534 .64415 L .683 .77 .917 r
F
.2551 .6444 m .25525 .64428 L .25523 .64857 L .353 .175 .495 r
F
.25496 .65255 m .25644 .65827 L .25521 .65091 L .683 .77 .917 r
F
.25513 .64865 m .25523 .64857 L .25518 .65695 L .353 .175 .495 r
F
.2551 .6444 m .25523 .64857 L .25513 .64865 L F
.25367 .64523 m .25373 .64548 L .25383 .6454 L .683 .77 .917 r
F
.25386 .64951 m .25389 .64962 L .25393 .64959 L F
.25378 .64518 m .25402 .64935 L .25352 .6453 L .515 .301 .526 r
F
.25402 .64935 m .25448 .65751 L .25385 .64942 L F
.25402 .64935 m .25385 .64942 L .25352 .6453 L F
.25597 .65369 m .26959 .66162 L .26056 .65232 L .683 .77 .917 r
F
.25463 .64907 m .26103 .6569 L .26501 .65489 L F
.25373 .64548 m .25597 .65369 L .25383 .6454 L F
.25433 .64494 m .25455 .64484 L .25448 .65751 L .515 .301 .526 r
F
.25309 .6411 m .2535 .64958 L .25327 .64962 L .641 .401 .539 r
F
.25218 .59922 m .25328 .64106 L .25309 .6411 L F
.25328 .64106 m .2535 .64958 L .25309 .6411 L F
.25104 .63844 m .25354 .64101 L .25471 .64049 L .683 .77 .917 r
F
.25199 .64759 m .25379 .64945 L .25463 .64907 L F
.25379 .64945 m .2603 .65615 L .25463 .64907 L F
.2556 .64802 m .25561 .65626 L .25544 .64824 L .065 0 .408 r
F
.25575 .6473 m .25577 .6472 L .25572 .65545 L 0 0 .125 r
F
.25575 .6473 m .25572 .65545 L .25566 .64793 L F
.25523 .64857 m .25561 .65626 L .25518 .65695 L .065 0 .408 r
F
.25577 .6472 m .25527 .6544 L .25572 .65545 L .986 .729 .348 r
F
.25577 .64307 m .25579 .64291 L .25577 .6472 L 0 0 .125 r
F
.25577 .64307 m .25577 .6472 L .25575 .6473 L F
.25579 .64291 m .25561 .64688 L .25577 .6472 L .986 .729 .348 r
F
.25482 .64918 m .26501 .65489 L .25523 .64856 L .683 .77 .917 r
F
.25559 .64378 m .25568 .64365 L .25566 .64793 L .065 0 .408 r
F
.2556 .64802 m .25566 .64793 L .25561 .65626 L F
.25559 .64378 m .25566 .64793 L .2556 .64802 L F
.25603 .64738 m .27009 .64956 L .27085 .64659 L .683 .77 .917 r
F
.25467 .64478 m .25485 .64488 L .25502 .64463 L F
.25457 .64056 m .25513 .64865 L .25452 .64912 L .353 .175 .495 r
F
.25199 .64759 m .25562 .64799 L .25603 .64738 L .683 .77 .917 r
F
.25547 .64906 m .26903 .65695 L .26004 .6477 L F
.25756 .6464 m .26056 .65232 L .26453 .65032 L F
.25562 .64799 m .27009 .64956 L .25603 .64738 L F
.25544 .64824 m .25561 .65626 L .25523 .64857 L .065 0 .408 r
F
.25561 .64688 m .25527 .6544 L .25577 .6472 L .986 .729 .348 r
F
.2603 .65615 m .26103 .6569 L .26012 .65578 L .683 .77 .917 r
F
.2603 .65615 m .26012 .65578 L .25463 .64907 L F
.25199 .64759 m .2546 .64906 L .25523 .64856 L F
.2546 .64906 m .25482 .64918 L .25523 .64857 L F
.2546 .64906 m .25523 .64857 L .25523 .64856 L F
.25429 .64996 m .25496 .65255 L .25521 .65091 L F
.25411 .65022 m .25644 .65827 L .25429 .64996 L F
.25513 .64865 m .25518 .65695 L .25452 .64912 L .353 .175 .495 r
F
.25533 .64201 m .2542 .65358 L .25527 .6544 L .908 .63 .502 r
F
.25479 .59858 m .2555 .59801 L .25527 .64 L .353 .175 .495 r
F
.25521 .64005 m .25527 .64 L .25525 .64428 L F
.25479 .59858 m .25527 .64 L .25521 .64005 L F
.25218 .59922 m .25309 .6411 L .25195 .6413 L .641 .401 .539 r
F
.25479 .59858 m .25507 .64016 L .25457 .64056 L .353 .175 .495 r
F
.25558 .59547 m .25451 .59464 L .25429 .63706 L .908 .63 .502 r
F
.25151 .64301 m .25628 .64276 L .25635 .64265 L .683 .77 .917 r
F
.25556 .64215 m .25635 .64265 L .25687 .64188 L F
.25151 .64301 m .25635 .64265 L .25556 .64215 L F
.25104 .63844 m .25599 .63897 L .25559 .6382 L F
.25459 .63725 m .25429 .63706 L .25426 .64134 L .908 .63 .502 r
F
.25433 .64494 m .25438 .64919 L .25378 .64518 L .515 .301 .526 r
F
.25427 .64069 m .25455 .64484 L .25433 .64494 L F
.25654 .64008 m .26707 .64321 L .25599 .63897 L .683 .77 .917 r
F
.25592 .64208 m .26985 .63912 L .25604 .64123 L F
.25559 .6382 m .26153 .63958 L .26981 .63744 L F
.25151 .64301 m .25705 .64466 L .26067 .64401 L F
.25581 .63863 m .25543 .6422 L .25579 .64291 L .986 .729 .348 r
F
.25771 .63808 m .26981 .63744 L .25957 .63663 L .683 .77 .917 r
F
.25558 .63955 m .25559 .64378 L .25527 .64 L .065 0 .408 r
F
.25548 .63798 m .25533 .64201 L .25543 .6422 L .986 .729 .348 r
F
.25417 .64132 m .26807 .63648 L .26517 .6343 L .683 .77 .917 r
F
.25151 .64301 m .25518 .64157 L .25417 .64132 L F
.25518 .64157 m .26807 .63648 L .25417 .64132 L F
.25438 .64919 m .25402 .64935 L .25378 .64518 L .515 .301 .526 r
F
.25327 .64962 m .2535 .64958 L .25345 .65795 L .641 .401 .539 r
F
.25385 .64942 m .25448 .65751 L .2535 .64958 L .515 .301 .526 r
F
.25426 .64134 m .25312 .6532 L .2542 .65358 L .809 .541 .533 r
F
.25104 .63844 m .25559 .6382 L .25535 .63773 L .683 .77 .917 r
F
.25104 .63844 m .25535 .63773 L .25511 .63757 L F
.25558 .59547 m .25459 .63725 L .25535 .63773 L .908 .63 .502 r
F
.25593 .59733 m .25581 .63863 L .25578 .63884 L 0 0 .125 r
F
.25593 .59733 m .25578 .63884 L .2557 .63937 L F
.25604 .59652 m .25548 .63798 L .25581 .63863 L .986 .729 .348 r
F
.2555 .59801 m .2557 .63937 L .25558 .63955 L .065 0 .408 r
F
.25604 .59652 m .2554 .63781 L .25548 .63798 L .986 .729 .348 r
F
.25604 .59652 m .25558 .59547 L .25535 .63773 L F
.25604 .59652 m .25535 .63773 L .2554 .63781 L F
.25104 .63844 m .25654 .64008 L .25599 .63897 L .683 .77 .917 r
F
.26004 .6477 m .26903 .65695 L .27694 .65296 L F
.25199 .64759 m .2681 .65239 L .27009 .64956 L F
.25351 .63687 m .25318 .64108 L .2534 .64113 L .809 .541 .533 r
F
.25451 .59464 m .2533 .63682 L .25351 .63687 L F
.2533 .63682 m .25318 .64108 L .25351 .63687 L F
.2535 .63687 m .26752 .63194 L .26463 .62976 L .683 .77 .917 r
F
.25104 .63844 m .25444 .6371 L .2535 .63687 L F
.25444 .6371 m .26752 .63194 L .2535 .63687 L F
.25221 .64125 m .2522 .64132 L .25224 .64133 L F
.25309 .6411 m .25318 .64536 L .25195 .6413 L .641 .401 .539 r
F
.25254 .64547 m .25263 .6457 L .25352 .6453 L .683 .77 .917 r
F
.25318 .64536 m .25345 .65795 L .25233 .64551 L .641 .401 .539 r
F
.25318 .64536 m .25233 .64551 L .25195 .6413 L F
.25151 .64301 m .25254 .64547 L .25367 .64523 L .683 .77 .917 r
F
.25254 .64547 m .25352 .6453 L .25367 .64523 L F
.25199 .64759 m .25286 .64969 L .25386 .64951 L F
.2532 .63679 m .25203 .65307 L .25312 .6532 L .734 .477 .54 r
F
.25343 .59427 m .25242 .63676 L .2532 .63679 L F
.25104 .63844 m .2535 .63687 L .2532 .63679 L .683 .77 .917 r
F
.25104 .63844 m .25258 .64212 L .25374 .64121 L F
.25459 .63725 m .25426 .64134 L .25449 .64148 L .908 .63 .502 r
F
.25548 .63798 m .25543 .6422 L .25581 .63863 L .986 .729 .348 r
F
.25526 .63754 m .25771 .63808 L .25957 .63663 L .683 .77 .917 r
F
.2554 .63781 m .25533 .64201 L .25548 .63798 L .986 .729 .348 r
F
.2554 .63781 m .25535 .63773 L .25533 .64201 L F
.25061 .59896 m .25195 .6413 L .2515 .64126 L .751 .491 .539 r
F
.25503 .63687 m .26928 .63456 L .26752 .63194 L .683 .77 .917 r
F
.25104 .63844 m .2579 .63698 L .25503 .63687 L F
.2579 .63698 m .26928 .63456 L .25503 .63687 L F
.25343 .59427 m .25235 .59414 L .25211 .63675 L .734 .477 .54 r
F
.25104 .63844 m .2532 .63679 L .25263 .63677 L .683 .77 .917 r
F
.2535 .63687 m .26463 .62976 L .25272 .63667 L F
.25351 .63687 m .2534 .64113 L .25429 .63706 L .809 .541 .533 r
F
.25511 .63757 m .25535 .63773 L .25526 .63754 L .683 .77 .917 r
F
.25459 .63725 m .25449 .64148 L .25535 .63773 L .908 .63 .502 r
F
.25245 .64105 m .26133 .6327 L .25683 .63181 L .683 .77 .917 r
F
.25151 .64301 m .25335 .64108 L .25245 .64105 L F
.25429 .63706 m .2534 .64113 L .25426 .64134 L .809 .541 .533 r
F
.25559 .6382 m .25771 .63808 L .25526 .63754 L .683 .77 .917 r
F
.25599 .63897 m .26153 .63958 L .25559 .6382 L F
.25335 .64108 m .26133 .6327 L .25245 .64105 L F
.25242 .63676 m .25211 .63675 L .25209 .64103 L .734 .477 .54 r
F
.25231 .64104 m .25207 .64532 L .25221 .64532 L F
.25151 .64301 m .25447 .64113 L .25335 .64108 L .683 .77 .917 r
F
.25242 .63676 m .25231 .64104 L .2532 .63679 L .734 .477 .54 r
F
.25231 .64104 m .2529 .64106 L .2532 .63679 L F
.25263 .63677 m .2532 .63679 L .25272 .63667 L .683 .77 .917 r
F
.2533 .63682 m .2532 .63679 L .25318 .64108 L .809 .541 .533 r
F
.25208 .64532 m .2573 .63639 L .25243 .63626 L .683 .77 .917 r
F
.25199 .64759 m .25305 .64535 L .25208 .64532 L F
.25231 .64104 m .25203 .65307 L .2529 .64106 L .734 .477 .54 r
F
.25151 .64301 m .25556 .64215 L .25484 .6417 L .683 .77 .917 r
F
.2534 .64113 m .2533 .64539 L .25426 .64134 L .809 .541 .533 r
F
.25199 .64759 m .25466 .64589 L .254 .64548 L .683 .77 .917 r
F
.25339 .64532 m .25352 .6453 L .2535 .64958 L .641 .401 .539 r
F
.2533 .64539 m .25312 .6532 L .25386 .64553 L .809 .541 .533 r
F
.25151 .64301 m .25467 .64478 L .25534 .64415 L .683 .77 .917 r
F
.2533 .64539 m .25386 .64553 L .25426 .64134 L .809 .541 .533 r
F
.25305 .64535 m .25306 .64533 L .25208 .64532 L .683 .77 .917 r
F
.25535 .63773 m .25449 .64148 L .25533 .64201 L .908 .63 .502 r
F
.25306 .64533 m .2573 .63639 L .25219 .64512 L .683 .77 .917 r
F
.25306 .64533 m .25219 .64512 L .25208 .64532 L F
.25231 .64104 m .25209 .64103 L .25207 .64532 L .734 .477 .54 r
F
.25221 .64532 m .25207 .64532 L .25203 .65307 L F
.25242 .63676 m .25209 .64103 L .25231 .64104 L F
.25343 .59427 m .25211 .63675 L .25242 .63676 L F
.25335 .64108 m .26517 .6343 L .26133 .6327 L .683 .77 .917 r
F
.25447 .64113 m .26517 .6343 L .25335 .64108 L F
.25272 .63667 m .26463 .62976 L .26081 .62818 L F
.25451 .59464 m .25343 .59427 L .2532 .63679 L .809 .541 .533 r
F
.25451 .59464 m .2532 .63679 L .2533 .63682 L F
.25449 .64148 m .25426 .64134 L .25424 .64563 L .908 .63 .502 r
F
.25484 .6417 m .25592 .64208 L .25604 .64123 L .683 .77 .917 r
F
.25556 .64215 m .25592 .64208 L .25484 .6417 L F
.25306 .64533 m .26181 .63728 L .2573 .63639 L F
.25199 .64759 m .25393 .64555 L .25306 .64533 L F
.25449 .64148 m .25424 .64563 L .25438 .64572 L .908 .63 .502 r
F
.25393 .64555 m .26181 .63728 L .25306 .64533 L .683 .77 .917 r
F
.2534 .64113 m .25318 .64108 L .25316 .64536 L .809 .541 .533 r
F
.2533 .64539 m .25316 .64536 L .25312 .6532 L F
.2534 .64113 m .25316 .64536 L .2533 .64539 L F
.25936 .6426 m .26962 .64498 L .27038 .64202 L .683 .77 .917 r
F
.25151 .64301 m .26854 .64486 L .25936 .6426 L F
.26854 .64486 m .26962 .64498 L .25936 .6426 L F
.25196 .63649 m .26081 .62818 L .25633 .62729 L F
.25211 .63675 m .25093 .65316 L .25203 .65307 L .66 .416 .54 r
F
.25235 .59414 m .25132 .63686 L .25211 .63675 L F
.25104 .63844 m .2527 .63667 L .25182 .63679 L .683 .77 .917 r
F
.25104 .63844 m .25092 .64149 L .25221 .64125 L F
.25102 .6369 m .24982 .6535 L .25093 .65316 L .567 .342 .533 r
F
.25125 .59423 m .25022 .63717 L .25102 .6369 L F
.25022 .63717 m .25001 .64579 L .25102 .6369 L F
.25001 .64579 m .25039 .64566 L .25102 .6369 L F
.25104 .63844 m .24991 .63728 L .24933 .63748 L .683 .77 .917 r
F
.25235 .59414 m .25125 .59423 L .25099 .64118 L .66 .416 .54 r
F
.25122 .64115 m .25099 .64118 L .25093 .65316 L F
.25235 .59414 m .25099 .64118 L .25122 .64115 L F
.24879 .64149 m .24246 .6337 L .23849 .63571 L .683 .77 .917 r
F
.25151 .64301 m .24988 .64134 L .24879 .64149 L F
.24988 .64134 m .24246 .6337 L .24879 .64149 L F
.25104 .63844 m .25148 .62716 L .24661 .6278 L F
.25076 .64122 m .25196 .63168 L .24706 .63233 L F
.25151 .64301 m .25159 .6411 L .25076 .64122 L F
.25132 .63686 m .25122 .64115 L .25211 .63675 L .66 .416 .54 r
F
.25104 .63844 m .25228 .63581 L .25117 .63512 L .683 .77 .917 r
F
.25159 .6411 m .25196 .63168 L .25076 .64122 L F
.25122 .64115 m .2518 .64107 L .25211 .63675 L .66 .416 .54 r
F
.25104 .63844 m .25272 .63667 L .2527 .63667 L .683 .77 .917 r
F
.25182 .63679 m .2527 .63667 L .25196 .63649 L F
.25109 .64543 m .25243 .63626 L .24753 .6369 L F
.25199 .64759 m .25209 .64509 L .25109 .64543 L F
.25122 .64115 m .25093 .65316 L .2518 .64107 L .66 .416 .54 r
F
.25272 .63667 m .26081 .62818 L .25196 .63649 L .683 .77 .917 r
F
.25228 .63581 m .25633 .62729 L .25117 .63512 L F
.25151 .64301 m .25683 .63181 L .25196 .63168 L F
.25209 .64509 m .25243 .63626 L .25109 .64543 L F
.25001 .64579 m .24982 .6535 L .25039 .64566 L .567 .342 .533 r
F
.24933 .63748 m .24204 .62917 L .23808 .63117 L .683 .77 .917 r
F
.24991 .63728 m .24204 .62917 L .24933 .63748 L F
.25451 .59464 m .25351 .63687 L .25429 .63706 L .809 .541 .533 r
F
.254 .64548 m .26564 .63887 L .26181 .63728 L .683 .77 .917 r
F
.25438 .64919 m .25448 .65751 L .25402 .64935 L .515 .301 .526 r
F
.25199 .64759 m .25574 .64739 L .25583 .64677 L .683 .77 .917 r
F
.25449 .64148 m .2542 .65358 L .25533 .64201 L .908 .63 .502 r
F
.25559 .64378 m .2556 .64802 L .25543 .64401 L .065 0 .408 r
F
.25466 .64589 m .26564 .63887 L .254 .64548 L .683 .77 .917 r
F
.25438 .64572 m .25424 .64563 L .2542 .65358 L .908 .63 .502 r
F
.25558 .59547 m .25429 .63706 L .25459 .63725 L F
.25117 .63512 m .25633 .62729 L .25148 .62716 L .683 .77 .917 r
F
.25628 .64276 m .27038 .64202 L .25687 .64188 L F
.2556 .64802 m .25544 .64824 L .25527 .64 L .065 0 .408 r
F
.26055 .65232 m .26056 .65232 L .25756 .6464 L .683 .77 .917 r
F
.26056 .65232 m .27754 .65761 L .26453 .65032 L F
.25523 .64856 m .26501 .65489 L .2681 .65239 L F
.26399 .6457 m .28309 .64798 L .26707 .64321 L F
.26067 .64401 m .26762 .64781 L .26962 .64498 L F
.25705 .64466 m .26762 .64781 L .26067 .64401 L F
.25499 .64567 m .26855 .64106 L .26564 .63887 L F
.25199 .64759 m .2553 .64628 L .25499 .64567 L F
.2553 .64628 m .26855 .64106 L .25499 .64567 L F
.25543 .6422 m .25533 .64201 L .25531 .64629 L .986 .729 .348 r
F
.25537 .64642 m .25531 .64629 L .25527 .6544 L F
.25543 .6422 m .25531 .64629 L .25537 .64642 L F
.25583 .64677 m .27085 .64659 L .27033 .6437 L .683 .77 .917 r
F
.25574 .64739 m .27085 .64659 L .25583 .64677 L F
.2553 .64628 m .27033 .6437 L .26855 .64106 L F
.25199 .64759 m .25558 .64683 L .2553 .64628 L F
.25558 .64683 m .27033 .6437 L .2553 .64628 L F
.25543 .6422 m .25537 .64642 L .25579 .64291 L .986 .729 .348 r
F
.25537 .64642 m .25527 .6544 L .25561 .64688 L F
.25537 .64642 m .25561 .64688 L .25579 .64291 L F
.33373 .88833 m .33348 .88613 L .33564 .88427 L .391 .239 .552 r
F
.33095 .88982 m .33348 .88613 L .33373 .88833 L .514 .326 .564 r
F
0 g
.3307 .88762 m
.33348 .88613 L
s
.33121 .89201 m .33095 .88982 L .33373 .88833 L .514 .326 .564 r
F
.328 .89303 m .33095 .88982 L .33121 .89201 L .6 .387 .565 r
F
.32884 .8875 m .33095 .88982 L .33373 .88833 L .692 .759 .903 r
F
.3267 .88818 m .33095 .88982 L .32884 .8875 L F
0 g
.32774 .89083 m
.33095 .88982 L
s
.33041 .88429 m .33343 .8861 L .33558 .88425 L .692 .759 .903 r
F
.127 .923 .03 r
.33555 .80025 m
.33656 .85002 L
s
.33377 .80075 m
.33416 .85099 L
s
.32857 .88528 m .33343 .8861 L .33041 .88429 L .692 .759 .903 r
F
0 g
.73692 .8037 m
.74674 .80349 L
s
.42122 .42687 m .45381 .42334 L .42249 .4217 L .654 .726 .902 r
F
.20896 .55111 m .18752 .54388 L .17961 .55505 L .673 .757 .914 r
F
0 g
.74674 .80349 m
.75647 .80485 L
s
.21106 .67371 m .2221 .6739 L .22257 .67848 L .859 .591 .532 r
F
.21106 .67371 m .21059 .66914 L .2221 .6739 L F
.22423 .66043 m .2221 .6739 L .2319 .66362 L .683 .77 .917 r
F
.22423 .66043 m .21059 .66914 L .2221 .6739 L F
0 g
.2221 .6739 m
.22616 .67471 L
s
.72191 .45374 m .72579 .42983 L .70919 .4466 L .654 .726 .902 r
F
.72191 .45374 m .74489 .44054 L .72579 .42983 L F
.18748 .54946 m .17925 .555 L .17953 .56068 L .157 .062 .489 r
F
.18748 .54946 m .1872 .54377 L .17925 .555 L F
0 g
.17625 .56693 m
.17925 .555 L
s
.29055 .6649 m .29007 .66033 L .29934 .65283 L .401 .257 .568 r
F
0 g
.28326 .66376 m
.29007 .66033 L
s
.73858 .88872 m .74145 .88719 L .74172 .88939 L .793 .527 .535 r
F
.73858 .88872 m .73831 .88652 L .74145 .88719 L F
0 g
.74145 .88719 m
.74484 .88729 L
s
.74065 .88394 m .74146 .88715 L .74273 .88439 L .692 .759 .904 r
F
.74065 .88394 m .73835 .88648 L .74146 .88715 L F
.25884 .55073 m .25296 .53507 L .25237 .55032 L .673 .757 .914 r
F
.25884 .55073 m .2659 .53588 L .25296 .53507 L F
.45314 .67827 m .45032 .68257 L .4508 .68714 L 0 0 .386 r
F
0 g
.45099 .68644 m
.45111 .68712 L
s
.47071 .67565 m .45265 .67369 L .45032 .68257 L .683 .77 .917 r
F
.45314 .67827 m .45265 .67369 L .45032 .68257 L 0 0 .386 r
F
.27694 .65296 m .28988 .66022 L .2991 .65275 L .683 .77 .917 r
F
.26903 .65695 m .28988 .66022 L .27694 .65296 L F
.52283 .66852 m .53362 .65768 L .51996 .66634 L F
.52283 .66852 m .53934 .66203 L .53362 .65768 L F
.32582 .5637 m .31843 .54708 L .31873 .55276 L .987 .712 .386 r
F
0 g
.32582 .5637 m
.3279 .57554 L
s
.127 .923 .03 r
.32139 .53744 m
.32319 .74002 L
s
.32467 .89069 m .32457 .8935 L .328 .89303 L .692 .759 .903 r
F
.127 .923 .03 r
.32321 .7422 m
.32323 .74438 L
s
.32424 .91123 m
.33133 1.23822 L
s
.32386 .89348 m
.32424 .91123 L
s
.3224 .89063 m .32457 .8935 L .32467 .89069 L .692 .759 .903 r
F
.3224 .89063 m .32117 .8934 L .32457 .8935 L F
.75175 .888 m .75148 .8858 L .75428 .88431 L .516 .328 .565 r
F
.74853 .88902 m .75148 .8858 L .75175 .888 L .6 .388 .565 r
F
0 g
.74826 .88682 m
.75148 .8858 L
s
.48926 .68219 m .46964 .68614 L .48847 .68514 L .683 .77 .917 r
F
.74939 .88346 m .75145 .88577 L .75423 .88429 L .692 .759 .904 r
F
.52867 .56318 m .50888 .55629 L .5092 .56197 L .733 .496 .569 r
F
0 g
.48925 .55821 m
.50888 .55629 L
s
.50888 .55629 m
.52835 .5575 L
s
.127 .923 .03 r
.525 .55892 m
.52517 .54815 L
s
.32695 .89038 m .328 .89303 L .33121 .89201 L .692 .759 .903 r
F
.32467 .89069 m .328 .89303 L .32695 .89038 L F
0 g
.32457 .8935 m
.328 .89303 L
s
.52194 .41478 m .54151 .41822 L .54109 .4255 L .858 .601 .549 r
F
.52194 .41478 m .52236 .4075 L .54151 .41822 L F
0 g
.54151 .41822 m
.54663 .41987 L
s
.20932 .5624 m .17982 .56636 L .20401 .56988 L .673 .757 .914 r
F
.31534 .89154 m .31777 .89054 L .31802 .89273 L .86 .578 .508 r
F
.31534 .89154 m .31509 .88934 L .31777 .89054 L F
.31826 .88719 m .31777 .89054 L .32005 .88798 L .692 .759 .903 r
F
.31826 .88719 m .31509 .88934 L .31777 .89054 L F
0 g
.31777 .89054 m
.32092 .89121 L
s
.127 .923 .03 r
.30331 .83429 m
.30352 .83672 L
s
0 g
.59632 .44313 m
.5968 .44312 L
s
.57219 .42086 m .58753 .44342 L .58844 .4231 L .654 .726 .902 r
F
.57219 .42086 m .56318 .44006 L .58753 .44342 L F
0 g
.58753 .44342 m
.59632 .44313 L
s
.24586 .55096 m .23994 .53635 L .22772 .53962 L .673 .757 .914 r
F
.25237 .55032 m .23994 .53635 L .24586 .55096 L F
.54547 .39415 m .54176 .41796 L .55818 .40126 L .654 .726 .902 r
F
.54547 .39415 m .52271 .4073 L .54176 .41796 L F
.52899 .56886 m .52867 .56318 L .5092 .56197 L .733 .496 .569 r
F
0 g
.52867 .56318 m
.54667 .56743 L
s
.74538 .89169 m .74511 .88949 L .74853 .88902 L .669 .437 .561 r
F
.74199 .89159 m .74511 .88949 L .74538 .89169 L .731 .482 .551 r
F
.74199 .89159 m .74172 .88939 L .74511 .88949 L F
.74525 .88668 m .74511 .88949 L .74853 .88902 L .692 .759 .904 r
F
.74299 .88661 m .74511 .88949 L .74525 .88668 L F
.74299 .88661 m .74172 .88939 L .74511 .88949 L F
.3203 .89018 m .32117 .8934 L .3224 .89063 L .692 .759 .903 r
F
.3203 .89018 m .31802 .89273 L .32117 .8934 L F
0 g
.32117 .8934 m
.32457 .8935 L
s
.127 .923 .03 r
.31685 .79785 m
.31688 .80001 L
s
.25246 .87164 m
.2525 .87377 L
s
.38778 .54551 m .38748 .53983 L .4071 .53791 L .672 .449 .574 r
F
.36829 .5443 m .38748 .53983 L .38778 .54551 L .733 .496 .569 r
F
.127 .923 .03 r
.38025 .48625 m
.38036 .54149 L
s
.38025 .48625 m
.38103 .54133 L
s
.36829 .5443 m .36799 .53862 L .38748 .53983 L .733 .496 .569 r
F
.31305 .88771 m .31483 .88715 L .31509 .88934 L .933 .634 .451 r
F
.31305 .88771 m .3128 .88551 L .31483 .88715 L F
0 g
.31483 .88715 m
.31694 .88808 L
s
.7488 .89121 m .74853 .88902 L .75175 .888 L .6 .388 .565 r
F
.74538 .89169 m .74853 .88902 L .7488 .89121 L .669 .437 .561 r
F
.74753 .88636 m .74853 .88902 L .75175 .888 L .692 .759 .904 r
F
.74525 .88668 m .74853 .88902 L .74753 .88636 L F
0 g
.74511 .88949 m
.74853 .88902 L
s
.31669 .88389 m .31488 .88712 L .31804 .88497 L .692 .759 .903 r
F
.31669 .88389 m .31286 .88549 L .31488 .88712 L F
.25237 .55032 m .25296 .53507 L .23994 .53635 L .673 .757 .914 r
F
.33373 .88833 m .33564 .88427 L .33589 .88647 L .391 .239 .552 r
F
.33398 .89053 m .33373 .88833 L .33589 .88647 L F
.33121 .89201 m .33373 .88833 L .33398 .89053 L .514 .326 .564 r
F
.33069 .88651 m .33373 .88833 L .33589 .88647 L .692 .759 .903 r
F
.127 .923 .03 r
.33416 .85099 m
.33417 .85313 L
s
.32884 .8875 m .33373 .88833 L .33069 .88651 L .692 .759 .903 r
F
0 g
.33095 .88982 m
.33373 .88833 L
s
.32909 .8897 m .33121 .89201 L .33398 .89053 L .692 .759 .903 r
F
.32695 .89038 m .33121 .89201 L .32909 .8897 L F
0 g
.328 .89303 m
.33121 .89201 L
s
.38815 .52434 m .38749 .5396 L .40702 .53769 L .673 .757 .914 r
F
.37522 .52354 m .38749 .5396 L .38815 .52434 L F
.37522 .52354 m .3681 .53839 L .38749 .5396 L F
.73592 .88753 m .73831 .88652 L .73858 .88872 L .861 .577 .505 r
F
.73592 .88753 m .73565 .88533 L .73831 .88652 L F
0 g
.73831 .88652 m
.74145 .88719 L
s
.73889 .88315 m .73835 .88648 L .74065 .88394 L .692 .759 .904 r
F
.73889 .88315 m .7357 .8853 L .73835 .88648 L F
.26518 .55775 m .26626 .54141 L .25917 .55633 L .673 .757 .914 r
F
.26518 .55775 m .2783 .54425 L .26626 .54141 L F
.2706 .56577 m .2786 .54994 L .26548 .56343 L F
.2706 .56577 m .28884 .55462 L .2786 .54994 L F
.72416 .55193 m .75151 .54351 L .72633 .54397 L F
.70007 .54841 m .72416 .55193 L .72633 .54397 L F
.69735 .55215 m .72416 .55193 L .70007 .54841 L F
.127 .923 .03 r
.58831 .44433 m
.58834 .44286 L
s
.47325 5.56523 m
.48976 4.83026 L
s
.46174 6.07741 m
.47325 5.56523 L
s
.40002 8.82437 m
.46174 6.07741 L
s
.73885 .89092 m .74172 .88939 L .74199 .89159 L .793 .527 .535 r
F
.73885 .89092 m .73858 .88872 L .74172 .88939 L F
.7409 .88616 m .74172 .88939 L .74299 .88661 L .692 .759 .904 r
F
.7409 .88616 m .73858 .88872 L .74172 .88939 L F
0 g
.74172 .88939 m
.74511 .88949 L
s
.49078 .67479 m .47071 .67565 L .48877 .67761 L .683 .77 .917 r
F
.25474 .44566 m .23069 .43917 L .23022 .44646 L .667 .431 .554 r
F
0 g
.20726 .45135 m
.23022 .44646 L
s
.25474 .44566 m .2552 .43838 L .23069 .43917 L .667 .431 .554 r
F
0 g
.20773 .44407 m
.23069 .43917 L
s
.4712 .68023 m .4508 .68714 L .46964 .68614 L .683 .77 .917 r
F
.48926 .68219 m .4712 .68023 L .46964 .68614 L F
0 g
.59569 .44539 m
.59672 .44461 L
s
.127 .923 .03 r
.28339 .66639 m
.28342 .66829 L
s
.60072 .55194 m .60235 .55811 L .60268 .56379 L .823 .62 .068 r
F
.60072 .55194 m .6004 .54626 L .60235 .55811 L F
.62559 .5458 m .60235 .55811 L .62688 .5537 L .673 .757 .914 r
F
.62559 .5458 m .6004 .54626 L .60235 .55811 L F
0 g
.60235 .55811 m
.60564 .56326 L
s
.33589 .88647 m .33564 .88427 L .33703 .88216 L .185 .095 .513 r
F
0 g
.33348 .88613 m
.33564 .88427 L
s
.33184 .88306 m .33558 .88425 L .33696 .88216 L .692 .759 .903 r
F
.33041 .88429 m .33558 .88425 L .33184 .88306 L F
.27911 .44902 m .27957 .44173 L .2552 .43838 L .732 .487 .558 r
F
0 g
.27957 .44173 m
.29865 .44788 L
s
.75455 .88651 m .75428 .88431 L .75646 .88245 L .396 .244 .555 r
F
.75175 .888 m .75428 .88431 L .75455 .88651 L .516 .328 .565 r
F
0 g
.75148 .8858 m
.75428 .88431 L
s
.75202 .8902 m .75175 .888 L .75455 .88651 L .516 .328 .565 r
F
.7488 .89121 m .75175 .888 L .75202 .8902 L .6 .388 .565 r
F
.74968 .88569 m .75175 .888 L .75455 .88651 L .692 .759 .904 r
F
.74753 .88636 m .75175 .888 L .74968 .88569 L F
0 g
.74853 .88902 m
.75175 .888 L
s
.75124 .88248 m .75423 .88429 L .7564 .88243 L .692 .759 .904 r
F
.74939 .88346 m .75423 .88429 L .75124 .88248 L F
.52564 .68026 m .5405 .67112 L .5239 .67763 L .683 .77 .917 r
F
.127 .923 .03 r
.58493 .59487 m
.58502 .59051 L
s
.52564 .68026 m .54398 .67637 L .5405 .67112 L .683 .77 .917 r
F
.54349 .67179 m .5566 .66002 L .54 .66654 L F
.54349 .67179 m .56183 .6679 L .5566 .66002 L F
.56183 .6679 m .56133 .66333 L .5561 .65545 L .98 .689 .335 r
F
0 g
.56133 .66333 m
.5628 .672 L
s
.127 .923 .03 r
.48976 4.83026 m
.56876 1.31415 L
s
.49974 4.99985 m
.59449 1.34616 L
s
.40741 .54359 m .4071 .53791 L .42553 .53298 L .603 .396 .573 r
F
.38778 .54551 m .4071 .53791 L .40741 .54359 L .672 .449 .574 r
F
0 g
.38748 .53983 m
.4071 .53791 L
s
.31851 .88939 m .31802 .89273 L .3203 .89018 L .692 .759 .903 r
F
.31851 .88939 m .31534 .89154 L .31802 .89273 L F
0 g
.31802 .89273 m
.32117 .8934 L
s
.127 .923 .03 r
.30352 .83672 m
.30373 .83915 L
s
.75926 .45395 m .74528 .43326 L .74489 .44054 L .93 .67 .523 r
F
0 g
.75926 .45395 m
.76795 .46912 L
s
.50882 .75007 m .50748 .75511 L .51073 .75504 L .645 .732 .913 r
F
.50721 .6947 m .50871 .75008 L .50721 .7502 L .641 .402 .54 r
F
.50782 .74746 m .5077 .75016 L .50882 .75007 L .645 .732 .913 r
F
.5077 .75016 m .50748 .75511 L .50882 .75007 L F
.50748 .75511 m .50714 .76275 L .51365 .76261 L F
.5085 .75366 m .50723 .75892 L .5105 .75885 L F
.50721 .7502 m .50881 .75356 L .50723 .75376 L .641 .402 .54 r
F
.50757 .75124 m .50746 .75374 L .5085 .75366 L .645 .732 .913 r
F
.50746 .75374 m .50723 .75892 L .5085 .75366 L F
.50871 .75008 m .50881 .75356 L .50721 .7502 L .641 .402 .54 r
F
.51133 .74988 m .51379 .75445 L .51644 .75339 L .645 .732 .913 r
F
.50881 .75007 m .50983 .75312 L .50881 .75356 L .517 .303 .528 r
F
.5088 .6945 m .50977 .74974 L .50881 .75007 L F
.50782 .74746 m .51073 .75504 L .51379 .75445 L .645 .732 .913 r
F
.50977 .74974 m .50983 .75312 L .50881 .75007 L .517 .303 .528 r
F
.51054 .74923 m .51098 .75187 L .51054 .75255 L .076 0 .415 r
F
.51053 .69349 m .51095 .74865 L .51054 .74923 L F
.51067 .74942 m .51003 .74994 L .51133 .74988 L .645 .732 .913 r
F
.51003 .74994 m .51 .74998 L .51133 .74988 L F
.51095 .74865 m .51098 .75187 L .51054 .74923 L .076 0 .415 r
F
.51003 .74994 m .50997 .74998 L .51 .74998 L .645 .732 .913 r
F
.50782 .74746 m .50976 .74974 L .51067 .74942 L F
.50983 .74972 m .51054 .75255 L .50983 .75312 L .358 .18 .498 r
F
.50982 .69406 m .5105 .74925 L .50983 .74972 L F
.50983 .74972 m .50997 .74998 L .51067 .74942 L .645 .732 .913 r
F
.50978 .74975 m .50997 .74998 L .50983 .74972 L F
.5105 .74925 m .51054 .75255 L .50983 .74972 L .358 .18 .498 r
F
.50976 .74974 m .50978 .74975 L .50983 .74972 L .645 .732 .913 r
F
.50997 .74998 m .51379 .75445 L .51133 .74988 L F
.50721 .6947 m .5088 .6945 L .50881 .75007 L .641 .402 .54 r
F
.50871 .75008 m .50881 .75007 L .50881 .75356 L F
.50721 .6947 m .50881 .75007 L .50871 .75008 L F
.50652 .75006 m .50125 .75371 L .50424 .75466 L .645 .732 .913 r
F
.50769 .75029 m .50424 .75466 L .50748 .75511 L F
.50652 .75006 m .50424 .75466 L .50769 .75029 L F
.50125 .75371 m .50067 .76184 L .50424 .75466 L F
.5053 .75339 m .49841 .75615 L .50097 .75752 L F
.50564 .7499 m .50721 .75376 L .50564 .75346 L .751 .491 .539 r
F
.50464 .69397 m .50563 .69444 L .50564 .7499 L .845 .571 .524 r
F
.50558 .74987 m .50564 .7499 L .50564 .7535 L F
.50464 .69397 m .50564 .7499 L .50558 .74987 L F
.50539 .74978 m .49871 .75235 L .50125 .75371 L .645 .732 .913 r
F
.50563 .69444 m .50712 .75018 L .50564 .7499 L .751 .491 .539 r
F
.50782 .74746 m .50439 .7493 L .50539 .74978 L .645 .732 .913 r
F
.50439 .7493 m .49871 .75235 L .50539 .74978 L F
.50757 .75124 m .50401 .75315 L .5053 .75339 L F
.50401 .75315 m .49841 .75615 L .5053 .75339 L F
.50424 .75466 m .50067 .76184 L .50714 .76275 L F
.50406 .7583 m .50097 .75752 L .50398 .75847 L F
.50424 .75466 m .50714 .76275 L .50748 .75511 L F
.50757 .75124 m .50382 .75481 L .50406 .7583 L F
.50382 .75481 m .50097 .75752 L .50406 .7583 L F
.50355 .75093 m .50361 .75174 L .50361 .75177 L .783 .625 .063 r
F
.4968 .77291 m .50679 .7705 L .50654 .77427 L .733 .498 .572 r
F
.4968 .77291 m .49705 .76914 L .50679 .7705 L F
.50067 .76184 m .5068 .77038 L .50714 .76275 L .645 .732 .913 r
F
.50067 .76184 m .49711 .76903 L .5068 .77038 L F
.49655 .77668 m .50654 .77427 L .50629 .77804 L .733 .498 .572 r
F
.49655 .77668 m .4968 .77291 L .50654 .77427 L F
.50039 .76569 m .50654 .77427 L .50689 .7666 L .645 .732 .913 r
F
.50039 .76569 m .4968 .77291 L .50654 .77427 L F
.50014 .76946 m .50629 .77804 L .50664 .77037 L F
.50014 .76946 m .49655 .77668 L .50629 .77804 L F
.50398 .75847 m .50039 .76569 L .50689 .7666 L F
.50373 .76224 m .50014 .76946 L .50664 .77037 L F
.50404 .76161 m .50072 .76129 L .50373 .76224 L F
.50757 .75124 m .50398 .75847 L .50723 .75892 L F
.50465 .75303 m .50564 .7535 L .50564 .75702 L .845 .571 .524 r
F
.50535 .75688 m .50381 .75835 L .50619 .75728 L .645 .732 .913 r
F
.50571 .80988 m .50451 .81002 L .50555 .81024 L .692 .759 .903 r
F
.50555 .81024 m .50657 .81309 L .50669 .81027 L F
.50696 .81212 m .50581 .81245 L .50695 .81249 L .692 .759 .904 r
F
.50572 .80986 m .50564 .80986 L .50571 .80988 L .692 .759 .903 r
F
.50669 .81027 m .50657 .81309 L .50884 .81277 L F
.50714 .80999 m .50722 .81297 L .50564 .80986 L .751 .491 .539 r
F
.50706 .80966 m .506 .81203 L .50696 .81212 L .692 .759 .904 r
F
.506 .81203 m .50581 .81245 L .50696 .81212 L F
.50555 .81024 m .50431 .81302 L .50657 .81309 L .692 .759 .903 r
F
.50431 .81302 m .50645 .8159 L .50657 .81309 L F
.50581 .81245 m .50683 .81531 L .50695 .81249 L .692 .759 .904 r
F
.50564 .812 m .50722 .81297 L .50564 .81271 L .751 .491 .539 r
F
.50564 .80986 m .50678 .8121 L .50564 .812 L F
.50678 .8121 m .50722 .81297 L .50564 .812 L F
.50373 .76224 m .50664 .77037 L .50698 .76269 L .645 .732 .913 r
F
.50097 .75752 m .50039 .76569 L .50398 .75847 L F
.50399 .75243 m .50465 .75303 L .50465 .75655 L .929 .648 .488 r
F
.50403 .75602 m .50465 .75655 L .50465 .81224 L F
.50399 .75243 m .50465 .75655 L .50403 .75602 L F
.50361 .75174 m .50399 .75243 L .50399 .75598 L .989 .72 .386 r
F
.50363 .75537 m .50399 .75598 L .50399 .81164 L F
.50361 .75174 m .50399 .75598 L .50363 .75537 L F
.50481 .7574 m .49816 .75992 L .50072 .76129 L .645 .732 .913 r
F
.5052 .75703 m .50471 .75723 L .50481 .7574 L F
.50471 .75723 m .49816 .75992 L .50481 .7574 L F
.50528 .75695 m .50517 .757 L .5052 .75703 L F
.50354 .8082 m .50242 .8077 L .50254 .80842 L .692 .759 .903 r
F
.50469 .7572 m .49816 .75992 L .50471 .75723 L .645 .732 .913 r
F
.50427 .80918 m .50295 .80907 L .50362 .80962 L .692 .759 .903 r
F
.50411 .75673 m .49816 .75992 L .50517 .757 L .645 .732 .913 r
F
.50491 .80957 m .50451 .81002 L .50571 .80988 L .692 .759 .903 r
F
.50398 .75847 m .50689 .7666 L .50723 .75892 L .645 .732 .913 r
F
.50619 .75728 m .50381 .75835 L .50404 .76161 L F
.50451 .81002 m .50431 .81302 L .50555 .81024 L .692 .759 .903 r
F
.50491 .80957 m .50362 .80962 L .50451 .81002 L F
.50465 .75655 m .50559 .80984 L .50465 .80947 L .845 .571 .524 r
F
.5068 .80746 m .50413 .80927 L .50491 .80957 L .692 .759 .903 r
F
.50413 .80927 m .50362 .80962 L .50491 .80957 L F
.50435 .8115 m .50387 .81183 L .50514 .81181 L .692 .759 .904 r
F
.50451 .81002 m .50222 .81257 L .50431 .81302 L .692 .759 .903 r
F
.50399 .8111 m .50465 .81224 L .50399 .81164 L .929 .648 .488 r
F
.50399 .80895 m .5045 .8115 L .50399 .8111 L F
.50504 .81192 m .50387 .81183 L .50476 .81223 L .692 .759 .904 r
F
.5045 .8115 m .50465 .81224 L .50399 .8111 L .929 .648 .488 r
F
.50514 .81181 m .5049 .81181 L .50504 .81192 L .692 .759 .904 r
F
.5049 .81181 m .50387 .81183 L .50504 .81192 L F
.50559 .80984 m .50563 .812 L .50465 .80947 L .845 .571 .524 r
F
.50706 .80966 m .50476 .81223 L .50581 .81245 L .692 .759 .904 r
F
.50563 .812 m .50564 .81271 L .5054 .8119 L .845 .571 .524 r
F
.50563 .812 m .5054 .8119 L .50465 .80947 L F
.50435 .8115 m .50319 .81128 L .50387 .81183 L .692 .759 .904 r
F
.50465 .80947 m .5054 .8119 L .50465 .81162 L .845 .571 .524 r
F
.50706 .80966 m .50347 .81116 L .50435 .8115 L .692 .759 .904 r
F
.50347 .81116 m .50319 .81128 L .50435 .8115 L F
.5056 .80984 m .50564 .80986 L .50564 .81271 L .845 .571 .524 r
F
.50706 .80966 m .50435 .8115 L .50514 .81181 L .692 .759 .904 r
F
.50465 .81162 m .50564 .81271 L .50465 .81224 L .845 .571 .524 r
F
.5054 .8119 m .50564 .81271 L .50465 .81162 L F
.50465 .75303 m .50471 .75658 L .50465 .75655 L F
.50471 .75658 m .50564 .81271 L .50465 .75655 L F
.50125 .75371 m .4947 .75996 L .50067 .76184 L .645 .732 .913 r
F
.49841 .75615 m .49438 .7638 L .50097 .75752 L F
.50465 .75303 m .50564 .75702 L .50471 .75658 L .845 .571 .524 r
F
.48961 .75723 m .48814 .76621 L .4947 .75996 L .645 .732 .913 r
F
.49841 .75615 m .48927 .76105 L .49438 .7638 L F
.50246 .75641 m .49505 .75629 L .49623 .75821 L F
.50355 .75102 m .50356 .75463 L .50356 .75459 L .783 .625 .063 r
F
.49871 .75235 m .4947 .75996 L .50125 .75371 L .645 .732 .913 r
F
.50371 .7533 m .49648 .75444 L .49841 .75615 L F
.50712 .75018 m .50721 .7502 L .50721 .75376 L .751 .491 .539 r
F
.50465 .75299 m .50564 .7535 L .50465 .75303 L .845 .571 .524 r
F
.5036 .69268 m .50398 .69337 L .50399 .74886 L .989 .72 .386 r
F
.50396 .74882 m .50399 .74886 L .50399 .75243 L F
.5036 .69268 m .50399 .74886 L .50396 .74882 L F
.50428 .74936 m .49679 .75065 L .49871 .75235 L .645 .732 .913 r
F
.50439 .7493 m .50426 .74932 L .50428 .74936 L F
.50426 .74932 m .49679 .75065 L .50428 .74936 L F
.50464 .69397 m .50558 .74987 L .50465 .74942 L .845 .571 .524 r
F
.50782 .74746 m .50328 .74877 L .50439 .7493 L .645 .732 .913 r
F
.50361 .74821 m .50399 .75243 L .50361 .75174 L .989 .72 .386 r
F
.5036 .69268 m .50396 .74882 L .50361 .74821 L F
.50328 .74877 m .50426 .74932 L .50419 .7492 L .645 .732 .913 r
F
.50396 .74882 m .50399 .75243 L .50361 .74821 L .989 .72 .386 r
F
.50328 .74877 m .49679 .75065 L .50426 .74932 L .645 .732 .913 r
F
.50419 .7492 m .50426 .74932 L .50439 .7493 L F
.50465 .74942 m .50564 .75346 L .50465 .75299 L .845 .571 .524 r
F
.50533 .74984 m .50523 .74992 L .50652 .75006 L .645 .732 .913 r
F
.50523 .74992 m .50125 .75371 L .5059 .7505 L F
.50523 .74992 m .5059 .7505 L .50652 .75006 L F
.49679 .75065 m .48961 .75723 L .49871 .75235 L F
.50314 .7517 m .49496 .7505 L .4953 .75251 L F
.50399 .74886 m .50464 .75298 L .50399 .75242 L .929 .648 .488 r
F
.50355 .75093 m .50361 .75177 L .50356 .75102 L .783 .625 .063 r
F
.50712 .75018 m .50721 .75376 L .50564 .7499 L .751 .491 .539 r
F
.50757 .75124 m .50224 .75092 L .50314 .7517 L .645 .732 .913 r
F
.50224 .75092 m .49496 .7505 L .50314 .7517 L F
.50757 .75124 m .50366 .75251 L .50447 .7529 L F
.50399 .75242 m .50465 .75303 L .50399 .75243 L .929 .648 .488 r
F
.50464 .75298 m .50465 .75303 L .50399 .75242 L F
.50398 .69337 m .50461 .74939 L .50399 .74886 L F
.50461 .74939 m .50465 .75303 L .50399 .74886 L F
.50558 .74987 m .50564 .75346 L .50465 .74942 L .845 .571 .524 r
F
.50564 .75346 m .50564 .7535 L .50465 .75299 L F
.50757 .75124 m .50365 .75237 L .50366 .75251 L .645 .732 .913 r
F
.50447 .7529 m .50366 .75251 L .50371 .7533 L F
.50365 .75237 m .49648 .75444 L .50371 .7533 L F
.50356 .75102 m .50361 .75177 L .50361 .75533 L .783 .625 .063 r
F
.50356 .75102 m .50361 .75533 L .50356 .75463 L F
.49871 .75235 m .48961 .75723 L .4947 .75996 L .645 .732 .913 r
F
.50259 .75267 m .4953 .75251 L .49648 .75444 L F
.50757 .75124 m .50316 .75169 L .50259 .75267 L F
.50316 .75169 m .4953 .75251 L .50259 .75267 L F
.50409 .7499 m .50355 .75093 L .50355 .75102 L 0 0 .377 r
F
.50406 .75016 m .50355 .75102 L .50356 .75459 L F
.50409 .7499 m .50355 .75102 L .50406 .75016 L F
.50356 .75459 m .50361 .81095 L .50356 .81014 L .783 .625 .063 r
F
.50356 .75463 m .50361 .81095 L .50356 .75459 L F
.50454 .7565 m .5037 .75667 L .50372 .75694 L .645 .732 .913 r
F
.50364 .75607 m .49623 .75821 L .50454 .7565 L F
.50399 .75243 m .50403 .75602 L .50399 .75598 L .929 .648 .488 r
F
.50361 .75533 m .50397 .80892 L .50361 .80832 L .989 .72 .386 r
F
.50363 .75537 m .50399 .81164 L .50361 .75533 L F
.50356 .75463 m .50361 .75533 L .50361 .81095 L .783 .625 .063 r
F
.49648 .75444 m .48927 .76105 L .49841 .75615 L .645 .732 .913 r
F
.50068 .7557 m .49471 .75427 L .49505 .75629 L F
.50373 .80875 m .50295 .80907 L .50427 .80918 L .692 .759 .903 r
F
.50233 .75472 m .49523 .75231 L .49471 .75427 L .645 .732 .913 r
F
.50732 .75501 m .50333 .75412 L .50233 .75472 L F
.50333 .75412 m .49523 .75231 L .50233 .75472 L F
.50564 .7535 m .50573 .75704 L .50564 .75702 L .751 .491 .539 r
F
.50732 .75501 m .50364 .75607 L .50454 .7565 L .645 .732 .913 r
F
.5068 .80746 m .50373 .80875 L .50427 .80918 L .692 .759 .903 r
F
.50507 .75691 m .50517 .757 L .50528 .75695 L .645 .732 .913 r
F
.50399 .75598 m .50462 .80945 L .50399 .80895 L .929 .648 .488 r
F
.5068 .80746 m .50322 .80766 L .50354 .8082 L .692 .759 .903 r
F
.50564 .7535 m .50721 .75376 L .50721 .75732 L .751 .491 .539 r
F
.50361 .75174 m .50363 .75537 L .50361 .75533 L .989 .72 .386 r
F
.50188 .7538 m .49657 .75053 L .49523 .75231 L .645 .732 .913 r
F
.50732 .75501 m .50348 .75341 L .50188 .7538 L F
.50348 .75341 m .49657 .75053 L .50188 .7538 L F
.50563 .69444 m .50721 .6947 L .50721 .7502 L .751 .491 .539 r
F
.50563 .69444 m .50721 .7502 L .50712 .75018 L F
.50295 .74797 m .49528 .74673 L .49562 .74873 L .645 .732 .913 r
F
.50398 .69337 m .50464 .69397 L .50465 .74942 L .929 .648 .488 r
F
.50398 .69337 m .50465 .74942 L .50461 .74939 L F
.50364 .74867 m .49562 .74873 L .49679 .75065 L .645 .732 .913 r
F
.50782 .74746 m .50359 .7479 L .50364 .74867 L F
.50359 .7479 m .49562 .74873 L .50364 .74867 L F
.50355 .69187 m .5036 .69268 L .50361 .74821 L .783 .625 .063 r
F
.5036 .74816 m .50361 .74821 L .50361 .75174 L F
.50355 .69187 m .50361 .74821 L .5036 .74816 L F
.50521 .74587 m .50409 .7499 L .50521 .74912 L .401 .213 .507 r
F
.50521 .69006 m .50415 .74651 L .50521 .74587 L F
.50782 .74746 m .50302 .74718 L .50295 .74797 L .645 .732 .913 r
F
.50415 .74651 m .50409 .7499 L .50521 .74587 L .401 .213 .507 r
F
.50302 .74718 m .50196 .74712 L .50243 .74753 L .645 .732 .913 r
F
.50302 .74718 m .50243 .74753 L .50295 .74797 L F
.50196 .74712 m .49528 .74673 L .50295 .74797 L F
.50461 .74939 m .50465 .74942 L .50465 .75303 L .929 .648 .488 r
F
.50354 .74721 m .49579 .74477 L .49528 .74673 L .645 .732 .913 r
F
.50782 .74746 m .50349 .74649 L .50354 .74721 L F
.50349 .74649 m .49579 .74477 L .50354 .74721 L F
.50355 .74746 m .50361 .75174 L .50355 .75093 L .783 .625 .063 r
F
.50355 .69187 m .5036 .74816 L .50355 .74746 L F
.5036 .74816 m .50361 .75174 L .50355 .74746 L F
.50397 .74973 m .49889 .74528 L .49682 .74675 L .645 .732 .913 r
F
.50757 .75124 m .50502 .74948 L .50397 .74973 L F
.50502 .74948 m .49889 .74528 L .50397 .74973 L F
.50632 .74878 m .50521 .74912 L .50521 .74944 L .568 .343 .534 r
F
.50246 .75009 m .49682 .74675 L .49548 .74853 L .645 .732 .913 r
F
.50521 .74912 m .50409 .7499 L .50409 .75011 L .401 .213 .507 r
F
.50512 .74949 m .50409 .75011 L .50409 .75367 L F
.50521 .74912 m .50409 .75011 L .50512 .74949 L F
.50366 .75036 m .50397 .74973 L .50246 .75009 L .645 .732 .913 r
F
.50757 .75124 m .50441 .74992 L .50366 .75036 L F
.50409 .74654 m .50355 .75093 L .50409 .7499 L 0 0 .377 r
F
.50409 .69084 m .50359 .74741 L .50409 .74654 L F
.50359 .74741 m .50355 .75093 L .50409 .74654 L F
.50409 .69084 m .50355 .69187 L .50355 .74746 L F
.50359 .74741 m .50355 .74746 L .50355 .75093 L F
.50409 .69084 m .50355 .74746 L .50359 .74741 L F
.50439 .74603 m .49919 .74153 L .49712 .743 L .645 .732 .913 r
F
.50632 .74561 m .50521 .74912 L .50632 .74878 L .568 .343 .534 r
F
.50632 .68972 m .50527 .74586 L .50632 .74561 L F
.50782 .74746 m .50543 .74582 L .50445 .74606 L .645 .732 .913 r
F
.50782 .74746 m .50439 .74603 L .50404 .74662 L F
.50527 .74586 m .50521 .74912 L .50632 .74561 L .568 .343 .534 r
F
.50445 .74606 m .50477 .74537 L .50439 .74603 L .645 .732 .913 r
F
.50543 .74582 m .50477 .74537 L .50445 .74606 L F
.50477 .74537 m .49919 .74153 L .50439 .74603 L F
.50404 .74662 m .49712 .743 L .49579 .74477 L F
.50439 .74603 m .49712 .743 L .50404 .74662 L F
.50441 .74992 m .50397 .74973 L .50366 .75036 L F
.50397 .74973 m .49682 .74675 L .50246 .75009 L F
.50564 .75702 m .50714 .80999 L .50564 .80986 L .751 .491 .539 r
F
.50573 .75704 m .50714 .80999 L .50564 .75702 L F
.50564 .7535 m .50721 .75732 L .50573 .75704 L F
.50732 .75501 m .50535 .75688 L .50619 .75728 L .645 .732 .913 r
F
.50757 .75124 m .49938 .7494 L .49496 .7505 L F
.49938 .7494 m .49548 .74853 L .49521 .74954 L F
.49938 .7494 m .49521 .74954 L .49496 .7505 L F
.50782 .74746 m .50533 .74984 L .50652 .75006 L F
.50742 .74869 m .50632 .74878 L .50632 .74917 L .66 .417 .541 r
F
.50654 .77427 m .50679 .7705 L .51661 .77029 L .67 .443 .567 r
F
.50714 .76275 m .5068 .77038 L .51656 .77017 L .645 .732 .913 r
F
.50654 .77427 m .51661 .77029 L .51636 .77406 L .67 .443 .567 r
F
.50629 .77804 m .50654 .77427 L .51636 .77406 L F
.50689 .7666 m .50654 .77427 L .51636 .77406 L .645 .732 .913 r
F
.50629 .77804 m .51636 .77406 L .51611 .77783 L .67 .443 .567 r
F
.50664 .77037 m .50629 .77804 L .51611 .77783 L .645 .732 .913 r
F
.50664 .77037 m .51611 .77783 L .51318 .77023 L F
.50689 .7666 m .51636 .77406 L .51343 .76646 L F
.50698 .76269 m .50664 .77037 L .51318 .77023 L F
.50732 .75501 m .50373 .76224 L .50698 .76269 L F
.50573 .75704 m .50721 .75732 L .50722 .81297 L .751 .491 .539 r
F
.50721 .75376 m .50721 .75376 L .50564 .75346 L F
.50782 .74746 m .50652 .75006 L .50769 .75029 L .645 .732 .913 r
F
.50219 .75287 m .49864 .74905 L .49657 .75053 L F
.50732 .75501 m .50411 .75281 L .50219 .75287 L F
.50409 .7499 m .50356 .75459 L .50405 .75373 L 0 0 .377 r
F
.50411 .75281 m .49864 .74905 L .50219 .75287 L .645 .732 .913 r
F
.50757 .75124 m .50156 .74421 L .49889 .74528 L F
.50741 .74914 m .50632 .74917 L .50632 .75274 L .66 .417 .541 r
F
.50735 .7527 m .50632 .75274 L .50633 .80799 L F
.50741 .74914 m .50632 .75274 L .50735 .7527 L F
.50742 .74869 m .50632 .74917 L .50741 .74914 L F
.50409 .7499 m .50405 .75373 L .50409 .75367 L 0 0 .377 r
F
.5046 .75315 m .50131 .74799 L .49864 .74905 L .645 .732 .913 r
F
.50732 .75501 m .50553 .75292 L .5046 .75315 L F
.50553 .75292 m .50131 .74799 L .5046 .75315 L F
.50732 .75501 m .50411 .75673 L .50528 .75695 L F
.50411 .75673 m .50517 .757 L .50507 .75691 L F
.50517 .757 m .50469 .7572 L .5052 .75703 L F
.50469 .7572 m .50471 .75723 L .5052 .75703 L F
.50471 .75658 m .50564 .75702 L .50564 .80986 L .845 .571 .524 r
F
.50471 .75658 m .50564 .80986 L .5056 .80984 L F
.50564 .75346 m .50721 .75376 L .50564 .7535 L .751 .491 .539 r
F
.50625 .75275 m .50521 .753 L .50522 .80833 L .568 .343 .534 r
F
.50522 .80571 m .50578 .80481 L .50471 .80514 L .692 .759 .903 r
F
.5068 .80746 m .50602 .80542 L .50522 .80571 L F
.50632 .75274 m .50527 .80569 L .50633 .80531 L .568 .343 .534 r
F
.50602 .80542 m .50578 .80481 L .50522 .80571 L .692 .759 .903 r
F
.50337 .80706 m .50307 .80626 L .5026 .80696 L F
.5068 .80746 m .50403 .80657 L .50337 .80706 L F
.50403 .80657 m .50307 .80626 L .50337 .80706 L F
.5068 .80746 m .50471 .80514 L .50379 .80564 L F
.50351 .80764 m .5026 .80696 L .50242 .8077 L F
.5068 .80746 m .50379 .8071 L .50351 .80764 L F
.50379 .8071 m .5026 .80696 L .50351 .80764 L F
.5068 .80746 m .50254 .80842 L .50295 .80907 L F
.50409 .80653 m .50365 .80951 L .50409 .80867 L 0 0 .377 r
F
.50358 .8075 m .50356 .81014 L .50409 .80653 L F
.50408 .8087 m .50403 .80783 L .50331 .80846 L .692 .759 .904 r
F
.5068 .80746 m .50491 .80957 L .50564 .80986 L .692 .759 .903 r
F
.5068 .80746 m .50564 .80986 L .50572 .80986 L F
.5068 .80746 m .50555 .81024 L .50669 .81027 L F
.50706 .80966 m .50441 .80806 L .50408 .8087 L .692 .759 .904 r
F
.5068 .80746 m .50379 .80564 L .50307 .80626 L .692 .759 .903 r
F
.50414 .80649 m .5041 .80867 L .50522 .8057 L .401 .213 .507 r
F
.50706 .80966 m .50331 .80846 L .50284 .80916 L .692 .759 .904 r
F
.5041 .80867 m .50409 .80911 L .50428 .80853 L .401 .213 .507 r
F
.5041 .80867 m .50428 .80853 L .50522 .8057 L F
.50441 .80806 m .50403 .80783 L .50408 .80869 L .692 .759 .904 r
F
.50409 .80867 m .50408 .80869 L .50408 .8087 L F
.50441 .80806 m .50408 .80869 L .50409 .80867 L F
.50397 .80892 m .50399 .81164 L .50361 .80832 L .989 .72 .386 r
F
.50462 .80945 m .50465 .81224 L .50399 .80895 L .929 .648 .488 r
F
.50706 .80966 m .50284 .80916 L .50266 .8099 L .692 .759 .904 r
F
.50409 .80867 m .50356 .81014 L .50409 .80911 L 0 0 .377 r
F
.50365 .80951 m .50356 .81014 L .50409 .80867 L F
.50409 .75367 m .50358 .8075 L .50409 .80653 L F
.50522 .8057 m .50428 .80853 L .50522 .80785 L .401 .213 .507 r
F
.5047 .80823 m .50496 .80733 L .50403 .80783 L .692 .759 .904 r
F
.50706 .80966 m .50535 .80776 L .5047 .80823 L F
.50535 .80776 m .50496 .80733 L .5047 .80823 L F
.50522 .80785 m .50409 .80911 L .50522 .80833 L .401 .213 .507 r
F
.50428 .80853 m .50409 .80911 L .50522 .80785 L F
.50521 .753 m .50414 .80649 L .50522 .8057 L F
.50527 .80569 m .50522 .80833 L .50633 .80531 L .568 .343 .534 r
F
.50538 .80779 m .50604 .80699 L .50496 .80733 L .692 .759 .904 r
F
.50706 .80966 m .50623 .80749 L .50538 .80779 L F
.50633 .80531 m .50542 .80778 L .50633 .80745 L .568 .343 .534 r
F
.50623 .80749 m .50604 .80699 L .50538 .80779 L .692 .759 .904 r
F
.50633 .80745 m .50522 .80833 L .50633 .80799 L .568 .343 .534 r
F
.50542 .80778 m .50522 .80833 L .50633 .80745 L F
.50632 .74917 m .50626 .75275 L .50632 .75274 L F
.50626 .75275 m .50522 .80833 L .50632 .75274 L F
.50632 .74878 m .50631 .74917 L .50632 .74917 L F
.50631 .74917 m .50522 .80833 L .50632 .74917 L F
.50621 .7492 m .50521 .74944 L .50521 .753 L F
.50632 .74878 m .50521 .74944 L .50621 .7492 L F
.50632 .74878 m .50521 .753 L .50625 .75275 L F
.50521 .74912 m .50514 .75304 L .50521 .753 L .401 .213 .507 r
F
.50514 .75304 m .50409 .80911 L .50521 .753 L F
.50405 .75373 m .50356 .81014 L .50409 .75367 L 0 0 .377 r
F
.50305 .75545 m .50233 .75472 L .50068 .7557 L .645 .732 .913 r
F
.50732 .75501 m .50344 .75478 L .50305 .75545 L F
.50344 .75478 m .50233 .75472 L .50305 .75545 L F
.50233 .75472 m .49471 .75427 L .50068 .7557 L F
.50732 .75501 m .50305 .75545 L .5025 .7564 L F
.50403 .75602 m .50465 .81224 L .50399 .75598 L .929 .648 .488 r
F
.50514 .75304 m .50409 .75367 L .50409 .80911 L .401 .213 .507 r
F
.50521 .74912 m .50409 .75367 L .50514 .75304 L F
.50405 .75373 m .50356 .75459 L .50356 .81014 L 0 0 .377 r
F
.5025 .7564 m .49942 .75583 L .50246 .75641 L .645 .732 .913 r
F
.50305 .75545 m .49942 .75583 L .5025 .7564 L F
.49942 .75583 m .49505 .75629 L .50246 .75641 L F
.50372 .75694 m .49623 .75821 L .49816 .75992 L F
.5037 .75667 m .49623 .75821 L .50372 .75694 L F
.50322 .80766 m .50242 .8077 L .50354 .8082 L .692 .759 .903 r
F
.50362 .80962 m .50222 .81257 L .50451 .81002 L F
.50362 .80962 m .50044 .81178 L .50222 .81257 L F
.5036 .81044 m .50266 .8099 L .50278 .81062 L .692 .759 .904 r
F
.50361 .80832 m .50391 .81097 L .50361 .81046 L .989 .72 .386 r
F
.50706 .80966 m .50326 .80987 L .5036 .81044 L .692 .759 .904 r
F
.50326 .80987 m .50266 .8099 L .5036 .81044 L F
.50706 .80966 m .50278 .81062 L .50319 .81128 L F
.50361 .81046 m .50399 .81164 L .50361 .81095 L .989 .72 .386 r
F
.50391 .81097 m .50399 .81164 L .50361 .81046 L F
.50381 .75835 m .50072 .76129 L .50404 .76161 L .645 .732 .913 r
F
.127 .923 .03 r
.47772 3.65771 m
.50108 2.12673 L
s
0 g
.5072 .68965 m
.50721 .6947 L
s
.127 .923 .03 r
.49875 6.36251 m
.5021 3.59477 L
s
.32452 .88568 m .32442 .8885 L .3267 .88818 L .692 .759 .903 r
F
0 g
.32479 .88617 m
.32479 .88534 L
s
.32339 .88565 m .32215 .88843 L .32442 .8885 L .692 .759 .903 r
F
.32566 .88553 m .3267 .88818 L .32884 .8875 L F
.49037 .67023 m .47441 .66547 L .4704 .67109 L .683 .77 .917 r
F
.49346 .66775 m .47441 .66547 L .49037 .67023 L F
.74552 .88888 m .74538 .89169 L .7488 .89121 L .692 .759 .904 r
F
.74326 .88881 m .74538 .89169 L .74552 .88888 L F
.74326 .88881 m .74199 .89159 L .74538 .89169 L F
.65057 .53966 m .6268 .54798 L .65121 .54359 L .673 .757 .914 r
F
.65057 .53966 m .62551 .54011 L .6268 .54798 L F
.40118 .52307 m .40702 .53769 L .42535 .53279 L F
.38815 .52434 m .40702 .53769 L .40118 .52307 L F
.69491 .42737 m .67972 .40491 L .67876 .42515 L .654 .726 .902 r
F
.69491 .42737 m .70396 .40826 L .67972 .40491 L F
.51168 .74907 m .51644 .75339 L .51851 .75192 L .645 .732 .913 r
F
.50782 .74746 m .51067 .74942 L .51168 .74907 L F
.51067 .74942 m .51644 .75339 L .51168 .74907 L F
.5088 .6945 m .50982 .69406 L .50983 .74972 L .517 .303 .528 r
F
.50977 .74974 m .50983 .74972 L .50983 .75312 L F
.5088 .6945 m .50983 .74972 L .50977 .74974 L F
.3133 .88991 m .31509 .88934 L .31534 .89154 L .933 .634 .451 r
F
.3133 .88991 m .31305 .88771 L .31509 .88934 L F
.31691 .8861 m .31509 .88934 L .31826 .88719 L .692 .759 .903 r
F
.31691 .8861 m .31305 .88771 L .31509 .88934 L F
0 g
.31509 .88934 m
.3172 .89028 L
s
.7478 .88856 m .7488 .89121 L .75202 .8902 L .692 .759 .904 r
F
.74552 .88888 m .7488 .89121 L .7478 .88856 L F
0 g
.74538 .89169 m
.7488 .89121 L
s
.23999 .55821 m .22789 .54517 L .21727 .55023 L .673 .757 .914 r
F
.24613 .55657 m .22789 .54517 L .23999 .55821 L F
.2247 .66501 m .22257 .67848 L .23237 .66819 L .683 .77 .917 r
F
.2247 .66501 m .21106 .67371 L .22257 .67848 L F
0 g
.22257 .67848 m
.23607 .68114 L
s
.32234 .88543 m .32215 .88843 L .32339 .88565 L .692 .759 .903 r
F
.32234 .88543 m .32005 .88798 L .32215 .88843 L F
.50952 .56765 m .48957 .56389 L .48989 .56957 L .672 .449 .574 r
F
0 g
.47145 .57449 m
.48989 .56957 L
s
.50952 .56765 m .5092 .56197 L .48957 .56389 L .672 .449 .574 r
F
0 g
.47113 .56881 m
.48957 .56389 L
s
.2963 .55513 m .3068 .53777 L .28855 .54893 L .673 .757 .914 r
F
.2963 .55513 m .31843 .54708 L .3068 .53777 L F
.33398 .89053 m .33589 .88647 L .33614 .88867 L .391 .239 .552 r
F
.33095 .88871 m .33398 .89053 L .33614 .88867 L .692 .759 .903 r
F
.127 .923 .03 r
.33417 .85313 m
.33419 .85527 L
s
.32909 .8897 m .33398 .89053 L .33095 .88871 L .692 .759 .903 r
F
0 g
.33121 .89201 m
.33398 .89053 L
s
.29055 .6649 m .29934 .65283 L .29982 .6574 L .401 .257 .568 r
F
.29102 .66948 m .29055 .6649 L .29982 .6574 L F
.27754 .65761 m .29055 .6649 L .29982 .6574 L .683 .77 .917 r
F
.26959 .66162 m .29055 .6649 L .27754 .65761 L F
0 g
.28373 .66834 m
.29055 .6649 L
s
.73619 .88973 m .73858 .88872 L .73885 .89092 L .861 .577 .505 r
F
.73619 .88973 m .73592 .88753 L .73858 .88872 L F
.73912 .88537 m .73858 .88872 L .7409 .88616 L .692 .759 .904 r
F
.73912 .88537 m .73592 .88753 L .73858 .88872 L F
0 g
.73858 .88872 m
.74172 .88939 L
s
.70959 .43932 m .7037 .41526 L .6946 .43446 L .654 .726 .902 r
F
.70959 .43932 m .72619 .42254 L .7037 .41526 L F
0 g
.25558 .59547 m
.25569 .57571 L
s
.4712 .68023 m .45314 .67827 L .4508 .68714 L .683 .77 .917 r
F
0 g
.4508 .68714 m
.45232 .69581 L
s
.32673 .88519 m .32884 .8875 L .33069 .88651 L .692 .759 .903 r
F
0 g
.24903 .59535 m
.24914 .57582 L
s
.5118 .74835 m .51851 .75192 L .51984 .75015 L .645 .732 .913 r
F
.50782 .74746 m .51111 .74884 L .5118 .74835 L F
.51111 .74884 m .51851 .75192 L .5118 .74835 L F
.50982 .69406 m .51053 .69349 L .51054 .74923 L .358 .18 .498 r
F
.5105 .74925 m .51054 .74923 L .51054 .75255 L F
.50982 .69406 m .51054 .74923 L .5105 .74925 L F
.74117 .88836 m .74199 .89159 L .74326 .88881 L .692 .759 .904 r
F
.74117 .88836 m .73885 .89092 L .74199 .89159 L F
0 g
.74199 .89159 m
.74538 .89169 L
s
.5234 .67306 m .53425 .66217 L .52053 .67087 L .683 .77 .917 r
F
.5234 .67306 m .54 .66654 L .53425 .66217 L F
.23497 .56642 m .21756 .55591 L .20932 .5624 L .673 .757 .914 r
F
.24028 .56389 m .21756 .55591 L .23497 .56642 L F
.21716 .54465 m .18752 .54388 L .20896 .55111 L F
.127 .923 .03 r
.19428 .48364 m
.19572 .5441 L
s
.73391 .88589 m .73565 .88533 L .73592 .88753 L .935 .633 .445 r
F
.127 .923 .03 r
.64865 .8116 m
.66453 .93071 L
s
.66453 .93071 m
.73398 1.45167 L
s
.73391 .88589 m .73364 .8837 L .73565 .88533 L .935 .633 .445 r
F
0 g
.73565 .88533 m
.73777 .88628 L
s
.127 .923 .03 r
.59706 4.13035 m
.73034 .90647 L
s
.35878 .43298 m .32906 .44196 L .35966 .4383 L .654 .726 .902 r
F
.35878 .43298 m .32729 .43133 L .32906 .44196 L F
.73755 .88207 m .7357 .8853 L .73889 .88315 L .692 .759 .904 r
F
.73755 .88207 m .7337 .88367 L .7357 .8853 L F
.55717 .416 m .56318 .44006 L .57219 .42086 L .654 .726 .902 r
F
.55717 .416 m .54067 .43278 L .56318 .44006 L F
0 g
.56318 .44006 m
.58753 .44342 L
s
.127 .923 .03 r
.55498 .43765 m
.555 .43742 L
s
.33589 .88647 m .33703 .88216 L .33728 .88436 L .185 .095 .513 r
F
.33614 .88867 m .33589 .88647 L .33728 .88436 L F
.33213 .88527 m .33589 .88647 L .33728 .88436 L .692 .759 .903 r
F
.127 .923 .03 r
.33656 .85002 m
.33661 .85215 L
s
.33069 .88651 m .33589 .88647 L .33213 .88527 L .692 .759 .903 r
F
0 g
.33373 .88833 m
.33589 .88647 L
s
.32053 .88228 m .31669 .88389 L .31804 .88497 L .692 .759 .903 r
F
.75455 .88651 m .75646 .88245 L .75673 .88465 L .396 .244 .555 r
F
.75482 .88871 m .75455 .88651 L .75673 .88465 L F
.75202 .8902 m .75455 .88651 L .75482 .88871 L .516 .328 .565 r
F
.75154 .88469 m .75455 .88651 L .75673 .88465 L .692 .759 .904 r
F
.74968 .88569 m .75455 .88651 L .75154 .88469 L F
0 g
.75175 .888 m
.75455 .88651 L
s
.3118 .88575 m .3128 .88551 L .31305 .88771 L .976 .675 .312 r
F
.3118 .88575 m .31155 .88355 L .3128 .88551 L F
0 g
.3128 .88551 m
.31469 .88703 L
s
.74995 .88788 m .75202 .8902 L .75482 .88871 L .692 .759 .904 r
F
.7478 .88856 m .75202 .8902 L .74995 .88788 L F
0 g
.7488 .89121 m
.75202 .8902 L
s
.31587 .88258 m .31286 .88549 L .31669 .88389 L .692 .759 .903 r
F
.31587 .88258 m .31162 .88354 L .31286 .88549 L F
.20903 .55672 m .18748 .54946 L .17953 .56068 L .673 .757 .914 r
F
.18777 .55514 m .17953 .56068 L .17982 .56636 L .157 .062 .489 r
F
.18777 .55514 m .18748 .54946 L .17953 .56068 L F
0 g
.17654 .57261 m
.17953 .56068 L
s
.45069 .44832 m .48475 .43957 L .45326 .43792 L .654 .726 .902 r
F
.42049 .44148 m .45069 .44832 L .45326 .43792 L F
.41715 .44621 m .45069 .44832 L .42049 .44148 L F
.32144 .88503 m .32005 .88798 L .32234 .88543 L .692 .759 .903 r
F
.32144 .88503 m .31826 .88719 L .32005 .88798 L F
.51996 .66634 m .52603 .65452 L .51617 .66476 L .683 .77 .917 r
F
.51996 .66634 m .53362 .65768 L .52603 .65452 L F
.51165 .74769 m .51984 .75015 L .52036 .7482 L .645 .732 .913 r
F
.50782 .74746 m .51126 .74823 L .51165 .74769 L F
.51126 .74823 m .51984 .75015 L .51165 .74769 L F
.51053 .69349 m .51097 .69281 L .51098 .74862 L .076 0 .415 r
F
.51095 .74865 m .51098 .74862 L .51098 .75187 L F
.51053 .69349 m .51098 .74862 L .51095 .74865 L F
.25917 .55633 m .25326 .5406 L .25267 .55593 L .673 .757 .914 r
F
.25917 .55633 m .26626 .54141 L .25326 .5406 L F
.33184 .88306 m .33696 .88216 L .33276 .88166 L .692 .759 .903 r
F
.3281 .88187 m .33184 .88306 L .33276 .88166 L F
.32477 .88788 m .32467 .89069 L .32695 .89038 L F
.32364 .88785 m .32467 .89069 L .32477 .88788 L F
.32364 .88785 m .3224 .89063 L .32467 .89069 L F
.75673 .88465 m .75646 .88245 L .75788 .88035 L .198 .106 .519 r
F
0 g
.75428 .88431 m
.75646 .88245 L
s
.75269 .88124 m .7564 .88243 L .75782 .88034 L .692 .759 .904 r
F
.75124 .88248 m .7564 .88243 L .75269 .88124 L F
.32591 .88772 m .32695 .89038 L .32909 .8897 L .692 .759 .903 r
F
.32477 .88788 m .32695 .89038 L .32591 .88772 L F
.52899 .56886 m .5092 .56197 L .50952 .56765 L .733 .496 .569 r
F
0 g
.48957 .56389 m
.5092 .56197 L
s
.5092 .56197 m
.52867 .56318 L
s
.52899 .56886 m
.54699 .57311 L
s
.127 .923 .03 r
.52397 .62633 m
.525 .55892 L
s
.32766 .88469 m .33069 .88651 L .33213 .88527 L .692 .759 .903 r
F
.35026 .54003 m .36799 .53862 L .36829 .5443 L .794 .544 .559 r
F
.35026 .54003 m .34996 .53435 L .36799 .53862 L F
0 g
.36799 .53862 m
.38748 .53983 L
s
.47441 .66547 m .45244 .66914 L .4704 .67109 L .683 .77 .917 r
F
0 g
.25541 .62726 m
.25558 .59547 L
s
.31716 .8883 m .31534 .89154 L .31851 .88939 L .692 .759 .903 r
F
.31716 .8883 m .3133 .88991 L .31534 .89154 L F
0 g
.31534 .89154 m
.31802 .89273 L
s
.24878 .6402 m
.24878 .63991 L
s
.24885 .62751 m
.24903 .59535 L
s
.74207 .881 m .73889 .88315 L .74065 .88394 L .692 .759 .904 r
F
.33728 .88436 m .33703 .88216 L .33755 .87996 L 0 0 .377 r
F
0 g
.33564 .88427 m
.33703 .88216 L
s
.33276 .88166 m .33696 .88216 L .33749 .87996 L .692 .759 .903 r
F
.32259 .88763 m .3224 .89063 L .32364 .88785 L F
.32259 .88763 m .3203 .89018 L .3224 .89063 L F
.36325 .52071 m .3681 .53839 L .37522 .52354 L .673 .757 .914 r
F
.36325 .52071 m .35016 .53415 L .3681 .53839 L F
.27911 .44902 m .2552 .43838 L .25474 .44566 L .732 .487 .558 r
F
0 g
.2552 .43838 m
.27957 .44173 L
s
.27911 .44902 m
.30168 .45629 L
s
.23069 .43917 m
.2552 .43838 L
s
.73939 .88757 m .73885 .89092 L .74117 .88836 L .692 .759 .904 r
F
.73939 .88757 m .73619 .88973 L .73885 .89092 L F
0 g
.73885 .89092 m
.74199 .89159 L
s
.24613 .55657 m .24017 .54188 L .22789 .54517 L .673 .757 .914 r
F
.25267 .55593 m .24017 .54188 L .24613 .55657 L F
.49127 .67936 m .4712 .68023 L .48926 .68219 L .683 .77 .917 r
F
.69961 .54271 m .72574 .53829 L .70068 .53875 L .673 .757 .914 r
F
.74539 .88387 m .74525 .88668 L .74753 .88636 L .692 .759 .904 r
F
0 g
.74567 .88352 m
.74567 .88435 L
s
.74426 .88383 m .74299 .88661 L .74525 .88668 L .692 .759 .904 r
F
0 g
.50952 .56765 m
.52899 .56886 L
s
.51065 .74691 m .50959 .7492 L .51065 .75002 L .909 .63 .5 r
F
.51064 .69096 m .50964 .74616 L .51065 .74691 L F
.51097 .69281 m .51109 .74792 L .51098 .74862 L 0 0 .142 r
F
.51122 .74711 m .52036 .7482 L .52002 .74619 L .645 .732 .913 r
F
.50782 .74746 m .51113 .74766 L .51122 .74711 L F
.51113 .74766 m .52036 .7482 L .51122 .74711 L F
.51097 .69281 m .51108 .692 L .5111 .74789 L 0 0 .142 r
F
.51109 .74792 m .5111 .74789 L .5111 .75106 L F
.51097 .69281 m .5111 .74789 L .51109 .74792 L F
.50964 .74616 m .50959 .7492 L .51065 .74691 L .909 .63 .5 r
F
.50878 .74552 m .51176 .7437 L .51139 .74026 L .645 .732 .913 r
F
.50959 .74612 m .50851 .74882 L .50959 .7492 L .809 .541 .532 r
F
.50958 .69014 m .50856 .74575 L .50959 .74612 L F
.50782 .74746 m .50932 .74603 L .50865 .74578 L .645 .732 .913 r
F
.51108 .692 m .51064 .69096 L .51065 .74691 L .984 .727 .339 r
F
.51067 .74696 m .51065 .74691 L .51065 .75002 L F
.51108 .692 m .51065 .74691 L .51067 .74696 L F
.50996 .74542 m .51693 .74257 L .51438 .74121 L .645 .732 .913 r
F
.50782 .74746 m .51029 .74614 L .50996 .74542 L F
.51029 .74614 m .51693 .74257 L .50996 .74542 L F
.51029 .74614 m .51885 .74428 L .51693 .74257 L F
.50782 .74746 m .51054 .74668 L .51029 .74614 L F
.51054 .74668 m .51885 .74428 L .51029 .74614 L F
.51098 .74862 m .5111 .75106 L .51098 .75187 L 0 0 .142 r
F
.51109 .74792 m .5111 .75106 L .51098 .74862 L F
.5111 .74789 m .51065 .75002 L .5111 .75106 L .984 .727 .339 r
F
.51108 .692 m .51067 .74696 L .5111 .74789 L F
.51067 .74696 m .51065 .75002 L .5111 .74789 L F
.50856 .74575 m .50851 .74882 L .50959 .74612 L .809 .541 .532 r
F
.50865 .74578 m .50938 .74597 L .50878 .74552 L .645 .732 .913 r
F
.50932 .74603 m .50938 .74597 L .50865 .74578 L F
.50938 .74597 m .51176 .7437 L .50878 .74552 L F
.51176 .7437 m .51438 .74121 L .51227 .74054 L F
.51176 .7437 m .51227 .74054 L .51139 .74026 L F
.32698 .88739 m .32909 .8897 L .33095 .88871 L .692 .759 .903 r
F
.32591 .88772 m .32909 .8897 L .32698 .88739 L F
.38809 .55119 m .38778 .54551 L .40741 .54359 L .672 .449 .574 r
F
.3686 .54998 m .38778 .54551 L .38809 .55119 L .733 .496 .569 r
F
.127 .923 .03 r
.38108 .54509 m
.38111 .54706 L
s
.38036 .54505 m
.38037 .54723 L
s
.3686 .54998 m .36829 .5443 L .38778 .54551 L .733 .496 .569 r
F
.38845 .53018 m .38778 .54551 L .40741 .54359 L .673 .757 .914 r
F
.37545 .52937 m .38778 .54551 L .38845 .53018 L F
.37545 .52937 m .36829 .5443 L .38778 .54551 L F
.74653 .88371 m .74753 .88636 L .74968 .88569 L .692 .759 .904 r
F
.73418 .88809 m .73592 .88753 L .73619 .88973 L .935 .633 .445 r
F
.73418 .88809 m .73391 .88589 L .73592 .88753 L F
.73779 .88428 m .73592 .88753 L .73912 .88537 L .692 .759 .904 r
F
.73779 .88428 m .73391 .88589 L .73592 .88753 L F
0 g
.73592 .88753 m
.73804 .88848 L
s
.54398 .67637 m .5571 .6646 L .5405 .67112 L .683 .77 .917 r
F
.54398 .67637 m .56233 .67248 L .5571 .6646 L F
.25267 .55593 m .25326 .5406 L .24017 .54188 L .673 .757 .914 r
F
.33614 .88867 m .33728 .88436 L .33753 .88656 L .185 .095 .513 r
F
.33238 .88747 m .33614 .88867 L .33753 .88656 L .692 .759 .903 r
F
.33095 .88871 m .33614 .88867 L .33238 .88747 L F
0 g
.33398 .89053 m
.33614 .88867 L
s
.56183 .6679 m .5561 .65545 L .5566 .66002 L .98 .689 .335 r
F
.56233 .67248 m .56183 .6679 L .5566 .66002 L F
0 g
.56183 .6679 m
.5633 .67658 L
s
.32076 .88449 m .31826 .88719 L .32144 .88503 L .692 .759 .903 r
F
.32076 .88449 m .31691 .8861 L .31826 .88719 L F
.74322 .88361 m .74299 .88661 L .74426 .88383 L .692 .759 .904 r
F
.74322 .88361 m .7409 .88616 L .74299 .88661 L F
.75482 .88871 m .75673 .88465 L .757 .88685 L .396 .244 .555 r
F
.75182 .88689 m .75482 .88871 L .757 .88685 L .692 .759 .904 r
F
.74995 .88788 m .75482 .88871 L .75182 .88689 L F
0 g
.75202 .8902 m
.75482 .88871 L
s
.32012 .88163 m .31669 .88389 L .32053 .88228 L .692 .759 .903 r
F
.32012 .88163 m .31587 .88258 L .31669 .88389 L F
.31206 .88795 m .31305 .88771 L .3133 .88991 L .976 .675 .312 r
F
.31206 .88795 m .3118 .88575 L .31305 .88771 L F
.31608 .88479 m .31305 .88771 L .31691 .8861 L .692 .759 .903 r
F
.31608 .88479 m .3118 .88575 L .31305 .88771 L F
0 g
.31305 .88771 m
.31494 .88923 L
s
.42093 .43419 m .45369 .43064 L .42221 .42899 L .654 .726 .902 r
F
0 0 0 r
2.5 Mabswid
.28345 .67069 Mdot
.127 .923 .03 r
.5 Mabswid
.34928 5.51274 m
.39431 8.82552 L
s
.26548 .56343 m .26656 .54709 L .25946 .56201 L .673 .757 .914 r
F
.26548 .56343 m .2786 .54994 L .26656 .54709 L F
.7245 .55761 m .75185 .54919 L .72667 .54965 L .673 .758 .914 r
F
.7004 .55409 m .7245 .55761 L .72667 .54965 L F
.69768 .55783 m .7245 .55761 L .7004 .55409 L F
.127 .923 .03 r
.23724 .66868 m
.23725 .66915 L
s
.74761 .88337 m .74968 .88569 L .75154 .88469 L .692 .759 .904 r
F
.32169 .88723 m .3203 .89018 L .32259 .88763 L .692 .759 .903 r
F
.127 .923 .03 r
.28529 .80644 m
.28535 .81075 L
s
.32169 .88723 m .31851 .88939 L .3203 .89018 L .692 .759 .903 r
F
.49078 .67479 m .47474 .67 L .47071 .67565 L .683 .77 .917 r
F
.49389 .67229 m .47474 .67 L .49078 .67479 L F
.62592 .55148 m .60268 .56379 L .62721 .55938 L .673 .758 .914 r
F
.62592 .55148 m .60072 .55194 L .60268 .56379 L F
0 g
.60268 .56379 m
.60965 .57472 L
s
.33213 .88527 m .33728 .88436 L .33306 .88387 L .692 .759 .903 r
F
.32838 .88407 m .33213 .88527 L .33306 .88387 L F
.127 .923 .03 r
.23806 .66837 m
.23809 .66932 L
s
.20187 .66259 m .21012 .66456 L .21059 .66914 L .932 .647 .479 r
F
.20187 .66259 m .2014 .65801 L .21012 .66456 L F
0 g
.21012 .66456 m
.21475 .66648 L
s
.75673 .88465 m .75788 .88035 L .75815 .88254 L .198 .106 .519 r
F
.757 .88685 m .75673 .88465 L .75815 .88254 L F
.753 .88345 m .75673 .88465 L .75815 .88254 L .692 .759 .904 r
F
.75154 .88469 m .75673 .88465 L .753 .88345 L F
0 g
.75455 .88651 m
.75673 .88465 L
s
.33276 .88166 m .33749 .87996 L .33311 .8802 L .692 .759 .903 r
F
.32857 .88117 m .33276 .88166 L .33311 .8802 L F
.3281 .88187 m .33276 .88166 L .32857 .88117 L F
.49346 .66775 m .48059 .66049 L .47441 .66547 L .683 .77 .917 r
F
.49743 .66575 m .48059 .66049 L .49346 .66775 L F
.74141 .88046 m .73889 .88315 L .74207 .881 L .692 .759 .904 r
F
.74141 .88046 m .73755 .88207 L .73889 .88315 L F
.32791 .88689 m .33095 .88871 L .33238 .88747 L .692 .759 .903 r
F
.32698 .88739 m .33095 .88871 L .32791 .88689 L F
.7327 .88393 m .73364 .8837 L .73391 .88589 L .973 .67 .296 r
F
.127 .923 .03 r
.73034 .90647 m
.73126 .88415 L
s
.73084 .85732 m
.73335 .82617 L
s
.67862 1.50701 m
.73084 .85732 L
s
.7327 .88393 m .73243 .88173 L .73364 .8837 L .973 .67 .296 r
F
0 g
.73364 .8837 m
.73552 .88523 L
s
.73675 .88077 m .7337 .88367 L .73755 .88207 L .692 .759 .904 r
F
.73675 .88077 m .73249 .88172 L .7337 .88367 L F
.127 .923 .03 r
.73126 .88415 m
.73148 .87893 L
s
.21811 .65142 m .21033 .66443 L .22389 .65577 L .683 .77 .917 r
F
.21811 .65142 m .20165 .65791 L .21033 .66443 L F
.29102 .66948 m .29982 .6574 L .3003 .66198 L .401 .257 .568 r
F
.27802 .66219 m .29102 .66948 L .3003 .66198 L .683 .77 .917 r
F
.27007 .66619 m .29102 .66948 L .27802 .66219 L F
0 g
.2791 .67549 m
.29102 .66948 L
s
.52151 .42207 m .54109 .4255 L .54067 .43278 L .858 .601 .549 r
F
.52151 .42207 m .52194 .41478 L .54109 .4255 L F
.54482 .40156 m .54109 .4255 L .55759 .40871 L .654 .726 .902 r
F
.54482 .40156 m .52194 .41478 L .54109 .4255 L F
0 g
.54109 .4255 m
.5462 .42715 L
s
.127 .923 .03 r
.55493 .44441 m
.55498 .43765 L
s
.74233 .88321 m .7409 .88616 L .74322 .88361 L .692 .759 .904 r
F
.74233 .88321 m .73912 .88537 L .7409 .88616 L F
.40741 .54359 m .42553 .53298 L .42584 .53866 L .603 .396 .573 r
F
.40772 .54927 m .40741 .54359 L .42584 .53866 L F
.38809 .55119 m .40741 .54359 L .40772 .54927 L .672 .449 .574 r
F
.40155 .52889 m .40741 .54359 L .42584 .53866 L .673 .757 .914 r
F
.38845 .53018 m .40741 .54359 L .40155 .52889 L F
0 g
.38778 .54551 m
.40741 .54359 L
s
.33728 .88436 m .33755 .87996 L .33781 .88215 L 0 0 .377 r
F
.33753 .88656 m .33728 .88436 L .33781 .88215 L F
.33306 .88387 m .33728 .88436 L .33781 .88215 L .692 .759 .903 r
F
0 g
.33589 .88647 m
.33728 .88436 L
s
.5239 .67763 m .53474 .66675 L .52102 .67545 L .683 .77 .917 r
F
.5239 .67763 m .5405 .67112 L .53474 .66675 L F
.75269 .88124 m .75782 .88034 L .75363 .87984 L .692 .759 .904 r
F
.74898 .88005 m .75269 .88124 L .75363 .87984 L F
.65077 .54534 m .62688 .5537 L .65142 .54929 L .673 .757 .914 r
F
.65077 .54534 m .62559 .5458 L .62688 .5537 L F
.74566 .88606 m .74552 .88888 L .7478 .88856 L .692 .759 .904 r
F
.74453 .88603 m .74552 .88888 L .74566 .88606 L F
.74453 .88603 m .74326 .88881 L .74552 .88888 L F
.33102 .40642 m .30093 .3996 L .29719 .41514 L .654 .726 .902 r
F
.30001 .40678 m .29672 .41512 L .29626 .4224 L 0 0 .129 r
F
0 g
.29725 .41828 m
.29795 .42249 L
s
.30001 .40678 m .30047 .39949 L .29672 .41512 L 0 0 .129 r
F
.33102 .40642 m .29719 .41514 L .32851 .41678 L .654 .726 .902 r
F
.31143 .88359 m .31155 .88355 L .3118 .88575 L .77 .552 0 r
F
.127 .923 .03 r
.30373 .83915 m
.30402 .84254 L
s
.31143 .88359 m .31118 .88139 L .31155 .88355 L .77 .552 0 r
F
0 g
.31155 .88355 m
.3128 .88551 L
s
.31562 .88115 m .31162 .88354 L .31587 .88258 L .692 .759 .903 r
F
.31562 .88115 m .31125 .88139 L .31162 .88354 L F
.7468 .88591 m .7478 .88856 L .74995 .88788 L .692 .759 .904 r
F
.74566 .88606 m .7478 .88856 L .7468 .88591 L F
.74854 .88287 m .75154 .88469 L .753 .88345 L F
.3611 .41324 m .32851 .41678 L .35984 .41842 L .654 .726 .902 r
F
.3611 .41324 m .33102 .40642 L .32851 .41678 L F
.24028 .56389 m .22818 .55085 L .21756 .55591 L .673 .757 .914 r
F
.24642 .56225 m .22818 .55085 L .24028 .56389 L F
.73806 .88648 m .73619 .88973 L .73939 .88757 L .692 .759 .904 r
F
.73806 .88648 m .73418 .88809 L .73619 .88973 L F
0 g
.73619 .88973 m
.73885 .89092 L
s
.127 .923 .03 r
.5561 .43843 m
.55613 .43722 L
s
0 g
.48989 .56957 m
.50952 .56765 L
s
.2966 .56082 m .3071 .54345 L .28884 .55462 L .673 .757 .914 r
F
.2966 .56082 m .31873 .55276 L .3071 .54345 L F
.75815 .88254 m .75788 .88035 L .75844 .87814 L 0 0 .394 r
F
0 g
.75646 .88245 m
.75788 .88035 L
s
.32101 .88668 m .31851 .88939 L .32169 .88723 L .692 .759 .903 r
F
.32101 .88668 m .31716 .8883 L .31851 .88939 L F
.75363 .87984 m .75782 .88034 L .75837 .87814 L .692 .759 .904 r
F
.74349 .88581 m .74326 .88881 L .74453 .88603 L F
.74349 .88581 m .74117 .88836 L .74326 .88881 L F
.42249 .4217 m .45209 .41275 L .42162 .41641 L .654 .726 .902 r
F
.42249 .4217 m .45381 .42334 L .45209 .41275 L F
.32035 .88383 m .31691 .8861 L .32076 .88449 L .692 .759 .903 r
F
.32035 .88383 m .31608 .88479 L .31691 .8861 L F
.51617 .66476 m .5171 .65275 L .51171 .66388 L .683 .77 .917 r
F
.51617 .66476 m .52603 .65452 L .5171 .65275 L F
.31633 .88699 m .3133 .88991 L .31716 .8883 L .692 .759 .903 r
F
.31633 .88699 m .31206 .88795 L .3133 .88991 L F
0 g
.3133 .88991 m
.31534 .89154 L
s
.45381 .42334 m .48258 .4091 L .45209 .41275 L .654 .726 .902 r
F
.45381 .42334 m .48514 .42497 L .48258 .4091 L F
.52053 .67087 m .52662 .65899 L .51672 .66928 L .683 .77 .917 r
F
.52053 .67087 m .53425 .66217 L .52662 .65899 L F
.48518 .43228 m .48561 .425 L .48304 .40904 L .92 .74 .251 r
F
0 g
.48383 .43221 m
.48481 .42825 L
s
.74788 .88557 m .74995 .88788 L .75182 .88689 L .692 .759 .904 r
F
.7468 .88591 m .74995 .88788 L .74788 .88557 L F
.51039 .74672 m .52002 .74619 L .51885 .74428 L .645 .732 .913 r
F
.50782 .74746 m .51095 .74714 L .51039 .74672 L F
.51095 .74714 m .52002 .74619 L .51039 .74672 L F
.51064 .69096 m .50958 .69014 L .50959 .74612 L .909 .63 .5 r
F
.50964 .74616 m .50959 .74612 L .50959 .7492 L F
.51064 .69096 m .50959 .74612 L .50964 .74616 L F
0 g
.51064 .69096 m
.51065 .74177 L
s
.127 .923 .03 r
.39942 8.8243 m
.47577 4.73788 L
s
.49618 8.80046 m
.50423 7.65475 L
s
0 g
.51063 .68285 m
.51064 .69096 L
s
.31999 .88091 m .31587 .88258 L .32012 .88163 L .692 .759 .903 r
F
.31999 .88091 m .31562 .88115 L .31587 .88258 L F
.32857 .88117 m .33311 .8802 L .32874 .88044 L F
0 g
.23022 .44646 m
.25474 .44566 L
s
.50537 .74578 m .50184 .74047 L .49919 .74153 L .645 .732 .913 r
F
.50742 .74557 m .50632 .74878 L .50742 .74869 L .66 .417 .541 r
F
.50741 .68963 m .50638 .74561 L .50742 .74557 L F
.50782 .74746 m .50623 .74561 L .50537 .74578 L .645 .732 .913 r
F
.50638 .74561 m .50632 .74878 L .50742 .74557 L .66 .417 .541 r
F
.50623 .74561 m .50604 .74538 L .50562 .74563 L .645 .732 .913 r
F
.50623 .74561 m .50562 .74563 L .50537 .74578 L F
.50604 .74538 m .50184 .74047 L .50537 .74578 L F
.50521 .69006 m .50409 .69084 L .50409 .74654 L .401 .213 .507 r
F
.50415 .74651 m .50409 .74654 L .50409 .7499 L F
.50521 .69006 m .50409 .74654 L .50415 .74651 L F
0 g
.50409 .69084 m
.50409 .7431 L
s
.50408 .68317 m
.50409 .69084 L
s
.21727 .55023 m .18748 .54946 L .20903 .55672 L .673 .757 .914 r
F
.127 .923 .03 r
.19584 .54925 m
.19585 .54967 L
s
.33238 .88747 m .33753 .88656 L .33331 .88606 L .692 .759 .903 r
F
.32863 .88627 m .33238 .88747 L .33331 .88606 L F
.32791 .88689 m .33238 .88747 L .32863 .88627 L F
0 g
.32479 .88617 m
.32638 .88597 L
s
.32479 .88617 m
.32479 .88617 L
s
.32321 .88591 m
.32479 .88617 L
s
.25474 .44566 m
.27911 .44902 L
s
.47474 .67 m .45265 .67369 L .47071 .67565 L .683 .77 .917 r
F
.33781 .88215 m .33755 .87996 L .33718 .8778 L .768 .55 0 r
F
.127 .923 .03 r
.32323 .74438 m
.32401 .8322 L
s
.33419 .85527 m
.33427 .86598 L
s
0 g
.33703 .88216 m
.33751 .88012 L
s
.757 .88685 m .75815 .88254 L .75842 .88474 L .198 .106 .519 r
F
.75327 .88565 m .757 .88685 L .75842 .88474 L .692 .759 .904 r
F
.75182 .88689 m .757 .88685 L .75327 .88565 L F
0 g
.75482 .88871 m
.757 .88685 L
s
.33311 .8802 m .33749 .87996 L .33712 .87781 L .692 .759 .903 r
F
.53934 .66203 m .54727 .64902 L .53362 .65768 L .683 .77 .917 r
F
.53934 .66203 m .55586 .65554 L .54727 .64902 L F
.33306 .88387 m .33781 .88215 L .33341 .88239 L .692 .759 .903 r
F
.32884 .88337 m .33306 .88387 L .33341 .88239 L F
.32838 .88407 m .33306 .88387 L .32884 .88337 L F
.74166 .88267 m .73912 .88537 L .74233 .88321 L .692 .759 .904 r
F
.74166 .88267 m .73779 .88428 L .73912 .88537 L F
.74101 .87981 m .73755 .88207 L .74141 .88046 L F
.74101 .87981 m .73675 .88077 L .73755 .88207 L F
.73297 .88613 m .73391 .88589 L .73418 .88809 L .973 .67 .296 r
F
.73297 .88613 m .7327 .88393 L .73391 .88589 L F
.73698 .88297 m .73391 .88589 L .73779 .88428 L .692 .759 .904 r
F
.73698 .88297 m .7327 .88393 L .73391 .88589 L F
0 g
.73391 .88589 m
.73579 .88742 L
s
.20932 .5624 m .18777 .55514 L .17982 .56636 L .673 .757 .914 r
F
0 g
.17682 .57829 m
.17982 .56636 L
s
0 0 0 r
2.5 Mabswid
.23375 .56343 Mdot
.7426 .88541 m .74117 .88836 L .74349 .88581 L .692 .759 .904 r
F
.7426 .88541 m .73939 .88757 L .74117 .88836 L F
.33311 .8802 m .33712 .87781 L .33287 .87877 L .692 .759 .903 r
F
.32874 .88044 m .33311 .8802 L .33287 .87877 L F
.33753 .88656 m .33781 .88215 L .33806 .88435 L 0 0 .377 r
F
.33331 .88606 m .33753 .88656 L .33806 .88435 L .692 .759 .903 r
F
0 g
.5 Mabswid
.33614 .88867 m
.33753 .88656 L
s
.127 .923 .03 r
.33661 .85215 m
.33665 .85428 L
s
.25946 .56201 m .25355 .54629 L .25296 .56161 L .673 .757 .914 r
F
.25946 .56201 m .26656 .54709 L .25355 .54629 L F
.32487 .88507 m .32477 .88788 L .32591 .88772 L .692 .759 .903 r
F
.32487 .88507 m .32364 .88785 L .32477 .88788 L F
.75151 .54351 m .75117 .53783 L .74928 .52597 L .815 .614 .058 r
F
0 g
.74961 .54355 m
.75091 .53878 L
s
.72574 .53829 m .75079 .53784 L .74891 .52604 L .673 .757 .914 r
F
.32487 .88507 m .32591 .88772 L .32698 .88739 L .692 .759 .903 r
F
0 g
.32638 .88597 m
.3274 .88553 L
s
.753 .88345 m .75815 .88254 L .75395 .88205 L .692 .759 .904 r
F
.74927 .88225 m .753 .88345 L .75395 .88205 L F
.31168 .88579 m .3118 .88575 L .31206 .88795 L .77 .552 0 r
F
.31168 .88579 m .31143 .88359 L .3118 .88575 L F
.31583 .88335 m .3118 .88575 L .31608 .88479 L .692 .759 .903 r
F
.31583 .88335 m .31143 .88359 L .3118 .88575 L F
0 g
.3118 .88575 m
.31305 .88771 L
s
.35056 .54571 m .36829 .5443 L .3686 .54998 L .794 .544 .559 r
F
.35056 .54571 m .35026 .54003 L .36829 .5443 L F
.36343 .52652 m .36829 .5443 L .37545 .52937 L .673 .757 .914 r
F
.36343 .52652 m .35026 .54003 L .36829 .5443 L F
0 g
.36829 .5443 m
.38778 .54551 L
s
.32874 .88044 m .33287 .87877 L .32862 .87972 L .692 .759 .903 r
F
.42584 .53866 m .42553 .53298 L .44152 .52539 L .515 .329 .567 r
F
0 g
.41723 .5352 m
.42553 .53298 L
s
.75363 .87984 m .75837 .87814 L .754 .87838 L .692 .759 .904 r
F
.74945 .87935 m .75363 .87984 L .754 .87838 L F
.74898 .88005 m .75363 .87984 L .74945 .87935 L F
0 g
.74913 .87973 m
.74913 .88063 L
s
.32487 .88507 m .32259 .88763 L .32364 .88785 L .692 .759 .903 r
F
0 g
.32222 .88544 m
.32321 .88591 L
s
.50958 .69014 m .5085 .68976 L .50851 .74882 L .809 .541 .532 r
F
.56233 .67248 m .5566 .66002 L .5571 .6646 L .98 .689 .335 r
F
0 g
.56233 .67248 m
.5638 .68115 L
s
.74881 .88507 m .75182 .88689 L .75327 .88565 L .692 .759 .904 r
F
.74788 .88557 m .75182 .88689 L .74881 .88507 L F
.49743 .66575 m .48853 .6565 L .48059 .66049 L .683 .77 .917 r
F
.502 .66439 m .48853 .6565 L .49743 .66575 L F
.50632 .68972 m .50521 .69006 L .50521 .74912 L .568 .343 .534 r
F
.74528 .43326 m .74567 .42597 L .72659 .41526 L .859 .601 .547 r
F
0 g
.74567 .42597 m
.76005 .43938 L
s
.32487 .88507 m .32698 .88739 L .32791 .88689 L .692 .759 .903 r
F
.64622 .44331 m .63128 .42489 L .61127 .43355 L .654 .726 .902 r
F
0 g
.59672 .44461 m
.61127 .43355 L
s
.66159 .44005 m .63128 .42489 L .64622 .44331 L .654 .726 .902 r
F
.58997 .29916 m .59168 .35751 L .59008 .35772 L .641 .4 .539 r
F
.58997 .29916 m .59156 .29895 L .59168 .35751 L F
.5884 .29889 m .58997 .29916 L .59008 .35772 L .751 .49 .538 r
F
0 g
.58997 .29916 m
.58997 .29916 L
s
.6946 .43446 m .67933 .4119 L .67836 .43223 L .654 .726 .902 r
F
.6946 .43446 m .7037 .41526 L .67933 .4119 L F
.41341 .5198 m .42535 .53279 L .44126 .52523 L .673 .757 .914 r
F
.40118 .52307 m .42535 .53279 L .41341 .5198 L F
.75815 .88254 m .75844 .87814 L .75871 .88034 L 0 0 .394 r
F
.75842 .88474 m .75815 .88254 L .75871 .88034 L F
.75395 .88205 m .75815 .88254 L .75871 .88034 L .692 .759 .904 r
F
0 g
.75673 .88465 m
.75815 .88254 L
s
.70919 .4466 m .70329 .42254 L .69419 .44175 L .654 .726 .902 r
F
.70919 .4466 m .72579 .42983 L .70329 .42254 L F
.3206 .88603 m .31716 .8883 L .32101 .88668 L .692 .759 .903 r
F
.3206 .88603 m .31633 .88699 L .31716 .8883 L F
.24642 .56225 m .24046 .54757 L .22818 .55085 L .673 .757 .914 r
F
.25296 .56161 m .24046 .54757 L .24642 .56225 L F
.70007 .54841 m .72633 .54397 L .70115 .54443 L F
.59156 .29895 m .5927 .35707 L .59168 .35751 L .516 .301 .527 r
F
.59156 .29895 m .59259 .29851 L .5927 .35707 L F
0 g
.58997 .29916 m
.59156 .29895 L
s
.32487 .88507 m .32169 .88723 L .32259 .88763 L .692 .759 .903 r
F
0 g
.32156 .88485 m
.32222 .88544 L
s
.5085 .68976 m .50742 .74869 L .50851 .74882 L .734 .477 .54 r
F
.5085 .68976 m .50741 .68963 L .50742 .74869 L F
.5884 .29889 m .59008 .35772 L .58851 .35745 L .751 .49 .538 r
F
.58741 .29841 m .5884 .29889 L .58851 .35745 L .846 .571 .522 r
F
0 g
.5884 .29889 m
.58997 .29916 L
s
.28807 .54337 m .29094 .52526 L .27787 .53871 L .673 .757 .914 r
F
.28807 .54337 m .30623 .53226 L .29094 .52526 L F
.49127 .67936 m .47523 .67457 L .4712 .68023 L .683 .77 .917 r
F
.49438 .67686 m .47523 .67457 L .49127 .67936 L F
.38876 .53586 m .38809 .55119 L .40772 .54927 L .673 .757 .914 r
F
.37576 .53505 m .38809 .55119 L .38876 .53586 L F
.127 .923 .03 r
.38038 .5554 m
.38049 .61156 L
s
.38037 .55071 m
.38038 .5554 L
s
.38122 .55511 m
.38142 .56956 L
s
.38116 .55076 m
.38122 .55511 L
s
.37576 .53505 m .3686 .54998 L .38809 .55119 L .673 .757 .914 r
F
.50741 .68963 m .50632 .68972 L .50632 .74878 L .66 .417 .541 r
F
.73236 .88177 m .73243 .88173 L .7327 .88393 L .743 .529 0 r
F
.73236 .88177 m .73209 .87958 L .73243 .88173 L F
0 g
.73243 .88173 m
.73364 .8837 L
s
.73652 .87933 m .73249 .88172 L .73675 .88077 L .692 .759 .904 r
F
.73652 .87933 m .73215 .87957 L .73249 .88172 L F
.32022 .88311 m .31608 .88479 L .32035 .88383 L .692 .759 .903 r
F
.32022 .88311 m .31583 .88335 L .31608 .88479 L F
.32884 .88337 m .33341 .88239 L .32901 .88263 L F
.32017 .88018 m .31562 .88115 L .31999 .88091 L F
.20234 .66716 m .21059 .66914 L .21106 .67371 L .932 .647 .479 r
F
.20234 .66716 m .20187 .66259 L .21059 .66914 L F
.21841 .65606 m .21059 .66914 L .22423 .66043 L .683 .77 .917 r
F
.21841 .65606 m .20187 .66259 L .21059 .66914 L F
0 g
.21059 .66914 m
.21523 .67106 L
s
.32487 .88507 m .32791 .88689 L .32863 .88627 L .692 .759 .903 r
F
0 g
.3274 .88553 m
.32811 .88497 L
s
.51171 .66388 m .50743 .65249 L .50687 .66375 L .683 .77 .917 r
F
.51171 .66388 m .5171 .65275 L .50743 .65249 L F
0 0 0 r
2.5 Mabswid
.23732 .67298 Mdot
.127 .923 .03 r
.5 Mabswid
.27341 2.55784 m
.32143 5.0651 L
s
.32143 5.0651 m
.39344 8.82552 L
s
0 g
.32811 .88497 m
.32854 .88429 L
s
.49389 .67229 m .48095 .665 L .47474 .67 L .683 .77 .917 r
F
.49788 .67028 m .48095 .665 L .49389 .67229 L F
.25296 .56161 m .25355 .54629 L .24046 .54757 L .673 .757 .914 r
F
0 g
.32117 .88416 m
.32156 .88485 L
s
.33781 .88215 m .33718 .8778 L .33743 .87999 L .768 .55 0 r
F
.33806 .88435 m .33781 .88215 L .33743 .87999 L F
0 g
.33728 .88436 m
.33777 .88232 L
s
.33341 .88239 m .33781 .88215 L .33743 .87999 L .692 .759 .903 r
F
.59259 .29851 m .59342 .35649 L .5927 .35707 L .356 .178 .497 r
F
.59259 .29851 m .5933 .29793 L .59342 .35649 L F
0 g
.59156 .29895 m
.59259 .29851 L
s
.32862 .87972 m .33204 .87746 L .3282 .87907 L .692 .759 .903 r
F
0 g
.32821 .87907 m
.3284 .8273 L
s
.32862 .87972 m .33287 .87877 L .33204 .87746 L .692 .759 .903 r
F
.33331 .88606 m .33806 .88435 L .33366 .88459 L F
.127 .923 .03 r
.33727 .88487 m
.35915 1.96213 L
s
.32909 .88557 m .33331 .88606 L .33366 .88459 L .692 .759 .903 r
F
.32863 .88627 m .33331 .88606 L .32909 .88557 L F
.74193 .88487 m .73939 .88757 L .7426 .88541 L .692 .759 .904 r
F
.74193 .88487 m .73806 .88648 L .73939 .88757 L F
.31597 .87969 m .31125 .88139 L .31562 .88115 L .692 .759 .903 r
F
.32017 .88018 m .31597 .87969 L .31562 .88115 L F
.74126 .88201 m .73779 .88428 L .74166 .88267 L .692 .759 .904 r
F
.74126 .88201 m .73698 .88297 L .73779 .88428 L F
.73725 .88517 m .73418 .88809 L .73806 .88648 L F
.73725 .88517 m .73297 .88613 L .73418 .88809 L F
0 g
.73418 .88809 m
.73619 .88973 L
s
.31843 .54708 m .31813 .5414 L .3065 .53209 L .931 .657 .497 r
F
0 g
.31813 .5414 m
.32522 .55235 L
s
.58741 .29841 m .58851 .35745 L .58752 .35697 L .846 .571 .522 r
F
.58675 .29781 m .58741 .29841 L .58752 .35697 L .93 .648 .485 r
F
0 g
.58741 .29841 m
.5884 .29889 L
s
.72574 .53829 m .74891 .52604 L .72448 .53043 L .673 .757 .914 r
F
.70068 .53875 m .72574 .53829 L .72448 .53043 L F
.127 .923 .03 r
.32971 3.56281 m
.49551 8.79957 L
s
0 0 0 r
2.5 Mabswid
.2382 .67265 Mdot
.32487 .88507 m .32101 .88668 L .32169 .88723 L .692 .759 .903 r
F
.127 .923 .03 r
.5 Mabswid
.24255 .80992 m
.24261 .81207 L
s
.33341 .88239 m .33743 .87999 L .33316 .88095 L .692 .759 .903 r
F
.32901 .88263 m .33341 .88239 L .33316 .88095 L F
.74089 .87909 m .73675 .88077 L .74101 .87981 L .692 .759 .904 r
F
.74089 .87909 m .73652 .87933 L .73675 .88077 L F
.74945 .87935 m .754 .87838 L .74963 .87862 L F
.31597 .87969 m .31177 .87919 L .31125 .88139 L .692 .759 .903 r
F
.31196 .88138 m .31118 .88139 L .31143 .88359 L 0 0 .376 r
F
0 g
.31151 .88328 m
.31155 .88355 L
s
.31196 .88138 m .31171 .87919 L .31118 .88139 L 0 0 .376 r
F
.32487 .88507 m .32863 .88627 L .32909 .88557 L .692 .759 .903 r
F
.502 .66439 m .49769 .65378 L .48853 .6565 L .683 .77 .917 r
F
.50687 .66375 m .49769 .65378 L .502 .66439 L F
.75327 .88565 m .75842 .88474 L .75422 .88424 L .692 .759 .904 r
F
.74954 .88445 m .75327 .88565 L .75422 .88424 L F
.74881 .88507 m .75327 .88565 L .74954 .88445 L F
0 g
.74567 .88435 m
.74727 .88415 L
s
.74567 .88435 m
.74567 .88435 L
s
.7441 .88409 m
.74567 .88435 L
s
.75871 .88034 m .75844 .87814 L .7581 .87598 L .741 .528 0 r
F
0 g
.75788 .88035 m
.75842 .87823 L
s
.754 .87838 m .75837 .87814 L .75804 .87599 L .692 .759 .904 r
F
.31608 .88555 m .31206 .88795 L .31633 .88699 L .692 .759 .903 r
F
.31608 .88555 m .31168 .88579 L .31206 .88795 L F
0 g
.31206 .88795 m
.3133 .88991 L
s
.32063 .87948 m .31597 .87969 L .32017 .88018 L .692 .759 .903 r
F
.32901 .88263 m .33316 .88095 L .32889 .88191 L F
0 g
.32854 .88429 m
.32865 .88349 L
s
.75395 .88205 m .75871 .88034 L .75432 .88057 L .692 .759 .904 r
F
.74974 .88155 m .75395 .88205 L .75432 .88057 L F
.74927 .88225 m .75395 .88205 L .74974 .88155 L F
.33287 .87877 m .33588 .87586 L .33204 .87746 L .692 .759 .903 r
F
.33287 .87877 m .33712 .87781 L .33588 .87586 L F
.29982 .6574 m .29934 .65283 L .30533 .64434 L .195 .11 .525 r
F
0 g
.29362 .65746 m
.29934 .65283 L
s
.5933 .29793 m .59385 .35581 L .59342 .35649 L .076 0 .415 r
F
.5933 .29793 m .59373 .29724 L .59385 .35581 L F
0 g
.59259 .29851 m
.5933 .29793 L
s
.50687 .66375 m .50743 .65249 L .49769 .65378 L .683 .77 .917 r
F
0 g
.32112 .88335 m
.32117 .88416 L
s
.28309 .64798 m .2991 .65275 L .30506 .64431 L .683 .77 .917 r
F
.27694 .65296 m .2991 .65275 L .28309 .64798 L F
.51672 .66928 m .51765 .65721 L .51223 .6684 L F
.51672 .66928 m .52662 .65899 L .51765 .65721 L F
.58675 .29781 m .58752 .35697 L .58686 .35637 L .93 .648 .485 r
F
.58637 .29711 m .58675 .29781 L .58686 .35637 L .988 .719 .381 r
F
0 g
.58675 .29781 m
.58741 .29841 L
s
.40772 .54927 m .42584 .53866 L .42615 .54434 L .603 .396 .573 r
F
.40185 .53458 m .40772 .54927 L .42615 .54434 L .673 .757 .914 r
F
.38876 .53586 m .40772 .54927 L .40185 .53458 L F
0 g
.38809 .55119 m
.40772 .54927 L
s
.52102 .67545 m .52712 .66357 L .51721 .67386 L .683 .77 .917 r
F
.52102 .67545 m .53474 .66675 L .52712 .66357 L F
.47441 .66547 m .45844 .6607 L .45244 .66914 L F
.3282 .87907 m .33069 .87638 L .32753 .87853 L .692 .759 .903 r
F
.3282 .87907 m .33204 .87746 L .33069 .87638 L F
.754 .87838 m .75804 .87599 L .75378 .87695 L .692 .759 .904 r
F
.74963 .87862 m .754 .87838 L .75378 .87695 L F
.32462 .88287 m .32086 .88167 L .3204 .88238 L .692 .759 .903 r
F
0 g
.32164 .88233 m
.32165 .88189 L
s
.32462 .88287 m .32848 .88126 L .3278 .88071 L .692 .759 .903 r
F
0 g
.3282 .88104 m
.32821 .87941 L
s
.32462 .88287 m .32889 .88191 L .32848 .88126 L .692 .759 .903 r
F
0 g
.3282 .88245 m
.3282 .88155 L
s
.75842 .88474 m .75871 .88034 L .75898 .88253 L 0 0 .394 r
F
.75422 .88424 m .75842 .88474 L .75898 .88253 L .692 .759 .904 r
F
0 g
.757 .88685 m
.75842 .88474 L
s
.45869 .66521 m .45217 .66911 L .45265 .67369 L .2 .114 .528 r
F
.45869 .66521 m .4582 .66063 L .45217 .66911 L F
0 g
.44983 .67799 m
.45217 .66911 L
s
.32487 .88507 m .3206 .88603 L .32101 .88668 L .692 .759 .903 r
F
.7458 .88325 m .74566 .88606 L .7468 .88591 L .692 .759 .904 r
F
.7458 .88325 m .74453 .88603 L .74566 .88606 L F
.65111 .55102 m .62721 .55938 L .65175 .55497 L .673 .758 .914 r
F
.65111 .55102 m .62592 .55148 L .62721 .55938 L F
.7458 .88325 m .7468 .88591 L .74788 .88557 L .692 .759 .904 r
F
0 g
.74727 .88415 m
.7483 .88371 L
s
.127 .923 .03 r
.31842 .55728 m
.32286 .76166 L
s
.34229 1.65739 m
.49728 8.80043 L
s
0 0 0 r
2.5 Mabswid
.31842 .55728 Mdot
.127 .923 .03 r
.5 Mabswid
.31842 .55728 m
.32032 .76263 L
s
.33705 2.56844 m
.39499 8.82488 L
s
.73263 .88397 m .7327 .88393 L .73297 .88613 L .743 .529 0 r
F
.73263 .88397 m .73236 .88177 L .7327 .88393 L F
.73675 .88153 m .7327 .88393 L .73698 .88297 L .692 .759 .904 r
F
.73675 .88153 m .73236 .88177 L .7327 .88393 L F
0 g
.7327 .88393 m
.73391 .88589 L
s
.74963 .87862 m .75378 .87695 L .74952 .8779 L .692 .759 .904 r
F
.47523 .67457 m .45314 .67827 L .4712 .68023 L .683 .77 .917 r
F
.32047 .88531 m .31633 .88699 L .3206 .88603 L .692 .759 .903 r
F
.127 .923 .03 r
.32032 .76263 m
.32034 .7648 L
s
.32047 .88531 m .31608 .88555 L .31633 .88699 L .692 .759 .903 r
F
.32909 .88557 m .33366 .88459 L .32927 .88483 L F
.127 .923 .03 r
.32286 .76166 m
.3229 .76382 L
s
.32487 .88507 m .32909 .88557 L .32927 .88483 L .692 .759 .903 r
F
.3204 .88238 m .31583 .88335 L .32022 .88311 L F
.33743 .87999 m .33718 .8778 L .33594 .87583 L .976 .674 .311 r
F
.127 .923 .03 r
.32579 1.35241 m
.33705 2.56844 L
s
.33881 1.49677 m
.34229 1.65739 L
s
.32979 1.48222 m
.36621 5.57987 L
s
.33531 1.0014 m
.34552 2.33428 L
s
0 g
.33718 .8778 m
.33755 .87996 L
s
.7458 .88325 m .74349 .88581 L .74453 .88603 L .692 .759 .904 r
F
0 g
.74312 .88362 m
.7441 .88409 L
s
.70068 .53875 m .72448 .53043 L .70005 .53482 L .673 .757 .914 r
F
.54 .66654 m .54798 .65347 L .53425 .66217 L .683 .77 .917 r
F
.54 .66654 m .5566 .66002 L .54798 .65347 L F
.7458 .88325 m .74788 .88557 L .74881 .88507 L .692 .759 .904 r
F
.32063 .87948 m .31689 .87829 L .31597 .87969 L .692 .759 .903 r
F
.32134 .87886 m .31689 .87829 L .32063 .87948 L F
.59373 .29724 m .59397 .35498 L .59385 .35581 L 0 0 .146 r
F
.59373 .29724 m .59385 .29642 L .59397 .35498 L F
0 g
.5933 .29793 m
.59373 .29724 L
s
.33806 .88435 m .33743 .87999 L .33769 .88219 L .768 .55 0 r
F
.127 .923 .03 r
.3229 .76382 m
.32422 .82436 L
s
.33366 .88459 m .33806 .88435 L .33769 .88219 L .692 .759 .903 r
F
0 g
.33753 .88656 m
.33806 .88435 L
s
.32889 .88191 m .33233 .87964 L .32848 .88126 L .692 .759 .903 r
F
.32889 .88191 m .33316 .88095 L .33233 .87964 L F
.31618 .88188 m .31143 .88359 L .31583 .88335 L F
.3204 .88238 m .31618 .88188 L .31583 .88335 L F
.42049 .44148 m .45326 .43792 L .42176 .43628 L .654 .726 .902 r
F
.74153 .88421 m .73806 .88648 L .74193 .88487 L .692 .759 .904 r
F
.74153 .88421 m .73725 .88517 L .73806 .88648 L F
.58637 .29711 m .58686 .35637 L .58648 .35567 L .988 .719 .381 r
F
.58632 .29628 m .58637 .29711 L .58648 .35567 L .777 .62 .057 r
F
0 g
.58637 .29711 m
.58675 .29781 L
s
.32753 .87853 m .32891 .87559 L .32664 .87813 L .692 .759 .903 r
F
.32753 .87853 m .33069 .87638 L .32891 .87559 L F
.7458 .88325 m .7426 .88541 L .74349 .88581 L .692 .759 .904 r
F
0 g
.74246 .88303 m
.74312 .88362 L
s
.25154 .65891 m .2511 .67022 L .26089 .66894 L .683 .77 .917 r
F
.24668 .65878 m .2511 .67022 L .25154 .65891 L F
.24668 .65878 m .24137 .66997 L .2511 .67022 L F
.23746 .64711 m .22389 .65577 L .23152 .65894 L F
.31689 .87829 m .31177 .87919 L .31597 .87969 L .692 .759 .903 r
F
.33366 .88459 m .33769 .88219 L .33341 .88315 L F
.32927 .88483 m .33366 .88459 L .33341 .88315 L F
.74114 .88129 m .73698 .88297 L .74126 .88201 L .692 .759 .904 r
F
.74114 .88129 m .73675 .88153 L .73698 .88297 L F
.32487 .88507 m .32047 .88531 L .3206 .88603 L .692 .759 .903 r
F
.74974 .88155 m .75432 .88057 L .74993 .88081 L .692 .759 .904 r
F
.74108 .87836 m .73652 .87933 L .74089 .87909 L F
.26056 .65232 m .26959 .66162 L .27754 .65761 L .683 .77 .917 r
F
.7458 .88325 m .74881 .88507 L .74954 .88445 L .692 .759 .904 r
F
0 g
.7483 .88371 m
.74901 .88315 L
s
.31221 .88358 m .31143 .88359 L .31168 .88579 L 0 0 .376 r
F
0 g
.31176 .88548 m
.3118 .88575 L
s
.31618 .88188 m .31196 .88138 L .31143 .88359 L .692 .759 .903 r
F
.31221 .88358 m .31196 .88138 L .31143 .88359 L 0 0 .376 r
F
.21756 .55591 m .18777 .55514 L .20932 .5624 L .673 .757 .914 r
F
0 g
.74901 .88315 m
.74945 .88247 L
s
.49788 .67028 m .48893 .66099 L .48095 .665 L .683 .77 .917 r
F
.50248 .66891 m .48893 .66099 L .49788 .67028 L F
0 g
.74209 .88234 m
.74246 .88303 L
s
.32134 .87886 m .31832 .87705 L .31689 .87829 L .692 .759 .903 r
F
.32226 .87837 m .31832 .87705 L .32134 .87886 L F
.75871 .88034 m .7581 .87598 L .75837 .87818 L .741 .528 0 r
F
.75898 .88253 m .75871 .88034 L .75837 .87818 L F
0 g
.75815 .88254 m
.75869 .88043 L
s
.75432 .88057 m .75871 .88034 L .75837 .87818 L .692 .759 .904 r
F
.25644 .65827 m .26089 .66894 L .27007 .66619 L .683 .77 .917 r
F
.25154 .65891 m .26089 .66894 L .25644 .65827 L F
.127 .923 .03 r
.19597 .55463 m
.19599 .55535 L
s
.32927 .88483 m .33341 .88315 L .32914 .88411 L .692 .759 .903 r
F
.32487 .88507 m .32927 .88483 L .32914 .88411 L F
.74952 .8779 m .75297 .87564 L .74912 .87725 L .692 .759 .904 r
F
0 g
.74912 .87759 m
.74913 .87921 L
s
.74952 .8779 m .75378 .87695 L .75297 .87564 L .692 .759 .904 r
F
.32086 .88167 m .31618 .88188 L .3204 .88238 L .692 .759 .903 r
F
.75422 .88424 m .75898 .88253 L .75459 .88277 L .692 .759 .904 r
F
.75001 .88375 m .75422 .88424 L .75459 .88277 L F
.74954 .88445 m .75422 .88424 L .75001 .88375 L F
.73689 .87787 m .73215 .87957 L .73652 .87933 L F
.74108 .87836 m .73689 .87787 L .73652 .87933 L F
.33316 .88095 m .33619 .87803 L .33233 .87964 L .692 .759 .903 r
F
.33316 .88095 m .33743 .87999 L .33619 .87803 L F
.5444 .40885 m .54067 .43278 L .55717 .416 L .654 .726 .902 r
F
.5444 .40885 m .52151 .42207 L .54067 .43278 L F
0 g
.54067 .43278 m
.56318 .44006 L
s
.32664 .87813 m .32682 .87514 L .32559 .87791 L .692 .759 .903 r
F
.32664 .87813 m .32891 .87559 L .32682 .87514 L F
.7458 .88325 m .74193 .88487 L .7426 .88541 L .692 .759 .904 r
F
.33204 .87746 m .33386 .87423 L .33069 .87638 L .692 .759 .903 r
F
.33204 .87746 m .33588 .87586 L .33386 .87423 L F
.59385 .29642 m .59353 .35393 L .59397 .35498 L .983 .725 .333 r
F
.59385 .29642 m .59341 .29536 L .59353 .35393 L F
.32848 .88126 m .33098 .87856 L .3278 .88071 L .692 .759 .903 r
F
.32848 .88126 m .33233 .87964 L .33098 .87856 L F
.75432 .88057 m .75837 .87818 L .75409 .87914 L .692 .759 .904 r
F
.74993 .88081 m .75432 .88057 L .75409 .87914 L F
.74553 .88105 m .74114 .88129 L .74126 .88201 L F
.32487 .88507 m .32065 .88457 L .32047 .88531 L .692 .759 .903 r
F
.32487 .88507 m .32111 .88387 L .32065 .88457 L F
.32487 .88507 m .32183 .88325 L .32111 .88387 L F
0 g
.32112 .88335 m
.32164 .88233 L
s
.32487 .88507 m .32276 .88275 L .32183 .88325 L .692 .759 .903 r
F
.32487 .88507 m .32383 .88242 L .32276 .88275 L F
.32487 .88507 m .32497 .88226 L .32383 .88242 L F
.32487 .88507 m .3261 .88229 L .32497 .88226 L F
.32487 .88507 m .32715 .88251 L .3261 .88229 L F
.32487 .88507 m .32805 .88291 L .32715 .88251 L F
.32487 .88507 m .32873 .88346 L .32805 .88291 L F
0 g
.3282 .88245 m
.32859 .88335 L
s
.32487 .88507 m .32914 .88411 L .32873 .88346 L .692 .759 .903 r
F
.67563 .5392 m .66381 .52622 L .65849 .52874 L .673 .757 .914 r
F
.67563 .5392 m .66994 .52458 L .66381 .52622 L F
.73689 .87787 m .73271 .87737 L .73215 .87957 L .692 .759 .904 r
F
.73291 .87956 m .73209 .87958 L .73236 .88177 L 0 0 .393 r
F
0 g
.7324 .88159 m
.73243 .88173 L
s
.73291 .87956 m .73265 .87737 L .73209 .87958 L 0 0 .393 r
F
.127 .923 .03 r
.73148 .87893 m
.73166 .87451 L
s
.73166 .87451 m
.7337 .82524 L
s
.75151 .54351 m .74928 .52597 L .74962 .53165 L .815 .614 .058 r
F
.72633 .54397 m .75151 .54351 L .74962 .53165 L .673 .757 .914 r
F
.75185 .54919 m .75151 .54351 L .74962 .53165 L .815 .614 .058 r
F
0 g
.74995 .54923 m
.75125 .54446 L
s
.21888 .66064 m .21106 .67371 L .2247 .66501 L .683 .77 .917 r
F
.21888 .66064 m .20234 .66716 L .21106 .67371 L F
0 g
.21106 .67371 m
.22257 .67848 L
s
.7458 .88325 m .74954 .88445 L .75001 .88375 L .692 .759 .904 r
F
.58632 .29628 m .58648 .35567 L .58643 .35484 L .777 .62 .057 r
F
.58686 .29524 m .58632 .29628 L .58643 .35484 L 0 0 .377 r
F
.39029 .42759 m .38594 .42459 L .38491 .42546 L .675 .735 .895 r
F
.32226 .87837 m .32016 .87607 L .31832 .87705 L .692 .759 .903 r
F
.32333 .87803 m .32016 .87607 L .32226 .87837 L F
.33026 .41364 m .30001 .40678 L .29626 .4224 L .654 .726 .902 r
F
.29956 .41407 m .29626 .4224 L .2958 .42969 L 0 0 .129 r
F
0 g
.29679 .42557 m
.2975 .42978 L
s
.29956 .41407 m .30001 .40678 L .29626 .4224 L 0 0 .129 r
F
.33026 .41364 m .29626 .4224 L .32774 .42405 L .654 .726 .902 r
F
.33491 .53301 m .34996 .53435 L .35026 .54003 L .859 .596 .54 r
F
.33491 .53301 m .33461 .52733 L .34996 .53435 L F
0 g
.34996 .53435 m
.3547 .53547 L
s
.49438 .67686 m .48145 .66957 L .47523 .67457 L .683 .77 .917 r
F
.49837 .67486 m .48145 .66957 L .49438 .67686 L F
.36373 .53221 m .3686 .54998 L .37576 .53505 L .673 .757 .914 r
F
.36373 .53221 m .35056 .54571 L .3686 .54998 L F
0 g
.3686 .54998 m
.38809 .55119 L
s
.42584 .53866 m .44152 .52539 L .44183 .53107 L .515 .329 .567 r
F
.42615 .54434 m .42584 .53866 L .44183 .53107 L F
.41384 .52561 m .42584 .53866 L .44183 .53107 L .673 .757 .914 r
F
.40155 .52889 m .42584 .53866 L .41384 .52561 L F
0 g
.41754 .54088 m
.42584 .53866 L
s
.51223 .6684 m .50793 .65696 L .50737 .66827 L .683 .77 .917 r
F
.51223 .6684 m .51765 .65721 L .50793 .65696 L F
.36049 .42049 m .32774 .42405 L .35923 .4257 L .654 .726 .902 r
F
.36049 .42049 m .33026 .41364 L .32774 .42405 L F
.32559 .87791 m .32456 .87508 L .32447 .87788 L .692 .759 .903 r
F
.32559 .87791 m .32682 .87514 L .32456 .87508 L F
.73702 .88373 m .73297 .88613 L .73725 .88517 L .692 .759 .904 r
F
.73702 .88373 m .73263 .88397 L .73297 .88613 L F
0 g
.73297 .88613 m
.73418 .88809 L
s
.74155 .87766 m .73689 .87787 L .74108 .87836 L .692 .759 .904 r
F
.74993 .88081 m .75409 .87914 L .74981 .88009 L F
0 g
.74945 .88247 m
.74957 .88167 L
s
.75378 .87695 m .75683 .87404 L .75297 .87564 L .692 .759 .904 r
F
.75378 .87695 m .75804 .87599 L .75683 .87404 L F
.32065 .88457 m .31608 .88555 L .32047 .88531 L .692 .759 .903 r
F
.33743 .87999 m .33594 .87583 L .33619 .87803 L .976 .674 .311 r
F
.33769 .88219 m .33743 .87999 L .33619 .87803 L F
0 g
.33743 .87999 m
.33781 .88215 L
s
.32713 .88163 m
.3282 .88245 L
s
.3282 .88245 m
.3282 .88245 L
s
.48059 .66049 m .45844 .6607 L .47441 .66547 L .683 .77 .917 r
F
.32333 .87803 m .32229 .87539 L .32016 .87607 L .692 .759 .903 r
F
.32447 .87788 m .32229 .87539 L .32333 .87803 L F
.35307 .51604 m .35016 .53415 L .36325 .52071 L .673 .757 .914 r
F
.35307 .51604 m .33488 .52716 L .35016 .53415 L F
.21716 .54465 m .19982 .53419 L .18752 .54388 L F
.22772 .53962 m .19982 .53419 L .21716 .54465 L F
0 g
.74204 .88153 m
.74209 .88234 L
s
.39033 .41771 m .38723 .41379 L .3887 .41784 L .675 .735 .895 r
F
.39033 .41771 m .39049 .41352 L .38723 .41379 L F
.39039 .42054 m .39054 .41633 L .38727 .4166 L F
.39044 .42338 m .38733 .41945 L .38881 .42352 L F
.39044 .42338 m .3906 .41918 L .38733 .41945 L F
.39049 .41352 m .38576 .40974 L .38723 .41379 L F
.39049 .41352 m .39064 .40934 L .38576 .40974 L F
.39054 .41633 m .38579 .41253 L .38727 .4166 L F
.39054 .41633 m .3907 .41212 L .38579 .41253 L F
.3906 .41918 m .39076 .41497 L .38584 .41538 L F
.3907 .41212 m .38573 .40968 L .38579 .41253 L .665 .424 .546 r
F
.3907 .41212 m .39065 .40928 L .38573 .40968 L F
.39076 .41497 m .38579 .41253 L .38584 .41538 L F
.39076 .41497 m .3907 .41212 L .38579 .41253 L F
.39072 .42734 m .39148 .40701 L .3833 .40727 L .654 .726 .902 r
F
0 g
.38705 .43069 m
.38706 .42631 L
s
.32164 .88233 m
.32164 .88233 L
s
.32164 .88233 m
.32276 .88155 L
s
.32447 .87788 m .32456 .87508 L .32229 .87539 L .692 .759 .903 r
F
.32086 .88167 m .3171 .88047 L .31618 .88188 L F
.32158 .88105 m .3171 .88047 L .32086 .88167 L F
.42221 .42899 m .45196 .42 L .42133 .42367 L .654 .726 .902 r
F
.42221 .42899 m .45369 .43064 L .45196 .42 L F
.74912 .87725 m .75164 .87456 L .74845 .87671 L .692 .759 .904 r
F
.74912 .87725 m .75297 .87564 L .75164 .87456 L F
.31689 .87829 m .31315 .8771 L .31177 .87919 L .692 .759 .903 r
F
.7004 .55409 m .72667 .54965 L .70148 .55011 L .673 .758 .914 r
F
.31335 .87928 m .31171 .87919 L .31196 .88138 L .184 .094 .512 r
F
.31335 .87928 m .31309 .87708 L .31171 .87919 L F
0 g
.31118 .88139 m
.31171 .87919 L
s
.32914 .88411 m .33258 .88184 L .32873 .88346 L .692 .759 .903 r
F
.32914 .88411 m .33341 .88315 L .33258 .88184 L F
.31643 .88408 m .31168 .88579 L .31608 .88555 L F
.32065 .88457 m .31643 .88408 L .31608 .88555 L F
.7458 .88325 m .74153 .88421 L .74193 .88487 L .692 .759 .904 r
F
.45369 .43064 m .4826 .41633 L .45196 .42 L .654 .726 .902 r
F
.45369 .43064 m .48518 .43228 L .4826 .41633 L F
.3278 .88071 m .32919 .87776 L .3269 .88032 L .692 .759 .903 r
F
.3278 .88071 m .33098 .87856 L .32919 .87776 L F
.48518 .43228 m .48304 .40904 L .4826 .41633 L .92 .74 .251 r
F
.48475 .43957 m .48518 .43228 L .4826 .41633 L F
0 g
.48339 .4395 m
.48438 .43554 L
s
.28855 .54893 m .29143 .53074 L .2783 .54425 L .673 .757 .914 r
F
.28855 .54893 m .3068 .53777 L .29143 .53074 L F
.50248 .66891 m .49813 .65824 L .48893 .66099 L .683 .77 .917 r
F
.50737 .66827 m .49813 .65824 L .50248 .66891 L F
.74141 .88349 m .73725 .88517 L .74153 .88421 L .692 .759 .904 r
F
.74141 .88349 m .73702 .88373 L .73725 .88517 L F
.3171 .88047 m .31196 .88138 L .31618 .88188 L .692 .759 .903 r
F
.75001 .88375 m .75459 .88277 L .7502 .88301 L .692 .759 .904 r
F
.7458 .88325 m .75001 .88375 L .7502 .88301 L F
.74133 .88056 m .73675 .88153 L .74114 .88129 L F
.75837 .87818 m .7581 .87598 L .75689 .87401 L .973 .67 .295 r
F
0 g
.7581 .87598 m
.75844 .87814 L
s
.31643 .88408 m .31221 .88358 L .31168 .88579 L .692 .759 .903 r
F
0 g
.31168 .88579 m
.31206 .88795 L
s
.24217 .65789 m .24137 .66997 L .24668 .65878 L .683 .77 .917 r
F
.24217 .65789 m .23237 .66819 L .24137 .66997 L F
.31832 .87705 m .31315 .8771 L .31689 .87829 L .692 .759 .903 r
F
.29982 .6574 m .30533 .64434 L .30581 .64891 L .195 .11 .525 r
F
.3003 .66198 m .29982 .6574 L .30581 .64891 L F
.28373 .65261 m .29982 .6574 L .30581 .64891 L .683 .77 .917 r
F
.27754 .65761 m .29982 .6574 L .28373 .65261 L F
0 g
.29409 .66203 m
.29982 .6574 L
s
.50737 .66827 m .50793 .65696 L .49813 .65824 L .683 .77 .917 r
F
.74155 .87766 m .73783 .87647 L .73689 .87787 L .692 .759 .904 r
F
.74227 .87705 m .73783 .87647 L .74155 .87766 L F
.51721 .67386 m .51814 .66179 L .51272 .67297 L .683 .77 .917 r
F
.51721 .67386 m .52712 .66357 L .51814 .66179 L F
.59341 .29536 m .59247 .35309 L .59353 .35393 L .911 .629 .497 r
F
.59341 .29536 m .59235 .29453 L .59247 .35309 L F
0 g
.59341 .29536 m
.59385 .29642 L
s
.59341 .29536 m
.59341 .29536 L
s
.65163 .5357 m .62551 .54011 L .65057 .53966 L .673 .757 .914 r
F
.26399 .6457 m .27694 .65296 L .28309 .64798 L .683 .77 .917 r
F
.75898 .88253 m .75837 .87818 L .75864 .88037 L .741 .528 0 r
F
.75459 .88277 m .75898 .88253 L .75864 .88037 L .692 .759 .904 r
F
0 g
.75842 .88474 m
.75898 .88253 L
s
.32158 .88105 m .31854 .87923 L .3171 .88047 L .692 .759 .903 r
F
.32251 .88056 m .31854 .87923 L .32158 .88105 L F
.72633 .54397 m .74962 .53165 L .72506 .53607 L .673 .757 .914 r
F
.70115 .54443 m .72633 .54397 L .72506 .53607 L F
.32111 .88387 m .31643 .88408 L .32065 .88457 L .692 .759 .903 r
F
.74981 .88009 m .75328 .87783 L .74941 .87944 L .692 .759 .904 r
F
.74981 .88009 m .75409 .87914 L .75328 .87783 L F
.31843 .54708 m .3065 .53209 L .3068 .53777 L .931 .657 .497 r
F
.31873 .55276 m .31843 .54708 L .3068 .53777 L F
0 g
.31843 .54708 m
.32552 .55802 L
s
.33341 .88315 m .33644 .88023 L .33258 .88184 L .692 .759 .903 r
F
.33341 .88315 m .33769 .88219 L .33644 .88023 L F
.73712 .88006 m .73236 .88177 L .73675 .88153 L .692 .759 .904 r
F
.74133 .88056 m .73712 .88006 L .73675 .88153 L F
.45918 .66978 m .45265 .67369 L .45314 .67827 L .2 .114 .528 r
F
.47474 .67 m .45869 .66521 L .45265 .67369 L .683 .77 .917 r
F
.45918 .66978 m .45869 .66521 L .45265 .67369 L .2 .114 .528 r
F
0 g
.45032 .68257 m
.45265 .67369 L
s
.32605 .88126 m
.32713 .88163 L
s
.58798 .29445 m .58686 .29524 L .58697 .35381 L .4 .211 .506 r
F
.58686 .29524 m .58643 .35484 L .58697 .35381 L 0 0 .377 r
F
0 g
.58632 .29628 m
.58686 .29524 L
s
.58686 .29524 m
.58686 .29524 L
s
.74845 .87671 m .74988 .87377 L .74757 .87631 L .692 .759 .904 r
F
.74845 .87671 m .75164 .87456 L .74988 .87377 L F
0 g
.32276 .88155 m
.32387 .88122 L
s
.3269 .88032 m .32709 .87731 L .32585 .88009 L .692 .759 .903 r
F
.3269 .88032 m .32919 .87776 L .32709 .87731 L F
.33619 .87803 m .33594 .87583 L .3339 .8742 L .933 .634 .451 r
F
.127 .923 .03 r
.28535 .81075 m
.29166 1.2747 L
s
.29166 1.2747 m
.34928 5.51274 L
s
0 g
.33594 .87583 m
.33718 .8778 L
s
.33233 .87964 m .33416 .8764 L .33098 .87856 L .692 .759 .903 r
F
.33233 .87964 m .33619 .87803 L .33416 .8764 L F
.33069 .87638 m .33118 .87305 L .32891 .87559 L F
.33069 .87638 m .33386 .87423 L .33118 .87305 L F
.32873 .88346 m .33123 .88075 L .32805 .88291 L F
.32873 .88346 m .33258 .88184 L .33123 .88075 L F
.73783 .87647 m .73271 .87737 L .73689 .87787 L .692 .759 .904 r
F
.75459 .88277 m .75864 .88037 L .75436 .88133 L F
.7502 .88301 m .75459 .88277 L .75436 .88133 L F
.7458 .88325 m .74141 .88349 L .74153 .88421 L F
.73318 .88176 m .73236 .88177 L .73263 .88397 L 0 0 .393 r
F
0 g
.73267 .88378 m
.7327 .88393 L
s
.73712 .88006 m .73291 .87956 L .73236 .88177 L .692 .759 .904 r
F
.73318 .88176 m .73291 .87956 L .73236 .88177 L 0 0 .393 r
F
.50745 .40136 m .52236 .4075 L .52194 .41478 L .928 .67 .525 r
F
.50745 .40136 m .50788 .39407 L .52236 .4075 L F
0 g
.52236 .4075 m
.52855 .41096 L
s
.5405 .67112 m .54847 .65804 L .53474 .66675 L .683 .77 .917 r
F
.5405 .67112 m .5571 .6646 L .54847 .65804 L F
.32251 .88056 m .32039 .87824 L .31854 .87923 L .692 .759 .903 r
F
.32358 .88022 m .32039 .87824 L .32251 .88056 L F
0 g
.32496 .88113 m
.32605 .88126 L
s
.32387 .88122 m
.32496 .88113 L
s
.74227 .87705 m .73928 .87524 L .73783 .87647 L .692 .759 .904 r
F
.7432 .87655 m .73928 .87524 L .74227 .87705 L F
.3644 .40852 m .33102 .40642 L .3611 .41324 L .654 .726 .902 r
F
.32585 .88009 m .32482 .87725 L .32472 .88006 L .692 .759 .903 r
F
.32585 .88009 m .32709 .87731 L .32482 .87725 L F
.7502 .88301 m .75436 .88133 L .75008 .88229 L .692 .759 .904 r
F
.7458 .88325 m .7502 .88301 L .75008 .88229 L F
.7418 .87986 m .73712 .88006 L .74133 .88056 L F
.75409 .87914 m .75716 .87621 L .75328 .87783 L F
.75409 .87914 m .75837 .87818 L .75716 .87621 L F
.33769 .88219 m .33619 .87803 L .33644 .88023 L .976 .674 .311 r
F
.127 .923 .03 r
.33665 .85428 m
.33727 .88487 L
s
0 g
.33769 .88219 m
.33806 .88435 L
s
.74528 .43326 m .72659 .41526 L .72619 .42254 L .859 .601 .547 r
F
.74489 .44054 m .74528 .43326 L .72619 .42254 L F
0 g
.74528 .43326 m
.75966 .44666 L
s
.53587 .38523 m .52271 .4073 L .54547 .39415 L .654 .726 .902 r
F
.53587 .38523 m .50829 .39394 L .52271 .4073 L F
.66159 .44005 m .65436 .41998 L .63128 .42489 L F
.67796 .43951 m .65436 .41998 L .66159 .44005 L F
.23787 .65173 m .22423 .66043 L .2319 .66362 L .683 .77 .917 r
F
.74757 .87631 m .7478 .87333 L .74653 .87609 L .692 .759 .904 r
F
.74757 .87631 m .74988 .87377 L .7478 .87333 L F
.32358 .88022 m .32253 .87756 L .32039 .87824 L .692 .759 .903 r
F
.32472 .88006 m .32253 .87756 L .32358 .88022 L F
.42162 .41641 m .44622 .40266 L .41868 .41136 L .654 .726 .902 r
F
.42162 .41641 m .45209 .41275 L .44622 .40266 L F
.32472 .88006 m .32482 .87725 L .32253 .87756 L .692 .759 .903 r
F
.69419 .44175 m .67893 .41918 L .67796 .43951 L .654 .726 .902 r
F
.69419 .44175 m .70329 .42254 L .67893 .41918 L F
0 g
.67054 .40342 m
.67157 .40264 L
s
.66849 .40498 m
.67054 .40342 L
s
.32111 .88387 m .31736 .88267 L .31643 .88408 L .692 .759 .903 r
F
.32183 .88325 m .31736 .88267 L .32111 .88387 L F
.75297 .87564 m .75483 .87241 L .75164 .87456 L .692 .759 .904 r
F
.75297 .87564 m .75683 .87404 L .75483 .87241 L F
.74941 .87944 m .75195 .87674 L .74874 .8789 L F
.74941 .87944 m .75328 .87783 L .75195 .87674 L F
.59235 .29453 m .59139 .35271 L .59247 .35309 L .81 .54 .53 r
F
.59235 .29453 m .59128 .29415 L .59139 .35271 L F
0 g
.59235 .29453 m
.59341 .29536 L
s
.3136 .88147 m .31196 .88138 L .31221 .88358 L .184 .094 .512 r
F
.3171 .88047 m .31335 .87928 L .31196 .88138 L .692 .759 .903 r
F
.3136 .88147 m .31335 .87928 L .31196 .88138 L .184 .094 .512 r
F
0 g
.31143 .88359 m
.31196 .88138 L
s
.7458 .88325 m .7416 .88276 L .74141 .88349 L .692 .759 .904 r
F
.7458 .88325 m .74207 .88205 L .7416 .88276 L F
.7458 .88325 m .7428 .88143 L .74207 .88205 L F
0 g
.74204 .88153 m
.74258 .88051 L
s
.7458 .88325 m .74373 .88094 L .7428 .88143 L .692 .759 .904 r
F
.7458 .88325 m .7448 .8806 L .74373 .88094 L F
.7458 .88325 m .74595 .88044 L .7448 .8806 L F
.7458 .88325 m .74708 .88047 L .74595 .88044 L F
.7458 .88325 m .74812 .8807 L .74708 .88047 L F
.7458 .88325 m .74901 .88109 L .74812 .8807 L F
.7458 .88325 m .74968 .88164 L .74901 .88109 L F
0 g
.74913 .88063 m
.7495 .88149 L
s
.7458 .88325 m .75008 .88229 L .74968 .88164 L .692 .759 .904 r
F
.26103 .6569 m .27007 .66619 L .27802 .66219 L .683 .77 .917 r
F
.25644 .65827 m .27007 .66619 L .26103 .6569 L F
.58798 .29445 m .58697 .35381 L .5881 .35301 L .4 .211 .506 r
F
.58909 .29411 m .58798 .29445 L .5881 .35301 L .567 .342 .533 r
F
0 g
.58686 .29524 m
.58798 .29445 L
s
.32805 .88291 m .32944 .87996 L .32715 .88251 L .692 .759 .903 r
F
.32805 .88291 m .33123 .88075 L .32944 .87996 L F
.7432 .87655 m .74114 .87425 L .73928 .87524 L .692 .759 .904 r
F
.74427 .87621 m .74114 .87425 L .7432 .87655 L F
.62763 .53219 m .60045 .54057 L .62551 .54011 L .673 .757 .914 r
F
.65163 .5357 m .62763 .53219 L .62551 .54011 L F
.31832 .87705 m .3153 .87524 L .31315 .8771 L .692 .759 .903 r
F
.32016 .87607 m .3153 .87524 L .31832 .87705 L F
.70115 .54443 m .72506 .53607 L .70051 .54048 L .673 .757 .914 r
F
.74653 .87609 m .74554 .87326 L .7454 .87606 L .692 .759 .904 r
F
.74653 .87609 m .7478 .87333 L .74554 .87326 L F
.49837 .67486 m .48943 .66556 L .48145 .66957 L .683 .77 .917 r
F
.50297 .67349 m .48943 .66556 L .49837 .67486 L F
.31736 .88267 m .31221 .88358 L .31643 .88408 L .692 .759 .903 r
F
.7416 .88276 m .73702 .88373 L .74141 .88349 L .692 .759 .904 r
F
.75837 .87818 m .75689 .87401 L .75716 .87621 L .973 .67 .295 r
F
.75864 .88037 m .75837 .87818 L .75716 .87621 L F
0 g
.75837 .87818 m
.75871 .88034 L
s
.74808 .87981 m
.74913 .88063 L
s
.74913 .88063 m
.74913 .88063 L
s
.31854 .87923 m .31335 .87928 L .3171 .88047 L .692 .759 .903 r
F
.74427 .87621 m .74327 .87357 L .74114 .87425 L .692 .759 .904 r
F
.7454 .87606 m .74327 .87357 L .74427 .87621 L F
.59128 .29415 m .5903 .35258 L .59139 .35271 L .734 .476 .539 r
F
.59128 .29415 m .59019 .29402 L .5903 .35258 L F
0 g
.59128 .29415 m
.59235 .29453 L
s
.74258 .88051 m
.74258 .88051 L
s
.74258 .88051 m
.74371 .87973 L
s
.7454 .87606 m .74554 .87326 L .74327 .87357 L .692 .759 .904 r
F
.58909 .29411 m .5881 .35301 L .5892 .35267 L .567 .342 .533 r
F
.59019 .29402 m .58909 .29411 L .5892 .35267 L .66 .415 .539 r
F
0 g
.58798 .29445 m
.58909 .29411 L
s
.7418 .87986 m .73807 .87866 L .73712 .88006 L .692 .759 .904 r
F
.74253 .87923 m .73807 .87866 L .7418 .87986 L F
.73783 .87647 m .73412 .87528 L .73271 .87737 L F
.59019 .29402 m .5892 .35267 L .5903 .35258 L .66 .415 .539 r
F
0 g
.59019 .29402 m
.59128 .29415 L
s
.58909 .29411 m
.59019 .29402 L
s
.32183 .88325 m .31879 .88143 L .31736 .88267 L .692 .759 .903 r
F
.32276 .88275 m .31879 .88143 L .32183 .88325 L F
.73433 .87746 m .73265 .87737 L .73291 .87956 L .197 .105 .519 r
F
.73433 .87746 m .73406 .87526 L .73265 .87737 L F
0 g
.73209 .87958 m
.73265 .87737 L
s
.32891 .87559 m .32805 .87238 L .32682 .87514 L .692 .759 .903 r
F
.32891 .87559 m .33118 .87305 L .32805 .87238 L F
.75008 .88229 m .75355 .88002 L .74968 .88164 L .692 .759 .904 r
F
.75008 .88229 m .75436 .88133 L .75355 .88002 L F
.73739 .88226 m .73263 .88397 L .73702 .88373 L F
.7416 .88276 m .73739 .88226 L .73702 .88373 L F
.38594 .42459 m .37952 .42332 L .38491 .42546 L .675 .735 .895 r
F
.5566 .66002 m .5561 .65545 L .54748 .64889 L .933 .647 .475 r
F
.127 .923 .03 r
.47577 4.73788 m
.52764 1.96195 L
s
0 g
.5561 .65545 m
.56133 .66333 L
s
.127 .923 .03 r
.50423 7.65475 m
.54077 2.45795 L
s
.74874 .8789 m .75017 .87594 L .74785 .8785 L .692 .759 .904 r
F
.74874 .8789 m .75195 .87674 L .75017 .87594 L F
.53362 .65768 m .5359 .64427 L .52603 .65452 L .683 .77 .917 r
F
.53362 .65768 m .54727 .64902 L .5359 .64427 L F
.32715 .88251 m .32734 .87951 L .3261 .88229 L .692 .759 .903 r
F
.32715 .88251 m .32944 .87996 L .32734 .87951 L F
.33619 .87803 m .3339 .8742 L .33416 .8764 L .933 .634 .451 r
F
.33644 .88023 m .33619 .87803 L .33416 .8764 L F
0 g
.33619 .87803 m
.33743 .87999 L
s
.33258 .88184 m .33441 .8786 L .33123 .88075 L .692 .759 .903 r
F
.33258 .88184 m .33644 .88023 L .33441 .8786 L F
.51272 .67297 m .50842 .66153 L .50787 .67284 L .683 .77 .917 r
F
.51272 .67297 m .51814 .66179 L .50842 .66153 L F
.33098 .87856 m .33147 .8752 L .32919 .87776 L .692 .759 .903 r
F
.33098 .87856 m .33416 .8764 L .33147 .8752 L F
.73807 .87866 m .73291 .87956 L .73712 .88006 L .692 .759 .904 r
F
.3155 .87741 m .31309 .87708 L .31335 .87928 L .39 .238 .552 r
F
.3155 .87741 m .31525 .87522 L .31309 .87708 L F
0 g
.31171 .87919 m
.31309 .87708 L
s
.73739 .88226 m .73318 .88176 L .73263 .88397 L .692 .759 .904 r
F
0 g
.73263 .88397 m
.73297 .88613 L
s
.73928 .87524 m .73412 .87528 L .73783 .87647 L .692 .759 .904 r
F
.32276 .88275 m .32065 .88044 L .31879 .88143 L .692 .759 .903 r
F
.32383 .88242 m .32065 .88044 L .32276 .88275 L F
.48095 .665 m .45869 .66521 L .47474 .67 L .683 .77 .917 r
F
.74253 .87923 m .73952 .87741 L .73807 .87866 L .692 .759 .904 r
F
.74346 .87874 m .73952 .87741 L .74253 .87923 L F
.3261 .88229 m .32507 .87944 L .32497 .88226 L .692 .759 .903 r
F
.3261 .88229 m .32734 .87951 L .32507 .87944 L F
.74207 .88205 m .73739 .88226 L .7416 .88276 L .692 .759 .904 r
F
.32016 .87607 m .31806 .87376 L .3153 .87524 L .692 .759 .903 r
F
.32229 .87539 m .31806 .87376 L .32016 .87607 L F
.75436 .88133 m .75743 .87841 L .75355 .88002 L .692 .759 .904 r
F
.75436 .88133 m .75864 .88037 L .75743 .87841 L F
0 g
.74701 .87944 m
.74808 .87981 L
s
.32383 .88242 m .32279 .87976 L .32065 .88044 L .692 .759 .903 r
F
.32497 .88226 m .32279 .87976 L .32383 .88242 L F
0 g
.74371 .87973 m
.74482 .8794 L
s
.74785 .8785 m .74808 .8755 L .74681 .87828 L .692 .759 .904 r
F
.74785 .8785 m .75017 .87594 L .74808 .8755 L F
.62763 .53219 m .60362 .52867 L .60045 .54057 L .673 .757 .914 r
F
.60359 .5343 m .60007 .54058 L .6004 .54626 L 0 0 .327 r
F
0 g
.60077 .54484 m
.60101 .54625 L
s
.60359 .5343 m .60326 .52862 L .60007 .54058 L 0 0 .327 r
F
.32497 .88226 m .32507 .87944 L .32279 .87976 L .692 .759 .903 r
F
.67596 .54488 m .67025 .53019 L .66409 .53183 L .673 .757 .914 r
F
.75716 .87621 m .75689 .87401 L .75488 .87238 L .935 .633 .445 r
F
0 g
.75689 .87401 m
.7581 .87598 L
s
.32682 .87514 m .32466 .87228 L .32456 .87508 L .692 .759 .903 r
F
.32682 .87514 m .32805 .87238 L .32466 .87228 L F
.75185 .54919 m .74962 .53165 L .74996 .53734 L .815 .614 .058 r
F
.72667 .54965 m .75185 .54919 L .74996 .53734 L .673 .758 .914 r
F
0 g
.74859 .56113 m
.75185 .54919 L
s
.75328 .87783 m .75515 .87458 L .75195 .87674 L .692 .759 .904 r
F
.75328 .87783 m .75716 .87621 L .75515 .87458 L F
.75164 .87456 m .75219 .87123 L .74988 .87377 L F
.75164 .87456 m .75483 .87241 L .75219 .87123 L F
.74968 .88164 m .75222 .87894 L .74901 .88109 L F
.74968 .88164 m .75355 .88002 L .75222 .87894 L F
.31736 .88267 m .3136 .88147 L .31221 .88358 L .692 .759 .903 r
F
0 g
.31168 .88579 m
.31221 .88358 L
s
0 0 0 r
2.5 Mabswid
.1961 .56 Mdot
.50297 .67349 m .49863 .66282 L .48943 .66556 L .683 .77 .917 r
F
.50787 .67284 m .49863 .66282 L .50297 .67349 L F
.67796 .43951 m .67893 .41918 L .65436 .41998 L .654 .726 .902 r
F
.33521 .53869 m .35026 .54003 L .35056 .54571 L .859 .596 .54 r
F
.33521 .53869 m .33491 .53301 L .35026 .54003 L F
.35319 .52183 m .35026 .54003 L .36343 .52652 L .673 .757 .914 r
F
.35319 .52183 m .33491 .53301 L .35026 .54003 L F
0 g
.5 Mabswid
.35026 .54003 m
.35501 .54115 L
s
.42615 .54434 m .44183 .53107 L .44214 .53675 L .515 .329 .567 r
F
.41415 .53129 m .42615 .54434 L .44214 .53675 L .673 .757 .914 r
F
.40185 .53458 m .42615 .54434 L .41415 .53129 L F
0 g
.40772 .54927 m
.42615 .54434 L
s
.19985 .53971 m .1872 .54377 L .18748 .54946 L .383 .23 .546 r
F
.19985 .53971 m .19956 .53403 L .1872 .54377 L F
0 g
.17925 .555 m
.1872 .54377 L
s
.33416 .8764 m .3339 .8742 L .33122 .87301 L .86 .577 .508 r
F
.127 .923 .03 r
.24824 2.75186 m
.3927 8.82489 L
s
0 g
.3339 .8742 m
.33594 .87583 L
s
.38594 .42459 m .38159 .42159 L .37952 .42332 L .675 .735 .895 r
F
.38727 .42393 m .38159 .42159 L .38594 .42459 L F
.3003 .66198 m .30581 .64891 L .30628 .65349 L .195 .11 .525 r
F
.2842 .65718 m .3003 .66198 L .30628 .65349 L .683 .77 .917 r
F
.27802 .66219 m .3003 .66198 L .2842 .65718 L F
0 g
.29102 .66948 m
.3003 .66198 L
s
.74346 .87874 m .74139 .87642 L .73952 .87741 L .692 .759 .904 r
F
.74453 .8784 m .74139 .87642 L .74346 .87874 L F
0 g
.74592 .87931 m
.74701 .87944 L
s
.26453 .65032 m .27754 .65761 L .28373 .65261 L .683 .77 .917 r
F
.50787 .67284 m .50842 .66153 L .49863 .66282 L F
0 g
.74482 .8794 m
.74592 .87931 L
s
.32229 .87539 m .32126 .87275 L .31806 .87376 L .692 .759 .903 r
F
.32456 .87508 m .32126 .87275 L .32229 .87539 L F
.31854 .87923 m .3155 .87741 L .31335 .87928 L F
.32039 .87824 m .3155 .87741 L .31854 .87923 L F
.74681 .87828 m .74582 .87543 L .74568 .87824 L .692 .759 .904 r
F
.74681 .87828 m .74808 .8755 L .74582 .87543 L F
.75864 .88037 m .75716 .87621 L .75743 .87841 L .973 .67 .295 r
F
0 g
.75864 .88037 m
.75898 .88253 L
s
.32456 .87508 m .32466 .87228 L .32126 .87275 L .692 .759 .903 r
F
.47523 .67457 m .45918 .66978 L .45314 .67827 L .683 .77 .917 r
F
0 g
.4508 .68714 m
.45314 .67827 L
s
.31879 .88143 m .3136 .88147 L .31736 .88267 L .692 .759 .903 r
F
.74453 .8784 m .74353 .87574 L .74139 .87642 L .692 .759 .904 r
F
.74568 .87824 m .74353 .87574 L .74453 .8784 L F
.74568 .87824 m .74582 .87543 L .74353 .87574 L F
.21727 .55023 m .19985 .53971 L .18748 .54946 L .673 .757 .914 r
F
.22789 .54517 m .19985 .53971 L .21727 .55023 L F
.74207 .88205 m .73834 .88085 L .73739 .88226 L .692 .759 .904 r
F
.7428 .88143 m .73834 .88085 L .74207 .88205 L F
.27787 .53871 m .27297 .52102 L .2659 .53588 L .673 .757 .914 r
F
.27787 .53871 m .29094 .52526 L .27297 .52102 L F
.70005 .53482 m .71988 .52316 L .69775 .53118 L F
.70005 .53482 m .72448 .53043 L .71988 .52316 L F
.7346 .87966 m .73291 .87956 L .73318 .88176 L .197 .105 .519 r
F
.73807 .87866 m .73433 .87746 L .73291 .87956 L .692 .759 .904 r
F
.7346 .87966 m .73433 .87746 L .73291 .87956 L .197 .105 .519 r
F
0 g
.73236 .88177 m
.73291 .87956 L
s
.32919 .87776 m .32832 .87453 L .32709 .87731 L .692 .759 .903 r
F
.32919 .87776 m .33147 .8752 L .32832 .87453 L F
.28884 .55462 m .29173 .53643 L .2786 .54994 L .673 .757 .914 r
F
.28884 .55462 m .3071 .54345 L .29173 .53643 L F
.74901 .88109 m .75044 .87814 L .74812 .8807 L .692 .759 .904 r
F
.74901 .88109 m .75222 .87894 L .75044 .87814 L F
.33644 .88023 m .33416 .8764 L .33441 .8786 L .933 .634 .451 r
F
0 g
.33644 .88023 m
.33769 .88219 L
s
.73928 .87524 m .73629 .87342 L .73412 .87528 L .692 .759 .904 r
F
.74114 .87425 m .73629 .87342 L .73928 .87524 L F
.38727 .42393 m .38425 .42027 L .38159 .42159 L .675 .735 .895 r
F
.38881 .42352 m .38425 .42027 L .38727 .42393 L F
.33123 .88075 m .33172 .8774 L .32944 .87996 L .692 .759 .903 r
F
.33123 .88075 m .33441 .8786 L .33172 .8774 L F
.73834 .88085 m .73318 .88176 L .73739 .88226 L .692 .759 .904 r
F
0 0 0 r
2.5 Mabswid
.66652 .43818 Mdot
.31575 .87961 m .31335 .87928 L .3136 .88147 L .39 .238 .552 r
F
.31575 .87961 m .3155 .87741 L .31335 .87928 L F
0 g
.5 Mabswid
.31196 .88138 m
.31335 .87928 L
s
.73952 .87741 m .73433 .87746 L .73807 .87866 L .692 .759 .904 r
F
.65185 .54136 m .62559 .5458 L .65077 .54534 L .673 .757 .914 r
F
.23834 .6563 m .23237 .66819 L .24217 .65789 L .683 .77 .917 r
F
.23834 .6563 m .2247 .66501 L .23237 .66819 L F
.72667 .54965 m .74996 .53734 L .7254 .54175 L .673 .758 .914 r
F
.70148 .55011 m .72667 .54965 L .7254 .54175 L F
.31873 .55276 m .3068 .53777 L .3071 .54345 L .931 .657 .497 r
F
0 g
.31873 .55276 m
.32582 .5637 L
s
.23457 .64493 m .22389 .65577 L .23746 .64711 L .683 .77 .917 r
F
.23457 .64493 m .21811 .65142 L .22389 .65577 L F
.19652 .6547 m .2014 .65801 L .20187 .66259 L .982 .691 .347 r
F
.127 .923 .03 r
.20759 1.04293 m
.24824 2.75186 L
s
.19652 .6547 m .19605 .65012 L .2014 .65801 L .982 .691 .347 r
F
0 g
.2014 .65801 m
.20556 .66113 L
s
.7428 .88143 m .73979 .87961 L .73834 .88085 L .692 .759 .904 r
F
.74373 .88094 m .73979 .87961 L .7428 .88143 L F
.74988 .87377 m .74907 .87056 L .7478 .87333 L F
.74988 .87377 m .75219 .87123 L .74907 .87056 L F
.32039 .87824 m .31828 .87592 L .3155 .87741 L .692 .759 .903 r
F
.32253 .87756 m .31828 .87592 L .32039 .87824 L F
.21456 .64619 m .20165 .65791 L .21811 .65142 L .683 .77 .917 r
F
.21456 .64619 m .19633 .65006 L .20165 .65791 L F
.127 .923 .03 r
.19478 .66949 m
.19753 .74319 L
s
.19266 .61265 m
.19478 .66949 L
s
.74812 .8807 m .74835 .87769 L .74708 .88047 L .692 .759 .904 r
F
.74812 .8807 m .75044 .87814 L .74835 .87769 L F
.75716 .87621 m .75488 .87238 L .75515 .87458 L .935 .633 .445 r
F
.75743 .87841 m .75716 .87621 L .75515 .87458 L F
0 g
.75716 .87621 m
.75837 .87818 L
s
.31828 .87592 m .31525 .87522 L .3155 .87741 L .513 .326 .563 r
F
.31828 .87592 m .31803 .87373 L .31525 .87522 L F
0 g
.31309 .87708 m
.31525 .87522 L
s
.75355 .88002 m .75542 .87678 L .75222 .87894 L .692 .759 .904 r
F
.75355 .88002 m .75743 .87841 L .75542 .87678 L F
.32709 .87731 m .32492 .87443 L .32482 .87725 L .692 .759 .903 r
F
.32709 .87731 m .32832 .87453 L .32492 .87443 L F
.59018 .38807 m .58928 .40832 L .60556 .40779 L .654 .726 .902 r
F
.58209 .38696 m .58928 .40832 L .59018 .38807 L F
.58209 .38696 m .57312 .4061 L .58928 .40832 L F
.75195 .87674 m .75249 .87339 L .75017 .87594 L .692 .759 .904 r
F
.75195 .87674 m .75515 .87458 L .75249 .87339 L F
.73651 .87559 m .73406 .87526 L .73433 .87746 L .396 .244 .555 r
F
.73651 .87559 m .73624 .8734 L .73406 .87526 L F
0 g
.73265 .87737 m
.73406 .87526 L
s
.32981 .42092 m .2958 .42969 L .32729 .43133 L .654 .726 .902 r
F
.32981 .42092 m .29956 .41407 L .2958 .42969 L F
0 g
.2958 .42969 m
.29848 .44563 L
s
.33416 .8764 m .33122 .87301 L .33147 .8752 L .86 .577 .508 r
F
.33441 .8786 m .33416 .8764 L .33147 .8752 L F
0 g
.33416 .8764 m
.33619 .87803 L
s
.74373 .88094 m .74166 .87862 L .73979 .87961 L .692 .759 .904 r
F
.7448 .8806 m .74166 .87862 L .74373 .88094 L F
.36004 .42778 m .32729 .43133 L .35878 .43298 L .654 .726 .902 r
F
.36004 .42778 m .32981 .42092 L .32729 .43133 L F
.31879 .88143 m .31575 .87961 L .3136 .88147 L .692 .759 .903 r
F
0 g
.31221 .88358 m
.3136 .88147 L
s
.32065 .88044 m .31575 .87961 L .31879 .88143 L .692 .759 .903 r
F
.127 .923 .03 r
.59754 .43281 m
.59756 .43134 L
s
.49478 8.79996 m
.58951 1.0866 L
s
.59753 .43282 m
.59756 .43134 L
s
.40019 8.82421 m
.57536 1.37519 L
s
.74708 .88047 m .74609 .87763 L .74595 .88044 L .692 .759 .904 r
F
.74708 .88047 m .74835 .87769 L .74609 .87763 L F
.32253 .87756 m .32149 .87491 L .31828 .87592 L .692 .759 .903 r
F
.32482 .87725 m .32149 .87491 L .32253 .87756 L F
.74114 .87425 m .73907 .87194 L .73629 .87342 L .692 .759 .904 r
F
.74327 .87357 m .73907 .87194 L .74114 .87425 L F
.32482 .87725 m .32492 .87443 L .32149 .87491 L .692 .759 .903 r
F
.38425 .42027 m .37724 .41859 L .38159 .42159 L .675 .735 .895 r
F
.38425 .42027 m .38123 .41661 L .37724 .41859 L F
.39027 .43463 m .38285 .41456 L .37517 .4162 L .654 .726 .902 r
F
.39027 .43463 m .39103 .4143 L .38285 .41456 L F
.7448 .8806 m .7438 .87794 L .74166 .87862 L .692 .759 .904 r
F
.74595 .88044 m .7438 .87794 L .7448 .8806 L F
.5566 .66002 m .54748 .64889 L .54798 .65347 L .933 .647 .475 r
F
.5571 .6646 m .5566 .66002 L .54798 .65347 L F
0 g
.5566 .66002 m
.56183 .6679 L
s
.42176 .43628 m .45153 .42729 L .42089 .43096 L .654 .726 .902 r
F
.42176 .43628 m .45326 .43792 L .45153 .42729 L F
.74595 .88044 m .74609 .87763 L .7438 .87794 L .692 .759 .904 r
F
.33147 .8752 m .33122 .87301 L .32807 .87234 L .793 .527 .536 r
F
0 g
.33122 .87301 m
.3339 .8742 L
s
.7478 .87333 m .74569 .87046 L .74554 .87326 L .692 .759 .904 r
F
.7478 .87333 m .74907 .87056 L .74569 .87046 L F
.45326 .43792 m .48217 .42362 L .45153 .42729 L .654 .726 .902 r
F
.45326 .43792 m .48475 .43957 L .48217 .42362 L F
.73834 .88085 m .7346 .87966 L .73318 .88176 L .692 .759 .904 r
F
0 g
.73263 .88397 m
.73318 .88176 L
s
.53425 .66217 m .53654 .64869 L .52662 .65899 L .683 .77 .917 r
F
.53425 .66217 m .54798 .65347 L .53654 .64869 L F
.32944 .87996 m .32857 .87673 L .32734 .87951 L .692 .759 .903 r
F
.32944 .87996 m .33172 .8774 L .32857 .87673 L F
.44183 .53107 m .44152 .52539 L .45397 .51564 L .387 .233 .548 r
F
0 g
.43313 .52937 m
.44152 .52539 L
s
.48475 .43957 m .4826 .41633 L .48217 .42362 L .92 .74 .251 r
F
0 g
.48089 .45517 m
.48475 .43957 L
s
.62772 .53783 m .6004 .54626 L .62559 .5458 L .673 .757 .914 r
F
.65185 .54136 m .62772 .53783 L .62559 .5458 L F
.75515 .87458 m .75488 .87238 L .75222 .87119 L .861 .577 .505 r
F
0 g
.75488 .87238 m
.75689 .87401 L
s
.70148 .55011 m .7254 .54175 L .70085 .54616 L .673 .758 .914 r
F
.74327 .87357 m .74228 .87093 L .73907 .87194 L .692 .759 .904 r
F
.74554 .87326 m .74228 .87093 L .74327 .87357 L F
.73952 .87741 m .73651 .87559 L .73433 .87746 L F
.74139 .87642 m .73651 .87559 L .73952 .87741 L F
.42402 .51475 m .44126 .52523 L .45365 .51553 L .673 .757 .914 r
F
.127 .923 .03 r
.43097 .51494 m
.43117 .46748 L
s
.41341 .5198 m .44126 .52523 L .42402 .51475 L .673 .757 .914 r
F
.48145 .66957 m .45918 .66978 L .47523 .67457 L .683 .77 .917 r
F
.74554 .87326 m .74569 .87046 L .74228 .87093 L .692 .759 .904 r
F
.73979 .87961 m .7346 .87966 L .73834 .88085 L F
.127 .923 .03 r
.50125 .81933 m
.50134 .81218 L
s
.50136 .81115 m
.50175 .78002 L
s
.50175 .78002 m
.50179 .77741 L
s
.50226 .74096 m
.50267 .70901 L
s
.49596 8.79958 m
.50256 .83377 L
s
.50256 .83377 m
.50258 .81265 L
s
.50258 .81032 m
.50258 .80849 L
s
.50259 .80702 m
.50261 .77977 L
s
.50261 .77977 m
.50261 .77753 L
s
.50264 .74141 m
.50267 .70901 L
s
.75017 .87594 m .74936 .87272 L .74808 .8755 L .692 .759 .904 r
F
.75017 .87594 m .75249 .87339 L .74936 .87272 L F
.32065 .88044 m .31853 .87812 L .31575 .87961 L .692 .759 .903 r
F
.32279 .87976 m .31853 .87812 L .32065 .88044 L F
.48059 .66049 m .46771 .65323 L .45844 .6607 L .683 .77 .917 r
F
.48853 .6565 m .46771 .65323 L .48059 .66049 L F
.65434 .53197 m .62763 .53219 L .65163 .5357 L .673 .757 .914 r
F
.22772 .53962 m .21567 .52663 L .19982 .53419 L F
.23994 .53635 m .21567 .52663 L .22772 .53962 L F
0 g
.61127 .43355 m
.63128 .42489 L
s
.32149 .87491 m .31803 .87373 L .31828 .87592 L .599 .387 .565 r
F
.32149 .87491 m .32124 .87271 L .31803 .87373 L F
0 g
.31525 .87522 m
.31803 .87373 L
s
.75743 .87841 m .75515 .87458 L .75542 .87678 L .935 .633 .445 r
F
0 g
.75743 .87841 m
.75864 .88037 L
s
.31853 .87812 m .3155 .87741 L .31575 .87961 L .513 .326 .563 r
F
0 g
.3136 .88147 m
.31575 .87961 L
s
.31853 .87812 m .31828 .87592 L .3155 .87741 L .513 .326 .563 r
F
0 g
.31335 .87928 m
.3155 .87741 L
s
.127 .923 .03 r
.30402 .84254 m
.31602 .98224 L
s
.26501 .65489 m .27802 .66219 L .2842 .65718 L .683 .77 .917 r
F
.26103 .6569 m .27802 .66219 L .26501 .65489 L F
.32734 .87951 m .32517 .87663 L .32507 .87944 L .692 .759 .903 r
F
.32734 .87951 m .32857 .87673 L .32517 .87663 L F
.75222 .87894 m .75276 .87558 L .75044 .87814 L .692 .759 .904 r
F
.75222 .87894 m .75542 .87678 L .75276 .87558 L F
.50702 .40865 m .52194 .41478 L .52151 .42207 L .928 .67 .525 r
F
.50702 .40865 m .50745 .40136 L .52194 .41478 L F
.53516 .39261 m .52194 .41478 L .54482 .40156 L .654 .726 .902 r
F
.53516 .39261 m .50745 .40136 L .52194 .41478 L F
0 g
.52194 .41478 m
.52813 .41825 L
s
.73678 .87779 m .73433 .87746 L .7346 .87966 L .396 .244 .555 r
F
.73678 .87779 m .73651 .87559 L .73433 .87746 L F
0 g
.73291 .87956 m
.73433 .87746 L
s
.57462 .38454 m .57312 .4061 L .58209 .38696 L .654 .726 .902 r
F
.57462 .38454 m .55818 .40126 L .57312 .4061 L F
.33441 .8786 m .33147 .8752 L .33172 .8774 L .86 .577 .508 r
F
0 g
.33441 .8786 m
.33644 .88023 L
s
.127 .923 .03 r
.33427 .86598 m
.33531 1.0014 L
s
0 0 0 r
2.5 Mabswid
.66776 .55118 Mdot
.59833 .38781 m .60556 .40779 L .62086 .40454 L .654 .726 .902 r
F
.59018 .38807 m .60556 .40779 L .59833 .38781 L F
.36382 .41575 m .33026 .41364 L .36049 .42049 L F
.32832 .87453 m .32807 .87234 L .32466 .87224 L .731 .482 .551 r
F
.33147 .8752 m .32807 .87234 L .32832 .87453 L .793 .527 .536 r
F
0 g
.5 Mabswid
.32807 .87234 m
.33122 .87301 L
s
.74489 .44054 m .72619 .42254 L .72579 .42983 L .859 .601 .547 r
F
0 g
.74489 .44054 m
.75926 .45395 L
s
.32279 .87976 m .32174 .87711 L .31853 .87812 L .692 .759 .903 r
F
.32507 .87944 m .32174 .87711 L .32279 .87976 L F
.74139 .87642 m .73931 .8741 L .73651 .87559 L .692 .759 .904 r
F
.74353 .87574 m .73931 .8741 L .74139 .87642 L F
.32507 .87944 m .32517 .87663 L .32174 .87711 L .692 .759 .903 r
F
.60392 .53999 m .6004 .54626 L .60072 .55194 L 0 0 .327 r
F
0 g
.6011 .55053 m
.60133 .55193 L
s
.62772 .53783 m .60359 .5343 L .6004 .54626 L .673 .757 .914 r
F
.60392 .53999 m .60359 .5343 L .6004 .54626 L 0 0 .327 r
F
.42133 .42367 m .44606 .40986 L .41838 .41861 L .654 .726 .902 r
F
.42133 .42367 m .45196 .42 L .44606 .40986 L F
.33172 .8774 m .33147 .8752 L .32832 .87453 L .793 .527 .536 r
F
0 g
.33147 .8752 m
.33416 .8764 L
s
0 0 0 r
2.5 Mabswid
.66857 .55089 Mdot
.73931 .8741 m .73624 .8734 L .73651 .87559 L .515 .328 .565 r
F
.73931 .8741 m .73904 .87191 L .73624 .8734 L F
0 g
.5 Mabswid
.73406 .87526 m
.73624 .8734 L
s
.28309 .64798 m .30506 .64431 L .28706 .64235 L .683 .77 .917 r
F
.26707 .64321 m .28309 .64798 L .28706 .64235 L F
.74808 .8755 m .74596 .87261 L .74582 .87543 L .692 .759 .904 r
F
.74808 .8755 m .74936 .87272 L .74596 .87261 L F
.35349 .52752 m .35056 .54571 L .36373 .53221 L .673 .757 .914 r
F
.35349 .52752 m .33521 .53869 L .35056 .54571 L F
0 g
.35056 .54571 m
.3686 .54998 L
s
.20013 .5454 m .18748 .54946 L .18777 .55514 L .383 .23 .546 r
F
.20013 .5454 m .19985 .53971 L .18748 .54946 L F
0 g
.17953 .56068 m
.18748 .54946 L
s
.48779 .77008 m .49705 .76914 L .4968 .77291 L .793 .551 .571 r
F
.127 .923 .03 r
.38775 1.57269 m
.49666 8.79866 L
s
.37532 .74822 m
.38775 1.57269 L
s
.48779 .77008 m .48804 .7663 L .49705 .76914 L .793 .551 .571 r
F
0 g
.49705 .76914 m
.49857 .76935 L
s
.32492 .87443 m .32124 .87271 L .32149 .87491 L .669 .437 .56 r
F
.32492 .87443 m .32466 .87224 L .32124 .87271 L F
0 g
.31803 .87373 m
.32124 .87271 L
s
.51636 .77406 m .51661 .77029 L .52582 .76852 L .597 .38 .558 r
F
0 g
.51492 .77032 m
.51661 .77029 L
s
.75515 .87458 m .75222 .87119 L .75249 .87339 L .861 .577 .505 r
F
.75542 .87678 m .75515 .87458 L .75249 .87339 L F
0 g
.75515 .87458 m
.75716 .87621 L
s
.23496 .64954 m .22423 .66043 L .23787 .65173 L .683 .77 .917 r
F
.23496 .64954 m .21841 .65606 L .22423 .66043 L F
.4947 .75996 m .49711 .76903 L .50067 .76184 L .645 .732 .913 r
F
.4947 .75996 m .48814 .76621 L .49711 .76903 L F
.32832 .87453 m .32466 .87224 L .32492 .87443 L .731 .482 .551 r
F
0 g
.32124 .87271 m
.32466 .87224 L
s
.32466 .87224 m
.32807 .87234 L
s
.73979 .87961 m .73678 .87779 L .7346 .87966 L .692 .759 .904 r
F
0 g
.73318 .88176 m
.7346 .87966 L
s
.74166 .87862 m .73678 .87779 L .73979 .87961 L .692 .759 .904 r
F
.51365 .76261 m .51656 .77017 L .52573 .76842 L .645 .732 .913 r
F
.50714 .76275 m .51656 .77017 L .51365 .76261 L F
.74353 .87574 m .74253 .87309 L .73931 .8741 L .692 .759 .904 r
F
.74582 .87543 m .74253 .87309 L .74353 .87574 L F
.19699 .65927 m .20187 .66259 L .20234 .66716 L .982 .691 .347 r
F
.19699 .65927 m .19652 .6547 L .20187 .66259 L F
.21485 .6508 m .20187 .66259 L .21841 .65606 L .683 .77 .917 r
F
.21485 .6508 m .19652 .6547 L .20187 .66259 L F
0 g
.20187 .66259 m
.20603 .66571 L
s
.74582 .87543 m .74596 .87261 L .74253 .87309 L .692 .759 .904 r
F
.21756 .55591 m .20013 .5454 L .18777 .55514 L .673 .757 .914 r
F
0 g
.17982 .56636 m
.18777 .55514 L
s
.22818 .55085 m .20013 .5454 L .21756 .55591 L .673 .757 .914 r
F
.75249 .87339 m .75222 .87119 L .74908 .87052 L .793 .527 .534 r
F
0 g
.75222 .87119 m
.75488 .87238 L
s
.70051 .54048 m .72045 .52876 L .6982 .53682 L .673 .757 .914 r
F
.70051 .54048 m .72506 .53607 L .72045 .52876 L F
.3644 .40852 m .33763 .39698 L .33102 .40642 L .654 .726 .902 r
F
.36954 .40459 m .33763 .39698 L .3644 .40852 L F
.2783 .54425 m .27337 .52647 L .26626 .54141 L .673 .757 .914 r
F
.2783 .54425 m .29143 .53074 L .27337 .52647 L F
.75044 .87814 m .74963 .87491 L .74835 .87769 L .692 .759 .904 r
F
.75044 .87814 m .75276 .87558 L .74963 .87491 L F
.41868 .41136 m .43658 .39375 L .41386 .40691 L .654 .726 .902 r
F
.41868 .41136 m .44622 .40266 L .43658 .39375 L F
.32174 .87711 m .31828 .87592 L .31853 .87812 L .599 .387 .565 r
F
.32174 .87711 m .32149 .87491 L .31828 .87592 L F
0 g
.3155 .87741 m
.31828 .87592 L
s
.127 .923 .03 r
.31688 .80001 m
.3197 1.09089 L
s
.2525 .87377 m
.31873 4.60457 L
s
0 g
.31575 .87961 m
.31853 .87812 L
s
.33763 .39698 m .30093 .3996 L .33102 .40642 L .654 .726 .902 r
F
.65218 .54704 m .62592 .55148 L .65111 .55102 L .673 .758 .914 r
F
.52603 .65452 m .52249 .64161 L .5171 .65275 L .683 .77 .917 r
F
.52603 .65452 m .5359 .64427 L .52249 .64161 L F
.5571 .6646 m .54798 .65347 L .54847 .65804 L .933 .647 .475 r
F
0 g
.5571 .6646 m
.56233 .67248 L
s
.72448 .53043 m .74203 .51513 L .71988 .52316 L .673 .757 .914 r
F
.72448 .53043 m .74891 .52604 L .74203 .51513 L F
.32857 .87673 m .32832 .87453 L .32492 .87443 L .731 .482 .551 r
F
.33172 .8774 m .32832 .87453 L .32857 .87673 L .793 .527 .536 r
F
0 g
.32832 .87453 m
.33147 .8752 L
s
.33172 .8774 m
.33441 .8786 L
s
.6458 .4074 m
.65518 .40541 L
s
.67416 .65069 m .67365 .64611 L .68834 .64418 L .673 .453 .579 r
F
.65959 .6503 m .67365 .64611 L .67416 .65069 L .733 .497 .57 r
F
.127 .923 .03 r
.66433 .64889 m
.66606 .59488 L
s
.65995 .6502 m
.66092 .60169 L
s
.65959 .6503 m .65909 .64573 L .67365 .64611 L .733 .497 .57 r
F
.127 .923 .03 r
.66727 .64594 m
.66855 .58493 L
s
.66645 .64592 m
.66844 .5845 L
s
.74166 .87862 m .73958 .8763 L .73678 .87779 L .692 .759 .904 r
F
.7438 .87794 m .73958 .8763 L .74166 .87862 L F
.53474 .66675 m .53704 .65327 L .52712 .66357 L .683 .77 .917 r
F
.53474 .66675 m .54847 .65804 L .53704 .65327 L F
.45209 .41275 m .47377 .39396 L .44622 .40266 L .654 .726 .902 r
F
.45209 .41275 m .48258 .4091 L .47377 .39396 L F
0 0 0 r
2.5 Mabswid
.22381 .55489 Mdot
.74253 .87309 m .73904 .87191 L .73931 .8741 L .6 .388 .565 r
F
.74253 .87309 m .74226 .87089 L .73904 .87191 L F
0 g
.5 Mabswid
.73624 .8734 m
.73904 .87191 L
s
.67429 .63467 m .67366 .64594 L .68828 .64402 L .683 .77 .917 r
F
.66463 .63442 m .67366 .64594 L .67429 .63467 L F
.66463 .63442 m .65917 .64556 L .67366 .64594 L F
.127 .923 .03 r
.65648 .71789 m
.65816 .66442 L
s
.65816 .66442 m
.66013 .60198 L
s
.64935 .75994 m
.65676 .66492 L
s
.65676 .66492 m
.66191 .599 L
s
.73958 .8763 m .73651 .87559 L .73678 .87779 L .515 .328 .565 r
F
0 g
.7346 .87966 m
.73678 .87779 L
s
.73958 .8763 m .73931 .8741 L .73651 .87559 L .515 .328 .565 r
F
0 g
.73433 .87746 m
.73651 .87559 L
s
.72619 .42254 m .72659 .41526 L .7041 .40797 L .794 .542 .556 r
F
0 g
.72659 .41526 m
.74567 .42597 L
s
.74835 .87769 m .74623 .87481 L .74609 .87763 L .692 .759 .904 r
F
.74835 .87769 m .74963 .87491 L .74623 .87481 L F
.2659 .53588 m .25354 .51981 L .25296 .53507 L .673 .757 .914 r
F
.2659 .53588 m .27297 .52102 L .25354 .51981 L F
.32517 .87663 m .32149 .87491 L .32174 .87711 L .669 .437 .56 r
F
.32517 .87663 m .32492 .87443 L .32149 .87491 L F
0 g
.31828 .87592 m
.32149 .87491 L
s
.75542 .87678 m .75249 .87339 L .75276 .87558 L .861 .577 .505 r
F
0 g
.75542 .87678 m
.75743 .87841 L
s
.74936 .87272 m .74908 .87052 L .74569 .87042 L .731 .482 .551 r
F
.75249 .87339 m .74908 .87052 L .74936 .87272 L .793 .527 .534 r
F
0 g
.74908 .87052 m
.75222 .87119 L
s
.32857 .87673 m .32492 .87443 L .32517 .87663 L .731 .482 .551 r
F
0 g
.32149 .87491 m
.32492 .87443 L
s
.32492 .87443 m
.32832 .87453 L
s
.127 .923 .03 r
.24261 .81207 m
.32971 3.56281 L
s
.32422 .82436 m
.33881 1.49677 L
s
.32401 .8322 m
.32979 1.48222 L
s
.32034 .7648 m
.32579 1.35241 L
s
0 g
.32857 .87673 m
.33172 .8774 L
s
.68885 .64875 m .68834 .64418 L .70216 .64006 L .606 .405 .583 r
F
.67416 .65069 m .68834 .64418 L .68885 .64875 L .673 .453 .579 r
F
0 g
.67365 .64611 m
.68834 .64418 L
s
.7438 .87794 m .7428 .87529 L .73958 .8763 L .692 .759 .904 r
F
.74609 .87763 m .7428 .87529 L .7438 .87794 L F
.30581 .64891 m .30533 .64434 L .30762 .63544 L 0 0 .38 r
F
0 g
.3016 .64962 m
.30533 .64434 L
s
.74609 .87763 m .74623 .87481 L .7428 .87529 L .692 .759 .904 r
F
.28706 .64235 m .30506 .64431 L .30734 .63546 L .683 .77 .917 r
F
.75276 .87558 m .75249 .87339 L .74936 .87272 L .793 .527 .534 r
F
0 g
.75249 .87339 m
.75515 .87458 L
s
.68404 .63339 m .68828 .64402 L .70203 .63992 L .683 .77 .917 r
F
.67429 .63467 m .68828 .64402 L .68404 .63339 L F
.69775 .53118 m .71227 .51697 L .69394 .52809 L .673 .757 .914 r
F
.69775 .53118 m .71988 .52316 L .71227 .51697 L F
.48095 .665 m .46801 .6577 L .45869 .66521 L .683 .77 .917 r
F
.48893 .66099 m .46801 .6577 L .48095 .665 L F
.44183 .53107 m .45397 .51564 L .45428 .52132 L .387 .233 .548 r
F
.44214 .53675 m .44183 .53107 L .45428 .52132 L F
.4245 .52054 m .44183 .53107 L .45428 .52132 L .673 .757 .914 r
F
.41384 .52561 m .44183 .53107 L .4245 .52054 L F
0 g
.43344 .53505 m
.44183 .53107 L
s
.46801 .6577 m .4582 .66063 L .45869 .66521 L .403 .258 .569 r
F
.46801 .6577 m .46752 .65312 L .4582 .66063 L F
0 g
.45217 .66911 m
.4582 .66063 L
s
.62805 .54352 m .60072 .55194 L .62592 .55148 L .673 .758 .914 r
F
.65218 .54704 m .62805 .54352 L .62592 .55148 L F
.74596 .87261 m .74226 .87089 L .74253 .87309 L .669 .437 .56 r
F
.74596 .87261 m .74569 .87042 L .74226 .87089 L F
0 g
.73904 .87191 m
.74226 .87089 L
s
.31853 .87812 m
.32174 .87711 L
s
.74936 .87272 m .74569 .87042 L .74596 .87261 L .731 .482 .551 r
F
0 g
.74226 .87089 m
.74569 .87042 L
s
.74569 .87042 m
.74908 .87052 L
s
.48754 .77385 m .4968 .77291 L .49655 .77668 L .793 .551 .571 r
F
.48754 .77385 m .48779 .77008 L .4968 .77291 L F
.49438 .7638 m .4968 .77291 L .50039 .76569 L .645 .732 .913 r
F
.127 .923 .03 r
.38262 .68386 m
.38267 .68746 L
s
.49438 .7638 m .48779 .77008 L .4968 .77291 L .645 .732 .913 r
F
0 g
.4968 .77291 m
.49832 .77312 L
s
.51636 .77406 m .52582 .76852 L .52557 .7723 L .597 .38 .558 r
F
.51611 .77783 m .51636 .77406 L .52557 .7723 L F
.51343 .76646 m .51636 .77406 L .52557 .7723 L .645 .732 .913 r
F
0 g
.51467 .7741 m
.51636 .77406 L
s
.28373 .65261 m .30581 .64891 L .28771 .64695 L .683 .77 .917 r
F
.26762 .64781 m .28373 .65261 L .28771 .64695 L F
.26453 .65032 m .28373 .65261 L .26762 .64781 L F
.58976 .39546 m .58885 .41581 L .60522 .41528 L .654 .726 .902 r
F
.58163 .39434 m .58885 .41581 L .58976 .39546 L F
.58163 .39434 m .57261 .41357 L .58885 .41581 L F
0 g
.32517 .87663 m
.32857 .87673 L
s
.65456 .53762 m .62772 .53783 L .65185 .54136 L .673 .757 .914 r
F
.23994 .53635 m .234 .52172 L .21567 .52663 L F
.25296 .53507 m .234 .52172 L .23994 .53635 L F
.7428 .87529 m .73931 .8741 L .73958 .8763 L .6 .388 .565 r
F
.7428 .87529 m .74253 .87309 L .73931 .8741 L F
0 g
.73651 .87559 m
.73931 .8741 L
s
.23543 .65412 m .2247 .66501 L .23834 .6563 L .683 .77 .917 r
F
.23543 .65412 m .21888 .66064 L .2247 .66501 L F
.22789 .54517 m .21578 .53212 L .19985 .53971 L .673 .757 .914 r
F
.24017 .54188 m .21578 .53212 L .22789 .54517 L F
0 g
.73678 .87779 m
.73958 .8763 L
s
.48012 .76596 m .48804 .7663 L .48779 .77008 L .856 .609 .564 r
F
.48012 .76596 m .48037 .76219 L .48804 .7663 L F
0 g
.48804 .7663 m
.49083 .76718 L
s
.21532 .65538 m .20234 .66716 L .21888 .66064 L .683 .77 .917 r
F
.21532 .65538 m .19699 .65927 L .20234 .66716 L F
0 g
.20234 .66716 m
.21106 .67371 L
s
.32174 .87711 m
.32517 .87663 L
s
.48961 .75723 m .48051 .76211 L .48814 .76621 L .645 .732 .913 r
F
.52557 .7723 m .52582 .76852 L .53381 .76532 L .5 .3 .539 r
F
0 g
.52003 .76963 m
.52582 .76852 L
s
.74963 .87491 m .74936 .87272 L .74596 .87261 L .731 .482 .551 r
F
.75276 .87558 m .74936 .87272 L .74963 .87491 L .793 .527 .534 r
F
0 g
.74936 .87272 m
.75249 .87339 L
s
.75276 .87558 m
.75542 .87678 L
s
.62805 .54352 m .60392 .53999 L .60072 .55194 L .673 .758 .914 r
F
0 g
.60072 .55194 m
.60268 .56379 L
s
.51976 .76144 m .52573 .76842 L .53368 .76523 L .645 .732 .913 r
F
.127 .923 .03 r
.55196 .66042 m
.55322 .59286 L
s
.51365 .76261 m .52573 .76842 L .51976 .76144 L .645 .732 .913 r
F
.32328 .52369 m .33461 .52733 L .33491 .53301 L .931 .657 .497 r
F
.32328 .52369 m .32298 .51801 L .33461 .52733 L F
0 g
.33461 .52733 m
.34009 .52984 L
s
.25296 .53507 m .25354 .51981 L .234 .52172 L .673 .757 .914 r
F
.48853 .6565 m .47962 .64725 L .46771 .65323 L .683 .77 .917 r
F
.49769 .65378 m .47962 .64725 L .48853 .6565 L F
.34536 .50986 m .33488 .52716 L .35307 .51604 L .673 .757 .914 r
F
.34536 .50986 m .32332 .51789 L .33488 .52716 L F
.39121 .51177 m .38929 .52423 L .40118 .52307 L F
.39167 .50879 m .40118 .52307 L .39534 .50843 L F
.38882 .50907 m .39121 .51177 L .39167 .50879 L F
.39121 .51177 m .40118 .52307 L .39167 .50879 L F
.39386 .46675 m .39397 .46593 L .39391 .49423 L 0 0 .133 r
F
.38912 .51483 m .38845 .53018 L .40155 .52889 L .673 .757 .914 r
F
.38882 .50907 m .38929 .52423 L .39121 .51177 L F
.38912 .51483 m .40155 .52889 L .39567 .51419 L F
.39272 .46801 m .39343 .46744 L .39336 .49561 L .354 .175 .495 r
F
.39204 .49662 m .39534 .50843 L .39207 .49659 L .673 .757 .914 r
F
.38853 .46839 m .3901 .46866 L .39003 .49682 L .751 .491 .538 r
F
.39169 .46845 m .39272 .46801 L .39265 .49615 L .515 .301 .526 r
F
.39169 .46845 m .39265 .49615 L .39212 .49637 L F
.3901 .46866 m .39169 .46845 L .39163 .49658 L .641 .4 .539 r
F
.3901 .46866 m .39163 .49658 L .3908 .4967 L F
.39272 .46801 m .39336 .49561 L .39299 .49589 L .354 .175 .495 r
F
.39169 .46845 m .39212 .49637 L .39163 .49658 L .515 .301 .526 r
F
.39272 .46801 m .39299 .49589 L .39265 .49615 L .354 .175 .495 r
F
.3901 .46866 m .3908 .4967 L .39003 .49682 L .641 .4 .539 r
F
.39138 .49852 m .38882 .50907 L .39534 .50843 L .673 .757 .914 r
F
.39309 .50478 m .39567 .51419 L .39332 .50329 L F
.39544 .49739 m .40146 .50679 L .40676 .50427 L F
.38949 .49378 m .39836 .50343 L .39544 .49739 L F
.39836 .50343 m .40146 .50679 L .39544 .49739 L F
.39343 .46744 m .39386 .46675 L .39379 .49497 L .069 0 .411 r
F
.39397 .46593 m .39352 .46488 L .39345 .49329 L .985 .728 .342 r
F
.39534 .50843 m .40118 .52307 L .41341 .5198 L .673 .757 .914 r
F
.39332 .50329 m .39567 .51419 L .40182 .51254 L F
.39024 .50019 m .38882 .50907 L .39138 .49852 L F
.39073 .49696 m .38882 .50907 L .39075 .49695 L F
.38882 .50907 m .38815 .52434 L .38929 .52423 L F
.38235 .50867 m .38815 .52434 L .38831 .52073 L F
.38744 .50898 m .38831 .52073 L .38882 .50907 L F
.38235 .50867 m .38831 .52073 L .38744 .50898 L F
.38643 .4658 m .38649 .46662 L .38642 .4951 L .79 .631 .071 r
F
.38687 .46732 m .38753 .46792 L .38746 .49624 L .929 .648 .488 r
F
.38262 .51442 m .38845 .53018 L .38851 .5289 L .673 .757 .914 r
F
.38746 .51472 m .38851 .5289 L .38912 .51483 L F
.38235 .50867 m .37522 .52354 L .38815 .52434 L F
.38262 .51442 m .38851 .5289 L .38746 .51472 L F
.38697 .50262 m .38235 .50867 L .38744 .50898 L F
.37636 .50725 m .37522 .52354 L .38235 .50867 L F
.38297 .50047 m .37127 .50491 L .37636 .50725 L F
.38697 .50262 m .38744 .50898 L .38882 .50907 L F
.38953 .5055 m .38262 .51442 L .38912 .51483 L F
.38868 .50412 m .38262 .51442 L .38953 .5055 L F
.38923 .49967 m .38697 .50262 L .38882 .50907 L F
.38857 .50201 m .38843 .50231 L .38966 .50244 L F
.3872 .49613 m .38524 .49637 L .38297 .50047 L F
.38639 .49472 m .38642 .4951 L .3864 .50042 L .79 .631 .071 r
F
.38297 .50047 m .37887 .50784 L .38235 .50867 L .673 .757 .914 r
F
.38865 .49873 m .38235 .50867 L .38923 .49967 L F
.38906 .49747 m .38235 .50867 L .38932 .49768 L F
.38817 .49652 m .38779 .49732 L .38935 .49699 L F
.38779 .49732 m .38235 .50867 L .38848 .49844 L F
.38779 .49732 m .38848 .49844 L .38935 .49699 L F
.38808 .49671 m .38297 .50047 L .38235 .50867 L F
.38642 .4951 m .38662 .50077 L .3864 .50042 L .989 .72 .388 r
F
.38649 .46662 m .3866 .4954 L .38642 .4951 L F
.38725 .49607 m .38297 .50047 L .38808 .49671 L .673 .757 .914 r
F
.3866 .4954 m .38662 .50077 L .38642 .4951 L .989 .72 .388 r
F
.38697 .50118 m .38476 .50254 L .38762 .50169 L .673 .757 .914 r
F
.38476 .50254 m .37148 .51065 L .38416 .50361 L F
.38476 .50254 m .38416 .50361 L .38762 .50169 L F
.38983 .51133 m .38293 .52011 L .38943 .52051 L F
.3766 .513 m .37545 .52937 L .38262 .51442 L F
.38115 .51433 m .37179 .51634 L .37691 .51868 L F
.38736 .50196 m .37148 .51065 L .3766 .513 L F
.38662 .50077 m .38664 .50615 L .3864 .50042 L .989 .72 .388 r
F
.38832 .50887 m .38293 .52011 L .38983 .51133 L .673 .757 .914 r
F
.38664 .50615 m .38672 .52615 L .38647 .50587 L .989 .72 .388 r
F
.38658 .50276 m .3766 .513 L .3868 .50571 L .673 .757 .914 r
F
.38664 .50615 m .38647 .50587 L .3864 .50042 L .989 .72 .388 r
F
.38638 .5001 m .3864 .50042 L .38639 .50574 L .79 .631 .071 r
F
.38712 .49597 m .38746 .49624 L .38745 .50156 L .929 .648 .488 r
F
.38843 .50231 m .38658 .50276 L .3868 .50571 L .673 .757 .914 r
F
.38877 .50792 m .38115 .51433 L .38293 .52011 L F
.38762 .50169 m .3873 .50187 L .38736 .50196 L F
.38638 .5001 m .38639 .50574 L .38637 .50549 L .79 .631 .071 r
F
.38297 .50047 m .37636 .50725 L .37887 .50784 L .673 .757 .914 r
F
.3868 .50129 m .36761 .50754 L .37148 .51065 L F
.38746 .49624 m .38762 .50162 L .38745 .50156 L .845 .571 .524 r
F
.38979 .49946 m .38583 .50091 L .3868 .50129 L .673 .757 .914 r
F
.38583 .50091 m .36761 .50754 L .3868 .50129 L F
.38794 .49643 m .38846 .49663 L .38844 .50195 L .845 .571 .524 r
F
.38857 .50201 m .38821 .50214 L .38843 .50231 L .673 .757 .914 r
F
.38814 .50716 m .38714 .50696 L .3876 .50771 L F
.38293 .52011 m .38876 .53586 L .38943 .52051 L F
.38843 .50728 m .38996 .52749 L .38838 .52722 L .751 .491 .538 r
F
.38844 .50195 m .38876 .50731 L .38843 .50728 L F
.38876 .50731 m .38996 .52749 L .38843 .50728 L F
.37636 .50725 m .36325 .52071 L .37522 .52354 L .673 .757 .914 r
F
.37127 .50491 m .36325 .52071 L .37636 .50725 L F
.37127 .50491 m .35307 .51604 L .36325 .52071 L F
.38528 .5069 m .36555 .50957 L .36792 .51323 L F
.3873 .50187 m .37148 .51065 L .38736 .50196 L F
.38712 .49597 m .38717 .50133 L .3868 .49572 L .929 .648 .488 r
F
.38717 .50133 m .3869 .50113 L .3868 .49572 L F
.38687 .46732 m .38712 .49597 L .3868 .49572 L F
.38687 .46732 m .38746 .49624 L .38712 .49597 L F
.3866 .4954 m .3868 .49572 L .38679 .50104 L .989 .72 .388 r
F
.3866 .4954 m .38679 .50104 L .38662 .50077 L F
.38689 .4934 m .38657 .49927 L .38688 .49872 L 0 0 .372 r
F
.38696 .46476 m .38663 .49387 L .38689 .4934 L F
.38753 .46792 m .38794 .49643 L .38746 .49624 L .845 .571 .524 r
F
.38949 .49378 m .38626 .49575 L .3872 .49613 L .673 .757 .914 r
F
.38649 .46662 m .3868 .49572 L .3866 .4954 L .989 .72 .388 r
F
.38663 .49387 m .38657 .49927 L .38689 .4934 L 0 0 .372 r
F
.38524 .49637 m .38256 .4963 L .37127 .50491 L .673 .757 .914 r
F
.38949 .49378 m .38597 .49506 L .38524 .49637 L F
.38597 .49506 m .38256 .4963 L .38524 .49637 L F
.38256 .4963 m .36742 .50182 L .37055 .50433 L F
.38256 .4963 m .37055 .50433 L .37127 .50491 L F
.38809 .46397 m .38696 .46476 L .38689 .4934 L .398 .209 .505 r
F
.38712 .49597 m .38745 .50156 L .38717 .50133 L .929 .648 .488 r
F
.38717 .50133 m .38721 .5067 L .3869 .50113 L F
.38097 .50268 m .36525 .50388 L .36761 .50754 L .673 .757 .914 r
F
.38794 .49643 m .38844 .50195 L .38802 .50178 L .845 .571 .524 r
F
.38802 .50178 m .38762 .50162 L .38746 .49624 L F
.38979 .49946 m .38429 .50045 L .38097 .50268 L .673 .757 .914 r
F
.38524 .49637 m .37127 .50491 L .38297 .50047 L F
.38429 .50045 m .36525 .50388 L .38097 .50268 L F
.38735 .49841 m .38687 .50404 L .38724 .5038 L .398 .209 .505 r
F
.38747 .49302 m .38717 .49853 L .38735 .49841 L F
.38717 .49853 m .38687 .50404 L .38735 .49841 L F
.38809 .46397 m .3872 .4932 L .38747 .49302 L F
.3872 .4932 m .38687 .50404 L .38747 .49302 L F
.38256 .4963 m .36507 .49817 L .36742 .50182 L .673 .757 .914 r
F
.38949 .49378 m .38517 .49455 L .38256 .4963 L F
.38517 .49455 m .36507 .49817 L .38256 .4963 L F
.3868 .50571 m .38049 .51022 L .38262 .51442 L F
.3901 .50515 m .38342 .50635 L .38528 .5069 L F
.38734 .50684 m .38714 .50696 L .38814 .50716 L F
.38744 .50688 m .38838 .52722 L .38739 .52675 L .845 .571 .524 r
F
.3868 .50571 m .3869 .50714 L .38933 .50302 L .673 .757 .914 r
F
.38745 .50156 m .38765 .50696 L .38744 .50688 L .845 .571 .524 r
F
.38765 .50696 m .38838 .52722 L .38744 .50688 L F
.38529 .50601 m .36486 .5056 L .36555 .50957 L .673 .757 .914 r
F
.38802 .50178 m .38843 .50728 L .38809 .50714 L .845 .571 .524 r
F
.3901 .50515 m .38343 .50527 L .38529 .50601 L .673 .757 .914 r
F
.38343 .50527 m .36486 .5056 L .38529 .50601 L F
.38767 .50164 m .38658 .50276 L .38857 .50201 L F
.38762 .50162 m .38778 .50702 L .38745 .50156 L .845 .571 .524 r
F
.38778 .50702 m .38838 .52722 L .38765 .50696 L F
.38778 .50702 m .38765 .50696 L .38745 .50156 L F
.38343 .50527 m .36589 .50161 L .36486 .5056 L .673 .757 .914 r
F
.38843 .50231 m .3868 .50571 L .38933 .50302 L F
.38717 .50133 m .38744 .50688 L .38721 .5067 L .929 .648 .488 r
F
.38721 .5067 m .387 .50654 L .3869 .50113 L F
.38638 .5001 m .38637 .50549 L .38636 .49981 L .79 .631 .071 r
F
.38637 .50549 m .38634 .52545 L .38635 .50526 L F
.38637 .50549 m .38635 .50526 L .38636 .49981 L F
.38635 .50521 m .37913 .50354 L .38343 .50527 L .673 .757 .914 r
F
.3901 .50515 m .38631 .50459 L .38635 .50521 L F
.38631 .50459 m .37913 .50354 L .38635 .50521 L F
.37913 .50354 m .36589 .50161 L .38343 .50527 L F
.3864 .50042 m .38647 .50587 L .38639 .50574 L .989 .72 .388 r
F
.38677 .50636 m .38739 .52675 L .38672 .52615 L .929 .648 .488 r
F
.38679 .50104 m .38691 .50647 L .38677 .50636 L F
.3876 .50771 m .38656 .50802 L .38661 .50873 L .673 .757 .914 r
F
.38691 .50647 m .38739 .52675 L .38677 .50636 L .929 .648 .488 r
F
.38429 .50045 m .36456 .49992 L .36525 .50388 L .673 .757 .914 r
F
.38979 .49946 m .38566 .49954 L .38429 .50045 L F
.38566 .49954 m .36456 .49992 L .38429 .50045 L F
.38821 .50214 m .38658 .50276 L .38843 .50231 L F
.38802 .50178 m .38809 .50714 L .38762 .50162 L .845 .571 .524 r
F
.38717 .50133 m .38745 .50156 L .38744 .50688 L .929 .648 .488 r
F
.388 .49797 m .38724 .5038 L .38799 .50329 L .398 .209 .505 r
F
.38753 .46792 m .38846 .49663 L .38794 .49643 L .845 .571 .524 r
F
.38517 .49455 m .36438 .49423 L .36507 .49817 L .673 .757 .914 r
F
.38949 .49378 m .38625 .49384 L .38517 .49455 L F
.38625 .49384 m .36438 .49423 L .38517 .49455 L F
.38949 .49378 m .38725 .49607 L .38808 .49671 L F
.38801 .49265 m .38735 .49841 L .388 .49797 L .398 .209 .505 r
F
.38809 .46397 m .38747 .49302 L .38801 .49265 L F
.38747 .49302 m .38735 .49841 L .38801 .49265 L F
.38794 .49643 m .38802 .50178 L .38746 .49624 L .845 .571 .524 r
F
.38735 .49841 m .38724 .5038 L .388 .49797 L .398 .209 .505 r
F
.38253 .50306 m .36857 .49785 L .36777 .49898 L .673 .757 .914 r
F
.38753 .46792 m .38853 .46839 L .38846 .49663 L .845 .571 .524 r
F
.38409 .49387 m .36541 .49025 L .36438 .49423 L .673 .757 .914 r
F
.38649 .46662 m .38687 .46732 L .3868 .49572 L .989 .72 .388 r
F
.38696 .46476 m .38645 .49421 L .38663 .49387 L 0 0 .372 r
F
.38949 .49378 m .38603 .49327 L .38409 .49387 L .673 .757 .914 r
F
.38603 .49327 m .36541 .49025 L .38409 .49387 L F
.38919 .46363 m .38809 .46397 L .38801 .49265 L .567 .342 .533 r
F
.3872 .4932 m .38689 .4934 L .38688 .49872 L .398 .209 .505 r
F
.38603 .49327 m .36807 .48652 L .36541 .49025 L .673 .757 .914 r
F
.38949 .49378 m .38705 .49295 L .38603 .49327 L F
.38643 .4658 m .38639 .49472 L .38636 .49436 L .79 .631 .071 r
F
.38643 .4658 m .38642 .4951 L .38639 .49472 L F
.38696 .46476 m .38643 .4658 L .38636 .49436 L 0 0 .372 r
F
.38696 .46476 m .38636 .49436 L .38645 .49421 L F
.38705 .49295 m .36807 .48652 L .38603 .49327 L .673 .757 .914 r
F
.38979 .49946 m .38697 .50118 L .38762 .50169 L F
.38858 .49247 m .38799 .50329 L .38836 .50318 L .567 .342 .533 r
F
.38932 .49768 m .38865 .49873 L .38923 .49967 L .673 .757 .914 r
F
.38846 .49663 m .38934 .50206 L .38844 .50195 L .751 .491 .538 r
F
.38853 .46839 m .38921 .49672 L .38846 .49663 L F
.38936 .49674 m .38846 .49663 L .38935 .49699 L .673 .757 .914 r
F
.38921 .49672 m .38934 .50206 L .38846 .49663 L .751 .491 .538 r
F
.38949 .49378 m .38817 .49652 L .38846 .49663 L .673 .757 .914 r
F
.38949 .49378 m .38846 .49663 L .38936 .49674 L F
.38919 .46363 m .38831 .49256 L .38858 .49247 L .567 .342 .533 r
F
.38831 .49256 m .38799 .50329 L .38858 .49247 L F
.38809 .46397 m .38689 .4934 L .3872 .4932 L .398 .209 .505 r
F
.38776 .49273 m .37751 .48075 L .3722 .48327 L .673 .757 .914 r
F
.38949 .49378 m .38836 .49255 L .38776 .49273 L F
.38836 .49255 m .37751 .48075 L .38776 .49273 L F
.38979 .49946 m .38907 .49764 L .38833 .49787 L F
.38461 .50434 m .36777 .49898 L .37913 .50354 L F
.3901 .50515 m .38583 .50397 L .38461 .50434 L F
.38583 .50397 m .36777 .49898 L .38461 .50434 L F
.38904 .50735 m .38799 .50731 L .38877 .50792 L F
.38947 .5074 m .38876 .50731 L .38844 .50195 L .751 .491 .538 r
F
.38935 .49692 m .38882 .50907 L .39066 .49672 L .673 .757 .914 r
F
.3901 .50515 m .38807 .50723 L .38904 .50735 L F
.38807 .50723 m .38799 .50731 L .38904 .50735 L F
.38843 .50231 m .38933 .50302 L .38966 .50244 L F
.38966 .50244 m .38868 .50412 L .38953 .5055 L F
.38934 .50206 m .38947 .5074 L .38844 .50195 L .751 .491 .538 r
F
.38965 .50273 m .38912 .51483 L .39088 .50224 L .673 .757 .914 r
F
.39082 .50223 m .39088 .50224 L .39089 .50221 L F
.38965 .50273 m .39088 .50224 L .39082 .50223 L F
.38921 .49672 m .39003 .49682 L .39002 .50214 L .751 .491 .538 r
F
.39 .50746 m .38832 .50887 L .38983 .51133 L .673 .757 .914 r
F
.38934 .50206 m .39001 .50746 L .38947 .5074 L .751 .491 .538 r
F
.3901 .50515 m .38904 .50735 L .39 .50746 L .673 .757 .914 r
F
.38904 .50735 m .38832 .50887 L .39 .50746 L F
.38934 .50206 m .39002 .50214 L .39001 .50746 L .751 .491 .538 r
F
.3909 .50224 m .38912 .51483 L .39567 .51419 L .673 .757 .914 r
F
.39088 .50224 m .38912 .51483 L .3909 .50224 L F
.3928 .51191 m .39151 .52031 L .39598 .51987 L F
.39377 .50561 m .39384 .52477 L .39372 .52558 L 0 0 .133 r
F
.39207 .49659 m .39534 .50843 L .40146 .50679 L .673 .757 .914 r
F
.39534 .50843 m .41341 .5198 L .40146 .50679 L F
.39356 .50175 m .40182 .51254 L .40715 .51001 L F
.39075 .49695 m .39534 .50843 L .39163 .49658 L F
.39212 .49637 m .39264 .50147 L .3922 .50165 L .515 .301 .526 r
F
.38979 .49946 m .39332 .50329 L .39356 .50175 L .673 .757 .914 r
F
.39332 .50329 m .40182 .51254 L .39356 .50175 L F
.39378 .50029 m .39381 .50535 L .39377 .50561 L 0 0 .133 r
F
.39379 .49497 m .3938 .50016 L .39378 .50029 L F
.3938 .50016 m .39381 .50535 L .39378 .50029 L F
.39342 .50082 m .39349 .50603 L .39335 .50093 L .069 0 .411 r
F
.39217 .50796 m .39598 .51987 L .39239 .50764 L .673 .757 .914 r
F
.39199 .50184 m .39148 .50367 L .39241 .5023 L F
.39089 .50221 m .39088 .50224 L .3909 .50224 L F
.39075 .49695 m .39024 .50019 L .39138 .49852 L F
.39073 .4969 m .39073 .49696 L .39075 .49695 L F
.39066 .49672 m .39064 .49689 L .39073 .4969 L F
.3908 .4967 m .39106 .5073 L .39003 .49682 L .641 .4 .539 r
F
.39157 .50883 m .38943 .52051 L .39151 .52031 L .673 .757 .914 r
F
.39106 .5073 m .39155 .52728 L .39056 .50738 L .641 .4 .539 r
F
.39106 .5073 m .39056 .50738 L .39003 .49682 L F
.3901 .50515 m .39097 .50732 L .3919 .5071 L .673 .757 .914 r
F
.39097 .50732 m .39103 .50746 L .3916 .50722 L F
.3908 .4967 m .3916 .50722 L .39106 .5073 L .641 .4 .539 r
F
.39097 .50732 m .3916 .50722 L .3919 .5071 L .673 .757 .914 r
F
.38979 .49946 m .39082 .50202 L .39199 .50184 L F
.39082 .50202 m .39148 .50367 L .39199 .50184 L F
.39066 .49672 m .39075 .49695 L .39163 .49658 L F
.3908 .4967 m .39163 .49658 L .39161 .5019 L .641 .4 .539 r
F
.3912 .50196 m .39161 .5019 L .3916 .50722 L F
.3908 .4967 m .39161 .5019 L .3912 .50196 L F
.39103 .50746 m .39119 .50788 L .39181 .50719 L .673 .757 .914 r
F
.39103 .50746 m .39181 .50719 L .3916 .50722 L F
.39106 .5073 m .3916 .50722 L .39155 .52728 L .641 .4 .539 r
F
.3916 .50722 m .39181 .50719 L .3919 .5071 L .673 .757 .914 r
F
.39119 .50788 m .39598 .51987 L .39196 .5073 L F
.39119 .50788 m .39196 .5073 L .3919 .5071 L F
.39263 .50679 m .39329 .52627 L .39258 .52684 L .354 .175 .495 r
F
.39241 .5023 m .39309 .50478 L .39332 .50329 L .673 .757 .914 r
F
.39265 .49615 m .39287 .5066 L .39263 .50679 L .354 .175 .495 r
F
.39287 .5066 m .39329 .52627 L .39263 .50679 L F
.39349 .50603 m .39372 .52558 L .39343 .50611 L .069 0 .411 r
F
.39349 .50603 m .39343 .50611 L .39335 .50093 L F
.39567 .51419 m .40155 .52889 L .41384 .52561 L .673 .757 .914 r
F
.39239 .50764 m .39598 .51987 L .40055 .51865 L F
.39567 .51419 m .41384 .52561 L .40182 .51254 L F
.39565 .50852 m .40213 .51823 L .40746 .51569 L F
.39343 .46744 m .39379 .49497 L .39357 .4953 L .069 0 .411 r
F
.39343 .46744 m .39357 .4953 L .39336 .49561 L F
.39386 .46675 m .39391 .49423 L .39385 .49461 L 0 0 .133 r
F
.39386 .46675 m .39385 .49461 L .39379 .49497 L F
.39405 .49369 m .41356 .4973 L .41459 .49332 L .673 .757 .914 r
F
.38949 .49378 m .39548 .49465 L .39405 .49369 L F
.39548 .49465 m .41356 .4973 L .39405 .49369 L F
.39335 .50093 m .39343 .50611 L .39334 .50625 L .069 0 .411 r
F
.39148 .50367 m .39567 .51419 L .39241 .5023 L .673 .757 .914 r
F
.39336 .49561 m .39342 .50082 L .39335 .50093 L .069 0 .411 r
F
.39299 .49589 m .39336 .49561 L .39335 .50093 L .354 .175 .495 r
F
.40146 .50679 m .41341 .5198 L .42402 .51475 L .673 .757 .914 r
F
.40182 .51254 m .4245 .52054 L .40715 .51001 L F
.39334 .50624 m .40746 .51569 L .41161 .51244 L F
.39163 .49658 m .39172 .49686 L .39201 .49652 L F
.39172 .49686 m .39204 .49662 L .39201 .49652 L F
.39201 .49652 m .39204 .49662 L .39207 .49659 L F
.39451 .49548 m .40676 .50427 L .41089 .50103 L F
.39544 .50029 m .4113 .50675 L .41399 .503 L F
.3922 .50165 m .39195 .50176 L .39163 .49658 L .515 .301 .526 r
F
.39299 .49589 m .39335 .50093 L .39304 .50116 L .354 .175 .495 r
F
.39474 .49594 m .40676 .50427 L .39451 .49548 L .673 .757 .914 r
F
.39311 .49598 m .40676 .50427 L .39365 .49519 L F
.39548 .49465 m .41089 .50103 L .41356 .4973 L F
.38949 .49378 m .39896 .49699 L .39548 .49465 L F
.39896 .49699 m .41089 .50103 L .39548 .49465 L F
.39352 .46488 m .39246 .46405 L .39239 .49258 L .909 .63 .5 r
F
.39385 .50054 m .39401 .50089 L .39445 .5007 L .673 .757 .914 r
F
.38979 .49946 m .39358 .50075 L .39385 .50054 L F
.39385 .49461 m .39385 .49987 L .39379 .49497 L 0 0 .133 r
F
.3937 .50079 m .39401 .50089 L .39373 .50064 L .673 .757 .914 r
F
.39239 .50764 m .3933 .50863 L .39292 .50686 L F
.3933 .50863 m .39837 .51414 L .39346 .50759 L F
.3933 .50863 m .39346 .50759 L .39292 .50686 L F
.39284 .50131 m .39554 .50295 L .39358 .50075 L F
.39554 .50295 m .40715 .51001 L .39491 .50165 L F
.39554 .50295 m .39491 .50165 L .39358 .50075 L F
.39385 .49987 m .39384 .50512 L .3938 .50016 L 0 0 .133 r
F
.39172 .49686 m .39534 .50843 L .39204 .49662 L .673 .757 .914 r
F
.39384 .50512 m .39381 .50535 L .3938 .50016 L 0 0 .133 r
F
.39373 .50064 m .39401 .50089 L .39385 .50054 L .673 .757 .914 r
F
.39389 .49955 m .39372 .50454 L .39388 .50487 L .985 .728 .342 r
F
.39385 .49461 m .39391 .49423 L .39389 .49955 L 0 0 .133 r
F
.39385 .49461 m .39389 .49955 L .39385 .49987 L F
.39391 .49423 m .39382 .49938 L .39389 .49955 L .985 .728 .342 r
F
.39382 .49938 m .39372 .50454 L .39389 .49955 L F
.40146 .50679 m .42402 .51475 L .40676 .50427 L .673 .757 .914 r
F
.39358 .50075 m .40715 .51001 L .4113 .50675 L F
.39403 .50572 m .41161 .51244 L .4143 .50868 L F
.3922 .50165 m .39263 .50679 L .39228 .50694 L .515 .301 .526 r
F
.3901 .50515 m .39334 .50624 L .39403 .50572 L .673 .757 .914 r
F
.39334 .50624 m .41161 .51244 L .39403 .50572 L F
.39304 .50116 m .39309 .50643 L .39276 .50137 L .354 .175 .495 r
F
.39271 .50673 m .39292 .50686 L .39334 .50625 L .673 .757 .914 r
F
.39309 .50643 m .39329 .52627 L .39287 .5066 L .354 .175 .495 r
F
.39309 .50643 m .39287 .5066 L .39276 .50137 L F
.39384 .50512 m .39384 .52477 L .39381 .50535 L 0 0 .133 r
F
.39385 .49987 m .3938 .50016 L .39379 .49497 L F
.39358 .50075 m .3937 .50079 L .39373 .50064 L .673 .757 .914 r
F
.39299 .49589 m .39304 .50116 L .39265 .49615 L .354 .175 .495 r
F
.39304 .50116 m .39276 .50137 L .39265 .49615 L F
.3922 .50165 m .39264 .50147 L .39263 .50679 L .515 .301 .526 r
F
.3919 .5071 m .39239 .50764 L .39273 .50674 L .673 .757 .914 r
F
.39157 .50883 m .39151 .52031 L .3928 .51191 L F
.39228 .50694 m .39263 .50679 L .39258 .52684 L .515 .301 .526 r
F
.39212 .49637 m .39265 .49615 L .39264 .50147 L F
.39458 .49937 m .41399 .503 L .41503 .499 L .673 .757 .914 r
F
.39359 .50056 m .39349 .50072 L .39336 .49561 L .069 0 .411 r
F
.39357 .4953 m .39359 .50056 L .39336 .49561 L F
.38949 .49378 m .39311 .49598 L .39365 .49519 L .673 .757 .914 r
F
.39369 .49378 m .39345 .49329 L .39344 .49861 L .985 .728 .342 r
F
.39362 .50583 m .39349 .50603 L .39336 .49561 L .069 0 .411 r
F
.39356 .49885 m .39344 .49861 L .39343 .50393 L .985 .728 .342 r
F
.39369 .49378 m .39344 .49861 L .39356 .49885 L F
.39382 .49939 m .39608 .50038 L .39458 .49937 L .673 .757 .914 r
F
.38979 .49946 m .39416 .5001 L .39382 .49939 L F
.39416 .5001 m .39608 .50038 L .39382 .49939 L F
.39608 .50038 m .41399 .503 L .39458 .49937 L F
.39294 .49295 m .39239 .49258 L .39238 .4979 L .909 .63 .5 r
F
.39228 .50694 m .39196 .50707 L .39163 .49658 L .515 .301 .526 r
F
.3901 .50515 m .39271 .50673 L .39334 .50624 L .673 .757 .914 r
F
.3951 .50506 m .4143 .50868 L .41533 .50469 L F
.3901 .50515 m .39667 .50611 L .3951 .50506 L F
.39667 .50611 m .4143 .50868 L .3951 .50506 L F
.39283 .4982 m .39238 .4979 L .39236 .50322 L .909 .63 .5 r
F
.39401 .50089 m .4113 .50675 L .39544 .50029 L .673 .757 .914 r
F
.39304 .50116 m .39334 .50625 L .39309 .50643 L .354 .175 .495 r
F
.40676 .50427 m .43227 .50828 L .41089 .50103 L .673 .757 .914 r
F
.39415 .50442 m .41533 .50469 L .41465 .50073 L F
.3901 .50515 m .3951 .50506 L .39415 .50442 L F
.3951 .50506 m .41533 .50469 L .39415 .50442 L F
.39309 .50643 m .39334 .50625 L .39329 .52627 L .354 .175 .495 r
F
.39343 .50393 m .39232 .52288 L .39338 .52371 L .909 .63 .5 r
F
.38979 .49946 m .39445 .5007 L .39416 .5001 L .673 .757 .914 r
F
.39304 .50116 m .39335 .50093 L .39334 .50625 L .354 .175 .495 r
F
.39345 .49329 m .39306 .50368 L .39343 .50393 L .909 .63 .5 r
F
.39343 .50393 m .41465 .50073 L .4123 .49706 L .673 .757 .914 r
F
.3901 .50515 m .39415 .50442 L .39343 .50393 L F
.39357 .4953 m .39379 .49497 L .39378 .50029 L .069 0 .411 r
F
.39367 .50046 m .39378 .50029 L .39377 .50561 L F
.39357 .4953 m .39378 .50029 L .39367 .50046 L F
.39357 .4953 m .39377 .50561 L .39362 .50583 L F
.39334 .50625 m .39372 .52558 L .39329 .52627 L F
.39369 .49378 m .39364 .49901 L .39391 .49423 L .985 .728 .342 r
F
.39362 .50583 m .39372 .52558 L .39349 .50603 L .069 0 .411 r
F
.39352 .50722 m .39837 .51414 L .39565 .50852 L .673 .757 .914 r
F
.39292 .50686 m .39346 .50759 L .39352 .50722 L F
.39346 .50759 m .39837 .51414 L .39352 .50722 L F
.39385 .49987 m .39389 .49955 L .39388 .50487 L 0 0 .133 r
F
.39384 .50512 m .39388 .50487 L .39384 .52477 L F
.39385 .49987 m .39388 .50487 L .39384 .50512 L F
.39585 .49725 m .41434 .49504 L .41199 .49138 L .673 .757 .914 r
F
.39498 .49853 m .41434 .49504 L .39585 .49725 L F
.39397 .46593 m .39345 .49329 L .39369 .49378 L .985 .728 .342 r
F
.39397 .46593 m .39369 .49378 L .39391 .49423 L F
.39384 .49299 m .41459 .49332 L .41391 .48938 L .673 .757 .914 r
F
.38949 .49378 m .39618 .49366 L .39384 .49299 L F
.39618 .49366 m .41459 .49332 L .39384 .49299 L F
.39283 .4982 m .39236 .50322 L .39272 .50346 L .909 .63 .5 r
F
.39206 .50313 m .39312 .5033 L .39272 .50246 L .673 .757 .914 r
F
.3922 .50165 m .39228 .50694 L .39195 .50176 L .515 .301 .526 r
F
.38943 .52051 m .38876 .53586 L .40185 .53458 L .673 .757 .914 r
F
.38943 .52051 m .40185 .53458 L .39598 .51987 L F
.39163 .49658 m .39258 .52684 L .39155 .52728 L .515 .301 .526 r
F
.3901 .50515 m .39297 .50339 L .39206 .50313 L .673 .757 .914 r
F
.39297 .50339 m .39312 .5033 L .39206 .50313 L F
.3919 .5071 m .39217 .50796 L .39239 .50764 L F
.39228 .50694 m .39258 .52684 L .39196 .50707 L .515 .301 .526 r
F
.39498 .49853 m .41503 .499 L .41434 .49504 L .673 .757 .914 r
F
.3944 .49938 m .41503 .499 L .39498 .49853 L F
.39297 .50339 m .4123 .49706 L .40843 .49395 L F
.3901 .50515 m .39406 .5037 L .39297 .50339 L F
.39406 .5037 m .4123 .49706 L .39297 .50339 L F
.39212 .49637 m .3922 .50165 L .39163 .49658 L .515 .301 .526 r
F
.39175 .49772 m .39202 .4978 L .39239 .49258 L .81 .54 .531 r
F
.39246 .46405 m .39131 .49227 L .39148 .49232 L F
.39186 .49243 m .3913 .49759 L .39175 .49772 L F
.39246 .46405 m .39148 .49232 L .39186 .49243 L F
.39148 .49232 m .3913 .49759 L .39186 .49243 L F
.39352 .46488 m .39239 .49258 L .39294 .49295 L .909 .63 .5 r
F
.39352 .46488 m .39294 .49295 L .39345 .49329 L F
.38979 .49946 m .39236 .49789 L .39155 .49766 L .673 .757 .914 r
F
.38983 .5114 m .38943 .52051 L .39157 .50883 L F
.39001 .50746 m .39155 .52728 L .38996 .52749 L .641 .4 .539 r
F
.39082 .50202 m .38965 .50273 L .39089 .50221 L .673 .757 .914 r
F
.39064 .49689 m .38882 .50907 L .39073 .4969 L F
.39003 .49682 m .3903 .5021 L .39002 .50214 L .641 .4 .539 r
F
.38979 .49946 m .38967 .50219 L .39082 .50202 L .673 .757 .914 r
F
.38967 .50219 m .38965 .50273 L .39082 .50202 L F
.39002 .50214 m .39056 .50738 L .39001 .50746 L .641 .4 .539 r
F
.3903 .5021 m .39056 .50738 L .39002 .50214 L F
.39 .50746 m .38983 .5114 L .39097 .50732 L .673 .757 .914 r
F
.39056 .50738 m .39155 .52728 L .39001 .50746 L .641 .4 .539 r
F
.39097 .50732 m .38983 .5114 L .39157 .50883 L .673 .757 .914 r
F
.3901 .50515 m .39 .50746 L .39097 .50732 L F
.39364 .49901 m .39382 .49938 L .39391 .49423 L .985 .728 .342 r
F
.39369 .49378 m .39356 .49885 L .39364 .49901 L F
.39269 .49769 m .41199 .49138 L .40812 .48826 L .673 .757 .914 r
F
.39238 .4979 m .39198 .50311 L .39236 .50322 L .81 .54 .531 r
F
.39239 .49258 m .39219 .49784 L .39238 .4979 L F
.39219 .49784 m .39198 .50311 L .39238 .4979 L F
.39294 .49295 m .39283 .4982 L .39345 .49329 L .909 .63 .5 r
F
.39283 .4982 m .39272 .50346 L .39309 .49837 L F
.39283 .4982 m .39309 .49837 L .39345 .49329 L F
.39236 .49789 m .39432 .49781 L .39269 .49769 L .673 .757 .914 r
F
.38979 .49946 m .39334 .49817 L .39236 .49789 L F
.39334 .49817 m .39432 .49781 L .39236 .49789 L F
.39432 .49781 m .41199 .49138 L .39269 .49769 L F
.38949 .49378 m .39066 .49672 L .39201 .49652 L F
.39078 .49223 m .39021 .49751 L .39067 .49754 L .734 .477 .539 r
F
.39138 .46367 m .39039 .4922 L .39078 .49223 L F
.39039 .4922 m .39021 .49751 L .39078 .49223 L F
.39098 .49225 m .40772 .48263 L .40262 .48029 L .673 .757 .914 r
F
.38949 .49378 m .39188 .49231 L .39098 .49225 L F
.39188 .49231 m .40772 .48263 L .39098 .49225 L F
.39025 .49219 m .39103 .49219 L .39034 .49199 L F
.38949 .49378 m .39098 .49225 L .39025 .49219 L F
.39098 .49225 m .39103 .49219 L .39025 .49219 L F
.39138 .46367 m .39029 .46354 L .39022 .49219 L .734 .477 .539 r
F
.39039 .4922 m .39022 .49219 L .39021 .49751 L F
.39138 .46367 m .39022 .49219 L .39039 .4922 L F
.38979 .49946 m .3913 .49759 L .39071 .49755 L .673 .757 .914 r
F
.39067 .49754 m .39021 .49751 L .39015 .52237 L .734 .477 .539 r
F
.3913 .49759 m .39015 .52237 L .39124 .5225 L F
.39188 .49231 m .41157 .48573 L .40772 .48263 L .673 .757 .914 r
F
.38949 .49378 m .39323 .49241 L .39188 .49231 L F
.39323 .49241 m .41157 .48573 L .39188 .49231 L F
.39131 .49227 m .39067 .49754 L .3913 .49759 L .734 .477 .539 r
F
.39138 .46367 m .39078 .49223 L .39131 .49227 L F
.39078 .49223 m .39067 .49754 L .39131 .49227 L F
.38979 .49946 m .39155 .49766 L .3913 .49759 L .673 .757 .914 r
F
.39067 .49754 m .39015 .52237 L .3913 .49759 L .734 .477 .539 r
F
.39071 .49755 m .3913 .49759 L .39076 .49744 L .673 .757 .914 r
F
.39034 .49199 m .40262 .48029 L .39663 .47887 L F
.39103 .49219 m .40262 .48029 L .39034 .49199 L F
.39246 .46405 m .39186 .49243 L .39239 .49258 L .81 .54 .531 r
F
.38947 .5074 m .39001 .50746 L .38996 .52749 L .751 .491 .538 r
F
.38947 .5074 m .38996 .52749 L .38876 .50731 L F
.39534 .49164 m .41391 .48938 L .41157 .48573 L .673 .757 .914 r
F
.38949 .49378 m .41002 .49008 L .39534 .49164 L F
.41002 .49008 m .41391 .48938 L .39534 .49164 L F
.38853 .46839 m .39003 .49682 L .38921 .49672 L .751 .491 .538 r
F
.39029 .46354 m .38919 .46363 L .38912 .49231 L .66 .416 .54 r
F
.38935 .49699 m .38906 .49747 L .38932 .49768 L .673 .757 .914 r
F
.38921 .49672 m .39002 .50214 L .38934 .50206 L .751 .491 .538 r
F
.38979 .49946 m .38857 .50201 L .38966 .50244 L .673 .757 .914 r
F
.36826 .49985 m .36559 .49592 L .36456 .49992 L F
.38911 .49763 m .3887 .50307 L .3891 .50295 L .567 .342 .533 r
F
.38912 .49231 m .38891 .49769 L .38911 .49763 L F
.3868 .49572 m .3869 .50113 L .38679 .50104 L .929 .648 .488 r
F
.38979 .49946 m .38532 .49881 L .38282 .49959 L .673 .757 .914 r
F
.38891 .49769 m .3887 .50307 L .38911 .49763 L .567 .342 .533 r
F
.38282 .49959 m .38225 .49836 L .36826 .49985 L .673 .757 .914 r
F
.38532 .49881 m .38225 .49836 L .38282 .49959 L F
.38225 .49836 m .36559 .49592 L .36826 .49985 L F
.38968 .49225 m .38912 .49231 L .38911 .49763 L .66 .416 .54 r
F
.3901 .50515 m .38734 .50684 L .38814 .50716 L .673 .757 .914 r
F
.38493 .50339 m .37272 .49459 L .36857 .49785 L F
.3901 .50515 m .38687 .50319 L .38493 .50339 L F
.38657 .49927 m .38634 .505 L .38651 .50468 L 0 0 .372 r
F
.38532 .49881 m .36827 .49217 L .36559 .49592 L .673 .757 .914 r
F
.38979 .49946 m .38665 .49839 L .38532 .49881 L F
.38639 .49472 m .3864 .50042 L .38638 .5001 L .79 .631 .071 r
F
.38665 .49839 m .36827 .49217 L .38532 .49881 L .673 .757 .914 r
F
.38858 .49247 m .38847 .49783 L .38912 .49231 L .567 .342 .533 r
F
.38979 .49946 m .38826 .4978 L .38769 .49818 L .673 .757 .914 r
F
.3901 .50515 m .38677 .50636 L .38736 .50682 L F
.38979 .49946 m .38767 .50164 L .38857 .50201 L F
.38663 .49387 m .38635 .49968 L .38657 .49927 L 0 0 .372 r
F
.38638 .5001 m .38636 .49981 L .38636 .49436 L .79 .631 .071 r
F
.38636 .49436 m .38636 .49981 L .38635 .49968 L F
.38979 .49946 m .37242 .48891 L .36827 .49217 L .673 .757 .914 r
F
.38737 .50349 m .37806 .49205 L .37272 .49459 L F
.38802 .50178 m .38844 .50195 L .38843 .50728 L .845 .571 .524 r
F
.3901 .50515 m .38831 .5032 L .38737 .50349 L .673 .757 .914 r
F
.38657 .49927 m .38635 .49968 L .38634 .505 L 0 0 .372 r
F
.38662 .50077 m .38679 .50104 L .38677 .50636 L .989 .72 .388 r
F
.38664 .50615 m .38677 .50636 L .38672 .52615 L F
.38662 .50077 m .38677 .50636 L .38664 .50615 L F
.38799 .50731 m .3876 .50771 L .38877 .50792 L .673 .757 .914 r
F
.3876 .50771 m .38115 .51433 L .38809 .50849 L F
.3876 .50771 m .38809 .50849 L .38877 .50792 L F
.38651 .50468 m .38675 .50425 L .38688 .49872 L 0 0 .372 r
F
.3869 .50113 m .38739 .52675 L .38679 .50104 L .929 .648 .488 r
F
.38688 .49872 m .38675 .50425 L .38687 .50404 L 0 0 .372 r
F
.38831 .5032 m .37806 .49205 L .38737 .50349 L .673 .757 .914 r
F
.38847 .49783 m .38836 .50318 L .38891 .49769 L .567 .342 .533 r
F
.38809 .50714 m .38843 .50728 L .38838 .52722 L .845 .571 .524 r
F
.38836 .50318 m .38794 .5228 L .3887 .50307 L .567 .342 .533 r
F
.38836 .50318 m .3887 .50307 L .38891 .49769 L F
.38847 .49783 m .38891 .49769 L .38912 .49231 L F
.38687 .50319 m .37272 .49459 L .38493 .50339 L .673 .757 .914 r
F
.38957 .49758 m .38911 .49763 L .3891 .50295 L .66 .416 .54 r
F
.38946 .50291 m .3891 .50295 L .38905 .52246 L F
.38957 .49758 m .3891 .50295 L .38946 .50291 L F
.38949 .49378 m .38935 .49692 L .39066 .49672 L .673 .757 .914 r
F
.38968 .49225 m .38911 .49763 L .38957 .49758 L .66 .416 .54 r
F
.39029 .46354 m .38912 .49231 L .38968 .49225 L F
.39022 .49219 m .38905 .52246 L .39015 .52237 L F
.39029 .46354 m .38968 .49225 L .39022 .49219 L F
.38949 .49378 m .39025 .49219 L .38955 .49226 L .673 .757 .914 r
F
.38968 .49225 m .38957 .49758 L .39022 .49219 L .66 .416 .54 r
F
.38979 .49946 m .38988 .49755 L .38906 .49763 L .673 .757 .914 r
F
.38957 .49758 m .38946 .50291 L .38984 .49755 L .66 .416 .54 r
F
.38957 .49758 m .38984 .49755 L .39022 .49219 L F
.38831 .49256 m .38801 .49265 L .388 .49797 L .567 .342 .533 r
F
.38919 .46363 m .38858 .49247 L .38912 .49231 L F
.38919 .46363 m .38801 .49265 L .38831 .49256 L F
.38949 .49378 m .39015 .47847 L .38363 .47911 L .673 .757 .914 r
F
.38906 .49763 m .39047 .48408 L .38391 .48472 L F
.38955 .49226 m .39034 .49199 L .38957 .49178 L F
.39025 .49219 m .39034 .49199 L .38955 .49226 L F
.38988 .49755 m .39047 .48408 L .38906 .49763 L F
.38831 .49256 m .388 .49797 L .38815 .49793 L .567 .342 .533 r
F
.38907 .49764 m .38391 .48472 L .38833 .49787 L .673 .757 .914 r
F
.38815 .49793 m .388 .49797 L .38799 .50329 L .567 .342 .533 r
F
.3872 .4932 m .38688 .49872 L .38703 .49862 L .398 .209 .505 r
F
.38626 .49575 m .38524 .49637 L .3872 .49613 L .673 .757 .914 r
F
.38645 .49421 m .38635 .49968 L .38663 .49387 L 0 0 .372 r
F
.38922 .50294 m .39077 .48976 L .38421 .49041 L .673 .757 .914 r
F
.3901 .50515 m .3902 .50283 L .38922 .50294 L F
.38946 .50291 m .38981 .50287 L .39001 .49753 L .66 .416 .54 r
F
.38984 .49755 m .39001 .49753 L .39022 .49219 L F
.38946 .50291 m .39001 .49753 L .38984 .49755 L F
.39034 .49199 m .39663 .47887 L .38957 .49178 L .673 .757 .914 r
F
.39148 .49232 m .39131 .49227 L .3913 .49759 L .81 .54 .531 r
F
.38988 .49755 m .39698 .48448 L .39047 .48408 L .673 .757 .914 r
F
.38979 .49946 m .39076 .49745 L .38988 .49755 L F
.39186 .49243 m .39175 .49772 L .39239 .49258 L .81 .54 .531 r
F
.39076 .49745 m .39698 .48448 L .38988 .49755 L .673 .757 .914 r
F
.3902 .50283 m .39077 .48976 L .38922 .50294 L F
.38946 .50291 m .38905 .52246 L .38981 .50287 L .66 .416 .54 r
F
.38957 .49178 m .39663 .47887 L .39015 .47847 L .673 .757 .914 r
F
.39246 .46405 m .39138 .46367 L .39131 .49227 L .81 .54 .531 r
F
.39293 .49755 m .40812 .48826 L .39251 .49668 L .673 .757 .914 r
F
.39272 .50346 m .39306 .50368 L .39325 .49849 L .909 .63 .5 r
F
.39309 .49837 m .39325 .49849 L .39345 .49329 L F
.39272 .50346 m .39325 .49849 L .39309 .49837 L F
.38979 .49946 m .3944 .49938 L .39446 .4993 L .673 .757 .914 r
F
.39367 .49876 m .39446 .4993 L .39498 .49853 L F
.38979 .49946 m .39446 .4993 L .39367 .49876 L F
.39356 .49885 m .39343 .50393 L .39364 .49901 L .985 .728 .342 r
F
.38979 .49946 m .39498 .49853 L .39585 .49725 L .673 .757 .914 r
F
.39119 .50288 m .40331 .4916 L .39728 .49017 L F
.3901 .50515 m .39206 .50313 L .39119 .50288 L F
.39364 .49901 m .39358 .50425 L .39382 .49938 L .985 .728 .342 r
F
.39416 .5001 m .39445 .5007 L .39544 .50029 L .673 .757 .914 r
F
.39206 .50313 m .40331 .4916 L .39119 .50288 L F
.39175 .49772 m .3913 .49759 L .39128 .50291 L .81 .54 .531 r
F
.39164 .50301 m .39128 .50291 L .39124 .5225 L F
.39175 .49772 m .39128 .50291 L .39164 .50301 L F
.39155 .49766 m .39293 .49755 L .39251 .49668 L .673 .757 .914 r
F
.39236 .49789 m .39293 .49755 L .39155 .49766 L F
.39076 .49744 m .403 .48591 L .39698 .48448 L F
.39294 .49295 m .39238 .4979 L .39283 .4982 L .909 .63 .5 r
F
.39155 .49766 m .403 .48591 L .39076 .49744 L .673 .757 .914 r
F
.39175 .49772 m .39164 .50301 L .39202 .4978 L .81 .54 .531 r
F
.3901 .50515 m .3919 .5071 L .39273 .50674 L .673 .757 .914 r
F
.39164 .50301 m .39124 .5225 L .39198 .50311 L .81 .54 .531 r
F
.38979 .49946 m .39284 .50131 L .39358 .50075 L .673 .757 .914 r
F
.39164 .50301 m .39198 .50311 L .39239 .49258 L .81 .54 .531 r
F
.39236 .50322 m .39124 .5225 L .39232 .52288 L F
.39198 .50311 m .39124 .5225 L .39236 .50322 L F
.39272 .50246 m .40843 .49395 L .40331 .4916 L .673 .757 .914 r
F
.39358 .50425 m .39372 .50454 L .39382 .49938 L .985 .728 .342 r
F
.39359 .50056 m .39362 .50583 L .39349 .50072 L .069 0 .411 r
F
.39364 .49901 m .39343 .50393 L .39358 .50425 L .985 .728 .342 r
F
.39312 .5033 m .40843 .49395 L .39272 .50246 L .673 .757 .914 r
F
.39358 .50425 m .39338 .52371 L .39372 .50454 L .985 .728 .342 r
F
.39365 .49519 m .39474 .49594 L .39451 .49548 L .673 .757 .914 r
F
.39251 .49668 m .40812 .48826 L .403 .48591 L F
.39415 .50442 m .41465 .50073 L .39343 .50393 L F
.39273 .50674 m .39239 .50764 L .39292 .50686 L F
.39272 .50346 m .39232 .52288 L .39306 .50368 L .909 .63 .5 r
F
.39306 .50368 m .39232 .52288 L .39343 .50393 L F
.39272 .50346 m .39236 .50322 L .39232 .52288 L F
.39334 .50625 m .40746 .51569 L .39334 .50624 L .673 .757 .914 r
F
.39292 .50686 m .40746 .51569 L .39334 .50625 L F
.39362 .50583 m .39377 .50561 L .39372 .52558 L .069 0 .411 r
F
.39837 .51414 m .40213 .51823 L .39565 .50852 L .673 .757 .914 r
F
.39343 .50611 m .39372 .52558 L .39334 .50625 L .069 0 .411 r
F
.39358 .50425 m .39343 .50393 L .39338 .52371 L .985 .728 .342 r
F
.39381 .50535 m .39384 .52477 L .39377 .50561 L 0 0 .133 r
F
.39388 .50487 m .39338 .52371 L .39384 .52477 L .985 .728 .342 r
F
.39372 .50454 m .39338 .52371 L .39388 .50487 L F
.39837 .51414 m .40055 .51865 L .40213 .51823 L .673 .757 .914 r
F
.39239 .50764 m .40055 .51865 L .39837 .51414 L F
.3891 .50295 m .38794 .5228 L .38905 .52246 L .567 .342 .533 r
F
.3887 .50307 m .38794 .5228 L .3891 .50295 L F
.38833 .49787 m .38391 .48472 L .37775 .48637 L .673 .757 .914 r
F
.38809 .50714 m .38838 .52722 L .38778 .50702 L .845 .571 .524 r
F
.38836 .50318 m .38799 .50329 L .38794 .5228 L .567 .342 .533 r
F
.38583 .50397 m .38144 .50221 L .38253 .50306 L .673 .757 .914 r
F
.3901 .50515 m .38624 .50384 L .38583 .50397 L F
.38624 .50384 m .38144 .50221 L .38583 .50397 L F
.38144 .50221 m .36857 .49785 L .38253 .50306 L F
.37913 .50354 m .36777 .49898 L .36589 .50161 L F
.38809 .50714 m .38778 .50702 L .38762 .50162 L .845 .571 .524 r
F
.38799 .50329 m .38682 .52359 L .38794 .5228 L .398 .209 .505 r
F
.38721 .5067 m .38744 .50688 L .38739 .52675 L .929 .648 .488 r
F
.38721 .5067 m .38739 .52675 L .387 .50654 L F
.38724 .5038 m .38682 .52359 L .38799 .50329 L .398 .209 .505 r
F
.38677 .50636 m .37937 .50905 L .38736 .50682 L .673 .757 .914 r
F
.37937 .50905 m .36792 .51323 L .3782 .50984 L F
.37937 .50905 m .3782 .50984 L .38736 .50682 L F
.38949 .49378 m .3722 .48327 L .36807 .48652 L F
.38769 .49818 m .37775 .48637 L .37242 .48891 L F
.38639 .49472 m .38638 .5001 L .38636 .49436 L .79 .631 .071 r
F
.38645 .49421 m .38636 .49436 L .38635 .49968 L 0 0 .372 r
F
.38826 .4978 m .37775 .48637 L .38769 .49818 L .673 .757 .914 r
F
.38703 .49862 m .38688 .49872 L .38687 .50404 L .398 .209 .505 r
F
.38724 .5038 m .38687 .50404 L .38682 .52359 L F
.38342 .50635 m .38229 .50655 L .38299 .50664 L .673 .757 .914 r
F
.38342 .50635 m .38299 .50664 L .38528 .5069 L F
.38229 .50655 m .36555 .50957 L .38528 .5069 L F
.38637 .50549 m .38639 .50574 L .38634 .52545 L .79 .631 .071 r
F
.3868 .50571 m .38262 .51442 L .3869 .50714 L .673 .757 .914 r
F
.38714 .50696 m .38651 .50734 L .3876 .50771 L F
.38651 .50734 m .38428 .50871 L .38656 .50802 L F
.38651 .50734 m .38656 .50802 L .3876 .50771 L F
.38634 .505 m .38634 .52545 L .38629 .52463 L .79 .631 .071 r
F
.38635 .49968 m .38635 .50516 L .38634 .505 L F
.38635 .50516 m .38634 .52545 L .38634 .505 L F
.38639 .50574 m .38672 .52615 L .38634 .52545 L .989 .72 .388 r
F
.38656 .50802 m .38428 .50871 L .38661 .50873 L .673 .757 .914 r
F
.38636 .49981 m .38634 .52545 L .38635 .49968 L .79 .631 .071 r
F
.38651 .50468 m .38634 .505 L .38629 .52463 L 0 0 .372 r
F
.37148 .51065 m .36343 .52652 L .3766 .513 L .673 .757 .914 r
F
.38428 .50871 m .36792 .51323 L .37179 .51634 L F
.38736 .50682 m .38487 .50764 L .38428 .50871 L F
.38487 .50764 m .36792 .51323 L .38428 .50871 L F
.38115 .51433 m .37691 .51868 L .37852 .51906 L F
.38115 .51433 m .37852 .51906 L .38293 .52011 L F
.38657 .49927 m .38651 .50468 L .38688 .49872 L 0 0 .372 r
F
.38647 .50587 m .38672 .52615 L .38639 .50574 L .989 .72 .388 r
F
.38651 .50468 m .38629 .52463 L .38675 .50425 L 0 0 .372 r
F
.38661 .50873 m .38428 .50871 L .38115 .51433 L .673 .757 .914 r
F
.38049 .51022 m .3766 .513 L .37868 .51349 L F
.38049 .51022 m .37868 .51349 L .38262 .51442 L F
.38428 .50871 m .37179 .51634 L .38115 .51433 L F
.38687 .50404 m .38629 .52463 L .38682 .52359 L 0 0 .372 r
F
.38675 .50425 m .38629 .52463 L .38687 .50404 L F
.74623 .87481 m .74253 .87309 L .7428 .87529 L .669 .437 .56 r
F
.74623 .87481 m .74596 .87261 L .74253 .87309 L F
0 g
.73931 .8741 m
.74253 .87309 L
s
.64615 .64763 m .65909 .64573 L .65959 .6503 L .794 .542 .556 r
F
.127 .923 .03 r
.61651 .57054 m
.61658 .57112 L
s
.64615 .64763 m .64564 .64306 L .65909 .64573 L .794 .542 .556 r
F
0 g
.65909 .64573 m
.67365 .64611 L
s
.3068 .53777 m .3065 .53209 L .29113 .52506 L .859 .596 .54 r
F
0 g
.3065 .53209 m
.31813 .5414 L
s
.74963 .87491 m .74596 .87261 L .74623 .87481 L .731 .482 .551 r
F
0 g
.74253 .87309 m
.74596 .87261 L
s
.74596 .87261 m
.74936 .87272 L
s
.74963 .87491 m
.75276 .87558 L
s
.67467 .65526 m .67416 .65069 L .68885 .64875 L .673 .453 .579 r
F
.6601 .65488 m .67416 .65069 L .67467 .65526 L .733 .497 .57 r
F
.127 .923 .03 r
.66417 .65366 m
.66428 .65043 L
s
.6601 .65488 m .65959 .6503 L .67416 .65069 L .733 .497 .57 r
F
.67479 .63936 m .67416 .65069 L .68885 .64875 L .683 .77 .917 r
F
.66508 .63911 m .67416 .65069 L .67479 .63936 L F
.66508 .63911 m .65959 .6503 L .67416 .65069 L F
.52662 .65899 m .52307 .64602 L .51765 .65721 L F
.52662 .65899 m .53654 .64869 L .52307 .64602 L F
.6557 .63265 m .65917 .64556 L .66463 .63442 L F
.6557 .63265 m .64579 .6429 L .65917 .64556 L F
.127 .923 .03 r
.61658 .57112 m
.62601 .64183 L
s
.70085 .54616 m .72079 .53444 L .69854 .54251 L .673 .758 .914 r
F
.70085 .54616 m .7254 .54175 L .72079 .53444 L F
.65434 .53197 m .63303 .52473 L .62763 .53219 L .673 .757 .914 r
F
.65849 .52874 m .63303 .52473 L .65434 .53197 L F
.2786 .54994 m .27366 .53216 L .26656 .54709 L F
.2786 .54994 m .29173 .53643 L .27366 .53216 L F
.2328 .64231 m .21811 .65142 L .23457 .64493 L .683 .77 .917 r
F
.2328 .64231 m .21456 .64619 L .21811 .65142 L F
.57412 .39191 m .57261 .41357 L .58163 .39434 L .654 .726 .902 r
F
.57412 .39191 m .55759 .40871 L .57261 .41357 L F
.59795 .3952 m .60522 .41528 L .6206 .41201 L F
.58976 .39546 m .60522 .41528 L .59795 .3952 L F
0 g
.73958 .8763 m
.7428 .87529 L
s
.56827 .38098 m .55818 .40126 L .57462 .38454 L .654 .726 .902 r
F
.56827 .38098 m .54547 .39415 L .55818 .40126 L F
.53474 .39989 m .52151 .42207 L .5444 .40885 L F
.53474 .39989 m .50702 .40865 L .52151 .42207 L F
0 g
.52151 .42207 m
.54067 .43278 L
s
.68885 .64875 m .70216 .64006 L .70267 .64464 L .606 .405 .583 r
F
.68936 .65333 m .68885 .64875 L .70267 .64464 L F
.67467 .65526 m .68885 .64875 L .68936 .65333 L .673 .453 .579 r
F
.68459 .63807 m .68885 .64875 L .70267 .64464 L .683 .77 .917 r
F
.67479 .63936 m .68885 .64875 L .68459 .63807 L F
0 g
.67416 .65069 m
.68885 .64875 L
s
.30581 .64891 m .30762 .63544 L .3081 .64002 L 0 0 .38 r
F
.30628 .65349 m .30581 .64891 L .3081 .64002 L F
.28771 .64695 m .30581 .64891 L .3081 .64002 L .683 .77 .917 r
F
0 g
.30208 .65419 m
.30581 .64891 L
s
.60598 .38618 m .62086 .40454 L .63414 .39878 L .654 .726 .902 r
F
.59833 .38781 m .62086 .40454 L .60598 .38618 L F
.36337 .42304 m .32981 .42092 L .36004 .42778 L F
.72506 .53607 m .74271 .52069 L .72045 .52876 L .673 .757 .914 r
F
.72506 .53607 m .74962 .53165 L .74271 .52069 L F
.5171 .65275 m .50798 .64123 L .50743 .65249 L .683 .77 .917 r
F
.5171 .65275 m .52249 .64161 L .50798 .64123 L F
.127 .923 .03 r
.52045 .64155 m
.52062 .58298 L
s
.51976 .64154 m
.52062 .58298 L
s
0 g
.74623 .87481 m
.74963 .87491 L
s
.49413 .76757 m .49655 .77668 L .50014 .76946 L .645 .732 .913 r
F
.127 .923 .03 r
.38267 .68746 m
.38272 .69106 L
s
.49413 .76757 m .48754 .77385 L .49655 .77668 L .645 .732 .913 r
F
0 g
.49655 .77668 m
.50356 .77766 L
s
.48145 .66957 m .4685 .66228 L .45918 .66978 L .683 .77 .917 r
F
.48943 .66556 m .4685 .66228 L .48145 .66957 L F
.42089 .43096 m .44562 .41715 L .41793 .42589 L .654 .726 .902 r
F
.42089 .43096 m .45153 .42729 L .44562 .41715 L F
.4685 .66228 m .45869 .66521 L .45918 .66978 L .403 .258 .569 r
F
0 g
.45314 .67827 m
.45918 .66978 L
s
.4685 .66228 m .46801 .6577 L .45869 .66521 L .403 .258 .569 r
F
0 g
.45265 .67369 m
.45869 .66521 L
s
.51611 .77783 m .52557 .7723 L .52533 .77607 L .597 .38 .558 r
F
.51318 .77023 m .51611 .77783 L .52533 .77607 L .645 .732 .913 r
F
0 g
.50722 .77802 m
.51611 .77783 L
s
.7428 .87529 m
.74623 .87481 L
s
.26626 .54141 m .25385 .52526 L .25326 .5406 L .673 .757 .914 r
F
.26626 .54141 m .27337 .52647 L .25385 .52526 L F
.2842 .65718 m .30628 .65349 L .28819 .65152 L .683 .77 .917 r
F
.2681 .65239 m .2842 .65718 L .28819 .65152 L F
.26501 .65489 m .2842 .65718 L .2681 .65239 L F
.74962 .53165 m .74928 .52597 L .74236 .515 L .986 .71 .373 r
F
0 g
.74928 .52597 m
.75117 .53783 L
s
.47987 .76973 m .48779 .77008 L .48754 .77385 L .856 .609 .564 r
F
.47987 .76973 m .48012 .76596 L .48779 .77008 L F
.48927 .76105 m .48779 .77008 L .49438 .7638 L .645 .732 .913 r
F
.48927 .76105 m .48012 .76596 L .48779 .77008 L F
0 g
.48779 .77008 m
.49058 .77095 L
s
.70267 .64464 m .70216 .64006 L .71418 .63405 L .524 .345 .581 r
F
0 g
.69552 .64204 m
.70216 .64006 L
s
.44214 .53675 m .45428 .52132 L .45459 .527 L .387 .233 .548 r
F
.42481 .52622 m .44214 .53675 L .45459 .527 L .673 .757 .914 r
F
.41415 .53129 m .44214 .53675 L .42481 .52622 L F
0 g
.42615 .54434 m
.44214 .53675 L
s
.6982 .53682 m .71279 .52255 L .69437 .53372 L .673 .757 .914 r
F
.6982 .53682 m .72045 .52876 L .71279 .52255 L F
.63303 .52473 m .60362 .52867 L .62763 .53219 L F
.52557 .7723 m .53381 .76532 L .53357 .7691 L .5 .3 .539 r
F
.52533 .77607 m .52557 .7723 L .53357 .7691 L F
.51957 .76528 m .52557 .7723 L .53357 .7691 L .645 .732 .913 r
F
.127 .923 .03 r
.55189 .66405 m
.55196 .66042 L
s
.51343 .76646 m .52557 .7723 L .51957 .76528 L .645 .732 .913 r
F
0 g
.51978 .7734 m
.52557 .7723 L
s
.36382 .41575 m .3369 .40415 L .33026 .41364 L .654 .726 .902 r
F
.36898 .4118 m .3369 .40415 L .36382 .41575 L F
.36954 .40459 m .34789 .38911 L .33763 .39698 L F
.37615 .40172 m .34789 .38911 L .36954 .40459 L F
.69321 .63066 m .70203 .63992 L .71399 .63394 L .683 .77 .917 r
F
.68404 .63339 m .70203 .63992 L .69321 .63066 L F
.54798 .65347 m .54748 .64889 L .53604 .64411 L .86 .591 .53 r
F
0 g
.54748 .64889 m
.5561 .65545 L
s
.41838 .41861 m .43637 .40091 L .41353 .41413 L .654 .726 .902 r
F
.41838 .41861 m .44606 .40986 L .43637 .40091 L F
.41386 .40691 m .42384 .38663 L .40749 .40336 L F
.41386 .40691 m .43658 .39375 L .42384 .38663 L F
.3369 .40415 m .30001 .40678 L .33026 .41364 L F
.49769 .65378 m .49336 .64315 L .47962 .64725 L .683 .77 .917 r
F
.50743 .65249 m .49336 .64315 L .49769 .65378 L F
.127 .923 .03 r
.50569 .63744 m
.50576 .57438 L
s
0 g
.64538 .41469 m
.65477 .4127 L
s
.6549 .5433 m .62805 .54352 L .65218 .54704 L .673 .758 .914 r
F
.45196 .42 m .47375 .40111 L .44606 .40986 L .654 .726 .902 r
F
.45196 .42 m .4826 .41633 L .47375 .40111 L F
.69394 .52809 m .70215 .51231 L .68888 .52576 L .673 .757 .914 r
F
.69394 .52809 m .71227 .51697 L .70215 .51231 L F
.22818 .55085 m .21607 .5378 L .20013 .5454 L F
.24046 .54757 m .21607 .5378 L .22818 .55085 L F
.50743 .65249 m .50798 .64123 L .49336 .64315 L .683 .77 .917 r
F
.127 .923 .03 r
.50576 .57438 m
.51965 .64153 L
s
.48893 .66099 m .47998 .65168 L .46801 .6577 L .683 .77 .917 r
F
.49813 .65824 m .47998 .65168 L .48893 .66099 L F
.24017 .54188 m .2342 .52718 L .21578 .53212 L .673 .757 .914 r
F
.25326 .5406 m .2342 .52718 L .24017 .54188 L F
.72619 .42254 m .7041 .40797 L .7037 .41526 L .794 .542 .556 r
F
.72579 .42983 m .72619 .42254 L .7037 .41526 L F
0 g
.72619 .42254 m
.74528 .43326 L
s
.64665 .65221 m .65959 .6503 L .6601 .65488 L .794 .542 .556 r
F
.127 .923 .03 r
.65892 .70173 m
.65986 .65483 L
s
.64665 .65221 m .64615 .64763 L .65959 .6503 L .794 .542 .556 r
F
.65611 .63732 m .65959 .6503 L .66508 .63911 L .683 .77 .917 r
F
.65611 .63732 m .64615 .64763 L .65959 .6503 L F
0 g
.65959 .6503 m
.67416 .65069 L
s
.127 .923 .03 r
.62601 .64183 m
.62665 .64662 L
s
.6753 .64394 m .67467 .65526 L .68936 .65333 L .683 .77 .917 r
F
.66558 .64368 m .67467 .65526 L .6753 .64394 L F
.127 .923 .03 r
.66574 .66804 m
.66614 .6557 L
s
.66681 .66812 m
.66707 .65579 L
s
.66558 .64368 m .6601 .65488 L .67467 .65526 L .683 .77 .917 r
F
.127 .923 .03 r
.66707 .65579 m
.66708 .65506 L
s
.66614 .6557 m
.66616 .65504 L
s
.661 .75248 m
.66379 .66553 L
s
.66379 .66553 m
.66413 .65499 L
s
.52712 .66357 m .52357 .6506 L .51814 .66179 L .683 .77 .917 r
F
.52712 .66357 m .53704 .65327 L .52357 .6506 L F
.23318 .64691 m .21841 .65606 L .23496 .64954 L F
.23318 .64691 m .21485 .6508 L .21841 .65606 L F
.32358 .52938 m .33491 .53301 L .33521 .53869 L .931 .657 .497 r
F
.32358 .52938 m .32328 .52369 L .33491 .53301 L F
.34544 .51562 m .33491 .53301 L .35319 .52183 L .673 .757 .914 r
F
.34544 .51562 m .32328 .52369 L .33491 .53301 L F
0 g
.33491 .53301 m
.3404 .53552 L
s
.38262 .51442 m .37545 .52937 L .38845 .53018 L .673 .757 .914 r
F
.28706 .64235 m .30734 .63546 L .28857 .63645 L .683 .77 .917 r
F
.26905 .6404 m .28706 .64235 L .28857 .63645 L F
.26707 .64321 m .28706 .64235 L .26905 .6404 L F
.33763 .39698 m .31083 .38543 L .30093 .3996 L .654 .726 .902 r
F
.25326 .5406 m .25385 .52526 L .2342 .52718 L .673 .757 .914 r
F
.68936 .65333 m .70267 .64464 L .70318 .64922 L .606 .405 .583 r
F
.6851 .64265 m .68936 .65333 L .70318 .64922 L .683 .77 .917 r
F
.6753 .64394 m .68936 .65333 L .6851 .64265 L F
0 g
.67467 .65526 m
.68936 .65333 L
s
.3068 .53777 m .29113 .52506 L .29143 .53074 L .859 .596 .54 r
F
.3071 .54345 m .3068 .53777 L .29143 .53074 L F
0 g
.3068 .53777 m
.31843 .54708 L
s
.30997 .39254 m .30047 .39949 L .30001 .40678 L .058 0 .387 r
F
.30997 .39254 m .31042 .38526 L .30047 .39949 L F
0 g
.29672 .41512 m
.30047 .39949 L
s
.30628 .65349 m .3081 .64002 L .30857 .6446 L 0 0 .38 r
F
.28819 .65152 m .30628 .65349 L .30857 .6446 L .683 .77 .917 r
F
0 g
.3003 .66198 m
.30628 .65349 L
s
.65456 .53762 m .63315 .53034 L .62772 .53783 L .673 .757 .914 r
F
.65874 .53437 m .63315 .53034 L .65456 .53762 L F
.51765 .65721 m .50849 .64563 L .50793 .65696 L .683 .77 .917 r
F
.51765 .65721 m .52307 .64602 L .50849 .64563 L F
.58934 .40275 m .58844 .4231 L .6048 .42257 L .654 .726 .902 r
F
.58121 .40163 m .58844 .4231 L .58934 .40275 L F
.58121 .40163 m .57219 .42086 L .58844 .4231 L F
.48902 .76483 m .48754 .77385 L .49413 .76757 L .645 .732 .913 r
F
.48902 .76483 m .47987 .76973 L .48754 .77385 L F
0 g
.48754 .77385 m
.49655 .77668 L
s
.4826 .41633 m .48304 .40904 L .47419 .39382 L .99 .743 .457 r
F
0 g
.48304 .40904 m
.48561 .425 L
s
.47432 .76084 m .48037 .76219 L .48012 .76596 L .926 .677 .542 r
F
.127 .923 .03 r
.38272 .69106 m
.38351 .74822 L
s
.47432 .76084 m .47457 .75706 L .48037 .76219 L .926 .677 .542 r
F
0 g
.48037 .76219 m
.48376 .76401 L
s
.52533 .77607 m .53357 .7691 L .53332 .77287 L .5 .3 .539 r
F
.51933 .76905 m .52533 .77607 L .53332 .77287 L .645 .732 .913 r
F
.127 .923 .03 r
.55182 .66768 m
.55189 .66405 L
s
.51318 .77023 m .52533 .77607 L .51933 .76905 L .645 .732 .913 r
F
0 g
.51611 .77783 m
.52533 .77607 L
s
.48576 .75383 m .48051 .76211 L .48961 .75723 L .645 .732 .913 r
F
.48576 .75383 m .47474 .75701 L .48051 .76211 L F
.65849 .52874 m .64134 .51826 L .63303 .52473 L .673 .757 .914 r
F
.66381 .52622 m .64134 .51826 L .65849 .52874 L F
.53357 .7691 m .53381 .76532 L .54004 .76091 L .352 .179 .501 r
F
0 g
.52811 .76761 m
.53381 .76532 L
s
.7254 .54175 m .74305 .52637 L .72079 .53444 L .673 .758 .914 r
F
.7254 .54175 m .74996 .53734 L .74305 .52637 L F
.52506 .75931 m .53368 .76523 L .53988 .76084 L .645 .732 .913 r
F
.51976 .76144 m .53368 .76523 L .52506 .75931 L F
.70267 .64464 m .71418 .63405 L .71469 .63862 L .524 .345 .581 r
F
.70318 .64922 m .70267 .64464 L .71469 .63862 L F
.69381 .63533 m .70267 .64464 L .71469 .63862 L .683 .77 .917 r
F
.68459 .63807 m .70267 .64464 L .69381 .63533 L F
0 g
.69603 .64662 m
.70267 .64464 L
s
.54798 .65347 m .53604 .64411 L .53654 .64869 L .86 .591 .53 r
F
.54847 .65804 m .54798 .65347 L .53654 .64869 L F
0 g
.54798 .65347 m
.5566 .66002 L
s
.21578 .53212 m .19956 .53403 L .19985 .53971 L .514 .328 .566 r
F
.21578 .53212 m .21549 .52643 L .19956 .53403 L F
0 g
.1872 .54377 m
.19956 .53403 L
s
.65518 .40541 m
.67046 .40491 L
s
.67367 .40481 m
.67484 .40477 L
s
.26656 .54709 m .25414 .53095 L .25355 .54629 L .673 .757 .914 r
F
.26656 .54709 m .27366 .53216 L .25414 .53095 L F
.7037 .41526 m .7041 .40797 L .67974 .40461 L .732 .487 .557 r
F
0 g
.7041 .40797 m
.72659 .41526 L
s
.74962 .53165 m .74236 .515 L .74271 .52069 L .986 .71 .373 r
F
.74996 .53734 m .74962 .53165 L .74271 .52069 L F
0 g
.74962 .53165 m
.75151 .54351 L
s
.49813 .65824 m .49379 .64757 L .47998 .65168 L .683 .77 .917 r
F
.50793 .65696 m .49379 .64757 L .49813 .65824 L F
.3766 .513 m .36343 .52652 L .37545 .52937 L .673 .757 .914 r
F
.69854 .54251 m .71313 .52823 L .69471 .5394 L .673 .758 .914 r
F
.69854 .54251 m .72079 .53444 L .71313 .52823 L F
.19492 .64601 m .19605 .65012 L .19652 .6547 L .793 .576 .01 r
F
.19492 .64601 m .19445 .64143 L .19605 .65012 L F
0 g
.19605 .65012 m
.19882 .65421 L
s
.63315 .53034 m .60359 .5343 L .62772 .53783 L .673 .757 .914 r
F
.2135 .64042 m .19633 .65006 L .21456 .64619 L .683 .77 .917 r
F
.2135 .64042 m .19473 .64142 L .19633 .65006 L F
.48943 .66556 m .48047 .65626 L .4685 .66228 L F
.49863 .66282 m .48047 .65626 L .48943 .66556 L F
.56773 .38833 m .55759 .40871 L .57412 .39191 L .654 .726 .902 r
F
.56773 .38833 m .54482 .40156 L .55759 .40871 L F
.65662 .6419 m .6601 .65488 L .66558 .64368 L .683 .77 .917 r
F
.65662 .6419 m .64665 .65221 L .6601 .65488 L F
0 g
.6601 .65488 m
.67467 .65526 L
s
.127 .923 .03 r
.62665 .64662 m
.62729 .6514 L
s
.63473 .64285 m .64564 .64306 L .64615 .64763 L .86 .591 .529 r
F
.63473 .64285 m .63423 .63828 L .64564 .64306 L F
0 g
.64564 .64306 m
.64978 .64388 L
s
.5737 .3992 m .57219 .42086 L .58121 .40163 L .654 .726 .902 r
F
.5737 .3992 m .55717 .416 L .57219 .42086 L F
.50793 .65696 m .50849 .64563 L .49379 .64757 L .683 .77 .917 r
F
0 0 0 r
2.5 Mabswid
.43089 .53448 Mdot
.59753 .40248 m .6048 .42257 L .62019 .4193 L .654 .726 .902 r
F
.58934 .40275 m .6048 .42257 L .59753 .40248 L F
.60564 .39356 m .6206 .41201 L .63394 .40623 L F
.59795 .3952 m .6206 .41201 L .60564 .39356 L F
.64813 .62947 m .64579 .6429 L .6557 .63265 L .683 .77 .917 r
F
.64813 .62947 m .63443 .63815 L .64579 .6429 L F
.37615 .40172 m .36111 .38335 L .34789 .38911 L .654 .726 .902 r
F
.38378 .40009 m .36111 .38335 L .37615 .40172 L F
.23365 .65149 m .21888 .66064 L .23543 .65412 L .683 .77 .917 r
F
.23365 .65149 m .21532 .65538 L .21888 .66064 L F
.40749 .40336 m .40887 .38179 L .40001 .40094 L .654 .726 .902 r
F
.40749 .40336 m .42384 .38663 L .40887 .38179 L F
.28771 .64695 m .3081 .64002 L .28924 .64102 L .683 .77 .917 r
F
.26962 .64498 m .28771 .64695 L .28924 .64102 L F
.26762 .64781 m .28771 .64695 L .26962 .64498 L F
.49861 .38613 m .50788 .39407 L .50745 .40136 L .99 .743 .457 r
F
.49861 .38613 m .49904 .37884 L .50788 .39407 L F
0 g
.5 Mabswid
.50788 .39407 m
.51363 .39941 L
s
.68888 .52576 m .69022 .50947 L .68292 .52435 L .673 .757 .914 r
F
.68888 .52576 m .70215 .51231 L .69022 .50947 L F
.24046 .54757 m .23449 .53287 L .21607 .5378 L F
.25355 .54629 m .23449 .53287 L .24046 .54757 L F
.69437 .53372 m .70263 .51785 L .68929 .53138 L F
.69437 .53372 m .71279 .52255 L .70263 .51785 L F
.53002 .37513 m .50829 .39394 L .53587 .38523 L .654 .726 .902 r
F
.53002 .37513 m .4995 .37879 L .50829 .39394 L F
.51073 .75504 m .51365 .76261 L .51976 .76144 L .645 .732 .913 r
F
.50748 .75511 m .51365 .76261 L .51073 .75504 L F
.47407 .76461 m .48012 .76596 L .47987 .76973 L .926 .677 .542 r
F
.47407 .76461 m .47432 .76084 L .48012 .76596 L F
.4854 .75764 m .48012 .76596 L .48927 .76105 L .645 .732 .913 r
F
.4854 .75764 m .47432 .76084 L .48012 .76596 L F
0 g
.48012 .76596 m
.48351 .76778 L
s
.51814 .66179 m .50898 .65021 L .50842 .66153 L .683 .77 .917 r
F
.51814 .66179 m .52357 .6506 L .50898 .65021 L F
.34574 .5213 m .33521 .53869 L .35349 .52752 L .673 .757 .914 r
F
.34574 .5213 m .32358 .52938 L .33521 .53869 L F
0 g
.33521 .53869 m
.35056 .54571 L
s
.38293 .52011 m .37576 .53505 L .38876 .53586 L .673 .757 .914 r
F
.53357 .7691 m .54004 .76091 L .53979 .76468 L .352 .179 .501 r
F
.53332 .77287 m .53357 .7691 L .53979 .76468 L F
.5249 .76315 m .53357 .7691 L .53979 .76468 L .645 .732 .913 r
F
.51957 .76528 m .53357 .7691 L .5249 .76315 L F
0 g
.52786 .77138 m
.53357 .7691 L
s
.64449 .39091 m .67117 .40246 L .68126 .3883 L .654 .726 .902 r
F
.63414 .39878 m .67117 .40246 L .64449 .39091 L F
.36337 .42304 m .33645 .41144 L .32981 .42092 L F
.36853 .41909 m .33645 .41144 L .36337 .42304 L F
.45428 .52132 m .45397 .51564 L .46204 .50439 L .165 .07 .493 r
F
0 g
.44696 .52113 m
.45397 .51564 L
s
.25355 .54629 m .25414 .53095 L .23449 .53287 L .673 .757 .914 r
F
.3071 .54345 m .29143 .53074 L .29173 .53643 L .859 .596 .54 r
F
0 g
.3071 .54345 m
.31873 .55276 L
s
.36898 .4118 m .34722 .39624 L .3369 .40415 L .654 .726 .902 r
F
.37562 .40891 m .34722 .39624 L .36898 .4118 L F
.41793 .42589 m .43593 .4082 L .41309 .42142 L F
.41793 .42589 m .44562 .41715 L .43593 .4082 L F
.43227 .50828 m .45365 .51553 L .46167 .50434 L .673 .757 .914 r
F
.42402 .51475 m .45365 .51553 L .43227 .50828 L F
.41353 .41413 m .42356 .39375 L .40713 .41056 L .654 .726 .902 r
F
.41353 .41413 m .43637 .40091 L .42356 .39375 L F
.33645 .41144 m .29956 .41407 L .32981 .42092 L F
.70318 .64922 m .71469 .63862 L .7152 .6432 L .524 .345 .581 r
F
.69432 .63991 m .70318 .64922 L .7152 .6432 L .683 .77 .917 r
F
.6851 .64265 m .70318 .64922 L .69432 .63991 L F
0 g
.68936 .65333 m
.70318 .64922 L
s
.66381 .52622 m .65199 .51322 L .64134 .51826 L .673 .757 .914 r
F
.66994 .52458 m .65199 .51322 L .66381 .52622 L F
.6549 .5433 m .63348 .53603 L .62805 .54352 L .673 .758 .914 r
F
.65907 .54005 m .63348 .53603 L .6549 .5433 L F
.47998 .65168 m .46752 .65312 L .46801 .6577 L .523 .344 .581 r
F
.47998 .65168 m .47949 .64711 L .46752 .65312 L F
0 g
.4582 .66063 m
.46752 .65312 L
s
.63128 .42489 m
.65436 .41998 L
s
.71988 .52316 m .73061 .50585 L .71227 .51697 L .673 .757 .914 r
F
.71988 .52316 m .74203 .51513 L .73061 .50585 L F
.54847 .65804 m .53654 .64869 L .53704 .65327 L .86 .591 .53 r
F
0 g
.54847 .65804 m
.5571 .6646 L
s
.39598 .51987 m .40185 .53458 L .41415 .53129 L .673 .757 .914 r
F
.7037 .41526 m .67974 .40461 L .67933 .4119 L .732 .487 .557 r
F
0 g
.67974 .40461 m
.7041 .40797 L
s
.67689 .4047 m
.67974 .40461 L
s
.40182 .51254 m .41384 .52561 L .4245 .52054 L .673 .757 .914 r
F
.45153 .42729 m .47332 .4084 L .44562 .41715 L .654 .726 .902 r
F
.45153 .42729 m .48217 .42362 L .47332 .4084 L F
.72579 .42983 m .7037 .41526 L .70329 .42254 L .794 .542 .556 r
F
0 g
.72579 .42983 m
.74489 .44054 L
s
.50723 .75892 m .50689 .7666 L .51343 .76646 L .645 .732 .913 r
F
.65874 .53437 m .6415 .52384 L .63315 .53034 L .673 .757 .914 r
F
.66409 .53183 m .6415 .52384 L .65874 .53437 L F
.49863 .66282 m .49428 .65215 L .48047 .65626 L .683 .77 .917 r
F
.50842 .66153 m .49428 .65215 L .49863 .66282 L F
.67492 .6234 m .67429 .63467 L .68404 .63339 L F
.67492 .6234 m .68404 .63339 L .6798 .62275 L F
.67542 .62803 m .67479 .63936 L .68459 .63807 L F
.67542 .62803 m .68459 .63807 L .68032 .62738 L F
.67468 .57263 m .67625 .57289 L .67641 .61498 L .751 .491 .538 r
F
.67702 .6158 m .67492 .6234 L .6798 .62275 L .683 .77 .917 r
F
.67732 .61986 m .67542 .62803 L .68032 .62738 L F
.67659 .61614 m .67492 .6234 L .67702 .6158 L F
.67664 .6153 m .67492 .6234 L .67679 .61523 L F
.67538 .61516 m .67492 .6234 L .67666 .615 L F
.67641 .61498 m .67666 .615 L .67667 .61493 L F
.67538 .61516 m .67666 .615 L .67641 .61498 L F
.67304 .57155 m .67369 .57215 L .67385 .61449 L .93 .648 .486 r
F
.67261 .57004 m .67266 .57086 L .67282 .6134 L .772 .616 .051 r
F
.6743 .61465 m .674 .61528 L .67538 .61504 L .683 .77 .917 r
F
.67526 .6173 m .67322 .61965 L .67492 .6234 L F
.67322 .61965 m .67346 .62336 L .67492 .6234 L F
.67486 .61913 m .67473 .6194 L .67592 .61922 L F
.67473 .6194 m .67056 .6279 L .67546 .61995 L F
.67473 .6194 m .67546 .61995 L .67592 .61922 L F
.67306 .61719 m .67315 .61852 L .67461 .61625 L F
.67424 .61478 m .66894 .61945 L .67008 .62327 L F
.66894 .61945 m .66562 .62238 L .66712 .62268 L F
.66894 .61945 m .66712 .62268 L .67008 .62327 L F
.67261 .57004 m .67281 .6132 L .67277 .61267 L .772 .616 .051 r
F
.67266 .57086 m .67309 .61383 L .67282 .6134 L .988 .719 .38 r
F
.67261 .57004 m .67282 .6134 L .67281 .6132 L .772 .616 .051 r
F
.67266 .57086 m .67304 .57155 L .67319 .614 L .988 .719 .38 r
F
.67315 .56901 m .67261 .57004 L .67277 .61267 L 0 0 .382 r
F
.67008 .62327 m .67429 .63467 L .67492 .6234 L .683 .77 .917 r
F
.67574 .62232 m .67056 .6279 L .67542 .62803 L F
.6759 .61951 m .67493 .62103 L .67574 .62232 L F
.67493 .62103 m .67056 .6279 L .67574 .62232 L F
.67008 .62327 m .66463 .63442 L .67429 .63467 L F
.67056 .6279 m .66508 .63911 L .67479 .63936 L F
.66608 .62701 m .66508 .63911 L .67056 .6279 L F
.67474 .62499 m .66659 .63159 L .67107 .63248 L F
.67465 .61905 m .67486 .61913 L .67487 .62341 L .845 .571 .523 r
F
.67056 .6279 m .67479 .63936 L .67542 .62803 L .683 .77 .917 r
F
.67641 .62397 m .67107 .63248 L .67593 .63261 L F
.67535 .6156 m .67475 .61648 L .67526 .6173 L F
.67538 .61504 m .67513 .61543 L .67535 .6156 L F
.67592 .61922 m .67577 .61946 L .6759 .61951 L F
.67581 .62104 m .67542 .62803 L .67732 .61986 L F
.67596 .61494 m .67623 .62353 L .67484 .61485 L .751 .491 .538 r
F
.67644 .62354 m .67542 .62361 L .67641 .62397 L .683 .77 .917 r
F
.67549 .62346 m .67542 .62361 L .67644 .62354 L F
.67623 .62353 m .67648 .63184 L .67567 .62348 L .751 .491 .538 r
F
.67623 .62353 m .67567 .62348 L .67484 .61485 L F
.67592 .61922 m .67581 .62104 L .67711 .61932 L .683 .77 .917 r
F
.67609 .61923 m .67643 .61926 L .67648 .63184 L .751 .491 .538 r
F
.67656 .62127 m .67549 .62346 L .67644 .62354 L .683 .77 .917 r
F
.67542 .62361 m .67107 .63248 L .67641 .62397 L F
.67388 .62305 m .6749 .63157 L .67391 .6311 L .845 .571 .523 r
F
.67341 .61432 m .66963 .61823 L .6743 .61465 L .683 .77 .917 r
F
.66963 .61823 m .66562 .62238 L .66897 .6194 L F
.66963 .61823 m .66897 .6194 L .6743 .61465 L F
.67322 .61965 m .67008 .62327 L .67346 .62336 L F
.66562 .62238 m .66463 .63442 L .67008 .62327 L F
.67473 .6194 m .66608 .62701 L .67056 .6279 L F
.67484 .61485 m .67526 .61916 L .67486 .61913 L .751 .491 .538 r
F
.67606 .61669 m .67397 .61884 L .67473 .6194 L .683 .77 .917 r
F
.67397 .61884 m .66608 .62701 L .67473 .6194 L F
.674 .61528 m .67306 .61719 L .67461 .61625 L F
.67367 .61435 m .67385 .61449 L .67387 .61877 L .93 .648 .486 r
F
.67475 .61648 m .67008 .62327 L .67526 .6173 L .683 .77 .917 r
F
.674 .61882 m .67351 .61876 L .67372 .6191 L F
.67317 .61851 m .6729 .61869 L .67392 .61881 L F
.67387 .61877 m .67392 .61881 L .674 .61882 L F
.67317 .61851 m .67392 .61881 L .67387 .61877 L F
.67321 .61828 m .67391 .6311 L .67325 .6305 L .93 .648 .486 r
F
.67319 .614 m .67338 .61841 L .67321 .61828 L F
.67351 .61876 m .6729 .61869 L .67372 .6191 L .683 .77 .917 r
F
.67338 .61841 m .67391 .6311 L .67321 .61828 L .93 .648 .486 r
F
.67304 .57155 m .67367 .61435 L .67319 .614 L F
.67304 .57155 m .67385 .61449 L .67367 .61435 L F
.6742 .61474 m .66562 .62238 L .67424 .61478 L .683 .77 .917 r
F
.67369 .57215 m .67456 .61474 L .67385 .61449 L .845 .571 .523 r
F
.67369 .57215 m .67468 .57263 L .67484 .61485 L F
.67369 .57215 m .67484 .61485 L .67475 .61481 L F
.67341 .61432 m .66184 .62079 L .66562 .62238 L .683 .77 .917 r
F
.67555 .61211 m .67254 .61401 L .67341 .61432 L F
.67254 .61401 m .66184 .62079 L .67341 .61432 L F
.67456 .61474 m .67486 .61913 L .67465 .61905 L .845 .571 .523 r
F
.67369 .57215 m .67475 .61481 L .67456 .61474 L F
.674 .61528 m .67461 .61625 L .67538 .61504 L .683 .77 .917 r
F
.67513 .61543 m .67008 .62327 L .67535 .6156 L F
.67475 .61481 m .67486 .61913 L .67456 .61474 L .845 .571 .523 r
F
.67468 .57263 m .67596 .61494 L .67484 .61485 L .751 .491 .538 r
F
.67555 .61211 m .66899 .61468 L .66184 .62079 L .683 .77 .917 r
F
.66899 .61468 m .65898 .61861 L .66101 .62016 L F
.66899 .61468 m .66101 .62016 L .66184 .62079 L F
.67428 .56822 m .67315 .56901 L .67331 .61172 L .402 .214 .508 r
F
.67367 .61435 m .67373 .61867 L .67319 .614 L .93 .648 .486 r
F
.67373 .61867 m .67338 .61841 L .67319 .614 L F
.67373 .61867 m .67391 .6311 L .67338 .61841 L F
.67356 .61585 m .67334 .62029 L .67349 .62019 L .402 .214 .508 r
F
.66899 .61468 m .65726 .61599 L .65898 .61861 L .683 .77 .917 r
F
.67555 .61211 m .67149 .61297 L .66899 .61468 L F
.67149 .61297 m .65726 .61599 L .66899 .61468 L F
.67362 .61151 m .67342 .61594 L .67356 .61585 L .402 .214 .508 r
F
.67428 .56822 m .6735 .61159 L .67362 .61151 L F
.6735 .61159 m .67342 .61594 L .67362 .61151 L F
.67367 .61435 m .67387 .61877 L .67373 .61867 L .93 .648 .486 r
F
.67205 .61826 m .65767 .62059 L .65941 .62322 L .683 .77 .917 r
F
.67385 .61449 m .67412 .61886 L .67387 .61877 L .845 .571 .523 r
F
.67606 .61669 m .67252 .61744 L .67205 .61826 L .683 .77 .917 r
F
.67252 .61744 m .65767 .62059 L .67205 .61826 L F
.67323 .62823 m .67325 .6305 L .6732 .62829 L .988 .719 .38 r
F
.67404 .62387 m .66278 .62999 L .66659 .63159 L .683 .77 .917 r
F
.67465 .61905 m .67487 .62341 L .67474 .62336 L .845 .571 .523 r
F
.67656 .62127 m .67359 .62315 L .67404 .62387 L .683 .77 .917 r
F
.67359 .62315 m .66278 .62999 L .67404 .62387 L F
.67404 .62387 m .66659 .63159 L .67474 .62499 L F
.67323 .62823 m .6732 .62829 L .67304 .62228 L .988 .719 .38 r
F
.67306 .6223 m .67304 .62228 L .67293 .61784 L F
.67323 .62823 m .67304 .62228 L .67306 .6223 L F
.67306 .61719 m .67008 .62327 L .67315 .61852 L .683 .77 .917 r
F
.6729 .61869 m .66227 .62541 L .67297 .61987 L F
.67254 .62148 m .6585 .61929 L .6577 .62226 L F
.6712 .61976 m .66734 .62011 L .66227 .62541 L F
.67281 .6132 m .67282 .61753 L .67277 .61267 L .772 .616 .051 r
F
.66184 .62079 m .6557 .63265 L .66562 .62238 L .683 .77 .917 r
F
.66734 .62011 m .65941 .62322 L .66101 .62445 L F
.66734 .62011 m .66101 .62445 L .66227 .62541 L F
.67286 .62205 m .6577 .62226 L .65818 .62517 L F
.67373 .61867 m .67388 .62305 L .67379 .62299 L .93 .648 .486 r
F
.67577 .61946 m .67056 .6279 L .6759 .61951 L .683 .77 .917 r
F
.67387 .61877 m .67439 .62324 L .67388 .62305 L .845 .571 .523 r
F
.67372 .6191 m .6729 .61869 L .67297 .61987 L .683 .77 .917 r
F
.67293 .61784 m .67304 .62228 L .67283 .61768 L .988 .719 .38 r
F
.67304 .62228 m .67325 .6305 L .67298 .62218 L F
.67304 .62228 m .67298 .62218 L .67283 .61768 L F
.67656 .62127 m .67282 .62146 L .67285 .62197 L .683 .77 .917 r
F
.6729 .62204 m .67285 .62197 L .67286 .62205 L F
.67656 .62127 m .67285 .62197 L .6729 .62204 L F
.67282 .62146 m .6577 .62226 L .67286 .62205 L F
.67282 .61753 m .67284 .62187 L .6728 .61715 L .772 .616 .051 r
F
.67284 .62187 m .67288 .62981 L .67283 .62162 L F
.67284 .62187 m .67283 .62162 L .6728 .61715 L F
.67282 .61753 m .6728 .61715 L .67277 .61267 L F
.6729 .61869 m .67205 .61826 L .6712 .61976 L .683 .77 .917 r
F
.67606 .61669 m .67285 .61794 L .6729 .61869 L F
.67285 .61794 m .67205 .61826 L .6729 .61869 L F
.67205 .61826 m .66734 .62011 L .6712 .61976 L F
.67282 .6134 m .67293 .61784 L .67283 .61768 L .988 .719 .38 r
F
.67277 .61267 m .6728 .61715 L .67279 .61696 L .772 .616 .051 r
F
.67292 .61241 m .67277 .61267 L .67279 .61696 L 0 0 .382 r
F
.6728 .61715 m .67283 .62162 L .67279 .61696 L .772 .616 .051 r
F
.67283 .62162 m .67288 .62981 L .67282 .6215 L F
.67297 .61987 m .66227 .62541 L .66608 .62701 L .683 .77 .917 r
F
.67283 .62162 m .67282 .6215 L .67279 .61696 L .772 .616 .051 r
F
.67656 .62127 m .67301 .62088 L .67282 .62146 L .683 .77 .917 r
F
.67283 .61768 m .67298 .62218 L .67285 .62197 L .988 .719 .38 r
F
.6729 .61676 m .6728 .62124 L .67287 .62112 L 0 0 .382 r
F
.67301 .62088 m .67278 .62085 L .6728 .62124 L .683 .77 .917 r
F
.67301 .62088 m .6728 .62124 L .67282 .62146 L F
.67266 .57086 m .67319 .614 L .67309 .61383 L .988 .719 .38 r
F
.67149 .61297 m .65678 .6131 L .65726 .61599 L .683 .77 .917 r
F
.67555 .61211 m .67251 .61227 L .67149 .61297 L F
.67251 .61227 m .65678 .6131 L .67149 .61297 L F
.67656 .62127 m .67286 .62205 L .6729 .6227 L F
.67379 .62299 m .67388 .62305 L .67391 .6311 L .93 .648 .486 r
F
.67542 .62361 m .67404 .62387 L .67474 .62499 L .683 .77 .917 r
F
.67459 .62331 m .67404 .62387 L .67542 .62361 L F
.6743 .61465 m .6742 .61474 L .67424 .61478 L F
.67456 .61474 m .67465 .61905 L .67385 .61449 L .845 .571 .523 r
F
.67465 .61905 m .6749 .63157 L .67412 .61886 L F
.67465 .61905 m .67412 .61886 L .67385 .61449 L F
.67106 .61775 m .65719 .61768 L .65767 .62059 L .683 .77 .917 r
F
.67606 .61669 m .66915 .61705 L .67106 .61775 L F
.66915 .61705 m .65719 .61768 L .67106 .61775 L F
.67606 .61669 m .67317 .61851 L .674 .61882 L F
.67412 .61886 m .67439 .62324 L .67387 .61877 L .845 .571 .523 r
F
.67439 .62324 m .6749 .63157 L .67388 .62305 L F
.67555 .61211 m .67341 .61432 L .6743 .61465 L .683 .77 .917 r
F
.67256 .62083 m .66054 .61645 L .6585 .61929 L F
.67317 .62249 m .67306 .6223 L .67293 .61784 L .988 .719 .38 r
F
.67656 .62127 m .67333 .62029 L .67256 .62083 L .683 .77 .917 r
F
.67313 .61816 m .67317 .62249 L .67293 .61784 L .988 .719 .38 r
F
.67309 .61383 m .67319 .614 L .67321 .61828 L F
.67313 .61816 m .67321 .61828 L .67325 .6305 L F
.67309 .61383 m .67321 .61828 L .67313 .61816 L F
.67233 .61688 m .658 .61471 L .65719 .61768 L .683 .77 .917 r
F
.67362 .61151 m .67356 .61585 L .67444 .61094 L .402 .214 .508 r
F
.67313 .61816 m .67293 .61784 L .67282 .6134 L .988 .719 .38 r
F
.67606 .61669 m .67284 .61633 L .67233 .61688 L .683 .77 .917 r
F
.67281 .6132 m .67283 .61768 L .67283 .61758 L .772 .616 .051 r
F
.67606 .61669 m .67271 .61568 L .67275 .61632 L .683 .77 .917 r
F
.67373 .61867 m .67387 .61877 L .67388 .62305 L .93 .648 .486 r
F
.67275 .61632 m .66003 .61187 L .658 .61471 L .683 .77 .917 r
F
.67333 .62029 m .66367 .61394 L .66054 .61645 L F
.67656 .62127 m .67402 .61982 L .67333 .62029 L F
.67402 .61982 m .66367 .61394 L .67333 .62029 L F
.67356 .61585 m .67349 .62019 L .67416 .61543 L .402 .214 .508 r
F
.67656 .62127 m .67323 .62257 L .67382 .623 L .683 .77 .917 r
F
.67349 .62019 m .67337 .62796 L .67388 .61992 L .402 .214 .508 r
F
.67349 .62019 m .67388 .61992 L .67416 .61543 L F
.67356 .61585 m .67416 .61543 L .67444 .61094 L F
.67284 .61633 m .67193 .61623 L .67225 .61674 L .683 .77 .917 r
F
.67284 .61633 m .67225 .61674 L .67233 .61688 L F
.67193 .61623 m .658 .61471 L .67233 .61688 L F
.67319 .61625 m .67283 .62899 L .67333 .616 L 0 0 .382 r
F
.67333 .62029 m .66054 .61645 L .67256 .62083 L .683 .77 .917 r
F
.67447 .61951 m .67337 .62796 L .6745 .62717 L .402 .214 .508 r
F
.67444 .61094 m .67388 .61992 L .67447 .61951 L F
.67388 .61992 m .67337 .62796 L .67447 .61951 L F
.67428 .56822 m .67362 .61151 L .67444 .61094 L F
.67271 .61568 m .66003 .61187 L .67275 .61632 L .683 .77 .917 r
F
.67281 .6132 m .67282 .6134 L .67283 .61768 L .772 .616 .051 r
F
.67283 .61758 m .67283 .61768 L .67285 .62197 L F
.67284 .62187 m .67285 .62197 L .67288 .62981 L F
.67281 .6132 m .67285 .62197 L .67284 .62187 L F
.66562 .62238 m .6557 .63265 L .66463 .63442 L .683 .77 .917 r
F
.6729 .6227 m .65818 .62517 L .65991 .6278 L F
.67286 .62205 m .65818 .62517 L .6729 .6227 L F
.6729 .61676 m .67279 .61696 L .6728 .62124 L 0 0 .382 r
F
.67279 .61696 m .67288 .62981 L .67283 .62899 L .772 .616 .051 r
F
.67287 .62112 m .6728 .62124 L .67283 .62899 L 0 0 .382 r
F
.67292 .61241 m .67279 .61696 L .6729 .61676 L F
.67282 .62146 m .6721 .62078 L .67254 .62148 L .683 .77 .917 r
F
.67278 .62085 m .6721 .62078 L .67282 .62146 L F
.6721 .62078 m .6585 .61929 L .67254 .62148 L F
.67317 .62249 m .67323 .62823 L .67306 .6223 L .988 .719 .38 r
F
.67285 .62197 m .67325 .6305 L .67288 .62981 L F
.67298 .62218 m .67325 .6305 L .67285 .62197 L F
.67333 .616 m .67283 .62899 L .67337 .62796 L 0 0 .382 r
F
.67331 .61172 m .67319 .61625 L .67333 .616 L F
.67342 .61594 m .67334 .62029 L .67356 .61585 L .402 .214 .508 r
F
.67315 .56901 m .67292 .61241 L .67331 .61172 L 0 0 .382 r
F
.67315 .56901 m .67277 .61267 L .67292 .61241 L F
.67211 .61173 m .65961 .60732 L .65758 .61014 L .683 .77 .917 r
F
.67555 .61211 m .67314 .61138 L .67211 .61173 L F
.67314 .61138 m .65961 .60732 L .67211 .61173 L F
.67539 .56788 m .67428 .56822 L .67444 .61094 L .568 .343 .534 r
F
.67314 .61138 m .66272 .60482 L .65961 .60732 L .683 .77 .917 r
F
.67555 .61211 m .67385 .61114 L .67314 .61138 L F
.67385 .61114 m .66272 .60482 L .67314 .61138 L F
.67474 .62336 m .67487 .62341 L .6749 .63157 L .845 .571 .523 r
F
.67567 .62348 m .67541 .62346 L .67486 .61913 L .751 .491 .538 r
F
.67656 .62127 m .67459 .62331 L .67487 .62341 L .683 .77 .917 r
F
.67549 .62346 m .67487 .62341 L .67542 .62361 L F
.67656 .62127 m .67487 .62341 L .67549 .62346 L F
.67526 .61916 m .67567 .62348 L .67486 .61913 L .751 .491 .538 r
F
.67567 .62348 m .67648 .63184 L .67541 .62346 L F
.67557 .61485 m .675 .61933 L .67558 .61914 L .568 .343 .534 r
F
.67555 .61211 m .6743 .61465 L .67538 .61504 L .683 .77 .917 r
F
.67555 .61057 m .67528 .61495 L .67557 .61485 L .568 .343 .534 r
F
.67475 .61481 m .67484 .61485 L .67486 .61913 L .845 .571 .523 r
F
.67606 .61669 m .67385 .61543 L .67292 .61575 L .683 .77 .917 r
F
.67528 .61495 m .675 .61933 L .67557 .61485 L .568 .343 .534 r
F
.67555 .61211 m .65758 .61014 L .65678 .6131 L .683 .77 .917 r
F
.67292 .61575 m .66316 .60936 L .66003 .61187 L F
.67309 .61383 m .67313 .61816 L .67282 .6134 L .988 .719 .38 r
F
.67385 .61543 m .66316 .60936 L .67292 .61575 L .683 .77 .917 r
F
.67475 .61084 m .67468 .61515 L .67555 .61057 L .568 .343 .534 r
F
.67606 .61669 m .67462 .61517 L .67402 .61553 L .683 .77 .917 r
F
.67468 .61515 m .6745 .62717 L .67528 .61495 L .568 .343 .534 r
F
.67468 .61515 m .67528 .61495 L .67555 .61057 L F
.67475 .61084 m .67444 .61094 L .67446 .61523 L F
.67461 .61518 m .67446 .61523 L .67447 .61951 L F
.67475 .61084 m .67446 .61523 L .67461 .61518 L F
.6735 .61159 m .67331 .61172 L .67333 .616 L .402 .214 .508 r
F
.67555 .61211 m .66671 .60282 L .66272 .60482 L .683 .77 .917 r
F
.67462 .61517 m .67178 .60598 L .66717 .60735 L F
.67606 .61669 m .67535 .61492 L .67462 .61517 L F
.67535 .61492 m .67178 .60598 L .67462 .61517 L F
.67462 .61517 m .67458 .61514 L .67446 .61523 L F
.67462 .61517 m .67446 .61523 L .67402 .61553 L F
.67606 .61669 m .67486 .61913 L .67592 .61922 L F
.67555 .61211 m .67538 .61516 L .67667 .61493 L F
.67468 .57263 m .67641 .61498 L .67596 .61494 L .751 .491 .538 r
F
.67539 .56788 m .67444 .61094 L .67475 .61084 L .568 .343 .534 r
F
.67606 .61669 m .67616 .61477 L .67534 .61488 L .683 .77 .917 r
F
.67668 .61899 m .67561 .62683 L .67671 .62674 L .66 .416 .54 r
F
.67596 .61494 m .67641 .61498 L .67643 .61926 L .751 .491 .538 r
F
.67666 .615 m .67492 .6234 L .6767 .615 L .683 .77 .917 r
F
.67596 .61494 m .67643 .61926 L .67609 .61923 L .751 .491 .538 r
F
.67606 .61669 m .67592 .61922 L .67711 .61932 L .683 .77 .917 r
F
.67785 .57268 m .67888 .57224 L .67904 .61423 L .517 .303 .528 r
F
.67667 .61493 m .6798 .62275 L .67801 .61469 L .683 .77 .917 r
F
.6798 .62275 m .68404 .63339 L .69321 .63066 L F
.67968 .62049 m .68032 .62738 L .68494 .62601 L F
.68032 .62738 m .68459 .63807 L .69381 .63533 L F
.67973 .62459 m .68083 .63196 L .68544 .63059 L F
.68022 .62161 m .68038 .62913 L .68026 .62994 L 0 0 .152 r
F
.68003 .57099 m .68015 .57018 L .68031 .6123 L F
.67963 .6164 m .6798 .62275 L .68438 .62139 L .683 .77 .917 r
F
.6798 .62275 m .69321 .63066 L .68438 .62139 L F
.67995 .61889 m .68494 .62601 L .68894 .624 L F
.6792 .61899 m .6798 .62275 L .67963 .6164 L F
.67914 .61415 m .67929 .61435 L .67935 .61426 L F
.6782 .61489 m .68438 .62139 L .67914 .61415 L F
.67955 .61384 m .67962 .61808 L .67904 .61423 L .359 .181 .499 r
F
.67915 .61844 m .67968 .62049 L .67995 .61889 L .683 .77 .917 r
F
.67934 .62253 m .68032 .62738 L .67968 .62049 L F
.68438 .62139 m .69321 .63066 L .70118 .62666 L F
.68494 .62601 m .70182 .63131 L .68894 .624 L F
.6798 .62224 m .68945 .62858 L .69258 .62607 L F
.6785 .6198 m .68032 .62738 L .67872 .61948 L F
.67962 .61808 m .67977 .61796 L .67982 .63062 L .359 .181 .499 r
F
.67713 .61937 m .68032 .62738 L .67818 .61894 L .683 .77 .917 r
F
.67802 .61897 m .67818 .61894 L .67817 .61891 L F
.67713 .61937 m .67818 .61894 L .67802 .61897 L F
.67755 .61477 m .67801 .61469 L .67802 .61897 L .641 .401 .54 r
F
.67847 .62327 m .67919 .62783 L .67973 .62459 L .683 .77 .917 r
F
.6774 .62337 m .67593 .63261 L .68083 .63196 L F
.67711 .61932 m .67581 .62104 L .67732 .61986 L F
.67641 .61498 m .67725 .6234 L .67645 .62354 L .641 .401 .54 r
F
.67656 .62127 m .67644 .62355 L .6774 .62337 L .683 .77 .917 r
F
.67644 .62355 m .67593 .63261 L .6774 .62337 L F
.67645 .62354 m .67807 .63163 L .67648 .63184 L .641 .401 .54 r
F
.67725 .6234 m .67807 .63163 L .67645 .62354 L F
.67907 .6228 m .67982 .63062 L .6791 .63119 L .359 .181 .499 r
F
.67872 .61948 m .67934 .62253 L .67968 .62049 L .683 .77 .917 r
F
.67905 .61851 m .67931 .62261 L .67907 .6228 L .359 .181 .499 r
F
.67931 .62261 m .67982 .63062 L .67907 .6228 L F
.6784 .62319 m .67842 .62331 L .67847 .62327 L .683 .77 .917 r
F
.67842 .62331 m .67919 .62783 L .67847 .62327 L F
.67679 .61523 m .67659 .61614 L .67702 .6158 L F
.6767 .615 m .67664 .6153 L .67679 .61523 L F
.67667 .61493 m .67666 .615 L .6767 .615 L F
.67755 .61477 m .67768 .61903 L .67641 .61498 L .641 .401 .54 r
F
.67704 .61915 m .67713 .61937 L .67802 .61897 L .683 .77 .917 r
F
.67768 .61903 m .67807 .63163 L .67683 .61919 L .641 .401 .54 r
F
.67768 .61903 m .67683 .61919 L .67641 .61498 L F
.67606 .61669 m .67704 .61915 L .67817 .61891 L .683 .77 .917 r
F
.67755 .61477 m .67802 .61897 L .67768 .61903 L .641 .401 .54 r
F
.67704 .61915 m .67802 .61897 L .67817 .61891 L .683 .77 .917 r
F
.67656 .62127 m .6774 .62337 L .6784 .62319 L F
.67746 .62351 m .67919 .62783 L .67804 .62326 L F
.67804 .62326 m .6791 .63119 L .67807 .63163 L .517 .303 .528 r
F
.67817 .61891 m .67823 .61915 L .67833 .61908 L .683 .77 .917 r
F
.67801 .61469 m .67856 .62303 L .67804 .62326 L .517 .303 .528 r
F
.67804 .62326 m .67919 .62783 L .6784 .62319 L .683 .77 .917 r
F
.67856 .62303 m .6791 .63119 L .67804 .62326 L .517 .303 .528 r
F
.6774 .62337 m .67746 .62351 L .67804 .62326 L .683 .77 .917 r
F
.67768 .61903 m .67802 .61897 L .67804 .62326 L .641 .401 .54 r
F
.67782 .6233 m .67804 .62326 L .67807 .63163 L F
.67768 .61903 m .67804 .62326 L .67782 .6233 L F
.67924 .61837 m .67982 .63062 L .67905 .61851 L .359 .181 .499 r
F
.67801 .61469 m .67826 .61584 L .67861 .61533 L .683 .77 .917 r
F
.67833 .61908 m .6785 .6198 L .67872 .61948 L F
.67826 .61584 m .6798 .62275 L .67861 .61533 L F
.67874 .61436 m .67883 .61861 L .67801 .61469 L .517 .303 .528 r
F
.67959 .57167 m .68003 .57099 L .68019 .61304 L .082 0 .419 r
F
.67959 .57167 m .68019 .61304 L .68007 .61322 L F
.67935 .61426 m .68438 .62139 L .68468 .62124 L .683 .77 .917 r
F
.68201 .61578 m .68468 .62124 L .68837 .61939 L F
.67935 .61426 m .68468 .62124 L .68201 .61578 L F
.68015 .57018 m .67971 .56913 L .67987 .6114 L .982 .725 .331 r
F
.68007 .61322 m .68011 .61746 L .67975 .61368 L .082 0 .419 r
F
.68438 .62139 m .70118 .62666 L .68837 .61939 L .683 .77 .917 r
F
.6803 .61796 m .68894 .624 L .69207 .62149 L F
.68019 .62166 m .69258 .62607 L .69462 .62324 L F
.67883 .61861 m .67892 .62286 L .67829 .61886 L .517 .303 .528 r
F
.67892 .62286 m .67856 .62303 L .67829 .61886 L F
.67988 .6178 m .68026 .62994 L .67977 .61796 L .082 0 .419 r
F
.67823 .61915 m .68032 .62738 L .67833 .61908 L .683 .77 .917 r
F
.67656 .62127 m .67979 .62223 L .68019 .62166 L F
.67979 .62223 m .69258 .62607 L .68019 .62166 L F
.68011 .61746 m .68016 .6217 L .67988 .6178 L .082 0 .419 r
F
.67834 .62313 m .68473 .62984 L .67918 .62275 L .683 .77 .917 r
F
.68032 .62738 m .69381 .63533 L .68494 .62601 L F
.68473 .62984 m .68544 .63059 L .68455 .62947 L F
.68473 .62984 m .68455 .62947 L .67918 .62275 L F
.68016 .6217 m .68026 .62994 L .68001 .62192 L .082 0 .419 r
F
.68102 .61375 m .68837 .61939 L .69148 .61689 L .683 .77 .917 r
F
.67555 .61211 m .68201 .61578 L .68102 .61375 L F
.68201 .61578 m .68837 .61939 L .68102 .61375 L F
.68011 .61746 m .67988 .6178 L .67975 .61368 L .082 0 .419 r
F
.67874 .61436 m .67905 .61851 L .67883 .61861 L .517 .303 .528 r
F
.67861 .61533 m .6792 .61899 L .67963 .6164 L .683 .77 .917 r
F
.67904 .61423 m .67924 .61837 L .67905 .61851 L .359 .181 .499 r
F
.67606 .61669 m .67986 .61783 L .68032 .61715 L .683 .77 .917 r
F
.68 .61165 m .6799 .61996 L .67996 .62009 L .982 .725 .331 r
F
.68015 .57018 m .67995 .61155 L .68 .61165 L F
.67995 .61155 m .67987 .6114 L .6799 .61996 L F
.68007 .61322 m .68019 .61304 L .68021 .61732 L .082 0 .419 r
F
.68007 .61322 m .68021 .61732 L .68011 .61746 L F
.68028 .61251 m .68031 .6123 L .68033 .61659 L 0 0 .152 r
F
.68028 .61251 m .68033 .61659 L .6803 .61674 L F
.68003 .57099 m .68031 .6123 L .68028 .61251 L F
.68019 .61304 m .6803 .61674 L .68021 .61732 L F
.68003 .57099 m .68028 .61251 L .68019 .61304 L F
.68028 .61251 m .6803 .61674 L .68019 .61304 L F
.68026 .61262 m .69148 .61689 L .69351 .61407 L .683 .77 .917 r
F
.67785 .57268 m .67874 .61436 L .67801 .61469 L .517 .303 .528 r
F
.67555 .61211 m .68012 .61348 L .68026 .61262 L .683 .77 .917 r
F
.68012 .61348 m .69148 .61689 L .68026 .61262 L F
.68031 .6123 m .67998 .61587 L .68033 .61659 L .982 .725 .331 r
F
.68015 .57018 m .68 .61165 L .68031 .6123 L F
.68 .61165 m .67998 .61587 L .68031 .6123 L F
.6801 .61187 m .69351 .61407 L .69432 .61111 L .683 .77 .917 r
F
.67785 .57268 m .67904 .61423 L .67874 .61436 L .517 .303 .528 r
F
.67555 .61211 m .68048 .61265 L .6801 .61187 L .683 .77 .917 r
F
.68048 .61265 m .69351 .61407 L .6801 .61187 L F
.67953 .6183 m .68894 .624 L .6803 .61796 L F
.67918 .61846 m .67936 .61856 L .67953 .6183 L F
.67936 .61856 m .68894 .624 L .67953 .6183 L F
.67915 .62273 m .68945 .62858 L .6798 .62224 L F
.67962 .61808 m .67968 .62232 L .67924 .61837 L .359 .181 .499 r
F
.67919 .62783 m .68083 .63196 L .67973 .62459 L .683 .77 .917 r
F
.67968 .62232 m .67982 .63062 L .67943 .62252 L .359 .181 .499 r
F
.67968 .62232 m .67943 .62252 L .67924 .61837 L F
.67962 .61808 m .67924 .61837 L .67904 .61423 L F
.67833 .61908 m .67968 .62049 L .67915 .61844 L .683 .77 .917 r
F
.67975 .61368 m .67988 .6178 L .67977 .61796 L .082 0 .419 r
F
.67959 .57167 m .68007 .61322 L .67975 .61368 L F
.67969 .61373 m .67975 .61368 L .67977 .61796 L .359 .181 .499 r
F
.67888 .57224 m .67975 .61368 L .67969 .61373 L F
.67955 .61384 m .67977 .61796 L .67962 .61808 L F
.67888 .57224 m .67969 .61373 L .67955 .61384 L F
.67969 .61373 m .67977 .61796 L .67955 .61384 L F
.6841 .61029 m .69432 .61111 L .69384 .60823 L .683 .77 .917 r
F
.67656 .62127 m .67915 .62273 L .6798 .62224 L F
.68106 .61642 m .69411 .61866 L .69492 .61569 L F
.67929 .61435 m .68438 .62139 L .67935 .61426 L F
.67606 .61669 m .68261 .6174 L .68106 .61642 L F
.68261 .6174 m .69411 .61866 L .68106 .61642 L F
.67989 .61568 m .67888 .62725 L .67994 .62808 L .91 .629 .497 r
F
.67987 .6114 m .67961 .61551 L .67989 .61568 L F
.68012 .61582 m .69492 .61569 L .69444 .61278 L .683 .77 .917 r
F
.67606 .61669 m .68106 .61642 L .68012 .61582 L F
.68106 .61642 m .69492 .61569 L .68012 .61582 L F
.67888 .57224 m .67955 .61384 L .67904 .61423 L .359 .181 .499 r
F
.67911 .61092 m .67905 .61515 L .67987 .6114 L .91 .629 .497 r
F
.67883 .61861 m .67905 .61851 L .6791 .63119 L .517 .303 .528 r
F
.67936 .61962 m .67953 .61973 L .67989 .61568 L .91 .629 .497 r
F
.67555 .61211 m .68057 .61184 L .67963 .61124 L .683 .77 .917 r
F
.67888 .57224 m .67959 .57167 L .67975 .61368 L .359 .181 .499 r
F
.67874 .61436 m .67904 .61423 L .67905 .61851 L .517 .303 .528 r
F
.67971 .56913 m .67865 .5683 L .67882 .61073 L .91 .629 .497 r
F
.68154 .621 m .69462 .62324 L .69543 .62027 L .683 .77 .917 r
F
.68011 .61746 m .68021 .61732 L .68022 .62161 L .082 0 .419 r
F
.68016 .6217 m .68022 .62161 L .68026 .62994 L F
.67968 .62049 m .68494 .62601 L .67995 .61889 L .683 .77 .917 r
F
.68011 .61746 m .68022 .62161 L .68016 .6217 L .082 0 .419 r
F
.68061 .62105 m .68309 .62198 L .68154 .621 L .683 .77 .917 r
F
.67656 .62127 m .68019 .62166 L .68061 .62105 L F
.68019 .62166 m .68309 .62198 L .68061 .62105 L F
.68309 .62198 m .69462 .62324 L .68154 .621 L F
.67911 .61092 m .67882 .61073 L .67883 .61501 L .91 .629 .497 r
F
.67625 .57289 m .67801 .61469 L .67755 .61477 L .641 .401 .54 r
F
.67555 .61211 m .6782 .61489 L .67914 .61415 L .683 .77 .917 r
F
.67892 .62286 m .6791 .63119 L .67856 .62303 L .517 .303 .528 r
F
.67885 .6193 m .6778 .62687 L .67888 .62725 L .81 .54 .531 r
F
.67606 .61669 m .67968 .61526 L .67966 .61522 L .683 .77 .917 r
F
.67905 .61515 m .67961 .61551 L .67987 .6114 L .91 .629 .497 r
F
.67874 .61499 m .67966 .61522 L .67936 .6146 L .683 .77 .917 r
F
.67883 .61861 m .67829 .61886 L .67801 .61469 L .517 .303 .528 r
F
.67606 .61669 m .67966 .61522 L .67874 .61499 L .683 .77 .917 r
F
.67606 .61669 m .67918 .61846 L .6803 .61796 L F
.67883 .61501 m .67791 .61906 L .67885 .6193 L .81 .54 .531 r
F
.67971 .56913 m .67911 .61092 L .67987 .6114 L .91 .629 .497 r
F
.68015 .57018 m .67987 .6114 L .67995 .61155 L .982 .725 .331 r
F
.67625 .57289 m .67785 .57268 L .67801 .61469 L .641 .401 .54 r
F
.67625 .57289 m .67755 .61477 L .67641 .61498 L F
.67606 .61669 m .67833 .61908 L .67915 .61844 L .683 .77 .917 r
F
.67865 .5683 m .67758 .56792 L .67774 .61046 L .81 .54 .531 r
F
.67804 .61054 m .67774 .61046 L .67777 .61903 L F
.67798 .6148 m .67777 .61903 L .67791 .61906 L F
.67804 .61054 m .67791 .61478 L .67798 .6148 L F
.6794 .61537 m .68119 .6156 L .67974 .61524 L .683 .77 .917 r
F
.67606 .61669 m .68012 .61582 L .6794 .61537 L F
.68012 .61582 m .68119 .6156 L .6794 .61537 L F
.67905 .61515 m .67885 .6193 L .67899 .61939 L .91 .629 .497 r
F
.67911 .61092 m .67898 .61511 L .67905 .61515 L F
.67898 .61511 m .67885 .6193 L .67905 .61515 L F
.67791 .61478 m .67777 .61903 L .67798 .6148 L .81 .54 .531 r
F
.67974 .61524 m .69444 .61278 L .69271 .61015 L .683 .77 .917 r
F
.68119 .6156 m .69444 .61278 L .67974 .61524 L F
.67882 .61073 m .67798 .6148 L .67883 .61501 L .81 .54 .531 r
F
.67804 .61054 m .67798 .6148 L .67882 .61073 L F
.67774 .61046 m .67689 .61471 L .67776 .61474 L .734 .477 .539 r
F
.67758 .56792 m .67695 .61043 L .67774 .61046 L F
.67555 .61211 m .67803 .61053 L .67774 .61046 L .683 .77 .917 r
F
.67695 .61043 m .67689 .61471 L .67774 .61046 L .734 .477 .539 r
F
.67716 .61044 m .67774 .61046 L .67726 .61034 L .683 .77 .917 r
F
.67555 .61211 m .67774 .61046 L .67716 .61044 L F
.67555 .61211 m .67667 .61493 L .67801 .61469 L F
.67702 .61472 m .67811 .61456 L .67734 .61407 L F
.67606 .61669 m .67793 .61475 L .67702 .61472 L F
.67793 .61475 m .67811 .61456 L .67702 .61472 L F
.67776 .61474 m .67671 .62674 L .6778 .62687 L .734 .477 .539 r
F
.67683 .61899 m .67738 .61901 L .67776 .61474 L F
.67669 .61899 m .67767 .619 L .6767 .61876 L .683 .77 .917 r
F
.67656 .62127 m .67766 .61902 L .67669 .61899 L F
.67766 .61902 m .67767 .619 L .67669 .61899 L F
.67689 .61471 m .67683 .61899 L .67776 .61474 L .734 .477 .539 r
F
.67656 .62127 m .67834 .62313 L .67918 .62275 L .683 .77 .917 r
F
.67683 .61899 m .67671 .62674 L .67738 .61901 L .734 .477 .539 r
F
.68057 .61184 m .68222 .61175 L .67963 .61124 L .683 .77 .917 r
F
.67811 .61456 m .68604 .60636 L .67734 .61407 L F
.67911 .61092 m .67883 .61501 L .67898 .61511 L .91 .629 .497 r
F
.67995 .61155 m .67992 .61576 L .68 .61165 L .982 .725 .331 r
F
.6767 .61876 m .68206 .61004 L .6772 .60991 L .683 .77 .917 r
F
.67798 .6148 m .67791 .61906 L .67883 .61501 L .81 .54 .531 r
F
.67898 .61511 m .67883 .61501 L .67885 .6193 L .91 .629 .497 r
F
.67767 .619 m .68206 .61004 L .6767 .61876 L .683 .77 .917 r
F
.67791 .61906 m .67777 .61903 L .6778 .62687 L .81 .54 .531 r
F
.67865 .5683 m .67774 .61046 L .67804 .61054 L F
.67726 .61034 m .68927 .60342 L .68548 .60183 L .683 .77 .917 r
F
.67803 .61053 m .68927 .60342 L .67726 .61034 L F
.67758 .56792 m .67649 .56779 L .67665 .61042 L .734 .477 .539 r
F
.67555 .61211 m .69384 .60823 L .69374 .60807 L .683 .77 .917 r
F
.68157 .60974 m .69374 .60807 L .69212 .6056 L F
.67555 .61211 m .69374 .60807 L .68157 .60974 L F
.67606 .61669 m .67702 .61472 L .67667 .6147 L F
.67665 .61042 m .67619 .61477 L .67667 .6147 L .66 .416 .54 r
F
.67616 .61477 m .67667 .6147 L .67617 .61468 L .683 .77 .917 r
F
.67606 .61669 m .67667 .6147 L .67616 .61477 L F
.67667 .6147 m .67573 .61912 L .67668 .61899 L .66 .416 .54 r
F
.67619 .61477 m .67573 .61912 L .67667 .6147 L F
.67649 .56779 m .67586 .61053 L .67665 .61042 L F
.67555 .61211 m .67726 .61034 L .6765 .61015 L .683 .77 .917 r
F
.67586 .61053 m .67573 .61912 L .67665 .61042 L .66 .416 .54 r
F
.67695 .61043 m .67665 .61042 L .67667 .6147 L .734 .477 .539 r
F
.67963 .61124 m .68222 .61175 L .6841 .61029 L .683 .77 .917 r
F
.67793 .61475 m .68985 .60795 L .68604 .60636 L F
.67606 .61669 m .67904 .6148 L .67793 .61475 L F
.67904 .6148 m .68985 .60795 L .67793 .61475 L F
.67689 .61471 m .67668 .61899 L .67683 .61899 L .734 .477 .539 r
F
.67695 .61043 m .67682 .61471 L .67689 .61471 L F
.67682 .61471 m .67668 .61899 L .67689 .61471 L F
.67682 .61471 m .67667 .6147 L .67668 .61899 L F
.67695 .61043 m .67667 .6147 L .67682 .61471 L F
.67555 .61211 m .67956 .61053 L .67812 .61048 L .683 .77 .917 r
F
.6765 .61015 m .68548 .60183 L .68102 .60094 L F
.67726 .61034 m .68548 .60183 L .6765 .61015 L F
.67865 .5683 m .67804 .61054 L .67882 .61073 L .81 .54 .531 r
F
.67684 .60948 m .68102 .60094 L .67573 .60878 L .683 .77 .917 r
F
.67617 .61468 m .68155 .60546 L .67669 .60533 L F
.67702 .61472 m .68155 .60546 L .67617 .61468 L F
.6767 .61876 m .6772 .60991 L .67572 .61895 L F
.6761 .61896 m .67572 .61895 L .6757 .6191 L F
.6767 .61876 m .67572 .61895 L .6761 .61896 L F
.67683 .61899 m .67668 .61899 L .67671 .62674 L .734 .477 .539 r
F
.67758 .56792 m .67665 .61042 L .67695 .61043 L F
.67812 .61048 m .69212 .6056 L .68927 .60342 L .683 .77 .917 r
F
.67956 .61053 m .69212 .6056 L .67812 .61048 L F
.67656 .62127 m .67926 .61956 L .67885 .6193 L F
.67656 .62127 m .67885 .6193 L .67854 .61922 L F
.67656 .62127 m .67989 .61996 L .67926 .61956 L F
.67791 .61906 m .6778 .62687 L .67885 .6193 L .81 .54 .531 r
F
.67854 .61922 m .67885 .6193 L .67861 .61915 L .683 .77 .917 r
F
.67734 .61407 m .68604 .60636 L .68155 .60546 L F
.67899 .61939 m .67885 .6193 L .67888 .62725 L .91 .629 .497 r
F
.67971 .56913 m .67882 .61073 L .67911 .61092 L F
.67573 .60878 m .68102 .60094 L .67618 .60081 L .683 .77 .917 r
F
.67555 .61211 m .67684 .60948 L .67573 .60878 L F
.67861 .61915 m .69036 .61253 L .68655 .61094 L F
.67926 .61956 m .69036 .61253 L .67861 .61915 L F
.67905 .61515 m .67899 .61939 L .67961 .61551 L .91 .629 .497 r
F
.67899 .61939 m .67888 .62725 L .67936 .61962 L F
.67899 .61939 m .67936 .61962 L .67961 .61551 L F
.67926 .61956 m .69322 .61473 L .69036 .61253 L .683 .77 .917 r
F
.6803 .61674 m .68033 .61659 L .68035 .62087 L 0 0 .152 r
F
.67918 .62275 m .68455 .62947 L .68207 .62439 L .683 .77 .917 r
F
.68033 .62097 m .68035 .62087 L .68038 .62913 L 0 0 .152 r
F
.6803 .61674 m .68035 .62087 L .68033 .62097 L F
.68837 .61939 m .70741 .62168 L .69148 .61689 L .683 .77 .917 r
F
.68032 .61715 m .69207 .62149 L .69411 .61866 L F
.68042 .62045 m .69543 .62027 L .69495 .61736 L F
.6803 .61674 m .68038 .62913 L .68021 .61732 L 0 0 .152 r
F
.67656 .62127 m .68031 .62107 L .68042 .62045 L .683 .77 .917 r
F
.68031 .62107 m .69543 .62027 L .68042 .62045 L F
.68021 .61732 m .68027 .62135 L .68022 .62161 L 0 0 .152 r
F
.68033 .61659 m .68019 .62056 L .68035 .62087 L .982 .725 .331 r
F
.67989 .61996 m .69322 .61473 L .67926 .61956 L .683 .77 .917 r
F
.67961 .61551 m .67936 .61962 L .67989 .61568 L .91 .629 .497 r
F
.67936 .61962 m .67888 .62725 L .67953 .61973 L F
.68222 .61175 m .69432 .61111 L .6841 .61029 L .683 .77 .917 r
F
.67936 .6146 m .69271 .61015 L .68985 .60795 L F
.67992 .61576 m .67995 .61581 L .68 .61165 L .982 .725 .331 r
F
.67968 .61526 m .69271 .61015 L .67936 .6146 L .683 .77 .917 r
F
.67992 .61576 m .6799 .61996 L .67995 .61581 L .982 .725 .331 r
F
.68027 .62135 m .68038 .62913 L .68022 .62161 L 0 0 .152 r
F
.68035 .62087 m .67994 .62808 L .68038 .62913 L .982 .725 .331 r
F
.68019 .62056 m .67994 .62808 L .68035 .62087 L F
.68016 .6217 m .68001 .62192 L .67988 .6178 L .082 0 .419 r
F
.67986 .61783 m .69207 .62149 L .68032 .61715 L .683 .77 .917 r
F
.67977 .61796 m .68026 .62994 L .67982 .63062 L .082 0 .419 r
F
.67996 .62009 m .6799 .61996 L .67994 .62808 L .982 .725 .331 r
F
.68207 .62439 m .68544 .63059 L .68945 .62858 L .683 .77 .917 r
F
.68455 .62947 m .68544 .63059 L .68207 .62439 L F
.6799 .61996 m .69495 .61736 L .69322 .61473 L F
.67656 .62127 m .68017 .6205 L .6799 .61996 L F
.68017 .6205 m .69495 .61736 L .6799 .61996 L F
.67998 .61587 m .67996 .62009 L .68033 .61659 L .982 .725 .331 r
F
.67996 .62009 m .67994 .62808 L .68019 .62056 L F
.67996 .62009 m .68019 .62056 L .68033 .61659 L F
.67656 .62127 m .67669 .61898 L .67571 .61912 L .683 .77 .917 r
F
.67573 .61912 m .67561 .62683 L .67668 .61899 L .66 .416 .54 r
F
.67571 .61912 m .6767 .61876 L .6757 .6191 L .683 .77 .917 r
F
.67669 .61898 m .6767 .61876 L .67571 .61912 L F
.67497 .61065 m .67618 .60081 L .6713 .60145 L F
.67555 .61211 m .67564 .61056 L .67497 .61065 L F
.67649 .56779 m .67539 .56788 L .67557 .61485 L .66 .416 .54 r
F
.67564 .61056 m .67618 .60081 L .67497 .61065 L .683 .77 .917 r
F
.67586 .61053 m .67558 .61914 L .67573 .61912 L .66 .416 .54 r
F
.67649 .56779 m .67574 .61054 L .67586 .61053 L F
.67574 .61054 m .67558 .61914 L .67586 .61053 L F
.67534 .61488 m .67669 .60533 L .67178 .60598 L .683 .77 .917 r
F
.67616 .61477 m .67669 .60533 L .67534 .61488 L F
.67566 .61484 m .67557 .61485 L .67558 .61914 L .66 .416 .54 r
F
.67649 .56779 m .67557 .61485 L .67566 .61484 L F
.67656 .62127 m .67571 .61912 L .67479 .6194 L .683 .77 .917 r
F
.67573 .61912 m .67558 .61914 L .67561 .62683 L .66 .416 .54 r
F
.67571 .61912 m .6757 .6191 L .67558 .61914 L .683 .77 .917 r
F
.67571 .61912 m .67558 .61914 L .67479 .6194 L F
.6757 .6191 m .6772 .60991 L .67229 .61056 L F
.67486 .61913 m .67648 .63184 L .6749 .63157 L .751 .491 .538 r
F
.67558 .61914 m .6745 .62717 L .67561 .62683 L .568 .343 .534 r
F
.675 .61933 m .6745 .62717 L .67558 .61914 L F
.67539 .56788 m .67475 .61084 L .67555 .61057 L F
.67402 .61553 m .66717 .60735 L .66316 .60936 L .683 .77 .917 r
F
.6735 .61159 m .67333 .616 L .67342 .61594 L .402 .214 .508 r
F
.67458 .61514 m .66717 .60735 L .67402 .61553 L .683 .77 .917 r
F
.67342 .61594 m .67333 .616 L .67334 .62029 L .402 .214 .508 r
F
.67479 .6194 m .67229 .61056 L .66768 .61193 L .683 .77 .917 r
F
.67475 .61084 m .67447 .61951 L .67462 .61946 L .568 .343 .534 r
F
.6757 .6191 m .67229 .61056 L .67479 .6194 L .683 .77 .917 r
F
.67462 .61946 m .67447 .61951 L .6745 .62717 L .568 .343 .534 r
F
.67428 .56822 m .67331 .61172 L .6735 .61159 L .402 .214 .508 r
F
.67323 .62257 m .65991 .6278 L .67382 .623 L .683 .77 .917 r
F
.67349 .62019 m .67334 .62029 L .67337 .62796 L .402 .214 .508 r
F
.67382 .623 m .66488 .62609 L .66278 .62999 L .683 .77 .917 r
F
.66227 .62541 m .65611 .63732 L .66608 .62701 L F
.66488 .62609 m .65991 .6278 L .66108 .62869 L F
.66488 .62609 m .66108 .62869 L .66278 .62999 L F
.67371 .61964 m .66768 .61193 L .66367 .61394 L F
.67656 .62127 m .6742 .61878 L .67371 .61964 L F
.67287 .62112 m .67306 .62079 L .67331 .61172 L 0 0 .382 r
F
.6742 .61878 m .66768 .61193 L .67371 .61964 L .683 .77 .917 r
F
.67292 .61241 m .67287 .62112 L .67331 .61172 L 0 0 .382 r
F
.67287 .62112 m .67283 .62899 L .67306 .62079 L F
.19539 .65059 m .19652 .6547 L .19699 .65927 L .793 .576 .01 r
F
.19539 .65059 m .19492 .64601 L .19652 .6547 L F
.21379 .64501 m .19652 .6547 L .21485 .6508 L .683 .77 .917 r
F
.21379 .64501 m .19492 .64601 L .19652 .6547 L F
0 g
.19652 .6547 m
.19929 .65879 L
s
.23227 .63943 m .21456 .64619 L .2328 .64231 L .683 .77 .917 r
F
.23227 .63943 m .2135 .64042 L .21456 .64619 L F
.63303 .52473 m .61172 .51749 L .60362 .52867 L .673 .757 .914 r
F
.63524 .64743 m .64615 .64763 L .64665 .65221 L .86 .591 .529 r
F
.63524 .64743 m .63473 .64285 L .64615 .64763 L F
.6485 .63414 m .64615 .64763 L .65611 .63732 L .683 .77 .917 r
F
.6485 .63414 m .63473 .64285 L .64615 .64763 L F
0 g
.64615 .64763 m
.65028 .64845 L
s
.61172 .52306 m .60326 .52862 L .60359 .5343 L .17 .075 .496 r
F
.61172 .52306 m .61139 .51738 L .60326 .52862 L F
0 g
.60007 .54058 m
.60326 .52862 L
s
.50842 .66153 m .50898 .65021 L .49428 .65215 L .683 .77 .917 r
F
.71469 .63862 m .71418 .63405 L .72357 .62653 L .406 .261 .57 r
F
0 g
.70735 .63746 m
.71418 .63405 L
s
.51379 .75445 m .51976 .76144 L .52506 .75931 L .645 .732 .913 r
F
.51073 .75504 m .51976 .76144 L .51379 .75445 L F
.38378 .40009 m .37639 .38009 L .36111 .38335 L .654 .726 .902 r
F
.39192 .39982 m .37639 .38009 L .38378 .40009 L F
.21607 .5378 m .19985 .53971 L .20013 .5454 L .514 .328 .566 r
F
0 g
.18777 .55514 m
.20013 .5454 L
s
.21607 .5378 m .21578 .53212 L .19985 .53971 L .514 .328 .566 r
F
0 g
.18748 .54946 m
.19985 .53971 L
s
.68292 .52435 m .6773 .50867 L .67646 .52394 L .673 .757 .914 r
F
.68292 .52435 m .69022 .50947 L .6773 .50867 L F
.40001 .40094 m .39268 .37956 L .39192 .39982 L .654 .726 .902 r
F
.40001 .40094 m .40887 .38179 L .39268 .37956 L F
.56346 .37652 m .54547 .39415 L .56827 .38098 L F
.56346 .37652 m .53587 .38523 L .54547 .39415 L F
.70118 .62666 m .71399 .63394 L .72333 .62646 L .683 .77 .917 r
F
.69321 .63066 m .71399 .63394 L .70118 .62666 L F
.127 .923 .03 r
.21747 .53042 m
.21756 .53164 L
s
.21747 .53042 m
.21749 .53166 L
s
.50097 .75752 m .49438 .7638 L .50039 .76569 L .645 .732 .913 r
F
.26905 .6404 m .28857 .63645 L .26981 .63744 L .683 .77 .917 r
F
.3369 .40415 m .30997 .39254 L .30001 .40678 L .654 .726 .902 r
F
.30951 .39983 m .30001 .40678 L .29956 .41407 L .058 0 .387 r
F
.30951 .39983 m .30997 .39254 L .30001 .40678 L F
0 g
.29626 .4224 m
.30001 .40678 L
s
.5105 .75885 m .51343 .76646 L .51957 .76528 L .645 .732 .913 r
F
.50723 .75892 m .51343 .76646 L .5105 .75885 L F
.74996 .53734 m .74271 .52069 L .74305 .52637 L .986 .71 .373 r
F
0 g
.74996 .53734 m
.75185 .54919 L
s
.37691 .51868 m .37576 .53505 L .38293 .52011 L .673 .757 .914 r
F
.37691 .51868 m .36373 .53221 L .37576 .53505 L F
.61262 .3833 m .63414 .39878 L .64449 .39091 L .654 .726 .902 r
F
.60598 .38618 m .63414 .39878 L .61262 .3833 L F
.28819 .65152 m .30857 .6446 L .28971 .64559 L .683 .77 .917 r
F
.27009 .64956 m .28819 .65152 L .28971 .64559 L F
.2681 .65239 m .28819 .65152 L .27009 .64956 L F
.48515 .76141 m .47987 .76973 L .48902 .76483 L .645 .732 .913 r
F
.48515 .76141 m .47407 .76461 L .47987 .76973 L F
0 g
.47987 .76973 m
.48754 .77385 L
s
.63348 .53603 m .60392 .53999 L .62805 .54352 L .673 .758 .914 r
F
.66994 .52458 m .66425 .50994 L .65199 .51322 L .673 .757 .914 r
F
.67646 .52394 m .66425 .50994 L .66994 .52458 L F
.34789 .38911 m .31083 .38543 L .33763 .39698 L .654 .726 .902 r
F
.53332 .77287 m .53979 .76468 L .53954 .76845 L .352 .179 .501 r
F
.52465 .76692 m .53332 .77287 L .53954 .76845 L .645 .732 .913 r
F
.51933 .76905 m .53332 .77287 L .52465 .76692 L F
0 g
.52533 .77607 m
.53332 .77287 L
s
.4826 .41633 m .47419 .39382 L .47375 .40111 L .99 .743 .457 r
F
.48217 .42362 m .4826 .41633 L .47375 .40111 L F
0 g
.4826 .41633 m
.48518 .43228 L
s
.39192 .39982 m .39268 .37956 L .37639 .38009 L .654 .726 .902 r
F
.44622 .40266 m .45932 .38058 L .43658 .39375 L F
.44622 .40266 m .47377 .39396 L .45932 .38058 L F
.67646 .52394 m .6773 .50867 L .66425 .50994 L .673 .757 .914 r
F
.68929 .53138 m .69064 .51501 L .68329 .52995 L F
.68929 .53138 m .70263 .51785 L .69064 .51501 L F
.69471 .5394 m .70296 .52354 L .68962 .53706 L .673 .758 .914 r
F
.69471 .5394 m .71313 .52823 L .70296 .52354 L F
.37148 .51065 m .35319 .52183 L .36343 .52652 L .673 .757 .914 r
F
0 g
.65477 .4127 m
.67005 .4122 L
s
.3081 .64002 m .30762 .63544 L .30605 .62675 L .787 .57 .003 r
F
0 g
.30642 .64011 m
.30748 .63599 L
s
.28857 .63645 m .30734 .63546 L .30578 .62681 L .683 .77 .917 r
F
.70329 .42254 m .7037 .41526 L .67933 .4119 L .732 .487 .557 r
F
0 g
.7037 .41526 m
.72619 .42254 L
s
.48047 .65626 m .46801 .6577 L .4685 .66228 L .523 .344 .581 r
F
0 g
.45918 .66978 m
.4685 .66228 L
s
.48047 .65626 m .47998 .65168 L .46801 .6577 L .523 .344 .581 r
F
0 g
.45869 .66521 m
.46801 .6577 L
s
.53654 .64869 m .53604 .64411 L .52257 .64144 L .794 .542 .556 r
F
0 g
.53604 .64411 m
.54748 .64889 L
s
.40676 .50427 m .42402 .51475 L .43227 .50828 L .673 .757 .914 r
F
.127 .923 .03 r
.51969 .64593 m
.5197 .64565 L
s
.47079 .75506 m .47457 .75706 L .47432 .76084 L .99 .751 .477 r
F
.127 .923 .03 r
.3883 1.09431 m
.49498 8.79989 L
s
.38351 .74822 m
.3883 1.09431 L
s
.47079 .75506 m .47104 .75128 L .47457 .75706 L .99 .751 .477 r
F
0 g
.47457 .75706 m
.47773 .75985 L
s
.56731 .39562 m .55717 .416 L .5737 .3992 L .654 .726 .902 r
F
.56731 .39562 m .5444 .40885 L .55717 .416 L F
.45428 .52132 m .46204 .50439 L .46235 .51007 L .165 .07 .493 r
F
.45459 .527 m .45428 .52132 L .46235 .51007 L F
.4328 .51404 m .45428 .52132 L .46235 .51007 L .673 .757 .914 r
F
.4245 .52054 m .45428 .52132 L .4328 .51404 L F
0 g
.44727 .52681 m
.45428 .52132 L
s
.48342 .75 m .47474 .75701 L .48576 .75383 L .645 .732 .913 r
F
.48342 .75 m .47122 .75126 L .47474 .75701 L F
.29143 .53074 m .29113 .52506 L .27307 .52079 L .794 .544 .559 r
F
0 g
.29113 .52506 m
.3065 .53209 L
s
.51357 .75826 m .51957 .76528 L .5249 .76315 L .645 .732 .913 r
F
.5105 .75885 m .51957 .76528 L .51357 .75826 L F
.60522 .40085 m .62019 .4193 L .63353 .41351 L .654 .726 .902 r
F
.59753 .40248 m .62019 .4193 L .60522 .40085 L F
.53979 .76468 m .54004 .76091 L .54407 .75557 L .083 0 .406 r
F
.127 .923 .03 r
.55146 1.36832 m
.56438 .73356 L
s
.51301 3.25714 m
.55146 1.36832 L
s
0 g
.53536 .76422 m
.54004 .76091 L
s
.52919 .75638 m .53988 .76084 L .54388 .75553 L .645 .732 .913 r
F
.127 .923 .03 r
.55341 .66012 m
.55389 .5927 L
s
.52506 .75931 m .53988 .76084 L .52919 .75638 L .645 .732 .913 r
F
.21426 .64959 m .19699 .65927 L .21532 .65538 L .683 .77 .917 r
F
.21426 .64959 m .19539 .65059 L .19699 .65927 L F
0 g
.19699 .65927 m
.20234 .66716 L
s
.66409 .53183 m .6522 .51877 L .6415 .52384 L .673 .757 .914 r
F
.67025 .53019 m .6522 .51877 L .66409 .53183 L F
.50072 .76129 m .50014 .76946 L .50373 .76224 L .645 .732 .913 r
F
.50072 .76129 m .49413 .76757 L .50014 .76946 L F
.23265 .64401 m .21485 .6508 L .23318 .64691 L .683 .77 .917 r
F
.23265 .64401 m .21379 .64501 L .21485 .6508 L F
.51025 .76262 m .51318 .77023 L .51933 .76905 L .645 .732 .913 r
F
.50698 .76269 m .51318 .77023 L .51025 .76262 L F
.649 .63871 m .64665 .65221 L .65662 .6419 L .683 .77 .917 r
F
.649 .63871 m .63524 .64743 L .64665 .65221 L F
0 g
.64665 .65221 m
.6601 .65488 L
s
.37562 .40891 m .36051 .39045 L .34722 .39624 L .654 .726 .902 r
F
.3833 .40727 m .36051 .39045 L .37562 .40891 L F
.72045 .52876 m .73123 .51136 L .71279 .52255 L .673 .757 .914 r
F
.72045 .52876 m .74271 .52069 L .73123 .51136 L F
.40213 .51823 m .41415 .53129 L .42481 .52622 L F
.39598 .51987 m .41415 .53129 L .40213 .51823 L F
.71469 .63862 m .72357 .62653 L .72408 .63111 L .406 .261 .57 r
F
.7152 .6432 m .71469 .63862 L .72408 .63111 L F
.70182 .63131 m .71469 .63862 L .72408 .63111 L .683 .77 .917 r
F
.69381 .63533 m .71469 .63862 L .70182 .63131 L F
0 g
.70786 .64204 m
.71469 .63862 L
s
.49818 .39342 m .50745 .40136 L .50702 .40865 L .99 .743 .457 r
F
.49818 .39342 m .49861 .38613 L .50745 .40136 L F
.52928 .38245 m .50745 .40136 L .53516 .39261 L .654 .726 .902 r
F
.52928 .38245 m .49861 .38613 L .50745 .40136 L F
0 g
.50745 .40136 m
.5132 .40669 L
s
.40713 .41056 m .40851 .38888 L .39961 .40813 L .654 .726 .902 r
F
.40713 .41056 m .42356 .39375 L .40851 .38888 L F
0 g
.67963 .54936 m
.67971 .56913 L
s
.28857 .63645 m .30578 .62681 L .28753 .63068 L .683 .77 .917 r
F
.26981 .63744 m .28857 .63645 L .28753 .63068 L F
.26962 .64498 m .28924 .64102 L .27038 .64202 L F
0 g
.67308 .54947 m
.67315 .56901 L
s
.65907 .54005 m .64183 .52952 L .63348 .53603 L .673 .758 .914 r
F
.66442 .53752 m .64183 .52952 L .65907 .54005 L F
.64134 .51826 m .61172 .51749 L .63303 .52473 L .673 .757 .914 r
F
.49679 .75065 m .48576 .75383 L .48961 .75723 L .645 .732 .913 r
F
.67117 .40992 m .68171 .3884 L .68131 .39569 L .074 0 .397 r
F
.64435 .39832 m .67117 .40992 L .68131 .39569 L .654 .726 .902 r
F
.63394 .40623 m .67117 .40992 L .64435 .39832 L F
0 g
.67013 .41071 m
.67117 .40992 L
s
.67117 .40992 m
.67159 .40932 L
s
.51644 .75339 m .52506 .75931 L .52919 .75638 L .645 .732 .913 r
F
.51379 .75445 m .52506 .75931 L .51644 .75339 L F
.127 .923 .03 r
.21793 .53639 m
.218 .53728 L
s
.63315 .53034 m .61172 .52306 L .60359 .5343 L .673 .757 .914 r
F
.61205 .52875 m .60359 .5343 L .60392 .53999 L .17 .075 .496 r
F
.61205 .52875 m .61172 .52306 L .60359 .5343 L F
0 g
.6004 .54626 m
.60359 .5343 L
s
.68329 .52995 m .67764 .5142 L .6768 .52955 L .673 .757 .914 r
F
.68329 .52995 m .69064 .51501 L .67764 .5142 L F
.36853 .41909 m .34677 .40353 L .33645 .41144 L .654 .726 .902 r
F
.37517 .4162 m .34677 .40353 L .36853 .41909 L F
.41309 .42142 m .42312 .40104 L .40669 .41785 L F
.41309 .42142 m .43593 .4082 L .42312 .40104 L F
0 g
.67989 .61568 m
.6799 .61782 L
s
.67971 .56913 m
.67983 .60091 L
s
.127 .923 .03 r
.21758 .53581 m
.21761 .53739 L
s
0 g
.67315 .56901 m
.67327 .60119 L
s
.26981 .63744 m .28753 .63068 L .26928 .63456 L .683 .77 .917 r
F
.70329 .42254 m .67933 .4119 L .67893 .41918 L .732 .487 .557 r
F
0 g
.67933 .4119 m
.7037 .41526 L
s
.70329 .42254 m
.72579 .42983 L
s
.67327 .41209 m
.67933 .4119 L
s
.67025 .53019 m .66453 .51548 L .6522 .51877 L .673 .757 .914 r
F
.6768 .52955 m .66453 .51548 L .67025 .53019 L F
.3081 .64002 m .30605 .62675 L .30653 .63132 L .787 .57 .003 r
F
.28924 .64102 m .3081 .64002 L .30653 .63132 L .683 .77 .917 r
F
.30857 .6446 m .3081 .64002 L .30653 .63132 L .787 .57 .003 r
F
0 g
.30689 .64469 m
.30795 .64057 L
s
.47053 .75883 m .47432 .76084 L .47407 .76461 L .99 .751 .477 r
F
.47053 .75883 m .47079 .75506 L .47432 .76084 L F
.48304 .75378 m .47432 .76084 L .4854 .75764 L .645 .732 .913 r
F
.48304 .75378 m .47079 .75506 L .47432 .76084 L F
0 g
.47432 .76084 m
.47748 .76363 L
s
.49816 .75992 m .49413 .76757 L .50072 .76129 L .645 .732 .913 r
F
.49816 .75992 m .48902 .76483 L .49413 .76757 L F
.53654 .64869 m .52257 .64144 L .52307 .64602 L .794 .542 .556 r
F
.53704 .65327 m .53654 .64869 L .52307 .64602 L F
0 g
.53654 .64869 m
.54798 .65347 L
s
.31618 .51272 m .32298 .51801 L .32328 .52369 L .987 .712 .386 r
F
.127 .923 .03 r
.32095 .48714 m
.32121 .51663 L
s
.32124 .52054 m
.32139 .53744 L
s
.31618 .51272 m .31588 .50703 L .32298 .51801 L .987 .712 .386 r
F
0 g
.32298 .51801 m
.32795 .52199 L
s
.51332 .76203 m .51933 .76905 L .52465 .76692 L .645 .732 .913 r
F
.51025 .76262 m .51933 .76905 L .51332 .76203 L F
.6768 .52955 m .67764 .5142 L .66453 .51548 L .673 .757 .914 r
F
.53979 .76468 m .54407 .75557 L .54382 .75935 L .083 0 .406 r
F
.53954 .76845 m .53979 .76468 L .54382 .75935 L F
.52905 .7602 m .53979 .76468 L .54382 .75935 L .645 .732 .913 r
F
.127 .923 .03 r
.55339 .66374 m
.55341 .66012 L
s
.5249 .76315 m .53979 .76468 L .52905 .7602 L .645 .732 .913 r
F
0 g
.53511 .768 m
.53979 .76468 L
s
.34066 .50257 m .32332 .51789 L .34536 .50986 L .673 .757 .914 r
F
.34066 .50257 m .31625 .50697 L .32332 .51789 L F
.68962 .53706 m .69097 .52069 L .68363 .53564 L .673 .758 .914 r
F
.68962 .53706 m .70296 .52354 L .69097 .52069 L F
.5629 .38385 m .54482 .40156 L .56773 .38833 L .654 .726 .902 r
F
.5629 .38385 m .53516 .39261 L .54482 .40156 L F
.37179 .51634 m .36373 .53221 L .37691 .51868 L .673 .757 .914 r
F
.37179 .51634 m .35349 .52752 L .36373 .53221 L F
.36742 .50182 m .35307 .51604 L .37127 .50491 L F
.36742 .50182 m .34536 .50986 L .35307 .51604 L F
.127 .923 .03 r
.51962 .65049 m
.51963 .64997 L
s
.3833 .40727 m .37587 .38718 L .36051 .39045 L .654 .726 .902 r
F
.39148 .40701 m .37587 .38718 L .3833 .40727 L F
.33645 .41144 m .30951 .39983 L .29956 .41407 L F
0 g
.2958 .42969 m
.29956 .41407 L
s
.39961 .40813 m .39224 .38664 L .39148 .40701 L .654 .726 .902 r
F
.39961 .40813 m .40851 .38888 L .39224 .38664 L F
.40715 .51001 m .4245 .52054 L .4328 .51404 L .673 .757 .914 r
F
.61231 .39066 m .63394 .40623 L .64435 .39832 L .654 .726 .902 r
F
.60564 .39356 m .63394 .40623 L .61231 .39066 L F
.23312 .64859 m .21532 .65538 L .23365 .65149 L .683 .77 .917 r
F
.23312 .64859 m .21426 .64959 L .21532 .65538 L F
.62613 .63629 m .63423 .63828 L .63473 .64285 L .934 .647 .473 r
F
.127 .923 .03 r
.62837 .63684 m
.62906 .59456 L
s
.62613 .63629 m .62562 .63171 L .63423 .63828 L .934 .647 .473 r
F
0 g
.63423 .63828 m
.63888 .64023 L
s
.25104 .63844 m .24661 .6278 L .24204 .62917 L .683 .77 .917 r
F
.49648 .75444 m .4854 .75764 L .48927 .76105 L .645 .732 .913 r
F
.64242 .62511 m .63443 .63815 L .64813 .62947 L .683 .77 .917 r
F
.64242 .62511 m .62587 .63161 L .63443 .63815 L F
.127 .923 .03 r
.62662 .7448 m
.62803 .65788 L
s
.62803 .65788 m
.62835 .63799 L
s
.7152 .6432 m .72408 .63111 L .72459 .63568 L .406 .261 .57 r
F
.70233 .63589 m .7152 .6432 L .72459 .63568 L .683 .77 .917 r
F
.69432 .63991 m .7152 .6432 L .70233 .63589 L F
0 g
.70318 .64922 m
.7152 .6432 L
s
.51624 .75719 m .5249 .76315 L .52905 .7602 L .645 .732 .913 r
F
.51357 .75826 m .5249 .76315 L .51624 .75719 L F
.49379 .64757 m .47949 .64711 L .47998 .65168 L .606 .404 .582 r
F
.49379 .64757 m .4933 .64299 L .47949 .64711 L F
0 g
.46752 .65312 m
.47949 .64711 L
s
.28924 .64102 m .30653 .63132 L .28819 .63522 L .683 .77 .917 r
F
.27038 .64202 m .28924 .64102 L .28819 .63522 L F
.45459 .527 m .46235 .51007 L .46267 .51575 L .165 .07 .493 r
F
.43311 .51972 m .45459 .527 L .46267 .51575 L .673 .757 .914 r
F
.42481 .52622 m .45459 .527 L .43311 .51972 L F
0 g
.44214 .53675 m
.45459 .527 L
s
.2342 .52718 m .21549 .52643 L .21578 .53212 L .602 .395 .573 r
F
.2342 .52718 m .23391 .5215 L .21549 .52643 L F
0 g
.19956 .53403 m
.21549 .52643 L
s
.27009 .64956 m .28971 .64559 L .27085 .64659 L .683 .77 .917 r
F
.29143 .53074 m .27307 .52079 L .27337 .52647 L .794 .544 .559 r
F
.29173 .53643 m .29143 .53074 L .27337 .52647 L F
0 g
.29143 .53074 m
.3068 .53777 L
s
.48217 .42362 m .47375 .40111 L .47332 .4084 L .99 .743 .457 r
F
0 g
.48217 .42362 m
.48475 .43957 L
s
.34722 .39624 m .30997 .39254 L .3369 .40415 L .654 .726 .902 r
F
.66442 .53752 m .65254 .52445 L .64183 .52952 L .673 .758 .914 r
F
.67058 .53587 m .65254 .52445 L .66442 .53752 L F
.39148 .40701 m .39224 .38664 L .37587 .38718 L .654 .726 .902 r
F
.72079 .53444 m .73157 .51705 L .71313 .52823 L .673 .758 .914 r
F
.72079 .53444 m .74305 .52637 L .73157 .51705 L F
.44606 .40986 m .45923 .38767 L .43637 .40091 L .654 .726 .902 r
F
.44606 .40986 m .47375 .40111 L .45923 .38767 L F
0 0 0 r
2.5 Mabswid
.21839 .54237 Mdot
0 g
.5 Mabswid
.65436 .41998 m
.66965 .41949 L
s
.66965 .41949 m
.67893 .41918 L
s
.23302 .63648 m .2135 .64042 L .23227 .63943 L .683 .77 .917 r
F
.6415 .52384 m .61172 .52306 L .63315 .53034 L .673 .757 .914 r
F
0 g
.67893 .41918 m
.70329 .42254 L
s
.48279 .75756 m .47407 .76461 L .48515 .76141 L .645 .732 .913 r
F
.48279 .75756 m .47053 .75883 L .47407 .76461 L F
0 g
.47407 .76461 m
.47987 .76973 L
s
.27038 .64202 m .28819 .63522 L .26985 .63912 L .683 .77 .917 r
F
.63348 .53603 m .61205 .52875 L .60392 .53999 L .673 .758 .914 r
F
0 g
.60072 .55194 m
.60392 .53999 L
s
.30857 .6446 m .30653 .63132 L .30701 .6359 L .787 .57 .003 r
F
.28971 .64559 m .30857 .6446 L .30701 .6359 L .683 .77 .917 r
F
0 g
.30628 .65349 m
.30857 .6446 L
s
.53954 .76845 m .54382 .75935 L .54357 .76312 L .083 0 .406 r
F
.5288 .76397 m .53954 .76845 L .54357 .76312 L .645 .732 .913 r
F
.127 .923 .03 r
.55336 .66735 m
.55339 .66374 L
s
.52465 .76692 m .53954 .76845 L .5288 .76397 L .645 .732 .913 r
F
0 g
.53332 .77287 m
.53954 .76845 L
s
.68363 .53564 m .67798 .51988 L .67714 .53523 L .673 .758 .914 r
F
.68363 .53564 m .69097 .52069 L .67798 .51988 L F
.49562 .74873 m .48576 .75383 L .49679 .75065 L .645 .732 .913 r
F
.49562 .74873 m .48342 .75 L .48576 .75383 L F
.53704 .65327 m .52307 .64602 L .52357 .6506 L .794 .542 .556 r
F
0 g
.53704 .65327 m
.54847 .65804 L
s
.52307 .64602 m .52257 .64144 L .50799 .64106 L .733 .497 .57 r
F
0 g
.52257 .64144 m
.53604 .64411 L
s
.52919 .75638 m .54388 .75553 L .53186 .75284 L .645 .732 .913 r
F
.51851 .75192 m .52919 .75638 L .53186 .75284 L F
.51644 .75339 m .52919 .75638 L .51851 .75192 L F
.37517 .4162 m .36006 .39774 L .34677 .40353 L .654 .726 .902 r
F
.38285 .41456 m .36006 .39774 L .37517 .4162 L F
.52886 .38974 m .50702 .40865 L .53474 .39989 L F
.52886 .38974 m .49818 .39342 L .50702 .40865 L F
0 g
.50702 .40865 m
.52151 .42207 L
s
.49623 .75821 m .48902 .76483 L .49816 .75992 L .645 .732 .913 r
F
.49623 .75821 m .48515 .76141 L .48902 .76483 L F
.40669 .41785 m .40807 .39618 L .39916 .41542 L .654 .726 .902 r
F
.40669 .41785 m .42312 .40104 L .40807 .39618 L F
.67058 .53587 m .66487 .52116 L .65254 .52445 L .673 .758 .914 r
F
.67714 .53523 m .66487 .52116 L .67058 .53587 L F
.215 .63452 m .19473 .64142 L .2135 .64042 L .683 .77 .917 r
F
.23302 .63648 m .215 .63452 L .2135 .64042 L F
.71227 .51697 m .71544 .49884 L .70215 .51231 L .673 .757 .914 r
F
.71227 .51697 m .73061 .50585 L .71544 .49884 L F
.51599 .76097 m .52465 .76692 L .5288 .76397 L .645 .732 .913 r
F
.51332 .76203 m .52465 .76692 L .51599 .76097 L F
0 0 0 r
2.5 Mabswid
.2177 .54121 Mdot
.127 .923 .03 r
.5 Mabswid
.24094 1.63885 m
.3931 8.82462 L
s
.2177 .54121 m
.21915 .61005 L
s
.62663 .64087 m .63473 .64285 L .63524 .64743 L .934 .647 .473 r
F
.62663 .64087 m .62613 .63629 L .63473 .64285 L F
.64276 .62976 m .63473 .64285 L .6485 .63414 L .683 .77 .917 r
F
.64276 .62976 m .62613 .63629 L .63473 .64285 L F
0 g
.63473 .64285 m
.63939 .6448 L
s
.25151 .64301 m .24706 .63233 L .24246 .6337 L .683 .77 .917 r
F
.31648 .5184 m .32328 .52369 L .32358 .52938 L .987 .712 .386 r
F
.31648 .5184 m .31618 .51272 L .32328 .52369 L F
.34071 .5083 m .32328 .52369 L .34544 .51562 L .673 .757 .914 r
F
.34071 .5083 m .31618 .51272 L .32328 .52369 L F
0 g
.32328 .52369 m
.32825 .52767 L
s
.26928 .63456 m .284 .62544 L .26752 .63194 L .683 .77 .917 r
F
.26928 .63456 m .28753 .63068 L .284 .62544 L F
.67714 .53523 m .67798 .51988 L .66487 .52116 L .673 .758 .914 r
F
.67076 .41721 m .68131 .39569 L .68091 .40298 L .074 0 .397 r
F
.64394 .40561 m .67076 .41721 L .68091 .40298 L .654 .726 .902 r
F
.63353 .41351 m .67076 .41721 L .64394 .40561 L F
0 g
.66973 .41799 m
.67076 .41721 L
s
.67076 .41721 m
.67119 .41661 L
s
.49428 .65215 m .47998 .65168 L .48047 .65626 L .606 .404 .582 r
F
0 g
.4685 .66228 m
.48047 .65626 L
s
.49428 .65215 m .49379 .64757 L .47998 .65168 L .606 .404 .582 r
F
0 g
.46801 .6577 m
.47998 .65168 L
s
0 0 0 r
2.5 Mabswid
.51957 .6543 Mdot
.127 .923 .03 r
.5 Mabswid
.39879 8.82518 m
.50224 1.8268 L
s
.51861 .71916 m
.51957 .6543 L
s
.28971 .64559 m .30701 .6359 L .28867 .6398 L .683 .77 .917 r
F
.27085 .64659 m .28971 .64559 L .28867 .6398 L F
.74271 .52069 m .74236 .515 L .73089 .50568 L .934 .657 .492 r
F
0 g
.74236 .515 m
.74928 .52597 L
s
.36761 .50754 m .35319 .52183 L .37148 .51065 L .673 .757 .914 r
F
.36761 .50754 m .34544 .51562 L .35319 .52183 L F
.40746 .51569 m .42481 .52622 L .43311 .51972 L F
.40213 .51823 m .42481 .52622 L .40746 .51569 L F
.66608 .62701 m .65611 .63732 L .66508 .63911 L .683 .77 .917 r
F
.72408 .63111 m .72357 .62653 L .72969 .61803 L .207 .12 .531 r
F
0 g
.71778 .63116 m
.72357 .62653 L
s
.70741 .62168 m .72333 .62646 L .72942 .618 L .683 .77 .917 r
F
.70118 .62666 m .72333 .62646 L .70741 .62168 L F
.215 .63452 m .19698 .63256 L .19473 .64142 L F
.19717 .63711 m .19445 .64143 L .19492 .64601 L 0 0 .375 r
F
0 g
.19514 .64515 m
.19529 .64599 L
s
.19717 .63711 m .1967 .63253 L .19445 .64143 L 0 0 .375 r
F
.23449 .53287 m .21578 .53212 L .21607 .5378 L .602 .395 .573 r
F
0 g
.20013 .5454 m
.21607 .5378 L
s
.23449 .53287 m .2342 .52718 L .21578 .53212 L .602 .395 .573 r
F
0 g
.19985 .53971 m
.21578 .53212 L
s
.27337 .52647 m .27307 .52079 L .25355 .51958 L .733 .496 .569 r
F
0 g
.27307 .52079 m
.29113 .52506 L
s
.29173 .53643 m .27337 .52647 L .27366 .53216 L .794 .544 .559 r
F
0 g
.29173 .53643 m
.3071 .54345 L
s
.50849 .64563 m .4933 .64299 L .49379 .64757 L .673 .453 .579 r
F
.50849 .64563 m .50799 .64106 L .4933 .64299 L F
0 g
.47949 .64711 m
.4933 .64299 L
s
.127 .923 .03 r
.50568 .64175 m
.50569 .63744 L
s
.23341 .64105 m .21379 .64501 L .23265 .64401 L .683 .77 .917 r
F
.46975 .74902 m .47104 .75128 L .47079 .75506 L .927 .752 .27 r
F
.46975 .74902 m .47001 .74524 L .47104 .75128 L F
0 g
.47104 .75128 m
.47319 .75481 L
s
.48274 .74599 m .47122 .75126 L .48342 .75 L .645 .732 .913 r
F
.48274 .74599 m .47019 .74525 L .47122 .75126 L F
.4953 .75251 m .4854 .75764 L .49648 .75444 L F
.4953 .75251 m .48304 .75378 L .4854 .75764 L F
.27085 .64659 m .28867 .6398 L .27033 .6437 L .683 .77 .917 r
F
.54382 .75935 m .54407 .75557 L .54563 .74968 L 0 0 .146 r
F
.127 .923 .03 r
.52764 1.96195 m
.54346 1.11529 L
s
0 g
.5411 .7595 m
.54407 .75557 L
s
.127 .923 .03 r
.55113 .98508 m
.55336 .66735 L
s
.54077 2.45795 m
.55113 .98508 L
s
.52905 .7602 m .54382 .75935 L .53174 .75664 L .645 .732 .913 r
F
.51831 .75572 m .52905 .7602 L .53174 .75664 L F
.127 .923 .03 r
.51856 .72276 m
.51861 .71916 L
s
.51624 .75719 m .52905 .7602 L .51831 .75572 L .645 .732 .913 r
F
.53186 .75284 m .54388 .75553 L .54544 .74967 L F
.52307 .64602 m .50799 .64106 L .50849 .64563 L .733 .497 .57 r
F
0 g
.4933 .64299 m
.50799 .64106 L
s
.50799 .64106 m
.52257 .64144 L
s
.43227 .50828 m .46167 .50434 L .43762 .50082 L .673 .757 .914 r
F
.41089 .50103 m .43227 .50828 L .43762 .50082 L F
.56248 .39114 m .5444 .40885 L .56731 .39562 L .654 .726 .902 r
F
.56248 .39114 m .53474 .39989 L .5444 .40885 L F
.67593 .63261 m .6753 .64394 L .6851 .64265 L .683 .77 .917 r
F
.67107 .63248 m .6753 .64394 L .67593 .63261 L F
.67107 .63248 m .66558 .64368 L .6753 .64394 L F
.66184 .62079 m .64813 .62947 L .6557 .63265 L F
.51101 .75201 m .51831 .75572 L .51965 .75394 L .645 .732 .913 r
F
.50757 .75124 m .51091 .75263 L .51101 .75201 L F
.51091 .75263 m .51831 .75572 L .51101 .75201 L F
.51098 .75187 m .5111 .75106 L .5111 .75145 L 0 0 .142 r
F
.51054 .75255 m .51055 .75279 L .51054 .75279 L .076 0 .415 r
F
.51182 .75301 m .51624 .75719 L .51831 .75572 L .645 .732 .913 r
F
.51054 .75255 m .51098 .75187 L .51098 .75218 L .076 0 .415 r
F
.51057 .75631 m .51098 .75575 L .51099 .81108 L F
.50959 .75767 m .51332 .76203 L .51012 .75694 L .645 .732 .913 r
F
.512 .75697 m .51599 .76097 L .51806 .75949 L F
.50979 .75384 m .5105 .75885 L .51357 .75826 L F
.50732 .75501 m .51285 .75882 L .512 .75697 L F
.51285 .75882 m .51599 .76097 L .512 .75697 L F
.51072 .75255 m .51259 .75469 L .51182 .75301 L F
.51099 .75213 m .5111 .75145 L .5111 .75501 L 0 0 .142 r
F
.51109 .75144 m .51107 .75495 L .5111 .75145 L .984 .727 .339 r
F
.51107 .75495 m .51066 .80923 L .51107 .75495 L F
.51078 .75344 m .51357 .75826 L .51624 .75719 L .645 .732 .913 r
F
.50757 .75124 m .51057 .75475 L .51078 .75344 L F
.51057 .75475 m .51357 .75826 L .51078 .75344 L F
.51098 .75218 m .5111 .75501 L .51099 .7557 L 0 0 .142 r
F
.51098 .75187 m .51099 .75213 L .51098 .75218 L F
.51031 .75312 m .51259 .75469 L .51072 .75255 L .645 .732 .913 r
F
.51099 .75213 m .5111 .75501 L .51098 .75218 L 0 0 .142 r
F
.51107 .75495 m .51107 .75495 L .5111 .75145 L .984 .727 .339 r
F
.51099 .7557 m .5111 .75501 L .51111 .81027 L 0 0 .142 r
F
.51098 .75575 m .51111 .81027 L .51099 .81108 L F
.51098 .75187 m .51099 .7557 L .51098 .75575 L F
.51099 .7557 m .51111 .81027 L .51098 .75575 L F
.51097 .75583 m .51806 .75949 L .5194 .75772 L .645 .732 .913 r
F
.50899 .75494 m .5105 .75885 L .50979 .75384 L F
.50881 .75356 m .50983 .75312 L .50983 .75684 L .517 .303 .528 r
F
.50878 .75881 m .51025 .76262 L .50959 .75767 L .645 .732 .913 r
F
.50887 .75718 m .50983 .75684 L .50984 .81233 L .517 .303 .528 r
F
.50881 .75356 m .50983 .75684 L .50887 .75718 L F
.50732 .75501 m .51085 .75649 L .51097 .75583 L .645 .732 .913 r
F
.51086 .75649 m .51806 .75949 L .51097 .75583 L F
.5111 .75501 m .51066 .80923 L .51111 .81027 L .984 .727 .339 r
F
.5111 .75145 m .51107 .75495 L .5111 .75501 L F
.51107 .75495 m .51066 .80923 L .5111 .75501 L F
.51012 .75694 m .51332 .76203 L .51418 .76169 L .645 .732 .913 r
F
.51285 .75882 m .51418 .76169 L .51599 .76097 L F
.51012 .75694 m .51418 .76169 L .51285 .75882 L F
.50732 .75501 m .50959 .75767 L .51012 .75694 L F
.51055 .75279 m .51098 .75218 L .51098 .75575 L .076 0 .415 r
F
.51055 .75279 m .51098 .75575 L .51057 .75631 L F
.51054 .75255 m .51098 .75218 L .51055 .75279 L F
.50757 .75124 m .51031 .75312 L .51072 .75255 L .645 .732 .913 r
F
.51259 .75469 m .51624 .75719 L .51182 .75301 L F
.5111 .75106 m .51109 .75144 L .5111 .75145 L .984 .727 .339 r
F
.51098 .75187 m .5111 .75145 L .51099 .75213 L 0 0 .142 r
F
.5105 .75874 m .51025 .76262 L .51332 .76203 L .645 .732 .913 r
F
.50959 .75767 m .51008 .76136 L .5105 .75874 L F
.51008 .76136 m .51025 .76262 L .5105 .75874 L F
.50721 .75376 m .50881 .75356 L .50881 .7572 L .641 .402 .54 r
F
.50818 .75725 m .50878 .75881 L .50917 .75717 L .645 .732 .913 r
F
.50732 .75501 m .50698 .76269 L .51025 .76262 L F
.50669 .81027 m .50884 .81277 L .50782 .81012 L .692 .759 .903 r
F
.50796 .812 m .50695 .81249 L .50809 .81233 L .692 .759 .904 r
F
.50722 .81 m .50833 .81193 L .50722 .81214 L .641 .402 .54 r
F
.50706 .80966 m .50696 .81219 L .50796 .812 L .692 .759 .904 r
F
.50696 .81219 m .50695 .81249 L .50796 .812 L F
.50657 .81309 m .50986 .81542 L .50884 .81277 L .692 .759 .903 r
F
.50695 .81249 m .50912 .815 L .50809 .81233 L .692 .759 .904 r
F
.50722 .81214 m .50882 .81277 L .50722 .81297 L .641 .402 .54 r
F
.50786 .81014 m .50884 .81277 L .51098 .81209 L .692 .759 .903 r
F
.50782 .81012 m .50784 .81015 L .50786 .81014 L F
.50784 .81015 m .50884 .81277 L .50786 .81014 L F
.50985 .81134 m .50899 .8118 L .51009 .81149 L .692 .759 .904 r
F
.50882 .80969 m .50952 .8115 L .50882 .81184 L .517 .303 .528 r
F
.50881 .80969 m .50782 .81012 L .50889 .80978 L .692 .759 .903 r
F
.50774 .8099 m .50782 .81012 L .50881 .80969 L F
.50873 .80971 m .50879 .81184 L .50722 .81 L .641 .402 .54 r
F
.50706 .80966 m .50896 .81177 L .50985 .81134 L .692 .759 .904 r
F
.50896 .81177 m .50899 .8118 L .50985 .81134 L F
.50884 .81277 m .51307 .81441 L .51098 .81209 L .692 .759 .903 r
F
.50809 .81233 m .51126 .81432 L .50916 .81199 L .692 .759 .904 r
F
.50882 .81184 m .50984 .81233 L .50882 .81277 L .517 .303 .528 r
F
.50899 .8118 m .50916 .81199 L .5098 .81165 L .692 .759 .904 r
F
.50916 .81199 m .51312 .81332 L .51009 .81149 L F
.50952 .8115 m .50984 .81233 L .50882 .81184 L .517 .303 .528 r
F
.51397 .7554 m .5194 .75772 L .51992 .75575 L .645 .732 .913 r
F
.51109 .75144 m .51965 .75394 L .52017 .75198 L F
.50757 .75124 m .51139 .75209 L .51109 .75144 L F
.51139 .75209 m .51965 .75394 L .51109 .75144 L F
.5111 .75106 m .51065 .75002 L .51065 .75048 L .984 .727 .339 r
F
.51105 .75135 m .51065 .75048 L .51065 .75404 L F
.5111 .75106 m .51065 .75048 L .51105 .75135 L F
.50965 .81003 m .51098 .81209 L .51283 .8111 L .692 .759 .903 r
F
.50963 .80938 m .51283 .8111 L .50982 .80928 L F
.50889 .80978 m .50908 .80984 L .50963 .80938 L F
.50908 .80984 m .51283 .8111 L .50963 .80938 L F
.50943 .81037 m .51098 .81209 L .50965 .81003 L F
.50782 .81012 m .51098 .81209 L .50889 .80978 L F
.51053 .81078 m .51009 .81149 L .51082 .81087 L .692 .759 .904 r
F
.50706 .80966 m .50985 .81134 L .51053 .81078 L F
.50985 .81134 m .51009 .81149 L .51053 .81078 L F
.50984 .81135 m .51055 .81176 L .50984 .81233 L .358 .18 .498 r
F
.50984 .8092 m .51033 .81095 L .50984 .81135 L F
.51033 .81095 m .51055 .81176 L .50984 .81135 L F
.5162 .75245 m .51958 .75374 L .51841 .75181 L .645 .732 .913 r
F
.50983 .75684 m .51052 .80865 L .50984 .8092 L .358 .18 .498 r
F
.50983 .75312 m .51054 .75255 L .51054 .75635 L F
.50988 .75681 m .51054 .75635 L .51055 .81176 L F
.50983 .75312 m .51054 .75635 L .50988 .75681 L F
.50732 .75501 m .51122 .75589 L .5112 .75524 L .645 .732 .913 r
F
.51122 .75589 m .51153 .75595 L .51143 .75574 L F
.51122 .75589 m .51143 .75574 L .5112 .75524 L F
.50881 .7572 m .50979 .80923 L .50882 .80969 L .517 .303 .528 r
F
.5068 .80746 m .511 .80796 L .51118 .80722 L .692 .759 .903 r
F
.5068 .80746 m .51118 .80722 L .51107 .8065 L F
.51065 .75404 m .5096 .80841 L .51066 .80923 L .909 .63 .5 r
F
.51065 .75002 m .51058 .75399 L .51065 .75404 L F
.51054 .75279 m .51057 .75632 L .51054 .75635 L .076 0 .415 r
F
.51185 .75454 m .51992 .75575 L .51958 .75374 L .645 .732 .913 r
F
.51057 .75631 m .51057 .75632 L .51054 .75279 L .076 0 .415 r
F
.51052 .75038 m .51983 .74996 L .51865 .74803 L .645 .732 .913 r
F
.50757 .75124 m .51116 .75086 L .51052 .75038 L F
.51116 .75086 m .51983 .74996 L .51052 .75038 L F
.51065 .75002 m .50959 .7492 L .50959 .74968 L .909 .63 .5 r
F
.51249 .75073 m .52017 .75198 L .51983 .74996 L .645 .732 .913 r
F
.50757 .75124 m .51515 .75168 L .51249 .75073 L F
.51515 .75168 m .52017 .75198 L .51249 .75073 L F
.50887 .75718 m .50979 .80923 L .50881 .7572 L .517 .303 .528 r
F
.51055 .75279 m .51057 .75631 L .51054 .75279 L .076 0 .415 r
F
.51065 .75002 m .50959 .75325 L .51058 .75399 L .909 .63 .5 r
F
.50928 .75314 m .51647 .7501 L .51392 .74873 L .645 .732 .913 r
F
.50757 .75124 m .50899 .75494 L .50979 .75384 L F
.50732 .75501 m .5102 .75347 L .50928 .75314 L F
.5102 .75347 m .51647 .7501 L .50928 .75314 L F
.5068 .80746 m .51054 .80866 L .511 .80796 L .692 .759 .903 r
F
.50959 .75325 m .50857 .80521 L .5096 .80548 L .809 .541 .532 r
F
.50878 .80526 m .50998 .8053 L .5091 .80491 L .692 .759 .903 r
F
.50721 .75376 m .50873 .80971 L .50722 .81 L .641 .402 .54 r
F
.5068 .80746 m .50969 .8055 L .50878 .80526 L .692 .759 .903 r
F
.50969 .8055 m .50998 .8053 L .50878 .80526 L F
.5068 .80746 m .51107 .8065 L .51066 .80585 L F
.5096 .80548 m .50878 .80741 L .5096 .80762 L .809 .541 .532 r
F
.50903 .80747 m .51026 .80749 L .50937 .80709 L .692 .759 .904 r
F
.5068 .80746 m .50774 .8099 L .50881 .80969 L .692 .759 .903 r
F
.5068 .80746 m .50982 .80928 L .51054 .80866 L F
.50706 .80966 m .50994 .80771 L .50903 .80747 L .692 .759 .904 r
F
.50994 .80771 m .51026 .80749 L .50903 .80747 L F
.5096 .80762 m .50852 .80803 L .5096 .80841 L .809 .541 .532 r
F
.50878 .80741 m .50852 .80803 L .5096 .80762 L F
.5068 .80746 m .51066 .80585 L .50998 .8053 L .692 .759 .903 r
F
.50857 .80521 m .50852 .80803 L .5096 .80548 L .809 .541 .532 r
F
.50959 .74968 m .50952 .75322 L .50959 .75325 L F
.50952 .75322 m .50852 .80803 L .50959 .75325 L F
.50959 .7492 m .50958 .74968 L .50959 .74968 L F
.5102 .75347 m .51841 .75181 L .51647 .7501 L .645 .732 .913 r
F
.50732 .75501 m .5113 .75386 L .5102 .75347 L F
.5111 .75106 m .51065 .75404 L .51107 .75495 L .984 .727 .339 r
F
.5113 .75386 m .51841 .75181 L .5102 .75347 L .645 .732 .913 r
F
.50958 .74968 m .50951 .75322 L .50959 .74968 L .809 .541 .532 r
F
.50951 .75322 m .50852 .80803 L .50952 .75322 L F
.50951 .75322 m .50952 .75322 L .50959 .74968 L F
.51053 .75039 m .50959 .74968 L .50959 .75325 L .909 .63 .5 r
F
.51065 .75002 m .50959 .74968 L .51053 .75039 L F
.50732 .75501 m .51134 .75525 L .51166 .7548 L .645 .732 .913 r
F
.50732 .75501 m .51166 .7548 L .51138 .75459 L F
.50732 .75501 m .51138 .75459 L .51066 .75405 L F
.50983 .75312 m .50988 .75681 L .50983 .75684 L .358 .18 .498 r
F
.50988 .75681 m .51052 .80865 L .50983 .75684 L F
.51058 .75399 m .50959 .75325 L .5096 .80841 L .909 .63 .5 r
F
.51138 .75459 m .51166 .7548 L .51185 .75454 L .645 .732 .913 r
F
.51134 .75525 m .51992 .75575 L .51185 .75454 L F
.51057 .75631 m .51099 .81108 L .51057 .75632 L .076 0 .415 r
F
.51058 .75399 m .5096 .80841 L .51065 .75404 L .909 .63 .5 r
F
.51066 .75405 m .5134 .75438 L .5162 .75245 L .645 .732 .913 r
F
.51138 .75459 m .5134 .75438 L .51066 .75405 L F
.5134 .75438 m .51958 .75374 L .5162 .75245 L F
.50982 .80928 m .51283 .8111 L .51427 .80986 L .692 .759 .903 r
F
.51052 .80865 m .51054 .81077 L .50984 .8092 L .358 .18 .498 r
F
.51055 .80861 m .51085 .8103 L .51055 .81076 L .076 0 .415 r
F
.50706 .80966 m .51128 .81016 L .51147 .80942 L .692 .759 .904 r
F
.51128 .81016 m .51129 .81016 L .51129 .81015 L F
.51128 .81016 m .51129 .81015 L .51147 .80942 L F
.51054 .81077 m .51055 .81176 L .51033 .81095 L .358 .18 .498 r
F
.51054 .81077 m .51033 .81095 L .50984 .8092 L F
.51096 .81012 m .51082 .81087 L .51129 .81016 L .692 .759 .904 r
F
.50889 .80978 m .50943 .81037 L .50965 .81003 L .692 .759 .903 r
F
.50899 .8118 m .5098 .81165 L .51009 .81149 L .692 .759 .904 r
F
.50979 .80923 m .50984 .81233 L .50882 .80969 L .517 .303 .528 r
F
.50706 .80966 m .51054 .81078 L .51096 .81012 L .692 .759 .904 r
F
.51054 .81078 m .51082 .81087 L .51096 .81012 L F
.51009 .81149 m .51457 .81207 L .51082 .81087 L F
.51055 .81076 m .51099 .81108 L .51055 .81176 L .076 0 .415 r
F
.51085 .8103 m .51099 .81108 L .51055 .81076 L F
.51054 .75635 m .51097 .80797 L .51055 .80861 L F
.50982 .80928 m .51427 .80986 L .51054 .80866 L .692 .759 .903 r
F
.51097 .80797 m .51098 .81009 L .51055 .80861 L .076 0 .415 r
F
.50706 .80966 m .51141 .80942 L .51135 .8087 L .692 .759 .904 r
F
.51141 .80942 m .51147 .80942 L .51146 .80935 L F
.51141 .80942 m .51146 .80935 L .51135 .8087 L F
.51098 .81009 m .51099 .81108 L .51085 .8103 L .076 0 .415 r
F
.51098 .81009 m .51085 .8103 L .51055 .80861 L F
.51057 .75632 m .51099 .81108 L .51054 .75635 L F
.51107 .75495 m .51065 .75404 L .51066 .80923 L .984 .727 .339 r
F
.5112 .75524 m .51205 .75607 L .51397 .7554 L .645 .732 .913 r
F
.51153 .75595 m .51205 .75607 L .5112 .75524 L F
.51205 .75607 m .5194 .75772 L .51397 .7554 L F
.50881 .75356 m .50887 .75718 L .50881 .7572 L .517 .303 .528 r
F
.50899 .8118 m .50809 .81233 L .50916 .81199 L .692 .759 .904 r
F
.50879 .81184 m .50833 .81193 L .50722 .81 L .641 .402 .54 r
F
.50706 .80966 m .50796 .812 L .50899 .8118 L .692 .759 .904 r
F
.50796 .812 m .50809 .81233 L .50899 .8118 L F
.50879 .81184 m .50882 .81277 L .50833 .81193 L .641 .402 .54 r
F
.50833 .81193 m .50882 .81277 L .50722 .81214 L F
.50731 .75732 m .50881 .7572 L .50882 .81184 L F
.50879 .81184 m .50882 .81184 L .50882 .81277 L F
.50731 .75732 m .50882 .81184 L .50879 .81184 L F
.50721 .75376 m .50881 .7572 L .50731 .75732 L F
.50917 .75717 m .50878 .75881 L .50959 .75767 L .645 .732 .913 r
F
.50732 .75501 m .50818 .75725 L .50917 .75717 L F
.52357 .6506 m .52307 .64602 L .50849 .64563 L .733 .497 .57 r
F
0 g
.52307 .64602 m
.53654 .64869 L
s
.39352 .46488 m
.39359 .43358 L
s
.68494 .62601 m .69381 .63533 L .70182 .63131 L .683 .77 .917 r
F
.64183 .52952 m .61205 .52875 L .63348 .53603 L .673 .758 .914 r
F
.38285 .41456 m .37542 .39447 L .36006 .39774 L .654 .726 .902 r
F
.39103 .4143 m .37542 .39447 L .38285 .41456 L F
.39916 .41542 m .39179 .39393 L .39103 .4143 L F
.39916 .41542 m .40807 .39618 L .39179 .39393 L F
.6119 .39795 m .63353 .41351 L .64394 .40561 L F
.60522 .40085 m .63353 .41351 L .6119 .39795 L F
0 g
.38696 .46476 m
.38704 .43324 L
s
.56054 .37146 m .53587 .38523 L .56346 .37652 L .654 .726 .902 r
F
.56054 .37146 m .53002 .37513 L .53587 .38523 L F
.68083 .63196 m .6851 .64265 L .69432 .63991 L .683 .77 .917 r
F
.67593 .63261 m .6851 .64265 L .68083 .63196 L F
.59234 .37128 m .59018 .38807 L .59095 .38805 L .654 .726 .902 r
F
.59318 .37359 m .59095 .38805 L .59833 .38781 L F
.59234 .37128 m .59095 .38805 L .59318 .37359 L F
.58961 .38513 m .58954 .38228 L .59446 .38188 L .665 .424 .546 r
F
.59122 .3875 m .58976 .39546 L .59092 .39542 L .654 .726 .902 r
F
.58961 .38513 m .59446 .38188 L .59453 .38473 L .665 .424 .546 r
F
.58968 .38798 m .58961 .38513 L .59453 .38473 L F
.58979 .38091 m .58961 .38513 L .59453 .38473 L .675 .735 .895 r
F
.59198 .37181 m .59018 .38807 L .59234 .37128 L .654 .726 .902 r
F
.58973 .37802 m .59444 .38182 L .59299 .37776 L .675 .735 .895 r
F
.58998 .3767 m .59307 .38065 L .59162 .37656 L F
.59159 .37763 m .59057 .38752 L .59122 .3875 L .654 .726 .902 r
F
.59057 .38752 m .58976 .39546 L .59122 .3875 L F
.58979 .38091 m .59453 .38473 L .59307 .38065 L .675 .735 .895 r
F
.5916 .37767 m .59092 .39542 L .59304 .38164 L .654 .726 .902 r
F
.59206 .37068 m .59018 .38807 L .59211 .37064 L F
.5917 .37057 m .59018 .38807 L .59207 .37054 L F
.59095 .37064 m .59094 .37085 L .5917 .37057 L F
.59094 .37085 m .59018 .38807 L .5917 .37057 L F
.58991 .37383 m .59299 .37776 L .59154 .37369 L .675 .735 .895 r
F
.59198 .3747 m .59162 .37656 L .59316 .37615 L F
.592 .37196 m .59154 .37369 L .59308 .37328 L F
.58752 .35697 m .58851 .35745 L .58853 .37041 L .846 .571 .522 r
F
.58648 .35567 m .58686 .35637 L .58688 .36932 L .988 .719 .381 r
F
.5907 .37626 m .58725 .38056 L .59018 .38807 L .654 .726 .902 r
F
.58725 .38056 m .58209 .38696 L .58769 .38773 L F
.58725 .38056 m .58769 .38773 L .59018 .38807 L F
.58643 .35484 m .58648 .35567 L .5865 .36863 L .777 .62 .057 r
F
.58979 .3746 m .58714 .37886 L .5907 .37626 L .654 .726 .902 r
F
.58714 .37886 m .58209 .38696 L .58725 .38056 L F
.58714 .37886 m .58725 .38056 L .5907 .37626 L F
.5904 .37248 m .58949 .37406 L .59085 .3729 L F
.58949 .37406 m .58209 .38696 L .58979 .3746 L F
.58949 .37406 m .58979 .3746 L .59085 .3729 L F
.59063 .37145 m .59017 .37228 L .59091 .37159 L F
.59017 .37228 m .58209 .38696 L .5904 .37248 L F
.59017 .37228 m .5904 .37248 L .59091 .37159 L F
.59084 .37085 m .59054 .3714 L .59094 .37087 L F
.59054 .3714 m .58209 .38696 L .59063 .37145 L F
.59054 .3714 m .59063 .37145 L .59094 .37087 L F
.58969 .37075 m .58209 .38696 L .59084 .37085 L F
.59011 .37071 m .59084 .37085 L .59095 .37064 L F
.58969 .37075 m .59084 .37085 L .59011 .37071 L F
.59108 .36779 m .58063 .37842 L .58209 .38696 L F
.58063 .37842 m .57462 .38454 L .57686 .38527 L F
.58063 .37842 m .57686 .38527 L .58209 .38696 L F
.58648 .35567 m .58659 .36878 L .5865 .36863 L .988 .719 .381 r
F
.58643 .35484 m .58647 .36802 L .58645 .36784 L .777 .62 .057 r
F
.58643 .35484 m .5865 .36863 L .58647 .36802 L F
.58697 .35381 m .58643 .35484 L .58645 .36784 L 0 0 .377 r
F
.58063 .37842 m .56827 .38098 L .57462 .38454 L .654 .726 .902 r
F
.59108 .36779 m .58434 .37169 L .58063 .37842 L F
.58434 .37169 m .56827 .38098 L .58063 .37842 L F
.58694 .38718 m .58163 .39434 L .59011 .38761 L F
.5848 .38752 m .5858 .38702 L .58968 .38798 L .731 .476 .543 r
F
.5858 .38702 m .58961 .38513 L .58967 .38755 L F
.5858 .38702 m .58967 .38755 L .58968 .38798 L F
.59011 .38761 m .58163 .39434 L .58976 .39546 L .654 .726 .902 r
F
.59033 .38261 m .58694 .38718 L .59011 .38761 L F
.58998 .37221 m .58829 .37367 L .58991 .37383 L .675 .735 .895 r
F
.58888 .37047 m .59011 .37071 L .59011 .37223 L .751 .49 .538 r
F
.58888 .37047 m .59011 .37223 L .58915 .37208 L F
.5901 .36963 m .58901 .37206 L .58998 .37221 L .675 .735 .895 r
F
.58901 .37206 m .58829 .37367 L .58998 .37221 L F
.58829 .37367 m .58973 .37802 L .58991 .37383 L F
.59005 .37503 m .58835 .37654 L .58998 .3767 L F
.58915 .37208 m .59011 .37504 L .58964 .37497 L .751 .49 .538 r
F
.59016 .37248 m .58909 .37489 L .59005 .37503 L .675 .735 .895 r
F
.58909 .37489 m .58835 .37654 L .59005 .37503 L F
.58915 .37208 m .59011 .37223 L .59011 .37504 L .751 .49 .538 r
F
.59085 .3729 m .58979 .3746 L .5907 .37626 L .654 .726 .902 r
F
.58991 .37383 m .58973 .37802 L .59299 .37776 L .675 .735 .895 r
F
.58964 .37497 m .58986 .375 L .58982 .37599 L .751 .49 .538 r
F
.58986 .375 m .59011 .37504 L .58982 .37599 L F
.59103 .37492 m .58998 .3767 L .59162 .37656 L .675 .735 .895 r
F
.59098 .37211 m .58991 .37383 L .59154 .37369 L F
.59011 .37071 m .59027 .37502 L .59011 .37504 L .641 .4 .539 r
F
.59005 .37505 m .58998 .3767 L .59103 .37492 L .675 .735 .895 r
F
.59091 .37159 m .5904 .37248 L .59085 .3729 L .654 .726 .902 r
F
.58998 .37224 m .58991 .37383 L .59098 .37211 L .675 .735 .895 r
F
.58973 .37802 m .58955 .38222 L .59444 .38182 L F
.58998 .3767 m .58979 .38091 L .59307 .38065 L F
.59054 .37773 m .58976 .39546 L .59159 .37763 L .654 .726 .902 r
F
.59046 .37068 m .59067 .37772 L .59011 .37071 L .641 .4 .539 r
F
.58968 .38798 m .59035 .38753 L .5946 .38758 L .665 .424 .546 r
F
.59214 .38747 m .59092 .39542 L .59511 .38737 L .654 .726 .902 r
F
.59116 .3849 m .58934 .40275 L .5909 .4027 L F
.5929 .3897 m .5909 .4027 L .59753 .40248 L F
.59035 .38753 m .59453 .38473 L .59459 .38739 L .665 .424 .546 r
F
.59035 .38753 m .59459 .38739 L .5946 .38758 L F
.58986 .38376 m .58968 .38798 L .5946 .38758 L .675 .735 .895 r
F
.59116 .3849 m .5909 .4027 L .5929 .3897 L .654 .726 .902 r
F
.59511 .38737 m .59092 .39542 L .59795 .3952 L F
.59342 .38629 m .59753 .40248 L .60235 .40146 L F
.59844 .39249 m .60235 .40146 L .60522 .40085 L F
.59377 .36973 m .60598 .38618 L .61262 .3833 L F
.5927 .35707 m .59289 .37006 L .59273 .37018 L .356 .178 .497 r
F
.59108 .36779 m .59359 .37089 L .59377 .36973 L .654 .726 .902 r
F
.59342 .35649 m .59385 .35581 L .59388 .36901 L .076 0 .415 r
F
.59359 .37089 m .59697 .37507 L .59377 .36973 L .654 .726 .902 r
F
.59386 .37033 m .59544 .37176 L .59611 .37075 L .675 .735 .895 r
F
.59008 .35772 m .59131 .3706 L .59046 .37068 L .641 .4 .539 r
F
.59108 .36779 m .58969 .37075 L .59095 .37064 L .654 .726 .902 r
F
.59168 .35751 m .5927 .35707 L .59273 .37018 L .516 .301 .527 r
F
.59204 .37044 m .59211 .37064 L .59251 .37027 L .654 .726 .902 r
F
.59211 .37064 m .59833 .38781 L .59253 .37033 L F
.59211 .37064 m .59253 .37033 L .59251 .37027 L F
.5927 .35707 m .59342 .35649 L .59344 .36966 L .356 .178 .497 r
F
.59108 .36779 m .60216 .38699 L .59697 .37507 L .654 .726 .902 r
F
.59154 .37369 m .59299 .37776 L .59606 .37693 L .675 .735 .895 r
F
.59321 .37766 m .5934 .37644 L .59316 .37615 L F
.59166 .3766 m .59615 .37982 L .5917 .37654 L F
.59352 .36955 m .61262 .3833 L .59388 .36901 L .654 .726 .902 r
F
.59391 .36884 m .59391 .3701 L .59388 .36901 L 0 0 .146 r
F
.59301 .37166 m .59441 .37262 L .59345 .37097 L .675 .735 .895 r
F
.59376 .37109 m .59441 .37262 L .59544 .37176 L F
.59697 .37507 m .5959 .3726 L .59377 .36973 L .654 .726 .902 r
F
.59441 .37262 m .60079 .37389 L .59544 .37176 L .675 .735 .895 r
F
.59408 .37181 m .59648 .37252 L .59631 .37142 L F
.59392 .37287 m .59391 .37295 L .59389 .37025 L 0 0 .146 r
F
.59251 .37027 m .59833 .38781 L .60216 .38699 L .654 .726 .902 r
F
.59154 .37369 m .59606 .37693 L .59308 .37328 L .675 .735 .895 r
F
.59308 .37328 m .59606 .37693 L .59872 .37562 L F
.59346 .37379 m .5945 .37549 L .59554 .37462 L F
.59299 .37776 m .59444 .38182 L .59904 .38059 L F
.59162 .37656 m .59307 .38065 L .59615 .37982 L F
.59207 .37054 m .59206 .37068 L .59211 .37064 L .654 .726 .902 r
F
.59193 .37048 m .59273 .37018 L .59273 .37156 L .516 .301 .527 r
F
.59211 .37064 m .59198 .37181 L .59234 .37128 L .654 .726 .902 r
F
.5901 .36963 m .59282 .37152 L .59345 .37097 L .675 .735 .895 r
F
.59282 .37152 m .59301 .37166 L .59321 .37135 L F
.59289 .37006 m .59344 .36966 L .59344 .37098 L .356 .178 .497 r
F
.59282 .37152 m .59321 .37135 L .59344 .37098 L .675 .735 .895 r
F
.59282 .37152 m .59344 .37098 L .59335 .37106 L F
.59193 .37048 m .59273 .37156 L .59209 .37183 L .516 .301 .527 r
F
.5928 .37151 m .59308 .37328 L .59441 .37262 L .675 .735 .895 r
F
.59008 .35772 m .59168 .35751 L .5917 .372 L .641 .4 .539 r
F
.5901 .36963 m .59209 .37207 L .5928 .37151 L .675 .735 .895 r
F
.59209 .37207 m .59308 .37328 L .5928 .37151 L F
.593 .37134 m .59345 .3738 L .59322 .37398 L .356 .178 .497 r
F
.59289 .37006 m .59307 .37128 L .593 .37134 L F
.59307 .37128 m .59345 .3738 L .593 .37134 L F
.59307 .37128 m .59344 .37098 L .59345 .3738 L F
.59289 .37006 m .59344 .37098 L .59307 .37128 L F
.59335 .37106 m .59344 .37098 L .59345 .37097 L .675 .735 .895 r
F
.5979 .38669 m .59795 .3952 L .60228 .39427 L .654 .726 .902 r
F
.59487 .38733 m .59453 .38473 L .59915 .38349 L .591 .366 .543 r
F
.59453 .38473 m .59446 .38188 L .59908 .38064 L F
.59453 .38473 m .59908 .38064 L .59915 .38349 L F
.59307 .38065 m .59453 .38473 L .59915 .38349 L .675 .735 .895 r
F
.59803 .38666 m .59915 .38349 L .59922 .38634 L .591 .366 .543 r
F
.59556 .38718 m .59795 .3952 L .5979 .38669 L .654 .726 .902 r
F
.5946 .38758 m .59487 .38733 L .59803 .38666 L .591 .366 .543 r
F
.59487 .38733 m .59915 .38349 L .59803 .38666 L F
.59172 .37799 m .59202 .37883 L .59231 .37803 L .654 .726 .902 r
F
.59172 .37799 m .59231 .37803 L .5921 .37771 L F
.59162 .37656 m .59166 .3766 L .5917 .37654 L .675 .735 .895 r
F
.59103 .37492 m .59109 .37509 L .59171 .37482 L F
.59109 .37509 m .59162 .37656 L .59198 .3747 L F
.59059 .37498 m .59171 .37482 L .59172 .37762 L .641 .4 .539 r
F
.59171 .37482 m .59207 .37748 L .59172 .37762 L .516 .301 .527 r
F
.59201 .37751 m .59323 .379 L .59285 .37715 L .675 .735 .895 r
F
.59207 .37748 m .59207 .37749 L .59197 .37753 L .516 .301 .527 r
F
.59207 .37748 m .59197 .37753 L .59172 .37762 L F
.59076 .3757 m .59201 .37751 L .59285 .37715 L .675 .735 .895 r
F
.59059 .37498 m .59172 .37764 L .59091 .37775 L .641 .4 .539 r
F
.59066 .37508 m .59054 .37773 L .59159 .37763 L .654 .726 .902 r
F
.59023 .37533 m .59176 .3772 L .59076 .3757 L .675 .735 .895 r
F
.59176 .3772 m .59201 .37751 L .59076 .3757 L F
.59066 .37508 m .59103 .37611 L .59253 .37739 L .654 .726 .902 r
F
.59103 .37611 m .59159 .37763 L .59198 .37753 L F
.59103 .37611 m .59198 .37753 L .59253 .37739 L F
.59159 .37763 m .59172 .37799 L .59229 .37757 L F
.59207 .37748 m .59274 .37719 L .59274 .37724 L .516 .301 .527 r
F
.5919 .37756 m .59229 .37757 L .59253 .37739 L .654 .726 .902 r
F
.59176 .3772 m .59299 .37906 L .59323 .379 L .675 .735 .895 r
F
.59202 .37883 m .59795 .3952 L .59308 .3792 L .654 .726 .902 r
F
.59243 .37822 m .59308 .3792 L .59268 .37786 L F
.59202 .37883 m .59308 .3792 L .59243 .37822 L F
.59551 .38286 m .59922 .38634 L .59622 .38267 L .675 .735 .895 r
F
.59325 .37945 m .59556 .38718 L .59688 .38492 L .654 .726 .902 r
F
.59268 .37786 m .59795 .3952 L .59274 .37776 L F
.59314 .3835 m .59719 .38539 L .59551 .38286 L .675 .735 .895 r
F
.59719 .38539 m .59922 .38634 L .59551 .38286 L F
.59192 .37761 m .59169 .37941 L .59299 .37906 L F
.5921 .37771 m .59231 .37803 L .59253 .37739 L .654 .726 .902 r
F
.59202 .37883 m .59268 .37786 L .59253 .37739 L F
.59253 .37739 m .59268 .37786 L .59274 .37776 L F
.59459 .38739 m .59453 .38473 L .59487 .38733 L .591 .366 .543 r
F
.59345 .3738 m .5945 .37549 L .59346 .37379 L .675 .735 .895 r
F
.59281 .37432 m .59302 .37447 L .59345 .3738 L F
.59302 .37447 m .5945 .37549 L .59345 .3738 L F
.59345 .37097 m .59544 .37176 L .59386 .37033 L F
.59354 .36951 m .59358 .3736 L .59344 .36966 L .076 0 .415 r
F
.5946 .38758 m .59459 .38739 L .59487 .38733 L .591 .366 .543 r
F
.59304 .38164 m .59214 .38747 L .59511 .38737 L .654 .726 .902 r
F
.58986 .38376 m .5946 .38758 L .59314 .3835 L .675 .735 .895 r
F
.59251 .38517 m .59342 .38629 L .59305 .38439 L .654 .726 .902 r
F
.59342 .38629 m .60522 .40085 L .5936 .38514 L F
.59342 .38629 m .5936 .38514 L .59305 .38439 L F
.59388 .36901 m .61262 .3833 L .61779 .37936 L F
.59697 .37507 m .60598 .38618 L .5959 .3726 L F
.60316 .3815 m .60309 .37865 L .60622 .37605 L .356 .186 .508 r
F
.59606 .37693 m .60303 .37861 L .59872 .37562 L .675 .735 .895 r
F
.60316 .3815 m .60622 .37605 L .60628 .3789 L .356 .186 .508 r
F
.59697 .37507 m .60216 .38699 L .60598 .38618 L .654 .726 .902 r
F
.59606 .37693 m .59904 .38059 L .60303 .37861 L .675 .735 .895 r
F
.59915 .38349 m .60309 .37865 L .60316 .3815 L .496 .292 .533 r
F
.59883 .3785 m .60316 .3815 L .60628 .3789 L .675 .735 .895 r
F
.60635 .38175 m .60628 .3789 L .60831 .37586 L .118 .01 .444 r
F
.59883 .3785 m .60628 .3789 L .60091 .37676 L .675 .735 .895 r
F
.5945 .37549 m .59883 .3785 L .60091 .37676 L F
.60323 .38435 m .60316 .3815 L .60628 .3789 L .356 .186 .508 r
F
.60098 .37961 m .60635 .38175 L .60838 .37871 L .675 .735 .895 r
F
.60635 .38175 m .60831 .37586 L .60838 .37871 L .118 .01 .444 r
F
.60098 .37961 m .60838 .37871 L .60233 .37758 L .675 .735 .895 r
F
.59561 .37747 m .60098 .37961 L .60233 .37758 L F
.59561 .37747 m .60233 .37758 L .59628 .37646 L F
.59393 .37583 m .61752 .3867 L .62089 .38195 L .654 .726 .902 r
F
.59302 .37447 m .59316 .37615 L .5945 .37549 L .675 .735 .895 r
F
.59299 .37776 m .59904 .38059 L .59606 .37693 L F
.59321 .37766 m .59615 .37982 L .5934 .37644 L F
.59264 .37629 m .59317 .3765 L .59316 .37615 L F
.5917 .37654 m .59317 .3765 L .59264 .37629 L F
.5917 .37654 m .59321 .37766 L .59317 .3765 L F
.59067 .37772 m .59037 .37774 L .59011 .37071 L .641 .4 .539 r
F
.59023 .37533 m .59456 .37834 L .59561 .37747 L .675 .735 .895 r
F
.59346 .37662 m .59349 .37667 L .59346 .37671 L .076 0 .415 r
F
.59345 .3738 m .59349 .37657 L .59346 .37662 L F
.59316 .37615 m .59883 .3785 L .5945 .37549 L .675 .735 .895 r
F
.59498 .37622 m .59561 .37747 L .59628 .37646 L F
.59192 .37473 m .59207 .37748 L .59171 .37482 L .516 .301 .527 r
F
.59299 .37699 m .59346 .37671 L .59299 .37705 L .356 .178 .497 r
F
.59289 .37467 m .59316 .37615 L .59302 .37447 L .675 .735 .895 r
F
.59289 .37006 m .59345 .37662 L .59299 .37699 L .356 .178 .497 r
F
.59345 .37662 m .59346 .37671 L .59299 .37699 L F
.59414 .37606 m .59377 .37674 L .59498 .37622 L .675 .735 .895 r
F
.59198 .3747 m .59316 .37615 L .59283 .37433 L F
.59242 .37451 m .59274 .37437 L .59274 .37719 L .516 .301 .527 r
F
.59023 .37533 m .59346 .37662 L .59414 .37606 L .675 .735 .895 r
F
.59316 .37615 m .59615 .37982 L .59883 .3785 L F
.59346 .37662 m .59377 .37674 L .59414 .37606 L F
.59377 .37674 m .59561 .37747 L .59498 .37622 L F
.59349 .37657 m .59349 .37667 L .59346 .37662 L .076 0 .415 r
F
.5945 .37549 m .60091 .37676 L .59554 .37462 L .675 .735 .895 r
F
.59426 .37535 m .59628 .37646 L .59654 .37537 L F
.59358 .3736 m .59389 .37607 L .59361 .37649 L .076 0 .415 r
F
.59116 .3849 m .59132 .38535 L .59173 .38468 L .654 .726 .902 r
F
.59915 .38349 m .59908 .38064 L .60309 .37865 L .496 .292 .533 r
F
.59615 .37982 m .60316 .3815 L .59883 .3785 L .675 .735 .895 r
F
.60323 .38435 m .60628 .3789 L .60635 .38175 L .356 .186 .508 r
F
.59615 .37982 m .59915 .38349 L .60316 .3815 L .675 .735 .895 r
F
.59922 .38634 m .60316 .3815 L .60323 .38435 L .496 .292 .533 r
F
.5989 .38135 m .60323 .38435 L .60635 .38175 L .675 .735 .895 r
F
.5989 .38135 m .60635 .38175 L .60098 .37961 L F
.59456 .37834 m .5989 .38135 L .60098 .37961 L F
.59456 .37834 m .60098 .37961 L .59561 .37747 L F
.59368 .37639 m .61231 .39066 L .61752 .3867 L .654 .726 .902 r
F
.59193 .37048 m .59274 .37719 L .59207 .37748 L .516 .301 .527 r
F
.59066 .37508 m .59328 .37697 L .59368 .37639 L .654 .726 .902 r
F
.59328 .37697 m .61231 .39066 L .59368 .37639 L F
.59358 .3736 m .59361 .37649 L .59349 .37374 L .076 0 .415 r
F
.59307 .38065 m .59915 .38349 L .59615 .37982 L .675 .735 .895 r
F
.59323 .379 m .59622 .38267 L .5989 .38135 L F
.59351 .37859 m .59688 .38492 L .59771 .38378 L .654 .726 .902 r
F
.59303 .37728 m .59323 .379 L .59456 .37834 L .675 .735 .895 r
F
.59285 .37715 m .59291 .37747 L .59303 .37728 L F
.59291 .37747 m .59323 .379 L .59303 .37728 L F
.59169 .37941 m .59314 .3835 L .59551 .38286 L F
.59367 .38347 m .59361 .38357 L .59352 .37651 L .076 0 .415 r
F
.59354 .37648 m .59352 .37651 L .59349 .37374 L F
.59463 .38152 m .59551 .38286 L .59622 .38267 L .675 .735 .895 r
F
.59169 .37941 m .59622 .38267 L .59323 .379 L F
.59345 .37897 m .59688 .38492 L .59351 .37859 L .654 .726 .902 r
F
.59367 .38347 m .59352 .37651 L .59354 .37648 L .076 0 .415 r
F
.59253 .37739 m .59345 .37897 L .59351 .37859 L .654 .726 .902 r
F
.59274 .37776 m .59325 .37945 L .59688 .38492 L F
.59393 .3758 m .59403 .38234 L .59396 .38276 L 0 0 .146 r
F
.59392 .37287 m .59395 .37567 L .59393 .3758 L F
.59922 .38634 m .59915 .38349 L .60316 .3815 L .496 .292 .533 r
F
.59622 .38267 m .59922 .38634 L .60323 .38435 L .675 .735 .895 r
F
.59351 .37859 m .60564 .39356 L .59371 .37727 L .654 .726 .902 r
F
.59395 .37567 m .59403 .38234 L .59393 .3758 L 0 0 .146 r
F
.59323 .379 m .5989 .38135 L .59456 .37834 L .675 .735 .895 r
F
.59361 .37649 m .59367 .38347 L .59354 .37658 L .076 0 .415 r
F
.59361 .37649 m .59354 .37658 L .59349 .37374 L F
.59688 .38492 m .5979 .38669 L .59788 .38643 L .654 .726 .902 r
F
.59713 .38535 m .5974 .38679 L .5979 .38669 L F
.59688 .38492 m .5974 .38679 L .59713 .38535 L F
.59688 .38492 m .59556 .38718 L .5974 .38679 L F
.59719 .38539 m .59803 .38666 L .59922 .38634 L .675 .735 .895 r
F
.59314 .3835 m .59803 .38666 L .59719 .38539 L F
.59381 .37645 m .59383 .37646 L .59384 .37643 L .654 .726 .902 r
F
.59381 .37645 m .59384 .37643 L .59393 .37583 L F
.59361 .37649 m .59389 .37607 L .59391 .38312 L .076 0 .415 r
F
.59393 .3758 m .59396 .38276 L .59391 .37595 L 0 0 .146 r
F
.5979 .38669 m .60228 .39427 L .59888 .38648 L .654 .726 .902 r
F
.59314 .3835 m .5946 .38758 L .59803 .38666 L .675 .735 .895 r
F
.59283 .38424 m .59305 .38439 L .59347 .38377 L .654 .726 .902 r
F
.59771 .38378 m .60228 .39427 L .60564 .39356 L F
.59391 .37595 m .59394 .38288 L .59389 .37607 L 0 0 .146 r
F
.59389 .37607 m .59393 .38298 L .59391 .38312 L F
.59386 .37493 m .59382 .38187 L .59401 .37529 L .983 .725 .333 r
F
.59169 .38638 m .59753 .40248 L .59209 .38579 L .654 .726 .902 r
F
.59688 .38492 m .59788 .38643 L .59771 .38378 L F
.5979 .38669 m .59888 .38648 L .59771 .38378 L F
.59622 .38267 m .60323 .38435 L .5989 .38135 L .675 .735 .895 r
F
.59541 .3785 m .60564 .39356 L .61231 .39066 L .654 .726 .902 r
F
.59659 .38121 m .60564 .39356 L .59541 .3785 L F
.59415 .38326 m .6171 .39399 L .62048 .38924 L F
.59005 .37955 m .59314 .3835 L .59169 .37941 L .675 .735 .895 r
F
.59207 .37749 m .59276 .38429 L .59221 .3845 L .516 .301 .527 r
F
.59158 .37767 m .59092 .39542 L .5916 .37767 L .654 .726 .902 r
F
.59005 .37955 m .58986 .38376 L .59314 .3835 L .675 .735 .895 r
F
.59024 .38237 m .59347 .38377 L .59415 .38326 L .654 .726 .902 r
F
.59347 .38377 m .6171 .39399 L .59415 .38326 L F
.59299 .37705 m .59346 .37671 L .59347 .38377 L .356 .178 .497 r
F
.59305 .38439 m .59347 .38377 L .59347 .38377 L .654 .726 .902 r
F
.59309 .38405 m .59347 .38377 L .59353 .41521 L .356 .178 .497 r
F
.59299 .37705 m .59347 .38377 L .59309 .38405 L F
.59367 .38347 m .59391 .38312 L .59397 .41452 L .076 0 .415 r
F
.59383 .37646 m .61752 .3867 L .59393 .37583 L .654 .726 .902 r
F
.59087 .38476 m .59063 .38478 L .59037 .37774 L .641 .4 .539 r
F
.59692 .38272 m .62048 .38924 L .62179 .38402 L .654 .726 .902 r
F
.59283 .37433 m .59289 .37467 L .59302 .37447 L .675 .735 .895 r
F
.59422 .36851 m .61779 .37936 L .62115 .37463 L .654 .726 .902 r
F
.59388 .36901 m .61779 .37936 L .59422 .36851 L F
.59872 .37562 m .60303 .37861 L .60613 .37602 L .675 .735 .895 r
F
.60628 .3789 m .60622 .37605 L .60824 .37301 L .118 .01 .444 r
F
.60091 .37676 m .60628 .3789 L .60831 .37586 L .675 .735 .895 r
F
.59872 .37562 m .60613 .37602 L .60079 .37389 L F
.60628 .3789 m .60824 .37301 L .60831 .37586 L .118 .01 .444 r
F
.60091 .37676 m .60831 .37586 L .60226 .37473 L .675 .735 .895 r
F
.60838 .37871 m .60831 .37586 L .6091 .37259 L 0 0 .259 r
F
.60838 .37871 m .6091 .37259 L .60917 .37544 L F
.60233 .37758 m .60838 .37871 L .60917 .37544 L .675 .735 .895 r
F
.60233 .37758 m .60917 .37544 L .60286 .3754 L F
.59554 .37462 m .60091 .37676 L .60226 .37473 L F
.59628 .37646 m .60233 .37758 L .60286 .3754 L F
.59628 .37646 m .60286 .3754 L .59654 .37537 L F
.59533 .37533 m .62089 .38195 L .6222 .37673 L .654 .726 .902 r
F
.59349 .37374 m .59352 .37661 L .59345 .3738 L .076 0 .415 r
F
.59352 .37661 m .59361 .38357 L .5935 .37665 L F
.59352 .37661 m .5935 .37665 L .59345 .3738 L F
.59443 .37528 m .59448 .37595 L .59533 .37533 L .654 .726 .902 r
F
.59273 .37018 m .59285 .37715 L .59274 .37724 L .356 .178 .497 r
F
.59023 .37533 m .59385 .376 L .59426 .37535 L .675 .735 .895 r
F
.59066 .37508 m .59404 .37585 L .59443 .37528 L .654 .726 .902 r
F
.59385 .376 m .59628 .37646 L .59426 .37535 L .675 .735 .895 r
F
.59404 .37585 m .59448 .37595 L .59443 .37528 L .654 .726 .902 r
F
.59448 .37595 m .62089 .38195 L .59533 .37533 L F
.59289 .37006 m .59299 .37705 L .59273 .37018 L .356 .178 .497 r
F
.59299 .37705 m .59309 .38405 L .59291 .37711 L F
.59299 .37705 m .59291 .37711 L .59273 .37018 L F
.59309 .38405 m .59353 .41521 L .59298 .38413 L F
.59308 .37328 m .59872 .37562 L .59441 .37262 L .675 .735 .895 r
F
.59443 .37327 m .59554 .37462 L .59621 .37361 L F
.59393 .3758 m .59391 .37595 L .5939 .37304 L 0 0 .146 r
F
.59372 .37142 m .59441 .37262 L .59376 .37109 L .675 .735 .895 r
F
.59391 .37295 m .5939 .37304 L .59388 .36901 L 0 0 .146 r
F
.59377 .37392 m .5949 .37437 L .59388 .37317 L .675 .735 .895 r
F
.59393 .3758 m .5939 .37304 L .59391 .37295 L 0 0 .146 r
F
.59388 .37317 m .5949 .37437 L .59443 .37327 L .675 .735 .895 r
F
.59209 .37183 m .59273 .37156 L .59274 .37437 L .516 .301 .527 r
F
.59098 .37211 m .59154 .37369 L .592 .37196 L .675 .735 .895 r
F
.59144 .37204 m .5917 .372 L .59171 .37482 L .641 .4 .539 r
F
.59193 .37048 m .59207 .37749 L .5917 .37057 L .516 .301 .527 r
F
.59016 .37248 m .59377 .37392 L .59388 .37317 L .675 .735 .895 r
F
.5949 .37437 m .59554 .37462 L .59443 .37327 L F
.59441 .37262 m .59872 .37562 L .60079 .37389 L F
.59355 .37081 m .59389 .37311 L .59358 .3736 L .076 0 .415 r
F
.59016 .37248 m .59621 .37361 L .59628 .37334 L .675 .735 .895 r
F
.59519 .37251 m .59628 .37334 L .59648 .37252 L F
.59378 .36917 m .59389 .37311 L .59354 .36951 L .076 0 .415 r
F
.59391 .3701 m .59389 .37025 L .59388 .36901 L 0 0 .146 r
F
.59391 .36884 m .59401 .3723 L .59392 .37287 L F
.59385 .35581 m .59397 .36842 L .59391 .36884 L F
.59398 .36965 m .59611 .37075 L .59638 .36967 L .675 .735 .895 r
F
.59168 .35751 m .59273 .37018 L .59193 .37048 L .516 .301 .527 r
F
.59378 .36917 m .59388 .3703 L .59381 .37041 L .076 0 .415 r
F
.59008 .35772 m .5917 .372 L .59144 .37204 L .641 .4 .539 r
F
.59108 .36779 m .59095 .37064 L .59207 .37054 L .654 .726 .902 r
F
.5901 .36963 m .59388 .37033 L .59398 .36965 L .675 .735 .895 r
F
.59388 .37033 m .59611 .37075 L .59398 .36965 L F
.59397 .36842 m .59398 .36962 L .59391 .36884 L 0 0 .146 r
F
.59398 .36962 m .59401 .3723 L .59394 .36992 L F
.59398 .36962 m .59394 .36992 L .59391 .36884 L F
.59404 .36795 m .62115 .37463 L .62246 .36944 L .654 .726 .902 r
F
.5927 .35707 m .59344 .36966 L .59289 .37006 L .356 .178 .497 r
F
.59108 .36779 m .59397 .36845 L .59404 .36795 L .654 .726 .902 r
F
.59397 .36845 m .62115 .37463 L .59404 .36795 L F
.59379 .36899 m .59638 .36967 L .59621 .36858 L .675 .735 .895 r
F
.59168 .35751 m .59193 .37048 L .5917 .37057 L .516 .301 .527 r
F
.59108 .36779 m .59204 .37044 L .59251 .37027 L .654 .726 .902 r
F
.59378 .36917 m .59388 .36901 L .59388 .3703 L .076 0 .415 r
F
.59108 .36779 m .59388 .36901 L .59422 .36851 L .654 .726 .902 r
F
.59397 .36842 m .594 .36823 L .594 .36949 L 0 0 .146 r
F
.59398 .36962 m .594 .36949 L .59401 .3723 L F
.59397 .36842 m .594 .36949 L .59398 .36962 L F
.5901 .36963 m .59398 .36965 L .59379 .36899 L .675 .735 .895 r
F
.59398 .36965 m .59407 .36965 L .594 .36949 L F
.59398 .36965 m .594 .36949 L .59379 .36899 L F
.59407 .36965 m .59638 .36967 L .59379 .36899 L F
.5939 .368 m .59389 .36923 L .594 .36823 L .983 .725 .333 r
F
.59391 .3701 m .59392 .37287 L .59389 .37025 L 0 0 .146 r
F
.59389 .36923 m .59388 .372 L .59396 .36939 L .983 .725 .333 r
F
.59389 .36923 m .59396 .36939 L .594 .36823 L F
.59392 .37287 m .59401 .3723 L .59401 .37512 L 0 0 .146 r
F
.59395 .37553 m .59401 .37529 L .59395 .37567 L F
.59392 .37287 m .59401 .37515 L .59395 .37553 L F
.59322 .37398 m .59345 .3738 L .59346 .37671 L .356 .178 .497 r
F
.59429 .37463 m .59654 .37537 L .59638 .37427 L .675 .735 .895 r
F
.59023 .37533 m .59524 .37536 L .59429 .37463 L F
.59524 .37536 m .59654 .37537 L .59429 .37463 L F
.59353 .35393 m .59247 .35309 L .59249 .36638 L .911 .629 .497 r
F
.59342 .35649 m .59378 .36917 L .59354 .36951 L .076 0 .415 r
F
.59397 .35498 m .59353 .35393 L .59355 .36721 L .983 .725 .333 r
F
.59385 .35581 m .59397 .35498 L .594 .36823 L 0 0 .146 r
F
.59388 .36901 m .59391 .37595 L .59389 .37607 L F
.59392 .3721 m .59386 .37477 L .59401 .3723 L .983 .725 .333 r
F
.59358 .3736 m .59389 .37311 L .59389 .37607 L .076 0 .415 r
F
.59386 .37477 m .59386 .37493 L .59387 .37478 L .983 .725 .333 r
F
.59386 .37477 m .59387 .37478 L .59401 .3723 L F
.59326 .37338 m .5942 .37385 L .59438 .37266 L .675 .735 .895 r
F
.59409 .3725 m .59628 .37334 L .59519 .37251 L F
.59434 .37307 m .59628 .37334 L .59409 .3725 L F
.59361 .38357 m .59358 .38361 L .59345 .3738 L .076 0 .415 r
F
.59298 .38413 m .59353 .41521 L .59289 .3842 L .356 .178 .497 r
F
.59276 .38429 m .59353 .41521 L .59282 .41578 L F
.59209 .38465 m .59314 .3881 L .59342 .38629 L .654 .726 .902 r
F
.59289 .3842 m .59353 .41521 L .59276 .38429 L .356 .178 .497 r
F
.59349 .37667 m .59358 .38361 L .59346 .37671 L .076 0 .415 r
F
.59358 .38361 m .59355 .38365 L .59346 .37671 L F
.59346 .37671 m .59355 .38365 L .59347 .38377 L F
.5942 .37385 m .59638 .37427 L .59579 .37325 L .675 .735 .895 r
F
.60079 .37389 m .60815 .37299 L .60213 .37187 L F
.59544 .37176 m .60079 .37389 L .60213 .37187 L F
.60213 .37187 m .60815 .37299 L .60894 .36974 L F
.60266 .3697 m .60894 .36974 L .60844 .36648 L F
.6091 .37259 m .60903 .36974 L .60853 .36646 L .848 .651 .11 r
F
.59503 .36732 m .62246 .36944 L .62163 .36413 L .654 .726 .902 r
F
.59108 .36779 m .59716 .36811 L .59503 .36732 L F
.59716 .36811 m .62246 .36944 L .59503 .36732 L F
.59354 .36951 m .59365 .37066 L .59355 .37081 L .076 0 .415 r
F
.5901 .36963 m .59345 .37097 L .59386 .37033 L .675 .735 .895 r
F
.59342 .35649 m .59354 .36951 L .59344 .36966 L .076 0 .415 r
F
.59355 .36721 m .59325 .37103 L .59356 .37127 L .911 .629 .497 r
F
.59353 .35393 m .59331 .36702 L .59355 .36721 L F
.59338 .36707 m .62163 .36413 L .61872 .35907 L .654 .726 .902 r
F
.59108 .36779 m .59387 .36746 L .59338 .36707 L F
.59387 .36746 m .62163 .36413 L .59338 .36707 L F
.59016 .37248 m .59434 .37307 L .59409 .3725 L .675 .735 .895 r
F
.59358 .3736 m .59349 .37374 L .59344 .36966 L .076 0 .415 r
F
.59344 .36966 m .59349 .37374 L .59345 .3738 L F
.59016 .37248 m .59398 .3725 L .59401 .3723 L .675 .735 .895 r
F
.59016 .37248 m .59401 .3723 L .59381 .37185 L F
.59381 .37041 m .59388 .3703 L .59389 .37311 L .076 0 .415 r
F
.5939 .368 m .59371 .37161 L .59388 .372 L .983 .725 .333 r
F
.59287 .37074 m .59572 .3704 L .59476 .36952 L .675 .735 .895 r
F
.59094 .37087 m .59063 .37145 L .59091 .37159 L .654 .726 .902 r
F
.59095 .37064 m .59084 .37085 L .59094 .37087 L F
.59131 .3706 m .59171 .37482 L .59046 .37068 L .641 .4 .539 r
F
.59016 .37248 m .59351 .37123 L .59287 .37074 L .675 .735 .895 r
F
.59388 .372 m .59392 .3721 L .594 .36823 L .983 .725 .333 r
F
.594 .36823 m .59392 .3721 L .59401 .3723 L F
.59345 .37097 m .59372 .37142 L .59376 .37109 L .675 .735 .895 r
F
.59351 .37123 m .59572 .3704 L .59287 .37074 L F
.59325 .37103 m .59251 .37328 L .5932 .37381 L .911 .629 .497 r
F
.59331 .36702 m .59284 .37071 L .59325 .37103 L F
.59365 .37066 m .59389 .37311 L .59355 .37081 L .076 0 .415 r
F
.59412 .371 m .59631 .37142 L .59572 .3704 L .675 .735 .895 r
F
.59016 .37248 m .59568 .37153 L .59412 .371 L F
.59568 .37153 m .59631 .37142 L .59412 .371 L F
.59247 .35309 m .59139 .35271 L .59142 .3701 L .81 .54 .53 r
F
.59016 .37248 m .59303 .37064 L .59212 .37033 L .675 .735 .895 r
F
.59016 .37248 m .59198 .3747 L .59283 .37433 L F
.59209 .37183 m .59274 .37437 L .59242 .37451 L .516 .301 .527 r
F
.59388 .372 m .59386 .37476 L .59392 .3721 L .983 .725 .333 r
F
.59089 .37212 m .59171 .37482 L .5905 .37217 L .641 .4 .539 r
F
.5917 .37057 m .59192 .37473 L .59171 .37482 L .516 .301 .527 r
F
.59016 .37248 m .59281 .37432 L .59346 .37379 L .675 .735 .895 r
F
.59371 .37161 m .59358 .3741 L .59388 .372 L .983 .725 .333 r
F
.59381 .37185 m .59401 .3723 L .59408 .37181 L .675 .735 .895 r
F
.59286 .37245 m .59483 .37237 L .59355 .3717 L F
.59023 .37533 m .59326 .37338 L .59286 .37245 L F
.59326 .37338 m .59483 .37237 L .59286 .37245 L F
.59392 .37287 m .59401 .37512 L .59401 .37515 L 0 0 .146 r
F
.59392 .37287 m .59393 .3758 L .59391 .37295 L F
.59401 .3723 m .59387 .37478 L .59401 .37512 L .983 .725 .333 r
F
.59357 .37408 m .59408 .37467 L .5942 .37385 L .675 .735 .895 r
F
.59291 .37711 m .59285 .37715 L .59273 .37018 L .356 .178 .497 r
F
.59023 .37533 m .59384 .37471 L .59357 .37408 L .675 .735 .895 r
F
.59388 .372 m .59357 .37426 L .59386 .37493 L .983 .725 .333 r
F
.59384 .37471 m .59408 .37467 L .59357 .37408 L .675 .735 .895 r
F
.59401 .37515 m .59401 .37512 L .59401 .37529 L 0 0 .146 r
F
.59401 .37512 m .59386 .37493 L .59401 .37529 L .983 .725 .333 r
F
.59387 .37478 m .59386 .37493 L .59401 .37512 L F
.59358 .3741 m .59357 .37426 L .59359 .37413 L F
.59358 .3741 m .59359 .37413 L .59388 .372 L F
.59066 .37508 m .59294 .37377 L .59251 .37343 L .654 .726 .902 r
F
.59213 .37329 m .5925 .37343 L .59251 .37328 L .81 .54 .53 r
F
.59235 .37337 m .59251 .37343 L .59238 .37333 L .654 .726 .902 r
F
.59066 .37508 m .59251 .37343 L .59235 .37337 L F
.59218 .37035 m .59142 .3701 L .59143 .37303 L .81 .54 .53 r
F
.59172 .37762 m .59229 .37757 L .5919 .37756 L .654 .726 .902 r
F
.59207 .37749 m .59221 .3845 L .59172 .37762 L .516 .301 .527 r
F
.59221 .3845 m .59192 .38461 L .59172 .37762 L F
.59132 .38535 m .59169 .38638 L .59183 .38498 L .654 .726 .902 r
F
.59169 .38638 m .59209 .38579 L .59183 .38498 L F
.59132 .38535 m .59183 .38498 L .59173 .38468 L F
.59024 .38237 m .59251 .38517 L .59305 .38439 L F
.59159 .37763 m .59172 .37762 L .5919 .37756 L F
.59159 .37763 m .59158 .37767 L .5916 .37767 L F
.59108 .37773 m .59169 .37941 L .59192 .37761 L .675 .735 .895 r
F
.59091 .37775 m .59172 .37764 L .59173 .38468 L .641 .4 .539 r
F
.59023 .37533 m .59299 .37906 L .59176 .3772 L .675 .735 .895 r
F
.5911 .38474 m .59116 .3849 L .59173 .38468 L .654 .726 .902 r
F
.5911 .38474 m .59108 .38492 L .59116 .3849 L F
.59087 .38476 m .59173 .38468 L .59179 .41622 L .641 .4 .539 r
F
.59172 .37762 m .59192 .38461 L .59173 .38468 L .516 .301 .527 r
F
.5905 .37217 m .59171 .37482 L .59059 .37498 L .641 .4 .539 r
F
.59103 .37492 m .59171 .37482 L .59198 .3747 L .675 .735 .895 r
F
.59284 .37071 m .59251 .37328 L .59325 .37103 L .911 .629 .497 r
F
.59281 .36788 m .59563 .36756 L .59467 .36669 L .675 .735 .895 r
F
.59342 .35649 m .59388 .36901 L .59378 .36917 L .076 0 .415 r
F
.59385 .35581 m .594 .36823 L .59397 .36842 L 0 0 .146 r
F
.59385 .35581 m .59391 .36884 L .59388 .36901 L F
.59248 .36637 m .60756 .35103 L .59195 .36594 L .654 .726 .902 r
F
.59108 .36779 m .59352 .36955 L .59388 .36901 L F
.59329 .36825 m .59325 .37103 L .59346 .36838 L .911 .629 .497 r
F
.5939 .368 m .59355 .36721 L .59356 .36845 L .983 .725 .333 r
F
.59379 .369 m .59356 .36845 L .59356 .37127 L F
.5939 .368 m .59356 .36845 L .59379 .369 L F
.59351 .36835 m .59621 .36858 L .59563 .36756 L .675 .735 .895 r
F
.59397 .35498 m .5939 .368 L .594 .36823 L .983 .725 .333 r
F
.59366 .3663 m .61872 .35907 L .61392 .3546 L .654 .726 .902 r
F
.59353 .35393 m .59286 .36666 L .59331 .36702 L .911 .629 .497 r
F
.59108 .36779 m .59512 .36652 L .59366 .3663 L .654 .726 .902 r
F
.59512 .36652 m .61872 .35907 L .59366 .3663 L F
.59379 .36899 m .59621 .36858 L .59351 .36835 L .675 .735 .895 r
F
.59283 .36956 m .59476 .36952 L .59348 .36885 L F
.59304 .37005 m .59476 .36952 L .59283 .36956 L F
.5939 .368 m .59356 .37127 L .59371 .37161 L .983 .725 .333 r
F
.59303 .37064 m .59476 .36952 L .59212 .37033 L .675 .735 .895 r
F
.5925 .37046 m .59214 .37315 L .59251 .37328 L .81 .54 .53 r
F
.59108 .36779 m .61392 .3546 L .60756 .35103 L .654 .726 .902 r
F
.59621 .36858 m .60116 .3655 L .59563 .36756 L .675 .735 .895 r
F
.59563 .36756 m .59924 .36374 L .59467 .36669 L F
.59563 .36756 m .60116 .3655 L .59924 .36374 L F
.59467 .36669 m .59924 .36374 L .5967 .3624 L F
.60116 .3655 m .60381 .3608 L .59924 .36374 L F
.59476 .36952 m .5968 .36521 L .59348 .36885 L F
.59476 .36952 m .59935 .36657 L .5968 .36521 L F
.59924 .36374 m .6 .35878 L .5967 .3624 L F
.59924 .36374 m .60381 .3608 L .6 .35878 L F
.5901 .36963 m .59379 .36899 L .59356 .36845 L F
.59279 .36787 m .59265 .37057 L .59317 .36815 L .911 .629 .497 r
F
.59265 .37057 m .59251 .37328 L .59284 .37071 L F
.59265 .37057 m .59284 .37071 L .59317 .36815 L F
.59221 .37024 m .59304 .37005 L .59283 .36956 L .675 .735 .895 r
F
.5901 .36963 m .59346 .36837 L .59281 .36788 L F
.59223 .36755 m .5924 .36761 L .59249 .36638 L .81 .54 .53 r
F
.59286 .36666 m .59279 .36787 L .59331 .36702 L .911 .629 .497 r
F
.59205 .36749 m .59467 .36669 L .59339 .36601 L .675 .735 .895 r
F
.5901 .36963 m .59295 .36779 L .59205 .36749 L F
.59279 .36787 m .59317 .36815 L .59331 .36702 L .911 .629 .497 r
F
.59331 .36702 m .59329 .36825 L .59355 .36721 L F
.59295 .36779 m .59467 .36669 L .59205 .36749 L .675 .735 .895 r
F
.59225 .36628 m .59223 .36755 L .59249 .36638 L .81 .54 .53 r
F
.59223 .36755 m .59218 .37035 L .5924 .36761 L F
.59218 .37035 m .59214 .37315 L .59228 .37039 L F
.59218 .37035 m .59228 .37039 L .59249 .36638 L F
.5901 .36963 m .59356 .36845 L .59346 .36837 L .675 .735 .895 r
F
.59249 .36638 m .59228 .37039 L .5925 .37046 L .81 .54 .53 r
F
.59286 .36666 m .59249 .36638 L .5925 .37046 L .911 .629 .497 r
F
.59265 .37057 m .5925 .37046 L .59251 .37328 L F
.59286 .36666 m .5925 .37046 L .59265 .37057 L F
.59143 .36964 m .59348 .36885 L .59197 .36841 L .675 .735 .895 r
F
.59225 .36628 m .59142 .3701 L .59218 .37035 L .81 .54 .53 r
F
.59247 .35309 m .59167 .36607 L .59225 .36628 L F
.59108 .36779 m .59248 .36637 L .59186 .36614 L .654 .726 .902 r
F
.59167 .36607 m .59159 .36734 L .59225 .36628 L .81 .54 .53 r
F
.59186 .36614 m .59248 .36637 L .59195 .36594 L .654 .726 .902 r
F
.59247 .35309 m .59225 .36628 L .59249 .36638 L .81 .54 .53 r
F
.59248 .36637 m .59248 .36637 L .59186 .36614 L .654 .726 .902 r
F
.59118 .3672 m .59339 .36601 L .5919 .36558 L .675 .735 .895 r
F
.59139 .35271 m .5903 .35258 L .59033 .36581 L .734 .476 .539 r
F
.59139 .35271 m .59033 .36581 L .59043 .36583 L F
.58851 .35745 m .59008 .35772 L .59011 .37071 L .751 .49 .538 r
F
.58686 .35637 m .58752 .35697 L .58754 .36991 L .93 .648 .485 r
F
.5881 .35301 m .58697 .35381 L .58699 .36687 L .4 .211 .506 r
F
.58719 .3715 m .58456 .3717 L .58552 .37257 L .675 .735 .895 r
F
.58776 .37002 m .58853 .37041 L .58853 .37199 L .846 .571 .522 r
F
.5813 .38576 m .58018 .38631 L .58508 .38698 L .654 .726 .902 r
F
.58029 .38623 m .58147 .38581 L .5848 .38752 L .795 .529 .535 r
F
.58147 .38581 m .58473 .38467 L .58478 .38688 L F
.58147 .38581 m .58478 .38688 L .5848 .38752 L F
.58508 .38698 m .58018 .38631 L .58163 .39434 L .654 .726 .902 r
F
.58697 .38296 m .5813 .38576 L .58508 .38698 L F
.58649 .37772 m .58469 .38176 L .58955 .38222 L .675 .735 .895 r
F
.58473 .38467 m .58466 .38182 L .58954 .38228 L .731 .476 .543 r
F
.58654 .38061 m .58961 .38513 L .58979 .38091 L .675 .735 .895 r
F
.5886 .37948 m .58684 .38091 L .58697 .38296 L .654 .726 .902 r
F
.58022 .38338 m .58466 .38182 L .58473 .38467 L .795 .529 .535 r
F
.58353 .37975 m .58473 .38467 L .58654 .38061 L .675 .735 .895 r
F
.58684 .38091 m .58018 .38631 L .58697 .38296 L .654 .726 .902 r
F
.58851 .35745 m .58888 .37047 L .58853 .37041 L .751 .49 .538 r
F
.58752 .35697 m .58776 .37002 L .58754 .36991 L .846 .571 .522 r
F
.58752 .35697 m .58853 .37041 L .58776 .37002 L F
.59108 .36779 m .58009 .37126 L .56827 .38098 L .654 .726 .902 r
F
.58009 .37126 m .56346 .37652 L .56688 .37969 L F
.58009 .37126 m .56688 .37969 L .56827 .38098 L F
.58776 .37002 m .58853 .37199 L .58779 .37164 L .846 .571 .522 r
F
.58649 .37772 m .58955 .38222 L .58973 .37802 L .675 .735 .895 r
F
.58835 .37654 m .58654 .38061 L .58979 .38091 L F
.58836 .37904 m .58681 .38042 L .5886 .37948 L .654 .726 .902 r
F
.58681 .38042 m .58018 .38631 L .58684 .38091 L F
.58681 .38042 m .58684 .38091 L .5886 .37948 L F
.58896 .37823 m .5868 .38022 L .58912 .37838 L F
.5868 .38022 m .58018 .38631 L .58681 .38042 L F
.5868 .38022 m .58681 .38042 L .58912 .37838 L F
.58655 .37096 m .58398 .37068 L .58456 .3717 L .675 .735 .895 r
F
.58835 .37654 m .58979 .38091 L .58998 .3767 L F
.58935 .37786 m .58895 .37822 L .58936 .37786 L .654 .726 .902 r
F
.58683 .37085 m .58456 .3717 L .58719 .3715 L .675 .735 .895 r
F
.58574 .37166 m .58479 .37034 L .58411 .37135 L F
.58703 .36945 m .58705 .37109 L .58688 .36932 L .93 .648 .485 r
F
.588 .37193 m .58552 .37257 L .5868 .37325 L .675 .735 .895 r
F
.58738 .37138 m .58719 .3715 L .588 .37193 L F
.58719 .3715 m .58552 .37257 L .58749 .37206 L F
.58719 .3715 m .58749 .37206 L .588 .37193 L F
.58666 .37053 m .58689 .37376 L .58678 .37356 L .988 .719 .381 r
F
.58659 .36878 m .5867 .3706 L .58666 .37053 L F
.5867 .3706 m .58689 .37376 L .58666 .37053 L F
.58456 .3717 m .58095 .37551 L .58552 .37257 L .675 .735 .895 r
F
.58621 .37316 m .58385 .37244 L .58402 .37354 L F
.58709 .37393 m .58703 .37388 L .58694 .37099 L .93 .648 .485 r
F
.5868 .37325 m .5835 .37686 L .58649 .37772 L .675 .735 .895 r
F
.58722 .37437 m .5846 .37456 L .58557 .37544 L F
.5901 .36963 m .5868 .37325 L .58829 .37367 L F
.58779 .37164 m .58853 .37199 L .58854 .3748 L .846 .571 .522 r
F
.58826 .37886 m .58827 .37887 L .58896 .37823 L .654 .726 .902 r
F
.58686 .35637 m .58703 .36945 L .58688 .36932 L .93 .648 .485 r
F
.58648 .35567 m .58688 .36932 L .58659 .36878 L .988 .719 .381 r
F
.58686 .35637 m .58754 .36991 L .58703 .36945 L .93 .648 .485 r
F
.58851 .35745 m .59011 .37071 L .58888 .37047 L .751 .49 .538 r
F
.59108 .36779 m .57388 .36986 L .56346 .37652 L .654 .726 .902 r
F
.57388 .36986 m .56054 .37146 L .56148 .37309 L F
.57388 .36986 m .56148 .37309 L .56346 .37652 L F
.5892 .35267 m .5881 .35301 L .58812 .36615 L .567 .342 .533 r
F
.5835 .37686 m .58469 .38176 L .58649 .37772 L .675 .735 .895 r
F
.58685 .37611 m .58353 .37975 L .58654 .38061 L F
.58782 .37797 m .5809 .38501 L .58893 .37821 L .654 .726 .902 r
F
.5886 .37791 m .58893 .37821 L .58935 .37786 L F
.58782 .37797 m .58893 .37821 L .5886 .37791 L F
.58732 .37142 m .58709 .37131 L .58719 .3715 L .675 .735 .895 r
F
.5868 .37325 m .58649 .37772 L .58829 .37367 L F
.58806 .37479 m .58557 .37544 L .58685 .37611 L F
.58022 .38338 m .58015 .38053 L .58466 .38182 L .795 .529 .535 r
F
.58353 .37975 m .58022 .38338 L .58473 .38467 L .675 .735 .895 r
F
.5809 .38501 m .58061 .38553 L .58935 .37786 L .654 .726 .902 r
F
.58061 .38553 m .58018 .38631 L .58092 .38563 L F
.58061 .38553 m .58092 .38563 L .58935 .37786 L F
.58147 .38581 m .58022 .38338 L .58473 .38467 L .795 .529 .535 r
F
.58029 .38623 m .58027 .38542 L .58147 .38581 L F
.58027 .38542 m .58022 .38338 L .58147 .38581 L F
.58912 .37838 m .58836 .37904 L .5886 .37948 L .654 .726 .902 r
F
.58473 .38467 m .58954 .38228 L .58961 .38513 L .731 .476 .543 r
F
.58654 .38061 m .58473 .38467 L .58961 .38513 L .675 .735 .895 r
F
.5886 .37948 m .58511 .38693 L .59033 .38261 L .654 .726 .902 r
F
.58511 .38693 m .58163 .39434 L .58694 .38718 L F
.5858 .38702 m .58473 .38467 L .58961 .38513 L .731 .476 .543 r
F
.58511 .38693 m .58694 .38718 L .59033 .38261 L .654 .726 .902 r
F
.5848 .38752 m .58478 .38688 L .5858 .38702 L .731 .476 .543 r
F
.58478 .38688 m .58473 .38467 L .5858 .38702 L F
.58659 .36878 m .58678 .37356 L .58662 .37327 L .988 .719 .381 r
F
.58647 .36802 m .5865 .37283 L .58648 .3725 L .777 .62 .057 r
F
.58552 .37257 m .5835 .37686 L .5868 .37325 L .675 .735 .895 r
F
.58686 .37371 m .58402 .37354 L .5846 .37456 L F
.58779 .37164 m .58854 .3748 L .58784 .37448 L .846 .571 .522 r
F
.59016 .37248 m .58653 .3731 L .58686 .37371 L .675 .735 .895 r
F
.58653 .3731 m .58402 .37354 L .58686 .37371 L F
.58755 .37434 m .58557 .37544 L .58806 .37479 L F
.58743 .37424 m .58739 .37427 L .58755 .37434 L F
.58739 .37427 m .58557 .37544 L .58755 .37434 L F
.58829 .37367 m .58649 .37772 L .58973 .37802 L F
.59016 .37248 m .58685 .37611 L .58835 .37654 L F
.58755 .37434 m .58771 .37704 L .58756 .37697 L .846 .571 .522 r
F
.58754 .36991 m .58765 .37439 L .58755 .37434 L F
.58765 .37439 m .58771 .37704 L .58755 .37434 L F
.58665 .37592 m .58657 .37579 L .58655 .37314 L .988 .719 .381 r
F
.58659 .37322 m .58655 .37314 L .5865 .36863 L F
.58689 .37376 m .5846 .37456 L .58722 .37437 L .675 .735 .895 r
F
.58686 .37371 m .58684 .37372 L .58689 .37376 L F
.58684 .37372 m .5846 .37456 L .58689 .37376 L F
.58712 .37658 m .587 .37647 L .58695 .37382 L .93 .648 .485 r
F
.58703 .37388 m .58695 .37382 L .58688 .36932 L F
.58712 .37658 m .58695 .37382 L .58703 .37388 L F
.58665 .37592 m .58655 .37314 L .58659 .37322 L .988 .719 .381 r
F
.5865 .37283 m .58652 .37569 L .58648 .3725 L .777 .62 .057 r
F
.58647 .36802 m .5865 .36863 L .58651 .37025 L F
.58648 .36976 m .58651 .37025 L .58651 .37307 L F
.5865 .37283 m .58651 .37307 L .58652 .37569 L F
.58648 .36976 m .58651 .37307 L .5865 .37283 L F
.58647 .37246 m .58411 .37135 L .58385 .37244 L .675 .735 .895 r
F
.58678 .37356 m .58689 .37637 L .58662 .37327 L .988 .719 .381 r
F
.58684 .37153 m .58647 .3749 L .58682 .37426 L 0 0 .377 r
F
.58659 .36878 m .58688 .36932 L .58688 .37094 L .988 .719 .381 r
F
.5867 .3706 m .58688 .37094 L .58689 .37376 L F
.58659 .36878 m .58688 .37094 L .5867 .3706 L F
.58776 .37002 m .58779 .37164 L .58754 .36991 L .846 .571 .522 r
F
.5835 .37686 m .5802 .38048 L .58469 .38176 L .675 .735 .895 r
F
.58098 .37839 m .58022 .38338 L .58353 .37975 L F
.58685 .37611 m .58654 .38061 L .58835 .37654 L F
.58705 .37717 m .57646 .38329 L .58836 .37742 L .654 .726 .902 r
F
.57646 .38329 m .56773 .38833 L .57685 .38351 L F
.57646 .38329 m .57685 .38351 L .58836 .37742 L F
.57762 .38394 m .57638 .38135 L .58022 .38338 L .862 .585 .518 r
F
.57762 .38394 m .58022 .38338 L .58027 .38542 L F
.58373 .37987 m .57685 .38351 L .5809 .38501 L .654 .726 .902 r
F
.57685 .38351 m .56773 .38833 L .57996 .38525 L F
.57685 .38351 m .57996 .38525 L .5809 .38501 L F
.57645 .3842 m .57762 .38394 L .58029 .38623 L .862 .585 .518 r
F
.57762 .38394 m .58027 .38542 L .58029 .38623 L F
.57645 .3842 m .57643 .38328 L .57762 .38394 L F
.57643 .38328 m .57638 .38135 L .57762 .38394 L F
.58691 .37896 m .58661 .38346 L .58842 .37939 L .675 .735 .895 r
F
.58712 .37658 m .58756 .37697 L .58757 .38403 L .93 .648 .485 r
F
.58995 .38896 m .58121 .40163 L .58934 .40275 L .654 .726 .902 r
F
.59007 .38628 m .58925 .38769 L .58995 .38896 L F
.58925 .38769 m .58121 .40163 L .58995 .38896 L F
.58836 .37742 m .58373 .37987 L .5809 .38501 L F
.58772 .37808 m .58564 .37829 L .58691 .37896 L .675 .735 .895 r
F
.58854 .3748 m .58865 .37748 L .58854 .37746 L .751 .49 .538 r
F
.58661 .38346 m .5848 .38752 L .58968 .38798 L .675 .735 .895 r
F
.58974 .38598 m .58704 .39093 L .59007 .38628 L .654 .726 .902 r
F
.58704 .39093 m .58121 .40163 L .58707 .39147 L F
.58704 .39093 m .58707 .39147 L .59007 .38628 L F
.58726 .37724 m .58564 .37829 L .58772 .37808 L .675 .735 .895 r
F
.58648 .37517 m .58652 .37569 L .58653 .38274 L .777 .62 .057 r
F
.58661 .38346 m .58968 .38798 L .58986 .38376 L .675 .735 .895 r
F
.58911 .38479 m .58891 .38523 L .59011 .38529 L .654 .726 .902 r
F
.58895 .37822 m .58826 .37886 L .58896 .37823 L F
.58917 .37772 m .58691 .37896 L .58842 .37939 L .675 .735 .895 r
F
.59027 .37502 m .59037 .37774 L .59011 .37504 L .641 .4 .539 r
F
.58982 .37599 m .59011 .37504 L .59012 .37777 L .751 .49 .538 r
F
.58888 .37047 m .59012 .37777 L .58908 .37756 L F
.59066 .37508 m .58782 .37797 L .58937 .37783 L .654 .726 .902 r
F
.59023 .37533 m .58819 .37757 L .58917 .37772 L .675 .735 .895 r
F
.58782 .37797 m .58935 .37786 L .58931 .37784 L .654 .726 .902 r
F
.5884 .37739 m .58705 .37717 L .58836 .37742 L F
.58879 .37766 m .58869 .37764 L .58854 .3748 L .751 .49 .538 r
F
.58854 .37762 m .58898 .37782 L .58917 .37772 L .675 .735 .895 r
F
.58891 .38523 m .58694 .38941 L .58974 .38598 L .654 .726 .902 r
F
.58895 .37822 m .58896 .37823 L .58936 .37786 L F
.58888 .37047 m .58908 .37756 L .58853 .37041 L .751 .49 .538 r
F
.58869 .37483 m .58879 .37766 L .58854 .3748 L F
.58784 .37448 m .58854 .37746 L .58789 .37714 L .846 .571 .522 r
F
.59066 .37508 m .5852 .37681 L .58705 .37717 L .654 .726 .902 r
F
.58826 .37886 m .58018 .38631 L .58827 .37887 L F
.58691 .37896 m .5836 .3826 L .58661 .38346 L .675 .735 .895 r
F
.58647 .3749 m .58649 .3821 L .58648 .38196 L .777 .62 .057 r
F
.58648 .37517 m .58653 .38274 L .5865 .38232 L F
.58095 .37551 m .5802 .38048 L .5835 .37686 L .675 .735 .895 r
F
.58095 .37551 m .57639 .37845 L .5802 .38048 L F
.57349 .37871 m .57632 .3785 L .57638 .38135 L .934 .65 .478 r
F
.57349 .37871 m .57342 .37586 L .57632 .3785 L F
.57638 .38135 m .57632 .3785 L .58015 .38053 L .862 .585 .518 r
F
.57905 .37663 m .57638 .38135 L .58098 .37839 L .675 .735 .895 r
F
.57905 .37663 m .57349 .37871 L .57638 .38135 L F
.57187 .37771 m .55997 .37877 L .57349 .38051 L .654 .726 .902 r
F
.57179 .3785 m .57237 .37857 L .57355 .38156 L .986 .711 .377 r
F
.57237 .37857 m .57349 .37871 L .57353 .38059 L F
.57237 .37857 m .57353 .38059 L .57355 .38156 L F
.57349 .38051 m .55997 .37877 L .5629 .38385 L .654 .726 .902 r
F
.58644 .37642 m .57187 .37771 L .57349 .38051 L F
.58739 .37427 m .58709 .37413 L .58722 .37437 L .675 .735 .895 r
F
.58703 .36945 m .58756 .37697 L .58712 .37658 L .93 .648 .485 r
F
.58811 .37474 m .58797 .37472 L .58806 .37479 L .675 .735 .895 r
F
.58784 .37448 m .58854 .3748 L .58854 .37746 L .846 .571 .522 r
F
.59066 .37508 m .5851 .37575 L .58644 .37642 L .654 .726 .902 r
F
.57903 .37376 m .5735 .37583 L .57639 .37845 L .675 .735 .895 r
F
.57237 .37857 m .57173 .37565 L .57349 .37871 L .986 .711 .377 r
F
.57179 .3785 m .57177 .37754 L .57237 .37857 L F
.57177 .37754 m .57173 .37565 L .57237 .37857 L F
.58552 .37257 m .58095 .37551 L .5835 .37686 L .675 .735 .895 r
F
.5846 .37456 m .58098 .37839 L .58557 .37544 L F
.5846 .37456 m .57905 .37663 L .58098 .37839 L F
.5851 .37575 m .57167 .37736 L .58644 .37642 L .654 .726 .902 r
F
.57167 .37736 m .55997 .37877 L .57187 .37771 L F
.57787 .37459 m .57349 .37871 L .57905 .37663 L .675 .735 .895 r
F
.57167 .37736 m .57187 .37771 L .58644 .37642 L .654 .726 .902 r
F
.58779 .37164 m .58789 .37714 L .58758 .37154 L .846 .571 .522 r
F
.58789 .37714 m .58802 .38425 L .58777 .37708 L F
.58789 .37714 m .58777 .37708 L .58758 .37154 L F
.58557 .37544 m .58353 .37975 L .58685 .37611 L .675 .735 .895 r
F
.58665 .37592 m .58689 .37658 L .58665 .37614 L .988 .719 .381 r
F
.58662 .37327 m .58689 .37637 L .58665 .37592 L F
.58665 .37592 m .5867 .38306 L .58657 .37579 L F
.57638 .38135 m .58015 .38053 L .58022 .38338 L .862 .585 .518 r
F
.58098 .37839 m .57638 .38135 L .58022 .38338 L .675 .735 .895 r
F
.57645 .38329 m .5629 .38385 L .56773 .38833 L .654 .726 .902 r
F
.57451 .38149 m .57638 .38135 L .57643 .38328 L .934 .65 .478 r
F
.58705 .37717 m .5738 .38083 L .57645 .38329 L .654 .726 .902 r
F
.5738 .38083 m .5629 .38385 L .57645 .38329 L F
.57355 .38156 m .57451 .38149 L .57645 .3842 L .934 .65 .478 r
F
.57451 .38149 m .57643 .38328 L .57645 .3842 L F
.59023 .37533 m .58467 .37741 L .58564 .37829 L .675 .735 .895 r
F
.58648 .37502 m .5865 .3822 L .58647 .3749 L .777 .62 .057 r
F
.58905 .38476 m .58679 .38689 L .58911 .38479 L .654 .726 .902 r
F
.58679 .38689 m .5737 .3992 L .58679 .38696 L F
.58679 .38689 m .58679 .38696 L .58911 .38479 L F
.58648 .37517 m .5865 .38232 L .58648 .37502 L .777 .62 .057 r
F
.5882 .38445 m .58813 .38453 L .58918 .38464 L .654 .726 .902 r
F
.58117 .3916 m .58051 .39279 L .58873 .38507 L F
.5809 .38501 m .56773 .38833 L .57412 .39191 L F
.5809 .38501 m .57412 .39191 L .58018 .38631 L F
.5836 .3826 m .58029 .38623 L .5848 .38752 L .675 .735 .895 r
F
.58704 .38422 m .56248 .39114 L .56731 .39562 L .654 .726 .902 r
F
.58842 .37939 m .58661 .38346 L .58986 .38376 L .675 .735 .895 r
F
.59024 .38237 m .5854 .3839 L .58704 .38422 L .654 .726 .902 r
F
.5836 .3826 m .5848 .38752 L .58661 .38346 L .675 .735 .895 r
F
.5854 .3839 m .56248 .39114 L .58704 .38422 L .654 .726 .902 r
F
.58856 .38452 m .59019 .41643 L .58862 .41616 L .751 .49 .538 r
F
.58854 .37746 m .58885 .38457 L .58856 .38452 L F
.58813 .38453 m .58873 .38507 L .58918 .38464 L .654 .726 .902 r
F
.58885 .38457 m .59019 .41643 L .58856 .38452 L .751 .49 .538 r
F
.58802 .38425 m .58787 .38418 L .58771 .37704 L .846 .571 .522 r
F
.58777 .37708 m .58771 .37704 L .58758 .37154 L F
.58802 .38425 m .58771 .37704 L .58777 .37708 L F
.57903 .37376 m .57639 .37845 L .58095 .37551 L .675 .735 .895 r
F
.57173 .37565 m .57342 .37586 L .57349 .37871 L .986 .711 .377 r
F
.57173 .37565 m .57166 .3728 L .57342 .37586 L F
.57787 .37459 m .57173 .37565 L .57349 .37871 L .675 .735 .895 r
F
.5713 .37452 m .55912 .37343 L .57174 .37735 L .654 .726 .902 r
F
.57129 .37522 m .57143 .37536 L .57179 .3785 L .849 .652 .113 r
F
.57143 .37536 m .57173 .37565 L .57177 .37754 L F
.57143 .37536 m .57177 .37754 L .57179 .3785 L F
.57174 .37735 m .55912 .37343 L .55997 .37877 L .654 .726 .902 r
F
.5851 .37575 m .5713 .37452 L .57174 .37735 L F
.58908 .37756 m .58879 .37751 L .58853 .37041 L .751 .49 .538 r
F
.58736 .37417 m .58755 .37434 L .58756 .37697 L .93 .648 .485 r
F
.57951 .38576 m .55954 .38606 L .56248 .39114 L .654 .726 .902 r
F
.58819 .37757 m .58898 .37782 L .58854 .37762 L .675 .735 .895 r
F
.59054 .37785 m .5886 .37948 L .59033 .38261 L .654 .726 .902 r
F
.58842 .37939 m .58986 .38376 L .59005 .37955 L .675 .735 .895 r
F
.58865 .37748 m .58893 .38459 L .58854 .37746 L .751 .49 .538 r
F
.58893 .38459 m .59019 .41643 L .58885 .38457 L F
.58893 .38459 m .58885 .38457 L .58854 .37746 L F
.587 .37647 m .58711 .38361 L .58689 .37637 L .93 .648 .485 r
F
.58711 .38361 m .58763 .41569 L .58703 .38354 L F
.58711 .38361 m .58703 .38354 L .58689 .37637 L F
.58639 .38296 m .58357 .38317 L .58312 .38346 L .654 .726 .902 r
F
.58813 .38453 m .58117 .3916 L .58873 .38507 L F
.58911 .38479 m .58679 .38696 L .58694 .38941 L F
.58738 .38429 m .58758 .38466 L .5882 .38445 L F
.58757 .38403 m .58862 .41616 L .58763 .41569 L .846 .571 .522 r
F
.58756 .37697 m .58775 .38412 L .58757 .38403 L F
.58775 .38412 m .58862 .41616 L .58757 .38403 L F
.58557 .37544 m .58098 .37839 L .58353 .37975 L .675 .735 .895 r
F
.5852 .37681 m .57346 .38052 L .58705 .37717 L .654 .726 .902 r
F
.57346 .38052 m .5629 .38385 L .5738 .38083 L F
.57451 .38149 m .57349 .37871 L .57638 .38135 L .934 .65 .478 r
F
.57346 .38052 m .5738 .38083 L .58705 .37717 L .654 .726 .902 r
F
.57355 .38156 m .57353 .38059 L .57451 .38149 L .934 .65 .478 r
F
.57353 .38059 m .57349 .37871 L .57451 .38149 L F
.58104 .38124 m .58029 .38623 L .5836 .3826 L .675 .735 .895 r
F
.58541 .38295 m .5587 .38072 L .55954 .38606 L .654 .726 .902 r
F
.59016 .37248 m .58686 .37371 L .58709 .37413 L .675 .735 .895 r
F
.5856 .37482 m .58456 .37548 L .5851 .37575 L .654 .726 .902 r
F
.59023 .37533 m .58522 .3753 L .58408 .37639 L .675 .735 .895 r
F
.57787 .37173 m .5735 .37583 L .57903 .37376 L F
.58402 .37354 m .57905 .37663 L .5846 .37456 L F
.58456 .3717 m .57903 .37376 L .58095 .37551 L F
.58402 .37354 m .57787 .37459 L .57905 .37663 L F
.58295 .37468 m .57123 .37407 L .5851 .37575 L .654 .726 .902 r
F
.57123 .37407 m .55912 .37343 L .5713 .37452 L F
.57143 .37536 m .57122 .37237 L .57173 .37565 L .849 .652 .113 r
F
.57754 .37241 m .57173 .37565 L .57787 .37459 L .675 .735 .895 r
F
.57123 .37407 m .5713 .37452 L .5851 .37575 L .654 .726 .902 r
F
.57129 .37522 m .57127 .37433 L .57143 .37536 L .849 .652 .113 r
F
.57127 .37433 m .57122 .37237 L .57143 .37536 L F
.58522 .3753 m .58392 .37529 L .58405 .37613 L .675 .735 .895 r
F
.58522 .3753 m .58405 .37613 L .58408 .37639 L F
.58705 .37109 m .58694 .37099 L .58688 .36932 L .93 .648 .485 r
F
.5901 .36963 m .58651 .37025 L .58683 .37085 L .675 .735 .895 r
F
.58705 .37109 m .58709 .37393 L .58694 .37099 L .93 .648 .485 r
F
.5866 .37042 m .58665 .37592 L .58654 .37031 L .988 .719 .381 r
F
.59016 .37248 m .58668 .37183 L .58647 .37246 L .675 .735 .895 r
F
.58697 .35381 m .58645 .36784 L .58687 .36709 L 0 0 .377 r
F
.58336 .36739 m .561 .36096 L .5597 .36615 L .654 .726 .902 r
F
.59108 .36779 m .58613 .36667 L .58336 .36739 L F
.58613 .36667 m .561 .36096 L .58336 .36739 L F
.58689 .37637 m .58703 .38354 L .58691 .38343 L .93 .648 .485 r
F
.59024 .38237 m .58524 .38211 L .58541 .38295 L .654 .726 .902 r
F
.58541 .3839 m .58312 .38346 L .5854 .3839 L F
.58721 .3837 m .58711 .38361 L .587 .37647 L .93 .648 .485 r
F
.59024 .38237 m .58588 .38304 L .58541 .3839 L .654 .726 .902 r
F
.58588 .38304 m .58312 .38346 L .58541 .3839 L F
.58665 .37592 m .58689 .37637 L .58689 .37658 L .988 .719 .381 r
F
.59023 .37533 m .58408 .37639 L .58467 .37741 L .675 .735 .895 r
F
.58692 .37407 m .58685 .38128 L .587 .37392 L 0 0 .377 r
F
.5867 .38306 m .58697 .41509 L .58665 .38296 L .988 .719 .381 r
F
.57911 .37948 m .57645 .3842 L .58104 .38124 L .675 .735 .895 r
F
.58174 .38193 m .56 .3755 L .5587 .38072 L .654 .726 .902 r
F
.58774 .37353 m .58762 .3806 L .58796 .37337 L .4 .211 .506 r
F
.59024 .38237 m .58626 .38285 L .58639 .38296 L .654 .726 .902 r
F
.58704 .38422 m .58758 .38466 L .58738 .38429 L F
.58721 .3837 m .58757 .38403 L .58763 .41569 L .93 .648 .485 r
F
.58564 .37829 m .58104 .38124 L .5836 .3826 L .675 .735 .895 r
F
.5776 .37526 m .57179 .3785 L .57794 .37744 L F
.5776 .37526 m .57129 .37522 L .57179 .3785 L F
.59108 .36779 m .57011 .3667 L .56054 .37146 L .654 .726 .902 r
F
.57011 .3667 m .5597 .36615 L .55986 .36715 L F
.57011 .3667 m .55986 .36715 L .56054 .37146 L F
.5903 .35258 m .5892 .35267 L .58923 .36586 L .66 .415 .539 r
F
.58648 .3725 m .58652 .37569 L .58648 .37517 L .777 .62 .057 r
F
.58709 .37393 m .58712 .37658 L .58703 .37388 L .93 .648 .485 r
F
.58678 .37356 m .58689 .37376 L .58689 .37637 L .988 .719 .381 r
F
.5856 .37482 m .58546 .3739 L .58255 .37466 L .654 .726 .902 r
F
.59066 .37508 m .58662 .37417 L .5856 .37482 L F
.58662 .37417 m .58546 .3739 L .5856 .37482 L F
.58627 .36892 m .58475 .3675 L .58408 .36851 L .675 .735 .895 r
F
.5901 .36963 m .58701 .3684 L .58627 .36892 L F
.58701 .3684 m .58475 .3675 L .58627 .36892 L F
.58787 .36631 m .58699 .36687 L .58699 .36841 L .4 .211 .506 r
F
.58703 .36945 m .58754 .36991 L .58755 .37152 L .93 .648 .485 r
F
.58738 .37138 m .58709 .37131 L .58732 .37142 L .675 .735 .895 r
F
.58722 .37124 m .58709 .37131 L .58738 .37138 L F
.58722 .37124 m .58755 .37152 L .58755 .37434 L .93 .648 .485 r
F
.58703 .36945 m .58755 .37152 L .58722 .37124 L F
.58779 .37164 m .58758 .37154 L .58754 .36991 L .846 .571 .522 r
F
.5901 .36963 m .58722 .37124 L .58738 .37138 L .675 .735 .895 r
F
.58599 .37034 m .58381 .36959 L .58398 .37068 L F
.5866 .37042 m .58654 .37031 L .5865 .36863 L .988 .719 .381 r
F
.5901 .36963 m .58637 .36961 L .58599 .37034 L .675 .735 .895 r
F
.58637 .36961 m .58381 .36959 L .58599 .37034 L F
.58686 .36867 m .58662 .37196 L .58684 .37153 L 0 0 .377 r
F
.58687 .36709 m .58678 .36882 L .58686 .36867 L F
.58678 .36882 m .58662 .37196 L .58686 .36867 L F
.58659 .36878 m .5866 .37042 L .5865 .36863 L .988 .719 .381 r
F
.5901 .36963 m .58669 .369 L .58637 .36961 L .675 .735 .895 r
F
.58768 .36792 m .58699 .36841 L .587 .37123 L .4 .211 .506 r
F
.58768 .36792 m .587 .37123 L .58734 .37099 L F
.58787 .36631 m .58699 .36841 L .58768 .36792 L F
.58766 .36794 m .58735 .36773 L .58701 .3684 L .675 .735 .895 r
F
.58687 .36709 m .58645 .36784 L .58646 .36944 L 0 0 .377 r
F
.58687 .36709 m .58686 .36867 L .58699 .36687 L F
.58686 .36867 m .58695 .36849 L .58699 .36687 L F
.58735 .36773 m .58578 .36664 L .587 .36839 L .675 .735 .895 r
F
.58735 .36773 m .587 .36839 L .58701 .3684 L F
.58651 .37025 m .58398 .37068 L .58655 .37096 L F
.58647 .36802 m .58648 .3725 L .58645 .36784 L .777 .62 .057 r
F
.58648 .3725 m .58648 .37517 L .58647 .37243 L F
.58648 .3725 m .58647 .37243 L .58645 .36784 L F
.58639 .37098 m .58583 .36947 L .58479 .37034 L .675 .735 .895 r
F
.58673 .36892 m .58646 .36944 L .58646 .37226 L 0 0 .377 r
F
.58683 .37085 m .58651 .37025 L .58655 .37096 L .675 .735 .895 r
F
.58687 .36709 m .58646 .37226 L .58662 .37196 L 0 0 .377 r
F
.58703 .36945 m .58755 .37434 L .58736 .37417 L .93 .648 .485 r
F
.59016 .37248 m .58647 .37246 L .58651 .37311 L .675 .735 .895 r
F
.58779 .37067 m .587 .37392 L .58775 .37345 L .4 .211 .506 r
F
.5901 .36963 m .58651 .37025 L .58651 .37025 L .675 .735 .895 r
F
.58787 .36631 m .58734 .37099 L .58779 .37067 L .4 .211 .506 r
F
.58668 .37183 m .58508 .37046 L .58574 .37166 L .675 .735 .895 r
F
.5901 .36963 m .58738 .37138 L .588 .37193 L F
.59016 .37248 m .58701 .37122 L .58668 .37183 L F
.587 .37122 m .58508 .37046 L .58668 .37183 L F
.58682 .37426 m .58695 .37133 L .58689 .37145 L 0 0 .377 r
F
.58734 .37099 m .587 .37123 L .587 .37392 L .4 .211 .506 r
F
.5865 .36863 m .58657 .37579 L .58652 .37569 L .988 .719 .381 r
F
.58668 .37183 m .58643 .37179 L .58646 .37226 L .675 .735 .895 r
F
.58637 .36961 m .58408 .36851 L .58381 .36959 L F
.58508 .37046 m .58479 .37034 L .58574 .37166 L F
.58365 .36611 m .56435 .35622 L .561 .36096 L .654 .726 .902 r
F
.5881 .35301 m .58699 .36687 L .58787 .36631 L .4 .211 .506 r
F
.59108 .36779 m .58685 .36596 L .58365 .36611 L .654 .726 .902 r
F
.58685 .36596 m .56435 .35622 L .58365 .36611 L F
.59011 .38529 m .58974 .38598 L .59007 .38628 L F
.59014 .38482 m .58934 .40275 L .5911 .38474 L F
.59011 .37504 m .59037 .37774 L .59012 .37777 L .641 .4 .539 r
F
.58891 .38523 m .58974 .38598 L .59011 .38529 L .654 .726 .902 r
F
.58931 .37784 m .58935 .37786 L .58937 .37783 L F
.58937 .37783 m .58935 .37786 L .58936 .37786 L F
.58946 .37764 m .5886 .37948 L .59054 .37785 L F
.59012 .37786 m .58842 .37939 L .59005 .37955 L .675 .735 .895 r
F
.58908 .37756 m .59012 .37777 L .59012 .37786 L .751 .49 .538 r
F
.58908 .37756 m .59012 .37786 L .5891 .37771 L F
.59066 .37508 m .58946 .37764 L .59054 .37785 L .654 .726 .902 r
F
.59023 .37533 m .58917 .37772 L .59012 .37786 L .675 .735 .895 r
F
.58936 .37786 m .58896 .37823 L .58912 .37838 L .654 .726 .902 r
F
.58917 .37772 m .58842 .37939 L .59012 .37786 L .675 .735 .895 r
F
.5891 .37771 m .59012 .37786 L .59013 .38482 L .751 .49 .538 r
F
.59014 .38482 m .58911 .38479 L .59011 .38529 L .654 .726 .902 r
F
.58918 .38464 m .58911 .38479 L .59014 .38482 L F
.58929 .38466 m .59013 .38482 L .59019 .41643 L .751 .49 .538 r
F
.58908 .37756 m .59013 .38482 L .58929 .38466 L F
.59024 .38237 m .58918 .38464 L .59014 .38482 L .654 .726 .902 r
F
.58697 .35381 m .58687 .36709 L .58699 .36687 L 0 0 .377 r
F
.59108 .36779 m .56952 .35228 L .56435 .35622 L .654 .726 .902 r
F
.59108 .36779 m .57616 .34939 L .56952 .35228 L F
.5892 .35267 m .58812 .36615 L .58898 .36593 L .567 .342 .533 r
F
.5881 .35301 m .58787 .36631 L .58812 .36615 L .4 .211 .506 r
F
.59008 .35772 m .59046 .37068 L .59011 .37071 L .641 .4 .539 r
F
.59108 .36779 m .58382 .34775 L .57616 .34939 L .654 .726 .902 r
F
.57753 .36956 m .57175 .37278 L .57787 .37173 L .675 .735 .895 r
F
.57753 .36956 m .57125 .36952 L .57175 .37278 L F
.57122 .37237 m .57116 .36952 L .57166 .3728 L .849 .652 .113 r
F
.57201 .3691 m .57116 .36952 L .57122 .37237 L 0 0 .257 r
F
.57805 .36739 m .57203 .36627 L .57125 .36952 L .675 .735 .895 r
F
.57201 .3691 m .57194 .36625 L .57116 .36952 L 0 0 .257 r
F
.57806 .37023 m .57201 .3691 L .57122 .37237 L .675 .735 .895 r
F
.57806 .37023 m .57122 .37237 L .57754 .37241 L F
.58244 .37321 m .57383 .36871 L .57227 .3709 L .654 .726 .902 r
F
.5741 .36891 m .57366 .36895 L .57208 .37195 L .116 .008 .443 r
F
.57366 .36895 m .57201 .3691 L .57206 .3712 L F
.57366 .36895 m .57206 .3712 L .57208 .37195 L F
.57227 .3709 m .56379 .36345 L .56042 .36821 L .654 .726 .902 r
F
.57383 .36871 m .56379 .36345 L .57227 .3709 L F
.59016 .37248 m .58767 .37075 L .58701 .37122 L .675 .735 .895 r
F
.5901 .36963 m .58766 .36794 L .58701 .3684 L F
.58748 .36782 m .58711 .36598 L .58578 .36664 L F
.5901 .36963 m .58838 .36753 L .58748 .36782 L F
.58784 .36781 m .58804 .36767 L .58812 .36615 L .4 .211 .506 r
F
.58838 .36753 m .58711 .36598 L .58748 .36782 L .675 .735 .895 r
F
.58898 .36593 m .58812 .36615 L .58812 .36762 L .567 .342 .533 r
F
.58881 .3674 m .58813 .37043 L .58847 .37033 L F
.58789 .3706 m .58802 .37051 L .58812 .36615 L .4 .211 .506 r
F
.58784 .36781 m .58779 .37067 L .58804 .36767 L F
.58779 .37067 m .58774 .37353 L .58789 .3706 L F
.58779 .37067 m .58789 .3706 L .58804 .36767 L F
.5901 .36963 m .58683 .37085 L .58709 .37131 L .675 .735 .895 r
F
.59016 .37248 m .58842 .37034 L .58767 .37075 L F
.58842 .37034 m .58836 .37027 L .58813 .37043 L F
.58842 .37034 m .58813 .37043 L .58767 .37075 L F
.58891 .37019 m .58813 .3732 L .58886 .37302 L .567 .342 .533 r
F
.58898 .36593 m .58847 .37033 L .58891 .37019 L F
.58847 .37033 m .58813 .3732 L .58891 .37019 L F
.58812 .36615 m .58796 .37332 L .58813 .3732 L .4 .211 .506 r
F
.58836 .37027 m .58871 .3684 L .58717 .36881 L .675 .735 .895 r
F
.58842 .37034 m .58844 .37022 L .58836 .37027 L F
.58844 .37022 m .58871 .3684 L .58836 .37027 L F
.59008 .36582 m .58923 .36586 L .58923 .36727 L .66 .415 .539 r
F
.58925 .36726 m .59028 .36543 L .58865 .36557 L .675 .735 .895 r
F
.5901 .36963 m .5902 .36718 L .58925 .36726 L F
.59008 .36582 m .58923 .36727 L .5898 .36721 L .66 .415 .539 r
F
.5902 .36718 m .59028 .36543 L .58925 .36726 L .675 .735 .895 r
F
.58898 .36593 m .58812 .36762 L .58881 .3674 L .567 .342 .533 r
F
.58787 .36631 m .58784 .36781 L .58812 .36615 L .4 .211 .506 r
F
.58838 .36753 m .58865 .36557 L .58711 .36598 L .675 .735 .895 r
F
.5901 .36963 m .58925 .36726 L .58838 .36753 L F
.58925 .36726 m .58865 .36557 L .58838 .36753 L F
.58898 .36593 m .58896 .36735 L .58923 .36586 L .567 .342 .533 r
F
.58931 .37008 m .58924 .37008 L .58842 .37034 L .675 .735 .895 r
F
.58896 .36735 m .58886 .37302 L .58916 .36729 L .567 .342 .533 r
F
.58896 .36735 m .58916 .36729 L .58923 .36586 L F
.5898 .36721 m .58923 .36727 L .58924 .37008 L .66 .415 .539 r
F
.59016 .37248 m .58931 .37008 L .58842 .37034 L .675 .735 .895 r
F
.58918 .38464 m .58905 .38476 L .58911 .38479 L .654 .726 .902 r
F
.58929 .38466 m .59019 .41643 L .58904 .38461 L .751 .49 .538 r
F
.58904 .38461 m .59019 .41643 L .58893 .38459 L F
.58929 .38466 m .58904 .38461 L .58879 .37751 L F
.59024 .38237 m .5882 .38445 L .58918 .38464 L .654 .726 .902 r
F
.59001 .37001 m .58924 .37008 L .58924 .3729 L .66 .415 .539 r
F
.59001 .37001 m .58924 .3729 L .58996 .37283 L F
.58936 .37289 m .59041 .37111 L .58877 .37125 L .675 .735 .895 r
F
.5899 .3744 m .59034 .3728 L .58936 .37289 L F
.59016 .37248 m .59005 .37505 L .59103 .37492 L F
.59025 .37493 m .59034 .3728 L .5899 .3744 L F
.58847 .37033 m .58813 .37043 L .58813 .3732 L .567 .342 .533 r
F
.59008 .36582 m .58996 .37288 L .59033 .36581 L .66 .415 .539 r
F
.59016 .37248 m .58743 .37424 L .58797 .37472 L .675 .735 .895 r
F
.58688 .36932 m .587 .37647 L .58689 .37637 L .93 .648 .485 r
F
.59066 .37508 m .587 .3735 L .58546 .3739 L .654 .726 .902 r
F
.59023 .37533 m .59025 .37493 L .5899 .3744 L .675 .735 .895 r
F
.58541 .37245 m .58385 .37244 L .58621 .37316 L F
.58381 .36959 m .57787 .37173 L .58398 .37068 L F
.58381 .36959 m .57753 .36956 L .57787 .37173 L F
.58408 .36851 m .57805 .36739 L .57753 .36956 L F
.5794 .36537 m .57203 .36627 L .57805 .36739 L F
.58479 .37034 m .57806 .37023 L .58411 .37135 L F
.5794 .36537 m .57405 .36324 L .57203 .36627 L F
.57403 .36606 m .57194 .36625 L .57201 .3691 L .116 .008 .443 r
F
.57403 .36606 m .57397 .36321 L .57194 .36625 L F
.58408 .36851 m .57753 .36956 L .58381 .36959 L .675 .735 .895 r
F
.58479 .37034 m .57941 .3682 L .57806 .37023 L F
.57941 .3682 m .57403 .36606 L .57201 .3691 L F
.58598 .37306 m .57716 .36601 L .57445 .36807 L .654 .726 .902 r
F
.57722 .3663 m .57681 .36627 L .5741 .36891 L .356 .186 .508 r
F
.57681 .36627 m .57403 .36606 L .57409 .36834 L F
.57681 .36627 m .57409 .36834 L .5741 .36891 L F
.57445 .36807 m .56899 .35949 L .56379 .36345 L .654 .726 .902 r
F
.58149 .36646 m .57716 .36345 L .57403 .36606 L .675 .735 .895 r
F
.57722 .3663 m .57716 .36345 L .57403 .36606 L .356 .186 .508 r
F
.57716 .36601 m .56899 .35949 L .57445 .36807 L .654 .726 .902 r
F
.58682 .37426 m .58692 .37407 L .58695 .37133 L 0 0 .377 r
F
.58668 .37183 m .58646 .37226 L .58647 .37246 L .675 .735 .895 r
F
.58647 .37246 m .58541 .37245 L .58651 .37311 L F
.58645 .36784 m .58648 .37502 L .58647 .3749 L .777 .62 .057 r
F
.58648 .37517 m .58648 .37502 L .58645 .36784 L F
.58662 .37196 m .58646 .37226 L .58647 .3749 L 0 0 .377 r
F
.59016 .37248 m .58797 .37472 L .58811 .37474 L .675 .735 .895 r
F
.58853 .37041 m .58869 .37483 L .58854 .3748 L .751 .49 .538 r
F
.59016 .37248 m .58709 .37413 L .58739 .37427 L .675 .735 .895 r
F
.59066 .37508 m .58774 .37298 L .58598 .37306 L .654 .726 .902 r
F
.58662 .37196 m .58647 .3749 L .58684 .37153 L 0 0 .377 r
F
.58643 .37179 m .58411 .37135 L .58647 .37246 L .675 .735 .895 r
F
.58651 .37311 m .58541 .37245 L .58621 .37316 L F
.58583 .36947 m .57941 .3682 L .58479 .37034 L F
.58475 .3675 m .5794 .36537 L .57805 .36739 L F
.58149 .36646 m .57403 .36606 L .57941 .3682 L F
.57716 .36345 m .57397 .36321 L .57403 .36606 L .356 .186 .508 r
F
.58774 .37298 m .56899 .35949 L .58598 .37306 L .654 .726 .902 r
F
.58996 .37283 m .58924 .3729 L .58924 .37292 L .66 .415 .539 r
F
.59066 .37508 m .58987 .37289 L .58919 .37292 L .654 .726 .902 r
F
.57787 .37173 m .57175 .37278 L .5735 .37583 L .675 .735 .895 r
F
.57122 .37237 m .57166 .3728 L .57173 .37565 L .849 .652 .113 r
F
.57754 .37241 m .57122 .37237 L .57173 .37565 L .675 .735 .895 r
F
.57134 .37407 m .56042 .36821 L .55912 .37343 L .654 .726 .902 r
F
.58255 .37466 m .57196 .37157 L .57134 .37407 L F
.57184 .37207 m .57122 .37237 L .57127 .37433 L 0 0 .257 r
F
.57196 .37157 m .56042 .36821 L .57134 .37407 L .654 .726 .902 r
F
.57208 .37195 m .57184 .37207 L .57129 .37522 L 0 0 .257 r
F
.57184 .37207 m .57127 .37433 L .57129 .37522 L F
.58385 .37244 m .57787 .37459 L .58402 .37354 L .675 .735 .895 r
F
.58398 .37068 m .57787 .37173 L .57903 .37376 L F
.58385 .37244 m .57754 .37241 L .57787 .37459 L F
.58398 .37068 m .57903 .37376 L .58456 .3717 L F
.58546 .3739 m .57214 .37087 L .58255 .37466 L .654 .726 .902 r
F
.57184 .37207 m .57201 .3691 L .57122 .37237 L 0 0 .257 r
F
.57214 .37087 m .56042 .36821 L .57196 .37157 L .654 .726 .902 r
F
.57214 .37087 m .57196 .37157 L .58255 .37466 L F
.57208 .37195 m .57206 .3712 L .57184 .37207 L 0 0 .257 r
F
.57206 .3712 m .57201 .3691 L .57184 .37207 L F
.58408 .37639 m .57794 .37744 L .57911 .37948 L .675 .735 .895 r
F
.58392 .37529 m .5776 .37526 L .57794 .37744 L F
.57813 .37308 m .57129 .37522 L .5776 .37526 L F
.57813 .37308 m .57208 .37195 L .57129 .37522 L F
.58511 .38015 m .56857 .36678 L .56337 .37075 L .654 .726 .902 r
F
.59066 .37508 m .5856 .37482 L .5851 .37575 L F
.58712 .37658 m .58721 .3837 L .587 .37647 L .93 .648 .485 r
F
.58775 .37345 m .587 .37392 L .58702 .38098 L .4 .211 .506 r
F
.58712 .37658 m .58757 .38403 L .58721 .3837 L .93 .648 .485 r
F
.59024 .38237 m .58641 .38071 L .58554 .38094 L .654 .726 .902 r
F
.58577 .38136 m .58554 .38094 L .58479 .38114 L F
.59024 .38237 m .58554 .38094 L .58577 .38136 L F
.58657 .37579 m .58665 .38296 L .58652 .37569 L .988 .719 .381 r
F
.58665 .38296 m .58674 .39259 L .58661 .3829 L F
.58665 .38296 m .58661 .3829 L .58652 .37569 L F
.5879 .37732 m .58856 .38452 L .58802 .38425 L .846 .571 .522 r
F
.59024 .38237 m .58625 .38147 L .58524 .38211 L .654 .726 .902 r
F
.58691 .38343 m .58763 .41569 L .58697 .41509 L .93 .648 .485 r
F
.58703 .38354 m .58763 .41569 L .58691 .38343 L F
.58721 .3837 m .58763 .41569 L .58711 .38361 L F
.58762 .3806 m .58702 .38098 L .58708 .41252 L .4 .211 .506 r
F
.58747 .37693 m .58705 .37717 L .5884 .37739 L .654 .726 .902 r
F
.58775 .37345 m .58702 .38098 L .58762 .3806 L .4 .211 .506 r
F
.58652 .37569 m .58661 .3829 L .58653 .38274 L .988 .719 .381 r
F
.5867 .38306 m .58665 .38296 L .58657 .37579 L F
.58665 .37592 m .58691 .38343 L .5867 .38306 L F
.58702 .38098 m .58704 .38007 L .58511 .38015 L .654 .726 .902 r
F
.58819 .37757 m .58691 .37896 L .58898 .37782 L .675 .735 .895 r
F
.5879 .37732 m .58854 .37762 L .58856 .38452 L .846 .571 .522 r
F
.59024 .38237 m .5877 .38055 L .58702 .38098 L .654 .726 .902 r
F
.5877 .38055 m .58704 .38007 L .58702 .38098 L F
.5865 .38232 m .5865 .3822 L .58648 .37502 L .777 .62 .057 r
F
.5865 .3822 m .58649 .3821 L .58647 .3749 L F
.58564 .37829 m .5836 .3826 L .58691 .37896 L .675 .735 .895 r
F
.58467 .37741 m .58104 .38124 L .58564 .37829 L F
.58408 .37639 m .57911 .37948 L .58467 .37741 L F
.58704 .38007 m .56857 .36678 L .58511 .38015 L .654 .726 .902 r
F
.5856 .37482 m .58295 .37468 L .58456 .37548 L F
.59023 .37533 m .58477 .37431 L .58392 .37529 L .675 .735 .895 r
F
.58477 .37431 m .58418 .3742 L .5841 .37452 L F
.58477 .37431 m .5841 .37452 L .58392 .37529 L F
.58908 .37756 m .58929 .38466 L .58879 .37751 L .751 .49 .538 r
F
.58924 .3729 m .58891 .38006 L .58926 .37997 L .567 .342 .533 r
F
.58923 .36586 m .58907 .37295 L .58924 .3729 L F
.59007 .37466 m .58896 .37299 L .58809 .37323 L .654 .726 .902 r
F
.58775 .37345 m .58796 .37332 L .58802 .37051 L .4 .211 .506 r
F
.59023 .37533 m .5899 .3744 L .58723 .37166 L .675 .735 .895 r
F
.5899 .3744 m .58877 .37125 L .58795 .37147 L F
.58896 .37299 m .5888 .37278 L .58813 .3732 L .654 .726 .902 r
F
.58734 .37099 m .587 .37392 L .58779 .37067 L .4 .211 .506 r
F
.58701 .37122 m .58631 .36981 L .58639 .37098 L .675 .735 .895 r
F
.58767 .37075 m .58736 .37053 L .58701 .37122 L F
.58684 .37153 m .58689 .37145 L .58695 .36849 L 0 0 .377 r
F
.58736 .37053 m .58631 .36981 L .587 .37122 L .675 .735 .895 r
F
.58736 .37053 m .587 .37122 L .58701 .37122 L F
.58686 .36867 m .58684 .37153 L .58695 .36849 L 0 0 .377 r
F
.58684 .37153 m .58682 .37426 L .58689 .37145 L F
.58631 .36981 m .58583 .36947 L .58639 .37098 L .675 .735 .895 r
F
.58647 .36802 m .58651 .37025 L .58648 .36976 L .777 .62 .057 r
F
.58669 .369 m .58408 .36851 L .58637 .36961 L .675 .735 .895 r
F
.58699 .36687 m .58692 .37407 L .587 .37392 L 0 0 .377 r
F
.58475 .3675 m .57805 .36739 L .58408 .36851 L .675 .735 .895 r
F
.58578 .36664 m .5794 .36537 L .58475 .3675 L F
.58578 .36664 m .58147 .36364 L .5794 .36537 L F
.58717 .36881 m .58149 .36646 L .58583 .36947 L F
.58687 .36709 m .58646 .36944 L .58673 .36892 L 0 0 .377 r
F
.58701 .3684 m .58578 .36664 L .58475 .3675 L .675 .735 .895 r
F
.58717 .36881 m .58417 .36514 L .58149 .36646 L F
.58147 .36364 m .57716 .36065 L .57405 .36324 L F
.58413 .36232 m .57716 .36065 L .58147 .36364 L F
.58417 .36514 m .58117 .36146 L .57716 .36345 L F
.5888 .37278 m .57567 .35659 L .58809 .37323 L .654 .726 .902 r
F
.58774 .37353 m .58802 .37051 L .58789 .3706 L .4 .211 .506 r
F
.5899 .3744 m .58795 .37147 L .58723 .37166 L .675 .735 .895 r
F
.59066 .37508 m .58896 .37299 L .58896 .37299 L .654 .726 .902 r
F
.59066 .37508 m .58896 .37299 L .59007 .37466 L F
.58896 .37299 m .58813 .3732 L .58809 .37323 L F
.58907 .37295 m .58907 .37296 L .58924 .3729 L .567 .342 .533 r
F
.58907 .37296 m .58891 .38006 L .58924 .37292 L F
.58907 .37296 m .58924 .37292 L .58924 .3729 L F
.58996 .37288 m .58924 .37292 L .58926 .37997 L .66 .415 .539 r
F
.57805 .36739 m .57125 .36952 L .57753 .36956 L .675 .735 .895 r
F
.58411 .37135 m .57754 .37241 L .58385 .37244 L F
.58411 .37135 m .57806 .37023 L .57754 .37241 L F
.57941 .3682 m .57201 .3691 L .57806 .37023 L F
.58598 .37306 m .57432 .36801 L .58244 .37321 L .654 .726 .902 r
F
.57366 .36895 m .57403 .36606 L .57201 .3691 L .116 .008 .443 r
F
.57432 .36801 m .56379 .36345 L .57383 .36871 L .654 .726 .902 r
F
.57432 .36801 m .57383 .36871 L .58244 .37321 L F
.5741 .36891 m .57409 .36834 L .57366 .36895 L .116 .008 .443 r
F
.57409 .36834 m .57403 .36606 L .57366 .36895 L F
.58392 .37529 m .57794 .37744 L .58408 .37639 L .675 .735 .895 r
F
.58418 .3742 m .5776 .37526 L .58392 .37529 L F
.58418 .3742 m .57813 .37308 L .5776 .37526 L F
.58485 .37319 m .57948 .37105 L .57813 .37308 L F
.57948 .37105 m .57208 .37195 L .57813 .37308 L F
.57948 .37105 m .5741 .36891 L .57208 .37195 L F
.58156 .36931 m .5741 .36891 L .57948 .37105 L F
.58156 .36931 m .57722 .3663 L .5741 .36891 L F
.58704 .38007 m .57525 .36388 L .56857 .36678 L .654 .726 .902 r
F
.58789 .37714 m .58854 .37746 L .58854 .37762 L .846 .571 .522 r
F
.59066 .37508 m .58747 .37693 L .5884 .37739 L .654 .726 .902 r
F
.58789 .37714 m .58854 .37762 L .5879 .37732 L .846 .571 .522 r
F
.59023 .37533 m .58726 .37724 L .58772 .37808 L .675 .735 .895 r
F
.58886 .37302 m .58813 .3732 L .58815 .38026 L .567 .342 .533 r
F
.58802 .38425 m .58856 .38452 L .58862 .41616 L .846 .571 .522 r
F
.59024 .38237 m .58704 .38422 L .5882 .38445 L .654 .726 .902 r
F
.58874 .38011 m .58815 .38026 L .58821 .41173 L .567 .342 .533 r
F
.58886 .37302 m .58815 .38026 L .58874 .38011 L F
.58753 .38042 m .58833 .38001 L .58704 .38007 L .654 .726 .902 r
F
.58904 .38461 m .58893 .38459 L .58854 .3748 L .751 .49 .538 r
F
.59024 .38237 m .58846 .38018 L .58753 .38042 L .654 .726 .902 r
F
.58813 .3732 m .58794 .38039 L .58815 .38026 L .4 .211 .506 r
F
.58846 .38018 m .58833 .38001 L .58753 .38042 L .654 .726 .902 r
F
.58685 .38128 m .58692 .38116 L .587 .37392 L 0 0 .377 r
F
.587 .37392 m .58692 .38116 L .58702 .38098 L F
.58665 .37614 m .58689 .37658 L .58691 .38343 L .988 .719 .381 r
F
.58677 .38143 m .58685 .38128 L .58692 .37407 L 0 0 .377 r
F
.58682 .37426 m .58648 .38196 L .58677 .38143 L F
.5882 .38445 m .58764 .38475 L .58773 .38493 L .654 .726 .902 r
F
.58694 .38941 m .58704 .39093 L .58974 .38598 L F
.58771 .37704 m .58862 .41616 L .58756 .37697 L .846 .571 .522 r
F
.58546 .3739 m .58598 .37306 L .58244 .37321 L .654 .726 .902 r
F
.58485 .37319 m .57813 .37308 L .58418 .3742 L .675 .735 .895 r
F
.58833 .38001 m .57525 .36388 L .58704 .38007 L .654 .726 .902 r
F
.59023 .37533 m .58485 .37319 L .58418 .3742 L .675 .735 .895 r
F
.58996 .37288 m .58984 .37995 L .59017 .37288 L .66 .415 .539 r
F
.58984 .37995 m .58932 .41139 L .59001 .37994 L F
.58984 .37995 m .59001 .37994 L .59017 .37288 L F
.58984 .37995 m .58926 .37997 L .58932 .41139 L F
.58996 .37288 m .58926 .37997 L .58984 .37995 L F
.58996 .37283 m .58924 .37292 L .58996 .37288 L F
.59046 .37068 m .59089 .37212 L .5905 .37217 L .641 .4 .539 r
F
.5901 .36963 m .58998 .37224 L .59098 .37211 L .675 .735 .895 r
F
.59008 .36582 m .58924 .37008 L .59001 .37001 L .66 .415 .539 r
F
.58931 .37008 m .59035 .36826 L .58871 .3684 L .675 .735 .895 r
F
.59016 .37248 m .59027 .36999 L .58931 .37008 L F
.5901 .36963 m .59123 .36708 L .5902 .36718 L F
.59011 .37 m .59023 .36999 L .5903 .36717 L .66 .415 .539 r
F
.59026 .36717 m .5903 .36717 L .59033 .36581 L F
.59011 .37 m .5903 .36717 L .59026 .36717 L F
.59108 .36779 m .59116 .36594 L .59036 .36582 L .654 .726 .902 r
F
.59043 .36583 m .59033 .36581 L .59033 .36716 L .734 .476 .539 r
F
.59139 .35271 m .59033 .36716 L .59115 .36725 L F
.5902 .36718 m .5919 .36558 L .59028 .36543 L .675 .735 .895 r
F
.59108 .36779 m .59195 .36594 L .59119 .36535 L .654 .726 .902 r
F
.59123 .36708 m .5919 .36558 L .5902 .36718 L .675 .735 .895 r
F
.59027 .36999 m .59035 .36826 L .58931 .37008 L F
.58996 .37288 m .59017 .37288 L .59023 .36999 L .66 .415 .539 r
F
.58996 .37288 m .59023 .36999 L .59011 .37 L F
.58753 .37021 m .58717 .36881 L .58736 .37053 L .675 .735 .895 r
F
.58836 .37027 m .58717 .36881 L .58767 .37075 L F
.58711 .36598 m .58147 .36364 L .58578 .36664 L F
.58711 .36598 m .58413 .36232 L .58147 .36364 L F
.58881 .3674 m .58812 .36762 L .58813 .37043 L .567 .342 .533 r
F
.58871 .3684 m .58417 .36514 L .58717 .36881 L .675 .735 .895 r
F
.58865 .36557 m .58413 .36232 L .58711 .36598 L F
.58871 .3684 m .58725 .36431 L .58417 .36514 L F
.58413 .36232 m .58115 .35867 L .57716 .36065 L F
.5872 .3615 m .58115 .35867 L .58413 .36232 L F
.58689 .37145 m .58695 .37133 L .58699 .36687 L 0 0 .377 r
F
.58736 .37053 m .58717 .36881 L .58583 .36947 L .675 .735 .895 r
F
.58877 .37125 m .58732 .36716 L .58423 .36799 L F
.5872 .3615 m .58575 .35743 L .58115 .35867 L F
.58725 .36431 m .58117 .36146 L .58417 .36514 L F
.58865 .36557 m .5872 .3615 L .58413 .36232 L F
.58725 .36431 m .58579 .36022 L .58117 .36146 L F
.58579 .36022 m .5811 .35861 L .58117 .36146 L .591 .365 .543 r
F
.58579 .36022 m .58573 .35737 L .5811 .35861 L F
.58732 .36716 m .58586 .36307 L .58124 .36431 L .675 .735 .895 r
F
.58586 .36307 m .58117 .36146 L .58123 .36422 L .591 .365 .543 r
F
.58117 .36146 m .5811 .35861 L .57709 .3606 L .495 .292 .533 r
F
.58123 .36422 m .58117 .36146 L .58109 .36428 L F
.58169 .36402 m .57778 .35613 L .57567 .35659 L .654 .726 .902 r
F
.58896 .37299 m .58272 .36358 L .58169 .36402 L F
.58272 .36358 m .57778 .35613 L .58169 .36402 L F
.58109 .36428 m .58117 .36146 L .57716 .36345 L .495 .292 .533 r
F
.58147 .36364 m .57405 .36324 L .5794 .36537 L .675 .735 .895 r
F
.58583 .36947 m .58149 .36646 L .57941 .3682 L F
.57716 .36345 m .57709 .3606 L .57397 .36321 L .356 .186 .508 r
F
.58417 .36514 m .57716 .36345 L .58149 .36646 L .675 .735 .895 r
F
.58117 .36146 m .57709 .3606 L .57716 .36345 L .495 .292 .533 r
F
.5777 .36576 m .57567 .35659 L .56899 .35949 L .654 .726 .902 r
F
.58809 .37323 m .58133 .36418 L .5777 .36576 L F
.58109 .36428 m .57716 .36345 L .57722 .36596 L .495 .292 .533 r
F
.58133 .36418 m .57567 .35659 L .5777 .36576 L .654 .726 .902 r
F
.58124 .36431 m .58109 .36428 L .57722 .3663 L .495 .292 .533 r
F
.58109 .36428 m .57722 .36596 L .57722 .3663 L F
.58124 .36431 m .58123 .36422 L .58109 .36428 L F
.58291 .36386 m .58123 .36422 L .58124 .36431 L .591 .365 .543 r
F
.58586 .36307 m .58123 .36422 L .58291 .36386 L F
.58302 .36384 m .58337 .35494 L .57778 .35613 L .654 .726 .902 r
F
.58732 .36716 m .58124 .36431 L .58423 .36799 L .675 .735 .895 r
F
.58919 .37292 m .58604 .3632 L .58302 .36384 L .654 .726 .902 r
F
.58586 .36307 m .58579 .36022 L .58117 .36146 L .591 .365 .543 r
F
.58604 .3632 m .58337 .35494 L .58302 .36384 L .654 .726 .902 r
F
.58886 .37302 m .58898 .37298 L .58923 .36586 L .567 .342 .533 r
F
.59035 .36826 m .58725 .36431 L .58871 .3684 L .675 .735 .895 r
F
.5906 .36689 m .58586 .36307 L .58732 .36716 L F
.58987 .37289 m .58337 .35494 L .58919 .37292 L .654 .726 .902 r
F
.58767 .37075 m .58753 .37021 L .58736 .37053 L .675 .735 .895 r
F
.59066 .37508 m .57778 .35613 L .58896 .37299 L .654 .726 .902 r
F
.59034 .3728 m .59041 .37111 L .58936 .37289 L .675 .735 .895 r
F
.58931 .37008 m .5893 .37006 L .58924 .37008 L F
.5893 .37006 m .58871 .3684 L .58842 .37034 L F
.587 .3735 m .58598 .37306 L .58546 .3739 L .654 .726 .902 r
F
.59034 .37287 m .58932 .41139 L .59042 .4113 L .66 .415 .539 r
F
.5901 .36963 m .59142 .36728 L .59116 .36725 L .675 .735 .895 r
F
.59115 .36725 m .59033 .36716 L .59034 .36998 L .734 .476 .539 r
F
.5901 .36963 m .59098 .37211 L .592 .37196 L .675 .735 .895 r
F
.59016 .37248 m .59132 .36989 L .59027 .36999 L F
.59108 .38492 m .58934 .40275 L .59116 .3849 L .654 .726 .902 r
F
.59037 .37774 m .59063 .38478 L .59012 .37777 L .641 .4 .539 r
F
.59063 .38478 m .59179 .41622 L .59043 .3848 L F
.59063 .38478 m .59043 .3848 L .59012 .37777 L F
.59016 .37248 m .59103 .37492 L .59198 .3747 L .675 .735 .895 r
F
.5911 .37006 m .59034 .3728 L .59089 .37286 L .734 .476 .539 r
F
.59034 .3728 m .59204 .37127 L .59041 .37111 L .675 .735 .895 r
F
.59023 .37533 m .59131 .3729 L .59034 .3728 L F
.59794 .3825 m .60742 .38327 L .60913 .38269 L .654 .726 .902 r
F
.5958 .38171 m .60913 .38269 L .59947 .38127 L F
.59349 .3742 m .59332 .38112 L .59357 .37426 L .911 .629 .497 r
F
.5911 .37006 m .59128 .37008 L .59142 .36597 L .734 .476 .539 r
F
.59132 .36989 m .59197 .36841 L .59028 .36998 L .675 .735 .895 r
F
.59033 .36581 m .59023 .36999 L .59034 .36998 L .66 .415 .539 r
F
.59034 .36998 m .59028 .36998 L .59027 .36999 L .675 .735 .895 r
F
.59115 .36725 m .59034 .36998 L .5911 .37006 L .734 .476 .539 r
F
.59132 .36989 m .59028 .36998 L .59034 .36998 L .675 .735 .895 r
F
.5901 .36963 m .59205 .36749 L .59142 .36728 L F
.59117 .36594 m .5911 .37006 L .59142 .36597 L .734 .476 .539 r
F
.59016 .37248 m .59212 .37033 L .59142 .3701 L .675 .735 .895 r
F
.59023 .37533 m .59108 .37773 L .59192 .37761 L F
.59094 .38001 m .59111 .38004 L .59142 .36597 L .734 .476 .539 r
F
.59123 .37008 m .59142 .3701 L .59125 .37004 L .675 .735 .895 r
F
.59016 .37248 m .59142 .3701 L .59123 .37008 L F
.59142 .3701 m .59126 .373 L .59143 .37303 L .734 .476 .539 r
F
.59142 .36597 m .59133 .37009 L .59142 .3701 L F
.59133 .37009 m .59126 .373 L .59142 .3701 L F
.59023 .37533 m .59235 .37301 L .59131 .3729 L .675 .735 .895 r
F
.59214 .37315 m .59143 .37303 L .59213 .37329 L .81 .54 .53 r
F
.59218 .37035 m .59146 .37292 L .59214 .37315 L F
.59146 .37292 m .59143 .37303 L .59214 .37315 L F
.59132 .37288 m .59355 .3717 L .59204 .37127 L .675 .735 .895 r
F
.59131 .3729 m .59134 .37288 L .59132 .37288 L F
.59134 .37288 m .59355 .3717 L .59132 .37288 L F
.59235 .37301 m .59355 .3717 L .59131 .3729 L F
.5911 .37006 m .59105 .37287 L .59128 .37008 L .734 .476 .539 r
F
.59105 .37287 m .59094 .38001 L .59118 .37289 L F
.59105 .37287 m .59118 .37289 L .59128 .37008 L F
.59059 .37498 m .59173 .38468 L .59087 .38476 L .641 .4 .539 r
F
.59332 .38112 m .59339 .38117 L .59357 .37426 L .911 .629 .497 r
F
.59207 .37749 m .59274 .37724 L .59276 .38429 L .516 .301 .527 r
F
.59207 .37748 m .59274 .37724 L .59207 .37749 L F
.59202 .3803 m .59232 .38041 L .5925 .37343 L .81 .54 .53 r
F
.59357 .37426 m .59339 .38117 L .59358 .38132 L .911 .629 .497 r
F
.59325 .37103 m .5932 .37397 L .59356 .37127 L F
.59621 .36858 m .60232 .36753 L .60116 .3655 L .675 .735 .895 r
F
.59638 .36967 m .60232 .36753 L .59621 .36858 L F
.59572 .3704 m .59935 .36657 L .59476 .36952 L F
.59572 .3704 m .60128 .36832 L .59935 .36657 L F
.59942 .36942 m .60018 .36442 L .59686 .36806 L F
.59252 .37319 m .60723 .35824 L .5918 .37288 L .654 .726 .902 r
F
.59213 .37313 m .5918 .37288 L .59161 .37306 L F
.59252 .37319 m .5918 .37288 L .59213 .37313 L F
.59066 .37508 m .59542 .37451 L .59406 .37401 L F
.5932 .37397 m .59309 .38093 L .59349 .3742 L .911 .629 .497 r
F
.59621 .37361 m .60279 .37255 L .59648 .37252 L .675 .735 .895 r
F
.6091 .37259 m .60853 .36646 L .6086 .36931 L .848 .651 .11 r
F
.60831 .37586 m .60903 .36974 L .6091 .37259 L 0 0 .259 r
F
.60279 .37255 m .6091 .37259 L .6086 .36931 L .675 .735 .895 r
F
.60917 .37544 m .6091 .37259 L .6086 .36931 L .848 .651 .11 r
F
.60213 .37187 m .60894 .36974 L .60266 .3697 L .675 .735 .895 r
F
.60279 .37255 m .6086 .36931 L .60245 .37037 L F
.60917 .37544 m .6086 .36931 L .60867 .37216 L .848 .651 .11 r
F
.59638 .37427 m .60135 .37118 L .59579 .37325 L .675 .735 .895 r
F
.59544 .37176 m .60213 .37187 L .59611 .37075 L F
.59648 .37252 m .60279 .37255 L .60245 .37037 L F
.59638 .37427 m .60252 .37322 L .60135 .37118 L F
.60252 .37322 m .60691 .3691 L .60135 .37118 L F
.60252 .37322 m .60867 .37216 L .60691 .3691 L F
.59406 .37401 m .62137 .3714 L .61844 .36631 L .654 .726 .902 r
F
.59408 .37467 m .59638 .37427 L .5942 .37385 L .675 .735 .895 r
F
.60831 .37586 m .60824 .37301 L .60903 .36974 L 0 0 .259 r
F
.60226 .37473 m .6091 .37259 L .60279 .37255 L .675 .735 .895 r
F
.59621 .37361 m .60226 .37473 L .60279 .37255 L F
.60079 .37389 m .60613 .37602 L .60815 .37299 L F
.60286 .3754 m .60867 .37216 L .60252 .37322 L F
.59542 .37451 m .62137 .3714 L .59406 .37401 L .654 .726 .902 r
F
.59371 .37161 m .59356 .37127 L .59357 .37426 L .983 .725 .333 r
F
.59611 .37075 m .60266 .3697 L .59638 .36967 L .675 .735 .895 r
F
.60232 .36753 m .60669 .36343 L .60116 .3655 L F
.60232 .36753 m .60844 .36648 L .60669 .36343 L F
.59631 .37142 m .60128 .36832 L .59572 .3704 L F
.60116 .3655 m .60669 .36343 L .60381 .3608 L F
.60128 .36832 m .60395 .36361 L .59935 .36657 L F
.60128 .36832 m .60684 .36625 L .60395 .36361 L F
.60684 .36625 m .60678 .3634 L .60388 .36076 L .935 .65 .478 r
F
.59398 .3725 m .59648 .37252 L .59408 .37181 L .675 .735 .895 r
F
.59483 .37237 m .59686 .36806 L .59355 .3717 L F
.59483 .37237 m .59942 .36942 L .59686 .36806 L F
.60684 .36625 m .60388 .36076 L .60395 .36361 L .935 .65 .478 r
F
.59942 .36942 m .60402 .36646 L .60018 .36442 L .675 .735 .895 r
F
.60691 .3691 m .60395 .36361 L .60402 .36646 L .935 .65 .478 r
F
.59935 .36657 m .60395 .36361 L .60011 .36157 L .675 .735 .895 r
F
.60402 .36646 m .60395 .36361 L .60011 .36157 L .862 .585 .517 r
F
.60402 .36646 m .60011 .36157 L .60018 .36442 L F
.59238 .37333 m .61362 .36182 L .60723 .35824 L .654 .726 .902 r
F
.5932 .37397 m .59349 .3742 L .59356 .37127 L .911 .629 .497 r
F
.59356 .37127 m .59349 .3742 L .59357 .37426 L F
.59251 .37328 m .5925 .37343 L .59251 .37343 L .81 .54 .53 r
F
.59638 .36967 m .60266 .3697 L .60232 .36753 L .675 .735 .895 r
F
.59631 .37142 m .60245 .37037 L .60128 .36832 L F
.59611 .37075 m .60213 .37187 L .60266 .3697 L F
.59648 .37252 m .60245 .37037 L .59631 .37142 L F
.59579 .37325 m .60135 .37118 L .59942 .36942 L F
.59294 .37377 m .61362 .36182 L .59238 .37333 L .654 .726 .902 r
F
.59438 .37266 m .59579 .37325 L .59483 .37237 L .675 .735 .895 r
F
.5942 .37385 m .59579 .37325 L .59438 .37266 L F
.60266 .3697 m .60844 .36648 L .60232 .36753 L F
.60245 .37037 m .60684 .36625 L .60128 .36832 L F
.6086 .36931 m .60678 .3634 L .60684 .36625 L .986 .71 .376 r
F
.59579 .37325 m .59942 .36942 L .59483 .37237 L .675 .735 .895 r
F
.60135 .37118 m .60402 .36646 L .59942 .36942 L F
.60691 .3691 m .60684 .36625 L .60395 .36361 L .935 .65 .478 r
F
.59313 .37366 m .59941 .37232 L .61362 .36182 L .654 .726 .902 r
F
.59386 .37476 m .59386 .37477 L .59392 .3721 L .983 .725 .333 r
F
.59357 .37408 m .5942 .37385 L .59326 .37338 L .675 .735 .895 r
F
.59406 .37401 m .59941 .37232 L .59313 .37366 L .654 .726 .902 r
F
.59173 .38468 m .59209 .38579 L .59209 .38465 L F
.59209 .38579 m .59233 .38544 L .59209 .38465 L F
.59221 .3845 m .59282 .41578 L .59192 .38461 L .516 .301 .527 r
F
.59173 .38468 m .59282 .41578 L .59179 .41622 L F
.59192 .38461 m .59282 .41578 L .59173 .38468 L F
.60226 .37473 m .60831 .37586 L .6091 .37259 L .675 .735 .895 r
F
.60286 .3754 m .60917 .37544 L .60867 .37216 L F
.59554 .37462 m .60226 .37473 L .59621 .37361 L F
.59654 .37537 m .60286 .3754 L .60252 .37322 L F
.59654 .37537 m .60252 .37322 L .59638 .37427 L F
.59409 .37467 m .6222 .37673 L .62137 .3714 L .654 .726 .902 r
F
.59386 .37476 m .59386 .37493 L .59386 .37477 L .983 .725 .333 r
F
.59066 .37508 m .5949 .3753 L .59409 .37467 L .654 .726 .902 r
F
.5949 .3753 m .6222 .37673 L .59409 .37467 L F
.5932 .37381 m .59251 .37328 L .59251 .37343 L .911 .629 .497 r
F
.59023 .37533 m .59357 .37408 L .59326 .37338 L .675 .735 .895 r
F
.59066 .37508 m .59406 .37401 L .59313 .37366 L .654 .726 .902 r
F
.59309 .38405 m .59298 .38413 L .59285 .37715 L .356 .178 .497 r
F
.59309 .38405 m .59285 .37715 L .59291 .37711 L F
.59285 .37715 m .59298 .38413 L .59274 .37724 L F
.59298 .38413 m .59289 .3842 L .59274 .37724 L F
.59274 .37724 m .59289 .3842 L .59276 .38429 L F
.59066 .37508 m .59381 .37645 L .59393 .37583 L .654 .726 .902 r
F
.59221 .3845 m .59276 .38429 L .59282 .41578 L .516 .301 .527 r
F
.59066 .37508 m .59351 .37859 L .59371 .37727 L .654 .726 .902 r
F
.5932 .37381 m .59251 .37343 L .5932 .37397 L .911 .629 .497 r
F
.59214 .37315 m .59213 .37329 L .59251 .37328 L .81 .54 .53 r
F
.59066 .37508 m .59252 .37319 L .59161 .37306 L .654 .726 .902 r
F
.59213 .37329 m .59143 .37303 L .59144 .38009 L .81 .54 .53 r
F
.59131 .3729 m .59204 .37127 L .59034 .3728 L .675 .735 .895 r
F
.59108 .37773 m .59005 .37955 L .59169 .37941 L F
.59067 .37772 m .59067 .37778 L .59037 .37774 L .641 .4 .539 r
F
.59067 .37778 m .59037 .37783 L .59037 .37774 L F
.59023 .37533 m .59012 .37786 L .59108 .37773 L .675 .735 .895 r
F
.59012 .37786 m .59005 .37955 L .59108 .37773 L F
.59067 .37778 m .59087 .38476 L .59037 .37783 L .641 .4 .539 r
F
.5911 .37006 m .59035 .37993 L .59094 .38001 L .734 .476 .539 r
F
.59027 .36997 m .59197 .36841 L .59035 .36826 L .675 .735 .895 r
F
.59028 .36998 m .59197 .36841 L .59027 .36997 L F
.59116 .36725 m .59142 .36728 L .59118 .3672 L F
.59159 .36734 m .59199 .36747 L .59225 .36628 L .81 .54 .53 r
F
.59205 .36749 m .59339 .36601 L .59118 .3672 L .675 .735 .895 r
F
.59159 .36734 m .59142 .3701 L .59199 .36747 L .81 .54 .53 r
F
.59125 .37004 m .59166 .36982 L .59143 .36964 L .675 .735 .895 r
F
.59166 .36982 m .59348 .36885 L .59143 .36964 L F
.59212 .37033 m .59348 .36885 L .59125 .37004 L F
.59212 .37033 m .59227 .37028 L .59221 .37024 L F
.59227 .37028 m .59304 .37005 L .59221 .37024 L F
.59346 .36837 m .59356 .36845 L .59351 .36835 L F
.59228 .37039 m .59214 .37315 L .5925 .37046 L .81 .54 .53 r
F
.59355 .3717 m .59386 .3672 L .59204 .37127 L .675 .735 .895 r
F
.59329 .36825 m .59346 .36838 L .59355 .36721 L .911 .629 .497 r
F
.59346 .36837 m .59563 .36756 L .59281 .36788 L .675 .735 .895 r
F
.59353 .35393 m .59249 .36638 L .59286 .36666 L .911 .629 .497 r
F
.59397 .35498 m .59355 .36721 L .5939 .368 L .983 .725 .333 r
F
.59467 .36669 m .5967 .3624 L .59339 .36601 L .675 .735 .895 r
F
.59195 .36594 m .60756 .35103 L .60008 .3486 L .654 .726 .902 r
F
.59339 .36601 m .5937 .36154 L .5919 .36558 L .675 .735 .895 r
F
.59339 .36601 m .5967 .3624 L .5937 .36154 L F
.59139 .35271 m .59117 .36594 L .59142 .36597 L .734 .476 .539 r
F
.59195 .36594 m .60008 .3486 L .59119 .36535 L .654 .726 .902 r
F
.59119 .36535 m .60008 .3486 L .59198 .34749 L F
.5919 .36558 m .5937 .36154 L .59046 .36123 L .675 .735 .895 r
F
.59348 .36885 m .59379 .36435 L .59197 .36841 L F
.59348 .36885 m .5968 .36521 L .59379 .36435 L F
.59116 .36594 m .59198 .34749 L .59036 .36582 L .654 .726 .902 r
F
.5919 .36558 m .59046 .36123 L .59028 .36543 L .675 .735 .895 r
F
.59197 .36841 m .59379 .36435 L .59053 .36404 L F
.5967 .3624 m .59551 .35749 L .5937 .36154 L F
.5967 .3624 m .6 .35878 L .59551 .35749 L F
.5911 .37006 m .59034 .36998 L .59034 .3728 L .734 .476 .539 r
F
.59204 .37127 m .5906 .36689 L .59041 .37111 L .675 .735 .895 r
F
.59204 .37127 m .59386 .3672 L .5906 .36689 L F
.59047 .36465 m .59198 .34749 L .59004 .36493 L .654 .726 .902 r
F
.5937 .36154 m .59065 .35703 L .59046 .36123 L .675 .735 .895 r
F
.5937 .36154 m .59551 .35749 L .59065 .35703 L F
.5968 .36521 m .5956 .36028 L .59379 .36435 L F
.59379 .36435 m .59072 .35982 L .59053 .36404 L F
.59379 .36435 m .5956 .36028 L .59072 .35982 L F
.59197 .36841 m .59053 .36404 L .59035 .36826 L F
.59386 .3672 m .59078 .36267 L .5906 .36689 L F
.59386 .3672 m .59567 .36313 L .59078 .36267 L F
.5956 .36028 m .59553 .35743 L .59065 .35697 L .731 .476 .543 r
F
.60011 .36157 m .59553 .35743 L .5956 .36028 L .795 .528 .535 r
F
.5956 .36028 m .59065 .35697 L .59072 .35982 L .731 .476 .543 r
F
.59567 .36313 m .5956 .36028 L .59072 .35982 L F
.59567 .36313 m .59072 .35982 L .59078 .36267 L F
.59066 .37508 m .59971 .3558 L .59157 .35468 L .654 .726 .902 r
F
.59355 .3717 m .59686 .36806 L .59386 .3672 L .675 .735 .895 r
F
.59686 .36806 m .59567 .36313 L .59386 .3672 L F
.59935 .36657 m .60011 .36157 L .5968 .36521 L F
.59686 .36806 m .60018 .36442 L .59567 .36313 L F
.5904 .37882 m .59929 .36309 L .59115 .36197 L .654 .726 .902 r
F
.59024 .38237 m .5915 .37969 L .5904 .37882 L F
.5932 .37397 m .59251 .37343 L .59252 .38049 L .911 .629 .497 r
F
.59143 .37303 m .59124 .38006 L .59144 .38009 L .734 .476 .539 r
F
.59213 .37329 m .59202 .3803 L .5925 .37343 L .81 .54 .53 r
F
.59213 .37329 m .59144 .38009 L .59202 .3803 L F
.5915 .37969 m .59929 .36309 L .5904 .37882 L .654 .726 .902 r
F
.59309 .38093 m .59252 .38049 L .59258 .41181 L .911 .629 .497 r
F
.5932 .37397 m .59252 .38049 L .59309 .38093 L F
.59365 .38041 m .61803 .3736 L .6132 .36912 L .654 .726 .902 r
F
.59169 .37941 m .59551 .38286 L .59463 .38152 L .675 .735 .895 r
F
.59396 .38276 m .59394 .38288 L .59391 .37595 L 0 0 .146 r
F
.59361 .37649 m .59391 .38312 L .59367 .38347 L .076 0 .415 r
F
.59394 .38288 m .59393 .38298 L .59389 .37607 L 0 0 .146 r
F
.59024 .38237 m .59557 .38069 L .59365 .38041 L .654 .726 .902 r
F
.59557 .38069 m .61803 .3736 L .59365 .38041 L F
.59087 .38476 m .59179 .41622 L .59063 .38478 L .641 .4 .539 r
F
.59012 .37777 m .59179 .41622 L .59019 .41643 L F
.59386 .37493 m .59358 .38132 L .59382 .38187 L .983 .725 .333 r
F
.6086 .36931 m .60853 .36646 L .60678 .3634 L .986 .71 .376 r
F
.60245 .37037 m .6086 .36931 L .60684 .36625 L .675 .735 .895 r
F
.60867 .37216 m .6086 .36931 L .60684 .36625 L .986 .71 .376 r
F
.60867 .37216 m .60684 .36625 L .60691 .3691 L F
.60135 .37118 m .60691 .3691 L .60402 .36646 L .675 .735 .895 r
F
.59236 .38022 m .6132 .36912 L .60681 .36553 L .654 .726 .902 r
F
.59024 .38237 m .59365 .38041 L .59236 .38022 L F
.59382 .38187 m .59395 .38216 L .59401 .37529 L .983 .725 .333 r
F
.59395 .37567 m .59401 .37529 L .59403 .38234 L 0 0 .146 r
F
.59401 .37529 m .59395 .38216 L .59403 .38234 L .983 .725 .333 r
F
.59371 .37727 m .59659 .38121 L .59541 .3785 L .654 .726 .902 r
F
.59365 .38041 m .6132 .36912 L .59236 .38022 L F
.59126 .373 m .59111 .38004 L .59143 .37303 L .734 .476 .539 r
F
.59111 .38004 m .59042 .4113 L .59124 .38006 L F
.59111 .38004 m .59124 .38006 L .59143 .37303 L F
.59144 .38009 m .59042 .4113 L .59151 .41143 L F
.59024 .38237 m .59228 .3803 L .5915 .37969 L .654 .726 .902 r
F
.59024 .38237 m .5911 .38474 L .59209 .38465 L F
.59124 .38006 m .59042 .4113 L .59144 .38009 L .734 .476 .539 r
F
.59252 .38049 m .59151 .41143 L .59258 .41181 L .81 .54 .53 r
F
.59251 .37343 m .59232 .38041 L .59252 .38049 L F
.59232 .38041 m .59151 .41143 L .59252 .38049 L F
.59422 .38112 m .59947 .38127 L .59557 .38069 L .654 .726 .902 r
F
.59024 .38237 m .5958 .38171 L .59422 .38112 L F
.5958 .38171 m .59947 .38127 L .59422 .38112 L F
.5925 .37343 m .59151 .41143 L .59251 .37343 L .81 .54 .53 r
F
.59401 .37515 m .59401 .37529 L .59395 .37553 L 0 0 .146 r
F
.59386 .37493 m .59357 .37426 L .59358 .38132 L .983 .725 .333 r
F
.5915 .37969 m .60681 .36553 L .59929 .36309 L .654 .726 .902 r
F
.59309 .38093 m .59332 .38112 L .59349 .3742 L .911 .629 .497 r
F
.59228 .3803 m .60681 .36553 L .5915 .37969 L .654 .726 .902 r
F
.59024 .38237 m .59503 .38246 L .59431 .38189 L F
.59024 .38237 m .59415 .38326 L .59502 .38262 L F
.59309 .38093 m .59258 .41181 L .59332 .38112 L .911 .629 .497 r
F
.59094 .38001 m .59042 .4113 L .59111 .38004 L .734 .476 .539 r
F
.59557 .38069 m .62096 .37869 L .61803 .3736 L .654 .726 .902 r
F
.59947 .38127 m .62096 .37869 L .59557 .38069 L F
.59332 .38112 m .59258 .41181 L .59339 .38117 L .911 .629 .497 r
F
.59431 .38189 m .59794 .3825 L .5958 .38171 L .654 .726 .902 r
F
.59503 .38246 m .59794 .3825 L .59431 .38189 L F
.59794 .3825 m .60913 .38269 L .5958 .38171 L F
.59024 .38237 m .59283 .38424 L .59347 .38377 L F
.59202 .3803 m .59151 .41143 L .59232 .38041 L .81 .54 .53 r
F
.59358 .38132 m .59258 .41181 L .59364 .41264 L .911 .629 .497 r
F
.59024 .38237 m .59526 .38264 L .59503 .38246 L .654 .726 .902 r
F
.59339 .38117 m .59258 .41181 L .59358 .38132 L .911 .629 .497 r
F
.59503 .38246 m .59879 .38282 L .59794 .3825 L .654 .726 .902 r
F
.59526 .38264 m .59879 .38282 L .59503 .38246 L F
.59879 .38282 m .60742 .38327 L .59794 .3825 L F
.59202 .3803 m .59144 .38009 L .59151 .41143 L .81 .54 .53 r
F
.59089 .37286 m .59034 .3728 L .59035 .37993 L .734 .476 .539 r
F
.59087 .3841 m .59086 .38476 L .5911 .38474 L .654 .726 .902 r
F
.59024 .38237 m .59086 .38476 L .59087 .3841 L F
.59024 .38237 m .59014 .38482 L .59086 .38476 L F
.59094 .38001 m .59035 .37993 L .59042 .4113 L .734 .476 .539 r
F
.59947 .38127 m .60913 .38269 L .62096 .37869 L .654 .726 .902 r
F
.61262 .3833 m .64449 .39091 L .61779 .37936 L F
.60742 .38327 m .62179 .38402 L .62148 .38201 L F
.60742 .38327 m .62148 .38201 L .62096 .37869 L F
.59027 .36999 m .59028 .36998 L .59027 .36997 L .675 .735 .895 r
F
.59034 .36998 m .59017 .37288 L .59034 .37287 L .66 .415 .539 r
F
.59023 .36999 m .59017 .37288 L .59034 .36998 L F
.59017 .37288 m .58932 .41139 L .59034 .37287 L F
.5903 .35258 m .59008 .36582 L .59033 .36581 L F
.58774 .37353 m .58796 .37337 L .58796 .37332 L .4 .211 .506 r
F
.58774 .37353 m .58796 .37332 L .58775 .37345 L F
.5903 .35258 m .58923 .36586 L .59008 .36582 L .66 .415 .539 r
F
.58886 .37302 m .58874 .38011 L .58898 .37298 L .567 .342 .533 r
F
.58479 .38114 m .56337 .37075 L .56 .3755 L .654 .726 .902 r
F
.58467 .37741 m .57911 .37948 L .58104 .38124 L .675 .735 .895 r
F
.58641 .38071 m .56337 .37075 L .58479 .38114 L .654 .726 .902 r
F
.58874 .38011 m .58821 .41173 L .58891 .38006 L .567 .342 .533 r
F
.58879 .37766 m .58904 .38461 L .58869 .37764 L .751 .49 .538 r
F
.58874 .38011 m .58891 .38006 L .58923 .36586 L .567 .342 .533 r
F
.58762 .3806 m .58708 .41252 L .5878 .38048 L .4 .211 .506 r
F
.58762 .3806 m .5878 .38048 L .58796 .37337 L F
.58524 .38211 m .58479 .38114 L .58174 .38193 L .654 .726 .902 r
F
.58625 .38147 m .58479 .38114 L .58524 .38211 L F
.57794 .37744 m .57355 .38156 L .57911 .37948 L .675 .735 .895 r
F
.57794 .37744 m .57179 .3785 L .57355 .38156 L F
.58479 .38114 m .56 .3755 L .58174 .38193 L .654 .726 .902 r
F
.58926 .37997 m .58821 .41173 L .58932 .41139 L .567 .342 .533 r
F
.58891 .38006 m .58821 .41173 L .58926 .37997 L F
.58685 .38128 m .58654 .41356 L .58692 .38116 L 0 0 .377 r
F
.5892 .35267 m .58898 .36593 L .58923 .36586 L .567 .342 .533 r
F
.58796 .37332 m .5878 .38048 L .58813 .3732 L .4 .211 .506 r
F
.5878 .38048 m .58708 .41252 L .58794 .38039 L F
.5878 .38048 m .58794 .38039 L .58813 .3732 L F
.58524 .38211 m .58354 .38202 L .58457 .38254 L .654 .726 .902 r
F
.58524 .38211 m .58457 .38254 L .58541 .38295 L F
.57911 .37948 m .57355 .38156 L .57645 .3842 L .675 .735 .895 r
F
.58354 .38202 m .5587 .38072 L .58541 .38295 L .654 .726 .902 r
F
.58626 .38285 m .58357 .38317 L .58639 .38296 L F
.5854 .3839 m .58312 .38346 L .57951 .38576 L F
.58104 .38124 m .57645 .3842 L .58029 .38623 L .675 .735 .895 r
F
.58357 .38317 m .55954 .38606 L .57951 .38576 L .654 .726 .902 r
F
.58802 .38425 m .58862 .41616 L .58787 .38418 L .846 .571 .522 r
F
.58815 .38026 m .58708 .41252 L .58821 .41173 L .4 .211 .506 r
F
.58794 .38039 m .58708 .41252 L .58815 .38026 L F
.5867 .38306 m .58691 .38343 L .58697 .41509 L .988 .719 .381 r
F
.58674 .39259 m .58697 .41509 L .58658 .40943 L F
.58658 .40943 m .58697 .41509 L .58659 .41438 L F
.58702 .38098 m .58654 .41356 L .58708 .41252 L 0 0 .377 r
F
.58692 .38116 m .58654 .41356 L .58702 .38098 L F
.58117 .3916 m .5737 .3992 L .58051 .39279 L .654 .726 .902 r
F
.5865 .38232 m .58659 .41438 L .5865 .3822 L .777 .62 .057 r
F
.5865 .3822 m .58659 .41438 L .58649 .3821 L F
.58694 .38941 m .5737 .3992 L .58121 .40163 L .654 .726 .902 r
F
.58679 .38696 m .5737 .3992 L .58694 .38941 L F
.58653 .38274 m .58674 .39259 L .58658 .40943 L .988 .719 .381 r
F
.58661 .3829 m .58674 .39259 L .58653 .38274 L F
.58704 .38422 m .58439 .38576 L .58758 .38466 L .654 .726 .902 r
F
.58018 .38631 m .57412 .39191 L .57665 .39273 L F
.58018 .38631 m .57665 .39273 L .58163 .39434 L F
.58439 .38576 m .56731 .39562 L .58382 .38679 L F
.58439 .38576 m .58382 .38679 L .5882 .38445 L F
.58682 .37426 m .58677 .38143 L .58692 .37407 L 0 0 .377 r
F
.58677 .38143 m .58654 .41356 L .58685 .38128 L F
.58773 .38493 m .58382 .38679 L .58117 .3916 L .654 .726 .902 r
F
.58764 .38475 m .58382 .38679 L .58773 .38493 L F
.58682 .37426 m .58647 .3749 L .58648 .38196 L 0 0 .377 r
F
.58648 .38196 m .58659 .41438 L .58654 .41356 L .777 .62 .057 r
F
.58649 .3821 m .58659 .41438 L .58648 .38196 L F
.5865 .38232 m .58653 .38274 L .58659 .41438 L F
.58677 .38143 m .58648 .38196 L .58654 .41356 L 0 0 .377 r
F
.58117 .3916 m .56731 .39562 L .5737 .3992 L .654 .726 .902 r
F
.58382 .38679 m .56731 .39562 L .58117 .3916 L F
.58694 .38941 m .58121 .40163 L .58704 .39093 L F
.59004 .36493 m .59198 .34749 L .58382 .34775 L F
.59036 .36582 m .59047 .36465 L .59004 .36493 L F
.60395 .36361 m .60388 .36076 L .60005 .35872 L .862 .585 .517 r
F
.5968 .36521 m .60011 .36157 L .5956 .36028 L .675 .735 .895 r
F
.60395 .36361 m .60005 .35872 L .60011 .36157 L .862 .585 .517 r
F
.60011 .36157 m .60005 .35872 L .59553 .35743 L .795 .528 .535 r
F
.60018 .36442 m .60011 .36157 L .5956 .36028 L F
.60018 .36442 m .5956 .36028 L .59567 .36313 L F
.59161 .37306 m .60723 .35824 L .59971 .3558 L .654 .726 .902 r
F
.59941 .37232 m .61844 .36631 L .61363 .36184 L F
.59941 .37232 m .61363 .36184 L .61362 .36182 L F
.59502 .38262 m .59499 .38345 L .59692 .38272 L F
.59415 .38326 m .59499 .38345 L .59502 .38262 L F
.59499 .38345 m .62048 .38924 L .59692 .38272 L F
.59382 .38187 m .59364 .41264 L .59395 .38216 L .983 .725 .333 r
F
.59305 .38439 m .59577 .38635 L .59347 .38377 L .654 .726 .902 r
F
.59577 .38635 m .6119 .39795 L .59524 .38514 L F
.59577 .38635 m .59524 .38514 L .59347 .38377 L F
.59361 .38357 m .59397 .41452 L .59358 .38361 L .076 0 .415 r
F
.59396 .38276 m .59409 .4137 L .59394 .38288 L 0 0 .146 r
F
.59379 .38391 m .6119 .39795 L .6171 .39399 L .654 .726 .902 r
F
.59347 .38377 m .59377 .384 L .59379 .38391 L F
.59377 .384 m .6119 .39795 L .59379 .38391 L F
.59367 .38347 m .59397 .41452 L .59361 .38357 L .076 0 .415 r
F
.59396 .38276 m .59403 .38234 L .59409 .4137 L 0 0 .146 r
F
.59358 .38361 m .59397 .41452 L .59355 .38365 L .076 0 .415 r
F
.59347 .38377 m .59397 .41452 L .59353 .41521 L F
.59355 .38365 m .59397 .41452 L .59347 .38377 L F
.59382 .38187 m .59358 .38132 L .59364 .41264 L .983 .725 .333 r
F
.59577 .38635 m .60522 .40085 L .6119 .39795 L .654 .726 .902 r
F
.59305 .38439 m .5976 .39054 L .59577 .38635 L F
.5976 .39054 m .60522 .40085 L .59577 .38635 L F
.59209 .38579 m .59753 .40248 L .59233 .38544 L F
.59342 .38629 m .60235 .40146 L .59844 .39249 L F
.59394 .38288 m .59409 .4137 L .59393 .38298 L 0 0 .146 r
F
.59391 .38312 m .59409 .4137 L .59397 .41452 L F
.59393 .38298 m .59409 .4137 L .59391 .38312 L F
.59403 .38234 m .59364 .41264 L .59409 .4137 L .983 .725 .333 r
F
.59395 .38216 m .59364 .41264 L .59403 .38234 L F
.59314 .3881 m .59753 .40248 L .59342 .38629 L .654 .726 .902 r
F
.235 .63366 m .215 .63452 L .23302 .63648 L .683 .77 .917 r
F
.21529 .63908 m .19492 .64601 L .21379 .64501 L F
.23341 .64105 m .21529 .63908 L .21379 .64501 L F
.64449 .39091 m .68126 .3883 L .65121 .38147 L .654 .726 .902 r
F
.61779 .37936 m .64449 .39091 L .65121 .38147 L F
.64327 .63434 m .63524 .64743 L .649 .63871 L .683 .77 .917 r
F
.64327 .63434 m .62663 .64087 L .63524 .64743 L F
0 g
.63524 .64743 m
.64665 .65221 L
s
.25199 .64759 m .23388 .64562 L .23312 .64859 L .683 .77 .917 r
F
.25199 .64759 m .24753 .6369 L .24294 .63828 L F
.26985 .63912 m .28464 .62995 L .26807 .63648 L F
.26985 .63912 m .28819 .63522 L .28464 .62995 L F
.34677 .40353 m .30951 .39983 L .33645 .41144 L .654 .726 .902 r
F
.28753 .63068 m .30049 .61894 L .284 .62544 L .683 .77 .917 r
F
.28753 .63068 m .30578 .62681 L .30049 .61894 L F
.25385 .52526 m .23391 .5215 L .2342 .52718 L .672 .448 .573 r
F
.25385 .52526 m .25355 .51958 L .23391 .5215 L F
0 g
.21549 .52643 m
.23391 .5215 L
s
.34789 .38911 m .32622 .37362 L .31083 .38543 L .654 .726 .902 r
F
.36111 .38335 m .32622 .37362 L .34789 .38911 L F
.39103 .4143 m .39179 .39393 L .37542 .39447 L F
.64134 .51826 m .62417 .50778 L .61172 .51749 L .673 .757 .914 r
F
.65199 .51322 m .62417 .50778 L .64134 .51826 L F
.44562 .41715 m .45879 .39496 L .43593 .4082 L .654 .726 .902 r
F
.44562 .41715 m .47332 .4084 L .45879 .39496 L F
0 g
.39349 .47868 m
.39352 .46488 L
s
.43658 .39375 m .44021 .36989 L .42384 .38663 L .654 .726 .902 r
F
.43658 .39375 m .45932 .38058 L .44021 .36989 L F
0 g
.38687 .50164 m
.38688 .49872 L
s
.38693 .47878 m
.38696 .46476 L
s
.71279 .52255 m .71598 .50432 L .70263 .51785 L .673 .757 .914 r
F
.71279 .52255 m .73123 .51136 L .71598 .50432 L F
.34101 .51399 m .32358 .52938 L .34574 .5213 L F
.34101 .51399 m .31648 .5184 L .32358 .52938 L F
0 g
.32358 .52938 m
.33521 .53869 L
s
.66659 .63159 m .66558 .64368 L .67107 .63248 L .683 .77 .917 r
F
.66659 .63159 m .65662 .6419 L .66558 .64368 L F
.72408 .63111 m .72969 .61803 L .7302 .6226 L .207 .12 .531 r
F
.72459 .63568 m .72408 .63111 L .7302 .6226 L F
.70808 .6263 m .72408 .63111 L .7302 .6226 L .683 .77 .917 r
F
.70182 .63131 m .72408 .63111 L .70808 .6263 L F
0 g
.71829 .63574 m
.72408 .63111 L
s
.4695 .75279 m .47079 .75506 L .47053 .75883 L .927 .752 .27 r
F
.4695 .75279 m .46975 .74902 L .47079 .75506 L F
.48236 .74976 m .47079 .75506 L .48304 .75378 L .645 .732 .913 r
F
.48236 .74976 m .46975 .74902 L .47079 .75506 L F
0 g
.47079 .75506 m
.47294 .75858 L
s
.19764 .64169 m .19492 .64601 L .19539 .65059 L 0 0 .375 r
F
0 g
.19561 .64973 m
.19576 .65057 L
s
.21529 .63908 m .19717 .63711 L .19492 .64601 L .683 .77 .917 r
F
.19764 .64169 m .19717 .63711 L .19492 .64601 L 0 0 .375 r
F
.68837 .61939 m .70118 .62666 L .70741 .62168 L .683 .77 .917 r
F
.74271 .52069 m .73089 .50568 L .73123 .51136 L .934 .657 .492 r
F
.74305 .52637 m .74271 .52069 L .73123 .51136 L F
0 g
.74271 .52069 m
.74962 .53165 L
s
.49505 .75629 m .48515 .76141 L .49623 .75821 L .645 .732 .913 r
F
.49505 .75629 m .48279 .75756 L .48515 .76141 L F
.26752 .63194 m .27822 .62108 L .26463 .62976 L .683 .77 .917 r
F
.26752 .63194 m .284 .62544 L .27822 .62108 L F
.36792 .51323 m .35349 .52752 L .37179 .51634 L .673 .757 .914 r
F
.36792 .51323 m .34574 .5213 L .35349 .52752 L F
.50898 .65021 m .49379 .64757 L .49428 .65215 L .673 .453 .579 r
F
0 g
.48047 .65626 m
.49428 .65215 L
s
.50898 .65021 m .50849 .64563 L .49379 .64757 L .673 .453 .579 r
F
0 g
.47998 .65168 m
.49379 .64757 L
s
.127 .923 .03 r
.50559 .71627 m
.50568 .64606 L
s
.50568 .64606 m
.50568 .64175 L
s
.23388 .64562 m .21426 .64959 L .23312 .64859 L .683 .77 .917 r
F
.27337 .52647 m .25355 .51958 L .25385 .52526 L .733 .496 .569 r
F
0 g
.23391 .5215 m
.25355 .51958 L
s
.25355 .51958 m
.27307 .52079 L
s
.54382 .75935 m .54563 .74968 L .54538 .75346 L 0 0 .146 r
F
.54357 .76312 m .54382 .75935 L .54538 .75346 L F
.53174 .75664 m .54382 .75935 L .54538 .75346 L .645 .732 .913 r
F
0 g
.54085 .76328 m
.54382 .75935 L
s
.49528 .74673 m .48342 .75 L .49562 .74873 L .645 .732 .913 r
F
.49528 .74673 m .48274 .74599 L .48342 .75 L F
.5288 .76397 m .54357 .76312 L .53149 .76042 L F
.51806 .75949 m .5288 .76397 L .53149 .76042 L F
.51599 .76097 m .5288 .76397 L .51806 .75949 L F
.53186 .75284 m .54544 .74967 L .5329 .74893 L F
.51984 .75015 m .53186 .75284 L .5329 .74893 L F
.51851 .75192 m .53186 .75284 L .51984 .75015 L F
.27366 .53216 m .27337 .52647 L .25385 .52526 L .733 .496 .569 r
F
0 g
.27337 .52647 m
.29143 .53074 L
s
0 0 0 r
2.5 Mabswid
.70016 .63949 Mdot
.66227 .62541 m .6485 .63414 L .65611 .63732 L .683 .77 .917 r
F
.52357 .6506 m .50849 .64563 L .50898 .65021 L .733 .497 .57 r
F
0 g
.5 Mabswid
.49379 .64757 m
.50849 .64563 L
s
.50849 .64563 m
.52307 .64602 L
s
.52357 .6506 m
.53704 .65327 L
s
.127 .923 .03 r
.52292 .69565 m
.52391 .63067 L
s
0 g
.50898 .65021 m
.52357 .6506 L
s
.68544 .63059 m .69432 .63991 L .70233 .63589 L .683 .77 .917 r
F
.68083 .63196 m .69432 .63991 L .68544 .63059 L F
.46235 .51007 m .46204 .50439 L .46517 .49241 L 0 0 .32 r
F
0 g
.45749 .51072 m
.46204 .50439 L
s
.43762 .50082 m .46167 .50434 L .46479 .49241 L .673 .757 .914 r
F
.32544 .38067 m .31042 .38526 L .30997 .39254 L .336 .157 .485 r
F
.32544 .38067 m .32589 .37338 L .31042 .38526 L F
0 g
.30047 .39949 m
.31042 .38526 L
s
.2354 .63821 m .21529 .63908 L .23341 .64105 L .683 .77 .917 r
F
.4328 .51404 m .46235 .51007 L .43817 .50654 L .673 .757 .914 r
F
.4113 .50675 m .4328 .51404 L .43817 .50654 L F
.40715 .51001 m .4328 .51404 L .4113 .50675 L F
.21576 .64366 m .19539 .65059 L .21426 .64959 L .683 .77 .917 r
F
.23388 .64562 m .21576 .64366 L .21426 .64959 L F
.27033 .6437 m .28512 .63453 L .26855 .64106 L F
.27033 .6437 m .28867 .6398 L .28512 .63453 L F
.28819 .63522 m .30122 .62342 L .28464 .62995 L F
.28819 .63522 m .30653 .63132 L .30122 .62342 L F
.30653 .63132 m .30605 .62675 L .30074 .61884 L .981 .69 .343 r
F
0 g
.30605 .62675 m
.30762 .63544 L
s
.47375 .40111 m .47419 .39382 L .45967 .38038 L .928 .67 .525 r
F
0 g
.47419 .39382 m
.48304 .40904 L
s
.36507 .49817 m .34536 .50986 L .36742 .50182 L .673 .757 .914 r
F
.36507 .49817 m .34066 .50257 L .34536 .50986 L F
.25317 .71355 m .25188 .7186 L .25513 .71853 L .645 .732 .913 r
F
.25186 .65816 m .25306 .71356 L .25156 .71367 L .641 .401 .539 r
F
.25214 .71093 m .25205 .71364 L .25317 .71355 L .645 .732 .913 r
F
.25205 .71364 m .25188 .7186 L .25317 .71355 L F
.25188 .7186 m .25161 .72626 L .25812 .72612 L F
.25283 .71714 m .25161 .72241 L .25488 .72234 L .644 .733 .913 r
F
.25156 .71367 m .25314 .71704 L .25156 .71724 L .641 .401 .539 r
F
.25187 .71471 m .25179 .71722 L .25283 .71714 L .644 .733 .913 r
F
.25179 .71722 m .25161 .72241 L .25283 .71714 L F
.25306 .71356 m .25314 .71704 L .25156 .71367 L .641 .401 .539 r
F
.127 .923 .03 r
.23732 .67298 m
.23853 .73619 L
s
.25568 .71336 m .25819 .71794 L .26083 .71687 L .645 .732 .913 r
F
.25316 .71355 m .25416 .7166 L .25314 .71704 L .515 .301 .526 r
F
.25345 .65795 m .25412 .71321 L .25316 .71355 L F
.25214 .71093 m .25513 .71853 L .25819 .71794 L .645 .732 .913 r
F
.25412 .71321 m .25416 .7166 L .25316 .71355 L .515 .301 .526 r
F
.25488 .7127 m .2553 .71535 L .25487 .71603 L .065 0 .408 r
F
.25518 .65695 m .25529 .71213 L .25488 .7127 L F
.25502 .7129 m .25438 .71342 L .25568 .71336 L .645 .732 .913 r
F
.25438 .71342 m .25435 .71346 L .25568 .71336 L F
.25529 .71213 m .2553 .71535 L .25488 .7127 L .065 0 .408 r
F
.25438 .71342 m .25432 .71346 L .25435 .71346 L .645 .732 .913 r
F
.25214 .71093 m .25411 .71322 L .25502 .7129 L F
.25418 .71319 m .25487 .71603 L .25416 .7166 L .353 .175 .495 r
F
.25448 .65751 m .25485 .71273 L .25418 .71319 L F
.25418 .71319 m .25432 .71346 L .25502 .7129 L .645 .732 .913 r
F
.25412 .71323 m .25432 .71346 L .25418 .71319 L F
.25485 .71273 m .25487 .71603 L .25418 .71319 L .353 .175 .495 r
F
.25411 .71322 m .25412 .71323 L .25418 .71319 L .645 .732 .913 r
F
.25432 .71346 m .25819 .71794 L .25568 .71336 L F
.25186 .65816 m .25345 .65795 L .25316 .71355 L .641 .401 .539 r
F
.25306 .71356 m .25316 .71355 L .25314 .71704 L F
.25186 .65816 m .25316 .71355 L .25306 .71356 L F
.25087 .71354 m .24563 .7172 L .24864 .71815 L .645 .732 .913 r
F
.25204 .71377 m .24864 .71815 L .25188 .7186 L F
.25087 .71354 m .24864 .71815 L .25204 .71377 L F
.24563 .7172 m .24513 .72535 L .24864 .71815 L F
.24963 .71687 m .24276 .71963 L .24533 .72101 L .644 .733 .913 r
F
.24998 .71337 m .25154 .71724 L .24996 .71694 L .751 .491 .539 r
F
.24879 .71638 m .24833 .71662 L .24969 .71681 L .644 .733 .913 r
F
.24897 .71646 m .24996 .71698 L .24897 .7165 L .844 .571 .525 r
F
.24973 .71325 m .24308 .71583 L .24563 .7172 L .645 .732 .913 r
F
.25029 .65789 m .25147 .71366 L .24998 .71337 L .751 .491 .539 r
F
.25214 .71093 m .24873 .71278 L .24973 .71325 L .645 .732 .913 r
F
.24873 .71278 m .24308 .71583 L .24973 .71325 L F
.24899 .7129 m .24996 .71694 L .24897 .71646 L .844 .571 .525 r
F
.24929 .65742 m .24992 .71334 L .24899 .7129 L F
.24967 .71331 m .24958 .7134 L .25087 .71354 L .645 .732 .913 r
F
.24958 .7134 m .24563 .7172 L .25025 .71398 L F
.24958 .7134 m .25025 .71398 L .25087 .71354 L F
.24114 .71413 m .23402 .72073 L .24308 .71583 L F
.24745 .71517 m .23925 .71397 L .23961 .71599 L .644 .733 .913 r
F
.24832 .71233 m .24896 .71646 L .2483 .7159 L .927 .648 .491 r
F
.25147 .71366 m .25154 .71724 L .24998 .71337 L .751 .491 .539 r
F
.25187 .71471 m .24654 .7144 L .24745 .71517 L .644 .733 .913 r
F
.25029 .65789 m .25186 .65816 L .25156 .71367 L .751 .491 .539 r
F
.25029 .65789 m .25156 .71367 L .25147 .71366 L F
.24873 .71278 m .24114 .71413 L .24308 .71583 L .645 .732 .913 r
F
.25214 .71093 m .24761 .71225 L .24873 .71278 L F
.24761 .71225 m .24114 .71413 L .24873 .71278 L F
.24929 .65742 m .25029 .65789 L .24998 .71337 L .844 .571 .525 r
F
.24992 .71334 m .24998 .71337 L .24996 .71698 L F
.24929 .65742 m .24998 .71337 L .24992 .71334 L F
.24654 .7144 m .23925 .71397 L .24745 .71517 L .644 .733 .913 r
F
.24308 .71583 m .23913 .72347 L .24563 .7172 L .645 .732 .913 r
F
.24833 .71662 m .24081 .71792 L .24276 .71963 L .644 .733 .913 r
F
.25147 .71366 m .25156 .71367 L .25154 .71724 L .751 .491 .539 r
F
.24895 .71286 m .24897 .71646 L .24832 .71233 L .927 .648 .491 r
F
.24897 .71646 m .24897 .7165 L .24896 .71646 L F
.24897 .71646 m .24896 .71646 L .24832 .71233 L F
.24884 .71635 m .24649 .71627 L .24833 .71662 L .644 .733 .913 r
F
.25187 .71471 m .24817 .71578 L .24884 .71635 L F
.24817 .71578 m .24649 .71627 L .24884 .71635 L F
.24649 .71627 m .24081 .71792 L .24833 .71662 L F
.2483 .7159 m .24897 .7165 L .2483 .71591 L .927 .648 .491 r
F
.24896 .71646 m .24897 .7165 L .2483 .7159 L F
.24862 .65683 m .24895 .71286 L .24832 .71233 L F
.24992 .71334 m .24996 .71694 L .24899 .7129 L .844 .571 .525 r
F
.24996 .71694 m .24996 .71698 L .24897 .71646 L F
.24969 .71681 m .24833 .71662 L .24963 .71687 L .644 .733 .913 r
F
.25187 .71471 m .24879 .71638 L .24969 .71681 L F
.24833 .71662 m .24276 .71963 L .24963 .71687 L F
.24864 .71815 m .24513 .72535 L .25161 .72626 L .645 .732 .913 r
F
.25187 .71471 m .24533 .72101 L .24835 .72196 L .644 .733 .913 r
F
.24996 .71694 m .25154 .71724 L .24996 .71698 L .751 .491 .539 r
F
.24864 .71815 m .25161 .72626 L .25188 .7186 L .645 .732 .913 r
F
.25187 .71471 m .24835 .72196 L .25161 .72241 L .644 .733 .913 r
F
.25154 .71724 m .25154 .71724 L .24996 .71694 L .751 .491 .539 r
F
.25214 .71093 m .25087 .71354 L .25204 .71377 L .645 .732 .913 r
F
.25214 .71093 m .24967 .71331 L .25087 .71354 L F
0 g
.25156 .7148 m
.25156 .71474 L
s
.25186 .65816 m
.25189 .65308 L
s
.235 .63366 m .21896 .62888 L .215 .63452 L .683 .77 .917 r
F
.23808 .63117 m .21896 .62888 L .235 .63366 L F
.48211 .75353 m .47053 .75883 L .48279 .75756 L .645 .732 .913 r
F
.127 .923 .03 r
.697 .72623 m
.69727 .71904 L
s
.48211 .75353 m .4695 .75279 L .47053 .75883 L .645 .732 .913 r
F
0 g
.47053 .75883 m
.47407 .76461 L
s
.25602 .71255 m .26083 .71687 L .26288 .7154 L .645 .732 .913 r
F
.25214 .71093 m .25502 .7129 L .25602 .71255 L F
.25502 .7129 m .26083 .71687 L .25602 .71255 L F
.25345 .65795 m .25448 .65751 L .25418 .71319 L .515 .301 .526 r
F
.25412 .71321 m .25418 .71319 L .25416 .7166 L F
.25345 .65795 m .25418 .71319 L .25412 .71321 L F
.25414 .53095 m .2342 .52718 L .23449 .53287 L .672 .448 .573 r
F
0 g
.21607 .5378 m
.23449 .53287 L
s
.25414 .53095 m .25385 .52526 L .2342 .52718 L .672 .448 .573 r
F
0 g
.21578 .53212 m
.2342 .52718 L
s
.62425 .5133 m .61139 .51738 L .61172 .52306 L .389 .235 .549 r
F
.62425 .5133 m .62392 .50762 L .61139 .51738 L F
0 g
.60326 .52862 m
.61139 .51738 L
s
.72459 .63568 m .7302 .6226 L .73072 .62718 L .207 .12 .531 r
F
.70859 .63088 m .72459 .63568 L .73072 .62718 L .683 .77 .917 r
F
.70233 .63589 m .72459 .63568 L .70859 .63088 L F
0 g
.7152 .6432 m
.72459 .63568 L
s
.49496 .7505 m .48304 .75378 L .4953 .75251 L .645 .732 .913 r
F
.49496 .7505 m .48236 .74976 L .48304 .75378 L F
.54357 .76312 m .54538 .75346 L .54513 .75723 L 0 0 .146 r
F
.53149 .76042 m .54357 .76312 L .54513 .75723 L .645 .732 .913 r
F
0 g
.53954 .76845 m
.54357 .76312 L
s
.127 .923 .03 r
.698 .72593 m
.69818 .71877 L
s
.68894 .624 m .70182 .63131 L .70808 .6263 L .683 .77 .917 r
F
.21576 .64366 m .19764 .64169 L .19539 .65059 L F
0 g
.19539 .65059 m
.19699 .65927 L
s
.25614 .71183 m .26288 .7154 L .2642 .71363 L .645 .732 .913 r
F
.25214 .71093 m .25545 .71231 L .25614 .71183 L F
.25545 .71231 m .26288 .7154 L .25614 .71183 L F
.25448 .65751 m .25518 .65695 L .25488 .7127 L .353 .175 .495 r
F
.25485 .71273 m .25488 .7127 L .25487 .71603 L F
.25448 .65751 m .25488 .7127 L .25485 .71273 L F
.53174 .75664 m .54538 .75346 L .53278 .75272 L .645 .732 .913 r
F
.51965 .75394 m .53174 .75664 L .53278 .75272 L F
.51831 .75572 m .53174 .75664 L .51965 .75394 L F
.26807 .63648 m .27883 .62557 L .26517 .6343 L .683 .77 .917 r
F
.26807 .63648 m .28464 .62995 L .27883 .62557 L F
0 g
.49428 .65215 m
.50898 .65021 L
s
.6415 .52384 m .62425 .5133 L .61172 .52306 L .673 .757 .914 r
F
.6522 .51877 m .62425 .5133 L .6415 .52384 L F
.24807 .71212 m .23994 .7122 L .24114 .71413 L .645 .732 .913 r
F
.25214 .71093 m .24727 .71144 L .24807 .71212 L F
.24727 .71144 m .23994 .7122 L .24807 .71212 L F
.24862 .65683 m .24929 .65742 L .24899 .7129 L .927 .648 .491 r
F
.24895 .71286 m .24899 .7129 L .24897 .7165 L F
.24862 .65683 m .24899 .7129 L .24895 .71286 L F
.70215 .51231 m .69754 .49458 L .69022 .50947 L .673 .757 .914 r
F
.70215 .51231 m .71544 .49884 L .69754 .49458 L F
.51984 .75015 m .5329 .74893 L .52036 .7482 L .645 .732 .913 r
F
.71313 .52823 m .71632 .51001 L .70296 .52354 L .673 .758 .914 r
F
.71313 .52823 m .73157 .51705 L .71632 .51001 L F
.55997 .37877 m .53516 .39261 L .5629 .38385 L .654 .726 .902 r
F
.55997 .37877 m .52928 .38245 L .53516 .39261 L F
.26463 .62976 m .27059 .61791 L .26081 .62818 L .683 .77 .917 r
F
.26463 .62976 m .27822 .62108 L .27059 .61791 L F
.25598 .71116 m .2642 .71363 L .2647 .71167 L .645 .732 .913 r
F
.25214 .71093 m .25559 .7117 L .25598 .71116 L F
.25559 .7117 m .2642 .71363 L .25598 .71116 L F
.25518 .65695 m .25561 .65626 L .25531 .71209 L .065 0 .408 r
F
.25529 .71213 m .25531 .71209 L .2553 .71535 L F
.25518 .65695 m .25531 .71209 L .25529 .71213 L F
.66278 .62999 m .65662 .6419 L .66659 .63159 L .683 .77 .917 r
F
.66278 .62999 m .649 .63871 L .65662 .6419 L F
.74305 .52637 m .73123 .51136 L .73157 .51705 L .934 .657 .492 r
F
0 g
.74305 .52637 m
.74996 .53734 L
s
.65898 .61861 m .64813 .62947 L .66184 .62079 L .683 .77 .917 r
F
.65898 .61861 m .64242 .62511 L .64813 .62947 L F
.62091 .62839 m .62562 .63171 L .62613 .63629 L .98 .688 .332 r
F
.62091 .62839 m .62041 .62381 L .62562 .63171 L F
0 g
.62562 .63171 m
.62975 .63487 L
s
.24776 .71139 m .23958 .7102 L .23994 .7122 L .645 .732 .913 r
F
.25214 .71093 m .24734 .71065 L .24776 .71139 L F
.24952 .70934 m .24838 .71337 L .2495 .71259 L .398 .209 .505 r
F
.24982 .6535 m .24846 .70997 L .24952 .70934 L F
.24846 .70997 m .24838 .71337 L .24952 .70934 L F
.24733 .71065 m .23958 .7102 L .24776 .71139 L .645 .732 .913 r
F
.24824 .65613 m .24862 .65683 L .24832 .71233 L .989 .721 .393 r
F
.2483 .71229 m .24832 .71233 L .2483 .71591 L F
.24824 .65613 m .24832 .71233 L .2483 .71229 L F
.63897 .61987 m .62587 .63161 L .64242 .62511 L .683 .77 .917 r
F
.63897 .61987 m .62069 .62375 L .62587 .63161 L F
.64435 .39832 m .68131 .39569 L .6511 .38882 L .654 .726 .902 r
F
.61752 .3867 m .64435 .39832 L .6511 .38882 L F
.61231 .39066 m .64435 .39832 L .61752 .3867 L F
.27366 .53216 m .25385 .52526 L .25414 .53095 L .733 .496 .569 r
F
0 g
.2342 .52718 m
.25385 .52526 L
s
.25385 .52526 m
.27337 .52647 L
s
.27366 .53216 m
.29173 .53643 L
s
.49604 .37013 m .49904 .37884 L .49861 .38613 L .919 .74 .25 r
F
.49604 .37013 m .49647 .36285 L .49904 .37884 L F
0 g
.49904 .37884 m
.50296 .38561 L
s
.21896 .62888 m .19698 .63256 L .215 .63452 L .683 .77 .917 r
F
.52832 .36451 m .4995 .37879 L .53002 .37513 L .654 .726 .902 r
F
.52832 .36451 m .49694 .36287 L .4995 .37879 L F
.23587 .64279 m .21576 .64366 L .23388 .64562 L .683 .77 .917 r
F
0 g
.25414 .53095 m
.27366 .53216 L
s
.25497 .71038 m .25388 .71267 L .25495 .71349 L .908 .63 .502 r
F
.25527 .6544 m .25395 .70963 L .25497 .71038 L F
.25561 .65626 m .25542 .7114 L .25531 .71209 L 0 0 .125 r
F
.25554 .71058 m .2647 .71167 L .26434 .70966 L .645 .732 .913 r
F
.25214 .71093 m .25546 .71113 L .25554 .71058 L F
.25546 .71113 m .2647 .71167 L .25554 .71058 L F
.25561 .65626 m .25572 .65545 L .25542 .71136 L 0 0 .125 r
F
.25542 .7114 m .25542 .71136 L .25541 .71454 L F
.25561 .65626 m .25542 .71136 L .25542 .7114 L F
.25395 .70963 m .25388 .71267 L .25497 .71038 L .908 .63 .502 r
F
.25309 .70898 m .25605 .70716 L .25565 .70372 L .645 .732 .913 r
F
.2539 .70959 m .2528 .71229 L .25388 .71267 L .809 .541 .533 r
F
.2542 .65358 m .25287 .70922 L .2539 .70959 L F
.25214 .71093 m .25363 .70949 L .25296 .70925 L .645 .732 .913 r
F
.25572 .65545 m .25527 .6544 L .25497 .71038 L .986 .729 .348 r
F
.25499 .71043 m .25497 .71038 L .25495 .71349 L F
.25572 .65545 m .25497 .71038 L .25499 .71043 L F
.2546 .7096 m .26315 .70774 L .26121 .70603 L .645 .732 .913 r
F
.25214 .71093 m .25485 .71014 L .2546 .7096 L F
.25485 .71014 m .26315 .70774 L .2546 .7096 L F
.25426 .70889 m .26121 .70603 L .25865 .70466 L F
.25214 .71093 m .2546 .7096 L .25426 .70889 L F
.2546 .7096 m .26121 .70603 L .25426 .70889 L F
.25531 .71209 m .25541 .71454 L .2553 .71535 L 0 0 .125 r
F
.25542 .7114 m .25541 .71454 L .25531 .71209 L F
.25542 .71136 m .25495 .71349 L .25541 .71454 L .986 .729 .348 r
F
.25572 .65545 m .25499 .71043 L .25542 .71136 L F
.25499 .71043 m .25495 .71349 L .25542 .71136 L F
.25287 .70922 m .2528 .71229 L .2539 .70959 L .809 .541 .533 r
F
.25296 .70925 m .25369 .70944 L .25309 .70898 L .645 .732 .913 r
F
.25363 .70949 m .25369 .70944 L .25296 .70925 L F
.25369 .70944 m .25605 .70716 L .25309 .70898 L F
.25605 .70716 m .25865 .70466 L .25653 .70399 L F
.25605 .70716 m .25653 .70399 L .25565 .70372 L F
.34722 .39624 m .32544 .38067 L .30997 .39254 L .654 .726 .902 r
F
.36051 .39045 m .32544 .38067 L .34722 .39624 L F
.68131 .39569 m .68171 .3884 L .68569 .37274 L 0 0 .152 r
F
0 g
.67719 .39475 m
.68171 .3884 L
s
.68699 .34799 m
.71739 .38634 L
s
.24733 .71065 m .24008 .70824 L .23958 .7102 L .645 .732 .913 r
F
.25214 .71093 m .24679 .70974 L .24733 .71065 L F
.24679 .70974 m .24008 .70824 L .24733 .71065 L F
.24793 .71168 m .2483 .71591 L .24791 .71521 L .989 .721 .393 r
F
.24824 .65613 m .2483 .71229 L .24793 .71168 L F
.2483 .71229 m .2483 .71591 L .24793 .71168 L F
.2478 .70996 m .2414 .70646 L .24008 .70824 L .645 .732 .913 r
F
.25214 .71093 m .24773 .7091 L .2478 .70996 L F
.24773 .7091 m .2414 .70646 L .2478 .70996 L F
.24818 .65531 m .24824 .65613 L .24793 .71168 L .798 .638 .081 r
F
.24793 .71163 m .24793 .71168 L .24791 .71521 L F
.24818 .65531 m .24793 .71168 L .24793 .71163 L F
.65121 .38147 m .68126 .3883 L .68522 .37272 L .654 .726 .902 r
F
.28867 .6398 m .30169 .628 L .28512 .63453 L .683 .77 .917 r
F
.28867 .6398 m .30701 .6359 L .30169 .628 L F
.30653 .63132 m .30074 .61884 L .30122 .62342 L .981 .69 .343 r
F
.30701 .6359 m .30653 .63132 L .30122 .62342 L F
0 g
.30653 .63132 m
.3081 .64002 L
s
.43637 .40091 m .44002 .37692 L .42356 .39375 L .654 .726 .902 r
F
.43637 .40091 m .45923 .38767 L .44002 .37692 L F
0 g
.50722 .80855 m
.50722 .80949 L
s
.50722 .80956 m
.50722 .80963 L
s
.46235 .51007 m .46517 .49241 L .46548 .49809 L 0 0 .32 r
F
.46267 .51575 m .46235 .51007 L .46548 .49809 L F
.43817 .50654 m .46235 .51007 L .46548 .49809 L .673 .757 .914 r
F
0 g
.45781 .51641 m
.46235 .51007 L
s
.43311 .51972 m .46267 .51575 L .43849 .51222 L .673 .757 .914 r
F
.41161 .51244 m .43311 .51972 L .43849 .51222 L F
.40746 .51569 m .43311 .51972 L .41161 .51244 L F
.49471 .75427 m .48279 .75756 L .49505 .75629 L .645 .732 .913 r
F
.49471 .75427 m .48211 .75353 L .48279 .75756 L F
.2354 .63821 m .21927 .63341 L .21529 .63908 L .683 .77 .917 r
F
.23849 .63571 m .21927 .63341 L .2354 .63821 L F
.53149 .76042 m .54513 .75723 L .53253 .75649 L .645 .732 .913 r
F
.5194 .75772 m .53149 .76042 L .53253 .75649 L F
.51806 .75949 m .53149 .76042 L .5194 .75772 L F
.23808 .63117 m .22511 .62389 L .21896 .62888 L .683 .77 .917 r
F
.24204 .62917 m .22511 .62389 L .23808 .63117 L F
.65199 .51322 m .64015 .5002 L .62417 .50778 L .673 .757 .914 r
F
.66425 .50994 m .64015 .5002 L .65199 .51322 L F
.24773 .7091 m .24345 .70499 L .2414 .70646 L .645 .732 .913 r
F
.25214 .71093 m .24763 .70785 L .24773 .7091 L F
.24763 .70785 m .24345 .70499 L .24773 .7091 L F
.24788 .71093 m .24791 .71521 L .24786 .7144 L .798 .638 .081 r
F
.24818 .65531 m .24793 .71163 L .24788 .71093 L F
.24793 .71163 m .24791 .71521 L .24788 .71093 L F
.2484 .71001 m .24786 .7144 L .24838 .71337 L 0 0 .368 r
F
.24871 .65428 m .24791 .71088 L .2484 .71001 L F
.24791 .71088 m .24786 .7144 L .2484 .71001 L F
.24957 .70796 m .24915 .70333 L .24609 .70392 L .645 .732 .913 r
F
.25172 .70904 m .25061 .71225 L .25171 .71216 L .66 .416 .54 r
F
.25203 .65307 m .25068 .70907 L .25172 .70904 L F
.25214 .71093 m .2514 .70905 L .25054 .70908 L .645 .732 .913 r
F
.24973 .70929 m .24957 .70796 L .24907 .70884 L F
.25214 .71093 m .25055 .70909 L .24973 .70929 L F
.25093 .65316 m .24958 .70933 L .25063 .70907 L .567 .342 .533 r
F
.25055 .70909 m .24957 .70796 L .24973 .70929 L .645 .732 .913 r
F
.25063 .70907 m .2495 .71259 L .25061 .71225 L .567 .342 .533 r
F
.24958 .70933 m .2495 .71259 L .25063 .70907 L F
.25068 .70907 m .25061 .71225 L .25172 .70904 L .66 .416 .54 r
F
.25054 .70908 m .2504 .70651 L .24957 .70796 L .645 .732 .913 r
F
.2514 .70905 m .2504 .70651 L .25054 .70908 L F
.2504 .70651 m .24915 .70333 L .24957 .70796 L F
.24907 .70884 m .24609 .70392 L .24345 .70499 L F
.24957 .70796 m .24609 .70392 L .24907 .70884 L F
.24871 .65428 m .24818 .65531 L .24788 .71093 L 0 0 .368 r
F
.24791 .71088 m .24788 .71093 L .24786 .7144 L F
.24871 .65428 m .24788 .71093 L .24791 .71088 L F
.68945 .62858 m .70233 .63589 L .70859 .63088 L .683 .77 .917 r
F
.68544 .63059 m .70233 .63589 L .68945 .62858 L F
.51965 .75394 m .53278 .75272 L .52017 .75198 L .645 .732 .913 r
F
.127 .923 .03 r
.52286 .69925 m
.52292 .69565 L
s
.4713 .74312 m .47001 .74524 L .46975 .74902 L 0 0 .142 r
F
0 g
.4703 .74694 m
.47066 .74907 L
s
.48376 .74208 m .47173 .73939 L .47019 .74525 L .645 .732 .913 r
F
.4713 .74312 m .47155 .73935 L .47001 .74524 L 0 0 .142 r
F
.48376 .74208 m .47019 .74525 L .48274 .74599 L .645 .732 .913 r
F
.36525 .50388 m .34544 .51562 L .36761 .50754 L .673 .757 .914 r
F
.36525 .50388 m .34071 .5083 L .34544 .51562 L F
.49579 .74477 m .48274 .74599 L .49528 .74673 L .645 .732 .913 r
F
.49579 .74477 m .48376 .74208 L .48274 .74599 L F
.26855 .64106 m .27931 .63015 L .26564 .63887 L .683 .77 .917 r
F
.26855 .64106 m .28512 .63453 L .27931 .63015 L F
.50782 .74746 m .5049 .73988 L .50184 .74047 L .645 .732 .913 r
F
0 g
.50409 .74654 m
.50409 .74717 L
s
.50782 .74746 m .50816 .73981 L .5049 .73988 L .645 .732 .913 r
F
.50782 .74746 m .51139 .74026 L .50816 .73981 L F
.52036 .7482 m .53222 .74493 L .52002 .74619 L F
.52036 .7482 m .5329 .74893 L .53222 .74493 L F
.5329 .74893 m .54443 .74366 L .53222 .74493 L F
.5329 .74893 m .54544 .74967 L .54443 .74366 L F
.54538 .75346 m .54563 .74968 L .54461 .74364 L .925 .75 .266 r
F
0 g
.54464 .75341 m
.54521 .75126 L
s
.70741 .62168 m .72942 .618 L .71147 .61603 L .683 .77 .917 r
F
.69148 .61689 m .70741 .62168 L .71147 .61603 L F
0 g
.23449 .53287 m
.25414 .53095 L
s
.62458 .51899 m .61172 .52306 L .61205 .52875 L .389 .235 .549 r
F
.62458 .51899 m .62425 .5133 L .61172 .52306 L F
0 g
.60359 .5343 m
.61172 .52306 L
s
.26081 .62818 m .26162 .61613 L .25633 .62729 L .683 .77 .917 r
F
.26081 .62818 m .27059 .61791 L .26162 .61613 L F
.65941 .62322 m .6485 .63414 L .66227 .62541 L F
.65941 .62322 m .64276 .62976 L .6485 .63414 L F
.26517 .6343 m .27116 .62238 L .26133 .6327 L F
.26517 .6343 m .27883 .62557 L .27116 .62238 L F
.62142 .63297 m .62613 .63629 L .62663 .64087 L .98 .688 .332 r
F
.62142 .63297 m .62091 .62839 L .62613 .63629 L F
.63929 .62449 m .62613 .63629 L .64276 .62976 L .683 .77 .917 r
F
.63929 .62449 m .62091 .62839 L .62613 .63629 L F
0 g
.62613 .63629 m
.63026 .63944 L
s
.32498 .38796 m .30997 .39254 L .30951 .39983 L .336 .157 .485 r
F
.32498 .38796 m .32544 .38067 L .30997 .39254 L F
0 g
.30001 .40678 m
.30997 .39254 L
s
.25471 .71019 m .26434 .70966 L .26315 .70774 L .645 .732 .913 r
F
.25214 .71093 m .25527 .71061 L .25471 .71019 L F
.25527 .71061 m .26434 .70966 L .25471 .71019 L F
.25527 .6544 m .2542 .65358 L .2539 .70959 L .908 .63 .502 r
F
.25395 .70963 m .2539 .70959 L .25388 .71267 L F
.25527 .6544 m .2539 .70959 L .25395 .70963 L F
0 g
.25499 .70506 m
.25527 .6544 L
s
.25527 .6544 m
.25531 .64629 L
s
.64183 .52952 m .62458 .51899 L .61205 .52875 L .673 .758 .914 r
F
0 g
.60392 .53999 m
.61205 .52875 L
s
.65254 .52445 m .62458 .51899 L .64183 .52952 L .673 .758 .914 r
F
.24982 .6535 m .24871 .65428 L .24838 .71337 L .398 .209 .505 r
F
0 g
.24844 .70347 m
.24871 .65428 L
s
.24871 .65428 m
.24875 .64662 L
s
.70263 .51785 m .69798 .50004 L .69064 .51501 L .673 .757 .914 r
F
.70263 .51785 m .71598 .50432 L .69798 .50004 L F
.21927 .63341 m .19717 .63711 L .21529 .63908 L .683 .77 .917 r
F
.284 .62544 m .29182 .6124 L .27822 .62108 L F
.284 .62544 m .30049 .61894 L .29182 .6124 L F
.47375 .40111 m .45967 .38038 L .45923 .38767 L .928 .67 .525 r
F
.47332 .4084 m .47375 .40111 L .45923 .38767 L F
0 g
.47375 .40111 m
.4826 .41633 L
s
.36111 .38335 m .34606 .36496 L .32622 .37362 L .654 .726 .902 r
F
.37639 .38009 m .34606 .36496 L .36111 .38335 L F
.42384 .38663 m .41773 .36261 L .40887 .38179 L F
.42384 .38663 m .44021 .36989 L .41773 .36261 L F
.2542 .65358 m .25312 .6532 L .2528 .71229 L .809 .541 .533 r
F
.30701 .6359 m .30122 .62342 L .30169 .628 L .981 .69 .343 r
F
0 g
.30701 .6359 m
.30857 .6446 L
s
.24204 .62917 m .23302 .61989 L .22511 .62389 L .683 .77 .917 r
F
.24661 .6278 m .23302 .61989 L .24204 .62917 L F
.127 .923 .03 r
.23375 .56343 m
.2356 .62139 L
s
.23375 .56343 m
.23486 .62096 L
s
.25093 .65316 m .24982 .6535 L .2495 .71259 L .567 .342 .533 r
F
.69022 .50947 m .67813 .49337 L .6773 .50867 L .673 .757 .914 r
F
.69022 .50947 m .69754 .49458 L .67813 .49337 L F
.43762 .50082 m .46479 .49241 L .43969 .49287 L F
.41356 .4973 m .43762 .50082 L .43969 .49287 L F
.41089 .50103 m .43762 .50082 L .41356 .4973 L F
.25312 .6532 m .25171 .71216 L .2528 .71229 L .734 .477 .54 r
F
0 g
.25185 .66043 m
.25186 .65816 L
s
.25312 .6532 m .25203 .65307 L .25171 .71216 L .734 .477 .54 r
F
.23587 .64279 m .21974 .63799 L .21576 .64366 L .683 .77 .917 r
F
.23896 .64029 m .21974 .63799 L .23587 .64279 L F
.5194 .75772 m .53253 .75649 L .51992 .75575 L .645 .732 .913 r
F
.25203 .65307 m .25093 .65316 L .25061 .71225 L .66 .416 .54 r
F
.47105 .7469 m .46975 .74902 L .4695 .75279 L 0 0 .142 r
F
0 g
.47004 .75072 m
.47041 .75284 L
s
.48339 .74583 m .4713 .74312 L .46975 .74902 L .645 .732 .913 r
F
.47105 .7469 m .4713 .74312 L .46975 .74902 L 0 0 .142 r
F
.48339 .74583 m .46975 .74902 L .48236 .74976 L .645 .732 .913 r
F
.49548 .74853 m .48236 .74976 L .49496 .7505 L F
.49548 .74853 m .48339 .74583 L .48236 .74976 L F
.7302 .6226 m .72969 .61803 L .73213 .60911 L 0 0 .397 r
F
0 g
.72587 .62333 m
.72969 .61803 L
s
.31409 .50083 m .31588 .50703 L .31618 .51272 L .838 .633 .087 r
F
.31409 .50083 m .31379 .49515 L .31588 .50703 L F
0 g
.31588 .50703 m
.31921 .51217 L
s
.71147 .61603 m .72942 .618 L .73185 .60913 L .683 .77 .917 r
F
.33928 .49469 m .31625 .50697 L .34066 .50257 L .673 .757 .914 r
F
.33928 .49469 m .31417 .49514 L .31625 .50697 L F
.25633 .62729 m .25192 .61587 L .25148 .62716 L .683 .77 .917 r
F
.25633 .62729 m .26162 .61613 L .25192 .61587 L F
.50757 .75124 m .50463 .74362 L .50156 .74421 L .645 .732 .913 r
F
.50757 .75124 m .50791 .74355 L .50463 .74362 L F
.50757 .75124 m .51116 .744 L .50791 .74355 L F
.50757 .75124 m .51417 .74495 L .51116 .744 L F
.50757 .75124 m .51672 .74633 L .51417 .74495 L F
.50959 .7492 m .50851 .74882 L .50851 .7493 L .809 .541 .532 r
F
.50959 .7492 m .50851 .7493 L .50958 .74968 L F
.50743 .75247 m .51091 .74778 L .50766 .74733 L .645 .732 .913 r
F
.50851 .74882 m .50742 .74869 L .50742 .7527 L .734 .477 .54 r
F
.50732 .75501 m .50839 .75284 L .50742 .7527 L .645 .732 .913 r
F
.50843 .75285 m .50742 .7527 L .50743 .80791 L .734 .477 .54 r
F
.50851 .74882 m .50742 .7527 L .50843 .75285 L F
.50742 .7527 m .5084 .75282 L .50743 .75247 L .645 .732 .913 r
F
.50839 .75284 m .5084 .75282 L .50742 .7527 L F
.50757 .75124 m .51108 .75022 L .51011 .74987 L F
.50958 .74968 m .50851 .7493 L .50851 .75286 L .809 .541 .532 r
F
.5084 .75282 m .51091 .74778 L .50743 .75247 L .645 .732 .913 r
F
.50951 .75322 m .50851 .75286 L .50852 .80803 L .809 .541 .532 r
F
.50958 .74968 m .50851 .75286 L .50951 .75322 L F
.51011 .74987 m .51865 .74803 L .51672 .74633 L .645 .732 .913 r
F
.51108 .75022 m .51865 .74803 L .51011 .74987 L F
.23849 .63571 m .22545 .6284 L .21927 .63341 L .683 .77 .917 r
F
.24246 .6337 m .22545 .6284 L .23849 .63571 L F
.52017 .75198 m .5321 .74869 L .51983 .74996 L .645 .732 .913 r
F
.52017 .75198 m .53278 .75272 L .5321 .74869 L F
.53278 .75272 m .54436 .74741 L .5321 .74869 L F
.53278 .75272 m .54538 .75346 L .54436 .74741 L F
.54538 .75346 m .54461 .74364 L .54436 .74741 L .925 .75 .266 r
F
.54513 .75723 m .54538 .75346 L .54436 .74741 L F
0 g
.54439 .75719 m
.54496 .75504 L
s
.49712 .743 m .48376 .74208 L .49579 .74477 L .645 .732 .913 r
F
.46267 .51575 m .46548 .49809 L .4658 .50378 L 0 0 .32 r
F
.43849 .51222 m .46267 .51575 L .4658 .50378 L .673 .757 .914 r
F
0 g
.45459 .527 m
.46267 .51575 L
s
.52002 .74619 m .52988 .74109 L .51885 .74428 L .645 .732 .913 r
F
.52002 .74619 m .53222 .74493 L .52988 .74109 L F
.55954 .38606 m .53474 .39989 L .56248 .39114 L .654 .726 .902 r
F
.55954 .38606 m .52886 .38974 L .53474 .39989 L F
.70808 .6263 m .7302 .6226 L .71216 .62063 L .683 .77 .917 r
F
.69207 .62149 m .70808 .6263 L .71216 .62063 L F
.68894 .624 m .70808 .6263 L .69207 .62149 L F
.24661 .6278 m .24217 .61716 L .23302 .61989 L F
.127 .923 .03 r
.22381 .55489 m
.23456 .61943 L
s
.25148 .62716 m .24217 .61716 L .24661 .6278 L .683 .77 .917 r
F
.64394 .40561 m .68091 .40298 L .6507 .39611 L .654 .726 .902 r
F
.6171 .39399 m .64394 .40561 L .6507 .39611 L F
.6119 .39795 m .64394 .40561 L .6171 .39399 L F
.66425 .50994 m .65856 .49529 L .64015 .5002 L .673 .757 .914 r
F
.6773 .50867 m .65856 .49529 L .66425 .50994 L F
.49561 .37742 m .49861 .38613 L .49818 .39342 L .919 .74 .25 r
F
.49561 .37742 m .49604 .37013 L .49861 .38613 L F
.52758 .37178 m .49861 .38613 L .52928 .38245 L .654 .726 .902 r
F
.52758 .37178 m .49604 .37013 L .49861 .38613 L F
0 g
.49861 .38613 m
.50254 .3929 L
s
.25148 .62716 m .25192 .61587 L .24217 .61716 L .683 .77 .917 r
F
.127 .923 .03 r
.51917 .34542 m
.52127 .36414 L
s
0 g
.51065 .75048 m
.51065 .75184 L
s
.65991 .6278 m .649 .63871 L .66278 .62999 L .683 .77 .917 r
F
.65991 .6278 m .64327 .63434 L .649 .63871 L F
.6522 .51877 m .64031 .50569 L .62425 .5133 L .673 .757 .914 r
F
.66453 .51548 m .64031 .50569 L .6522 .51877 L F
.26133 .6327 m .26214 .6206 L .25683 .63181 L .683 .77 .917 r
F
.26133 .6327 m .27116 .62238 L .26214 .6206 L F
.36555 .50957 m .34574 .5213 L .36792 .51323 L .673 .757 .914 r
F
.36555 .50957 m .34101 .51399 L .34574 .5213 L F
.127 .923 .03 r
.66747 .60362 m
.66857 .55089 L
s
.66608 .60313 m
.66776 .55118 L
s
.26564 .63887 m .27164 .62696 L .26181 .63728 L .683 .77 .917 r
F
.26564 .63887 m .27931 .63015 L .27164 .62696 L F
.21896 .62888 m .20291 .6241 L .19698 .63256 L F
0 g
.50409 .80867 m
.50409 .80911 L
s
.50409 .80653 m
.50409 .8078 L
s
.50409 .75011 m
.50409 .75124 L
s
.6398 .62907 m .62663 .64087 L .64327 .63434 L .683 .77 .917 r
F
.6398 .62907 m .62142 .63297 L .62663 .64087 L F
0 g
.62663 .64087 m
.63524 .64743 L
s
.20314 .62861 m .1967 .63253 L .19717 .63711 L .191 .106 .524 r
F
.20314 .62861 m .20267 .62403 L .1967 .63253 L F
0 g
.19445 .64143 m
.1967 .63253 L
s
.127 .923 .03 r
.19679 .58915 m
.19764 .62479 L
s
.1961 .56 m
.19679 .58915 L
s
.34677 .40353 m .32498 .38796 L .30951 .39983 L .654 .726 .902 r
F
0 g
.29956 .41407 m
.30951 .39983 L
s
.36006 .39774 m .32498 .38796 L .34677 .40353 L .654 .726 .902 r
F
.21974 .63799 m .19764 .64169 L .21576 .64366 L .683 .77 .917 r
F
.68131 .39569 m .68569 .37274 L .68529 .38003 L 0 0 .152 r
F
.68091 .40298 m .68131 .39569 L .68529 .38003 L F
.6511 .38882 m .68131 .39569 L .68529 .38003 L .654 .726 .902 r
F
0 g
.67678 .40204 m
.68131 .39569 L
s
.28464 .62995 m .29251 .61685 L .27883 .62557 L .683 .77 .917 r
F
.28464 .62995 m .30122 .62342 L .29251 .61685 L F
.6773 .50867 m .67813 .49337 L .65856 .49529 L .673 .757 .914 r
F
.127 .923 .03 r
.66474 .49468 m
.66652 .43818 L
s
.43593 .4082 m .43958 .38422 L .42312 .40104 L .654 .726 .902 r
F
.43593 .4082 m .45879 .39496 L .43958 .38422 L F
.73123 .51136 m .73089 .50568 L .71564 .49864 L .861 .596 .537 r
F
0 g
.73089 .50568 m
.74236 .515 L
s
.70296 .52354 m .69832 .50573 L .69097 .52069 L .673 .758 .914 r
F
.70296 .52354 m .71632 .51001 L .69832 .50573 L F
.48314 .7496 m .4695 .75279 L .48211 .75353 L .645 .732 .913 r
F
.48314 .7496 m .47105 .7469 L .4695 .75279 L F
0 g
.4695 .75279 m
.47053 .75883 L
s
.24246 .6337 m .23341 .62438 L .22545 .6284 L .683 .77 .917 r
F
.24706 .63233 m .23341 .62438 L .24246 .6337 L F
.49523 .75231 m .48211 .75353 L .49471 .75427 L .645 .732 .913 r
F
.49523 .75231 m .48314 .7496 L .48211 .75353 L F
.50839 .75284 m .51392 .74873 L .51091 .74778 L F
.50732 .75501 m .50943 .753 L .50839 .75284 L F
.50943 .753 m .51392 .74873 L .50839 .75284 L F
.50851 .75286 m .50748 .80515 L .50852 .80519 L .734 .477 .54 r
F
.50783 .80516 m .5091 .80491 L .50805 .80468 L .692 .759 .903 r
F
.5068 .80746 m .50883 .80521 L .50783 .80516 L F
.50883 .80521 m .5091 .80491 L .50783 .80516 L F
.50748 .80515 m .50743 .80791 L .50852 .80519 L .734 .477 .54 r
F
.50716 .80728 m .50832 .80687 L .50718 .80683 L .692 .759 .904 r
F
.5068 .80746 m .50669 .81027 L .50782 .81012 L .692 .759 .903 r
F
.5068 .80746 m .50889 .80978 L .50982 .80928 L F
.50706 .80966 m .50811 .80732 L .50716 .80728 L .692 .759 .904 r
F
.50852 .80519 m .50767 .8073 L .50852 .80734 L .734 .477 .54 r
F
.50811 .80732 m .50832 .80687 L .50716 .80728 L .692 .759 .904 r
F
.50706 .80966 m .50937 .80709 L .50832 .80687 L F
.50852 .80734 m .50743 .80791 L .50852 .80803 L .734 .477 .54 r
F
.50767 .8073 m .50743 .80791 L .50852 .80734 L F
.50851 .74882 m .50843 .75285 L .50851 .75286 L F
.50843 .75285 m .50743 .80791 L .50851 .75286 L F
.127 .923 .03 r
.4022 8.82514 m
.54569 4.88316 L
s
.49582 8.79963 m
.5266 7.57061 L
s
.65726 .61599 m .64242 .62511 L .65898 .61861 L .683 .77 .917 r
F
.65726 .61599 m .63897 .61987 L .64242 .62511 L F
.50732 .75501 m .50438 .7474 L .50131 .74799 L .645 .732 .913 r
F
0 g
.50409 .75367 m
.50409 .80548 L
s
.50732 .75501 m .50766 .74733 L .50438 .7474 L .645 .732 .913 r
F
.5597 .36615 m .53002 .37513 L .56054 .37146 L .654 .726 .902 r
F
.5597 .36615 m .52832 .36451 L .53002 .37513 L F
.51992 .75575 m .53185 .75246 L .51958 .75374 L .645 .732 .913 r
F
.51992 .75575 m .53253 .75649 L .53185 .75246 L F
.50599 .80536 m .50692 .80465 L .50578 .80481 L .692 .759 .903 r
F
.5068 .80746 m .5069 .80522 L .50599 .80536 L F
.50742 .74869 m .50638 .8053 L .50743 .80515 L .66 .417 .541 r
F
.5069 .80522 m .50692 .80465 L .50599 .80536 L .692 .759 .903 r
F
.5068 .80746 m .50805 .80468 L .50692 .80465 L F
.50638 .8053 m .50633 .80799 L .50743 .80515 L .66 .417 .541 r
F
.50622 .80747 m .50718 .80683 L .50604 .80699 L .692 .759 .904 r
F
.50706 .80966 m .50716 .80733 L .50622 .80747 L F
.50743 .80515 m .50655 .80742 L .50743 .80729 L .66 .417 .541 r
F
.50716 .80733 m .50718 .80683 L .50622 .80747 L .692 .759 .904 r
F
.50743 .80729 m .50633 .80799 L .50743 .80791 L .66 .417 .541 r
F
.50655 .80742 m .50633 .80799 L .50743 .80729 L F
.53253 .75649 m .54412 .75119 L .53185 .75246 L .645 .732 .913 r
F
.53253 .75649 m .54513 .75723 L .54412 .75119 L F
.54513 .75723 m .54436 .74741 L .54412 .75119 L .925 .75 .266 r
F
0 g
.54357 .76312 m
.54513 .75723 L
s
.49682 .74675 m .48339 .74583 L .49548 .74853 L .645 .732 .913 r
F
.7302 .6226 m .73213 .60911 L .73264 .61369 L 0 0 .397 r
F
.73072 .62718 m .7302 .6226 L .73264 .61369 L F
.71216 .62063 m .7302 .6226 L .73264 .61369 L .683 .77 .917 r
F
0 g
.72638 .6279 m
.7302 .6226 L
s
.49712 .743 m .48643 .73854 L .48376 .74208 L .645 .732 .913 r
F
.49919 .74153 m .48643 .73854 L .49712 .743 L F
.51983 .74996 m .52975 .74483 L .51865 .74803 L F
.51983 .74996 m .5321 .74869 L .52975 .74483 L F
.51885 .74428 m .52604 .73769 L .51693 .74257 L F
.51885 .74428 m .52988 .74109 L .52604 .73769 L F
.48643 .73854 m .47173 .73939 L .48376 .74208 L F
.23896 .64029 m .22592 .63298 L .21974 .63799 L .683 .77 .917 r
F
.24294 .63828 m .22592 .63298 L .23896 .64029 L F
.65121 .38147 m .68522 .37272 L .65384 .37108 L .654 .726 .902 r
F
.62115 .37463 m .65121 .38147 L .65384 .37108 L F
.61779 .37936 m .65121 .38147 L .62115 .37463 L F
.25683 .63181 m .2524 .62034 L .25196 .63168 L .683 .77 .917 r
F
.25683 .63181 m .26214 .6206 L .2524 .62034 L F
.53222 .74493 m .54092 .7379 L .52988 .74109 L .645 .732 .913 r
F
.53222 .74493 m .54443 .74366 L .54092 .7379 L F
.22511 .62389 m .20291 .6241 L .21896 .62888 L .683 .77 .917 r
F
.43817 .50654 m .46548 .49809 L .44026 .49855 L .673 .757 .914 r
F
.41399 .503 m .43817 .50654 L .44026 .49855 L F
.4113 .50675 m .43817 .50654 L .41399 .503 L F
.69064 .51501 m .67848 .49882 L .67764 .5142 L F
.69064 .51501 m .69798 .50004 L .67848 .49882 L F
.70859 .63088 m .73072 .62718 L .71267 .62521 L .683 .77 .917 r
F
.69258 .62607 m .70859 .63088 L .71267 .62521 L F
.68945 .62858 m .70859 .63088 L .69258 .62607 L F
.31439 .50652 m .31618 .51272 L .31648 .5184 L .838 .633 .087 r
F
.31439 .50652 m .31409 .50083 L .31618 .51272 L F
.33933 .50037 m .31618 .51272 L .34071 .5083 L .673 .757 .914 r
F
.33933 .50037 m .31409 .50083 L .31618 .51272 L F
0 g
.31618 .51272 m
.31951 .51786 L
s
0 0 0 r
2.5 Mabswid
.37869 .51772 Mdot
.24706 .63233 m .2426 .62163 L .23341 .62438 L .683 .77 .917 r
F
.25196 .63168 m .2426 .62163 L .24706 .63233 L F
.25196 .63168 m .2524 .62034 L .2426 .62163 L F
.26181 .63728 m .26262 .62518 L .2573 .63639 L F
.26181 .63728 m .27164 .62696 L .26262 .62518 L F
.20361 .63318 m .19717 .63711 L .19764 .64169 L .191 .106 .524 r
F
.21927 .63341 m .20314 .62861 L .19717 .63711 L .683 .77 .917 r
F
.20361 .63318 m .20314 .62861 L .19717 .63711 L .191 .106 .524 r
F
0 g
.5 Mabswid
.19492 .64601 m
.19717 .63711 L
s
.127 .923 .03 r
.19764 .62479 m
.19774 .62912 L
s
.47332 .4084 m .45923 .38767 L .45879 .39496 L .928 .67 .525 r
F
0 g
.47332 .4084 m
.48217 .42362 L
s
.37639 .38009 m .36899 .36006 L .34606 .36496 L .654 .726 .902 r
F
.39268 .37956 m .36899 .36006 L .37639 .38009 L F
.36438 .49423 m .34066 .50257 L .36507 .49817 L .673 .757 .914 r
F
.36438 .49423 m .33928 .49469 L .34066 .50257 L F
.40887 .38179 m .39344 .35926 L .39268 .37956 L .654 .726 .902 r
F
.40887 .38179 m .41773 .36261 L .39344 .35926 L F
.28512 .63453 m .29298 .62143 L .27931 .63015 L .683 .77 .917 r
F
.28512 .63453 m .30169 .628 L .29298 .62143 L F
.36051 .39045 m .34538 .37197 L .32544 .38067 L .654 .726 .902 r
F
.37587 .38718 m .34538 .37197 L .36051 .39045 L F
.65254 .52445 m .64064 .51138 L .62458 .51899 L .673 .758 .914 r
F
.66487 .52116 m .64064 .51138 L .65254 .52445 L F
.66453 .51548 m .65881 .50075 L .64031 .50569 L .673 .757 .914 r
F
.67764 .5142 m .65881 .50075 L .66453 .51548 L F
.42356 .39375 m .41743 .36962 L .40851 .38888 L .654 .726 .902 r
F
.42356 .39375 m .44002 .37692 L .41743 .36962 L F
.49919 .74153 m .49055 .7356 L .48643 .73854 L .645 .732 .913 r
F
.50184 .74047 m .49055 .7356 L .49919 .74153 L F
.51693 .74257 m .52095 .73495 L .51438 .74121 L F
.51693 .74257 m .52604 .73769 L .52095 .73495 L F
.49657 .75053 m .48314 .7496 L .49523 .75231 L F
.24294 .63828 m .23388 .62896 L .22592 .63298 L .683 .77 .917 r
F
.24753 .6369 m .23388 .62896 L .24294 .63828 L F
.65767 .62059 m .64276 .62976 L .65941 .62322 L F
.65767 .62059 m .63929 .62449 L .64276 .62976 L F
.49682 .74675 m .48607 .74227 L .48339 .74583 L .645 .732 .913 r
F
.49889 .74528 m .48607 .74227 L .49682 .74675 L F
.51958 .75374 m .5295 .74861 L .51841 .75181 L F
.127 .923 .03 r
.5228 .70286 m
.52286 .69925 L
s
.51958 .75374 m .53185 .75246 L .5295 .74861 L .645 .732 .913 r
F
0 g
.59341 .29536 m
.59351 .3477 L
s
.71147 .61603 m .73185 .60913 L .71308 .61012 L .683 .77 .917 r
F
.69351 .61407 m .71147 .61603 L .71308 .61012 L F
.69148 .61689 m .71147 .61603 L .69351 .61407 L F
.51865 .74803 m .52588 .74141 L .51672 .74633 L .645 .732 .913 r
F
.51865 .74803 m .52975 .74483 L .52588 .74141 L F
.48607 .74227 m .4713 .74312 L .48339 .74583 L F
0 g
.58686 .29524 m
.58696 .34765 L
s
.67764 .5142 m .67848 .49882 L .65881 .50075 L .673 .757 .914 r
F
.73123 .51136 m .71564 .49864 L .71598 .50432 L .861 .596 .537 r
F
.73157 .51705 m .73123 .51136 L .71598 .50432 L F
0 g
.73123 .51136 m
.74271 .52069 L
s
.48643 .73854 m .47573 .73407 L .47173 .73939 L .645 .732 .913 r
F
.47532 .73778 m .47155 .73935 L .4713 .74312 L .08 0 .404 r
F
.47532 .73778 m .47557 .73401 L .47155 .73935 L F
0 g
.47001 .74524 m
.47155 .73935 L
s
.73072 .62718 m .73264 .61369 L .73315 .61827 L 0 0 .397 r
F
.71267 .62521 m .73072 .62718 L .73315 .61827 L .683 .77 .917 r
F
0 g
.72459 .63568 m
.73072 .62718 L
s
.30122 .62342 m .30074 .61884 L .29203 .61227 L .932 .647 .478 r
F
0 g
.30074 .61884 m
.30605 .62675 L
s
.5321 .74869 m .54084 .74163 L .52975 .74483 L .645 .732 .913 r
F
.5321 .74869 m .54436 .74741 L .54084 .74163 L F
.27822 .62108 m .28037 .60763 L .27059 .61791 L .683 .77 .917 r
F
.27822 .62108 m .29182 .6124 L .28037 .60763 L F
.2573 .63639 m .25288 .62492 L .25243 .63626 L F
.2573 .63639 m .26262 .62518 L .25288 .62492 L F
.54436 .74741 m .54461 .74364 L .54109 .73785 L .99 .751 .476 r
F
0 g
.54461 .74364 m
.54563 .74968 L
s
.39268 .37956 m .39344 .35926 L .36899 .36006 L .654 .726 .902 r
F
.22545 .6284 m .20314 .62861 L .21927 .63341 L .683 .77 .917 r
F
.52715 .37907 m .49818 .39342 L .52886 .38974 L .654 .726 .902 r
F
.52715 .37907 m .49561 .37742 L .49818 .39342 L F
0 g
.49818 .39342 m
.50702 .40865 L
s
.59743 .38682 m
.59743 .38682 L
s
.41356 .4973 m .43969 .49287 L .41459 .49332 L .673 .757 .914 r
F
.24753 .6369 m .24307 .62621 L .23388 .62896 L .683 .77 .917 r
F
.25243 .63626 m .24307 .62621 L .24753 .6369 L F
.50184 .74047 m .49586 .73347 L .49055 .7356 L .645 .732 .913 r
F
.5049 .73988 m .49586 .73347 L .50184 .74047 L F
.68091 .40298 m .68529 .38003 L .68488 .38732 L 0 0 .152 r
F
.6507 .39611 m .68091 .40298 L .68488 .38732 L .654 .726 .902 r
F
0 g
.67119 .41661 m
.68091 .40298 L
s
.25243 .63626 m .25288 .62492 L .24307 .62621 L .683 .77 .917 r
F
.51438 .74121 m .51497 .73306 L .51139 .74026 L .645 .732 .913 r
F
.51438 .74121 m .52095 .73495 L .51497 .73306 L F
.21974 .63799 m .20361 .63318 L .19764 .64169 L .683 .77 .917 r
F
.127 .923 .03 r
.19774 .62912 m
.19785 .63344 L
s
0 g
.19539 .65059 m
.19764 .64169 L
s
.43849 .51222 m .4658 .50378 L .44057 .50423 L .673 .757 .914 r
F
.4143 .50868 m .43849 .51222 L .44057 .50423 L F
.41161 .51244 m .43849 .51222 L .4143 .50868 L F
.64031 .50569 m .62392 .50762 L .62425 .5133 L .515 .33 .568 r
F
.64031 .50569 m .63997 .5 L .62392 .50762 L F
0 g
.61139 .51738 m
.62392 .50762 L
s
.69097 .52069 m .67882 .50451 L .67798 .51988 L .673 .758 .914 r
F
.69097 .52069 m .69832 .50573 L .67882 .50451 L F
.33963 .50606 m .31648 .5184 L .34101 .51399 L .673 .757 .914 r
F
.33963 .50606 m .31439 .50652 L .31648 .5184 L F
0 g
.31648 .5184 m
.32358 .52938 L
s
.61946 .61968 m .62041 .62381 L .62091 .62839 L .767 .554 0 r
F
.61946 .61968 m .61896 .6151 L .62041 .62381 L F
0 g
.62041 .62381 m
.62312 .62792 L
s
.49889 .74528 m .49022 .73932 L .48607 .74227 L .645 .732 .913 r
F
.50156 .74421 m .49022 .73932 L .49889 .74528 L F
.63801 .61409 m .62069 .62375 L .63897 .61987 L .683 .77 .917 r
F
.63801 .61409 m .61924 .61509 L .62069 .62375 L F
.51672 .74633 m .52077 .73866 L .51417 .74495 L .645 .732 .913 r
F
.51672 .74633 m .52588 .74141 L .52077 .73866 L F
.55912 .37343 m .52928 .38245 L .55997 .37877 L .654 .726 .902 r
F
.55912 .37343 m .52758 .37178 L .52928 .38245 L F
.5049 .73988 m .50198 .7323 L .49586 .73347 L .645 .732 .913 r
F
.50816 .73981 m .50198 .7323 L .5049 .73988 L F
.49657 .75053 m .48582 .74604 L .48314 .7496 L F
.49864 .74905 m .48582 .74604 L .49657 .75053 L F
.51139 .74026 m .5085 .73216 L .50816 .73981 L F
.51139 .74026 m .51497 .73306 L .5085 .73216 L F
.51841 .75181 m .52563 .74519 L .51647 .7501 L F
.51841 .75181 m .5295 .74861 L .52563 .74519 L F
.48582 .74604 m .47105 .7469 L .48314 .7496 L F
.36456 .49992 m .34071 .5083 L .36525 .50388 L .673 .757 .914 r
F
.36456 .49992 m .33933 .50037 L .34071 .5083 L F
.49055 .7356 m .47573 .73407 L .48643 .73854 L .645 .732 .913 r
F
.65818 .62517 m .64327 .63434 L .65991 .6278 L .683 .77 .917 r
F
.65818 .62517 m .6398 .62907 L .64327 .63434 L F
.6511 .38882 m .68529 .38003 L .65375 .37838 L .654 .726 .902 r
F
.62089 .38195 m .6511 .38882 L .65375 .37838 L F
.61752 .3867 m .6511 .38882 L .62089 .38195 L F
.47506 .74156 m .4713 .74312 L .47105 .7469 L .08 0 .404 r
F
.48607 .74227 m .47532 .73778 L .4713 .74312 L .645 .732 .913 r
F
.47506 .74156 m .47532 .73778 L .4713 .74312 L .08 0 .404 r
F
0 g
.46975 .74902 m
.4713 .74312 L
s
.53185 .75246 m .54059 .7454 L .5295 .74861 L .645 .732 .913 r
F
.53185 .75246 m .54412 .75119 L .54059 .7454 L F
.50816 .73981 m .5085 .73216 L .50198 .7323 L F
.71216 .62063 m .73264 .61369 L .71378 .61469 L .683 .77 .917 r
F
.69411 .61866 m .71216 .62063 L .71378 .61469 L F
.69207 .62149 m .71216 .62063 L .69411 .61866 L F
.52988 .74109 m .53516 .73279 L .52604 .73769 L .645 .732 .913 r
F
.52988 .74109 m .54092 .7379 L .53516 .73279 L F
.66487 .52116 m .65914 .50644 L .64064 .51138 L .673 .758 .914 r
F
.67798 .51988 m .65914 .50644 L .66487 .52116 L F
.54436 .74741 m .54109 .73785 L .54084 .74163 L .99 .751 .476 r
F
.54412 .75119 m .54436 .74741 L .54084 .74163 L F
0 g
.54436 .74741 m
.54538 .75346 L
s
.30122 .62342 m .29203 .61227 L .29251 .61685 L .932 .647 .478 r
F
.30169 .628 m .30122 .62342 L .29251 .61685 L F
0 g
.30122 .62342 m
.30653 .63132 L
s
.27883 .62557 m .28099 .61205 L .27116 .62238 L .683 .77 .917 r
F
.27883 .62557 m .29251 .61685 L .28099 .61205 L F
.22592 .63298 m .20361 .63318 L .21974 .63799 L F
.127 .923 .03 r
.19785 .63344 m
.20759 1.04293 L
s
.67798 .51988 m .67882 .50451 L .65914 .50644 L .673 .758 .914 r
F
.50156 .74421 m .49555 .73718 L .49022 .73932 L .645 .732 .913 r
F
.50463 .74362 m .49555 .73718 L .50156 .74421 L F
.73157 .51705 m .71598 .50432 L .71632 .51001 L .861 .596 .537 r
F
0 g
.73157 .51705 m
.74305 .52637 L
s
.25107 .7378 m .25134 .73403 L .26116 .73382 L .67 .442 .567 r
F
.24131 .73644 m .25134 .73403 L .25107 .7378 L .733 .498 .572 r
F
.127 .923 .03 r
.24166 .78195 m
.24255 .80992 L
s
.2382 .67265 m
.23951 .71398 L
s
.2402 .73573 m
.24031 .73931 L
s
.23963 .7177 m
.23977 .72223 L
s
.23979 .72284 m
.2402 .73573 L
s
.24131 .73644 m .24158 .73267 L .25134 .73403 L .733 .498 .572 r
F
.51417 .74495 m .51475 .73677 L .51116 .744 L .645 .732 .913 r
F
.51417 .74495 m .52077 .73866 L .51475 .73677 L F
.34538 .37197 m .32589 .37338 L .32544 .38067 L .49 .282 .525 r
F
.34538 .37197 m .34583 .36468 L .32589 .37338 L F
0 g
.31042 .38526 m
.32589 .37338 L
s
.22511 .62389 m .21213 .61661 L .20291 .6241 L .683 .77 .917 r
F
.23302 .61989 m .21213 .61661 L .22511 .62389 L F
.25161 .72626 m .25135 .73391 L .26111 .7337 L .645 .732 .913 r
F
.24513 .72535 m .25135 .73391 L .25161 .72626 L F
.24513 .72535 m .24163 .73256 L .25135 .73391 L F
.46548 .49809 m .46517 .49241 L .46315 .48051 L .83 .626 .077 r
F
0 g
.46368 .49812 m
.46488 .49353 L
s
.43969 .49287 m .46479 .49241 L .46278 .48058 L .673 .757 .914 r
F
.62115 .37463 m .65384 .37108 L .62246 .36944 L .654 .726 .902 r
F
.45923 .38767 m .45967 .38038 L .44046 .36963 L .858 .601 .549 r
F
0 g
.45967 .38038 m
.47419 .39382 L
s
.36006 .39774 m .34492 .37926 L .32498 .38796 L .654 .726 .902 r
F
.37542 .39447 m .34492 .37926 L .36006 .39774 L F
.37587 .38718 m .36843 .36705 L .34538 .37197 L F
.39224 .38664 m .36843 .36705 L .37587 .38718 L F
.40851 .38888 m .393 .36625 L .39224 .38664 L F
.40851 .38888 m .41743 .36962 L .393 .36625 L F
.42312 .40104 m .41698 .37691 L .40807 .39618 L F
.42312 .40104 m .43958 .38422 L .41698 .37691 L F
.49864 .74905 m .48996 .74309 L .48582 .74604 L .645 .732 .913 r
F
.50131 .74799 m .48996 .74309 L .49864 .74905 L F
.41399 .503 m .44026 .49855 L .41503 .499 L .673 .757 .914 r
F
.51647 .7501 m .52052 .74244 L .51392 .74873 L .645 .732 .913 r
F
.51647 .7501 m .52563 .74519 L .52052 .74244 L F
0 0 0 r
2.5 Mabswid
.23514 .63557 Mdot
.23227 .7336 m .24158 .73267 L .24131 .73644 L .793 .551 .572 r
F
.127 .923 .03 r
.5 Mabswid
.20037 .96975 m
.23291 2.29941 L
s
.19366 .69542 m
.20037 .96975 L
s
.23227 .7336 m .23254 .72983 L .24158 .73267 L .793 .551 .572 r
F
0 g
.24158 .73267 m
.25134 .73403 L
s
.50463 .74362 m .5017 .736 L .49555 .73718 L .645 .732 .913 r
F
.50791 .74355 m .5017 .736 L .50463 .74362 L F
.51116 .744 m .50825 .73586 L .50791 .74355 L F
.51116 .744 m .51475 .73677 L .50825 .73586 L F
.61996 .62426 m .62091 .62839 L .62142 .63297 L .767 .554 0 r
F
.61996 .62426 m .61946 .61968 L .62091 .62839 L F
.63833 .61868 m .62091 .62839 L .63929 .62449 L .683 .77 .917 r
F
.63833 .61868 m .61946 .61968 L .62091 .62839 L F
0 g
.62091 .62839 m
.62362 .6325 L
s
.26089 .73759 m .26116 .73382 L .27036 .73205 L .596 .379 .557 r
F
.25107 .7378 m .26116 .73382 L .26089 .73759 L .67 .442 .567 r
F
0 g
.25134 .73403 m
.26116 .73382 L
s
.65678 .6131 m .63897 .61987 L .65726 .61599 L .683 .77 .917 r
F
.65678 .6131 m .63801 .61409 L .63897 .61987 L F
.23913 .72347 m .24163 .73256 L .24513 .72535 L .645 .732 .913 r
F
.23913 .72347 m .23263 .72973 L .24163 .73256 L F
.25812 .72612 m .26111 .7337 L .27027 .73194 L F
.25161 .72626 m .26111 .7337 L .25812 .72612 L F
.49022 .73932 m .47532 .73778 L .48607 .74227 L F
.48582 .74604 m .47506 .74156 L .47105 .7469 L F
0 g
.4695 .75279 m
.47105 .7469 L
s
.43969 .49287 m .46278 .48058 L .43834 .48498 L .673 .757 .914 r
F
.41459 .49332 m .43969 .49287 L .43834 .48498 L F
.58769 .49346 m .58736 .48778 L .60702 .48585 L .672 .448 .573 r
F
.127 .923 .03 r
.59625 .4869 m
.59753 .43282 L
s
.59688 .48684 m
.59754 .43281 L
s
.56818 .49224 m .58736 .48778 L .58769 .49346 L .733 .496 .569 r
F
.127 .923 .03 r
.58733 .48778 m
.58831 .44433 L
s
.56818 .49224 m .56785 .48656 L .58736 .48778 L .733 .496 .569 r
F
.50791 .74355 m .50825 .73586 L .5017 .736 L .645 .732 .913 r
F
.64064 .51138 m .62425 .5133 L .62458 .51899 L .515 .33 .568 r
F
0 g
.61205 .52875 m
.62458 .51899 L
s
.64064 .51138 m .64031 .50569 L .62425 .5133 L .515 .33 .568 r
F
0 g
.61172 .52306 m
.62425 .5133 L
s
.127 .923 .03 r
.53019 .80041 m
.53041 .7505 L
s
.50646 6.12035 m
.50668 6.0718 L
s
.49451 8.80016 m
.50646 6.12035 L
s
0 0 0 r
2.5 Mabswid
.53041 .7505 Mdot
.127 .923 .03 r
.5 Mabswid
.52956 .80281 m
.53041 .7505 L
s
.50651 2.21911 m
.50696 2.19184 L
s
.39902 8.82554 m
.50651 2.21911 L
s
.52975 .74483 m .53504 .7365 L .52588 .74141 L .645 .732 .913 r
F
.52975 .74483 m .54084 .74163 L .53504 .7365 L F
.69351 .61407 m .71308 .61012 L .69432 .61111 L .683 .77 .917 r
F
.54412 .75119 m .54084 .74163 L .54059 .7454 L .99 .751 .476 r
F
0 g
.54412 .75119 m
.54513 .75723 L
s
.127 .923 .03 r
.54346 1.11529 m
.55182 .66768 L
s
.58815 .47223 m .58737 .48755 L .60694 .48563 L .673 .757 .914 r
F
.57521 .47142 m .58737 .48755 L .58815 .47223 L F
.57521 .47142 m .56796 .48633 L .58737 .48755 L F
.127 .923 .03 r
.58423 .47199 m
.58886 .4213 L
s
.71267 .62521 m .73315 .61827 L .71429 .61927 L .683 .77 .917 r
F
.69462 .62324 m .71267 .62521 L .71429 .61927 L F
.69258 .62607 m .71267 .62521 L .69462 .62324 L F
.27059 .61791 m .26691 .60496 L .26162 .61613 L F
.27059 .61791 m .28037 .60763 L .26691 .60496 L F
.30169 .628 m .29251 .61685 L .29298 .62143 L .932 .647 .478 r
F
0 g
.30169 .628 m
.30701 .6359 L
s
.27931 .63015 m .28147 .61663 L .27164 .62696 L .683 .77 .917 r
F
.27931 .63015 m .29298 .62143 L .28147 .61663 L F
.39224 .38664 m .393 .36625 L .36843 .36705 L .654 .726 .902 r
F
.36486 .5056 m .34101 .51399 L .36555 .50957 L .673 .757 .914 r
F
.36486 .5056 m .33963 .50606 L .34101 .51399 L F
.50131 .74799 m .4953 .74096 L .48996 .74309 L .645 .732 .913 r
F
.50438 .7474 m .4953 .74096 L .50131 .74799 L F
.25081 .74158 m .25107 .7378 L .26089 .73759 L .67 .442 .567 r
F
.24104 .74022 m .25107 .7378 L .25081 .74158 L .733 .498 .572 r
F
.24104 .74022 m .24131 .73644 L .25107 .7378 L F
.25134 .73011 m .25107 .7378 L .26089 .73759 L .644 .733 .913 r
F
.24483 .7292 m .25107 .7378 L .25134 .73011 L F
.24483 .7292 m .24131 .73644 L .25107 .7378 L F
.51392 .74873 m .5145 .74054 L .51091 .74778 L .645 .732 .913 r
F
.51392 .74873 m .52052 .74244 L .5145 .74054 L F
.41459 .49332 m .43834 .48498 L .41391 .48938 L .673 .757 .914 r
F
.60735 .49153 m .60702 .48585 L .62551 .48091 L .603 .396 .573 r
F
.58769 .49346 m .60702 .48585 L .60735 .49153 L .672 .448 .573 r
F
0 g
.58736 .48778 m
.60702 .48585 L
s
.60121 .47095 m .60694 .48563 L .62534 .48071 L .673 .757 .914 r
F
.58815 .47223 m .60694 .48563 L .60121 .47095 L F
.127 .923 .03 r
.58872 .47218 m
.58988 .42093 L
s
.73264 .61369 m .73213 .60911 L .73071 .6004 L .76 .548 0 r
F
0 g
.73085 .61379 m
.73203 .60948 L
s
.71308 .61012 m .73185 .60913 L .73044 .60046 L .683 .77 .917 r
F
.22545 .6284 m .2124 .62108 L .20314 .62861 L F
.23341 .62438 m .2124 .62108 L .22545 .6284 L F
.49055 .7356 m .48192 .72967 L .47573 .73407 L .645 .732 .913 r
F
.49586 .73347 m .48192 .72967 L .49055 .7356 L F
.2124 .62108 m .20267 .62403 L .20314 .62861 L .399 .255 .567 r
F
.2124 .62108 m .21193 .6165 L .20267 .62403 L F
0 g
.1967 .63253 m
.20267 .62403 L
s
.52604 .73769 m .52752 .72869 L .52095 .73495 L .645 .732 .913 r
F
.52604 .73769 m .53516 .73279 L .52752 .72869 L F
.127 .923 .03 r
.52156 .3667 m
.5221 .3715 L
s
.232 .73738 m .24131 .73644 L .24104 .74022 L .793 .551 .572 r
F
.127 .923 .03 r
.24144 .775 m
.24166 .78195 L
s
.23853 .73619 m
.23854 .73672 L
s
.232 .73738 m .23227 .7336 L .24131 .73644 L .793 .551 .572 r
F
.2388 .72731 m .24131 .73644 L .24483 .7292 L .644 .733 .913 r
F
.2388 .72731 m .23227 .7336 L .24131 .73644 L F
0 g
.24131 .73644 m
.25107 .7378 L
s
.50438 .7474 m .50145 .73978 L .4953 .74096 L .645 .732 .913 r
F
.50766 .74733 m .50145 .73978 L .50438 .7474 L F
.51091 .74778 m .508 .73964 L .50766 .74733 L F
.51091 .74778 m .5145 .74054 L .508 .73964 L F
.26089 .73759 m .27036 .73205 L .2701 .73582 L .596 .379 .557 r
F
.26062 .74137 m .26089 .73759 L .2701 .73582 L F
.25081 .74158 m .26089 .73759 L .26062 .74137 L .67 .442 .567 r
F
.25789 .72997 m .26089 .73759 L .2701 .73582 L .644 .733 .913 r
F
.25134 .73011 m .26089 .73759 L .25789 .72997 L F
0 g
.25107 .7378 m
.26089 .73759 L
s
.71598 .50432 m .71564 .49864 L .69765 .49436 L .795 .544 .558 r
F
0 g
.71564 .49864 m
.73089 .50568 L
s
.5587 .38072 m .52886 .38974 L .55954 .38606 L .654 .726 .902 r
F
.5587 .38072 m .52715 .37907 L .52886 .38974 L F
0 0 0 r
2.5 Mabswid
.53168 .38987 Mdot
.38949 .49378 m .38363 .47911 L .37751 .48075 L .673 .757 .914 r
F
.48996 .74309 m .47506 .74156 L .48582 .74604 L .645 .732 .913 r
F
.46548 .49809 m .46315 .48051 L .46346 .48619 L .83 .626 .077 r
F
.44026 .49855 m .46548 .49809 L .46346 .48619 L .673 .757 .914 r
F
.4658 .50378 m .46548 .49809 L .46346 .48619 L .83 .626 .077 r
F
0 g
.5 Mabswid
.46399 .50381 m
.46519 .49921 L
s
.50766 .74733 m .508 .73964 L .50145 .73978 L .645 .732 .913 r
F
.63883 .62326 m .62142 .63297 L .6398 .62907 L .683 .77 .917 r
F
.63883 .62326 m .61996 .62426 L .62142 .63297 L F
0 g
.62142 .63297 m
.62663 .64087 L
s
.5295 .74861 m .5348 .74027 L .52563 .74519 L .645 .732 .913 r
F
.5295 .74861 m .54059 .7454 L .5348 .74027 L F
.65719 .61768 m .63929 .62449 L .65767 .62059 L .683 .77 .917 r
F
.65719 .61768 m .63833 .61868 L .63929 .62449 L F
.6507 .39611 m .68488 .38732 L .65334 .38567 L .654 .726 .902 r
F
.62048 .38924 m .6507 .39611 L .65334 .38567 L F
.6171 .39399 m .6507 .39611 L .62048 .38924 L F
.48154 .73335 m .47557 .73401 L .47532 .73778 L .351 .177 .5 r
F
.48154 .73335 m .48179 .72958 L .47557 .73401 L F
0 g
.47155 .73935 m
.47557 .73401 L
s
.22456 .72947 m .23254 .72983 L .23227 .7336 L .856 .609 .565 r
F
.22456 .72947 m .22483 .7257 L .23254 .72983 L F
0 g
.23254 .72983 m
.23529 .73069 L
s
.23402 .72073 m .23263 .72973 L .23913 .72347 L .645 .732 .913 r
F
.23402 .72073 m .22496 .72562 L .23263 .72973 L F
.2701 .73582 m .27036 .73205 L .27833 .72884 L .498 .297 .538 r
F
0 g
.26455 .73316 m
.27036 .73205 L
s
.71308 .61012 m .73044 .60046 L .71214 .60434 L .683 .77 .917 r
F
.69432 .61111 m .71308 .61012 L .71214 .60434 L F
.4143 .50868 m .44057 .50423 L .41533 .50469 L .673 .757 .914 r
F
.69411 .61866 m .71378 .61469 L .69492 .61569 L .683 .77 .917 r
F
.54084 .74163 m .54109 .73785 L .53529 .73272 L .926 .677 .542 r
F
0 g
.54109 .73785 m
.54461 .74364 L
s
.26423 .72494 m .27027 .73194 L .2782 .72875 L .645 .732 .913 r
F
.25812 .72612 m .27027 .73194 L .26423 .72494 L F
.55015 .48796 m .56785 .48656 L .56818 .49224 L .794 .544 .558 r
F
.127 .923 .03 r
.55519 .48756 m
.5561 .43843 L
s
.55462 .48761 m
.55493 .44441 L
s
.55015 .48796 m .54983 .48228 L .56785 .48656 L .794 .544 .558 r
F
0 g
.56785 .48656 m
.58736 .48778 L
s
.23302 .61989 m .224 .61061 L .21213 .61661 L .683 .77 .917 r
F
.127 .923 .03 r
.22381 .55489 m
.2257 .61235 L
s
.24217 .61716 m .224 .61061 L .23302 .61989 L .683 .77 .917 r
F
.56325 .46858 m .56796 .48633 L .57521 .47142 L .673 .757 .914 r
F
.56325 .46858 m .55003 .48207 L .56796 .48633 L F
.25107 .73389 m .25081 .74158 L .26062 .74137 L .644 .733 .913 r
F
.24456 .73298 m .25081 .74158 L .25107 .73389 L F
.24456 .73298 m .24104 .74022 L .25081 .74158 L F
.127 .923 .03 r
.24042 .74288 m
.24144 .775 L
s
.24033 .73999 m
.24042 .74288 L
s
.36541 .49025 m .33928 .49469 L .36438 .49423 L .673 .757 .914 r
F
.44026 .49855 m .46346 .48619 L .4389 .49062 L F
.41503 .499 m .44026 .49855 L .4389 .49062 L F
.58801 .49914 m .58769 .49346 L .60735 .49153 L .672 .448 .573 r
F
.5685 .49793 m .58769 .49346 L .58801 .49914 L .733 .496 .569 r
F
.127 .923 .03 r
.5872 .49357 m
.5872 .49343 L
s
.5685 .49793 m .56818 .49224 L .58769 .49346 L .733 .496 .569 r
F
.58847 .47807 m .58769 .49346 L .60735 .49153 L .673 .757 .914 r
F
.57546 .47726 m .58769 .49346 L .58847 .47807 L F
.57546 .47726 m .56818 .49224 L .58769 .49346 L F
.27116 .62238 m .26747 .60937 L .26214 .6206 L .683 .77 .917 r
F
.27116 .62238 m .28099 .61205 L .26747 .60937 L F
.34492 .37926 m .32544 .38067 L .32498 .38796 L .49 .282 .525 r
F
0 g
.30951 .39983 m
.32498 .38796 L
s
.34492 .37926 m .34538 .37197 L .32544 .38067 L .49 .282 .525 r
F
0 g
.30997 .39254 m
.32544 .38067 L
s
.62089 .38195 m .65375 .37838 L .6222 .37673 L .654 .726 .902 r
F
.69432 .61111 m .71214 .60434 L .69384 .60823 L .683 .77 .917 r
F
.45923 .38767 m .44046 .36963 L .44002 .37692 L .858 .601 .549 r
F
.45879 .39496 m .45923 .38767 L .44002 .37692 L F
0 g
.45923 .38767 m
.47375 .40111 L
s
.49022 .73932 m .48154 .73335 L .47532 .73778 L .645 .732 .913 r
F
.49555 .73718 m .48154 .73335 L .49022 .73932 L F
.37542 .39447 m .36798 .37434 L .34492 .37926 L .654 .726 .902 r
F
.39179 .39393 m .36798 .37434 L .37542 .39447 L F
.40807 .39618 m .39256 .37354 L .39179 .39393 L F
.40807 .39618 m .41698 .37691 L .39256 .37354 L F
.73264 .61369 m .73071 .6004 L .73122 .60498 L .76 .548 0 r
F
.71378 .61469 m .73264 .61369 L .73122 .60498 L .683 .77 .917 r
F
.73315 .61827 m .73264 .61369 L .73122 .60498 L .76 .548 0 r
F
0 g
.73136 .61837 m
.73254 .61406 L
s
.52588 .74141 m .52737 .73237 L .52077 .73866 L .645 .732 .913 r
F
.52588 .74141 m .53504 .7365 L .52737 .73237 L F
.26162 .61613 m .25237 .60458 L .25192 .61587 L .683 .77 .917 r
F
.26162 .61613 m .26691 .60496 L .25237 .60458 L F
.23853 .73108 m .24104 .74022 L .24456 .73298 L .644 .733 .913 r
F
.127 .923 .03 r
.2206 .67845 m
.22068 .68208 L
s
.23867 .74337 m
.23925 .77398 L
s
.23859 .73945 m
.23867 .74337 L
s
.23853 .73108 m .232 .73738 L .24104 .74022 L .644 .733 .913 r
F
0 g
.24104 .74022 m
.25081 .74158 L
s
.22592 .63298 m .21287 .62566 L .20361 .63318 L .683 .77 .917 r
F
.23388 .62896 m .21287 .62566 L .22592 .63298 L F
.21287 .62566 m .20314 .62861 L .20361 .63318 L .399 .255 .567 r
F
0 g
.19764 .64169 m
.20361 .63318 L
s
.21287 .62566 m .2124 .62108 L .20314 .62861 L .399 .255 .567 r
F
0 g
.19717 .63711 m
.20314 .62861 L
s
.26062 .74137 m .2701 .73582 L .26983 .7396 L .596 .379 .557 r
F
.25762 .73374 m .26062 .74137 L .26983 .7396 L .644 .733 .913 r
F
.25107 .73389 m .26062 .74137 L .25762 .73374 L F
0 g
.25081 .74158 m
.26062 .74137 L
s
.34132 .48673 m .31417 .49514 L .33928 .49469 L .673 .757 .914 r
F
.36541 .49025 m .34132 .48673 L .33928 .49469 L F
.41503 .499 m .4389 .49062 L .41434 .49504 L F
.60735 .49153 m .62551 .48091 L .62585 .48659 L .603 .396 .573 r
F
.60768 .49722 m .60735 .49153 L .62585 .48659 L F
.58801 .49914 m .60735 .49153 L .60768 .49722 L .672 .448 .573 r
F
.60159 .47679 m .60735 .49153 L .62585 .48659 L .673 .757 .914 r
F
.58847 .47807 m .60735 .49153 L .60159 .47679 L F
0 g
.58769 .49346 m
.60735 .49153 L
s
.48128 .73713 m .47532 .73778 L .47506 .74156 L .351 .177 .5 r
F
.48128 .73713 m .48154 .73335 L .47532 .73778 L F
0 g
.4713 .74312 m
.47532 .73778 L
s
.5309 .35411 m .5008 .34727 L .49694 .36287 L .654 .726 .902 r
F
.49991 .35446 m .49647 .36285 L .49604 .37013 L 0 0 .141 r
F
0 g
.49701 .36621 m
.49765 .37022 L
s
.49991 .35446 m .50035 .34717 L .49647 .36285 L 0 0 .141 r
F
.49586 .73347 m .48987 .72648 L .48192 .72967 L .645 .732 .913 r
F
.50198 .7323 m .48987 .72648 L .49586 .73347 L F
.5309 .35411 m .49694 .36287 L .52832 .36451 L .654 .726 .902 r
F
.22429 .73325 m .23227 .7336 L .232 .73738 L .856 .609 .565 r
F
.22429 .73325 m .22456 .72947 L .23227 .7336 L F
.23366 .72455 m .23227 .7336 L .2388 .72731 L .644 .733 .913 r
F
.23366 .72455 m .22456 .72947 L .23227 .7336 L F
0 g
.23227 .7336 m
.23502 .73446 L
s
.561 .36096 m .52832 .36451 L .5597 .36615 L .654 .726 .902 r
F
.561 .36096 m .5309 .35411 L .52832 .36451 L F
.52095 .73495 m .51855 .72586 L .51497 .73306 L .645 .732 .913 r
F
.52095 .73495 m .52752 .72869 L .51855 .72586 L F
.2701 .73582 m .27833 .72884 L .27806 .73261 L .498 .297 .538 r
F
.26983 .7396 m .2701 .73582 L .27806 .73261 L F
.26402 .72879 m .2701 .73582 L .27806 .73261 L .644 .733 .913 r
F
.25789 .72997 m .2701 .73582 L .26402 .72879 L F
0 g
.26428 .73694 m
.2701 .73582 L
s
.6577 .62226 m .6398 .62907 L .65818 .62517 L .683 .77 .917 r
F
.6577 .62226 m .63883 .62326 L .6398 .62907 L F
.54084 .74163 m .53529 .73272 L .53504 .7365 L .926 .677 .542 r
F
.54059 .7454 m .54084 .74163 L .53504 .7365 L F
0 g
.54084 .74163 m
.54436 .74741 L
s
.67555 .61211 m .6713 .60145 L .66671 .60282 L .683 .77 .917 r
F
.62246 .36944 m .65219 .36046 L .62163 .36413 L .654 .726 .902 r
F
.62246 .36944 m .65384 .37108 L .65219 .36046 L F
.29251 .61685 m .29203 .61227 L .28052 .60748 L .86 .591 .531 r
F
0 g
.29203 .61227 m
.30074 .61884 L
s
.65384 .37108 m .68276 .35679 L .65219 .36046 L .654 .726 .902 r
F
.65384 .37108 m .68522 .37272 L .68276 .35679 L F
.127 .923 .03 r
.65739 .35983 m
.65811 .33609 L
s
.68529 .38003 m .68569 .37274 L .68322 .35673 L .913 .734 .239 r
F
0 g
.68386 .37996 m
.68491 .37581 L
s
.71378 .61469 m .73122 .60498 L .71283 .60888 L .683 .77 .917 r
F
.69492 .61569 m .71378 .61469 L .71283 .60888 L F
.65881 .50075 m .63997 .5 L .64031 .50569 L .603 .396 .574 r
F
.65881 .50075 m .65847 .49507 L .63997 .5 L F
0 g
.62392 .50762 m
.63997 .5 L
s
.69462 .62324 m .71429 .61927 L .69543 .62027 L .683 .77 .917 r
F
.71598 .50432 m .69765 .49436 L .69798 .50004 L .795 .544 .558 r
F
.71632 .51001 m .71598 .50432 L .69798 .50004 L F
0 g
.71598 .50432 m
.73123 .51136 L
s
.24217 .61716 m .23773 .6065 L .224 .61061 L .683 .77 .917 r
F
.25192 .61587 m .23773 .6065 L .24217 .61716 L F
.34132 .48673 m .31722 .48321 L .31417 .49514 L .673 .757 .914 r
F
.31716 .48884 m .31379 .49515 L .31409 .50083 L 0 0 .313 r
F
0 g
.3145 .49921 m
.31479 .50082 L
s
.31716 .48884 m .31686 .48315 L .31379 .49515 L 0 0 .313 r
F
.4658 .50378 m .46346 .48619 L .46377 .49188 L .83 .626 .077 r
F
.44057 .50423 m .4658 .50378 L .46377 .49188 L .673 .757 .914 r
F
0 g
.46267 .51575 m
.4658 .50378 L
s
.39179 .39393 m .39256 .37354 L .36798 .37434 L .654 .726 .902 r
F
.25192 .61587 m .25237 .60458 L .23773 .6065 L .683 .77 .917 r
F
.23341 .62438 m .22434 .61505 L .2124 .62108 L F
.2426 .62163 m .22434 .61505 L .23341 .62438 L F
.127 .923 .03 r
.52246 .37471 m
.52292 .37885 L
s
.27164 .62696 m .26794 .61395 L .26262 .62518 L .683 .77 .917 r
F
.27164 .62696 m .28147 .61663 L .26794 .61395 L F
.41391 .48938 m .43366 .47768 L .41157 .48573 L .673 .757 .914 r
F
.41391 .48938 m .43834 .48498 L .43366 .47768 L F
.55048 .49365 m .56818 .49224 L .5685 .49793 L .794 .544 .558 r
F
.127 .923 .03 r
.55458 .49332 m
.55461 .48902 L
s
.55508 .49328 m
.55516 .48915 L
s
.55048 .49365 m .55015 .48796 L .56818 .49224 L .794 .544 .558 r
F
.56344 .4744 m .56818 .49224 L .57546 .47726 L .673 .757 .914 r
F
.56344 .4744 m .55015 .48796 L .56818 .49224 L F
0 g
.56818 .49224 m
.58769 .49346 L
s
.62585 .48659 m .62551 .48091 L .64158 .47329 L .515 .33 .567 r
F
0 g
.61725 .48312 m
.62551 .48091 L
s
.48996 .74309 m .48128 .73713 L .47506 .74156 L .645 .732 .913 r
F
0 g
.47105 .7469 m
.47506 .74156 L
s
.4953 .74096 m .48128 .73713 L .48996 .74309 L .645 .732 .913 r
F
.65758 .61014 m .63801 .61409 L .65678 .6131 L .683 .77 .917 r
F
.52563 .74519 m .52713 .73614 L .52052 .74244 L .645 .732 .913 r
F
.52563 .74519 m .5348 .74027 L .52713 .73614 L F
.61348 .46767 m .62534 .48071 L .64132 .47313 L .673 .757 .914 r
F
.60121 .47095 m .62534 .48071 L .61348 .46767 L F
.69492 .61569 m .71283 .60888 L .69444 .61278 L .683 .77 .917 r
F
.36559 .49592 m .33933 .50037 L .36456 .49992 L .673 .757 .914 r
F
.44057 .50423 m .46377 .49188 L .43921 .4963 L F
.41533 .50469 m .44057 .50423 L .43921 .4963 L F
.5888 .48376 m .58801 .49914 L .60768 .49722 L F
.127 .923 .03 r
.59523 .53025 m
.59594 .50007 L
s
.59594 .50007 m
.59598 .49836 L
s
.59641 .5251 m
.59672 .49979 L
s
.59672 .49979 m
.59674 .49829 L
s
.57579 .48295 m .58801 .49914 L .5888 .48376 L .673 .757 .914 r
F
.127 .923 .03 r
.58502 .59051 m
.5868 .51145 L
s
.5868 .51145 m
.58708 .49909 L
s
.57579 .48295 m .5685 .49793 L .58801 .49914 L .673 .757 .914 r
F
.50198 .7323 m .49905 .72471 L .48987 .72648 L .645 .732 .913 r
F
.5085 .73216 m .49905 .72471 L .50198 .7323 L F
.73315 .61827 m .73122 .60498 L .73174 .60956 L .76 .548 0 r
F
.71429 .61927 m .73315 .61827 L .73174 .60956 L .683 .77 .917 r
F
0 g
.73072 .62718 m
.73315 .61827 L
s
.51497 .73306 m .50884 .7245 L .5085 .73216 L .645 .732 .913 r
F
.51497 .73306 m .51855 .72586 L .50884 .7245 L F
.26214 .6206 m .25285 .60899 L .2524 .62034 L .683 .77 .917 r
F
.26214 .6206 m .26747 .60937 L .25285 .60899 L F
.23339 .72833 m .232 .73738 L .23853 .73108 L .644 .733 .913 r
F
.23339 .72833 m .22429 .73325 L .232 .73738 L F
0 g
.232 .73738 m
.24104 .74022 L
s
.49555 .73718 m .48953 .73015 L .48154 .73335 L .645 .732 .913 r
F
.5017 .736 m .48953 .73015 L .49555 .73718 L F
.2187 .72434 m .22483 .7257 L .22456 .72947 L .924 .676 .544 r
F
.2187 .72434 m .21897 .72056 L .22483 .7257 L F
0 g
.22483 .7257 m
.2282 .7275 L
s
.52077 .73866 m .51835 .72953 L .51475 .73677 L .645 .732 .913 r
F
.52077 .73866 m .52737 .73237 L .51835 .72953 L F
.26983 .7396 m .27806 .73261 L .2778 .73639 L .498 .297 .538 r
F
.26376 .73256 m .26983 .7396 L .2778 .73639 L .644 .733 .913 r
F
.25762 .73374 m .26983 .7396 L .26376 .73256 L F
0 g
.26062 .74137 m
.26983 .7396 L
s
.23014 .71732 m .22496 .72562 L .23402 .72073 L .645 .732 .913 r
F
.23014 .71732 m .21914 .72051 L .22496 .72562 L F
.54059 .7454 m .53504 .7365 L .5348 .74027 L .926 .677 .542 r
F
0 g
.54059 .7454 m
.54412 .75119 L
s
.27806 .73261 m .27833 .72884 L .28451 .72441 L .348 .174 .498 r
F
0 g
.27263 .73113 m
.27833 .72884 L
s
.127 .923 .03 r
.28345 .67069 m
.28418 .72464 L
s
.5085 .73216 m .50884 .7245 L .49905 .72471 L .645 .732 .913 r
F
.63961 .60818 m .61924 .61509 L .63801 .61409 L .683 .77 .917 r
F
.65758 .61014 m .63961 .60818 L .63801 .61409 L F
.26951 .72281 m .2782 .72875 L .28435 .72434 L .645 .732 .913 r
F
.127 .923 .03 r
.28437 .73879 m
.28529 .80644 L
s
.28418 .72482 m
.28437 .73879 L
s
.26423 .72494 m .2782 .72875 L .26951 .72281 L .645 .732 .913 r
F
.34138 .49238 m .31409 .50083 L .33933 .50037 L .673 .757 .914 r
F
.36559 .49592 m .34138 .49238 L .33933 .50037 L F
.69384 .60823 m .7087 .59909 L .69212 .6056 L .683 .77 .917 r
F
.69384 .60823 m .71214 .60434 L .7087 .59909 L F
.41533 .50469 m .43921 .4963 L .41465 .50073 L .673 .757 .914 r
F
.29251 .61685 m .28052 .60748 L .28099 .61205 L .86 .591 .531 r
F
.29298 .62143 m .29251 .61685 L .28099 .61205 L F
0 g
.29251 .61685 m
.30122 .62342 L
s
.60768 .49722 m .62585 .48659 L .62618 .49228 L .603 .396 .573 r
F
.60192 .48247 m .60768 .49722 L .62618 .49228 L .673 .757 .914 r
F
.5888 .48376 m .60768 .49722 L .60192 .48247 L F
0 g
.58801 .49914 m
.60768 .49722 L
s
.71429 .61927 m .73174 .60956 L .71334 .61346 L .683 .77 .917 r
F
.69543 .62027 m .71429 .61927 L .71334 .61346 L F
.127 .923 .03 r
.41398 4.83442 m
.49627 8.79949 L
s
.38253 3.31862 m
.41398 4.83442 L
s
0 0 0 r
2.5 Mabswid
.32423 .50929 Mdot
.127 .923 .03 r
.5 Mabswid
.37917 6.95567 m
.3951 8.82422 L
s
.2426 .62163 m .23814 .61092 L .22434 .61505 L .683 .77 .917 r
F
.2524 .62034 m .23814 .61092 L .2426 .62163 L F
.36807 .48652 m .34132 .48673 L .36541 .49025 L .673 .757 .914 r
F
0 0 0 r
2.5 Mabswid
.66416 .513 Mdot
.127 .923 .03 r
.5 Mabswid
.40147 8.82428 m
.48641 6.13678 L
s
.23388 .62896 m .22481 .61963 L .21287 .62566 L .683 .77 .917 r
F
.24307 .62621 m .22481 .61963 L .23388 .62896 L F
.62048 .38924 m .65334 .38567 L .62179 .38402 L .654 .726 .902 r
F
.2524 .62034 m .25285 .60899 L .23814 .61092 L .683 .77 .917 r
F
.48953 .73015 m .48179 .72958 L .48154 .73335 L .5 .299 .539 r
F
.48953 .73015 m .48978 .72637 L .48179 .72958 L F
0 g
.47557 .73401 m
.48179 .72958 L
s
.63961 .60818 m .62163 .60621 L .61924 .61509 L .683 .77 .917 r
F
.62186 .61076 m .61896 .6151 L .61946 .61968 L 0 0 .393 r
F
0 g
.61962 .61908 m
.61972 .61967 L
s
.62186 .61076 m .62136 .60618 L .61896 .6151 L 0 0 .393 r
F
.65914 .50644 m .64031 .50569 L .64064 .51138 L .603 .396 .574 r
F
0 g
.62458 .51899 m
.64064 .51138 L
s
.65914 .50644 m .65881 .50075 L .64031 .50569 L .603 .396 .574 r
F
0 g
.62425 .5133 m
.64031 .50569 L
s
.69798 .50004 m .69765 .49436 L .67815 .49314 L .733 .496 .569 r
F
0 g
.69765 .49436 m
.71564 .49864 L
s
.71632 .51001 m .69798 .50004 L .69832 .50573 L .795 .544 .558 r
F
0 g
.71632 .51001 m
.73157 .51705 L
s
.45879 .39496 m .44002 .37692 L .43958 .38422 L .858 .601 .549 r
F
0 g
.45879 .39496 m
.47332 .4084 L
s
.53504 .7365 m .53529 .73272 L .52762 .72859 L .856 .609 .564 r
F
0 g
.53529 .73272 m
.54109 .73785 L
s
.31746 .49453 m .31409 .50083 L .31439 .50652 L 0 0 .313 r
F
0 g
.3148 .50489 m
.31509 .5065 L
s
.34138 .49238 m .31716 .48884 L .31409 .50083 L .673 .757 .914 r
F
.31746 .49453 m .31716 .48884 L .31409 .50083 L 0 0 .313 r
F
.3901 .50515 m .38421 .49041 L .37806 .49205 L .673 .757 .914 r
F
.3901 .50515 m .39728 .49017 L .39077 .48976 L F
.658 .61471 m .63833 .61868 L .65719 .61768 L .683 .77 .917 r
F
.5017 .736 m .49876 .72837 L .48953 .73015 L .645 .732 .913 r
F
.50825 .73586 m .49876 .72837 L .5017 .736 L F
.51475 .73677 m .50859 .72816 L .50825 .73586 L F
.51475 .73677 m .51835 .72953 L .50859 .72816 L F
.69543 .62027 m .71334 .61346 L .69495 .61736 L .683 .77 .917 r
F
.24563 .7172 m .23913 .72347 L .24513 .72535 L .645 .732 .913 r
F
.25513 .71853 m .25812 .72612 L .26423 .72494 L F
.25188 .7186 m .25812 .72612 L .25513 .71853 L F
0 0 0 r
2.5 Mabswid
.66544 .62321 Mdot
.4953 .74096 m .48928 .73392 L .48128 .73713 L .645 .732 .913 r
F
.50145 .73978 m .48928 .73392 L .4953 .74096 L F
.21843 .72811 m .22456 .72947 L .22429 .73325 L .924 .676 .544 r
F
.21843 .72811 m .2187 .72434 L .22456 .72947 L F
.22976 .72113 m .22456 .72947 L .23366 .72455 L .644 .733 .913 r
F
.22976 .72113 m .2187 .72434 L .22456 .72947 L F
0 g
.5 Mabswid
.22456 .72947 m
.22793 .73128 L
s
.52052 .74244 m .5181 .7333 L .5145 .74054 L .645 .732 .913 r
F
.52052 .74244 m .52713 .73614 L .5181 .7333 L F
.59023 .37533 m .5859 .37232 L .58485 .37319 L .675 .735 .895 r
F
.59023 .37533 m .58723 .37166 L .5859 .37232 L F
.41434 .49504 m .43419 .48329 L .41199 .49138 L .673 .757 .914 r
F
.41434 .49504 m .4389 .49062 L .43419 .48329 L F
.26262 .62518 m .25332 .61357 L .25288 .62492 L .683 .77 .917 r
F
.26262 .62518 m .26794 .61395 L .25332 .61357 L F
.53017 .36133 m .49604 .37013 L .52758 .37178 L .654 .726 .902 r
F
.53017 .36133 m .49991 .35446 L .49604 .37013 L F
.49948 .36175 m .49604 .37013 L .49561 .37742 L 0 0 .141 r
F
0 g
.49658 .37349 m
.49722 .37751 L
s
.49948 .36175 m .49991 .35446 L .49604 .37013 L 0 0 .141 r
F
.53484 .48091 m .54983 .48228 L .55015 .48796 L .86 .596 .538 r
F
.53484 .48091 m .53452 .47522 L .54983 .48228 L F
0 g
.54983 .48228 m
.55461 .48341 L
s
.56377 .48009 m .5685 .49793 L .57579 .48295 L .673 .757 .914 r
F
.56377 .48009 m .55048 .49365 L .5685 .49793 L F
0 g
.5685 .49793 m
.58801 .49914 L
s
.127 .923 .03 r
.55322 .59286 m
.5548 .5083 L
s
.5548 .5083 m
.55505 .49473 L
s
.55389 .5927 m
.55448 .5085 L
s
.55448 .5085 m
.55458 .49462 L
s
.62585 .48659 m .64158 .47329 L .64191 .47897 L .515 .33 .567 r
F
.62618 .49228 m .62585 .48659 L .64191 .47897 L F
.61393 .47349 m .62585 .48659 L .64191 .47897 L .673 .757 .914 r
F
.60159 .47679 m .62585 .48659 L .61393 .47349 L F
0 g
.61758 .4888 m
.62585 .48659 L
s
.56042 .36821 m .52758 .37178 L .55912 .37343 L .654 .726 .902 r
F
.56042 .36821 m .53017 .36133 L .52758 .37178 L F
.27806 .73261 m .28451 .72441 L .28424 .72818 L .348 .174 .498 r
F
.2778 .73639 m .27806 .73261 L .28424 .72818 L F
.26933 .72665 m .27806 .73261 L .28424 .72818 L .644 .733 .913 r
F
.26402 .72879 m .27806 .73261 L .26933 .72665 L F
0 g
.27236 .73491 m
.27806 .73261 L
s
.50825 .73586 m .50859 .72816 L .49876 .72837 L .645 .732 .913 r
F
.55309 .4639 m .55003 .48207 L .56325 .46858 L .673 .757 .914 r
F
.55309 .4639 m .53479 .47505 L .55003 .48207 L F
.59028 .36543 m .5872 .3615 L .58865 .36557 L .675 .735 .895 r
F
.59028 .36543 m .59046 .36123 L .5872 .3615 L F
.59035 .36826 m .59053 .36404 L .58725 .36431 L F
.59041 .37111 m .58732 .36716 L .58877 .37125 L F
.59041 .37111 m .5906 .36689 L .58732 .36716 L F
.59046 .36123 m .58575 .35743 L .5872 .3615 L F
.59046 .36123 m .59065 .35703 L .58575 .35743 L F
.59053 .36404 m .58579 .36022 L .58725 .36431 L F
.59053 .36404 m .59072 .35982 L .58579 .36022 L F
.5906 .36689 m .59078 .36267 L .58586 .36307 L F
.59072 .35982 m .58573 .35737 L .58579 .36022 L .665 .424 .545 r
F
.59072 .35982 m .59065 .35697 L .58573 .35737 L F
.59078 .36267 m .58579 .36022 L .58586 .36307 L F
.59078 .36267 m .59072 .35982 L .58579 .36022 L F
.59066 .37508 m .59157 .35468 L .58337 .35494 L .654 .726 .902 r
F
0 g
.587 .37405 m
.58701 .37839 L
s
0 0 0 r
2.5 Mabswid
.66707 .62258 Mdot
.6222 .37673 m .65209 .36771 L .62137 .3714 L .654 .726 .902 r
F
.6222 .37673 m .65375 .37838 L .65209 .36771 L F
0 0 0 r
.52335 .38271 Mdot
.36589 .50161 m .33963 .50606 L .36486 .5056 L .673 .757 .914 r
F
.65375 .37838 m .68282 .36402 L .65209 .36771 L .654 .726 .902 r
F
.65375 .37838 m .68529 .38003 L .68282 .36402 L F
.65961 .60732 m .63961 .60818 L .65758 .61014 L .683 .77 .917 r
F
.68529 .38003 m .68322 .35673 L .68282 .36402 L .913 .734 .239 r
F
.68488 .38732 m .68529 .38003 L .68282 .36402 L F
0 g
.5 Mabswid
.68345 .38725 m
.68451 .3831 L
s
.63993 .61274 m .61946 .61968 L .63833 .61868 L .683 .77 .917 r
F
.658 .61471 m .63993 .61274 L .63833 .61868 L F
.43834 .48498 m .45576 .46963 L .43366 .47768 L .673 .757 .914 r
F
.43834 .48498 m .46278 .48058 L .45576 .46963 L F
.36843 .36705 m .34583 .36468 L .34538 .37197 L .591 .366 .543 r
F
.36843 .36705 m .36888 .35976 L .34583 .36468 L F
0 g
.32589 .37338 m
.34583 .36468 L
s
.38793 .60541 m .38744 .60083 L .40215 .5989 L .673 .453 .578 r
F
.127 .923 .03 r
.43061 .60496 m
.43089 .53448 L
s
.37332 .60502 m .38744 .60083 L .38793 .60541 L .733 .497 .57 r
F
.127 .923 .03 r
.38068 .54362 m
.38079 .60281 L
s
.38068 .54362 m
.38149 .6026 L
s
.37332 .60502 m .37284 .60045 L .38744 .60083 L .733 .497 .57 r
F
.22434 .61505 m .21193 .6165 L .2124 .62108 L .521 .342 .579 r
F
.22434 .61505 m .22387 .61047 L .21193 .6165 L F
0 g
.20267 .62403 m
.21193 .6165 L
s
.127 .923 .03 r
.21839 .54237 m
.22368 .61056 L
s
.21915 .61005 m
.21924 .61439 L
s
.67656 .62127 m .68655 .61094 L .68206 .61004 L .683 .77 .917 r
F
.69444 .61278 m .70938 .6036 L .69271 .61015 L F
.69444 .61278 m .71283 .60888 L .70938 .6036 L F
.71214 .60434 m .72528 .59258 L .7087 .59909 L F
.71214 .60434 m .73044 .60046 L .72528 .59258 L F
.38795 .58936 m .38745 .60066 L .40208 .59874 L F
.37826 .5891 m .38745 .60066 L .38795 .58936 L F
.127 .923 .03 r
.32423 .50929 m
.32478 .57464 L
s
.32423 .50929 m
.32558 .57435 L
s
.37826 .5891 m .37292 .60028 L .38745 .60066 L .683 .77 .917 r
F
.29298 .62143 m .28099 .61205 L .28147 .61663 L .86 .591 .531 r
F
0 g
.29298 .62143 m
.30169 .628 L
s
.67848 .49882 m .65847 .49507 L .65881 .50075 L .672 .448 .573 r
F
.67848 .49882 m .67815 .49314 L .65847 .49507 L F
0 g
.63997 .5 m
.65847 .49507 L
s
.44002 .37692 m .44046 .36963 L .41787 .36232 L .794 .542 .556 r
F
0 g
.44046 .36963 m
.45967 .38038 L
s
.25161 .72241 m .25134 .73011 L .25789 .72997 L .644 .733 .913 r
F
.24835 .72196 m .25134 .73011 L .25161 .72241 L F
.24835 .72196 m .24483 .7292 L .25134 .73011 L F
.40263 .60347 m .40215 .5989 L .41596 .59477 L .606 .404 .582 r
F
.38793 .60541 m .40215 .5989 L .40263 .60347 L .673 .453 .578 r
F
0 g
.38744 .60083 m
.40215 .5989 L
s
.24307 .62621 m .23861 .6155 L .22481 .61963 L .683 .77 .917 r
F
.25288 .62492 m .23861 .6155 L .24307 .62621 L F
.48928 .73392 m .48154 .73335 L .48128 .73713 L .5 .299 .539 r
F
0 g
.47506 .74156 m
.48128 .73713 L
s
.48928 .73392 m .48953 .73015 L .48154 .73335 L .5 .299 .539 r
F
0 g
.47532 .73778 m
.48154 .73335 L
s
.39771 .58807 m .40208 .59874 L .41583 .59463 L .683 .77 .917 r
F
.38795 .58936 m .40208 .59874 L .39771 .58807 L F
.41157 .48573 m .42596 .47148 L .40772 .48263 L .673 .757 .914 r
F
.41157 .48573 m .43366 .47768 L .42596 .47148 L F
.56435 .35622 m .5309 .35411 L .561 .36096 L .654 .726 .902 r
F
.53504 .7365 m .52762 .72859 L .52737 .73237 L .856 .609 .564 r
F
.5348 .74027 m .53504 .7365 L .52737 .73237 L F
0 g
.53504 .7365 m
.54084 .74163 L
s
.34168 .49807 m .31439 .50652 L .33963 .50606 L .673 .757 .914 r
F
.36589 .50161 m .34168 .49807 L .33963 .50606 L F
.24308 .71583 m .23402 .72073 L .23913 .72347 L .645 .732 .913 r
F
.25288 .62492 m .25332 .61357 L .23861 .6155 L .683 .77 .917 r
F
.25819 .71794 m .26423 .72494 L .26951 .72281 L .645 .732 .913 r
F
.25513 .71853 m .26423 .72494 L .25819 .71794 L F
.62163 .36413 m .64637 .35033 L .61872 .35907 L .654 .726 .902 r
F
.62163 .36413 m .65219 .36046 L .64637 .35033 L F
.62236 .61534 m .61946 .61968 L .61996 .62426 L 0 0 .393 r
F
0 g
.62012 .62366 m
.62022 .62425 L
s
.63993 .61274 m .62186 .61076 L .61946 .61968 L .683 .77 .917 r
F
.62236 .61534 m .62186 .61076 L .61946 .61968 L 0 0 .393 r
F
.50145 .73978 m .49851 .73215 L .48928 .73392 L .645 .732 .913 r
F
.508 .73964 m .49851 .73215 L .50145 .73978 L F
.24533 .72101 m .24483 .7292 L .24835 .72196 L .644 .733 .913 r
F
.24533 .72101 m .2388 .72731 L .24483 .7292 L F
.5145 .74054 m .50834 .73194 L .508 .73964 L .645 .732 .913 r
F
.5145 .74054 m .5181 .7333 L .50834 .73194 L F
.69212 .6056 m .703 .59472 L .68927 .60342 L .683 .77 .917 r
F
.69212 .6056 m .7087 .59909 L .703 .59472 L F
.25488 .72234 m .25789 .72997 L .26402 .72879 L .644 .733 .913 r
F
.25161 .72241 m .25789 .72997 L .25488 .72234 L F
.6585 .61929 m .63883 .62326 L .6577 .62226 L .683 .77 .917 r
F
.69798 .50004 m .67815 .49314 L .67848 .49882 L .733 .496 .569 r
F
0 g
.65847 .49507 m
.67815 .49314 L
s
.67815 .49314 m
.69765 .49436 L
s
.36827 .49217 m .34138 .49238 L .36559 .49592 L .673 .757 .914 r
F
.22949 .72491 m .22429 .73325 L .23339 .72833 L .644 .733 .913 r
F
.22949 .72491 m .21843 .72811 L .22429 .73325 L F
0 g
.22429 .73325 m
.232 .73738 L
s
.127 .923 .03 r
.22619 .62723 m
.22821 .68841 L
s
.29777 2.79503 m
.49608 8.8006 L
s
0 0 0 r
2.5 Mabswid
.22619 .62723 Mdot
.2778 .73639 m .28424 .72818 L .28398 .73196 L .348 .174 .498 r
F
.26907 .73042 m .2778 .73639 L .28398 .73196 L .644 .733 .913 r
F
.26376 .73256 m .2778 .73639 L .26907 .73042 L F
0 g
.5 Mabswid
.26983 .7396 m
.2778 .73639 L
s
.5859 .37232 m .57948 .37105 L .58485 .37319 L .675 .735 .895 r
F
.508 .73964 m .50834 .73194 L .49851 .73215 L .645 .732 .913 r
F
.69832 .50573 m .69798 .50004 L .67848 .49882 L .733 .496 .569 r
F
0 g
.69798 .50004 m
.71598 .50432 L
s
.34168 .49807 m .31746 .49453 L .31439 .50652 L .673 .757 .914 r
F
0 g
.31439 .50652 m
.31648 .5184 L
s
.35981 .60234 m .37284 .60045 L .37332 .60502 L .794 .542 .556 r
F
.35981 .60234 m .35932 .59776 L .37284 .60045 L F
0 g
.37284 .60045 m
.38744 .60083 L
s
.66003 .61187 m .63993 .61274 L .658 .61471 L .683 .77 .917 r
F
.64044 .61732 m .61996 .62426 L .63883 .62326 L F
.6585 .61929 m .64044 .61732 L .63883 .62326 L F
.38841 .60999 m .38793 .60541 L .40263 .60347 L .673 .453 .578 r
F
.3738 .6096 m .38793 .60541 L .38841 .60999 L .733 .497 .57 r
F
.127 .923 .03 r
.38153 .60524 m
.38156 .6073 L
s
.38079 .60522 m
.3808 .60753 L
s
.3738 .6096 m .37332 .60502 L .38793 .60541 L .733 .497 .57 r
F
.38843 .59405 m .38793 .60541 L .40263 .60347 L .683 .77 .917 r
F
.37869 .59379 m .38793 .60541 L .38843 .59405 L F
.127 .923 .03 r
.32478 .57464 m
.32482 .579 L
s
.32558 .57435 m
.32567 .57869 L
s
.37869 .59379 m .37332 .60502 L .38793 .60541 L .683 .77 .917 r
F
.36929 .58732 m .37292 .60028 L .37826 .5891 L F
.36929 .58732 m .35947 .59761 L .37292 .60028 L F
.22481 .61963 m .2124 .62108 L .21287 .62566 L .521 .342 .579 r
F
0 g
.20361 .63318 m
.21287 .62566 L
s
.22481 .61963 m .22434 .61505 L .2124 .62108 L .521 .342 .579 r
F
0 g
.20314 .62861 m
.2124 .62108 L
s
.127 .923 .03 r
.21924 .61439 m
.2206 .67845 L
s
.41465 .50073 m .4345 .48897 L .4123 .49706 L .673 .757 .914 r
F
.41465 .50073 m .43921 .4963 L .4345 .48897 L F
.36807 .48652 m .34665 .47925 L .34132 .48673 L F
.3722 .48327 m .34665 .47925 L .36807 .48652 L F
.53516 .48659 m .55015 .48796 L .55048 .49365 L .86 .596 .538 r
F
.53516 .48659 m .53484 .48091 L .55015 .48796 L F
.55323 .46969 m .55015 .48796 L .56344 .4744 L .673 .757 .914 r
F
.55323 .46969 m .53484 .48091 L .55015 .48796 L F
0 g
.55015 .48796 m
.55494 .4891 L
s
.62618 .49228 m .64191 .47897 L .64224 .48466 L .515 .33 .567 r
F
.61426 .47918 m .62618 .49228 L .64224 .48466 L .673 .757 .914 r
F
.60192 .48247 m .62618 .49228 L .61426 .47918 L F
0 g
.60768 .49722 m
.62618 .49228 L
s
.28099 .61205 m .28052 .60748 L .26699 .60479 L .794 .542 .556 r
F
0 g
.28052 .60748 m
.29203 .61227 L
s
.5859 .37232 m .58156 .36931 L .57948 .37105 L .675 .735 .895 r
F
.58723 .37166 m .58156 .36931 L .5859 .37232 L F
.25134 .72619 m .25107 .73389 L .25762 .73374 L .644 .733 .913 r
F
.24808 .72573 m .25107 .73389 L .25134 .72619 L F
.24808 .72573 m .24456 .73298 L .25107 .73389 L F
.69495 .61736 m .70989 .60818 L .69322 .61473 L .683 .77 .917 r
F
.69495 .61736 m .71334 .61346 L .70989 .60818 L F
.71283 .60888 m .72604 .59706 L .70938 .6036 L F
.71283 .60888 m .73122 .60498 L .72604 .59706 L F
.73122 .60498 m .73071 .6004 L .72553 .59248 L .98 .687 .328 r
F
0 g
.73071 .6004 m
.73213 .60911 L
s
.21511 .71854 m .21897 .72056 L .2187 .72434 L .989 .751 .482 r
F
.21511 .71854 m .21538 .71477 L .21897 .72056 L F
0 g
.21897 .72056 m
.22214 .72334 L
s
.49876 .72837 m .48978 .72637 L .48953 .73015 L .597 .38 .557 r
F
.49876 .72837 m .49901 .7246 L .48978 .72637 L F
0 g
.48179 .72958 m
.48978 .72637 L
s
.22775 .71348 m .21914 .72051 L .23014 .71732 L .645 .732 .913 r
F
.22775 .71348 m .21556 .71475 L .21914 .72051 L F
.24276 .71963 m .2388 .72731 L .24533 .72101 L .644 .733 .913 r
F
.24276 .71963 m .23366 .72455 L .2388 .72731 L F
.6783 .68725 m .67692 .6923 L .68019 .69223 L .645 .732 .913 r
F
.67648 .63184 m .67819 .68726 L .67669 .68737 L .641 .401 .54 r
F
.67731 .68462 m .67717 .68733 L .6783 .68725 L .645 .732 .913 r
F
.67717 .68733 m .67692 .6923 L .6783 .68725 L F
.67692 .6923 m .67653 .69998 L .68306 .69984 L F
.67799 .69084 m .67668 .69612 L .67996 .69605 L F
.67669 .68737 m .6783 .69073 L .67671 .69094 L .641 .401 .54 r
F
.67707 .6884 m .67694 .69092 L .67799 .69084 L .645 .732 .913 r
F
.67692 .6923 m .68306 .69984 L .68019 .69223 L F
.67694 .69092 m .67668 .69612 L .67799 .69084 L F
.67819 .68726 m .6783 .69073 L .67669 .68737 L .641 .401 .54 r
F
.68082 .68705 m .68326 .69164 L .68592 .69058 L .645 .732 .913 r
F
.67829 .68725 m .67933 .6903 L .6783 .69073 L .517 .303 .528 r
F
.67807 .63163 m .67926 .68691 L .67829 .68725 L F
.67731 .68462 m .68019 .69223 L .68326 .69164 L .645 .732 .913 r
F
.67926 .68691 m .67933 .6903 L .67829 .68725 L .517 .303 .528 r
F
.68003 .6864 m .68049 .68904 L .68005 .68973 L .082 0 .419 r
F
.67982 .63062 m .68045 .68582 L .68003 .6864 L F
.68016 .68659 m .67951 .68711 L .68082 .68705 L .645 .732 .913 r
F
.67951 .68711 m .67948 .68716 L .68082 .68705 L F
.68045 .68582 m .68049 .68904 L .68003 .6864 L .082 0 .419 r
F
.67951 .68711 m .67946 .68716 L .67948 .68716 L .645 .732 .913 r
F
.67731 .68462 m .67925 .68691 L .68016 .68659 L F
.67932 .68689 m .68005 .68973 L .67933 .6903 L .359 .181 .499 r
F
.6791 .63119 m .67999 .68642 L .67932 .68689 L F
.67932 .68689 m .67946 .68716 L .68016 .68659 L .645 .732 .913 r
F
.67926 .68693 m .67946 .68716 L .67932 .68689 L F
.67999 .68642 m .68005 .68973 L .67932 .68689 L .359 .181 .499 r
F
.67925 .68691 m .67926 .68693 L .67932 .68689 L .645 .732 .913 r
F
.67946 .68716 m .68326 .69164 L .68082 .68705 L F
.67648 .63184 m .67807 .63163 L .67829 .68725 L .641 .401 .54 r
F
.67819 .68726 m .67829 .68725 L .6783 .69073 L F
.67648 .63184 m .67829 .68725 L .67819 .68726 L F
.676 .68724 m .67069 .69091 L .67368 .69185 L .645 .732 .913 r
F
.67717 .68746 m .67368 .69185 L .67692 .6923 L F
.676 .68724 m .67368 .69185 L .67717 .68746 L F
.67069 .69091 m .67006 .69907 L .67368 .69185 L F
.67479 .69057 m .66787 .69334 L .67042 .69472 L F
.67511 .68707 m .6767 .69094 L .67512 .69064 L .751 .491 .538 r
F
.67391 .6311 m .6749 .63157 L .67511 .68707 L .845 .571 .523 r
F
.67505 .68704 m .67511 .68707 L .67512 .69068 L F
.67391 .6311 m .67511 .68707 L .67505 .68704 L F
.67486 .68695 m .66815 .68953 L .67069 .69091 L .645 .732 .913 r
F
.6749 .63157 m .67659 .68735 L .67511 .68707 L .751 .491 .538 r
F
.67731 .68462 m .67386 .68647 L .67486 .68695 L .645 .732 .913 r
F
.67386 .68647 m .66815 .68953 L .67486 .68695 L F
.67707 .6884 m .67349 .69032 L .67479 .69057 L F
.67349 .69032 m .66787 .69334 L .67479 .69057 L F
.67368 .69185 m .67006 .69907 L .67653 .69998 L F
.67351 .6955 m .67042 .69472 L .67343 .69566 L F
.67707 .6884 m .67329 .69199 L .67351 .6955 L F
.67329 .69199 m .67042 .69472 L .67351 .6955 L F
.6748 .68701 m .6747 .6871 L .676 .68724 L F
.6747 .6871 m .67069 .69091 L .67537 .68767 L F
.6747 .6871 m .67537 .68767 L .676 .68724 L F
.6749 .63157 m .67648 .63184 L .67669 .68737 L .751 .491 .538 r
F
.6749 .63157 m .67669 .68737 L .67659 .68735 L F
.67288 .62981 m .67325 .6305 L .67346 .68603 L .988 .719 .38 r
F
.67344 .68599 m .67346 .68603 L .67347 .68961 L F
.67288 .62981 m .67346 .68603 L .67344 .68599 L F
.67375 .68653 m .66623 .68783 L .66815 .68953 L .645 .732 .913 r
F
.67386 .68647 m .67373 .6865 L .67375 .68653 L F
.67373 .6865 m .66623 .68783 L .67375 .68653 L F
.67391 .6311 m .67505 .68704 L .67412 .6866 L .845 .571 .523 r
F
.67731 .68462 m .67276 .68594 L .67386 .68647 L .645 .732 .913 r
F
.67309 .68537 m .67347 .68961 L .6731 .68891 L .988 .719 .38 r
F
.67288 .62981 m .67344 .68599 L .67309 .68537 L F
.67276 .68594 m .67373 .6865 L .67366 .68638 L .645 .732 .913 r
F
.67344 .68599 m .67347 .68961 L .67309 .68537 L .988 .719 .38 r
F
.67276 .68594 m .66623 .68783 L .67373 .6865 L .645 .732 .913 r
F
.67366 .68638 m .67373 .6865 L .67386 .68647 L F
.66815 .68953 m .66408 .69718 L .67069 .69091 L F
.67295 .68959 m .66477 .68968 L .66594 .69162 L F
.67412 .6866 m .67511 .69063 L .67413 .69016 L .845 .571 .523 r
F
.67346 .68603 m .67413 .69015 L .67347 .68959 L .93 .648 .486 r
F
.67707 .6884 m .67164 .68897 L .67295 .68959 L .645 .732 .913 r
F
.67164 .68897 m .66477 .68968 L .67295 .68959 L F
.67413 .69016 m .67512 .69068 L .67414 .6902 L .845 .571 .523 r
F
.67511 .69063 m .67512 .69068 L .67413 .69016 L F
.67505 .68704 m .67512 .69068 L .67412 .6866 L F
.67263 .68887 m .66444 .68766 L .66477 .68968 L .645 .732 .913 r
F
.67305 .68809 m .6731 .68891 L .6731 .68894 L .772 .616 .051 r
F
.67305 .68809 m .6731 .68894 L .67305 .68819 L F
.67659 .68735 m .6767 .69094 L .67511 .68707 L .751 .491 .538 r
F
.67707 .6884 m .67173 .68809 L .67263 .68887 L .645 .732 .913 r
F
.67173 .68809 m .66444 .68766 L .67263 .68887 L F
.67349 .69032 m .66594 .69162 L .66787 .69334 L F
.67659 .68735 m .67669 .68737 L .6767 .69094 L .751 .491 .538 r
F
.67408 .68656 m .67413 .69016 L .67346 .68603 L .93 .648 .486 r
F
.67413 .69016 m .67414 .6902 L .67413 .69015 L F
.67413 .69016 m .67413 .69015 L .67346 .68603 L F
.674 .69005 m .67165 .68997 L .67349 .69032 L .645 .732 .913 r
F
.67707 .6884 m .67335 .68948 L .674 .69005 L F
.67335 .68948 m .67165 .68997 L .674 .69005 L F
.67165 .68997 m .66594 .69162 L .67349 .69032 L F
.67347 .68959 m .67414 .6902 L .67347 .68961 L .93 .648 .486 r
F
.67413 .69015 m .67414 .6902 L .67347 .68959 L F
.67325 .6305 m .67408 .68656 L .67346 .68603 L F
.66614 .71018 m .67614 .70776 L .6759 .71154 L .733 .497 .571 r
F
.66614 .71018 m .66638 .7064 L .67614 .70776 L F
.67006 .69907 m .67614 .70765 L .67653 .69998 L .645 .732 .913 r
F
.67006 .69907 m .66643 .70629 L .67614 .70765 L F
.6659 .71395 m .6759 .71154 L .67566 .71532 L .733 .497 .571 r
F
.6659 .71395 m .66614 .71018 L .6759 .71154 L F
.66978 .70292 m .6759 .71154 L .67629 .70383 L .645 .732 .913 r
F
.66978 .70292 m .66614 .71018 L .6759 .71154 L F
.66954 .7067 m .67566 .71532 L .67605 .70761 L F
.66954 .7067 m .6659 .71395 L .67566 .71532 L F
.67343 .69566 m .66978 .70292 L .67629 .70383 L F
.67319 .69944 m .66954 .7067 L .67605 .70761 L F
.6735 .69881 m .67018 .69849 L .67319 .69944 L F
.67368 .69185 m .67653 .69998 L .67692 .6923 L F
.67707 .6884 m .67343 .69566 L .67668 .69612 L F
.67414 .6902 m .67512 .69068 L .67514 .6942 L .845 .571 .523 r
F
.67485 .69406 m .6733 .69553 L .67569 .69446 L .645 .732 .913 r
F
.67541 .7471 m .6742 .74723 L .67525 .74746 L .692 .759 .904 r
F
.67525 .74746 m .67624 .75032 L .67638 .74749 L F
.67666 .74934 m .67551 .74967 L .67665 .74971 L F
.67542 .74708 m .67534 .74707 L .67541 .7471 L F
.67638 .74749 m .67624 .75032 L .67852 .75 L F
.67684 .74721 m .67693 .75019 L .67534 .74707 L .751 .491 .538 r
F
.67678 .74687 m .6757 .74925 L .67666 .74934 L .692 .759 .904 r
F
.6757 .74925 m .67551 .74967 L .67666 .74934 L F
.67525 .74746 m .67398 .75025 L .67624 .75032 L F
.67398 .75025 m .67611 .75314 L .67624 .75032 L F
.67551 .74967 m .67651 .75255 L .67665 .74971 L F
.67534 .74922 m .67693 .75019 L .67535 .74993 L .751 .491 .538 r
F
.67534 .74707 m .67648 .74932 L .67534 .74922 L F
.67648 .74932 m .67693 .75019 L .67534 .74922 L F
.67319 .69944 m .67605 .70761 L .67644 .6999 L .645 .732 .913 r
F
.67042 .69472 m .66978 .70292 L .67343 .69566 L F
.67347 .68961 m .67414 .6902 L .67415 .69373 L .93 .648 .486 r
F
.67353 .69319 m .67415 .69373 L .67436 .74945 L F
.67347 .68961 m .67415 .69373 L .67353 .69319 L F
.6731 .68891 m .67347 .68961 L .67349 .69316 L .988 .719 .38 r
F
.67313 .69254 m .67349 .69316 L .6737 .74886 L F
.6731 .68891 m .67349 .69316 L .67313 .69254 L F
.67431 .69458 m .66763 .69711 L .67018 .69849 L .645 .732 .913 r
F
.6747 .6942 m .67421 .69441 L .67431 .69458 L F
.67421 .69441 m .66763 .69711 L .67431 .69458 L F
.67478 .69413 m .67467 .69418 L .6747 .6942 L F
.67324 .7454 m .67212 .74491 L .67224 .74563 L .692 .759 .904 r
F
.67419 .69438 m .66763 .69711 L .67421 .69441 L .645 .732 .913 r
F
.67338 .74679 m .67264 .74629 L .67331 .74683 L .692 .759 .904 r
F
.67264 .74629 m .67011 .749 L .67331 .74683 L F
.67328 .74706 m .67255 .74637 L .67237 .74711 L F
.67397 .74639 m .67336 .74634 L .67338 .74679 L F
.6746 .74679 m .67331 .74683 L .6742 .74723 L F
.67361 .69391 m .66763 .69711 L .67467 .69418 L .645 .732 .913 r
F
.67343 .69566 m .67629 .70383 L .67668 .69612 L F
.67569 .69446 m .6733 .69553 L .6735 .69881 L F
.67415 .69373 m .67529 .74705 L .67435 .74669 L .845 .571 .523 r
F
.67414 .6902 m .67421 .69376 L .67415 .69373 L F
.67421 .69376 m .67529 .74705 L .67415 .69373 L F
.67307 .69176 m .67331 .74549 L .67326 .74475 L .772 .616 .051 r
F
.67305 .68809 m .67307 .6918 L .67307 .69176 L F
.67307 .6918 m .67331 .74549 L .67307 .69176 L F
.67069 .69091 m .66408 .69718 L .67006 .69907 L .645 .732 .913 r
F
.66787 .69334 m .66377 .70102 L .67042 .69472 L F
.67321 .69412 m .6657 .6954 L .66763 .69711 L F
.67404 .69368 m .6732 .69385 L .67321 .69412 L F
.6732 .69385 m .6657 .6954 L .67321 .69412 L F
.67512 .69068 m .67523 .69422 L .67514 .6942 L .751 .491 .538 r
F
.67414 .6902 m .67514 .6942 L .67421 .69376 L .845 .571 .523 r
F
.67683 .69218 m .67315 .69325 L .67404 .69368 L .645 .732 .913 r
F
.67305 .68819 m .6731 .68894 L .67311 .6925 L .772 .616 .051 r
F
.67305 .68819 m .67311 .6925 L .67307 .6918 L F
.67359 .68706 m .67305 .68809 L .67307 .69176 L 0 0 .382 r
F
.67347 .68961 m .67353 .69319 L .67349 .69316 L .93 .648 .486 r
F
.67311 .6925 m .67367 .74614 L .67331 .74553 L .988 .719 .38 r
F
.67313 .69254 m .6737 .74886 L .67311 .6925 L F
.67307 .6918 m .67311 .6925 L .67332 .74816 L .772 .616 .051 r
F
.659 .69444 m .65746 .70346 L .66408 .69718 L .645 .732 .913 r
F
.66787 .69334 m .65866 .69827 L .66377 .70102 L F
.67196 .69359 m .66453 .69346 L .6657 .6954 L F
.67321 .68581 m .66507 .6859 L .66623 .68783 L F
.67731 .68462 m .67243 .68513 L .67321 .68581 L F
.67243 .68513 m .66507 .6859 L .67321 .68581 L F
.67325 .6305 m .67391 .6311 L .67412 .6866 L .93 .648 .486 r
F
.67408 .68656 m .67412 .6866 L .67414 .6902 L F
.67325 .6305 m .67412 .6866 L .67408 .68656 L F
.67217 .68812 m .66497 .68569 L .66444 .68766 L .645 .732 .913 r
F
.67707 .6884 m .67316 .68753 L .67217 .68812 L F
.67316 .68753 m .66497 .68569 L .67217 .68812 L F
.67472 .68628 m .67359 .68706 L .67359 .68727 L .402 .214 .508 r
F
.67463 .68665 m .67359 .68727 L .67361 .69083 L F
.67472 .68628 m .67359 .68727 L .67463 .68665 L F
.67349 .69316 m .67431 .74666 L .67369 .74617 L .93 .648 .486 r
F
.67353 .69319 m .67436 .74945 L .67349 .69316 L F
.67361 .69391 m .67467 .69418 L .67457 .69409 L .645 .732 .913 r
F
.67467 .69418 m .67419 .69438 L .6747 .6942 L F
.67419 .69438 m .67421 .69441 L .6747 .6942 L F
.67255 .69263 m .6642 .69144 L .66453 .69346 L F
.67683 .69218 m .67295 .69195 L .67255 .69263 L F
.67295 .69195 m .6642 .69144 L .67255 .69263 L F
.67336 .74634 m .67264 .74629 L .67338 .74679 L .692 .759 .904 r
F
.67326 .74475 m .67331 .74753 L .67327 .7469 L .772 .616 .051 r
F
.67342 .74596 m .67264 .74629 L .67397 .74639 L .692 .759 .904 r
F
.67331 .74549 m .67332 .74816 L .67326 .74475 L .772 .616 .051 r
F
.67512 .69068 m .6767 .69094 L .67671 .6945 L .751 .491 .538 r
F
.66623 .68783 m .659 .69444 L .66815 .68953 L .645 .732 .913 r
F
.66815 .68953 m .659 .69444 L .66408 .69718 L F
.67183 .69189 m .66473 .68947 L .6642 .69144 L F
.67683 .69218 m .67285 .69129 L .67183 .69189 L F
.67285 .69129 m .66473 .68947 L .67183 .69189 L F
.67651 .74467 m .67342 .74596 L .67397 .74639 L .692 .759 .904 r
F
.67651 .74467 m .67292 .74486 L .67324 .7454 L F
.6731 .68891 m .67313 .69254 L .67311 .6925 L .988 .719 .38 r
F
.67139 .69096 m .66609 .68768 L .66473 .68947 L .645 .732 .913 r
F
.67683 .69218 m .673 .69058 L .67139 .69096 L F
.673 .69058 m .66609 .68768 L .67139 .69096 L F
.67307 .68507 m .66474 .68389 L .66507 .6859 L F
.67731 .68462 m .67302 .68437 L .67307 .68507 L F
.67302 .68437 m .66474 .68389 L .67307 .68507 L F
.67283 .62899 m .67288 .62981 L .67309 .68537 L .772 .616 .051 r
F
.67308 .68533 m .67309 .68537 L .6731 .68891 L F
.67283 .62899 m .67309 .68537 L .67308 .68533 L F
.67302 .68437 m .66527 .68192 L .66474 .68389 L .645 .732 .913 r
F
.67731 .68462 m .67348 .68376 L .67302 .68437 L F
.67471 .68303 m .67359 .68706 L .67472 .68628 L .402 .214 .508 r
F
.6745 .62717 m .67364 .68366 L .67471 .68303 L F
.67364 .68366 m .67359 .68706 L .67471 .68303 L F
.67304 .68462 m .6731 .68891 L .67305 .68809 L .772 .616 .051 r
F
.67308 .68533 m .6731 .68891 L .67304 .68462 L F
.67358 .6837 m .67305 .68809 L .67359 .68706 L 0 0 .382 r
F
.67337 .62796 m .67307 .68457 L .67358 .6837 L F
.67307 .68457 m .67305 .68809 L .67358 .6837 L F
.67283 .62899 m .67308 .68533 L .67304 .68462 L .772 .616 .051 r
F
.67337 .62796 m .67283 .62899 L .67304 .68462 L 0 0 .382 r
F
.67307 .68457 m .67304 .68462 L .67305 .68809 L F
.67337 .62796 m .67304 .68462 L .67307 .68457 L F
.67388 .68319 m .6687 .67867 L .66662 .68014 L .645 .732 .913 r
F
.67582 .68276 m .67472 .68628 L .67584 .68594 L .568 .343 .534 r
F
.67561 .62683 m .67477 .68301 L .67582 .68276 L F
.67731 .68462 m .67493 .68298 L .67394 .68321 L .645 .732 .913 r
F
.67731 .68462 m .67388 .68319 L .67354 .68378 L F
.67477 .68301 m .67472 .68628 L .67582 .68276 L .568 .343 .534 r
F
.67394 .68321 m .67427 .68252 L .67388 .68319 L .645 .732 .913 r
F
.67493 .68298 m .67427 .68252 L .67394 .68321 L F
.67427 .68252 m .6687 .67867 L .67388 .68319 L F
.67354 .68378 m .66662 .68014 L .66527 .68192 L F
.67388 .68319 m .66662 .68014 L .67354 .68378 L F
.67348 .68376 m .67298 .68365 L .673 .68405 L F
.67348 .68376 m .673 .68405 L .67302 .68437 L F
.67298 .68365 m .66527 .68192 L .67302 .68437 L F
.67347 .68689 m .66842 .68242 L .66633 .6839 L F
.67707 .6884 m .67453 .68664 L .67347 .68689 L F
.67453 .68664 m .66842 .68242 L .67347 .68689 L F
.67584 .68594 m .67472 .68628 L .67473 .6866 L .568 .343 .534 r
F
.67196 .68726 m .66633 .6839 L .66497 .68569 L .645 .732 .913 r
F
.67707 .6884 m .67347 .68689 L .67196 .68726 L F
.67347 .68689 m .66633 .6839 L .67196 .68726 L F
.67683 .69218 m .67017 .69288 L .67196 .69359 L F
.67514 .6942 m .67684 .74721 L .67534 .74707 L .751 .491 .538 r
F
.67523 .69422 m .67684 .74721 L .67514 .6942 L F
.67512 .69068 m .67671 .6945 L .67523 .69422 L F
.67683 .69218 m .67485 .69406 L .67569 .69446 L .645 .732 .913 r
F
.673 .69058 m .66818 .6862 L .66609 .68768 L F
.67683 .69218 m .67412 .69031 L .673 .69058 L F
.67359 .68706 m .67307 .69176 L .67357 .69089 L 0 0 .382 r
F
.67412 .69031 m .66818 .6862 L .673 .69058 L .645 .732 .913 r
F
.67683 .69218 m .67361 .69391 L .67478 .69413 L F
.67457 .69409 m .67467 .69418 L .67478 .69413 L F
.67421 .69376 m .67514 .6942 L .67534 .74707 L .845 .571 .523 r
F
.67421 .69376 m .67534 .74707 L .67529 .74705 L F
.67512 .69064 m .6767 .69094 L .67512 .69068 L .751 .491 .538 r
F
.67683 .69218 m .67319 .69944 L .67644 .6999 L .645 .732 .913 r
F
.67578 .68991 m .67474 .69016 L .67495 .74553 L .568 .343 .534 r
F
.67494 .7429 m .67551 .742 L .67443 .74234 L .692 .759 .904 r
F
.67651 .74467 m .67574 .74262 L .67494 .7429 L F
.67585 .6899 m .67499 .74288 L .67605 .7425 L .568 .343 .534 r
F
.67574 .74262 m .67551 .742 L .67494 .7429 L .692 .759 .904 r
F
.67308 .74426 m .67278 .74346 L .67231 .74417 L F
.67651 .74467 m .67374 .74377 L .67308 .74426 L F
.67374 .74377 m .67278 .74346 L .67308 .74426 L F
.67651 .74467 m .67443 .74234 L .6735 .74284 L F
.67321 .74485 m .67231 .74417 L .67212 .74491 L F
.67651 .74467 m .6735 .74431 L .67321 .74485 L F
.6735 .74431 m .67231 .74417 L .67321 .74485 L F
.67651 .74467 m .67224 .74563 L .67264 .74629 L F
.6738 .74373 m .67336 .74672 L .67381 .74588 L 0 0 .382 r
F
.67329 .7447 m .67327 .74735 L .6738 .74373 L F
.6738 .74591 m .67376 .74503 L .67303 .74566 L .692 .759 .904 r
F
.67651 .74467 m .67383 .74649 L .6746 .74679 L F
.67651 .74467 m .6746 .74679 L .67534 .74707 L F
.67651 .74467 m .67534 .74707 L .67542 .74708 L F
.67651 .74467 m .67525 .74746 L .67638 .74749 L F
.67678 .74687 m .67414 .74526 L .6738 .74591 L F
.67651 .74467 m .6735 .74284 L .67278 .74346 L F
.67386 .74369 m .67382 .74587 L .67494 .7429 L .402 .214 .508 r
F
.67678 .74687 m .67303 .74566 L .67255 .74637 L .692 .759 .904 r
F
.67382 .74587 m .67381 .74632 L .674 .74574 L .402 .214 .508 r
F
.67382 .74587 m .674 .74574 L .67494 .7429 L F
.67414 .74526 m .67376 .74503 L .6738 .74589 L .692 .759 .904 r
F
.67381 .74588 m .6738 .74589 L .6738 .74591 L F
.67414 .74526 m .6738 .74589 L .67381 .74588 L F
.67331 .74683 m .67189 .7498 L .6742 .74723 L F
.67367 .74659 m .6737 .74886 L .67347 .74696 L .988 .719 .38 r
F
.67367 .74659 m .67347 .74696 L .67331 .74553 L F
.67367 .74614 m .67367 .74659 L .67331 .74553 L F
.67383 .74649 m .67331 .74683 L .6746 .74679 L .692 .759 .904 r
F
.6746 .74679 m .6742 .74723 L .67541 .7471 L F
.6742 .74723 m .67398 .75025 L .67525 .74746 L F
.67529 .74705 m .67533 .74921 L .67435 .74669 L .845 .571 .523 r
F
.67678 .74687 m .67446 .74945 L .67551 .74967 L .692 .759 .904 r
F
.67533 .74921 m .67535 .74993 L .6751 .74912 L .845 .571 .523 r
F
.67533 .74921 m .6751 .74912 L .67435 .74669 L F
.67405 .74872 m .67357 .74905 L .67484 .74902 L .692 .759 .904 r
F
.6742 .74723 m .67189 .7498 L .67398 .75025 L F
.67369 .74831 m .67436 .74945 L .6737 .74886 L .93 .648 .486 r
F
.67369 .74617 m .67421 .74872 L .67369 .74831 L F
.67474 .74914 m .67357 .74905 L .67446 .74945 L .692 .759 .904 r
F
.67421 .74872 m .67436 .74945 L .67369 .74831 L .93 .648 .486 r
F
.67484 .74902 m .6746 .74903 L .67474 .74914 L .692 .759 .904 r
F
.6746 .74903 m .67357 .74905 L .67474 .74914 L F
.67435 .74883 m .67535 .74993 L .67436 .74945 L .845 .571 .523 r
F
.67435 .74669 m .6751 .74912 L .67435 .74883 L F
.6751 .74912 m .67535 .74993 L .67435 .74883 L F
.67405 .74872 m .67289 .7485 L .67357 .74905 L .692 .759 .904 r
F
.67678 .74687 m .67318 .74838 L .67405 .74872 L F
.67318 .74838 m .67289 .7485 L .67405 .74872 L F
.67529 .74705 m .67534 .74707 L .67535 .74993 L .845 .571 .523 r
F
.67678 .74687 m .67405 .74872 L .67484 .74902 L .692 .759 .904 r
F
.67678 .74687 m .67324 .74645 L .67328 .74706 L F
.67381 .74588 m .67327 .74735 L .67381 .74632 L 0 0 .382 r
F
.67336 .74672 m .67327 .74735 L .67381 .74588 L F
.67361 .69083 m .67329 .7447 L .6738 .74373 L F
.67494 .7429 m .674 .74574 L .67494 .74505 L .402 .214 .508 r
F
.67442 .74543 m .67469 .74453 L .67376 .74503 L .692 .759 .904 r
F
.67678 .74687 m .67507 .74496 L .67442 .74543 L F
.67507 .74496 m .67469 .74453 L .67442 .74543 L F
.67494 .74505 m .67381 .74632 L .67495 .74553 L .402 .214 .508 r
F
.674 .74574 m .67381 .74632 L .67494 .74505 L F
.67474 .69016 m .67386 .74369 L .67494 .7429 L F
.67499 .74288 m .67495 .74553 L .67605 .7425 L .568 .343 .534 r
F
.6751 .74499 m .67577 .74419 L .67469 .74453 L .692 .759 .904 r
F
.67678 .74687 m .67596 .74469 L .6751 .74499 L F
.67605 .7425 m .67515 .74498 L .67606 .74465 L .568 .343 .534 r
F
.67596 .74469 m .67577 .74419 L .6751 .74499 L .692 .759 .904 r
F
.67606 .74465 m .67495 .74553 L .67606 .74519 L .568 .343 .534 r
F
.67515 .74498 m .67495 .74553 L .67606 .74465 L F
.67584 .68633 m .67578 .68991 L .67585 .6899 L F
.67578 .68991 m .67495 .74553 L .67585 .6899 L F
.67731 .68462 m .6748 .68701 L .676 .68724 L .645 .732 .913 r
F
.67584 .68594 m .67583 .68633 L .67584 .68633 L .568 .343 .534 r
F
.67359 .68706 m .67357 .69089 L .67361 .69083 L 0 0 .382 r
F
.67412 .69031 m .67086 .68512 L .66818 .6862 L .645 .732 .913 r
F
.67683 .69218 m .67506 .69009 L .67412 .69031 L F
.67506 .69009 m .67086 .68512 L .67412 .69031 L F
.67707 .6884 m .67109 .68135 L .66842 .68242 L F
.67583 .68633 m .67578 .68991 L .67584 .68633 L .568 .343 .534 r
F
.67578 .68991 m .67495 .74553 L .67578 .68991 L F
.67578 .68991 m .67578 .68991 L .67584 .68633 L F
.67573 .68636 m .67473 .6866 L .67474 .69016 L F
.67584 .68594 m .67473 .6866 L .67573 .68636 L F
.67584 .68594 m .67474 .69016 L .67578 .68991 L F
.67472 .68628 m .67466 .69021 L .67474 .69016 L .402 .214 .508 r
F
.67466 .69021 m .67381 .74632 L .67474 .69016 L F
.67357 .69089 m .67327 .74735 L .67361 .69083 L 0 0 .382 r
F
.67466 .69021 m .67361 .69083 L .67381 .74632 L .402 .214 .508 r
F
.67472 .68628 m .67361 .69083 L .67466 .69021 L F
.67017 .69288 m .66891 .69301 L .6697 .69316 L .645 .732 .913 r
F
.67017 .69288 m .6697 .69316 L .67196 .69359 L F
.66891 .69301 m .66453 .69346 L .67196 .69359 L F
.6759 .71154 m .67614 .70776 L .68598 .70755 L .67 .443 .567 r
F
.67653 .69998 m .67614 .70765 L .68593 .70744 L .645 .732 .913 r
F
.6759 .71154 m .68598 .70755 L .68574 .71133 L .67 .443 .567 r
F
.67566 .71532 m .6759 .71154 L .68574 .71133 L F
.67629 .70383 m .6759 .71154 L .68574 .71133 L .645 .732 .913 r
F
.67566 .71532 m .68574 .71133 L .6855 .7151 L .67 .443 .567 r
F
.67629 .70383 m .68574 .71133 L .68285 .70369 L .645 .732 .913 r
F
.67605 .70761 m .67566 .71532 L .6855 .7151 L F
.67605 .70761 m .6855 .7151 L .68261 .70747 L F
.67644 .6999 m .67605 .70761 L .68261 .70747 L F
.67523 .69422 m .67671 .6945 L .67693 .75019 L .751 .491 .538 r
F
.67357 .69089 m .67307 .69176 L .67327 .74735 L 0 0 .382 r
F
.67315 .69325 m .67199 .69358 L .67404 .69368 L .645 .732 .913 r
F
.67199 .69358 m .6657 .6954 L .67165 .69417 L F
.67199 .69358 m .67165 .69417 L .67404 .69368 L F
.67324 .74645 m .67255 .74637 L .67328 .74706 L .692 .759 .904 r
F
.67431 .74666 m .67436 .74945 L .67369 .74617 L .93 .648 .486 r
F
.67331 .74683 m .67011 .749 L .67189 .7498 L .692 .759 .904 r
F
.6733 .74765 m .67237 .74711 L .67248 .74784 L F
.67331 .74553 m .67362 .74818 L .67332 .74767 L .988 .719 .38 r
F
.67678 .74687 m .67297 .74708 L .6733 .74765 L .692 .759 .904 r
F
.67297 .74708 m .67237 .74711 L .6733 .74765 L F
.67678 .74687 m .67248 .74784 L .67289 .7485 L F
.67332 .74767 m .6737 .74886 L .67332 .74816 L .988 .719 .38 r
F
.67362 .74818 m .6737 .74886 L .67332 .74767 L F
.67327 .7469 m .67332 .74816 L .67327 .74735 L .772 .616 .051 r
F
.67331 .74753 m .67332 .74816 L .67327 .7469 L F
.67292 .74486 m .67212 .74491 L .67324 .7454 L .692 .759 .904 r
F
.6733 .69553 m .67018 .69849 L .6735 .69881 L .645 .732 .913 r
F
.6767 .69094 m .6767 .69094 L .67512 .69064 L .751 .491 .538 r
F
.67731 .68462 m .676 .68724 L .67717 .68746 L .645 .732 .913 r
F
0 g
.67669 .68737 m
.67669 .68795 L
s
.67646 .62677 m
.67648 .63184 L
s
.5348 .74027 m .52737 .73237 L .52713 .73614 L .856 .609 .564 r
F
0 g
.5348 .74027 m
.54059 .7454 L
s
.127 .923 .03 r
.67774 1.53485 m
.69701 .76532 L
s
.69701 .76532 m
.698 .72593 L
s
.5266 7.57061 m
.67774 1.53485 L
s
.40263 .60347 m .41596 .59477 L .41645 .59935 L .606 .404 .582 r
F
.40312 .60805 m .40263 .60347 L .41645 .59935 L F
.127 .923 .03 r
.4304 .65658 m
.43061 .60496 L
s
.38841 .60999 m .40263 .60347 L .40312 .60805 L .673 .453 .578 r
F
.39824 .59276 m .40263 .60347 L .41645 .59935 L .683 .77 .917 r
F
.38843 .59405 m .40263 .60347 L .39824 .59276 L F
0 g
.38793 .60541 m
.40263 .60347 L
s
.25795 .72175 m .26402 .72879 L .26933 .72665 L .644 .733 .913 r
F
.25488 .72234 m .26402 .72879 L .25795 .72175 L F
.52737 .73237 m .52762 .72859 L .5186 .72575 L .793 .551 .571 r
F
0 g
.52762 .72859 m
.53529 .73272 L
s
.65961 .60732 m .64366 .60253 L .63961 .60818 L .683 .77 .917 r
F
.66272 .60482 m .64366 .60253 L .65961 .60732 L F
.28424 .72818 m .28451 .72441 L .28849 .71906 L .072 0 .399 r
F
.127 .923 .03 r
.26729 1.87205 m
.29777 2.79503 L
s
0 g
.27987 .72773 m
.28451 .72441 L
s
.4389 .49062 m .45641 .47519 L .43419 .48329 L .673 .757 .914 r
F
.4389 .49062 m .46346 .48619 L .45641 .47519 L F
.27362 .71987 m .28435 .72434 L .28831 .71902 L .645 .732 .913 r
F
.26951 .72281 m .28435 .72434 L .27362 .71987 L F
.68117 .68624 m .68592 .69058 L .688 .6891 L F
.67731 .68462 m .68016 .68659 L .68117 .68624 L F
.68016 .68659 m .68592 .69058 L .68117 .68624 L F
.67807 .63163 m .6791 .63119 L .67932 .68689 L .517 .303 .528 r
F
.67926 .68691 m .67932 .68689 L .67933 .6903 L F
.67807 .63163 m .67932 .68689 L .67926 .68691 L F
.24507 .72479 m .24456 .73298 L .24808 .72573 L .644 .733 .913 r
F
.24507 .72479 m .23853 .73108 L .24456 .73298 L F
.58723 .37166 m .58423 .36799 L .58156 .36931 L .675 .735 .895 r
F
.58877 .37125 m .58423 .36799 L .58723 .37166 L F
.25461 .72612 m .25762 .73374 L .26376 .73256 L .644 .733 .913 r
F
.25134 .72619 m .25762 .73374 L .25461 .72612 L F
.67882 .50451 m .65881 .50075 L .65914 .50644 L .672 .448 .573 r
F
0 g
.64064 .51138 m
.65914 .50644 L
s
.67882 .50451 m .67848 .49882 L .65881 .50075 L .672 .448 .573 r
F
0 g
.64031 .50569 m
.65881 .50075 L
s
.64044 .61732 m .62236 .61534 L .61996 .62426 L .683 .77 .917 r
F
0 g
.61996 .62426 m
.62142 .63297 L
s
.6813 .68552 m .688 .6891 L .68935 .68733 L .645 .732 .913 r
F
.67731 .68462 m .6806 .686 L .6813 .68552 L F
.6806 .686 m .688 .6891 L .6813 .68552 L F
.6791 .63119 m .67982 .63062 L .68003 .6864 L .359 .181 .499 r
F
.67999 .68642 m .68003 .6864 L .68005 .68973 L F
.6791 .63119 m .68003 .6864 L .67999 .68642 L F
.69271 .61015 m .70365 .59922 L .68985 .60795 L .683 .77 .917 r
F
.69271 .61015 m .70938 .6036 L .70365 .59922 L F
.24114 .71413 m .23014 .71732 L .23402 .72073 L .645 .732 .913 r
F
.46346 .48619 m .46315 .48051 L .4561 .46951 L .987 .711 .381 r
F
0 g
.46315 .48051 m
.46517 .49241 L
s
.41645 .59935 m .41596 .59477 L .42794 .58873 L .522 .343 .58 r
F
0 g
.4093 .59676 m
.41596 .59477 L
s
.26083 .71687 m .26951 .72281 L .27362 .71987 L .645 .732 .913 r
F
.25819 .71794 m .26951 .72281 L .26083 .71687 L F
.52975 .36863 m .49561 .37742 L .52715 .37907 L .654 .726 .902 r
F
.52975 .36863 m .49948 .36175 L .49561 .37742 L F
0 g
.49561 .37742 m
.49818 .39342 L
s
.41199 .49138 m .42646 .47705 L .40812 .48826 L .673 .757 .914 r
F
.41199 .49138 m .43419 .48329 L .42646 .47705 L F
.34665 .47925 m .31722 .48321 L .34132 .48673 L F
.56 .3755 m .52715 .37907 L .5587 .38072 L .654 .726 .902 r
F
.56 .3755 m .52975 .36863 L .52715 .37907 L F
.40688 .58533 m .41583 .59463 L .42774 .58862 L .683 .77 .917 r
F
.39771 .58807 m .41583 .59463 L .40688 .58533 L F
.127 .923 .03 r
.49426 8.7996 m
.49929 8.32481 L
s
.58423 .36799 m .57722 .3663 L .58156 .36931 L .675 .735 .895 r
F
.58423 .36799 m .58124 .36431 L .57722 .3663 L F
.59024 .38237 m .58295 .36224 L .57525 .36388 L .654 .726 .902 r
F
.59024 .38237 m .59115 .36197 L .58295 .36224 L F
.68927 .60342 m .69542 .59154 L .68548 .60183 L .683 .77 .917 r
F
.68927 .60342 m .703 .59472 L .69542 .59154 L F
.68115 .68485 m .68935 .68733 L .68988 .68536 L .645 .732 .913 r
F
.67731 .68462 m .68076 .6854 L .68115 .68485 L F
.68076 .6854 m .68935 .68733 L .68115 .68485 L F
.67982 .63062 m .68026 .62994 L .68047 .68579 L .082 0 .419 r
F
.68045 .68582 m .68047 .68579 L .68049 .68904 L F
.67982 .63062 m .68047 .68579 L .68045 .68582 L F
.62179 .38402 m .65168 .375 L .62096 .37869 L .654 .726 .902 r
F
.62179 .38402 m .65334 .38567 L .65168 .375 L F
.65334 .38567 m .68241 .37132 L .65168 .375 L F
.65334 .38567 m .68488 .38732 L .68241 .37132 L F
.64191 .47897 m .64158 .47329 L .65412 .4635 L .388 .235 .549 r
F
0 g
.6332 .47726 m
.64158 .47329 L
s
.68488 .38732 m .68282 .36402 L .68241 .37132 L .913 .734 .239 r
F
0 g
.68091 .40298 m
.68488 .38732 L
s
.69832 .50573 m .67848 .49882 L .67882 .50451 L .733 .496 .569 r
F
0 g
.65881 .50075 m
.67848 .49882 L
s
.67848 .49882 m
.69798 .50004 L
s
.69832 .50573 m
.71632 .51001 L
s
.36798 .37434 m .34538 .37197 L .34492 .37926 L .591 .366 .543 r
F
0 g
.32498 .38796 m
.34492 .37926 L
s
.36798 .37434 m .36843 .36705 L .34538 .37197 L .591 .366 .543 r
F
0 g
.32544 .38067 m
.34538 .37197 L
s
.64366 .60253 m .62163 .60621 L .63961 .60818 L .683 .77 .917 r
F
.36857 .49785 m .34168 .49807 L .36589 .50161 L .673 .757 .914 r
F
.62414 .46261 m .64132 .47313 L .6538 .46339 L F
.61348 .46767 m .64132 .47313 L .62414 .46261 L F
.40772 .48263 m .41577 .46679 L .40262 .48029 L F
.40772 .48263 m .42596 .47148 L .41577 .46679 L F
.44002 .37692 m .41787 .36232 L .41743 .36962 L .794 .542 .556 r
F
.43958 .38422 m .44002 .37692 L .41743 .36962 L F
0 g
.44002 .37692 m
.45923 .38767 L
s
.36029 .60692 m .37332 .60502 L .3738 .6096 L .794 .542 .556 r
F
.36029 .60692 m .35981 .60234 L .37332 .60502 L F
.36968 .592 m .37332 .60502 L .37869 .59379 L .683 .77 .917 r
F
.36968 .592 m .35981 .60234 L .37332 .60502 L F
0 g
.37332 .60502 m
.38793 .60541 L
s
.66054 .61645 m .64044 .61732 L .6585 .61929 L .683 .77 .917 r
F
0 g
.67882 .50451 m
.69832 .50573 L
s
.68015 .68407 m .67911 .68636 L .68016 .68718 L .91 .629 .497 r
F
.67994 .62808 m .67915 .68332 L .68015 .68407 L F
.68026 .62994 m .68059 .68509 L .68047 .68579 L 0 0 .152 r
F
.68073 .68427 m .68988 .68536 L .68955 .68335 L .645 .732 .913 r
F
.67731 .68462 m .68063 .68482 L .68073 .68427 L F
.68063 .68482 m .68988 .68536 L .68073 .68427 L F
.68026 .62994 m .68038 .62913 L .6806 .68505 L 0 0 .152 r
F
.68059 .68509 m .6806 .68505 L .68061 .68823 L F
.68026 .62994 m .6806 .68505 L .68059 .68509 L F
.67915 .68332 m .67911 .68636 L .68015 .68407 L .91 .629 .497 r
F
.68038 .62913 m .67994 .62808 L .68015 .68407 L .982 .725 .331 r
F
.68018 .68412 m .68015 .68407 L .68016 .68718 L F
.68038 .62913 m .68015 .68407 L .68018 .68412 L F
.68047 .68579 m .68061 .68823 L .68049 .68904 L 0 0 .152 r
F
.68059 .68509 m .68061 .68823 L .68047 .68579 L F
.6806 .68505 m .68016 .68718 L .68061 .68823 L .982 .725 .331 r
F
.68038 .62913 m .68018 .68412 L .6806 .68505 L F
.68018 .68412 m .68016 .68718 L .6806 .68505 L F
.67947 .68258 m .68647 .67971 L .68393 .67834 L .645 .732 .913 r
F
.67909 .68328 m .67803 .68598 L .67911 .68636 L .81 .54 .531 r
F
.67888 .62725 m .67807 .68291 L .67909 .68328 L F
.67731 .68462 m .67953 .68343 L .67883 .68318 L .645 .732 .913 r
F
.67731 .68462 m .67889 .68312 L .67829 .68267 L F
.6794 .68351 m .68839 .68142 L .68647 .67971 L F
.67731 .68462 m .67989 .68388 L .6794 .68351 L F
.67989 .68388 m .68839 .68142 L .6794 .68351 L F
.67994 .62808 m .67888 .62725 L .67909 .68328 L .91 .629 .497 r
F
.68038 .68374 m .68955 .68335 L .68839 .68142 L .645 .732 .913 r
F
.67731 .68462 m .68159 .68418 L .68038 .68374 L F
.68159 .68418 m .68955 .68335 L .68038 .68374 L F
.67888 .62725 m .6778 .62687 L .67802 .68289 L .81 .54 .531 r
F
.67807 .68291 m .67802 .68289 L .67803 .68598 L F
.67888 .62725 m .67802 .68289 L .67807 .68291 L F
.67915 .68332 m .67909 .68328 L .67911 .68636 L .91 .629 .497 r
F
.67994 .62808 m .67909 .68328 L .67915 .68332 L F
.67807 .68291 m .67803 .68598 L .67909 .68328 L .81 .54 .531 r
F
.67883 .68318 m .6798 .68329 L .67947 .68258 L .645 .732 .913 r
F
.67953 .68343 m .6798 .68329 L .67883 .68318 L F
.6798 .68329 m .68647 .67971 L .67947 .68258 L F
.67893 .68139 m .68129 .68085 L .68094 .67739 L F
.67829 .68267 m .67925 .68209 L .67893 .68139 L F
.67925 .68209 m .68129 .68085 L .67893 .68139 L F
.67889 .68312 m .68129 .68085 L .67829 .68267 L F
.68129 .68085 m .68393 .67834 L .68182 .67767 L F
.68129 .68085 m .68182 .67767 L .68094 .67739 L F
.38892 .59863 m .38841 .60999 L .40312 .60805 L .683 .77 .917 r
F
.37917 .59837 m .38841 .60999 L .38892 .59863 L F
.127 .923 .03 r
.32482 .579 m
.32486 .58336 L
s
.32567 .57869 m
.32576 .58303 L
s
.38081 .61504 m
.38092 .67297 L
s
.3808 .60979 m
.38081 .61504 L
s
.38166 .61472 m
.38262 .68386 L
s
.38159 .60981 m
.38166 .61472 L
s
.37917 .59837 m .3738 .6096 L .38841 .60999 L .683 .77 .917 r
F
.21484 .72232 m .2187 .72434 L .21843 .72811 L .989 .751 .482 r
F
.21484 .72232 m .21511 .71854 L .2187 .72434 L F
.22736 .71727 m .2187 .72434 L .22976 .72113 L .644 .733 .913 r
F
.22736 .71727 m .21511 .71854 L .2187 .72434 L F
0 g
.2187 .72434 m
.22187 .72712 L
s
.49851 .73215 m .48953 .73015 L .48928 .73392 L .597 .38 .557 r
F
0 g
.48128 .73713 m
.48928 .73392 L
s
.49851 .73215 m .49876 .72837 L .48953 .73015 L .597 .38 .557 r
F
0 g
.48154 .73335 m
.48953 .73015 L
s
.24249 .72341 m .23853 .73108 L .24507 .72479 L .644 .733 .913 r
F
.24249 .72341 m .23339 .72833 L .23853 .73108 L F
.28099 .61205 m .26699 .60479 L .26747 .60937 L .794 .542 .556 r
F
.28147 .61663 m .28099 .61205 L .26747 .60937 L F
0 g
.28099 .61205 m
.29251 .61685 L
s
.25768 .72553 m .26376 .73256 L .26907 .73042 L .644 .733 .913 r
F
.25461 .72612 m .26376 .73256 L .25768 .72553 L F
.71334 .61346 m .72656 .60164 L .70989 .60818 L .683 .77 .917 r
F
.71334 .61346 m .73174 .60956 L .72656 .60164 L F
.52737 .73237 m .5186 .72575 L .51835 .72953 L .793 .551 .571 r
F
.52713 .73614 m .52737 .73237 L .51835 .72953 L F
0 g
.52737 .73237 m
.53504 .7365 L
s
.73122 .60498 m .72553 .59248 L .72604 .59706 L .98 .687 .328 r
F
.73174 .60956 m .73122 .60498 L .72604 .59706 L F
0 g
.73122 .60498 m
.73264 .61369 L
s
.28424 .72818 m .28849 .71906 L .28823 .72284 L .072 0 .399 r
F
.28398 .73196 m .28424 .72818 L .28823 .72284 L F
.27346 .72369 m .28424 .72818 L .28823 .72284 L .644 .733 .913 r
F
.26933 .72665 m .28424 .72818 L .27346 .72369 L F
0 g
.2796 .73151 m
.28424 .72818 L
s
.56379 .36345 m .53017 .36133 L .56042 .36821 L .654 .726 .902 r
F
.40312 .60805 m .41645 .59935 L .41694 .60393 L .606 .404 .582 r
F
.39873 .59734 m .40312 .60805 L .41694 .60393 L .683 .77 .917 r
F
.38892 .59863 m .40312 .60805 L .39873 .59734 L F
0 g
.38841 .60999 m
.40312 .60805 L
s
.62137 .3714 m .64624 .35753 L .61844 .36631 L .654 .726 .902 r
F
.62137 .3714 m .65209 .36771 L .64624 .35753 L F
.66003 .61187 m .644 .60706 L .63993 .61274 L .683 .77 .917 r
F
.66316 .60936 m .644 .60706 L .66003 .61187 L F
.50859 .72816 m .49901 .7246 L .49876 .72837 L .67 .443 .567 r
F
.50859 .72816 m .50884 .72439 L .49901 .7246 L F
0 g
.48978 .72637 m
.49901 .7246 L
s
.55355 .47538 m .55048 .49365 L .56377 .48009 L .673 .757 .914 r
F
.55355 .47538 m .53516 .48659 L .55048 .49365 L F
0 g
.55048 .49365 m
.5685 .49793 L
s
.36827 .49217 m .34673 .48487 L .34138 .49238 L .673 .757 .914 r
F
.37242 .48891 m .34673 .48487 L .36827 .49217 L F
0 g
.6799 .61996 m
.67994 .62808 L
s
.51835 .72953 m .5186 .72575 L .50884 .72439 L .733 .497 .571 r
F
.127 .923 .03 r
.5185 .72635 m
.51856 .72276 L
s
0 g
.5186 .72575 m
.52762 .72859 L
s
.66272 .60482 m .64988 .59753 L .64366 .60253 L .683 .77 .917 r
F
.66671 .60282 m .64988 .59753 L .66272 .60482 L F
.24081 .71792 m .23366 .72455 L .24276 .71963 L .644 .733 .913 r
F
.24081 .71792 m .22976 .72113 L .23366 .72455 L F
.26061 .72068 m .26933 .72665 L .27346 .72369 L F
.25795 .72175 m .26933 .72665 L .26061 .72068 L F
.23814 .61092 m .22387 .61047 L .22434 .61505 L .605 .403 .582 r
F
.23814 .61092 m .23766 .60634 L .22387 .61047 L F
0 g
.21193 .6165 m
.22387 .61047 L
s
.69322 .61473 m .70416 .6038 L .69036 .61253 L .683 .77 .917 r
F
.69322 .61473 m .70989 .60818 L .70416 .6038 L F
.3722 .48327 m .3549 .47276 L .34665 .47925 L .673 .757 .914 r
F
.37751 .48075 m .3549 .47276 L .3722 .48327 L F
.56435 .35622 m .53759 .34464 L .5309 .35411 L .654 .726 .902 r
F
.56952 .35228 m .53759 .34464 L .56435 .35622 L F
.43921 .4963 m .45672 .48088 L .4345 .48897 L .673 .757 .914 r
F
.43921 .4963 m .46377 .49188 L .45672 .48088 L F
.41645 .59935 m .42794 .58873 L .42843 .59331 L .522 .343 .58 r
F
.41694 .60393 m .41645 .59935 L .42843 .59331 L F
.40745 .59001 m .41645 .59935 L .42843 .59331 L .683 .77 .917 r
F
.39824 .59276 m .41645 .59935 L .40745 .59001 L F
0 g
.40978 .60134 m
.41645 .59935 L
s
.61872 .35907 m .63678 .34139 L .61392 .3546 L .654 .726 .902 r
F
.61872 .35907 m .64637 .35033 L .63678 .34139 L F
0 g
.65914 .50644 m
.67882 .50451 L
s
.53759 .34464 m .5008 .34727 L .5309 .35411 L .654 .726 .902 r
F
.68548 .60183 m .68649 .58976 L .68102 .60094 L .683 .77 .917 r
F
.68548 .60183 m .69542 .59154 L .68649 .58976 L F
.51835 .72953 m .50884 .72439 L .50859 .72816 L .733 .497 .571 r
F
0 g
.50884 .72439 m
.5186 .72575 L
s
.49901 .7246 m
.50884 .72439 L
s
.127 .923 .03 r
.40004 8.82407 m
.46668 5.8741 L
s
0 0 0 r
2.5 Mabswid
.22465 .62308 Mdot
.68985 .60795 m .69603 .59602 L .68604 .60636 L .683 .77 .917 r
F
.68985 .60795 m .70365 .59922 L .69603 .59602 L F
.393 .36625 m .36888 .35976 L .36843 .36705 L .667 .43 .553 r
F
.393 .36625 m .39345 .35896 L .36888 .35976 L F
0 g
.5 Mabswid
.34583 .36468 m
.36888 .35976 L
s
.67994 .62808 m
.68013 .67901 L
s
.65219 .36046 m .67405 .34159 L .64637 .35033 L .654 .726 .902 r
F
.65219 .36046 m .68276 .35679 L .67405 .34159 L F
.41743 .36962 m .41787 .36232 L .39345 .35896 L .732 .487 .557 r
F
0 g
.41787 .36232 m
.44046 .36963 L
s
.46346 .48619 m .4561 .46951 L .45641 .47519 L .987 .711 .381 r
F
.46377 .49188 m .46346 .48619 L .45641 .47519 L F
0 g
.46346 .48619 m
.46548 .49809 L
s
.67487 .68294 m .67136 .6776 L .6687 .67867 L .645 .732 .913 r
F
.67693 .68273 m .67584 .68594 L .67694 .68585 L .66 .416 .54 r
F
.67671 .62674 m .67588 .68276 L .67693 .68273 L F
.67731 .68462 m .67574 .68277 L .67487 .68294 L .645 .732 .913 r
F
.67588 .68276 m .67584 .68594 L .67693 .68273 L .66 .416 .54 r
F
.67574 .68277 m .67554 .68254 L .67512 .68279 L .645 .732 .913 r
F
.67574 .68277 m .67512 .68279 L .67487 .68294 L F
.67554 .68254 m .67136 .6776 L .67487 .68294 L F
.6745 .62717 m .67337 .62796 L .67358 .6837 L .402 .214 .508 r
F
.67364 .68366 m .67358 .6837 L .67359 .68706 L F
.6745 .62717 m .67358 .6837 L .67364 .68366 L F
0 g
.67337 .62796 m
.67357 .6802 L
s
.67334 .62029 m
.67337 .62796 L
s
.127 .923 .03 r
.65717 .3671 m
.65737 .3606 L
s
.644 .60706 m .62186 .61076 L .63993 .61274 L .683 .77 .917 r
F
.22709 .72104 m .21843 .72811 L .22949 .72491 L .644 .733 .913 r
F
.22709 .72104 m .21484 .72232 L .21843 .72811 L F
0 g
.21843 .72811 m
.22429 .73325 L
s
.4123 .49706 m .42677 .48274 L .40843 .49395 L .673 .757 .914 r
F
.4123 .49706 m .4345 .48897 L .42677 .48274 L F
.7087 .59909 m .71673 .58602 L .703 .59472 L .683 .77 .917 r
F
.7087 .59909 m .72528 .59258 L .71673 .58602 L F
.34673 .48487 m .31716 .48884 L .34138 .49238 L .673 .757 .914 r
F
.37016 .59658 m .3738 .6096 L .37917 .59837 L .683 .77 .917 r
F
.37016 .59658 m .36029 .60692 L .3738 .6096 L F
0 g
.3738 .6096 m
.38841 .60999 L
s
.34831 .59755 m .35932 .59776 L .35981 .60234 L .86 .591 .53 r
F
.34831 .59755 m .34782 .59297 L .35932 .59776 L F
0 g
.35932 .59776 m
.3634 .59857 L
s
.52713 .73614 m .51835 .72953 L .5181 .7333 L .793 .551 .571 r
F
0 g
.52713 .73614 m
.5348 .74027 L
s
.127 .923 .03 r
.52205 .75211 m
.5228 .70286 L
s
.28398 .73196 m .28823 .72284 L .28796 .72661 L .072 0 .399 r
F
.27319 .72747 m .28398 .73196 L .28796 .72661 L .644 .733 .913 r
F
.26907 .73042 m .28398 .73196 L .27319 .72747 L F
0 g
.2778 .73639 m
.28398 .73196 L
s
.36166 .58413 m .35947 .59761 L .36929 .58732 L .683 .77 .917 r
F
.36166 .58413 m .34803 .59283 L .35947 .59761 L F
.23994 .7122 m .23014 .71732 L .24114 .71413 L .645 .732 .913 r
F
.23994 .7122 m .22775 .71348 L .23014 .71732 L F
.28147 .61663 m .26747 .60937 L .26794 .61395 L .794 .542 .556 r
F
0 g
.28147 .61663 m
.29298 .62143 L
s
.64191 .47897 m .65412 .4635 L .65446 .46919 L .388 .235 .549 r
F
.64224 .48466 m .64191 .47897 L .65446 .46919 L F
.62464 .4684 m .64191 .47897 L .65446 .46919 L .673 .757 .914 r
F
.61393 .47349 m .64191 .47897 L .62464 .4684 L F
0 g
.63352 .48295 m
.64191 .47897 L
s
.26747 .60937 m .26699 .60479 L .25237 .60441 L .733 .497 .57 r
F
0 g
.26699 .60479 m
.28052 .60748 L
s
.73174 .60956 m .72604 .59706 L .72656 .60164 L .98 .687 .328 r
F
0 g
.73174 .60956 m
.73315 .61827 L
s
.27362 .71987 m .28831 .71902 L .27625 .71632 L .645 .732 .913 r
F
.26288 .7154 m .27362 .71987 L .27625 .71632 L F
.26083 .71687 m .27362 .71987 L .26288 .7154 L F
.66671 .60282 m .65786 .59353 L .64988 .59753 L .683 .77 .917 r
F
.6713 .60145 m .65786 .59353 L .66671 .60282 L F
.67561 .62683 m .6745 .62717 L .67472 .68628 L .568 .343 .534 r
F
.50834 .73194 m .49876 .72837 L .49851 .73215 L .67 .443 .567 r
F
0 g
.48928 .73392 m
.49851 .73215 L
s
.50834 .73194 m .50859 .72816 L .49876 .72837 L .67 .443 .567 r
F
0 g
.48953 .73015 m
.49876 .72837 L
s
.40262 .48029 m .40379 .46395 L .39663 .47887 L .673 .757 .914 r
F
.40262 .48029 m .41577 .46679 L .40379 .46395 L F
.5181 .7333 m .51835 .72953 L .50859 .72816 L .733 .497 .571 r
F
0 g
.51835 .72953 m
.52737 .73237 L
s
.40812 .48826 m .41621 .47235 L .403 .48591 L .673 .757 .914 r
F
.40812 .48826 m .42646 .47705 L .41621 .47235 L F
.24054 .7217 m .23339 .72833 L .24249 .72341 L .644 .733 .913 r
F
.24054 .7217 m .22949 .72491 L .23339 .72833 L F
.6778 .62687 m .67694 .68585 L .67803 .68598 L .734 .477 .539 r
F
.6778 .62687 m .67671 .62674 L .67694 .68585 L F
.66054 .61645 m .64451 .61164 L .64044 .61732 L .683 .77 .917 r
F
.66367 .61394 m .64451 .61164 L .66054 .61645 L F
.26034 .72446 m .26907 .73042 L .27319 .72747 L .644 .733 .913 r
F
.25768 .72553 m .26907 .73042 L .26034 .72446 L F
.67671 .62674 m .67561 .62683 L .67584 .68594 L .66 .416 .54 r
F
.68102 .60094 m .67681 .5895 L .67618 .60081 L .683 .77 .917 r
F
.68102 .60094 m .68649 .58976 L .67681 .5895 L F
.66316 .60936 m .65026 .60204 L .644 .60706 L F
.66717 .60735 m .65026 .60204 L .66316 .60936 L F
.23861 .6155 m .22434 .61505 L .22481 .61963 L .605 .403 .582 r
F
0 g
.21287 .62566 m
.22481 .61963 L
s
.23861 .6155 m .23814 .61092 L .22434 .61505 L .605 .403 .582 r
F
0 g
.2124 .62108 m
.22434 .61505 L
s
.5181 .7333 m .50859 .72816 L .50834 .73194 L .733 .497 .571 r
F
0 g
.50859 .72816 m
.51835 .72953 L
s
.127 .923 .03 r
.51775 .77694 m
.5185 .72635 L
s
0 g
.5181 .7333 m
.52713 .73614 L
s
.49876 .72837 m
.50859 .72816 L
s
.41694 .60393 m .42843 .59331 L .42892 .59789 L .522 .343 .58 r
F
.40794 .59459 m .41694 .60393 L .42892 .59789 L .683 .77 .917 r
F
.39873 .59734 m .41694 .60393 L .40794 .59459 L F
0 g
.40312 .60805 m
.41694 .60393 L
s
.52327 .47156 m .53452 .47522 L .53484 .48091 L .933 .657 .494 r
F
.52327 .47156 m .52295 .46587 L .53452 .47522 L F
0 g
.53452 .47522 m
.54001 .47775 L
s
.6713 .60145 m .66704 .59079 L .65786 .59353 L .683 .77 .917 r
F
.67618 .60081 m .66704 .59079 L .6713 .60145 L F
.37751 .48075 m .36551 .4677 L .3549 .47276 L .673 .757 .914 r
F
.38363 .47911 m .36551 .4677 L .37751 .48075 L F
.36857 .49785 m .34704 .49055 L .34168 .49807 L F
.37272 .49459 m .34704 .49055 L .36857 .49785 L F
.54542 .45769 m .53479 .47505 L .55309 .4639 L F
.54542 .45769 m .52328 .46575 L .53479 .47505 L F
.43366 .47768 m .44422 .46032 L .42596 .47148 L F
.43366 .47768 m .45576 .46963 L .44422 .46032 L F
.67618 .60081 m .67681 .5895 L .66704 .59079 L .683 .77 .917 r
F
.59131 .45962 m .58929 .47212 L .60121 .47095 L .673 .757 .914 r
F
.59179 .45662 m .60121 .47095 L .59547 .45626 L F
.58894 .4569 m .59131 .45962 L .59179 .45662 L F
.59131 .45962 m .60121 .47095 L .59179 .45662 L F
.59397 .41452 m .59409 .4137 L .59415 .44201 L 0 0 .146 r
F
.58926 .46267 m .58847 .47807 L .60159 .47679 L .673 .757 .914 r
F
.58894 .4569 m .58929 .47212 L .59131 .45962 L F
.58926 .46267 m .60159 .47679 L .59583 .46202 L F
.58959 .46835 m .5888 .48376 L .60192 .48247 L F
.58959 .46835 m .60192 .48247 L .59615 .46771 L F
.59282 .41578 m .59322 .44367 L .59288 .44393 L .356 .178 .497 r
F
.59019 .41643 m .59101 .44449 L .59025 .44461 L .641 .4 .539 r
F
.59611 .44373 m .60694 .45209 L .6111 .44884 L .673 .757 .914 r
F
.58862 .41616 m .59019 .41643 L .59025 .44461 L .751 .49 .538 r
F
.59282 .41578 m .59353 .41521 L .59359 .44339 L .356 .178 .497 r
F
.59158 .44631 m .58894 .4569 L .59547 .45626 L .673 .757 .914 r
F
.59116 .44524 m .59072 .44757 L .59158 .44631 L F
.59072 .44757 m .58894 .4569 L .59158 .44631 L F
.59265 .44476 m .59547 .45626 L .60031 .45497 L F
.59265 .4501 m .59856 .4566 L .59326 .44921 L F
.59547 .45626 m .61348 .46767 L .60161 .45462 L F
.59856 .4566 m .602 .46037 L .59782 .45503 L F
.59856 .4566 m .59782 .45503 L .59326 .44921 L F
.59408 .47225 m .59409 .47227 L .59409 .47338 L .076 0 .415 r
F
.59179 .41622 m .59234 .44416 L .59185 .44437 L .516 .301 .527 r
F
.59019 .41643 m .59179 .41622 L .59185 .44437 L .641 .4 .539 r
F
.59019 .41643 m .59185 .44437 L .59101 .44449 L F
.59353 .41521 m .59397 .41452 L .59403 .44275 L .076 0 .415 r
F
.59353 .41521 m .59403 .44275 L .5938 .44309 L F
.59409 .4137 m .59364 .41264 L .5937 .44107 L .983 .725 .333 r
F
.59216 .44423 m .60161 .45462 L .59331 .44375 L .673 .757 .914 r
F
.58894 .4569 m .58815 .47223 L .58929 .47212 L F
.58246 .4565 m .58815 .47223 L .58834 .46861 L F
.58756 .45682 m .58834 .46861 L .58894 .4569 L F
.58246 .4565 m .58834 .46861 L .58756 .45682 L F
.58654 .41356 m .58659 .41438 L .58664 .44288 L .777 .62 .057 r
F
.58957 .44453 m .58894 .4569 L .59095 .44469 L .673 .757 .914 r
F
.58659 .41438 m .58697 .41509 L .58702 .4435 L .988 .719 .381 r
F
.58654 .41356 m .58662 .4425 L .58659 .44213 L .777 .62 .057 r
F
.58654 .41356 m .58664 .44288 L .58662 .4425 L F
.58708 .41252 m .58654 .41356 L .58659 .44213 L 0 0 .377 r
F
.58786 .44489 m .5822 .44996 L .588 .44511 L .673 .757 .914 r
F
.5822 .44996 m .57648 .45507 L .58201 .45029 L F
.5822 .44996 m .58201 .45029 L .588 .44511 L F
.58746 .44424 m .57648 .45507 L .58786 .44489 L F
.58974 .4533 m .58275 .46226 L .58926 .46267 L F
.58986 .45105 m .5891 .45224 L .58974 .4533 L F
.58952 .44547 m .58246 .4565 L .58894 .4569 L F
.58867 .44442 m .58958 .44985 L .58868 .44974 L .751 .49 .538 r
F
.58862 .41616 m .58943 .44451 L .58867 .44442 L F
.58957 .44453 m .58829 .4445 L .58952 .44547 L .673 .757 .914 r
F
.58835 .44438 m .58829 .4445 L .58957 .44453 L F
.58943 .44451 m .58958 .44985 L .58867 .44442 L .751 .49 .538 r
F
.58973 .44155 m .58835 .44438 L .58957 .44453 L .673 .757 .914 r
F
.58829 .4445 m .58246 .4565 L .58952 .44547 L F
.5891 .45224 m .58275 .46226 L .58974 .4533 L F
.58956 .45081 m .5889 .45192 L .58986 .45105 L F
.5889 .45192 m .58275 .46226 L .5891 .45224 L F
.5889 .45192 m .5891 .45224 L .58986 .45105 L F
.58275 .46226 m .58847 .47807 L .58926 .46267 L F
.58714 .46077 m .58308 .46795 L .58763 .46823 L F
.58682 .44318 m .58702 .4435 L .58703 .44882 L .988 .719 .381 r
F
.58786 .44948 m .58225 .45521 L .58866 .45011 L .673 .757 .914 r
F
.57648 .45507 m .57521 .47142 L .58246 .4565 L F
.58225 .45521 m .57674 .46083 L .58149 .45656 L F
.58246 .4565 m .57521 .47142 L .58815 .47223 L F
.58828 .45089 m .57674 .46083 L .58275 .46226 L F
.58811 .4506 m .58688 .45171 L .58828 .45089 L F
.58688 .45171 m .57674 .46083 L .58691 .45207 L F
.58688 .45171 m .58691 .45207 L .58828 .45089 L F
.58763 .41569 m .58816 .44421 L .58768 .44402 L .846 .571 .522 r
F
.58697 .41509 m .58763 .41569 L .58768 .44402 L .93 .648 .485 r
F
.58697 .41509 m .58768 .44402 L .58758 .44394 L F
.58747 .44386 m .5714 .45273 L .57648 .45507 L .673 .757 .914 r
F
.58973 .44155 m .58681 .44333 L .58747 .44386 L F
.58681 .44333 m .5714 .45273 L .58747 .44386 L F
.58734 .44375 m .58769 .44934 L .58741 .44912 L .93 .648 .485 r
F
.58697 .41509 m .58758 .44394 L .58734 .44375 L F
.58747 .44386 m .58741 .44391 L .58768 .44402 L .673 .757 .914 r
F
.588 .44511 m .58685 .4461 L .58693 .4473 L F
.58758 .44394 m .58769 .44934 L .58734 .44375 L .93 .648 .485 r
F
.58662 .4425 m .58663 .44789 L .58659 .44213 L .777 .62 .057 r
F
.58663 .44789 m .58661 .44759 L .58659 .44213 L F
.58659 .44213 m .58661 .44759 L .5866 .44746 L F
.58741 .44391 m .57648 .45507 L .58768 .44402 L .673 .757 .914 r
F
.58682 .44318 m .58687 .44856 L .58664 .44288 L .988 .719 .381 r
F
.58685 .4461 m .57648 .45507 L .58693 .4473 L .673 .757 .914 r
F
.58662 .4425 m .58664 .44288 L .58665 .4482 L .777 .62 .057 r
F
.58663 .44789 m .58666 .45353 L .58664 .45328 L F
.58662 .4425 m .58664 .44801 L .58663 .44789 L F
.58672 .44927 m .58499 .45033 L .58676 .44981 L .673 .757 .914 r
F
.58664 .44801 m .58666 .45353 L .58663 .44789 L .777 .62 .057 r
F
.58722 .44897 m .58672 .44927 L .58786 .44948 L .673 .757 .914 r
F
.58672 .44927 m .58676 .44981 L .58786 .44948 L F
.58693 .4473 m .58136 .45144 L .58246 .4565 L F
.58136 .45144 m .57648 .45507 L .57899 .45567 L F
.58136 .45144 m .57899 .45567 L .58246 .4565 L F
.58499 .45033 m .57163 .45847 L .58438 .45141 L F
.58499 .45033 m .58438 .45141 L .58786 .44948 L F
.58687 .44856 m .58703 .44882 L .58704 .45415 L .988 .719 .381 r
F
.58931 .45514 m .58923 .45529 L .59026 .45525 L .673 .757 .914 r
F
.58741 .44912 m .58748 .45449 L .58714 .44892 L .93 .648 .485 r
F
.59026 .45525 m .58714 .46077 L .58959 .46835 L .673 .757 .914 r
F
.58748 .45449 m .58774 .47455 L .58727 .45433 L .93 .648 .485 r
F
.58748 .45449 m .58727 .45433 L .58714 .44892 L F
.58923 .45529 m .58903 .45571 L .59005 .45562 L .673 .757 .914 r
F
.58903 .45571 m .58308 .46795 L .5897 .45624 L F
.58903 .45571 m .5897 .45624 L .59005 .45562 L F
.58988 .45052 m .58926 .46267 L .59112 .45003 L F
.59106 .45003 m .59112 .45003 L .59113 .45 L F
.58988 .45052 m .59112 .45003 L .59106 .45003 L F
.58943 .44451 m .59025 .44461 L .59026 .44993 L .751 .49 .538 r
F
.58923 .45529 m .59005 .45562 L .59026 .45525 L .673 .757 .914 r
F
.5899 .45024 m .58956 .45081 L .58986 .45105 L F
.59114 .45004 m .58926 .46267 L .59583 .46202 L F
.58225 .45521 m .57163 .45847 L .57674 .46083 L F
.57648 .45507 m .56325 .46858 L .57521 .47142 L F
.58717 .45489 m .5681 .46104 L .57196 .46416 L F
.58687 .45153 m .58688 .45171 L .58866 .45011 L F
.58741 .44912 m .58769 .44934 L .5877 .45467 L .93 .648 .485 r
F
.58748 .45449 m .5877 .45467 L .58774 .47455 L F
.58881 .4498 m .58275 .46226 L .5899 .45024 L .673 .757 .914 r
F
.58741 .44912 m .5877 .45467 L .58748 .45449 L .93 .648 .485 r
F
.58704 .44908 m .56778 .45535 L .57163 .45847 L .673 .757 .914 r
F
.58768 .44402 m .58805 .45481 L .5877 .45467 L .846 .571 .522 r
F
.59005 .44724 m .58607 .44869 L .58704 .44908 L .673 .757 .914 r
F
.58607 .44869 m .56778 .45535 L .58704 .44908 L F
.58768 .44402 m .58746 .44424 L .58829 .4445 L F
.58746 .44424 m .58786 .44489 L .58829 .4445 L F
.58829 .4445 m .58786 .44489 L .588 .44511 L F
.58816 .44421 m .58826 .44957 L .58768 .44402 L .846 .571 .522 r
F
.58664 .44801 m .58665 .4482 L .58666 .45353 L .777 .62 .057 r
F
.58672 .44831 m .58679 .45374 L .58665 .4482 L .988 .719 .381 r
F
.58763 .45461 m .58554 .4547 L .58717 .45489 L .673 .757 .914 r
F
.58679 .45374 m .58708 .47395 L .58674 .45366 L .988 .719 .381 r
F
.58679 .45374 m .58674 .45366 L .58665 .4482 L F
.5876 .45463 m .5874 .45475 L .5884 .45495 L .673 .757 .914 r
F
.58702 .4435 m .58714 .44892 L .58703 .44882 L .93 .648 .485 r
F
.58704 .44667 m .58696 .45216 L .58714 .4465 L 0 0 .377 r
F
.58275 .46226 m .57546 .47726 L .58847 .47807 L .673 .757 .914 r
F
.57674 .46083 m .57546 .47726 L .58275 .46226 L F
.58856 .45667 m .57707 .46652 L .58308 .46795 L F
.58786 .4555 m .58686 .45653 L .58856 .45667 L F
.58686 .45653 m .57707 .46652 L .58696 .45804 L F
.58686 .45653 m .58696 .45804 L .58856 .45667 L F
.58663 .44789 m .58664 .45328 L .58661 .44759 L .777 .62 .057 r
F
.58786 .44948 m .58438 .45141 L .58225 .45521 L .673 .757 .914 r
F
.58687 .44856 m .58691 .45394 L .58672 .44831 L .988 .719 .381 r
F
.58691 .45394 m .58708 .47395 L .58679 .45374 L F
.58691 .45394 m .58679 .45374 L .58672 .44831 L F
.58438 .45141 m .57163 .45847 L .58225 .45521 L .673 .757 .914 r
F
.5714 .45273 m .56325 .46858 L .57648 .45507 L F
.5714 .45273 m .55309 .4639 L .56325 .46858 L F
.58704 .45415 m .56577 .45737 L .5681 .46104 L F
.58836 .45493 m .58805 .45481 L .58786 .44941 L .846 .571 .522 r
F
.58868 .44974 m .58902 .45511 L .58869 .45507 L .751 .49 .538 r
F
.59038 .45293 m .5867 .4536 L .58704 .45415 L .673 .757 .914 r
F
.58225 .45521 m .58149 .45656 L .58688 .45171 L F
.5867 .4536 m .56577 .45737 L .58704 .45415 L F
.58664 .45328 m .5867 .47325 L .58663 .45304 L .777 .62 .057 r
F
.58664 .45328 m .58663 .45304 L .58661 .44759 L F
.58609 .4537 m .56511 .45339 L .56577 .45737 L .673 .757 .914 r
F
.59038 .45293 m .58649 .453 L .58609 .4537 L F
.58649 .453 m .56511 .45339 L .58609 .4537 L F
.58691 .45394 m .58704 .45415 L .58708 .47395 L .988 .719 .381 r
F
.58225 .45521 m .58688 .45171 L .58687 .45153 L .673 .757 .914 r
F
.58697 .41509 m .58734 .44375 L .58702 .4435 L .93 .648 .485 r
F
.58659 .41438 m .58702 .4435 L .58682 .44318 L .988 .719 .381 r
F
.58648 .44353 m .56757 .44962 L .5714 .45273 L .673 .757 .914 r
F
.58973 .44155 m .58544 .44312 L .58648 .44353 L F
.58544 .44312 m .56757 .44962 L .58648 .44353 L F
.58763 .41569 m .58862 .41616 L .58867 .44442 L .846 .571 .522 r
F
.58851 .44436 m .58867 .44442 L .58868 .44974 L F
.58763 .41569 m .58867 .44442 L .58851 .44436 L F
.58826 .44957 m .58786 .44941 L .58768 .44402 L F
.58816 .44421 m .58868 .44974 L .58826 .44957 L F
.58763 .41569 m .58851 .44436 L .58816 .44421 L F
.58851 .44436 m .58868 .44974 L .58816 .44421 L F
.58544 .44312 m .56524 .44597 L .56757 .44962 L .673 .757 .914 r
F
.58821 .41173 m .58708 .41252 L .58713 .44118 L .4 .211 .506 r
F
.58119 .45047 m .56544 .45168 L .56778 .45535 L .673 .757 .914 r
F
.59005 .44724 m .58454 .44824 L .58119 .45047 L F
.58454 .44824 m .56544 .45168 L .58119 .45047 L F
.58771 .44079 m .58713 .44118 L .58714 .4465 L .4 .211 .506 r
F
.58741 .44912 m .58714 .44892 L .58702 .4435 L .93 .648 .485 r
F
.58308 .46795 m .5888 .48376 L .58959 .46835 L .673 .757 .914 r
F
.58704 .45415 m .58774 .47455 L .58708 .47395 L .93 .648 .485 r
F
.58703 .44882 m .58718 .45426 L .58704 .45415 L F
.58718 .45426 m .58774 .47455 L .58704 .45415 L F
.58454 .44824 m .56478 .4477 L .56544 .45168 L .673 .757 .914 r
F
.59005 .44724 m .58592 .44732 L .58454 .44824 L F
.58592 .44732 m .56478 .4477 L .58454 .44824 L F
.58826 .44957 m .58836 .45493 L .58786 .44941 L .846 .571 .522 r
F
.58714 .46077 m .58763 .46823 L .58959 .46835 L .673 .757 .914 r
F
.5877 .45467 m .58873 .47503 L .58774 .47455 L .846 .571 .522 r
F
.5874 .45475 m .58775 .45532 L .5884 .45495 L .673 .757 .914 r
F
.58805 .45481 m .58873 .47503 L .5877 .45467 L .846 .571 .522 r
F
.58682 .44318 m .58703 .44882 L .58687 .44856 L .988 .719 .381 r
F
.58306 .44737 m .56584 .44369 L .56478 .4477 L .673 .757 .914 r
F
.59005 .44724 m .58558 .44659 L .58306 .44737 L F
.58558 .44659 m .56584 .44369 L .58306 .44737 L F
.57764 .44373 m .56458 .44201 L .56524 .44597 L F
.58973 .44155 m .58747 .44386 L .58829 .4445 L F
.58826 .44042 m .58762 .44618 L .58827 .44575 L .4 .211 .506 r
F
.58821 .41173 m .58771 .44079 L .58826 .44042 L F
.58758 .44394 m .58768 .44402 L .58769 .44934 L .93 .648 .485 r
F
.58771 .44079 m .58762 .44618 L .58826 .44042 L .4 .211 .506 r
F
.5854 .44233 m .58432 .44165 L .57764 .44373 L .673 .757 .914 r
F
.58973 .44155 m .58648 .44161 L .5854 .44233 L F
.58648 .44161 m .58432 .44165 L .5854 .44233 L F
.58432 .44165 m .56458 .44201 L .57764 .44373 L F
.58932 .41139 m .58821 .41173 L .58826 .44042 L .567 .342 .533 r
F
.58843 .44037 m .58826 .44042 L .58827 .44575 L F
.58932 .41139 m .58826 .44042 L .58843 .44037 L F
.58836 .45493 m .58873 .47503 L .58805 .45481 L .846 .571 .522 r
F
.58866 .45011 m .58811 .4506 L .58828 .45089 L .673 .757 .914 r
F
.58826 .44957 m .58868 .44974 L .58873 .47503 L .846 .571 .522 r
F
.59038 .45293 m .58704 .45415 L .58763 .45461 L .673 .757 .914 r
F
.59005 .44724 m .58722 .44897 L .58786 .44948 L F
.58973 .44155 m .5854 .44233 L .58544 .44312 L F
.58664 .44288 m .58672 .44831 L .58665 .4482 L .988 .719 .381 r
F
.58687 .44856 m .58672 .44831 L .58664 .44288 L F
.58687 .44164 m .5866 .44746 L .58683 .44705 L 0 0 .377 r
F
.58432 .44165 m .56564 .43802 L .56458 .44201 L .673 .757 .914 r
F
.58659 .41438 m .58682 .44318 L .58664 .44288 L .988 .719 .381 r
F
.58708 .41252 m .58659 .44213 L .58687 .44164 L 0 0 .377 r
F
.58973 .44155 m .58626 .44105 L .58432 .44165 L .673 .757 .914 r
F
.58626 .44105 m .56564 .43802 L .58432 .44165 L F
.58937 .44008 m .58874 .4456 L .58938 .4454 L .567 .342 .533 r
F
.58862 .41616 m .59025 .44461 L .58943 .44451 L .751 .49 .538 r
F
.58932 .41139 m .58883 .44025 L .58937 .44008 L .567 .342 .533 r
F
.58883 .44025 m .58874 .4456 L .58937 .44008 L F
.58626 .44105 m .56834 .43426 L .56564 .43802 L .673 .757 .914 r
F
.58973 .44155 m .58729 .44072 L .58626 .44105 L F
.58729 .44072 m .56834 .43426 L .58626 .44105 L F
.58883 .44025 m .58827 .44575 L .58874 .4456 L .567 .342 .533 r
F
.58932 .41139 m .58843 .44037 L .58883 .44025 L F
.58843 .44037 m .58827 .44575 L .58883 .44025 L F
.58691 .44617 m .57274 .43665 L .56856 .43992 L .673 .757 .914 r
F
.59005 .44724 m .58783 .44588 L .58691 .44617 L F
.58409 .44257 m .56524 .44597 L .58544 .44312 L F
.58783 .44588 m .57274 .43665 L .58691 .44617 L F
.58869 .45507 m .59031 .47529 L .58873 .47503 L .751 .49 .538 r
F
.58902 .45511 m .59031 .47529 L .58869 .45507 L F
.58655 .44673 m .56856 .43992 L .56584 .44369 L .673 .757 .914 r
F
.58652 .45162 m .57306 .44234 L .56888 .44561 L F
.58828 .45107 m .58719 .47139 L .58832 .47059 L .4 .211 .506 r
F
.59005 .44724 m .58786 .44948 L .58866 .45011 L .673 .757 .914 r
F
.58827 .44575 m .58804 .45123 L .58828 .45107 L .4 .211 .506 r
F
.58804 .45123 m .58719 .47139 L .58828 .45107 L F
.58714 .44892 m .58774 .47455 L .58703 .44882 L .93 .648 .485 r
F
.58714 .4465 m .58703 .45203 L .58715 .45183 L 0 0 .377 r
F
.58714 .45183 m .58766 .45127 L .58652 .45162 L .673 .757 .914 r
F
.59038 .45293 m .58783 .45137 L .58714 .45183 L F
.59038 .45293 m .58658 .45238 L .58663 .453 L F
.58662 .4425 m .58665 .4482 L .58664 .44801 L .777 .62 .057 r
F
.59005 .44724 m .58651 .44603 L .58655 .44673 L .673 .757 .914 r
F
.58762 .44618 m .58752 .45158 L .58827 .44575 L .4 .211 .506 r
F
.58752 .45158 m .58719 .47139 L .58804 .45123 L F
.58752 .45158 m .58804 .45123 L .58827 .44575 L F
.58679 .45246 m .58696 .45216 L .58704 .44667 L 0 0 .377 r
F
.58651 .44603 m .56856 .43992 L .58655 .44673 L .673 .757 .914 r
F
.58661 .44759 m .58663 .45304 L .5866 .44746 L .777 .62 .057 r
F
.58663 .45304 m .5867 .47325 L .58662 .45294 L F
.58663 .45304 m .58662 .45294 L .5866 .44746 L F
.58646 .45054 m .57842 .43979 L .57306 .44234 L .673 .757 .914 r
F
.58687 .44856 m .58704 .45415 L .58691 .45394 L .988 .719 .381 r
F
.58783 .45137 m .5864 .44961 L .58646 .45054 L .673 .757 .914 r
F
.5864 .44961 m .57842 .43979 L .58646 .45054 L F
.58874 .4456 m .58865 .45096 L .58938 .4454 L .567 .342 .533 r
F
.58958 .44985 m .59031 .47529 L .58868 .44974 L .751 .49 .538 r
F
.59038 .45293 m .5886 .45097 L .58783 .45137 L .673 .757 .914 r
F
.58958 .44985 m .59027 .45526 L .58973 .45519 L .751 .49 .538 r
F
.59038 .45293 m .5876 .45463 L .5884 .45495 L .673 .757 .914 r
F
.59038 .45293 m .58786 .4555 L .58856 .45667 L F
.58865 .45096 m .58832 .47059 L .58915 .4508 L .567 .342 .533 r
F
.58865 .45096 m .58915 .4508 L .58938 .4454 L F
.58874 .4456 m .58827 .44575 L .58828 .45107 L F
.58865 .45096 m .58828 .45107 L .58832 .47059 L F
.58874 .4456 m .58828 .45107 L .58865 .45096 L F
.5854 .44233 m .58409 .44257 L .58468 .44281 L .673 .757 .914 r
F
.5854 .44233 m .58468 .44281 L .58544 .44312 L F
.58683 .44705 m .58679 .45246 L .58704 .44667 L 0 0 .377 r
F
.58734 .44375 m .58741 .44912 L .58702 .4435 L .93 .648 .485 r
F
.58771 .44079 m .58714 .4465 L .58762 .44618 L .4 .211 .506 r
F
.58713 .44118 m .58704 .44667 L .58714 .4465 L 0 0 .377 r
F
.58687 .44164 m .58659 .44213 L .5866 .44746 L F
.58683 .44705 m .58704 .44667 L .58713 .44118 L F
.58821 .41173 m .58713 .44118 L .58771 .44079 L .4 .211 .506 r
F
.58708 .41252 m .58687 .44164 L .58713 .44118 L 0 0 .377 r
F
.58973 .44155 m .5725 .43101 L .56834 .43426 L .673 .757 .914 r
F
.58739 .44561 m .5781 .4341 L .57274 .43665 L F
.59005 .44724 m .58847 .4455 L .58739 .44561 L F
.58847 .4455 m .5781 .4341 L .58739 .44561 L F
.59042 .4113 m .58932 .41139 L .58938 .4454 L .66 .415 .539 r
F
.59038 .45293 m .58951 .45071 L .5886 .45097 L .673 .757 .914 r
F
.58943 .44451 m .59026 .44993 L .58958 .44985 L .751 .49 .538 r
F
.59005 .44724 m .58881 .4498 L .5899 .45024 L .673 .757 .914 r
F
.58985 .44535 m .58939 .45073 L .58976 .45069 L .66 .415 .539 r
F
.58951 .45071 m .5895 .45069 L .58939 .45073 L .673 .757 .914 r
F
.58951 .45071 m .58939 .45073 L .5886 .45097 L F
.58985 .44535 m .58938 .4454 L .58939 .45073 L .66 .415 .539 r
F
.58976 .45069 m .58939 .45073 L .58943 .47025 L F
.59042 .4113 m .58954 .44006 L .58993 .44002 L F
.58916 .4401 m .59051 .42619 L .58397 .42683 L .673 .757 .914 r
F
.58973 .44155 m .5898 .44003 L .58916 .4401 L F
.5898 .44003 m .59051 .42619 L .58916 .4401 L F
.58973 .44155 m .58957 .44453 L .59095 .44469 L F
.58993 .44002 m .58938 .4454 L .58985 .44535 L .66 .415 .539 r
F
.58954 .44006 m .58938 .4454 L .58993 .44002 L F
.5886 .45097 m .5846 .43814 L .57842 .43979 L .673 .757 .914 r
F
.58762 .44618 m .58714 .4465 L .58715 .45183 L .4 .211 .506 r
F
.58752 .45158 m .58715 .45183 L .58719 .47139 L F
.58762 .44618 m .58715 .45183 L .58752 .45158 L F
.5895 .45069 m .58937 .45035 L .5886 .45097 L .673 .757 .914 r
F
.58937 .45035 m .5846 .43814 L .58857 .45088 L F
.58937 .45035 m .58857 .45088 L .5886 .45097 L F
.5886 .45097 m .58853 .4509 L .58828 .45107 L F
.5886 .45097 m .58828 .45107 L .58783 .45137 L F
.58696 .45216 m .58703 .45203 L .58714 .4465 L 0 0 .377 r
F
.5866 .44746 m .58662 .45294 L .58661 .45278 L .777 .62 .057 r
F
.58683 .44705 m .5866 .44746 L .58661 .45278 L 0 0 .377 r
F
.58853 .4509 m .57842 .43979 L .58783 .45137 L .673 .757 .914 r
F
.58783 .45137 m .58766 .45127 L .58714 .45183 L F
.58683 .44705 m .58661 .45278 L .58679 .45246 L 0 0 .377 r
F
.58766 .45127 m .57306 .44234 L .58652 .45162 L .673 .757 .914 r
F
.58939 .45073 m .58832 .47059 L .58943 .47025 L .567 .342 .533 r
F
.58938 .4454 m .58915 .4508 L .58939 .45073 L F
.58915 .4508 m .58832 .47059 L .58939 .45073 L F
.58436 .45205 m .56888 .44561 L .56617 .44938 L .673 .757 .914 r
F
.59006 .4592 m .58959 .46835 L .59183 .45663 L F
.58973 .45519 m .59027 .45526 L .59031 .47529 L .751 .49 .538 r
F
.59049 .45061 m .58943 .47025 L .59053 .47016 L .66 .415 .539 r
F
.59084 .44548 m .58894 .4569 L .59116 .44524 L .673 .757 .914 r
F
.59094 .44475 m .58894 .4569 L .59097 .44474 L F
.59106 .44981 m .58988 .45052 L .59113 .45 L F
.59025 .44461 m .59054 .44989 L .59026 .44993 L .641 .4 .539 r
F
.59005 .44724 m .58991 .44998 L .59106 .44981 L .673 .757 .914 r
F
.58991 .44998 m .58988 .45052 L .59106 .44981 L F
.59112 .45003 m .58926 .46267 L .59114 .45004 L F
.59183 .45663 m .58959 .46835 L .59167 .46815 L F
.59026 .44993 m .59191 .47509 L .59031 .47529 L .641 .4 .539 r
F
.59123 .45511 m .59006 .4592 L .59183 .45663 L .673 .757 .914 r
F
.59082 .45517 m .5906 .4552 L .59026 .44993 L .641 .4 .539 r
F
.59113 .45 m .59112 .45003 L .59114 .45004 L .673 .757 .914 r
F
.59097 .44474 m .59084 .44548 L .59116 .44524 L F
.59095 .44469 m .59094 .44475 L .59097 .44474 L F
.59101 .44449 m .59117 .44979 L .59025 .44461 L .641 .4 .539 r
F
.60161 .45462 m .61348 .46767 L .62414 .46261 L .673 .757 .914 r
F
.602 .46037 m .62464 .4684 L .60735 .45783 L F
.59508 .45453 m .60768 .46352 L .61186 .46025 L F
.59131 .45046 m .59583 .46202 L .5923 .44971 L F
.59303 .45972 m .59167 .46815 L .59615 .46771 L F
.5929 .45458 m .59365 .47407 L .59294 .47464 L .356 .178 .497 r
F
.59289 .44926 m .59305 .45447 L .5929 .45458 L F
.59305 .45447 m .59365 .47407 L .5929 .45458 L F
.59247 .44502 m .59547 .45626 L .59265 .44476 L .673 .757 .914 r
F
.59384 .44853 m .59362 .44943 L .59559 .44913 L F
.59223 .44431 m .59226 .44441 L .59229 .44438 L F
.59088 .44451 m .59547 .45626 L .59223 .44431 L F
.5957 .44807 m .61153 .45456 L .61425 .4508 L F
.59244 .44944 m .5922 .44955 L .59185 .44437 L .516 .301 .527 r
F
.59234 .44416 m .59289 .44926 L .59244 .44944 L F
.59322 .44367 m .59359 .44339 L .5936 .44871 L .356 .178 .497 r
F
.59324 .45301 m .59583 .46202 L .59355 .45109 L .673 .757 .914 r
F
.59179 .41622 m .59282 .41578 L .59288 .44393 L .516 .301 .527 r
F
.59179 .41622 m .59288 .44393 L .59234 .44416 L F
.59353 .41521 m .5938 .44309 L .59359 .44339 L .076 0 .415 r
F
.59282 .41578 m .59359 .44339 L .59322 .44367 L .356 .178 .497 r
F
.59572 .44243 m .6111 .44884 L .6138 .44509 L .673 .757 .914 r
F
.58973 .44155 m .59919 .44478 L .59572 .44243 L F
.59919 .44478 m .6111 .44884 L .59572 .44243 L F
.59223 .45509 m .59615 .46771 L .5923 .45504 L F
.59226 .44441 m .59547 .45626 L .59229 .44438 L F
.59309 .4491 m .59362 .44943 L .59384 .44853 L F
.59329 .44895 m .5936 .44871 L .59361 .45404 L .356 .178 .497 r
F
.59101 .44449 m .59185 .44437 L .59187 .45502 L .641 .4 .539 r
F
.59129 .45526 m .59145 .45568 L .59208 .45498 L .673 .757 .914 r
F
.59129 .45526 m .59208 .45498 L .59187 .45502 L F
.59132 .4551 m .59187 .45502 L .59191 .47509 L .641 .4 .539 r
F
.59223 .44964 m .59131 .45046 L .5923 .44971 L .673 .757 .914 r
F
.59117 .44979 m .59054 .44989 L .59025 .44461 L .641 .4 .539 r
F
.59005 .44724 m .59106 .44981 L .59223 .44964 L .673 .757 .914 r
F
.59106 .44981 m .59131 .45046 L .59223 .44964 L F
.59117 .44979 m .59187 .45502 L .59132 .4551 L .641 .4 .539 r
F
.59101 .44449 m .59144 .44975 L .59117 .44979 L F
.59144 .44975 m .59187 .45502 L .59117 .44979 L F
.59187 .45502 m .59208 .45498 L .59216 .45489 L .673 .757 .914 r
F
.59145 .45568 m .59615 .46771 L .59223 .45509 L F
.59145 .45568 m .59223 .45509 L .59216 .45489 L F
.5923 .44971 m .59324 .45301 L .59355 .45109 L F
.59301 .44916 m .59315 .45439 L .59289 .44926 L .356 .178 .497 r
F
.59315 .45439 m .59365 .47407 L .59305 .45447 L F
.59315 .45439 m .59305 .45447 L .59289 .44926 L F
.59337 .45422 m .59361 .45404 L .59365 .47407 L F
.59329 .44895 m .59361 .45404 L .59337 .45422 L F
.59583 .46202 m .60159 .47679 L .61393 .47349 L .673 .757 .914 r
F
.59262 .45548 m .59615 .46771 L .60074 .46648 L F
.5923 .45504 m .59249 .45567 L .59262 .45548 L F
.59249 .45567 m .59615 .46771 L .59262 .45548 L F
.59265 .44476 m .60031 .45497 L .59854 .45124 L F
.59397 .41452 m .59415 .44201 L .59409 .4424 L 0 0 .146 r
F
.59397 .41452 m .59409 .4424 L .59403 .44275 L F
.5943 .44147 m .6138 .44509 L .61486 .4411 L .673 .757 .914 r
F
.58973 .44155 m .59572 .44243 L .5943 .44147 L F
.59572 .44243 m .6138 .44509 L .5943 .44147 L F
.59364 .41264 m .59258 .41181 L .59264 .44035 L .911 .629 .497 r
F
.59229 .44438 m .59247 .44502 L .59265 .44476 L .673 .757 .914 r
F
.59234 .44416 m .59288 .44393 L .59289 .44926 L .516 .301 .527 r
F
.59005 .44724 m .59384 .44853 L .59449 .44803 L .673 .757 .914 r
F
.59442 .44788 m .59449 .44803 L .59465 .44792 L F
.59329 .44895 m .59301 .44916 L .59288 .44393 L .356 .178 .497 r
F
.59005 .44724 m .59449 .44803 L .59442 .44788 L .673 .757 .914 r
F
.59385 .44835 m .5939 .45362 L .59374 .4485 L .076 0 .415 r
F
.5939 .44679 m .59372 .45172 L .59387 .45203 L .983 .725 .333 r
F
.5938 .44309 m .59404 .44808 L .59392 .44824 L .076 0 .415 r
F
.59393 .44155 m .59383 .44663 L .5939 .44679 L .983 .725 .333 r
F
.59385 .44835 m .59374 .4485 L .59359 .44339 L .076 0 .415 r
F
.59383 .44663 m .59372 .45172 L .5939 .44679 L .983 .725 .333 r
F
.59244 .44944 m .59289 .44926 L .5929 .45458 L .516 .301 .527 r
F
.59255 .45473 m .5929 .45458 L .59294 .47464 L F
.59244 .44944 m .5929 .45458 L .59255 .45473 L F
.60161 .45462 m .62414 .46261 L .60694 .45209 L .673 .757 .914 r
F
.59559 .44913 m .60735 .45783 L .61153 .45456 L F
.59854 .45124 m .60031 .45497 L .60161 .45462 L F
.5938 .44954 m .602 .46037 L .60735 .45783 L F
.59326 .44921 m .59375 .44984 L .5938 .44954 L F
.59375 .44984 m .602 .46037 L .5938 .44954 L F
.59404 .44808 m .59409 .45314 L .59405 .4534 L 0 0 .146 r
F
.59403 .44275 m .59406 .44795 L .59404 .44808 L F
.59406 .44795 m .59409 .45314 L .59404 .44808 L F
.59515 .45363 m .61186 .46025 L .61458 .45649 L .673 .757 .914 r
F
.59329 .44895 m .59337 .45422 L .59301 .44916 L .356 .178 .497 r
F
.59298 .45452 m .59341 .45478 L .59362 .45403 L .673 .757 .914 r
F
.59337 .45422 m .59365 .47407 L .59315 .45439 L .356 .178 .497 r
F
.59337 .45422 m .59315 .45439 L .59301 .44916 L F
.59547 .45626 m .60121 .47095 L .61348 .46767 L .673 .757 .914 r
F
.59355 .45109 m .59583 .46202 L .602 .46037 L F
.59431 .45351 m .59394 .45414 L .59515 .45363 L F
.59038 .45293 m .59362 .45403 L .59431 .45351 L F
.59362 .45403 m .59394 .45414 L .59431 .45351 L F
.59394 .45414 m .61186 .46025 L .59515 .45363 L F
.59288 .44393 m .59301 .44916 L .59289 .44926 L .356 .178 .497 r
F
.59484 .44716 m .61425 .4508 L .61532 .44679 L .673 .757 .914 r
F
.5938 .44309 m .59385 .44835 L .59359 .44339 L .076 0 .415 r
F
.58973 .44155 m .59384 .44407 L .59611 .44373 L .673 .757 .914 r
F
.59393 .44155 m .5937 .44107 L .59371 .44639 L .983 .725 .333 r
F
.5939 .45362 m .59376 .45382 L .59359 .44339 L .076 0 .415 r
F
.59383 .44663 m .59371 .44639 L .59372 .45172 L .983 .725 .333 r
F
.5938 .44309 m .59405 .4534 L .5939 .45361 L .076 0 .415 r
F
.59393 .44155 m .59371 .44639 L .59383 .44663 L .983 .725 .333 r
F
.59408 .44717 m .59634 .44817 L .59484 .44716 L .673 .757 .914 r
F
.59005 .44724 m .59442 .44788 L .59408 .44717 L F
.59442 .44788 m .59634 .44817 L .59408 .44717 L F
.59384 .44407 m .60694 .45209 L .59611 .44373 L F
.59634 .44817 m .61425 .4508 L .59484 .44716 L F
.59319 .44072 m .59264 .44035 L .59265 .44567 L .911 .629 .497 r
F
.59255 .45473 m .59222 .45486 L .59185 .44437 L .516 .301 .527 r
F
.59038 .45293 m .59298 .45452 L .59362 .45403 L .673 .757 .914 r
F
.59539 .45284 m .61458 .45649 L .61565 .45248 L F
.59038 .45293 m .59695 .4539 L .59539 .45284 L F
.59362 .44943 m .60735 .45783 L .59559 .44913 L F
.59695 .4539 m .61458 .45649 L .59539 .45284 L F
.5931 .44598 m .59265 .44567 L .59266 .451 L .911 .629 .497 r
F
.60694 .45209 m .63246 .45612 L .6111 .44884 L .673 .757 .914 r
F
.59444 .4522 m .61565 .45248 L .615 .4485 L F
.59331 .44375 m .59772 .44952 L .59566 .44518 L F
.59443 .44565 m .59526 .4463 L .59613 .44503 L F
.59411 .44765 m .59408 .44783 L .59403 .44275 L 0 0 .146 r
F
.59409 .4424 m .59416 .44733 L .59411 .44765 L F
.59183 .45663 m .59167 .46815 L .59303 .45972 L .673 .757 .914 r
F
.59255 .45473 m .59294 .47464 L .59222 .45486 L .516 .301 .527 r
F
.59187 .45502 m .59294 .47464 L .59191 .47509 L F
.59316 .44914 m .59265 .4501 L .59326 .44921 L .673 .757 .914 r
F
.59005 .44724 m .59216 .44956 L .59316 .44914 L F
.59216 .44956 m .59265 .4501 L .59316 .44914 L F
.59186 .44969 m .59222 .45486 L .59187 .45502 L .516 .301 .527 r
F
.59185 .44437 m .59204 .44962 L .59186 .44969 L F
.59204 .44962 m .59222 .45486 L .59186 .44969 L F
.59216 .45489 m .59223 .45509 L .5923 .45504 L .673 .757 .914 r
F
.59222 .45486 m .59294 .47464 L .59187 .45502 L .516 .301 .527 r
F
.593 .45454 m .59265 .45543 L .59319 .45465 L .673 .757 .914 r
F
.59132 .4551 m .59082 .45517 L .59054 .44989 L .641 .4 .539 r
F
.59038 .45293 m .59216 .45489 L .593 .45454 L .673 .757 .914 r
F
.59216 .45489 m .59265 .45543 L .593 .45454 L F
.59265 .44567 m .59243 .45093 L .59266 .451 L .81 .54 .53 r
F
.59409 .4424 m .59415 .44201 L .59416 .44733 L 0 0 .146 r
F
.59415 .44201 m .59408 .44717 L .59416 .44733 L .983 .725 .333 r
F
.59361 .44595 m .59435 .44616 L .59443 .44565 L .673 .757 .914 r
F
.5943 .44648 m .59526 .4463 L .59443 .44565 L F
.59359 .44339 m .59368 .4486 L .5936 .44871 L .076 0 .415 r
F
.5937 .44107 m .59335 .45146 L .59372 .45172 L .911 .629 .497 r
F
.59322 .44367 m .59329 .44895 L .59288 .44393 L .356 .178 .497 r
F
.5931 .44598 m .59336 .44615 L .5937 .44107 L .911 .629 .497 r
F
.5938 .44309 m .59403 .44275 L .59404 .44808 L .076 0 .415 r
F
.59393 .44155 m .5939 .44679 L .59415 .44201 L .983 .725 .333 r
F
.59392 .44824 m .59404 .44808 L .59405 .4534 L .076 0 .415 r
F
.5939 .45362 m .59409 .47338 L .59376 .45382 L F
.59583 .46202 m .61393 .47349 L .602 .46037 L .673 .757 .914 r
F
.59591 .45631 m .60232 .46606 L .60768 .46352 L F
.59411 .44765 m .59416 .44733 L .59417 .45266 L 0 0 .146 r
F
.59413 .45291 m .59417 .45266 L .59421 .47256 L F
.59411 .44765 m .59417 .45266 L .59413 .45291 L F
.59379 .45502 m .59794 .46058 L .59591 .45631 L .673 .757 .914 r
F
.59319 .45465 m .59374 .45533 L .59379 .45502 L F
.59374 .45533 m .59794 .46058 L .59379 .45502 L F
.59794 .46058 m .60232 .46606 L .59591 .45631 L F
.5939 .44679 m .59387 .45203 L .59408 .44717 L .983 .725 .333 r
F
.59387 .45203 m .59376 .47151 L .59401 .45233 L F
.59387 .45203 m .59401 .45233 L .59408 .44717 L F
.59409 .4424 m .59411 .44765 L .59403 .44275 L 0 0 .146 r
F
.59413 .45291 m .59409 .45314 L .59403 .44275 L F
.5939 .44679 m .59408 .44717 L .59415 .44201 L .983 .725 .333 r
F
.59409 .44077 m .61486 .4411 L .61422 .43714 L .673 .757 .914 r
F
.58973 .44155 m .59642 .44143 L .59409 .44077 L F
.59642 .44143 m .61486 .4411 L .59409 .44077 L F
.58973 .44155 m .59216 .44423 L .59331 .44375 L F
.59264 .44035 m .59203 .4455 L .59265 .44567 L .81 .54 .53 r
F
.59258 .41181 m .59212 .4402 L .59264 .44035 L F
.59212 .4402 m .59203 .4455 L .59264 .44035 L F
.59364 .41264 m .59264 .44035 L .59319 .44072 L .911 .629 .497 r
F
.59364 .41264 m .59319 .44072 L .5937 .44107 L F
.59409 .4137 m .5937 .44107 L .59393 .44155 L .983 .725 .333 r
F
.59409 .4137 m .59393 .44155 L .59415 .44201 L F
.59273 .43972 m .6119 .43348 L .60807 .43037 L .673 .757 .914 r
F
.59258 .41181 m .59151 .41143 L .59156 .44004 L .81 .54 .53 r
F
.59349 .44018 m .61422 .43714 L .6119 .43348 L .673 .757 .914 r
F
.58973 .44155 m .59621 .44038 L .59349 .44018 L F
.59621 .44038 m .61422 .43714 L .59349 .44018 L F
.59212 .4402 m .59156 .44004 L .59157 .44536 L .81 .54 .53 r
F
.59005 .44724 m .59263 .44567 L .59214 .44553 L .673 .757 .914 r
F
.5946 .44559 m .61234 .43913 L .59296 .44547 L F
.5938 .44309 m .59385 .44835 L .59385 .44835 L .076 0 .415 r
F
.59005 .44724 m .59467 .44716 L .59473 .44708 L .673 .757 .914 r
F
.59394 .44654 m .59473 .44708 L .59526 .4463 L F
.59322 .44367 m .5936 .44871 L .59329 .44895 L .356 .178 .497 r
F
.59005 .44724 m .59473 .44708 L .59394 .44654 L .673 .757 .914 r
F
.59302 .45124 m .59335 .45146 L .59353 .44626 L .911 .629 .497 r
F
.59336 .44615 m .59353 .44626 L .5937 .44107 L F
.59302 .45124 m .59353 .44626 L .59336 .44615 L F
.59203 .4455 m .59157 .44536 L .59158 .45069 L .81 .54 .53 r
F
.59526 .4463 m .61532 .44679 L .61467 .44281 L .673 .757 .914 r
F
.59467 .44716 m .61532 .44679 L .59526 .4463 L F
.59725 .44874 m .61267 .44482 L .60882 .44169 L F
.59411 .44765 m .59413 .45291 L .59408 .44783 L 0 0 .146 r
F
.59401 .45233 m .59407 .45246 L .59416 .44733 L .983 .725 .333 r
F
.59038 .45293 m .5957 .45099 L .59725 .44874 L .673 .757 .914 r
F
.59772 .44952 m .60161 .45462 L .59566 .44518 L F
.5957 .45099 m .61267 .44482 L .59725 .44874 L F
.59385 .44835 m .5939 .45361 L .59385 .44835 L .076 0 .415 r
F
.5939 .45361 m .59409 .47227 L .5939 .45362 L F
.5939 .45361 m .5939 .45362 L .59385 .44835 L F
.59385 .44835 m .5939 .45362 L .5939 .45362 L F
.59571 .45099 m .615 .4485 L .61267 .44482 L .673 .757 .914 r
F
.5936 .44871 m .5937 .4539 L .59361 .45404 L .076 0 .415 r
F
.59038 .45293 m .59956 .45128 L .59571 .45099 L .673 .757 .914 r
F
.59566 .44518 m .60161 .45462 L .60694 .45209 L F
.59426 .44868 m .61153 .45456 L .5957 .44807 L F
.59956 .45128 m .615 .4485 L .59571 .45099 L F
.59094 .44532 m .59085 .45064 L .59138 .44535 L .734 .476 .539 r
F
.59117 .44979 m .59132 .4551 L .59054 .44989 L .641 .4 .539 r
F
.59082 .45517 m .59191 .47509 L .5906 .4552 L F
.59085 .45064 m .59053 .47016 L .5912 .45066 L .734 .476 .539 r
F
.59085 .45064 m .5912 .45066 L .59138 .44535 L F
.59194 .45079 m .59158 .45069 L .59162 .47029 L .81 .54 .53 r
F
.59203 .4455 m .59158 .45069 L .59194 .45079 L F
.59236 .45091 m .59725 .44874 L .60371 .43933 L .673 .757 .914 r
F
.59244 .44944 m .59255 .45473 L .5922 .44955 L .516 .301 .527 r
F
.59038 .45293 m .59327 .45117 L .59236 .45091 L .673 .757 .914 r
F
.59327 .45117 m .59725 .44874 L .59236 .45091 L F
.59666 .44426 m .61234 .43913 L .5979 .44246 L F
.59613 .44503 m .61467 .44281 L .61234 .43913 L F
.59526 .4463 m .61467 .44281 L .59613 .44503 L F
.59725 .44874 m .60882 .44169 L .60372 .43934 L F
.59725 .44874 m .60372 .43934 L .60371 .43933 L F
.5939 .45362 m .59409 .47227 L .59408 .47225 L .076 0 .415 r
F
.5939 .45362 m .59409 .47227 L .5939 .45362 L F
.5979 .44246 m .61234 .43913 L .60849 .436 L .673 .757 .914 r
F
.59296 .44547 m .59666 .44426 L .5979 .44246 L F
.59234 .44416 m .59244 .44944 L .59185 .44437 L .516 .301 .527 r
F
.59005 .44724 m .5946 .44559 L .59296 .44547 L .673 .757 .914 r
F
.59103 .44 m .59094 .44532 L .59156 .44004 L .734 .476 .539 r
F
.58973 .44155 m .59286 .44041 L .592 .44017 L .673 .757 .914 r
F
.58973 .44155 m .59088 .44451 L .59223 .44431 L F
.59094 .44532 m .59138 .44535 L .59156 .44004 L .734 .476 .539 r
F
.59212 .4402 m .59157 .44536 L .59203 .4455 L .81 .54 .53 r
F
.59214 .44553 m .59264 .44567 L .59227 .44542 L .673 .757 .914 r
F
.59263 .44567 m .59264 .44567 L .59214 .44553 L F
.59187 .44539 m .59227 .44542 L .59201 .44524 L F
.59005 .44724 m .59227 .44542 L .59187 .44539 L F
.59038 .45293 m .59236 .45091 L .59158 .45069 L F
.59157 .44536 m .59135 .45067 L .59158 .45069 L .734 .476 .539 r
F
.59147 .45068 m .59158 .45069 L .59148 .45066 L .673 .757 .914 r
F
.59038 .45293 m .59158 .45069 L .59147 .45068 L F
.59132 .4551 m .59191 .47509 L .59082 .45517 L .641 .4 .539 r
F
.59158 .45069 m .59053 .47016 L .59162 .47029 L .734 .476 .539 r
F
.59038 .45293 m .59129 .45526 L .59216 .45489 L .673 .757 .914 r
F
.59135 .45067 m .59053 .47016 L .59158 .45069 L .734 .476 .539 r
F
.59156 .44004 m .59138 .44535 L .59157 .44536 L F
.59138 .44535 m .59053 .47016 L .59157 .44536 L F
.59151 .41143 m .59103 .44 L .59156 .44004 L F
.59258 .41181 m .59156 .44004 L .59212 .4402 L .81 .54 .53 r
F
.592 .44017 m .5956 .43941 L .59273 .43972 L .673 .757 .914 r
F
.59286 .44041 m .5956 .43941 L .592 .44017 L F
.5956 .43941 m .6119 .43348 L .59273 .43972 L F
.59047 .43996 m .58976 .45069 L .59049 .45061 L .66 .415 .539 r
F
.59042 .4113 m .58993 .44002 L .59047 .43996 L F
.58934 .44541 m .59084 .4318 L .58427 .43244 L .673 .757 .914 r
F
.59005 .44724 m .59015 .44532 L .58934 .44541 L F
.58993 .44002 m .58985 .44535 L .59047 .43996 L .66 .415 .539 r
F
.58985 .44535 m .59011 .44532 L .59047 .43996 L F
.5905 .43996 m .60298 .42802 L .597 .42659 L .673 .757 .914 r
F
.58973 .44155 m .59123 .44002 L .5905 .43996 L F
.59123 .44002 m .60298 .42802 L .5905 .43996 L F
.59151 .41143 m .59042 .4113 L .59047 .43996 L .734 .476 .539 r
F
.59038 .45293 m .59026 .45526 L .59123 .45511 L .673 .757 .914 r
F
.59026 .45526 m .59006 .4592 L .59123 .45511 L F
.59054 .44989 m .59082 .45517 L .59026 .44993 L .641 .4 .539 r
F
.58973 .44155 m .60807 .43037 L .60298 .42802 L .673 .757 .914 r
F
.59005 .44724 m .5943 .44648 L .59435 .44616 L F
.59103 .44 m .59049 .45061 L .59085 .45064 L .734 .476 .539 r
F
.59201 .44524 m .59292 .44473 L .59279 .44445 L .673 .757 .914 r
F
.59319 .44072 m .5931 .44598 L .5937 .44107 L .911 .629 .497 r
F
.59005 .44724 m .59435 .44616 L .59361 .44595 L .673 .757 .914 r
F
.59319 .44072 m .59265 .44567 L .5931 .44598 L .911 .629 .497 r
F
.59005 .44724 m .60338 .43364 L .59736 .43221 L .673 .757 .914 r
F
.5905 .45061 m .59769 .4379 L .59117 .43749 L F
.59038 .45293 m .59147 .45068 L .5905 .45061 L F
.5931 .44598 m .59302 .45124 L .59336 .44615 L .911 .629 .497 r
F
.59005 .44724 m .59309 .4491 L .59384 .44853 L .673 .757 .914 r
F
.59147 .45068 m .59769 .4379 L .5905 .45061 L F
.59103 .44 m .59047 .43996 L .59048 .44528 L .734 .476 .539 r
F
.59103 .44 m .59048 .44528 L .59076 .44531 L F
.59015 .44526 m .59736 .43221 L .59084 .4318 L .673 .757 .914 r
F
.59005 .44724 m .59099 .44532 L .59015 .44526 L F
.59099 .44532 m .59736 .43221 L .59015 .44526 L F
.59076 .44531 m .59048 .44528 L .59049 .45061 L .734 .476 .539 r
F
.59085 .45064 m .59049 .45061 L .59053 .47016 L F
.59151 .41143 m .59047 .43996 L .59103 .44 L F
.59015 .44532 m .59084 .4318 L .58934 .44541 L .673 .757 .914 r
F
.58985 .44535 m .58976 .45069 L .59011 .44532 L .66 .415 .539 r
F
.59279 .44445 m .60849 .436 L .60338 .43364 L .673 .757 .914 r
F
.59292 .44473 m .60849 .436 L .59279 .44445 L F
.59264 .44567 m .60849 .436 L .59201 .44524 L F
.59302 .45124 m .5927 .47067 L .59335 .45146 L .911 .629 .497 r
F
.59165 .45032 m .60371 .43933 L .59769 .4379 L .673 .757 .914 r
F
.59148 .45066 m .59177 .4504 L .59165 .45032 L F
.59177 .4504 m .60371 .43933 L .59165 .45032 L F
.5931 .44598 m .59266 .451 L .59302 .45124 L .911 .629 .497 r
F
.59465 .44792 m .59426 .44868 L .5957 .44807 L .673 .757 .914 r
F
.59384 .44853 m .59426 .44868 L .59465 .44792 L F
.59408 .44717 m .59401 .45233 L .59416 .44733 L .983 .725 .333 r
F
.59236 .45091 m .60371 .43933 L .59148 .45066 L .673 .757 .914 r
F
.59266 .451 m .59162 .47029 L .5927 .47067 L .81 .54 .53 r
F
.59243 .45093 m .59162 .47029 L .59266 .451 L F
.59203 .4455 m .59162 .47029 L .59265 .44567 L F
.59413 .45291 m .59421 .47256 L .59409 .45314 L 0 0 .146 r
F
.59424 .45224 m .59539 .45284 L .59444 .4522 L .673 .757 .914 r
F
.59038 .45293 m .59414 .45286 L .59424 .45224 L F
.59414 .45286 m .59539 .45284 L .59424 .45224 L F
.59539 .45284 m .61565 .45248 L .59444 .4522 L F
.59372 .45172 m .5927 .47067 L .59376 .47151 L .911 .629 .497 r
F
.59335 .45146 m .5927 .47067 L .59372 .45172 L F
.59302 .45124 m .59266 .451 L .5927 .47067 L F
.59362 .45403 m .59341 .45478 L .59506 .45454 L .673 .757 .914 r
F
.5939 .45361 m .59405 .4534 L .59409 .47227 L .076 0 .415 r
F
.59265 .45543 m .60232 .46606 L .59319 .45465 L .673 .757 .914 r
F
.59361 .45404 m .59409 .47338 L .59365 .47407 L .076 0 .415 r
F
.5937 .4539 m .59409 .47338 L .59361 .45404 L F
.59368 .4486 m .59376 .45382 L .5936 .44871 L F
.59376 .45382 m .59409 .47338 L .5937 .4539 L F
.59376 .45382 m .5937 .4539 L .5936 .44871 L F
.59265 .45543 m .60074 .46648 L .59859 .46196 L .673 .757 .914 r
F
.5923 .45504 m .59262 .45548 L .59265 .45543 L F
.59262 .45548 m .60074 .46648 L .59265 .45543 L F
.59387 .45203 m .59372 .45172 L .59376 .47151 L .983 .725 .333 r
F
.59859 .46196 m .60074 .46648 L .60232 .46606 L .673 .757 .914 r
F
.59401 .45233 m .59376 .47151 L .59407 .45246 L .983 .725 .333 r
F
.59506 .45453 m .59506 .45454 L .59508 .45453 L .673 .757 .914 r
F
.59362 .45403 m .59506 .45454 L .59506 .45453 L F
.59341 .45478 m .60768 .46352 L .59508 .45453 L F
.58958 .44985 m .59026 .44993 L .59027 .45526 L .751 .49 .538 r
F
.59038 .45293 m .58931 .45514 L .59026 .45525 L .673 .757 .914 r
F
.58976 .45069 m .58943 .47025 L .59049 .45061 L .66 .415 .539 r
F
.59038 .45293 m .58521 .45117 L .58436 .45205 L .673 .757 .914 r
F
.58521 .45117 m .58173 .44999 L .58348 .45136 L F
.58521 .45117 m .58348 .45136 L .58436 .45205 L F
.58173 .44999 m .56888 .44561 L .58436 .45205 L F
.58663 .453 m .56617 .44938 L .56511 .45339 L F
.58658 .45238 m .56617 .44938 L .58663 .453 L F
.58661 .45278 m .5867 .47325 L .58665 .47242 L .777 .62 .057 r
F
.58662 .45294 m .5867 .47325 L .58661 .45278 L F
.58715 .45183 m .58665 .47242 L .58719 .47139 L 0 0 .377 r
F
.58666 .45353 m .58708 .47395 L .5867 .47325 L .988 .719 .381 r
F
.58665 .4482 m .58674 .45366 L .58666 .45353 L F
.58674 .45366 m .58708 .47395 L .58666 .45353 L F
.58704 .45415 m .58554 .4547 L .58733 .45462 L .673 .757 .914 r
F
.58704 .45415 m .58733 .45462 L .58763 .45461 L F
.58704 .45415 m .58733 .45462 L .58704 .45415 L F
.58703 .45203 m .58665 .47242 L .58715 .45183 L 0 0 .377 r
F
.58696 .45216 m .58665 .47242 L .58703 .45203 L F
.5874 .45475 m .58452 .4565 L .58775 .45532 L .673 .757 .914 r
F
.58452 .4565 m .57196 .46416 L .58401 .45741 L F
.58452 .4565 m .58401 .45741 L .58775 .45532 L F
.58664 .45328 m .58666 .45353 L .5867 .47325 L .777 .62 .057 r
F
.58679 .45246 m .58661 .45278 L .58665 .47242 L 0 0 .377 r
F
.58135 .46215 m .57196 .46416 L .57707 .46652 L .673 .757 .914 r
F
.5884 .45495 m .58401 .45741 L .58135 .46215 L F
.58401 .45741 m .57196 .46416 L .58135 .46215 L F
.58679 .45246 m .58665 .47242 L .58696 .45216 L 0 0 .377 r
F
.58554 .4547 m .5681 .46104 L .58717 .45489 L .673 .757 .914 r
F
.58687 .44164 m .58683 .44705 L .58713 .44118 L 0 0 .377 r
F
.59405 .4534 m .59421 .47256 L .59409 .47338 L 0 0 .146 r
F
.59409 .45314 m .59421 .47256 L .59405 .4534 L F
.59416 .44733 m .59376 .47151 L .59421 .47256 L .983 .725 .333 r
F
.41743 .36962 m .39345 .35896 L .393 .36625 L .732 .487 .557 r
F
0 g
.39345 .35896 m
.41787 .36232 L
s
.36888 .35976 m
.39345 .35896 L
s
.68604 .60636 m .68705 .59423 L .68155 .60546 L .683 .77 .917 r
F
.68604 .60636 m .69603 .59602 L .68705 .59423 L F
.69036 .61253 m .69654 .6006 L .68655 .61094 L F
.69036 .61253 m .70416 .6038 L .69654 .6006 L F
.64366 .60253 m .6277 .59774 L .62163 .60621 L F
.43958 .38422 m .41743 .36962 L .41698 .37691 L .794 .542 .556 r
F
0 g
.43958 .38422 m
.45879 .39496 L
s
.62796 .60224 m .62136 .60618 L .62186 .61076 L .204 .117 .53 r
F
.62796 .60224 m .62746 .59766 L .62136 .60618 L F
0 g
.61896 .6151 m
.62136 .60618 L
s
.25285 .60899 m .23766 .60634 L .23814 .61092 L .673 .453 .578 r
F
.25285 .60899 m .25237 .60441 L .23766 .60634 L F
0 g
.22387 .61047 m
.23766 .60634 L
s
.37242 .48891 m .35503 .47834 L .34673 .48487 L .673 .757 .914 r
F
.37775 .48637 m .35503 .47834 L .37242 .48891 L F
.21401 .71249 m .21538 .71477 L .21511 .71854 L .935 .758 .283 r
F
.21401 .71249 m .21428 .70871 L .21538 .71477 L F
0 g
.21538 .71477 m
.21756 .71829 L
s
.22703 .70946 m .21556 .71475 L .22775 .71348 L .645 .732 .913 r
F
.22703 .70946 m .21447 .70872 L .21556 .71475 L F
.64451 .61164 m .62236 .61534 L .64044 .61732 L .683 .77 .917 r
F
.38845 .57804 m .38795 .58936 L .39771 .58807 L F
.38845 .57804 m .39771 .58807 L .39334 .5774 L F
.38894 .58268 m .38843 .59405 L .39824 .59276 L F
.38894 .58268 m .39824 .59276 L .39384 .58203 L F
.38838 .52722 m .38996 .52749 L .38986 .5696 L .751 .491 .538 r
F
.39048 .57042 m .38845 .57804 L .39334 .5774 L .683 .77 .917 r
F
.39075 .57449 m .38894 .58268 L .39384 .58203 L F
.39004 .57076 m .38845 .57804 L .39048 .57042 L F
.39009 .56992 m .38845 .57804 L .39024 .56985 L F
.38882 .56978 m .38845 .57804 L .3901 .56962 L F
.38986 .5696 m .3901 .56962 L .39012 .56955 L F
.38882 .56978 m .3901 .56962 L .38986 .5696 L F
.38672 .52615 m .38739 .52675 L .38728 .5691 L .929 .648 .488 r
F
.38774 .56927 m .38744 .5699 L .38883 .56966 L .683 .77 .917 r
F
.38629 .52463 m .38634 .52545 L .38623 .56801 L .79 .631 .071 r
F
.38652 .57181 m .38361 .57791 L .38662 .57315 L .683 .77 .917 r
F
.37912 .57702 m .37826 .5891 L .38361 .57791 L F
.38639 .5745 m .37572 .58005 L .37956 .58165 L F
.38683 .56894 m .38683 .56895 L .38774 .56927 L F
.3888 .57022 m .38361 .57791 L .38845 .57804 L F
.38814 .57403 m .38406 .58255 L .38889 .57457 L F
.38361 .57791 m .38795 .58936 L .38845 .57804 L F
.38768 .56939 m .38241 .57409 L .38361 .57791 L F
.38241 .57409 m .37912 .57702 L .38062 .57732 L F
.38241 .57409 m .38062 .57732 L .38361 .57791 L F
.38629 .52463 m .38622 .56781 L .38618 .56729 L .79 .631 .071 r
F
.38634 .52545 m .38651 .56845 L .38623 .56801 L .989 .72 .388 r
F
.38629 .52463 m .38623 .56801 L .38622 .56781 L .79 .631 .071 r
F
.38634 .52545 m .38672 .52615 L .38662 .56861 L .989 .72 .388 r
F
.38682 .52359 m .38629 .52463 L .38618 .56729 L 0 0 .372 r
F
.38624 .57256 m .38545 .57288 L .3863 .5733 L .683 .77 .917 r
F
.38739 .52675 m .388 .56936 L .38728 .5691 L .845 .571 .524 r
F
.38672 .52615 m .38728 .5691 L .3871 .56897 L .929 .648 .488 r
F
.38739 .52675 m .38838 .52722 L .38828 .56946 L .845 .571 .524 r
F
.38739 .52675 m .38828 .56946 L .38819 .56943 L F
.38634 .56946 m .38642 .57046 L .38729 .56967 L .683 .77 .917 r
F
.38919 .57696 m .38406 .58255 L .38894 .58268 L F
.38361 .57791 m .37826 .5891 L .38795 .58936 L F
.38406 .58255 m .37869 .59379 L .38843 .59405 L F
.37956 .58165 m .37869 .59379 L .38406 .58255 L F
.38814 .57961 m .38004 .58624 L .38455 .58713 L F
.38806 .57367 m .38827 .57375 L .38826 .57804 L .845 .571 .524 r
F
.38406 .58255 m .38843 .59405 L .38894 .58268 L .683 .77 .917 r
F
.38981 .5786 m .38455 .58713 L .38942 .58726 L F
.38932 .57413 m .38836 .57566 L .38919 .57696 L F
.38827 .57375 m .38814 .57403 L .38933 .57384 L F
.38867 .57378 m .38906 .5781 L .38827 .57375 L .751 .491 .538 r
F
.38925 .57566 m .38894 .58268 L .39075 .57449 L .683 .77 .917 r
F
.38906 .5781 m .38982 .58647 L .38879 .57808 L .751 .491 .538 r
F
.38836 .57566 m .38406 .58255 L .38919 .57696 L .683 .77 .917 r
F
.38906 .5781 m .38879 .57808 L .38827 .57375 L .751 .491 .538 r
F
.38983 .57817 m .3888 .57823 L .38981 .5786 L .683 .77 .917 r
F
.38887 .57809 m .3888 .57823 L .38983 .57817 L F
.38883 .56966 m .38858 .57005 L .3888 .57022 L F
.38814 .57403 m .38889 .57457 L .38933 .57384 L F
.38933 .57384 m .38918 .57408 L .38932 .57413 L F
.38941 .56956 m .38982 .58647 L .38828 .56946 L .751 .491 .538 r
F
.38933 .57384 m .38925 .57566 L .39053 .57394 L .683 .77 .917 r
F
.38951 .57385 m .38985 .57388 L .38982 .58647 L .751 .491 .538 r
F
.38993 .57588 m .38887 .57809 L .38983 .57817 L .683 .77 .917 r
F
.3888 .57823 m .38455 .58713 L .38981 .5786 L F
.38726 .57768 m .38824 .5862 L .38724 .58573 L .845 .571 .524 r
F
.38683 .56895 m .38729 .56967 L .38774 .56927 L .683 .77 .917 r
F
.38744 .5699 m .38652 .57181 L .38806 .57088 L F
.38858 .57005 m .38361 .57791 L .3888 .57022 L F
.38728 .5691 m .38753 .57348 L .38727 .57339 L .845 .571 .524 r
F
.38944 .5713 m .38624 .57256 L .38628 .57303 L .683 .77 .917 r
F
.38657 .57313 m .38628 .57303 L .3863 .5733 L F
.38944 .5713 m .38628 .57303 L .38657 .57313 L F
.38918 .57408 m .38406 .58255 L .38932 .57413 L F
.38727 .57339 m .38777 .57786 L .38726 .57768 L .845 .571 .524 r
F
.38814 .57403 m .37956 .58165 L .38406 .58255 L .683 .77 .917 r
F
.38828 .56946 m .38867 .57378 L .38827 .57375 L .751 .491 .538 r
F
.38944 .5713 m .38738 .57346 L .38814 .57403 L .683 .77 .917 r
F
.38738 .57346 m .37956 .58165 L .38814 .57403 L F
.38683 .56895 m .38634 .56946 L .38729 .56967 L F
.38652 .57181 m .38662 .57315 L .38806 .57088 L F
.3871 .56897 m .38713 .57329 L .38662 .56861 L .929 .648 .488 r
F
.3867 .57305 m .3863 .5733 L .38713 .57372 L .683 .77 .917 r
F
.38672 .52615 m .3871 .56897 L .38662 .56861 L .929 .648 .488 r
F
.38763 .56936 m .37912 .57702 L .38768 .56939 L .683 .77 .917 r
F
.38739 .52675 m .38819 .56943 L .388 .56936 L .845 .571 .524 r
F
.38838 .52722 m .38941 .56956 L .38828 .56946 L .751 .491 .538 r
F
.38896 .56672 m .38241 .5693 L .37531 .57543 L .683 .77 .917 r
F
.38241 .5693 m .37242 .57324 L .37447 .57479 L F
.38241 .5693 m .37447 .57479 L .37531 .57543 L F
.38794 .5228 m .38682 .52359 L .38671 .56633 L .398 .209 .505 r
F
.38713 .57329 m .38678 .57303 L .38662 .56861 L .929 .648 .488 r
F
.38309 .57286 m .37531 .57543 L .37912 .57702 L .683 .77 .917 r
F
.37531 .57543 m .36166 .58413 L .36929 .58732 L F
.38074 .57473 m .37106 .57521 L .37282 .57785 L F
.38633 .56702 m .38628 .57138 L .38671 .56633 L 0 0 .372 r
F
.38622 .5723 m .38635 .5768 L .38621 .57659 L .989 .72 .388 r
F
.3863 .5733 m .37572 .58005 L .38639 .5745 L .683 .77 .917 r
F
.38632 .57246 m .38641 .5769 L .38622 .5723 L .989 .72 .388 r
F
.38743 .5785 m .38004 .58624 L .38814 .57961 L .683 .77 .917 r
F
.38641 .5769 m .38658 .58513 L .38635 .5768 L .989 .72 .388 r
F
.38641 .5769 m .38635 .5768 L .38622 .5723 L F
.37531 .57543 m .36929 .58732 L .37912 .57702 L .683 .77 .917 r
F
.3863 .5733 m .37282 .57785 L .37572 .58005 L F
.38626 .57666 m .37102 .57688 L .37154 .57979 L F
.38621 .57215 m .38622 .5723 L .38621 .57659 L .79 .631 .071 r
F
.37956 .58165 m .36968 .592 L .37869 .59379 L .683 .77 .917 r
F
.38092 .58532 m .37621 .58463 L .38004 .58624 L F
.38993 .57588 m .38408 .57961 L .38092 .58532 L F
.38408 .57961 m .37621 .58463 L .38092 .58532 L F
.38621 .57659 m .38658 .58513 L .38619 .58443 L .989 .72 .388 r
F
.38713 .57372 m .3863 .5733 L .38639 .5745 L .683 .77 .917 r
F
.38241 .5693 m .37066 .57061 L .37242 .57324 L F
.38571 .5715 m .37131 .56932 L .37054 .5723 L F
.38653 .57278 m .38639 .57256 L .38623 .56801 L .989 .72 .388 r
F
.3869 .5662 m .38679 .57055 L .38702 .56611 L .398 .209 .505 r
F
.3871 .56897 m .38727 .57339 L .38713 .57329 L .929 .648 .488 r
F
.38944 .5713 m .3859 .57205 L .38545 .57288 L .683 .77 .917 r
F
.38679 .57055 m .38669 .5749 L .38685 .57051 L .398 .209 .505 r
F
.38679 .57055 m .38685 .57051 L .38702 .56611 L F
.38651 .56845 m .38661 .5729 L .38653 .57278 L .989 .72 .388 r
F
.38944 .5713 m .38622 .57095 L .38571 .5715 L .683 .77 .917 r
F
.38634 .56946 m .37912 .57702 L .38642 .57046 L F
.38622 .57095 m .3853 .57085 L .38562 .57136 L F
.38622 .57095 m .38562 .57136 L .38571 .5715 L F
.38597 .56863 m .37531 .57543 L .38683 .56894 L F
.3853 .57085 m .37131 .56932 L .38571 .5715 L F
.38651 .56845 m .38653 .57278 L .38623 .56801 L .989 .72 .388 r
F
.38653 .57278 m .38654 .57711 L .38639 .57256 L F
.38654 .57711 m .38658 .58513 L .38641 .5769 L F
.38654 .57711 m .38641 .5769 L .38623 .56801 L F
.37912 .57702 m .36929 .58732 L .37826 .5891 L .683 .77 .917 r
F
.3866 .57719 m .37154 .57979 L .37331 .58244 L F
.38806 .57367 m .38826 .57804 L .38812 .57799 L .845 .571 .524 r
F
.38653 .57278 m .38661 .5729 L .38658 .58513 L .989 .72 .388 r
F
.38993 .57588 m .38626 .57666 L .3866 .57719 L .683 .77 .917 r
F
.38626 .57666 m .37154 .57979 L .3866 .57719 L F
.38669 .5749 m .38614 .58361 L .38667 .58257 L 0 0 .372 r
F
.38651 .56845 m .38662 .56861 L .38661 .5729 L .989 .72 .388 r
F
.38671 .56633 m .38641 .5754 L .38669 .5749 L 0 0 .372 r
F
.38719 .57763 m .37827 .58072 L .37621 .58463 L .683 .77 .917 r
F
.38635 .5768 m .38658 .58513 L .38621 .57659 L .989 .72 .388 r
F
.38641 .5754 m .38614 .58361 L .38669 .5749 L 0 0 .372 r
F
.38621 .57649 m .38621 .57659 L .38619 .58443 L .79 .631 .071 r
F
.38621 .57215 m .38621 .57659 L .38621 .57649 L F
.38993 .57588 m .38617 .57608 L .38626 .57666 L .683 .77 .917 r
F
.38617 .57608 m .3859 .57609 L .38621 .57659 L F
.38617 .57608 m .38621 .57659 L .38626 .57666 L F
.3859 .57609 m .37102 .57688 L .38626 .57666 L F
.38455 .57023 m .37531 .57543 L .38309 .57286 L F
.38405 .57245 m .37106 .57521 L .38074 .57473 L F
.38545 .57288 m .37282 .57785 L .38496 .57376 L F
.3862 .57199 m .37054 .5723 L .37106 .57521 L F
.3871 .56897 m .38728 .5691 L .38727 .57339 L .929 .648 .488 r
F
.38944 .5713 m .38616 .57147 L .3862 .57199 L .683 .77 .917 r
F
.38616 .57147 m .37054 .5723 L .3862 .57199 L F
.38622 .56781 m .38621 .57215 L .38618 .56729 L .79 .631 .071 r
F
.38621 .57215 m .38619 .58443 L .38618 .57176 L F
.38621 .57215 m .38618 .57176 L .38618 .56729 L F
.38636 .57549 m .37381 .57105 L .3718 .5739 L .683 .77 .917 r
F
.3888 .57823 m .38743 .5785 L .38814 .57961 L F
.38797 .57793 m .38743 .5785 L .3888 .57823 L F
.38774 .56927 m .38763 .56936 L .38768 .56939 L F
.388 .56936 m .38806 .57367 L .38728 .5691 L .845 .571 .524 r
F
.38806 .57367 m .38824 .5862 L .38753 .57348 L F
.38806 .57367 m .38753 .57348 L .38728 .5691 L F
.388 .56936 m .38827 .57375 L .38806 .57367 L F
.38944 .5713 m .3867 .57305 L .38681 .57322 L .683 .77 .917 r
F
.3874 .57344 m .38681 .57322 L .38713 .57372 L F
.38944 .5713 m .38681 .57322 L .3874 .57344 L F
.38993 .57588 m .38668 .57491 L .38636 .57549 L F
.38545 .57288 m .38405 .57245 L .38074 .57473 L F
.38668 .57491 m .37381 .57105 L .38636 .57549 L F
.38628 .57138 m .38623 .57573 L .38656 .57086 L 0 0 .372 r
F
.38623 .57573 m .38614 .58361 L .38641 .5754 L F
.38623 .57573 m .38641 .5754 L .38656 .57086 L F
.38628 .57138 m .38656 .57086 L .38671 .56633 L F
.3859 .57205 m .38405 .57245 L .38545 .57288 L .683 .77 .917 r
F
.38713 .57329 m .38717 .57761 L .38678 .57303 L .929 .648 .488 r
F
.38693 .57046 m .38669 .5749 L .38683 .5748 L .398 .209 .505 r
F
.38702 .56611 m .38685 .57051 L .38693 .57046 L F
.38685 .57051 m .38669 .5749 L .38693 .57046 L F
.38794 .5228 m .3869 .5662 L .38702 .56611 L F
.38896 .56672 m .3849 .56758 L .38241 .5693 L .683 .77 .917 r
F
.3849 .56758 m .37066 .57061 L .38241 .5693 L F
.38683 .56894 m .38455 .57023 L .38309 .57286 L F
.38622 .56781 m .38623 .56801 L .38622 .5723 L .79 .631 .071 r
F
.38717 .57761 m .38724 .58573 L .38694 .57744 L .929 .648 .488 r
F
.38777 .57786 m .38824 .5862 L .38726 .57768 L .845 .571 .524 r
F
.38781 .57412 m .38667 .58257 L .38779 .58179 L .398 .209 .505 r
F
.38896 .56672 m .38597 .56863 L .38683 .56894 L .683 .77 .917 r
F
.3849 .56758 m .37015 .56771 L .37066 .57061 L F
.38634 .52545 m .38662 .56861 L .38651 .56845 L .989 .72 .388 r
F
.38896 .56672 m .38591 .56688 L .3849 .56758 L .683 .77 .917 r
F
.38591 .56688 m .37015 .56771 L .3849 .56758 L F
.38783 .56555 m .38683 .5748 L .38781 .57412 L .398 .209 .505 r
F
.38794 .5228 m .38702 .56611 L .38783 .56555 L F
.38896 .56672 m .38683 .56894 L .38774 .56927 L .683 .77 .917 r
F
.38693 .57046 m .38733 .57017 L .38783 .56555 L .398 .209 .505 r
F
.3869 .5662 m .38671 .56633 L .3867 .57061 L F
.38682 .52359 m .38633 .56702 L .38671 .56633 L 0 0 .372 r
F
.38682 .52359 m .38618 .56729 L .38633 .56702 L F
.38724 .56575 m .37999 .5574 L .37601 .55941 L .683 .77 .917 r
F
.38896 .56672 m .38783 .56555 L .38724 .56575 L F
.38783 .56555 m .37999 .5574 L .38724 .56575 L F
.38905 .52246 m .38794 .5228 L .38783 .56555 L .567 .342 .533 r
F
.38496 .57081 m .37332 .56647 L .37131 .56932 L .683 .77 .917 r
F
.38623 .56801 m .38632 .57246 L .38622 .5723 L .989 .72 .388 r
F
.38622 .56781 m .38622 .5723 L .38621 .57215 L .79 .631 .071 r
F
.38944 .5713 m .38629 .57035 L .38496 .57081 L .683 .77 .917 r
F
.38629 .57035 m .37332 .56647 L .38496 .57081 L F
.38814 .56545 m .38783 .56555 L .38782 .56984 L .567 .342 .533 r
F
.38545 .57288 m .38496 .57376 L .3863 .5733 L .683 .77 .917 r
F
.38744 .5699 m .38806 .57088 L .38883 .56966 L F
.38819 .56943 m .38827 .57375 L .388 .56936 L .845 .571 .524 r
F
.38633 .56702 m .38617 .57157 L .38628 .57138 L 0 0 .372 r
F
.38618 .56729 m .38618 .57176 L .38617 .57157 L .79 .631 .071 r
F
.38819 .56943 m .38828 .56946 L .38827 .57375 L .845 .571 .524 r
F
.38355 .567 m .37092 .56474 L .37015 .56771 L .683 .77 .917 r
F
.38896 .56672 m .38551 .56634 L .38355 .567 L F
.38551 .56634 m .37092 .56474 L .38355 .567 L F
.38896 .56672 m .38774 .56927 L .38883 .56966 L F
.38894 .56517 m .38805 .56976 L .38893 .56946 L .567 .342 .533 r
F
.38905 .52246 m .38814 .56545 L .38894 .56517 L F
.38814 .56545 m .38805 .56976 L .38894 .56517 L F
.38629 .57035 m .37643 .56395 L .37332 .56647 L .683 .77 .917 r
F
.38944 .5713 m .38722 .57004 L .38629 .57035 L F
.38722 .57004 m .37643 .56395 L .38629 .57035 L F
.38812 .57799 m .38826 .57804 L .38824 .5862 L .845 .571 .524 r
F
.38993 .57588 m .38797 .57793 L .3888 .57823 L .683 .77 .917 r
F
.38827 .57375 m .38982 .58647 L .38824 .5862 L .751 .491 .538 r
F
.38893 .56946 m .38779 .58179 L .3889 .58145 L .567 .342 .533 r
F
.38993 .57588 m .38813 .57401 L .38719 .57433 L .683 .77 .917 r
F
.38944 .5713 m .38862 .56929 L .38795 .56975 L F
.38944 .5713 m .38795 .56975 L .38739 .57014 L F
.38713 .57329 m .38727 .57339 L .38724 .58573 L .929 .648 .488 r
F
.38993 .57588 m .3866 .57719 L .38719 .57763 L .683 .77 .917 r
F
.38693 .57046 m .38683 .5748 L .38733 .57017 L .398 .209 .505 r
F
.38896 .56672 m .37292 .56191 L .37092 .56474 L .683 .77 .917 r
F
.38896 .56672 m .37601 .55941 L .37292 .56191 L F
.38739 .57014 m .38043 .56193 L .37643 .56395 L F
.3869 .5662 m .3867 .57061 L .38679 .57055 L .398 .209 .505 r
F
.38633 .56702 m .38618 .56729 L .38617 .57157 L 0 0 .372 r
F
.38795 .56975 m .38043 .56193 L .38739 .57014 L .683 .77 .917 r
F
.3866 .57719 m .38724 .58573 L .38658 .58513 L .929 .648 .488 r
F
.38662 .56861 m .38694 .57744 L .3866 .57719 L F
.38694 .57744 m .38724 .58573 L .3866 .57719 L F
.38516 .57613 m .3718 .5739 L .37102 .57688 L .683 .77 .917 r
F
.38717 .57761 m .38694 .57744 L .38678 .57303 L .929 .648 .488 r
F
.38628 .57138 m .38617 .57157 L .38616 .57586 L 0 0 .372 r
F
.38617 .57157 m .38619 .58443 L .38614 .58361 L .79 .631 .071 r
F
.38618 .57176 m .38619 .57624 L .38617 .57157 L F
.38619 .57624 m .38619 .58443 L .38618 .57611 L F
.38619 .57624 m .38618 .57611 L .38617 .57157 L F
.38993 .57588 m .38636 .57549 L .38616 .57586 L .683 .77 .917 r
F
.38617 .57608 m .38616 .57586 L .38603 .57609 L F
.38993 .57588 m .38616 .57586 L .38617 .57608 L F
.38623 .57573 m .38616 .57586 L .38614 .58361 L 0 0 .372 r
F
.38628 .57138 m .38616 .57586 L .38623 .57573 L F
.38603 .57609 m .38392 .57522 L .38516 .57613 L .683 .77 .917 r
F
.38636 .57549 m .38392 .57522 L .38603 .57609 L F
.38392 .57522 m .3718 .5739 L .38516 .57613 L F
.38679 .57055 m .3867 .57061 L .38669 .5749 L .398 .209 .505 r
F
.38813 .57401 m .38552 .56514 L .38091 .56652 L .683 .77 .917 r
F
.38838 .52722 m .38986 .5696 L .38941 .56956 L .751 .491 .538 r
F
.38944 .5713 m .38953 .56938 L .3887 .56949 L .683 .77 .917 r
F
.38941 .56956 m .38986 .5696 L .38985 .57388 L .751 .491 .538 r
F
.3901 .56962 m .38845 .57804 L .39015 .56962 L .683 .77 .917 r
F
.38941 .56956 m .38985 .57388 L .38951 .57385 L .751 .491 .538 r
F
.38944 .5713 m .38933 .57384 L .39053 .57394 L .683 .77 .917 r
F
.38896 .56672 m .38882 .56978 L .39012 .56955 L F
.39155 .52728 m .39258 .52684 L .39248 .56885 L .515 .301 .526 r
F
.39012 .56955 m .39334 .5774 L .39145 .56931 L .683 .77 .917 r
F
.3928 .57716 m .39384 .58203 L .39312 .57512 L F
.39384 .58203 m .39824 .59276 L .40745 .59001 L F
.39314 .57921 m .39433 .58661 L .39894 .58524 L F
.39186 .57789 m .39263 .58247 L .39314 .57921 L F
.39085 .57814 m .38942 .58726 L .39433 .58661 L F
.38981 .57861 m .38942 .58726 L .39085 .57814 L F
.38984 .57817 m .39141 .58626 L .38982 .58647 L .641 .4 .539 r
F
.39053 .57394 m .38925 .57566 L .39075 .57449 L .683 .77 .917 r
F
.38986 .5696 m .39064 .57802 L .38984 .57817 L .641 .4 .539 r
F
.3908 .57799 m .38981 .57861 L .39085 .57814 L .683 .77 .917 r
F
.38983 .57817 m .38981 .57861 L .3908 .57799 L F
.39064 .57802 m .39141 .58626 L .38984 .57817 L .641 .4 .539 r
F
.38993 .57588 m .38983 .57817 L .3908 .57799 L .683 .77 .917 r
F
.39143 .57788 m .39244 .58582 L .39141 .58626 L .515 .301 .526 r
F
.39159 .57353 m .39165 .57377 L .39175 .5737 L .683 .77 .917 r
F
.39055 .57399 m .39384 .58203 L .3916 .57357 L F
.39144 .57359 m .3916 .57357 L .39159 .57353 L F
.39055 .57399 m .3916 .57357 L .39144 .57359 L F
.391 .56939 m .39145 .56931 L .39144 .57359 L .641 .4 .539 r
F
.39179 .57782 m .39102 .57855 L .39186 .57789 L .683 .77 .917 r
F
.3908 .57799 m .39102 .57855 L .39179 .57782 L F
.39024 .56985 m .39004 .57076 L .39048 .57042 L F
.39015 .56962 m .39009 .56992 L .39024 .56985 L F
.39012 .56955 m .3901 .56962 L .39015 .56962 L F
.391 .56939 m .3911 .57366 L .38986 .5696 L .641 .4 .539 r
F
.39046 .57377 m .39055 .57399 L .39144 .57359 L .683 .77 .917 r
F
.3911 .57366 m .39141 .58626 L .39025 .57381 L .641 .4 .539 r
F
.3911 .57366 m .39025 .57381 L .38986 .5696 L F
.38944 .5713 m .39046 .57377 L .39159 .57353 L .683 .77 .917 r
F
.391 .56939 m .39144 .57359 L .3911 .57366 L .641 .4 .539 r
F
.39046 .57377 m .39144 .57359 L .39159 .57353 L .683 .77 .917 r
F
.38993 .57588 m .3908 .57799 L .39179 .57782 L F
.3911 .57366 m .39144 .57359 L .39143 .57788 L .641 .4 .539 r
F
.39121 .57792 m .39143 .57788 L .39141 .58626 L F
.3911 .57366 m .39143 .57788 L .39121 .57792 L F
.39145 .56931 m .39195 .57765 L .39143 .57788 L .515 .301 .526 r
F
.39102 .57855 m .39263 .58247 L .39186 .57789 L .683 .77 .917 r
F
.39195 .57765 m .39244 .58582 L .39143 .57788 L .515 .301 .526 r
F
.39246 .57742 m .39315 .58525 L .39244 .58582 L .354 .175 .495 r
F
.39215 .57411 m .3928 .57716 L .39312 .57512 L .683 .77 .917 r
F
.39193 .57442 m .39384 .58203 L .39215 .57411 L F
.39247 .57313 m .3927 .57723 L .39246 .57742 L .354 .175 .495 r
F
.3927 .57723 m .39315 .58525 L .39246 .57742 L F
.39263 .58247 m .39433 .58661 L .39314 .57921 L .683 .77 .917 r
F
.3936 .57622 m .3937 .58375 L .39358 .58456 L 0 0 .133 r
F
.39372 .52558 m .39384 .52477 L .39374 .56691 L F
.3931 .57102 m .39334 .5774 L .39792 .57603 L .683 .77 .917 r
F
.39312 .57512 m .39845 .58066 L .39337 .57351 L F
.39172 .57046 m .39334 .5774 L .39207 .56995 L F
.39792 .57603 m .41482 .58133 L .40189 .57402 L F
.39327 .57245 m .40245 .57864 L .40556 .57613 L F
.39145 .56931 m .39172 .57046 L .39207 .56995 L F
.39219 .56898 m .39225 .57323 L .39145 .56931 L .515 .301 .526 r
F
.39175 .5737 m .39193 .57442 L .39215 .57411 L .683 .77 .917 r
F
.39334 .5774 m .39771 .58807 L .40688 .58533 L F
.39312 .57512 m .39384 .58203 L .39845 .58066 L F
.39329 .52627 m .39372 .52558 L .39362 .56765 L .069 0 .411 r
F
.39329 .52627 m .39362 .56765 L .3935 .56783 L F
.39329 .52627 m .3935 .56783 L .39319 .56829 L F
.39279 .56888 m .39792 .57603 L .39822 .57588 L .683 .77 .917 r
F
.39548 .5704 m .39822 .57588 L .40189 .57402 L F
.39279 .56888 m .39822 .57588 L .39548 .5704 L F
.39384 .52477 m .39338 .52371 L .39328 .566 L .985 .728 .342 r
F
.39337 .57351 m .39845 .58065 L .39548 .57471 L .683 .77 .917 r
F
.39164 .56951 m .39792 .57603 L .39259 .56877 L F
.39391 .56726 m .40499 .57152 L .40699 .56869 L F
.39155 .52728 m .39248 .56885 L .39219 .56898 L .515 .301 .526 r
F
.38896 .56672 m .39446 .56837 L .39391 .56726 L .683 .77 .917 r
F
.39446 .56837 m .40499 .57152 L .39391 .56726 L F
.39352 .57207 m .39337 .5723 L .39319 .56829 L .069 0 .411 r
F
.39354 .57631 m .39339 .57654 L .39319 .56829 L F
.40189 .57402 m .42101 .57632 L .40499 .57152 L .683 .77 .917 r
F
.39403 .5718 m .40556 .57613 L .40757 .57328 L F
.39207 .56995 m .39269 .57363 L .3931 .57102 L F
.39219 .56898 m .39247 .57313 L .39225 .57323 L .515 .301 .526 r
F
.39248 .56885 m .39265 .57299 L .39247 .57313 L .354 .175 .495 r
F
.39259 .56877 m .39273 .56897 L .39279 .56888 L .683 .77 .917 r
F
.39299 .56845 m .39303 .5727 L .39248 .56885 L .354 .175 .495 r
F
.39269 .57363 m .39334 .5774 L .3931 .57102 L .683 .77 .917 r
F
.39303 .5727 m .39318 .57258 L .39315 .58525 L .354 .175 .495 r
F
.39254 .57736 m .39275 .57748 L .39317 .57686 L .683 .77 .917 r
F
.39265 .57299 m .39315 .58525 L .39247 .57313 L .354 .175 .495 r
F
.38993 .57588 m .39254 .57736 L .39318 .57685 L .683 .77 .917 r
F
.39307 .57694 m .39282 .57714 L .39265 .57299 L .354 .175 .495 r
F
.39254 .57736 m .39317 .57686 L .39318 .57685 L .683 .77 .917 r
F
.39259 .57308 m .39277 .57318 L .39295 .57292 L F
.39259 .57308 m .39295 .57292 L .39327 .57245 L F
.39225 .57323 m .3917 .57348 L .39145 .56931 L .515 .301 .526 r
F
.38944 .5713 m .39312 .57512 L .39337 .57351 L .683 .77 .917 r
F
.39303 .5727 m .39307 .57694 L .39265 .57299 L .354 .175 .495 r
F
.39307 .57694 m .39315 .58525 L .39282 .57714 L F
.39303 .5727 m .39265 .57299 L .39248 .56885 L F
.38944 .5713 m .39333 .57246 L .39403 .5718 L .683 .77 .917 r
F
.39333 .57246 m .39454 .57283 L .39407 .57188 L F
.39333 .57246 m .39407 .57188 L .39403 .5718 L F
.39454 .57283 m .40556 .57613 L .39403 .5718 L F
.39277 .57318 m .40245 .57864 L .39327 .57245 L F
.39337 .57048 m .39326 .57458 L .39333 .5747 L .985 .728 .342 r
F
.3935 .56783 m .39352 .57207 L .39319 .56829 L .069 0 .411 r
F
.39446 .56837 m .40189 .57402 L .40499 .57152 L .683 .77 .917 r
F
.38896 .56672 m .39548 .5704 L .39446 .56837 L F
.39548 .5704 m .40189 .57402 L .39446 .56837 L F
.3935 .56783 m .39362 .56765 L .39361 .57194 L .069 0 .411 r
F
.3935 .56783 m .39361 .57194 L .39352 .57207 L F
.3937 .56712 m .39374 .56691 L .39373 .5712 L 0 0 .133 r
F
.3937 .56712 m .39373 .5712 L .3937 .57136 L F
.39374 .56691 m .39337 .57048 L .39373 .5712 L .985 .728 .342 r
F
.39372 .52558 m .39374 .56691 L .3937 .56712 L 0 0 .133 r
F
.39362 .56765 m .3937 .57136 L .39361 .57194 L F
.39372 .52558 m .3937 .56712 L .39362 .56765 L F
.3937 .56712 m .3937 .57136 L .39362 .56765 L F
.39381 .56646 m .40699 .56869 L .40776 .56572 L .683 .77 .917 r
F
.39155 .52728 m .39219 .56898 L .39145 .56931 L .515 .301 .526 r
F
.38896 .56672 m .39369 .56723 L .39381 .56646 L .683 .77 .917 r
F
.39369 .56723 m .40699 .56869 L .39381 .56646 L F
.39384 .52477 m .39341 .56626 L .39374 .56691 L .985 .728 .342 r
F
.39341 .56626 m .39337 .57048 L .39374 .56691 L F
.39341 .56626 m .39334 .57042 L .39337 .57048 L F
.39334 .57042 m .39326 .57458 L .39337 .57048 L F
.39384 .52477 m .39336 .56616 L .39341 .56626 L F
.39336 .56616 m .39328 .566 L .39326 .57458 L F
.39299 .56845 m .39318 .57258 L .39303 .5727 L .354 .175 .495 r
F
.39258 .52684 m .39312 .56834 L .39299 .56845 L F
.39312 .56834 m .39318 .57258 L .39299 .56845 L F
.39751 .5649 m .40776 .56572 L .40725 .56283 L .683 .77 .917 r
F
.39319 .56829 m .39329 .57241 L .39318 .57258 L .069 0 .411 r
F
.39312 .56834 m .39319 .56829 L .39318 .57258 L .354 .175 .495 r
F
.39792 .57603 m .40688 .58533 L .41482 .58133 L .683 .77 .917 r
F
.40245 .57864 m .42166 .58095 L .40556 .57613 L F
.39648 .5766 m .40604 .58071 L .40805 .57786 L F
.39231 .57749 m .39195 .57765 L .3917 .57348 L .515 .301 .526 r
F
.39329 .57241 m .39339 .57654 L .39318 .57258 L .069 0 .411 r
F
.39173 .57775 m .39821 .58448 L .39257 .57737 L .683 .77 .917 r
F
.39384 .58203 m .40745 .59001 L .39845 .58066 L F
.39821 .58448 m .39894 .58524 L .39803 .58411 L F
.39821 .58448 m .39803 .58411 L .39257 .57737 L F
.39354 .57631 m .39358 .58456 L .39339 .57654 L .069 0 .411 r
F
.39257 .57737 m .39803 .58411 L .39548 .57902 L .683 .77 .917 r
F
.3937 .57559 m .39372 .57549 L .3937 .58375 L 0 0 .133 r
F
.39364 .57597 m .3937 .58375 L .3936 .57622 L F
.39372 .57549 m .39324 .58269 L .3937 .58375 L .985 .728 .342 r
F
.3937 .57136 m .39373 .5712 L .39372 .57549 L 0 0 .133 r
F
.3937 .57136 m .39372 .57549 L .3937 .57559 L F
.39361 .57194 m .39364 .57597 L .3936 .57622 L F
.3937 .57136 m .3937 .58375 L .39361 .57194 L F
.39373 .5712 m .39356 .57517 L .39372 .57549 L .985 .728 .342 r
F
.39339 .57654 m .39358 .58456 L .39332 .57665 L .069 0 .411 r
F
.39275 .57748 m .40293 .58322 L .39318 .57685 L .683 .77 .917 r
F
.39352 .57207 m .39361 .57194 L .3936 .57622 L .069 0 .411 r
F
.39354 .57631 m .3936 .57622 L .39358 .58456 L F
.39352 .57207 m .3936 .57622 L .39354 .57631 L F
.39398 .57567 m .40805 .57786 L .40883 .57488 L .683 .77 .917 r
F
.38993 .57588 m .39356 .57628 L .39398 .57567 L F
.39334 .5774 m .40688 .58533 L .39792 .57603 L F
.39548 .57471 m .39845 .58066 L .40245 .57864 L F
.39356 .57628 m .40805 .57786 L .39398 .57567 L F
.39356 .57517 m .39324 .58269 L .39372 .57549 L .985 .728 .342 r
F
.39339 .57654 m .39332 .57665 L .39318 .57258 L .069 0 .411 r
F
.39356 .57628 m .40027 .57898 L .39648 .5766 L .683 .77 .917 r
F
.39225 .57323 m .39231 .57749 L .3917 .57348 L .515 .301 .526 r
F
.39165 .57377 m .39384 .58203 L .39175 .5737 L .683 .77 .917 r
F
.38993 .57588 m .39318 .57685 L .39356 .57628 L F
.39318 .57685 m .40027 .57898 L .39356 .57628 L F
.40027 .57898 m .40604 .58071 L .39648 .5766 L F
.39326 .57458 m .39218 .58187 L .39324 .58269 L .909 .63 .5 r
F
.39446 .57103 m .40757 .57328 L .40834 .5703 L .683 .77 .917 r
F
.39273 .56897 m .39792 .57603 L .39279 .56888 L F
.38944 .5713 m .39602 .57202 L .39446 .57103 L F
.39602 .57202 m .40757 .57328 L .39446 .57103 L F
.39327 .57029 m .39271 .57423 L .39326 .57458 L .909 .63 .5 r
F
.39328 .566 m .393 .57012 L .39327 .57029 L F
.393 .57012 m .39271 .57423 L .39327 .57029 L F
.39271 .57423 m .39218 .58187 L .39326 .57458 L F
.39258 .52684 m .39329 .52627 L .39319 .56829 L .354 .175 .495 r
F
.39258 .52684 m .39319 .56829 L .39312 .56834 L F
.39338 .52371 m .39252 .56552 L .39328 .566 L .909 .63 .5 r
F
.38944 .5713 m .39421 .57105 L .39429 .57093 L .683 .77 .917 r
F
.3935 .57044 m .39429 .57093 L .39482 .57016 L F
.39219 .56898 m .39248 .56885 L .39247 .57313 L .515 .301 .526 r
F
.38944 .5713 m .39429 .57093 L .3935 .57044 L .683 .77 .917 r
F
.39258 .52684 m .39299 .56845 L .39248 .56885 L .354 .175 .495 r
F
.39252 .56552 m .39243 .56976 L .39328 .566 L .909 .63 .5 r
F
.39231 .57749 m .39244 .58582 L .39195 .57765 L .515 .301 .526 r
F
.38993 .57588 m .39369 .57568 L .39378 .57506 L .683 .77 .917 r
F
.39225 .57323 m .39247 .57313 L .39244 .58582 L .515 .301 .526 r
F
.38896 .56672 m .39399 .56645 L .39304 .56585 L .683 .77 .917 r
F
.39338 .52371 m .39232 .52288 L .39222 .56533 L .909 .63 .5 r
F
.39278 .56998 m .40783 .56739 L .40607 .56474 L .683 .77 .917 r
F
.38944 .5713 m .3935 .57044 L .39278 .56998 L F
.3935 .57044 m .40783 .56739 L .39278 .56998 L F
.39252 .56552 m .39222 .56533 L .39221 .56962 L .909 .63 .5 r
F
.39243 .56976 m .39221 .56962 L .39218 .58187 L F
.39252 .56552 m .39221 .56962 L .39243 .56976 L F
.39338 .52371 m .39222 .56533 L .39252 .56552 L F
.38996 .52749 m .39145 .56931 L .391 .56939 L .641 .4 .539 r
F
.39004 .56502 m .3889 .58145 L .39 .58136 L .66 .416 .54 r
F
.39015 .52237 m .38925 .56513 L .39004 .56502 L F
.38925 .56513 m .38907 .57373 L .39004 .56502 L F
.38896 .56672 m .39022 .56408 L .38911 .56338 L .683 .77 .917 r
F
.38836 .56525 m .38946 .55538 L .38457 .55603 L F
.38896 .56672 m .38903 .56516 L .38836 .56525 L F
.38903 .56516 m .38946 .55538 L .38836 .56525 L F
.38944 .5713 m .38827 .57375 L .38933 .57384 L F
.38925 .56513 m .38892 .57375 L .38907 .57373 L .66 .416 .54 r
F
.39015 .52237 m .38913 .56515 L .38925 .56513 L F
.38913 .56515 m .38892 .57375 L .38925 .56513 L F
.3887 .56949 m .38995 .55991 L .38504 .56055 L .683 .77 .917 r
F
.39384 .52477 m .39328 .566 L .39336 .56616 L .985 .728 .342 r
F
.38996 .52749 m .39155 .52728 L .39145 .56931 L .641 .4 .539 r
F
.38996 .52749 m .391 .56939 L .38986 .5696 L F
.39232 .52288 m .39124 .5225 L .39113 .56507 L .81 .54 .531 r
F
.38944 .5713 m .39306 .56987 L .39304 .56983 L .683 .77 .917 r
F
.39243 .56976 m .393 .57012 L .39328 .566 L .909 .63 .5 r
F
.39211 .5696 m .39304 .56983 L .39273 .5692 L .683 .77 .917 r
F
.38944 .5713 m .39304 .56983 L .39211 .5696 L F
.39144 .56514 m .39113 .56507 L .39112 .56935 L .81 .54 .531 r
F
.39243 .56976 m .39234 .574 L .393 .57012 L .909 .63 .5 r
F
.39304 .56585 m .39564 .56636 L .39751 .5649 L .683 .77 .917 r
F
.39564 .56636 m .40776 .56572 L .39751 .5649 L F
.39273 .5692 m .40607 .56474 L .40317 .56254 L F
.39331 .57037 m .39334 .57042 L .39341 .56626 L .985 .728 .342 r
F
.38944 .5713 m .39259 .57308 L .39327 .57245 L .683 .77 .917 r
F
.39101 .57361 m .39982 .56552 L .39531 .56462 L F
.39111 .57364 m .39 .58136 L .3911 .58149 L .734 .477 .539 r
F
.38896 .56672 m .39143 .56514 L .39113 .56507 L .683 .77 .917 r
F
.39124 .5225 m .39035 .56503 L .39113 .56507 L .734 .477 .539 r
F
.39056 .56504 m .39113 .56507 L .39065 .56495 L .683 .77 .917 r
F
.38896 .56672 m .39113 .56507 L .39056 .56504 L F
.38896 .56672 m .39164 .56951 L .39259 .56877 L F
.39113 .56507 m .39017 .5736 L .39111 .57364 L .734 .477 .539 r
F
.39035 .56503 m .39026 .56932 L .39113 .56507 L F
.39232 .52288 m .39113 .56507 L .39144 .56514 L .81 .54 .531 r
F
.38896 .56672 m .39012 .56955 L .39145 .56931 L .683 .77 .917 r
F
.39124 .5225 m .39015 .52237 L .39004 .56502 L .734 .477 .539 r
F
.39035 .56503 m .39004 .56502 L .39002 .57359 L F
.38944 .5713 m .39039 .56932 L .39003 .56931 L .683 .77 .917 r
F
.38955 .56937 m .38974 .56935 L .39004 .56502 L .66 .416 .54 r
F
.38953 .56938 m .39003 .56931 L .38953 .56929 L .683 .77 .917 r
F
.38944 .5713 m .39003 .56931 L .38953 .56938 L F
.38907 .57373 m .38944 .57367 L .38974 .56935 L .66 .416 .54 r
F
.38907 .57373 m .38974 .56935 L .38955 .56937 L F
.39296 .56514 m .4055 .56019 L .39152 .56508 L .683 .77 .917 r
F
.39144 .56514 m .39112 .56935 L .39135 .56941 L .81 .54 .531 r
F
.39143 .56514 m .40262 .558 L .39065 .56495 L .683 .77 .917 r
F
.39399 .56645 m .39564 .56636 L .39304 .56585 L F
.38944 .5713 m .39934 .56094 L .39483 .56004 L F
.39003 .57359 m .39044 .56449 L .38907 .57356 L F
.39002 .57359 m .38907 .57356 L .38905 .57373 L F
.39003 .57359 m .38907 .57356 L .39002 .57359 L F
.39017 .5736 m .39002 .57359 L .39 .58136 L .734 .477 .539 r
F
.39336 .56616 m .39331 .57037 L .39341 .56626 L .985 .728 .342 r
F
.38896 .56672 m .40725 .56283 L .4055 .56019 L .683 .77 .917 r
F
.3913 .56936 m .40317 .56254 L .39934 .56094 L F
.38944 .5713 m .39241 .5694 L .3913 .56936 L F
.39241 .5694 m .40317 .56254 L .3913 .56936 L F
.39026 .56932 m .39002 .57359 L .39017 .5736 L .734 .477 .539 r
F
.39035 .56503 m .39018 .56931 L .39026 .56932 L F
.39018 .56931 m .39002 .57359 L .39026 .56932 L F
.39124 .5225 m .39004 .56502 L .39035 .56503 L F
.39152 .56508 m .4055 .56019 L .40262 .558 L .683 .77 .917 r
F
.38896 .56672 m .39296 .56514 L .39152 .56508 L F
.38989 .56476 m .3988 .55641 L .39431 .55551 L F
.38896 .56672 m .39065 .56495 L .38989 .56476 L F
.39065 .56495 m .3988 .55641 L .38989 .56476 L F
.39022 .56408 m .39431 .55551 L .38911 .56338 L F
.38953 .56929 m .39483 .56004 L .38995 .55991 L F
.39026 .56932 m .39065 .56933 L .39113 .56507 L .734 .477 .539 r
F
.39144 .56514 m .39135 .56941 L .39222 .56533 L .81 .54 .531 r
F
.38993 .57588 m .39261 .57417 L .3922 .57391 L .683 .77 .917 r
F
.38993 .57588 m .39173 .57775 L .39257 .57737 L F
.39222 .56533 m .3911 .58149 L .39218 .58187 L .81 .54 .531 r
F
.39189 .57383 m .3922 .57391 L .39196 .57376 L .683 .77 .917 r
F
.38993 .57588 m .3922 .57391 L .39189 .57383 L F
.39135 .56941 m .39126 .57367 L .39192 .56955 L .81 .54 .531 r
F
.39126 .57367 m .3911 .58149 L .39163 .57377 L F
.39126 .57367 m .39163 .57377 L .39192 .56955 L F
.39135 .56941 m .39192 .56955 L .39222 .56533 L F
.39039 .56932 m .39045 .56919 L .38953 .56929 L .683 .77 .917 r
F
.39045 .56919 m .39483 .56004 L .3897 .569 L F
.39045 .56919 m .3897 .569 L .38953 .56929 L F
.39026 .56932 m .39017 .5736 L .39065 .56933 L .734 .477 .539 r
F
.38993 .57588 m .39189 .57383 L .39111 .57364 L .683 .77 .917 r
F
.38993 .57588 m .39111 .57364 L .391 .57363 L F
.39017 .5736 m .39 .58136 L .39111 .57364 L .734 .477 .539 r
F
.391 .57363 m .39111 .57364 L .39101 .57361 L .683 .77 .917 r
F
.39234 .574 m .39271 .57423 L .393 .57012 L .909 .63 .5 r
F
.39306 .56987 m .40607 .56474 L .39273 .5692 L .683 .77 .917 r
F
.39331 .57037 m .39326 .57458 L .39334 .57042 L .985 .728 .342 r
F
.39189 .57383 m .39982 .56552 L .39101 .57361 L .683 .77 .917 r
F
.39135 .56941 m .39112 .56935 L .39111 .57364 L .81 .54 .531 r
F
.39126 .57367 m .39111 .57364 L .3911 .58149 L F
.39135 .56941 m .39111 .57364 L .39126 .57367 L F
.39065 .56495 m .40262 .558 L .3988 .55641 L .683 .77 .917 r
F
.39232 .52288 m .39144 .56514 L .39222 .56533 L .81 .54 .531 r
F
.38953 .56938 m .38995 .55991 L .3887 .56949 L .683 .77 .917 r
F
.38902 .56945 m .38893 .56946 L .38892 .57375 L .66 .416 .54 r
F
.38805 .56976 m .38796 .57407 L .38893 .56946 L .567 .342 .533 r
F
.38814 .56545 m .38782 .56984 L .38805 .56976 L F
.38702 .56611 m .38693 .57046 L .38783 .56555 L .398 .209 .505 r
F
.38862 .56929 m .38504 .56055 L .38795 .56975 L .683 .77 .917 r
F
.38905 .57373 m .39044 .56449 L .38552 .56514 L F
.38993 .57588 m .39003 .57359 L .38905 .57373 L F
.38907 .57373 m .3889 .58145 L .38944 .57367 L .66 .416 .54 r
F
.38911 .56338 m .39431 .55551 L .38946 .55538 L .683 .77 .917 r
F
.39196 .57376 m .40366 .56712 L .39982 .56552 L F
.39352 .57207 m .39354 .57631 L .39337 .5723 L .069 0 .411 r
F
.39261 .57417 m .40366 .56712 L .39196 .57376 L .683 .77 .917 r
F
.39234 .574 m .39218 .58187 L .39271 .57423 L .909 .63 .5 r
F
.39482 .57016 m .40834 .5703 L .40783 .56739 L .683 .77 .917 r
F
.39421 .57105 m .40834 .5703 L .39482 .57016 L F
.39845 .58065 m .39845 .58066 L .39548 .57471 L F
.39845 .58066 m .41544 .58598 L .40245 .57864 L F
.39318 .57685 m .40293 .58322 L .40604 .58071 L F
.39318 .57258 m .39358 .58456 L .39315 .58525 L .069 0 .411 r
F
.39333 .5747 m .39326 .57458 L .39324 .58269 L .985 .728 .342 r
F
.39548 .57902 m .39894 .58524 L .40293 .58322 L .683 .77 .917 r
F
.39803 .58411 m .39894 .58524 L .39548 .57902 L F
.39378 .57506 m .40883 .57488 L .40832 .57197 L F
.39369 .57568 m .40883 .57488 L .39378 .57506 L F
.39326 .57457 m .40832 .57197 L .40656 .56932 L F
.38993 .57588 m .39353 .57512 L .39326 .57457 L F
.39353 .57512 m .40832 .57197 L .39326 .57457 L F
.39337 .57048 m .39333 .5747 L .39373 .5712 L .985 .728 .342 r
F
.39333 .5747 m .39324 .58269 L .39356 .57517 L F
.39333 .5747 m .39356 .57517 L .39373 .5712 L F
.39015 .52237 m .38905 .52246 L .38893 .56946 L .66 .416 .54 r
F
.39015 .52237 m .38893 .56946 L .38902 .56945 L F
.38993 .57588 m .38905 .57373 L .38813 .57401 L .683 .77 .917 r
F
.38907 .57373 m .38892 .57375 L .3889 .58145 L .66 .416 .54 r
F
.38905 .57373 m .38904 .57371 L .38892 .57375 L .683 .77 .917 r
F
.38905 .57373 m .38892 .57375 L .38813 .57401 L F
.38796 .57407 m .38852 .57388 L .38893 .56946 L .567 .342 .533 r
F
.38805 .56976 m .38782 .56984 L .38781 .57412 L F
.38805 .56976 m .38781 .57412 L .38796 .57407 L F
.38904 .57371 m .38552 .56514 L .38813 .57401 L .683 .77 .917 r
F
.38796 .57407 m .38779 .58179 L .38852 .57388 L .567 .342 .533 r
F
.38719 .57433 m .38091 .56652 L .37692 .56853 L .683 .77 .917 r
F
.38813 .57401 m .38091 .56652 L .38719 .57433 L F
.38796 .57407 m .38781 .57412 L .38779 .58179 L .567 .342 .533 r
F
.38905 .52246 m .38783 .56555 L .38814 .56545 L F
.38795 .56975 m .38504 .56055 L .38043 .56193 L .683 .77 .917 r
F
.38753 .57348 m .38777 .57786 L .38727 .57339 L .845 .571 .524 r
F
.38683 .5748 m .38667 .58257 L .38781 .57412 L .398 .209 .505 r
F
.3866 .57719 m .37907 .58016 L .38719 .57763 L .683 .77 .917 r
F
.37572 .58005 m .36968 .592 L .37956 .58165 L F
.37907 .58016 m .37331 .58244 L .37827 .58072 L F
.37907 .58016 m .37827 .58072 L .38719 .57763 L F
.38794 .5228 m .38671 .56633 L .3869 .5662 L .398 .209 .505 r
F
.38683 .5748 m .38669 .5749 L .38667 .58257 L F
.37827 .58072 m .37331 .58244 L .37449 .58333 L .683 .77 .917 r
F
.37827 .58072 m .37449 .58333 L .37621 .58463 L F
.23961 .71599 m .22976 .72113 L .24081 .71792 L .644 .733 .913 r
F
.23961 .71599 m .22736 .71727 L .22976 .72113 L F
.50671 .81814 m .50645 .81594 L .50988 .81546 L .668 .436 .56 r
F
.5033 .81804 m .50645 .81594 L .50671 .81814 L .731 .481 .551 r
F
.5033 .81804 m .50304 .81584 L .50645 .81594 L F
.70938 .6036 m .71745 .59047 L .70365 .59922 L .683 .77 .917 r
F
.70938 .6036 m .72604 .59706 L .71745 .59047 L F
.50657 .81309 m .50645 .8159 L .50986 .81542 L .692 .759 .903 r
F
.50431 .81302 m .50306 .81579 L .50645 .8159 L F
.127 .923 .03 r
.50553 .76767 m
.50559 .71627 L
s
.51014 .81766 m .50988 .81546 L .5131 .81444 L .599 .387 .564 r
F
.50671 .81814 m .50988 .81546 L .51014 .81766 L .668 .436 .56 r
F
0 g
.50645 .81594 m
.50988 .81546 L
s
.34665 .47925 m .3252 .47198 L .31722 .48321 L .673 .757 .914 r
F
.50884 .81277 m .50986 .81542 L .51307 .81441 L .692 .759 .903 r
F
.34879 .60213 m .35981 .60234 L .36029 .60692 L .86 .591 .53 r
F
.34879 .60213 m .34831 .59755 L .35981 .60234 L F
.36201 .5888 m .35981 .60234 L .36968 .592 L .683 .77 .917 r
F
.36201 .5888 m .34831 .59755 L .35981 .60234 L F
0 g
.35981 .60234 m
.36389 .60315 L
s
.28823 .72284 m .28849 .71906 L .29 .71316 L 0 0 .13 r
F
0 g
.28557 .72299 m
.28849 .71906 L
s
.27346 .72369 m .28823 .72284 L .27611 .72013 L .644 .733 .913 r
F
.26267 .7192 m .27346 .72369 L .27611 .72013 L F
.26061 .72068 m .27346 .72369 L .26267 .7192 L F
.27625 .71632 m .28831 .71902 L .28981 .71314 L .645 .732 .913 r
F
.32518 .47756 m .31686 .48315 L .31716 .48884 L .16 .065 .49 r
F
.32518 .47756 m .32488 .47187 L .31686 .48315 L F
0 g
.31379 .49515 m
.31686 .48315 L
s
.42843 .59331 m .42794 .58873 L .43727 .58119 L .402 .257 .568 r
F
0 g
.42113 .59216 m
.42794 .58873 L
s
.26747 .60937 m .25237 .60441 L .25285 .60899 L .733 .497 .57 r
F
0 g
.23766 .60634 m
.25237 .60441 L
s
.25237 .60441 m
.26699 .60479 L
s
.56337 .37075 m .52975 .36863 L .56 .3755 L .654 .726 .902 r
F
.39663 .47887 m .39082 .46314 L .39015 .47847 L .673 .757 .914 r
F
.39663 .47887 m .40379 .46395 L .39082 .46314 L F
0 g
.49851 .73215 m
.50834 .73194 L
s
.41482 .58133 m .42774 .58862 L .43703 .58112 L .683 .77 .917 r
F
.40688 .58533 m .42774 .58862 L .41482 .58133 L F
.25487 .71603 m .2553 .71535 L .2553 .71566 L .065 0 .408 r
F
.25391 .72116 m .25461 .72612 L .25768 .72553 L .644 .733 .913 r
F
.25154 .71724 m .25314 .71704 L .25312 .72068 L .641 .401 .539 r
F
.25249 .72073 m .2531 .72229 L .25348 .72065 L .644 .733 .913 r
F
.2516 .71849 m .25134 .72619 L .25461 .72612 L F
.25162 .7208 m .25312 .72068 L .25282 .77627 L .641 .401 .539 r
F
.25154 .71724 m .25312 .72068 L .25162 .7208 L F
.25348 .72065 m .2531 .72229 L .25391 .72116 L .644 .733 .913 r
F
.2516 .71849 m .25249 .72073 L .25348 .72065 L F
.2531 .72229 m .25461 .72612 L .25391 .72116 L F
.25511 .71692 m .25795 .72175 L .26061 .72068 L F
.25187 .71471 m .25491 .71823 L .25511 .71692 L F
.25491 .71823 m .25795 .72175 L .25511 .71692 L F
.2553 .71535 m .25541 .71454 L .25541 .71492 L 0 0 .125 r
F
.25504 .72083 m .25768 .72553 L .26034 .72446 L .644 .733 .913 r
F
.25334 .71842 m .25488 .72234 L .25412 .71732 L F
.25314 .71704 m .25416 .7166 L .25414 .72032 L .515 .301 .526 r
F
.25318 .72066 m .25414 .72032 L .25384 .77583 L F
.25314 .71704 m .25414 .72032 L .25318 .72066 L F
.25412 .71732 m .25488 .72234 L .25795 .72175 L .644 .733 .913 r
F
.25424 .72029 m .25483 .72222 L .25504 .72083 L F
.2516 .71849 m .25341 .72058 L .25424 .72029 L F
.25414 .72032 m .25454 .77427 L .25385 .77485 L .353 .175 .495 r
F
.25291 .77328 m .25503 .7756 L .25687 .77461 L .692 .759 .903 r
F
.2531 .77334 m .25687 .77461 L .25364 .77289 L F
.25498 .77362 m .25489 .77426 L .25528 .77366 L F
.25499 .77358 m .25509 .77377 L .25498 .77458 L 0 0 .125 r
F
.25516 .71997 m .26034 .72446 L .2624 .72298 L .644 .733 .913 r
F
.2516 .71849 m .25504 .72083 L .25516 .71997 L F
.25504 .72083 m .26034 .72446 L .25516 .71997 L F
.25528 .71922 m .2551 .77281 L .25499 .77358 L 0 0 .125 r
F
.2553 .71535 m .25528 .71918 L .25528 .71922 L F
.25528 .71918 m .2551 .77281 L .25528 .71922 L F
.25397 .77306 m .25687 .77461 L .25406 .77292 L .692 .759 .903 r
F
.25457 .77211 m .25485 .7738 L .25456 .77426 L .065 0 .408 r
F
.25291 .77328 m .2531 .77334 L .25364 .77289 L .692 .759 .903 r
F
.25384 .77278 m .25687 .77461 L .25831 .77336 L F
.25453 .77215 m .25457 .77211 L .25455 .77527 L .353 .175 .495 r
F
.25105 .77316 m .25527 .77366 L .25546 .77292 L .692 .759 .903 r
F
.2551 .77281 m .25509 .77377 L .25499 .77358 L 0 0 .125 r
F
.25496 .77362 m .25482 .77437 L .25489 .77426 L .692 .759 .903 r
F
.25496 .77362 m .25489 .77426 L .25498 .77362 L F
.25189 .77365 m .25289 .77628 L .25503 .7756 L F
.25184 .77362 m .25186 .77366 L .25189 .77365 L F
.25186 .77366 m .25289 .77628 L .25189 .77365 L F
.25386 .77485 m .25317 .77549 L .2541 .77499 L F
.25283 .77319 m .25353 .775 L .25282 .77534 L .515 .301 .526 r
F
.25071 .77378 m .25061 .7766 L .25289 .77628 L .692 .759 .903 r
F
.25071 .77378 m .25289 .77628 L .25184 .77362 L F
.25197 .7755 m .25095 .77599 L .2521 .77583 L F
.25124 .7735 m .25234 .77543 L .25123 .77564 L .641 .401 .539 r
F
.25105 .77316 m .25096 .77569 L .25197 .7755 L .692 .759 .903 r
F
.25096 .77569 m .25095 .77599 L .25197 .7755 L F
.25061 .7766 m .25394 .77894 L .25289 .77628 L F
.25095 .77599 m .25315 .77851 L .2521 .77583 L F
.25123 .77564 m .25282 .77627 L .25122 .77647 L .641 .401 .539 r
F
.253 .77531 m .2521 .77583 L .25317 .77549 L .692 .759 .903 r
F
.2528 .77534 m .25234 .77543 L .25124 .7735 L .641 .401 .539 r
F
.25105 .77316 m .25197 .7755 L .253 .77531 L .692 .759 .903 r
F
.25197 .7755 m .2521 .77583 L .253 .77531 L F
.25283 .77319 m .25184 .77362 L .25291 .77328 L F
.25176 .7734 m .25184 .77362 L .25283 .77319 L F
.25275 .77321 m .2528 .77534 L .25124 .7735 L .641 .401 .539 r
F
.25289 .77628 m .25714 .77792 L .25503 .7756 L .692 .759 .903 r
F
.2521 .77583 m .2553 .77783 L .25317 .77549 L F
.2528 .77534 m .25282 .77627 L .25234 .77543 L .641 .401 .539 r
F
.25234 .77543 m .25282 .77627 L .25123 .77564 L F
.25154 .71724 m .25275 .77321 L .25124 .7735 L F
.2508 .77096 m .25176 .7734 L .25283 .77319 L .692 .759 .903 r
F
.25105 .77316 m .25297 .77527 L .25386 .77485 L F
.25297 .77527 m .25317 .77549 L .25386 .77485 L F
.25282 .77534 m .25384 .77583 L .25282 .77627 L .515 .301 .526 r
F
.25317 .77549 m .25716 .77683 L .2541 .77499 L .692 .759 .903 r
F
.25353 .775 m .25384 .77583 L .25282 .77534 L .515 .301 .526 r
F
.25312 .72068 m .2538 .77273 L .25283 .77319 L F
.25184 .77362 m .25503 .7756 L .25291 .77328 L .692 .759 .903 r
F
.25383 .77486 m .25353 .775 L .25283 .77319 L .515 .301 .526 r
F
.25105 .77316 m .25386 .77485 L .25482 .77437 L .692 .759 .903 r
F
.25386 .77485 m .2541 .77499 L .25477 .77441 L F
.25386 .77485 m .25477 .77441 L .25482 .77437 L F
.2538 .77273 m .25383 .77486 L .25283 .77319 L .515 .301 .526 r
F
.25383 .77486 m .25384 .77583 L .25353 .775 L F
.25314 .71704 m .25318 .72066 L .25312 .72068 L F
.25318 .72066 m .25384 .77583 L .25312 .72068 L F
.25635 .71955 m .2624 .72298 L .26372 .7212 L .644 .733 .913 r
F
.25416 .7166 m .25487 .71603 L .25485 .71983 L .353 .175 .495 r
F
.25414 .72032 m .25483 .72222 L .25424 .72029 L .644 .733 .913 r
F
.25419 .72029 m .25485 .71983 L .25457 .77211 L .353 .175 .495 r
F
.25416 .7166 m .25485 .71983 L .25419 .72029 L F
.25552 .71936 m .25516 .71997 L .25635 .71955 L .644 .733 .913 r
F
.25416 .7166 m .25419 .72029 L .25414 .72032 L .353 .175 .495 r
F
.2516 .71849 m .25484 .71983 L .25552 .71936 L .644 .733 .913 r
F
.25484 .71983 m .25516 .71997 L .25552 .71936 L F
.25516 .71997 m .2624 .72298 L .25635 .71955 L F
.25105 .77316 m .25454 .77428 L .25496 .77362 L .692 .759 .903 r
F
.25454 .77428 m .25482 .77437 L .25496 .77362 L F
.2541 .77499 m .2586 .77558 L .25482 .77437 L F
.25456 .77426 m .25498 .77458 L .25455 .77527 L .065 0 .408 r
F
.25485 .7738 m .25498 .77458 L .25456 .77426 L F
.25614 .71649 m .26061 .72068 L .26267 .7192 L .644 .733 .913 r
F
.25187 .71471 m .25694 .71817 L .25614 .71649 L F
.25694 .71817 m .26061 .72068 L .25614 .71649 L F
.25384 .77278 m .25831 .77336 L .25455 .77216 L .692 .759 .903 r
F
.25498 .77147 m .25498 .77359 L .25457 .77211 L .065 0 .408 r
F
.25498 .77359 m .25498 .77458 L .25485 .7738 L F
.25498 .77359 m .25485 .7738 L .25457 .77211 L F
.25364 .77289 m .25397 .77306 L .25384 .77278 L .692 .759 .903 r
F
.25397 .77306 m .25406 .77292 L .25384 .77278 L F
.25105 .77316 m .2554 .77292 L .25533 .77219 L F
.2554 .77292 m .25546 .77292 L .25545 .77285 L F
.2554 .77292 m .25545 .77285 L .25533 .77219 L F
.25528 .71918 m .25539 .71849 L .25509 .77377 L 0 0 .125 r
F
.25487 .71979 m .25528 .71922 L .25498 .77458 L .065 0 .408 r
F
.2553 .71535 m .25541 .71492 L .2553 .71566 L 0 0 .125 r
F
.2554 .71492 m .26399 .71742 L .26449 .71545 L .644 .733 .913 r
F
.25187 .71471 m .25571 .71557 L .2554 .71492 L F
.25571 .71557 m .26399 .71742 L .2554 .71492 L F
.25541 .71454 m .25495 .71349 L .25495 .71395 L .986 .729 .348 r
F
.25485 .71983 m .25498 .77147 L .25457 .77211 L .065 0 .408 r
F
.25487 .71979 m .25498 .77147 L .25485 .71983 L F
.2553 .71566 m .25541 .71492 L .25539 .71849 L 0 0 .125 r
F
.2553 .71566 m .25539 .71849 L .25528 .71918 L F
.25487 .71626 m .2553 .71566 L .25528 .71922 L .065 0 .408 r
F
.25487 .71626 m .25528 .71922 L .25487 .71979 L F
.25487 .71603 m .2553 .71566 L .25487 .71626 L F
.25187 .71471 m .26267 .7192 L .26399 .71742 L .644 .733 .913 r
F
.2554 .71492 m .25495 .71395 L .25493 .71751 L .986 .729 .348 r
F
.25482 .71385 m .26413 .71343 L .26294 .7115 L .644 .733 .913 r
F
.25187 .71471 m .25547 .71433 L .25482 .71385 L F
.25547 .71433 m .26413 .71343 L .25482 .71385 L F
.25495 .71349 m .25388 .71267 L .25388 .71315 L .908 .63 .502 r
F
.2516 .71849 m .25523 .7193 L .25563 .71872 L .644 .733 .913 r
F
.25355 .72074 m .25483 .72222 L .25414 .72032 L F
.25419 .72029 m .25455 .77527 L .25414 .72032 L .353 .175 .495 r
F
.25541 .71454 m .25495 .71395 L .2554 .71492 L .986 .729 .348 r
F
.25541 .71454 m .2554 .71492 L .25541 .71492 L F
.25547 .71433 m .26449 .71545 L .26413 .71343 L .644 .733 .913 r
F
.25187 .71471 m .25632 .71497 L .25547 .71433 L F
.25632 .71497 m .26449 .71545 L .25547 .71433 L F
.25487 .71603 m .25487 .71979 L .25485 .71983 L .065 0 .408 r
F
.25419 .72029 m .25457 .77211 L .25453 .77215 L .353 .175 .495 r
F
.25416 .7166 m .25419 .72029 L .25419 .72029 L F
.25419 .72029 m .25457 .77211 L .25419 .72029 L F
.26047 .71591 m .26386 .71721 L .26267 .71528 L .644 .733 .913 r
F
.25567 .71806 m .26422 .71923 L .26386 .71721 L F
.2516 .71849 m .25663 .71878 L .25567 .71806 L F
.25663 .71878 m .26422 .71923 L .25567 .71806 L F
.25494 .71394 m .25486 .71746 L .25495 .71395 L .908 .63 .502 r
F
.25486 .71746 m .25356 .7719 L .25486 .71746 L F
.25486 .71746 m .25486 .71746 L .25495 .71395 L F
.2508 .77096 m .25501 .77146 L .25519 .77072 L .692 .759 .903 r
F
.2508 .77096 m .25519 .77072 L .25506 .77 L F
.25493 .71751 m .25356 .7719 L .25463 .77273 L .908 .63 .502 r
F
.25495 .71395 m .25486 .71746 L .25493 .71751 L F
.25486 .71746 m .25356 .7719 L .25493 .71751 L F
.25494 .71752 m .25769 .71785 L .26047 .71591 L .644 .733 .913 r
F
.2516 .71849 m .25567 .71806 L .25494 .71752 L F
.25567 .71806 m .25769 .71785 L .25494 .71752 L F
.25769 .71785 m .26386 .71721 L .26047 .71591 L F
.25495 .71349 m .25494 .71394 L .25495 .71395 L .908 .63 .502 r
F
.25494 .71394 m .25388 .71315 L .25356 .7719 L F
.25495 .71349 m .25388 .71315 L .25494 .71394 L F
.25421 .71598 m .26072 .71356 L .25815 .71218 L .644 .733 .913 r
F
.25187 .71471 m .25334 .71842 L .25412 .71732 L F
.25359 .71305 m .26099 .70978 L .25841 .70841 L F
.25187 .71471 m .2544 .71334 L .25359 .71305 L F
.2544 .71334 m .26099 .70978 L .25359 .71305 L F
.25388 .71267 m .2528 .71229 L .2528 .71276 L .809 .541 .533 r
F
.2544 .71334 m .26294 .7115 L .26099 .70978 L .644 .733 .913 r
F
.25187 .71471 m .25538 .71369 L .2544 .71334 L F
.25538 .71369 m .26294 .7115 L .2544 .71334 L F
.2508 .77096 m .25455 .77216 L .25501 .77146 L .692 .759 .903 r
F
.25388 .71315 m .25255 .7687 L .25358 .76897 L .809 .541 .533 r
F
.25275 .76875 m .25397 .7688 L .25307 .7684 L .692 .759 .903 r
F
.2508 .77096 m .25367 .769 L .25275 .76875 L F
.25367 .769 m .25397 .7688 L .25275 .76875 L F
.2508 .77096 m .25506 .77 L .25464 .76934 L F
.25358 .76897 m .25275 .7709 L .25357 .77112 L .809 .541 .533 r
F
.25299 .77097 m .25423 .77099 L .25333 .77058 L .692 .759 .903 r
F
.2508 .77096 m .25384 .77278 L .25455 .77216 L F
.25105 .77316 m .25391 .77121 L .25299 .77097 L F
.25391 .77121 m .25423 .77099 L .25299 .77097 L F
.25357 .77112 m .25248 .77153 L .25356 .7719 L .809 .541 .533 r
F
.25275 .7709 m .25248 .77153 L .25357 .77112 L F
.2508 .77096 m .25464 .76934 L .25397 .7688 L .692 .759 .903 r
F
.25255 .7687 m .25248 .77153 L .25358 .76897 L .809 .541 .533 r
F
.25388 .71267 m .25387 .71315 L .25388 .71315 L F
.25341 .72058 m .25355 .72074 L .25414 .72032 L .644 .733 .913 r
F
.25387 .71315 m .25248 .77153 L .25388 .71315 L .809 .541 .533 r
F
.25375 .71311 m .2528 .71276 L .25278 .71633 L F
.25388 .71267 m .2528 .71276 L .25375 .71311 L F
.2516 .71849 m .25447 .71694 L .25355 .71661 L .644 .733 .913 r
F
.2516 .71849 m .25493 .71752 L .25462 .71686 L F
.25379 .71669 m .25278 .71633 L .25248 .77153 L .809 .541 .533 r
F
.25388 .71267 m .25278 .71633 L .25379 .71669 L F
.25355 .71661 m .25462 .71686 L .25421 .71598 L .644 .733 .913 r
F
.25447 .71694 m .25462 .71686 L .25355 .71661 L F
.25462 .71686 m .26072 .71356 L .25421 .71598 L F
.25536 .71842 m .25493 .71751 L .25463 .77273 L .986 .729 .348 r
F
.2554 .71492 m .25493 .71751 L .25536 .71842 L F
.25462 .71686 m .26267 .71528 L .26072 .71356 L .644 .733 .913 r
F
.25541 .71492 m .25536 .71843 L .25539 .71849 L .986 .729 .348 r
F
.25493 .71752 m .26267 .71528 L .25462 .71686 L .644 .733 .913 r
F
.25539 .71849 m .25463 .77273 L .25509 .77377 L .986 .729 .348 r
F
.25536 .71843 m .25463 .77273 L .25539 .71849 L F
.2554 .71492 m .25463 .77273 L .25541 .71492 L F
.25563 .71872 m .26372 .7212 L .26422 .71923 L .644 .733 .913 r
F
.25523 .7193 m .26372 .7212 L .25563 .71872 L F
.25527 .77366 m .25528 .77366 L .25529 .77365 L .692 .759 .903 r
F
.25527 .77366 m .25529 .77365 L .25546 .77292 L F
.25385 .77485 m .25455 .77527 L .25384 .77583 L .353 .175 .495 r
F
.25454 .77427 m .25455 .77527 L .25385 .77485 L F
.25483 .72222 m .25768 .72553 L .25504 .72083 L .644 .733 .913 r
F
.127 .923 .03 r
.25365 1.45888 m
.26018 1.65671 L
s
.26018 1.65671 m
.26729 1.87205 L
s
0 g
.50834 .73194 m
.5181 .7333 L
s
.62096 .37869 m .64583 .36483 L .61803 .3736 L .654 .726 .902 r
F
.62096 .37869 m .65168 .375 L .64583 .36483 L F
.26794 .61395 m .26747 .60937 L .25285 .60899 L .733 .497 .57 r
F
0 g
.26747 .60937 m
.28099 .61205 L
s
.46377 .49188 m .45641 .47519 L .45672 .48088 L .987 .711 .381 r
F
0 g
.46377 .49188 m
.4658 .50378 L
s
.50015 .81736 m .50304 .81584 L .5033 .81804 L .793 .527 .535 r
F
.50015 .81736 m .49989 .81516 L .50304 .81584 L F
0 g
.50304 .81584 m
.50645 .81594 L
s
.50222 .81257 m .50306 .81579 L .50431 .81302 L .692 .759 .903 r
F
.50222 .81257 m .49993 .81512 L .50306 .81579 L F
.66717 .60735 m .65828 .59801 L .65026 .60204 L .683 .77 .917 r
F
.67178 .60598 m .65828 .59801 L .66717 .60735 L F
.34704 .49055 m .31746 .49453 L .34168 .49807 L .673 .757 .914 r
F
.51336 .81664 m .5131 .81444 L .51589 .81295 L .514 .326 .564 r
F
.51014 .81766 m .5131 .81444 L .51336 .81664 L .599 .387 .564 r
F
0 g
.50988 .81546 m
.5131 .81444 L
s
.38363 .47911 m .37777 .46442 L .36551 .4677 L .673 .757 .914 r
F
.39015 .47847 m .37777 .46442 L .38363 .47911 L F
.51098 .81209 m .51307 .81441 L .51585 .81292 L .692 .759 .903 r
F
.64224 .48466 m .65446 .46919 L .65479 .47487 L .388 .235 .549 r
F
.62497 .47409 m .64224 .48466 L .65479 .47487 L .673 .757 .914 r
F
.61426 .47918 m .64224 .48466 L .62497 .47409 L F
0 g
.62618 .49228 m
.64224 .48466 L
s
.66367 .61394 m .65076 .60662 L .64451 .61164 L .683 .77 .917 r
F
.66768 .61193 m .65076 .60662 L .66367 .61394 L F
.56379 .36345 m .5369 .35182 L .53017 .36133 L .654 .726 .902 r
F
.56899 .35949 m .5369 .35182 L .56379 .36345 L F
.39015 .47847 m .39082 .46314 L .37777 .46442 L .673 .757 .914 r
F
.68155 .60546 m .67732 .59397 L .67669 .60533 L .683 .77 .917 r
F
.68155 .60546 m .68705 .59423 L .67732 .59397 L F
.56952 .35228 m .54793 .33674 L .53759 .34464 L .654 .726 .902 r
F
.57616 .34939 m .54793 .33674 L .56952 .35228 L F
.61844 .36631 m .6366 .34855 L .61362 .36182 L F
.61844 .36631 m .64624 .35753 L .6366 .34855 L F
.50697 .82034 m .50671 .81814 L .51014 .81766 L .668 .436 .56 r
F
.50356 .82024 m .50671 .81814 L .50697 .82034 L .731 .481 .551 r
F
.50356 .82024 m .5033 .81804 L .50671 .81814 L F
.50683 .81531 m .50671 .81814 L .51014 .81766 L .692 .759 .904 r
F
.127 .923 .03 r
.58013 .69728 m
.58016 .69509 L
s
.58367 .69555 m
.58372 .69335 L
s
.52202 .75429 m
.52205 .75211 L
s
.51772 .77911 m
.51775 .77694 L
s
.53018 .80256 m
.53019 .80041 L
s
.50456 .81524 m .50671 .81814 L .50683 .81531 L .692 .759 .904 r
F
.127 .923 .03 r
.50553 .76983 m
.50553 .76767 L
s
.50456 .81524 m .5033 .81804 L .50671 .81814 L .692 .759 .904 r
F
.61392 .3546 m .62406 .33424 L .60756 .35103 L .654 .726 .902 r
F
.61392 .3546 m .63678 .34139 L .62406 .33424 L F
.64988 .59753 m .6277 .59774 L .64366 .60253 L .683 .77 .917 r
F
.5104 .81986 m .51014 .81766 L .51336 .81664 L .599 .387 .564 r
F
.50697 .82034 m .51014 .81766 L .5104 .81986 L .668 .436 .56 r
F
.50912 .815 m .51014 .81766 L .51336 .81664 L .692 .759 .904 r
F
.50683 .81531 m .51014 .81766 L .50912 .815 L F
0 g
.50671 .81814 m
.51014 .81766 L
s
.403 .48591 m .40417 .46949 L .39698 .48448 L .673 .757 .914 r
F
.403 .48591 m .41621 .47235 L .40417 .46949 L F
.40843 .49395 m .41652 .47803 L .40331 .4916 L F
.40843 .49395 m .42677 .48274 L .41652 .47803 L F
.5369 .35182 m .49991 .35446 L .53017 .36133 L .654 .726 .902 r
F
.49747 .81616 m .49989 .81516 L .50015 .81736 L .861 .577 .506 r
F
.127 .923 .03 r
.56194 3.74719 m
.65668 .74956 L
s
.48641 6.13678 m
.56194 3.74719 L
s
.52127 3.45784 m
.58367 .69555 L
s
.46668 5.8741 m
.52127 3.45784 L
s
.54539 3.97589 m
.58013 .69728 L
s
.49929 8.32481 m
.54539 3.97589 L
s
.49747 .81616 m .49721 .81396 L .49989 .81516 L .861 .577 .506 r
F
0 g
.49989 .81516 m
.50304 .81584 L
s
.39256 .37354 m .36843 .36705 L .36798 .37434 L .667 .43 .553 r
F
0 g
.34492 .37926 m
.36798 .37434 L
s
.39256 .37354 m .393 .36625 L .36843 .36705 L .667 .43 .553 r
F
0 g
.34538 .37197 m
.36843 .36705 L
s
.50044 .81178 m .49993 .81512 L .50222 .81257 L .692 .759 .903 r
F
.50044 .81178 m .49726 .81393 L .49993 .81512 L F
.67178 .60598 m .66751 .59526 L .65828 .59801 L .683 .77 .917 r
F
.67669 .60533 m .66751 .59526 L .67178 .60598 L F
.41698 .37691 m .41743 .36962 L .393 .36625 L .732 .487 .557 r
F
0 g
.41743 .36962 m
.44002 .37692 L
s
.65209 .36771 m .67406 .34875 L .64624 .35753 L .654 .726 .902 r
F
.65209 .36771 m .68282 .36402 L .67406 .34875 L F
.50041 .81956 m .5033 .81804 L .50356 .82024 L .793 .527 .535 r
F
.50041 .81956 m .50015 .81736 L .5033 .81804 L F
.50245 .8148 m .5033 .81804 L .50456 .81524 L .692 .759 .904 r
F
.50245 .8148 m .50015 .81736 L .5033 .81804 L F
0 g
.5033 .81804 m
.50671 .81814 L
s
.21374 .71626 m .21511 .71854 L .21484 .72232 L .935 .758 .283 r
F
.21374 .71626 m .21401 .71249 L .21511 .71854 L F
.22663 .71323 m .21511 .71854 L .22736 .71727 L .644 .733 .913 r
F
.22663 .71323 m .21401 .71249 L .21511 .71854 L F
0 g
.21511 .71854 m
.21729 .72206 L
s
.127 .923 .03 r
.65695 .37437 m
.65715 .36785 L
s
.67669 .60533 m .67732 .59397 L .66751 .59526 L .683 .77 .917 r
F
.68655 .61094 m .68756 .59881 L .68206 .61004 L F
.68655 .61094 m .69654 .6006 L .68756 .59881 L F
.23935 .71976 m .22949 .72491 L .24054 .7217 L .644 .733 .913 r
F
.23935 .71976 m .22709 .72104 L .22949 .72491 L F
.62846 .60683 m .62186 .61076 L .62236 .61534 L .204 .117 .53 r
F
.644 .60706 m .62796 .60224 L .62186 .61076 L .683 .77 .917 r
F
.62846 .60683 m .62796 .60224 L .62186 .61076 L .204 .117 .53 r
F
0 g
.61946 .61968 m
.62186 .61076 L
s
.51615 .81515 m .51589 .81295 L .51807 .81108 L .392 .24 .553 r
F
.51336 .81664 m .51589 .81295 L .51615 .81515 L .514 .326 .564 r
F
0 g
.5131 .81444 m
.51589 .81295 L
s
.51362 .81884 m .51336 .81664 L .51615 .81515 L .514 .326 .564 r
F
.5104 .81986 m .51336 .81664 L .51362 .81884 L .599 .387 .564 r
F
.51126 .81432 m .51336 .81664 L .51615 .81515 L .692 .759 .904 r
F
.50912 .815 m .51336 .81664 L .51126 .81432 L F
0 g
.51014 .81766 m
.51336 .81664 L
s
.51283 .8111 m .51585 .81292 L .51801 .81106 L .692 .759 .903 r
F
.51098 .81209 m .51585 .81292 L .51283 .8111 L F
.25332 .61357 m .23814 .61092 L .23861 .6155 L .673 .453 .578 r
F
0 g
.22481 .61963 m
.23861 .6155 L
s
.25332 .61357 m .25285 .60899 L .23814 .61092 L .673 .453 .578 r
F
0 g
.22434 .61505 m
.23814 .61092 L
s
.24996 .71698 m .25154 .71724 L .25152 .7208 L .751 .491 .539 r
F
.25152 .7208 m .24808 .72573 L .25134 .72619 L .644 .733 .913 r
F
.25004 .72052 m .25152 .7208 L .25122 .77647 L .751 .491 .539 r
F
.24996 .71698 m .25152 .7208 L .25004 .72052 L F
.2516 .71849 m .25057 .72062 L .25152 .7208 L .644 .733 .913 r
F
.25057 .72062 m .24808 .72573 L .25152 .7208 L F
.28823 .72284 m .29 .71316 L .28973 .71693 L 0 0 .13 r
F
.28796 .72661 m .28823 .72284 L .28973 .71693 L F
.27611 .72013 m .28823 .72284 L .28973 .71693 L .644 .733 .913 r
F
0 g
.2853 .72677 m
.28823 .72284 L
s
.23958 .7102 m .22775 .71348 L .23994 .7122 L .645 .732 .913 r
F
.23958 .7102 m .22703 .70946 L .22775 .71348 L F
.27319 .72747 m .28796 .72661 L .27584 .7239 L .644 .733 .913 r
F
.2624 .72298 m .27319 .72747 L .27584 .7239 L F
.26034 .72446 m .27319 .72747 L .2624 .72298 L F
.52359 .47724 m .53484 .48091 L .53516 .48659 L .933 .657 .494 r
F
.52359 .47724 m .52327 .47156 L .53484 .48091 L F
.54552 .46346 m .53484 .48091 L .55323 .46969 L .673 .757 .914 r
F
.54552 .46346 m .52327 .47156 L .53484 .48091 L F
0 g
.53484 .48091 m
.54033 .48344 L
s
.70989 .60818 m .71796 .59505 L .70416 .6038 L .683 .77 .917 r
F
.70989 .60818 m .72656 .60164 L .71796 .59505 L F
.27625 .71632 m .28981 .71314 L .27725 .71241 L .645 .732 .913 r
F
.2642 .71363 m .27625 .71632 L .27725 .71241 L F
.26288 .7154 m .27625 .71632 L .2642 .71363 L F
.37775 .48637 m .3657 .47326 L .35503 .47834 L .673 .757 .914 r
F
.38391 .48472 m .3657 .47326 L .37775 .48637 L F
0 g
.25156 .71469 m
.25156 .71367 L
s
.24897 .7165 m .24996 .71698 L .24994 .7205 L .844 .571 .525 r
F
.24973 .77339 m .24852 .77352 L .24957 .77374 L .692 .759 .903 r
F
.24957 .77374 m .25061 .7766 L .25071 .77378 L F
.25097 .77562 m .24982 .77596 L .25095 .77599 L F
.24974 .77336 m .24966 .77336 L .24973 .77339 L F
.25116 .77349 m .25122 .77647 L .24966 .77336 L .751 .491 .539 r
F
.25105 .77316 m .25 .77554 L .25097 .77562 L .692 .759 .903 r
F
.24957 .77374 m .24835 .77653 L .25061 .7766 L F
.25 .77554 m .24982 .77596 L .25097 .77562 L F
.24835 .77653 m .25052 .77941 L .25061 .7766 L F
.24982 .77596 m .25086 .77882 L .25095 .77599 L F
.24964 .7755 m .25122 .77647 L .24964 .77621 L .751 .491 .539 r
F
.24966 .77336 m .25079 .7756 L .24964 .7755 L F
.25079 .7756 m .25122 .77647 L .24964 .7755 L F
.2483 .71591 m .24897 .7165 L .24895 .72003 L .927 .648 .491 r
F
.24965 .72036 m .24951 .72051 L .2505 .72076 L .644 .733 .913 r
F
.24791 .71521 m .2483 .71591 L .24828 .71946 L .989 .721 .393 r
F
.24792 .71885 m .24828 .71946 L .24798 .77515 L F
.24791 .71521 m .24828 .71946 L .24792 .71885 L F
.24951 .72051 m .24912 .72088 L .25013 .72104 L .644 .733 .913 r
F
.24912 .72088 m .24507 .72479 L .24949 .72151 L F
.24912 .72088 m .24949 .72151 L .25013 .72104 L F
.24951 .72051 m .25013 .72104 L .2505 .72076 L F
.24773 .77225 m .24695 .77257 L .24828 .77268 L .692 .759 .903 r
F
.24763 .77312 m .24625 .77608 L .24852 .77352 L F
.24763 .77312 m .24446 .77528 L .24625 .77608 L F
.24758 .77394 m .24663 .7734 L .24676 .77412 L F
.2476 .77181 m .2479 .77447 L .24759 .77396 L .989 .721 .393 r
F
.24828 .77268 m .24812 .77266 L .24817 .77275 L .692 .759 .903 r
F
.24852 .77352 m .24625 .77608 L .24835 .77653 L F
.24863 .77295 m .24864 .77574 L .24799 .77245 L .927 .648 .491 r
F
.24892 .77307 m .24852 .77352 L .24973 .77339 L .692 .759 .903 r
F
.25105 .77316 m .24723 .77337 L .24758 .77394 L F
.24723 .77337 m .24663 .7734 L .24758 .77394 L F
.25105 .77316 m .24676 .77412 L .24718 .77478 L F
.24759 .77396 m .24798 .77515 L .24759 .77445 L .989 .721 .393 r
F
.24843 .77495 m .24718 .77478 L .24786 .77533 L .692 .759 .903 r
F
.24786 .7144 m .24791 .71521 L .24789 .71881 L .798 .638 .081 r
F
.24852 .77352 m .24835 .77653 L .24957 .77374 L .692 .759 .903 r
F
.24892 .77307 m .24763 .77312 L .24852 .77352 L F
.24895 .72003 m .24961 .77334 L .24866 .77297 L .844 .571 .525 r
F
.2508 .77096 m .24814 .77277 L .24892 .77307 L .692 .759 .903 r
F
.24814 .77277 m .24763 .77312 L .24892 .77307 L F
.24914 .77531 m .24786 .77533 L .24876 .77573 L F
.24961 .77334 m .24964 .77621 L .24866 .77297 L .844 .571 .525 r
F
.24961 .77334 m .24966 .77336 L .24964 .77621 L F
.25105 .77316 m .24834 .775 L .24914 .77531 L .692 .759 .903 r
F
.24834 .775 m .24786 .77533 L .24914 .77531 L F
.25105 .77316 m .24876 .77573 L .24982 .77596 L F
.24865 .77512 m .24964 .77621 L .24864 .77574 L .844 .571 .525 r
F
.24866 .77297 m .2494 .77541 L .24865 .77512 L F
.2494 .77541 m .24964 .77621 L .24865 .77512 L F
.24897 .7165 m .24901 .72006 L .24895 .72003 L F
.24901 .72006 m .24964 .77621 L .24895 .72003 L F
.2477 .77307 m .24695 .77257 L .24763 .77312 L .692 .759 .903 r
F
.24817 .77275 m .24767 .77268 L .2477 .77307 L F
.24767 .77268 m .24695 .77257 L .2477 .77307 L F
.24695 .77257 m .24446 .77528 L .24763 .77312 L F
.24755 .77335 m .24681 .77266 L .24663 .7734 L F
.24812 .77266 m .24695 .77257 L .24817 .77275 L F
.24797 .77242 m .24798 .77515 L .2476 .77181 L .989 .721 .393 r
F
.25105 .77316 m .2475 .77274 L .24755 .77335 L .692 .759 .903 r
F
.2475 .77274 m .24681 .77266 L .24755 .77335 L F
.24753 .77319 m .24759 .77445 L .24753 .77363 L .798 .638 .081 r
F
.24755 .77104 m .24758 .77382 L .24753 .77319 L F
.24758 .77382 m .24759 .77445 L .24753 .77319 L F
.24784 .71806 m .2476 .77178 L .24755 .77104 L F
.2476 .77178 m .24759 .77445 L .24755 .77104 L F
.24786 .7144 m .24784 .71811 L .24784 .71806 L F
.24897 .7165 m .24994 .7205 L .24901 .72006 L .844 .571 .525 r
F
.2468 .71988 m .23935 .71976 L .24054 .7217 L .644 .733 .913 r
F
.2483 .71591 m .24895 .72003 L .24832 .71949 L .927 .648 .491 r
F
.2516 .71849 m .24734 .71893 L .2468 .71988 L .644 .733 .913 r
F
.24734 .71893 m .23935 .71976 L .2468 .71988 L F
.24786 .7144 m .24789 .71881 L .24784 .71811 L .798 .638 .081 r
F
.24691 .71615 m .23961 .71599 L .24081 .71792 L .644 .733 .913 r
F
.25187 .71471 m .24747 .71517 L .24691 .71615 L F
.24747 .71517 m .23961 .71599 L .24691 .71615 L F
.24838 .71337 m .24786 .7144 L .24786 .7145 L 0 0 .368 r
F
.24835 .71363 m .24786 .7145 L .24784 .71806 L F
.24838 .71337 m .24786 .7145 L .24835 .71363 L F
.24784 .71811 m .24759 .77445 L .24784 .71806 L .798 .638 .081 r
F
.24794 .71955 m .24054 .7217 L .24884 .71998 L .644 .733 .913 r
F
.24784 .71811 m .24789 .71881 L .24759 .77445 L .798 .638 .081 r
F
.2505 .72076 m .24507 .72479 L .24808 .72573 L .644 .733 .913 r
F
.24789 .71881 m .24797 .77242 L .2476 .77181 L .989 .721 .393 r
F
.24792 .71885 m .24797 .77242 L .24789 .71881 L F
.2483 .71591 m .24832 .71949 L .24828 .71946 L .927 .648 .491 r
F
.24497 .71918 m .23898 .71775 L .23935 .71976 L .644 .733 .913 r
F
.24661 .71819 m .23948 .71578 L .23898 .71775 L F
.2516 .71849 m .24761 .71759 L .24661 .71819 L F
.24761 .71759 m .23948 .71578 L .24661 .71819 L F
.24996 .71698 m .25004 .72052 L .24994 .7205 L .751 .491 .539 r
F
.2516 .71849 m .24794 .71955 L .24884 .71998 L .644 .733 .913 r
F
.2508 .77096 m .24773 .77225 L .24828 .77268 L .692 .759 .903 r
F
.24791 .71521 m .24792 .71885 L .24789 .71881 L .989 .721 .393 r
F
.24615 .71727 m .24081 .71399 L .23948 .71578 L .644 .733 .913 r
F
.2516 .71849 m .24775 .71688 L .24615 .71727 L F
.24775 .71688 m .24081 .71399 L .24615 .71727 L F
.24825 .7132 m .24314 .70874 L .24107 .71021 L F
.25187 .71471 m .2493 .71295 L .24825 .7132 L F
.2493 .71295 m .24314 .70874 L .24825 .7132 L F
.25061 .71225 m .2495 .71259 L .2495 .7129 L .567 .342 .533 r
F
.24675 .71356 m .24107 .71021 L .23975 .712 L .644 .733 .913 r
F
.2495 .71259 m .24838 .71337 L .24838 .71358 L .398 .209 .505 r
F
.24941 .71296 m .24838 .71358 L .24836 .71714 L F
.2495 .71259 m .24838 .71358 L .24941 .71296 L F
.24795 .71383 m .24825 .7132 L .24675 .71356 L .644 .733 .913 r
F
.25187 .71471 m .2487 .71339 L .24795 .71383 L F
.2487 .71339 m .24825 .7132 L .24795 .71383 L F
.24825 .7132 m .24107 .71021 L .24675 .71356 L F
.24994 .7205 m .25116 .77349 L .24966 .77336 L .751 .491 .539 r
F
.25004 .72052 m .25116 .77349 L .24994 .7205 L F
.25187 .71471 m .24366 .71287 L .23925 .71397 L .644 .733 .913 r
F
.24366 .71287 m .23975 .712 L .23949 .71301 L F
.24366 .71287 m .23949 .71301 L .23925 .71397 L F
.25171 .71216 m .25061 .71225 L .25061 .71264 L .66 .416 .54 r
F
.2516 .71849 m .24965 .72036 L .2505 .72076 L .644 .733 .913 r
F
.24646 .71634 m .24287 .71251 L .24081 .71399 L F
.2516 .71849 m .24838 .71628 L .24646 .71634 L F
.24838 .71337 m .24784 .71806 L .24833 .7172 L 0 0 .368 r
F
.24838 .71628 m .24287 .71251 L .24646 .71634 L .644 .733 .913 r
F
.25187 .71471 m .24579 .70766 L .24314 .70874 L F
.2517 .7126 m .25061 .71264 L .25059 .71621 L .66 .416 .54 r
F
.25161 .71617 m .25059 .71621 L .25029 .77149 L F
.2517 .7126 m .25059 .71621 L .25161 .71617 L F
.25171 .71216 m .25061 .71264 L .2517 .7126 L F
.24838 .71337 m .24833 .7172 L .24836 .71714 L 0 0 .368 r
F
.24887 .71662 m .24552 .71144 L .24287 .71251 L .644 .733 .913 r
F
.2516 .71849 m .2498 .71639 L .24887 .71662 L F
.2498 .71639 m .24552 .71144 L .24887 .71662 L F
.24958 .72043 m .24948 .72048 L .24951 .72051 L F
.2516 .71849 m .24842 .72021 L .24958 .72043 L F
.24951 .72051 m .24902 .72071 L .24912 .72088 L F
.24901 .72006 m .24994 .7205 L .24966 .77336 L .844 .571 .525 r
F
.24901 .72006 m .24966 .77336 L .24961 .77334 L F
.25051 .71622 m .24948 .71647 L .24918 .77182 L .567 .342 .533 r
F
.24919 .7692 m .24975 .7683 L .24868 .76864 L .692 .759 .903 r
F
.2508 .77096 m .24999 .76891 L .24919 .7692 L F
.25059 .71621 m .24925 .76918 L .2503 .7688 L .567 .342 .533 r
F
.24999 .76891 m .24975 .7683 L .24919 .7692 L .692 .759 .903 r
F
.24735 .77055 m .24704 .76975 L .24658 .77046 L F
.2508 .77096 m .24801 .77007 L .24735 .77055 L F
.24801 .77007 m .24704 .76975 L .24735 .77055 L F
.24717 .77178 m .24641 .7712 L .24653 .77192 L F
.24828 .71946 m .24863 .77295 L .24799 .77245 L .927 .648 .491 r
F
.2508 .77096 m .2475 .77114 L .24717 .77178 L .692 .759 .903 r
F
.2475 .77114 m .24641 .7712 L .24717 .77178 L F
.2508 .77096 m .24653 .77192 L .24695 .77257 L F
.24807 .77002 m .24762 .77301 L .24806 .77217 L 0 0 .368 r
F
.2508 .77096 m .24658 .77046 L .24641 .7712 L .692 .759 .903 r
F
.24757 .77099 m .24753 .77363 L .24807 .77002 L 0 0 .368 r
F
.24804 .7722 m .24799 .77132 L .24727 .77195 L .692 .759 .903 r
F
.2508 .77096 m .24892 .77307 L .24966 .77336 L F
.2508 .77096 m .24957 .77374 L .25071 .77378 L F
.25105 .77316 m .24838 .77156 L .24804 .7722 L F
.2508 .77096 m .24776 .76913 L .24704 .76975 L F
.24812 .76998 m .24807 .77216 L .24919 .7692 L .398 .209 .505 r
F
.25105 .77316 m .24727 .77195 L .24681 .77266 L .692 .759 .903 r
F
.24807 .77216 m .24806 .77261 L .24825 .77203 L .398 .209 .505 r
F
.24807 .77216 m .24825 .77203 L .24919 .7692 L F
.24838 .77156 m .24799 .77132 L .24804 .77218 L .692 .759 .903 r
F
.24806 .77217 m .24804 .77218 L .24804 .7722 L F
.24838 .77156 m .24804 .77218 L .24806 .77217 L F
.24806 .77217 m .24753 .77363 L .24806 .77261 L 0 0 .368 r
F
.24762 .77301 m .24753 .77363 L .24806 .77217 L F
.24836 .71714 m .24757 .77099 L .24807 .77002 L F
.2508 .77096 m .24868 .76864 L .24776 .76913 L .692 .759 .903 r
F
.24919 .7692 m .24825 .77203 L .24918 .77134 L .398 .209 .505 r
F
.24866 .77173 m .24892 .77082 L .24799 .77132 L .692 .759 .903 r
F
.2508 .77096 m .24966 .77336 L .24974 .77336 L F
.25105 .77316 m .24931 .77125 L .24866 .77173 L F
.24931 .77125 m .24892 .77082 L .24866 .77173 L F
.24918 .77134 m .24806 .77261 L .24918 .77182 L .398 .209 .505 r
F
.24825 .77203 m .24806 .77261 L .24918 .77134 L F
.24948 .71647 m .24812 .76998 L .24919 .7692 L F
.24925 .76918 m .24918 .77182 L .2503 .7688 L .567 .342 .533 r
F
.24934 .77129 m .24999 .77048 L .24892 .77082 L .692 .759 .903 r
F
.25105 .77316 m .25019 .77098 L .24934 .77129 L F
.2503 .7688 m .24938 .77127 L .25029 .77094 L .567 .342 .533 r
F
.25019 .77098 m .24999 .77048 L .24934 .77129 L .692 .759 .903 r
F
.25029 .77094 m .24918 .77182 L .25029 .77149 L .567 .342 .533 r
F
.24938 .77127 m .24918 .77182 L .25029 .77094 L F
.25061 .71264 m .25052 .71622 L .25059 .71621 L F
.25052 .71622 m .24918 .77182 L .25059 .71621 L F
.25061 .71225 m .2506 .71264 L .25061 .71264 L F
.2506 .71264 m .24918 .77182 L .25061 .71264 L F
.2505 .71267 m .2495 .7129 L .24948 .71647 L F
.25061 .71225 m .2495 .7129 L .2505 .71267 L F
.25061 .71225 m .24948 .71647 L .25051 .71622 L F
.2495 .71259 m .24941 .71651 L .24948 .71647 L .398 .209 .505 r
F
.24941 .71651 m .24806 .77261 L .24948 .71647 L F
.24884 .71998 m .248 .72015 L .24802 .72042 L .644 .733 .913 r
F
.24833 .7172 m .24753 .77363 L .24836 .71714 L 0 0 .368 r
F
.24734 .71893 m .24661 .71819 L .24497 .71918 L .644 .733 .913 r
F
.2516 .71849 m .24772 .71826 L .24734 .71893 L F
.24772 .71826 m .24661 .71819 L .24734 .71893 L F
.24661 .71819 m .23898 .71775 L .24497 .71918 L F
.24912 .72088 m .24809 .72127 L .24813 .72183 L F
.24832 .71949 m .24864 .77574 L .24828 .71946 L .927 .648 .491 r
F
.24832 .71949 m .24895 .72003 L .24864 .77574 L F
.24941 .71651 m .24836 .71714 L .24806 .77261 L .398 .209 .505 r
F
.2495 .71259 m .24836 .71714 L .24941 .71651 L F
.24833 .7172 m .24784 .71806 L .24753 .77363 L 0 0 .368 r
F
.24802 .72042 m .24054 .7217 L .24249 .72341 L .644 .733 .913 r
F
.248 .72015 m .24054 .7217 L .24802 .72042 L F
.24813 .72183 m .24249 .72341 L .24507 .72479 L F
.24809 .72127 m .24249 .72341 L .24813 .72183 L F
.24902 .72071 m .24249 .72341 L .24912 .72088 L F
.25105 .77316 m .24785 .7745 L .24843 .77495 L .692 .759 .903 r
F
.24785 .7745 m .24718 .77478 L .24843 .77495 L F
.24798 .7746 m .24864 .77574 L .24798 .77515 L .927 .648 .491 r
F
.24799 .77245 m .2485 .775 L .24798 .7746 L F
.2485 .775 m .24864 .77574 L .24798 .7746 L F
.2479 .77447 m .24798 .77515 L .24759 .77396 L .989 .721 .393 r
F
.24948 .72048 m .24249 .72341 L .24951 .72051 L .644 .733 .913 r
F
.24842 .72021 m .24249 .72341 L .24958 .72043 L F
.53759 .34464 m .51082 .33305 L .5008 .34727 L .654 .726 .902 r
F
.36249 .59338 m .36029 .60692 L .37016 .59658 L .683 .77 .917 r
F
.36249 .59338 m .34879 .60213 L .36029 .60692 L F
0 g
.36029 .60692 m
.3738 .6096 L
s
.43419 .48329 m .44481 .46584 L .42646 .47705 L .673 .757 .914 r
F
.43419 .48329 m .45641 .47519 L .44481 .46584 L F
.42843 .59331 m .43727 .58119 L .43776 .58577 L .402 .257 .568 r
F
.42892 .59789 m .42843 .59331 L .43776 .58577 L F
.41544 .58598 m .42843 .59331 L .43776 .58577 L .683 .77 .917 r
F
.40745 .59001 m .42843 .59331 L .41544 .58598 L F
0 g
.42162 .59674 m
.42843 .59331 L
s
.50709 .81751 m .50697 .82034 L .5104 .81986 L .692 .759 .904 r
F
.127 .923 .03 r
.52199 .75647 m
.52202 .75429 L
s
.51769 .78128 m
.51772 .77911 L
s
.53017 .8047 m
.53018 .80256 L
s
.52952 .80497 m
.52956 .80281 L
s
.50482 .81744 m .50697 .82034 L .50709 .81751 L .692 .759 .904 r
F
.127 .923 .03 r
.50552 .772 m
.50553 .76983 L
s
.50482 .81744 m .50356 .82024 L .50697 .82034 L .692 .759 .904 r
F
.50999 .34017 m .50035 .34717 L .49991 .35446 L .065 0 .392 r
F
.50999 .34017 m .51042 .33288 L .50035 .34717 L F
0 g
.49647 .36285 m
.50035 .34717 L
s
.39338 .52371 m
.39343 .50393 L
s
.26794 .61395 m .25285 .60899 L .25332 .61357 L .733 .497 .57 r
F
0 g
.23814 .61092 m
.25285 .60899 L
s
.25285 .60899 m
.26747 .60937 L
s
.26794 .61395 m
.28147 .61663 L
s
.50938 .8172 m .5104 .81986 L .51362 .81884 L .692 .759 .904 r
F
.50709 .81751 m .5104 .81986 L .50938 .8172 L F
0 g
.50697 .82034 m
.5104 .81986 L
s
.38682 .52359 m
.38687 .50404 L
s
.25332 .61357 m
.26794 .61395 L
s
.37272 .49459 m .35533 .48403 L .34704 .49055 L .673 .757 .914 r
F
.37806 .49205 m .35533 .48403 L .37272 .49459 L F
.3549 .47276 m .3252 .47198 L .34665 .47925 L F
.49773 .81836 m .50015 .81736 L .50041 .81956 L .861 .577 .506 r
F
.49773 .81836 m .49747 .81616 L .50015 .81736 L F
.50067 .814 m .50015 .81736 L .50245 .8148 L .692 .759 .904 r
F
.50067 .814 m .49747 .81616 L .50015 .81736 L F
0 g
.50015 .81736 m
.5033 .81804 L
s
.66768 .61193 m .65878 .60259 L .65076 .60662 L .683 .77 .917 r
F
.67229 .61056 m .65878 .60259 L .66768 .61193 L F
.68282 .36402 m .68322 .35673 L .67446 .34146 L .991 .743 .452 r
F
0 g
.68322 .35673 m
.68569 .37274 L
s
.50272 .817 m .50356 .82024 L .50482 .81744 L .692 .759 .904 r
F
.50272 .817 m .50041 .81956 L .50356 .82024 L F
0 g
.50356 .82024 m
.50697 .82034 L
s
.127 .923 .03 r
.49022 1.67826 m
.501 .8387 L
s
.501 .8387 m
.50124 .81974 L
s
.49544 .81452 m .49721 .81396 L .49747 .81616 L .934 .633 .448 r
F
.127 .923 .03 r
.49585 .81439 m
.49591 .80968 L
s
.49544 .81452 m .49518 .81232 L .49721 .81396 L .934 .633 .448 r
F
0 g
.49721 .81396 m
.49932 .81491 L
s
.34673 .48487 m .32518 .47756 L .31716 .48884 L .673 .757 .914 r
F
.32548 .48325 m .31716 .48884 L .31746 .49453 L .16 .065 .49 r
F
.32548 .48325 m .32518 .47756 L .31716 .48884 L F
0 g
.31409 .50083 m
.31716 .48884 L
s
.4991 .81069 m .49726 .81393 L .50044 .81178 L .692 .759 .903 r
F
.4991 .81069 m .49524 .8123 L .49726 .81393 L F
.127 .923 .03 r
.48769 .98112 m
.49647 8.80003 L
s
.48749 .79574 m
.48769 .98112 L
s
.51615 .81515 m .51807 .81108 L .51833 .81328 L .392 .24 .553 r
F
.51642 .81735 m .51615 .81515 L .51833 .81328 L F
.51362 .81884 m .51615 .81515 L .51642 .81735 L .514 .326 .564 r
F
.51312 .81332 m .51615 .81515 L .51833 .81328 L .692 .759 .904 r
F
.51126 .81432 m .51615 .81515 L .51312 .81332 L F
0 g
.51336 .81664 m
.51615 .81515 L
s
.72604 .59706 m .72553 .59248 L .71694 .58589 L .934 .647 .472 r
F
0 g
.72553 .59248 m
.73071 .6004 L
s
.51152 .81652 m .51362 .81884 L .51642 .81735 L .692 .759 .904 r
F
.50938 .8172 m .51362 .81884 L .51152 .81652 L F
0 g
.5104 .81986 m
.51362 .81884 L
s
.39698 .48448 m .39114 .46867 L .39047 .48408 L .673 .757 .914 r
F
.39698 .48448 m .40417 .46949 L .39114 .46867 L F
.703 .59472 m .70537 .58124 L .69542 .59154 L .683 .77 .917 r
F
.703 .59472 m .71673 .58602 L .70537 .58124 L F
.68206 .61004 m .67783 .59855 L .6772 .60991 L F
.68206 .61004 m .68756 .59881 L .67783 .59855 L F
0 g
.39331 .55548 m
.39338 .52371 L
s
.65026 .60204 m .62796 .60224 L .644 .60706 L .683 .77 .917 r
F
0 g
.38674 .55574 m
.38682 .52359 L
s
.51833 .81328 m .51807 .81108 L .51947 .80896 L .189 .098 .515 r
F
.127 .923 .03 r
.50668 6.0718 m
.53003 .83588 L
s
.53003 .83588 m
.53017 .8047 L
s
.50696 2.19184 m
.52909 .83139 L
s
.52909 .83139 m
.52952 .80497 L
s
0 g
.51589 .81295 m
.51807 .81108 L
s
.51427 .80986 m .51801 .81106 L .51941 .80895 L .692 .759 .903 r
F
.51283 .8111 m .51801 .81106 L .51427 .80986 L F
.41698 .37691 m .393 .36625 L .39256 .37354 L .732 .487 .557 r
F
0 g
.393 .36625 m
.41743 .36962 L
s
.41698 .37691 m
.43958 .38422 L
s
.36843 .36705 m
.393 .36625 L
s
.38391 .48472 m .37801 .46996 L .3657 .47326 L .673 .757 .914 r
F
.39047 .48408 m .37801 .46996 L .38391 .48472 L F
.22636 .717 m .21484 .72232 L .22709 .72104 L .644 .733 .913 r
F
.22636 .717 m .21374 .71626 L .21484 .72232 L F
0 g
.21484 .72232 m
.21843 .72811 L
s
.57674 .46083 m .56344 .4744 L .57546 .47726 L .673 .757 .914 r
F
.67229 .61056 m .66802 .59984 L .65878 .60259 L .683 .77 .917 r
F
.6772 .60991 m .66802 .59984 L .67229 .61056 L F
.50093 .8162 m .50041 .81956 L .50272 .817 L .692 .759 .904 r
F
.50093 .8162 m .49773 .81836 L .50041 .81956 L F
0 g
.50041 .81956 m
.50356 .82024 L
s
.23925 .71397 m .22736 .71727 L .23961 .71599 L .644 .733 .913 r
F
.23925 .71397 m .22663 .71323 L .22736 .71727 L F
.28796 .72661 m .28973 .71693 L .28946 .72071 L 0 0 .13 r
F
.27584 .7239 m .28796 .72661 L .28946 .72071 L .644 .733 .913 r
F
0 g
.28398 .73196 m
.28796 .72661 L
s
.127 .923 .03 r
.37869 .51772 m
.37878 .55801 L
s
.37869 .51772 m
.37925 .55777 L
s
.6772 .60991 m .67783 .59855 L .66802 .59984 L .683 .77 .917 r
F
.39047 .48408 m .39114 .46867 L .37801 .46996 L .673 .757 .914 r
F
.50695 .81249 m .50683 .81531 L .50912 .815 L .692 .759 .904 r
F
0 g
.50722 .81214 m
.50722 .81297 L
s
.50581 .81245 m .50456 .81524 L .50683 .81531 L .692 .759 .904 r
F
.50809 .81233 m .50912 .815 L .51126 .81432 L F
.27611 .72013 m .28973 .71693 L .27711 .71619 L .644 .733 .913 r
F
.26399 .71742 m .27611 .72013 L .27711 .71619 L F
.26267 .7192 m .27611 .72013 L .26399 .71742 L F
.40331 .4916 m .40448 .47518 L .39728 .49017 L .673 .757 .914 r
F
.40331 .4916 m .41652 .47803 L .40448 .47518 L F
.64451 .61164 m .62846 .60683 L .62236 .61534 L .683 .77 .917 r
F
0 g
.61996 .62426 m
.62236 .61534 L
s
.4957 .81672 m .49747 .81616 L .49773 .81836 L .934 .633 .448 r
F
.127 .923 .03 r
.49582 .81668 m
.49585 .81485 L
s
.4957 .81672 m .49544 .81452 L .49747 .81616 L .934 .633 .448 r
F
.49932 .8129 m .49747 .81616 L .50067 .814 L .692 .759 .904 r
F
.49932 .8129 m .49544 .81452 L .49747 .81616 L F
0 g
.49747 .81616 m
.49958 .81711 L
s
.23861 .6155 m
.25332 .61357 L
s
.57616 .34939 m .56122 .33096 L .54793 .33674 L .654 .726 .902 r
F
.58382 .34775 m .56122 .33096 L .57616 .34939 L F
.2642 .71363 m .27725 .71241 L .2647 .71167 L .645 .732 .913 r
F
.50476 .81223 m .50456 .81524 L .50581 .81245 L .692 .759 .904 r
F
.50476 .81223 m .50245 .8148 L .50456 .81524 L F
.51642 .81735 m .51833 .81328 L .51859 .81548 L .392 .24 .553 r
F
.51339 .81552 m .51642 .81735 L .51859 .81548 L .692 .759 .904 r
F
.51152 .81652 m .51642 .81735 L .51339 .81552 L F
0 g
.51362 .81884 m
.51642 .81735 L
s
.60756 .35103 m .60909 .32939 L .60008 .3486 L .654 .726 .902 r
F
.60756 .35103 m .62406 .33424 L .60909 .32939 L F
.3396 .59096 m .34782 .59297 L .34831 .59755 L .933 .647 .477 r
F
.127 .923 .03 r
.32486 .58336 m
.32508 .60873 L
s
.32576 .58303 m
.32855 .71772 L
s
.32855 .71772 m
.38253 3.31862 L
s
.3396 .59096 m .33912 .58638 L .34782 .59297 L .933 .647 .477 r
F
0 g
.34782 .59297 m
.35246 .5949 L
s
.50916 .81199 m .51126 .81432 L .51312 .81332 L .692 .759 .904 r
F
.35589 .57976 m .34803 .59283 L .36166 .58413 L .683 .77 .917 r
F
.35589 .57976 m .33937 .58628 L .34803 .59283 L F
.42892 .59789 m .43776 .58577 L .43825 .59035 L .402 .257 .568 r
F
.41593 .59056 m .42892 .59789 L .43825 .59035 L .683 .77 .917 r
F
.40794 .59459 m .42892 .59789 L .41593 .59056 L F
0 g
.41694 .60393 m
.42892 .59789 L
s
.51833 .81328 m .51947 .80896 L .51973 .81116 L .189 .098 .515 r
F
.51859 .81548 m .51833 .81328 L .51973 .81116 L F
.51457 .81207 m .51833 .81328 L .51973 .81116 L .692 .759 .904 r
F
.51312 .81332 m .51833 .81328 L .51457 .81207 L F
0 g
.51615 .81515 m
.51833 .81328 L
s
.50295 .80907 m .50044 .81178 L .50362 .80962 L .692 .759 .903 r
F
.50295 .80907 m .4991 .81069 L .50044 .81178 L F
.49421 .81255 m .49518 .81232 L .49544 .81452 L .975 .672 .304 r
F
.49421 .81255 m .49395 .81035 L .49518 .81232 L F
0 g
.49518 .81232 m
.49706 .81384 L
s
.49828 .80938 m .49524 .8123 L .4991 .81069 L .692 .759 .903 r
F
.49828 .80938 m .49401 .81034 L .49524 .8123 L F
.54584 .46914 m .53516 .48659 L .55355 .47538 L .673 .757 .914 r
F
.54584 .46914 m .52359 .47724 L .53516 .48659 L F
0 g
.53516 .48659 m
.55048 .49365 L
s
.58308 .46795 m .57579 .48295 L .5888 .48376 L .673 .757 .914 r
F
.50387 .81183 m .50245 .8148 L .50476 .81223 L .692 .759 .904 r
F
.50387 .81183 m .50067 .814 L .50245 .8148 L F
.37806 .49205 m .366 .47895 L .35533 .48403 L .673 .757 .914 r
F
.38421 .49041 m .366 .47895 L .37806 .49205 L F
.56337 .37075 m .53647 .35911 L .52975 .36863 L .654 .726 .902 r
F
.56857 .36678 m .53647 .35911 L .56337 .37075 L F
.65446 .46919 m .65412 .4635 L .66229 .45221 L .171 .075 .496 r
F
0 g
.64708 .46899 m
.65412 .4635 L
s
.51427 .80986 m .51941 .80895 L .51521 .80846 L .692 .759 .903 r
F
.51054 .80866 m .51427 .80986 L .51521 .80846 L F
.4345 .48897 m .44512 .47152 L .42677 .48274 L .673 .757 .914 r
F
.4345 .48897 m .45672 .48088 L .44512 .47152 L F
.50721 .81469 m .50709 .81751 L .50938 .8172 L .692 .759 .904 r
F
.50607 .81465 m .50709 .81751 L .50721 .81469 L F
.50607 .81465 m .50482 .81744 L .50709 .81751 L F
.56899 .35949 m .54729 .34388 L .5369 .35182 L .654 .726 .902 r
F
.57567 .35659 m .54729 .34388 L .56899 .35949 L F
.61803 .3736 m .63618 .35584 L .6132 .36912 L F
.61803 .3736 m .64583 .36483 L .63618 .35584 L F
.50835 .81453 m .50938 .8172 L .51152 .81652 L .692 .759 .904 r
F
.50721 .81469 m .50938 .8172 L .50835 .81453 L F
.51009 .81149 m .51312 .81332 L .51457 .81207 L F
.63246 .45612 m .6538 .46339 L .66193 .45216 L .673 .757 .914 r
F
.62414 .46261 m .6538 .46339 L .63246 .45612 L F
.61362 .36182 m .62381 .34137 L .60723 .35824 L .654 .726 .902 r
F
.61362 .36182 m .6366 .34855 L .62381 .34137 L F
.72604 .59706 m .71694 .58589 L .71745 .59047 L .934 .647 .472 r
F
.72656 .60164 m .72604 .59706 L .71745 .59047 L F
0 g
.72604 .59706 m
.73122 .60498 L
s
.53647 .35911 m .49948 .36175 L .52975 .36863 L .654 .726 .902 r
F
.49958 .8151 m .49773 .81836 L .50093 .8162 L .692 .759 .904 r
F
.49958 .8151 m .4957 .81672 L .49773 .81836 L F
0 g
.49773 .81836 m
.50041 .81956 L
s
.127 .923 .03 r
.38425 .77034 m
.38426 .77118 L
s
.49261 1.08058 m
.49473 .90681 L
s
.49473 .90681 m
.49582 .81682 L
s
.70365 .59922 m .70603 .58567 L .69603 .59602 L .683 .77 .917 r
F
.70365 .59922 m .71745 .59047 L .70603 .58567 L F
.51973 .81116 m .51947 .80896 L .52002 .80674 L 0 0 .384 r
F
0 g
.51807 .81108 m
.51947 .80896 L
s
.51521 .80846 m .51941 .80895 L .51995 .80675 L .692 .759 .903 r
F
.50502 .81443 m .50482 .81744 L .50607 .81465 L .692 .759 .904 r
F
.50502 .81443 m .50272 .817 L .50482 .81744 L F
0 g
.36798 .37434 m
.39256 .37354 L
s
.25124 .77312 m
.25124 .77303 L
s
.25124 .77294 m
.25125 .7721 L
s
.127 .923 .03 r
.23973 .79874 m
.27341 2.55784 L
s
.23925 .77398 m
.23973 .79874 L
s
.35503 .47834 m .32518 .47756 L .34673 .48487 L .673 .757 .914 r
F
.59615 .46771 m .60192 .48247 L .61426 .47918 L F
.602 .46037 m .61393 .47349 L .62464 .4684 L F
0 g
.39256 .37354 m
.41698 .37691 L
s
.65168 .375 m .67365 .35605 L .64583 .36483 L .654 .726 .902 r
F
.65168 .375 m .68241 .37132 L .67365 .35605 L F
.50942 .81419 m .51152 .81652 L .51339 .81552 L .692 .759 .904 r
F
.50835 .81453 m .51152 .81652 L .50942 .81419 L F
.65076 .60662 m .62846 .60683 L .64451 .61164 L .683 .77 .917 r
F
.34704 .49055 m .32548 .48325 L .31746 .49453 L .673 .757 .914 r
F
0 g
.31439 .50652 m
.31746 .49453 L
s
.23898 .71775 m .22709 .72104 L .23935 .71976 L .644 .733 .913 r
F
.23898 .71775 m .22636 .717 L .22709 .72104 L F
0 0 0 r
2.5 Mabswid
.65693 .3751 Mdot
.127 .923 .03 r
.5 Mabswid
.64508 1.70695 m
.66128 .93249 L
s
.66566 .72318 m
.66573 .7196 L
s
.66573 .7196 m
.66617 .69875 L
s
.66656 .68023 m
.66681 .66812 L
s
.51859 .81548 m .51973 .81116 L .52 .81336 L .189 .098 .515 r
F
.51483 .81427 m .51859 .81548 L .52 .81336 L .692 .759 .904 r
F
.51339 .81552 m .51859 .81548 L .51483 .81427 L F
0 g
.51642 .81735 m
.51859 .81548 L
s
.50319 .81128 m .50067 .814 L .50387 .81183 L .692 .759 .904 r
F
.50319 .81128 m .49932 .8129 L .50067 .814 L F
.39728 .49017 m .39144 .47436 L .39077 .48976 L .673 .757 .914 r
F
.39728 .49017 m .40448 .47518 L .39144 .47436 L F
.50254 .80842 m .4991 .81069 L .50295 .80907 L .692 .759 .903 r
F
.50254 .80842 m .49828 .80938 L .4991 .81069 L F
.27584 .7239 m .28946 .72071 L .27684 .71997 L .644 .733 .913 r
F
.26372 .7212 m .27584 .7239 L .27684 .71997 L F
.2624 .72298 m .27584 .7239 L .26372 .7212 L F
.49447 .81475 m .49544 .81452 L .4957 .81672 L .975 .672 .304 r
F
.49447 .81475 m .49421 .81255 L .49544 .81452 L F
.49849 .81159 m .49544 .81452 L .49932 .8129 L .692 .759 .904 r
F
.49849 .81159 m .49421 .81255 L .49544 .81452 L F
0 g
.49544 .81452 m
.49732 .81604 L
s
.64988 .59753 m .63703 .59024 L .6277 .59774 L .683 .77 .917 r
F
.65786 .59353 m .63703 .59024 L .64988 .59753 L F
.50413 .81403 m .50272 .817 L .50502 .81443 L .692 .759 .904 r
F
.50413 .81403 m .50093 .8162 L .50272 .817 L F
.26399 .71742 m .27711 .71619 L .26449 .71545 L .644 .733 .913 r
F
.2155 .70658 m .21428 .70871 L .21401 .71249 L 0 0 .125 r
F
0 g
.21457 .71029 m
.21498 .71254 L
s
.22802 .70554 m .21595 .70284 L .21447 .70872 L .645 .732 .913 r
F
.2155 .70658 m .21577 .7028 L .21428 .70871 L 0 0 .125 r
F
.22802 .70554 m .21447 .70872 L .22703 .70946 L .645 .732 .913 r
F
.24008 .70824 m .22703 .70946 L .23958 .7102 L F
.24008 .70824 m .22802 .70554 L .22703 .70946 L F
.58382 .34775 m .57656 .32768 L .56122 .33096 L .654 .726 .902 r
F
.59198 .34749 m .57656 .32768 L .58382 .34775 L F
.60008 .3486 m .59288 .32715 L .59198 .34749 L F
.60008 .3486 m .60909 .32939 L .59288 .32715 L F
.51457 .81207 m .51973 .81116 L .51551 .81066 L .692 .759 .904 r
F
.51082 .81087 m .51457 .81207 L .51551 .81066 L F
.25214 .71093 m .2524 .70326 L .24915 .70333 L .645 .732 .913 r
F
.25214 .71093 m .25565 .70372 L .2524 .70326 L F
0 g
.25496 .71173 m
.25497 .71038 L
s
.2647 .71167 m .27654 .70839 L .26434 .70966 L .645 .732 .913 r
F
.2647 .71167 m .27725 .71241 L .27654 .70839 L F
.5369 .35182 m .50999 .34017 L .49991 .35446 L .654 .726 .902 r
F
.50956 .34746 m .49991 .35446 L .49948 .36175 L .065 0 .392 r
F
.50956 .34746 m .50999 .34017 L .49991 .35446 L F
0 g
.49604 .37013 m
.49991 .35446 L
s
.27725 .71241 m .28874 .70712 L .27654 .70839 L .645 .732 .913 r
F
.27725 .71241 m .28981 .71314 L .28874 .70712 L F
.51521 .80846 m .51995 .80675 L .51557 .80698 L .692 .759 .903 r
F
.511 .80796 m .51521 .80846 L .51557 .80698 L F
.51054 .80866 m .51521 .80846 L .511 .80796 L F
.38421 .49041 m .37832 .47565 L .366 .47895 L .673 .757 .914 r
F
.39077 .48976 m .37832 .47565 L .38421 .49041 L F
.51035 .81369 m .51339 .81552 L .51483 .81427 L .692 .759 .904 r
F
.50942 .81419 m .51339 .81552 L .51035 .81369 L F
.28973 .71693 m .29 .71316 L .28892 .7071 L .933 .756 .279 r
F
0 g
.28904 .71689 m
.28956 .71486 L
s
.42596 .47148 m .42894 .45328 L .41577 .46679 L .673 .757 .914 r
F
.42596 .47148 m .44422 .46032 L .42894 .45328 L F
.57707 .46652 m .57579 .48295 L .58308 .46795 L F
.57707 .46652 m .56377 .48009 L .57579 .48295 L F
.34008 .59554 m .34831 .59755 L .34879 .60213 L .933 .647 .477 r
F
.34008 .59554 m .3396 .59096 L .34831 .59755 L F
.35621 .58441 m .34831 .59755 L .36201 .5888 L .683 .77 .917 r
F
.35621 .58441 m .3396 .59096 L .34831 .59755 L F
0 g
.34831 .59755 m
.35294 .59948 L
s
.51973 .81116 m .52002 .80674 L .52028 .80894 L 0 0 .384 r
F
.52 .81336 m .51973 .81116 L .52028 .80894 L F
.51551 .81066 m .51973 .81116 L .52028 .80894 L .692 .759 .904 r
F
0 g
.51833 .81328 m
.51973 .81116 L
s
.65712 .70733 m .66638 .7064 L .66614 .71018 L .793 .551 .57 r
F
.127 .923 .03 r
.66449 .70659 m
.6647 .70015 L
s
.66529 .68191 m
.66574 .66804 L
s
.65712 .70733 m .65736 .70355 L .66638 .7064 L .793 .551 .57 r
F
0 g
.66638 .7064 m
.66793 .70662 L
s
.68574 .71133 m .68598 .70755 L .69523 .70578 L .597 .38 .558 r
F
0 g
.68432 .70759 m
.68598 .70755 L
s
.39077 .48976 m .39144 .47436 L .37832 .47565 L .673 .757 .914 r
F
.66408 .69718 m .66643 .70629 L .67006 .69907 L .645 .732 .913 r
F
.66408 .69718 m .65746 .70346 L .66643 .70629 L F
.54793 .33674 m .51082 .33305 L .53759 .34464 L .654 .726 .902 r
F
.68282 .36402 m .67446 .34146 L .67406 .34875 L .991 .743 .452 r
F
.68241 .37132 m .68282 .36402 L .67406 .34875 L F
0 g
.68282 .36402 m
.68529 .38003 L
s
.68306 .69984 m .68593 .70744 L .69514 .70567 L .645 .732 .913 r
F
.67653 .69998 m .68593 .70744 L .68306 .69984 L F
.49385 .81038 m .49395 .81035 L .49421 .81255 L .757 .542 0 r
F
.49385 .81038 m .49359 .80818 L .49395 .81035 L F
0 g
.49395 .81035 m
.49518 .81232 L
s
.49804 .80794 m .49401 .81034 L .49828 .80938 L .692 .759 .903 r
F
.49804 .80794 m .49365 .80818 L .49401 .81034 L F
.45641 .47519 m .4561 .46951 L .4445 .46015 L .932 .657 .494 r
F
0 g
.4561 .46951 m
.46315 .48051 L
s
.59198 .34749 m .59288 .32715 L .57656 .32768 L .654 .726 .902 r
F
.64637 .35033 m .65966 .32817 L .63678 .34139 L F
.64637 .35033 m .67405 .34159 L .65966 .32817 L F
.50345 .81348 m .50093 .8162 L .50413 .81403 L .692 .759 .904 r
F
.50345 .81348 m .49958 .8151 L .50093 .8162 L F
.50278 .81062 m .49932 .8129 L .50319 .81128 L F
.50278 .81062 m .49849 .81159 L .49932 .8129 L F
.49875 .81379 m .4957 .81672 L .49958 .8151 L F
.49875 .81379 m .49447 .81475 L .4957 .81672 L F
0 g
.4957 .81672 m
.49773 .81836 L
s
.50242 .8077 m .49828 .80938 L .50254 .80842 L .692 .759 .903 r
F
.50242 .8077 m .49804 .80794 L .49828 .80938 L F
.511 .80796 m .51557 .80698 L .51118 .80722 L F
.43776 .58577 m .43727 .58119 L .44331 .57267 L .198 .112 .527 r
F
0 g
.43153 .58583 m
.43727 .58119 L
s
.57163 .45847 m .56344 .4744 L .57674 .46083 L .673 .757 .914 r
F
.57163 .45847 m .55323 .46969 L .56344 .4744 L F
.42101 .57632 m .43703 .58112 L .44304 .57264 L .683 .77 .917 r
F
.41482 .58133 m .43703 .58112 L .42101 .57632 L F
.69542 .59154 m .69197 .57857 L .68649 .58976 L F
.69542 .59154 m .70537 .58124 L .69197 .57857 L F
.72656 .60164 m .71745 .59047 L .71796 .59505 L .934 .647 .472 r
F
0 g
.72656 .60164 m
.73174 .60956 L
s
.51483 .81427 m .52 .81336 L .51577 .81286 L .692 .759 .904 r
F
.51108 .81307 m .51483 .81427 L .51577 .81286 L F
.51035 .81369 m .51483 .81427 L .51108 .81307 L F
0 g
.50722 .81297 m
.50882 .81277 L
s
.50722 .81297 m
.50722 .81297 L
s
.50564 .81271 m
.50722 .81297 L
s
.52028 .80894 m .52002 .80674 L .51966 .80457 L .756 .54 0 r
F
.127 .923 .03 r
.52079 .8349 m
.52199 .75647 L
s
.50108 2.12673 m
.52079 .8349 L
s
0 g
.51947 .80896 m
.51998 .80687 L
s
.51557 .80698 m .51995 .80675 L .51959 .80459 L .692 .759 .903 r
F
.51551 .81066 m .52028 .80894 L .51587 .80918 L .692 .759 .904 r
F
.51129 .81016 m .51551 .81066 L .51587 .80918 L F
.51082 .81087 m .51551 .81066 L .51129 .81016 L F
.70416 .6038 m .70654 .59025 L .69654 .6006 L .683 .77 .917 r
F
.70416 .6038 m .71796 .59505 L .70654 .59025 L F
.60694 .45209 m .62414 .46261 L .63246 .45612 L .673 .757 .914 r
F
.51557 .80698 m .51959 .80459 L .51533 .80555 L .692 .759 .903 r
F
.51118 .80722 m .51557 .80698 L .51533 .80555 L F
.52 .81336 m .52028 .80894 L .52054 .81114 L 0 0 .384 r
F
.51577 .81286 m .52 .81336 L .52054 .81114 L .692 .759 .904 r
F
0 g
.51859 .81548 m
.52 .81336 L
s
.65446 .46919 m .66229 .45221 L .66262 .4579 L .171 .075 .496 r
F
.65479 .47487 m .65446 .46919 L .66262 .4579 L F
.633 .46188 m .65446 .46919 L .66262 .4579 L .673 .757 .914 r
F
.62464 .4684 m .65446 .46919 L .633 .46188 L F
0 g
.64741 .47468 m
.65446 .46919 L
s
.50732 .81186 m .50721 .81469 L .50835 .81453 L .692 .759 .904 r
F
.50732 .81186 m .50607 .81465 L .50721 .81469 L F
.50732 .81186 m .50835 .81453 L .50942 .81419 L F
0 g
.50882 .81277 m
.50984 .81233 L
s
.26372 .7212 m .27684 .71997 L .26422 .71923 L .644 .733 .913 r
F
.21523 .71036 m .21401 .71249 L .21374 .71626 L 0 0 .125 r
F
0 g
.2143 .71406 m
.21471 .71632 L
s
.22763 .70929 m .2155 .70658 L .21401 .71249 L .644 .733 .913 r
F
.21523 .71036 m .2155 .70658 L .21401 .71249 L 0 0 .125 r
F
.22763 .70929 m .21401 .71249 L .22663 .71323 L .644 .733 .913 r
F
.49411 .81258 m .49421 .81255 L .49447 .81475 L .757 .542 0 r
F
.49411 .81258 m .49385 .81038 L .49421 .81255 L F
.49825 .81014 m .49421 .81255 L .49849 .81159 L .692 .759 .904 r
F
.49825 .81014 m .49385 .81038 L .49421 .81255 L F
0 g
.49421 .81255 m
.49544 .81452 L
s
.51118 .80722 m .51533 .80555 L .51107 .8065 L .692 .759 .903 r
F
.50732 .81186 m .50502 .81443 L .50607 .81465 L .692 .759 .904 r
F
0 g
.50465 .81224 m
.50564 .81271 L
s
.2484 .71068 m
.2484 .71001 L
s
.23975 .712 m .22663 .71323 L .23925 .71397 L .644 .733 .913 r
F
.23975 .712 m .22763 .70929 L .22663 .71323 L F
.50732 .81186 m .50942 .81419 L .51035 .81369 L .692 .759 .904 r
F
.38942 .58726 m .38892 .59863 L .39873 .59734 L .683 .77 .917 r
F
.38455 .58713 m .38892 .59863 L .38942 .58726 L F
.38455 .58713 m .37917 .59837 L .38892 .59863 L F
.25187 .71471 m .24886 .70707 L .24579 .70766 L .644 .733 .913 r
F
.25187 .71471 m .25214 .707 L .24886 .70707 L F
.25187 .71471 m .2554 .70746 L .25214 .707 L F
.25187 .71471 m .25841 .70841 L .2554 .70746 L F
.26449 .71545 m .27639 .71215 L .26413 .71343 L F
.26449 .71545 m .27711 .71619 L .27639 .71215 L F
.65026 .60204 m .63734 .59471 L .62796 .60224 L .683 .77 .917 r
F
.65828 .59801 m .63734 .59471 L .65026 .60204 L F
.39845 .58066 m .40745 .59001 L .41544 .58598 L F
.27711 .71619 m .28865 .71087 L .27639 .71215 L .644 .733 .913 r
F
.27711 .71619 m .28973 .71693 L .28865 .71087 L F
.63734 .59471 m .62746 .59766 L .62796 .60224 L .404 .259 .569 r
F
.63734 .59471 m .63684 .59013 L .62746 .59766 L F
0 g
.62136 .60618 m
.62746 .59766 L
s
.35533 .48403 m .32548 .48325 L .34704 .49055 L .673 .757 .914 r
F
.28973 .71693 m .28892 .7071 L .28865 .71087 L .933 .756 .279 r
F
.28946 .72071 m .28973 .71693 L .28865 .71087 L F
0 g
.28878 .72067 m
.28929 .71864 L
s
.57567 .35659 m .56065 .33806 L .54729 .34388 L .654 .726 .902 r
F
.58337 .35494 m .56065 .33806 L .57567 .35659 L F
.50304 .81282 m .49958 .8151 L .50345 .81348 L .692 .759 .904 r
F
.50304 .81282 m .49875 .81379 L .49958 .8151 L F
.2414 .70646 m .22802 .70554 L .24008 .70824 L .645 .732 .913 r
F
.60232 .46606 m .61426 .47918 L .62497 .47409 L .673 .757 .914 r
F
.59615 .46771 m .61426 .47918 L .60232 .46606 L F
.50732 .81186 m .50413 .81403 L .50502 .81443 L .692 .759 .904 r
F
0 g
.50399 .81164 m
.50465 .81224 L
s
.60723 .35824 m .60876 .33649 L .59971 .3558 L .654 .726 .902 r
F
.60723 .35824 m .62381 .34137 L .60876 .33649 L F
.26434 .70966 m .27416 .70454 L .26315 .70774 L .645 .732 .913 r
F
.26434 .70966 m .27654 .70839 L .27416 .70454 L F
.39433 .58661 m .39873 .59734 L .40794 .59459 L .683 .77 .917 r
F
.38942 .58726 m .39873 .59734 L .39433 .58661 L F
.50266 .8099 m .49849 .81159 L .50278 .81062 L .692 .759 .904 r
F
.50266 .8099 m .49825 .81014 L .49849 .81159 L F
.65688 .71111 m .66614 .71018 L .6659 .71395 L .793 .551 .57 r
F
.127 .923 .03 r
.66437 .71035 m
.66439 .70962 L
s
.65688 .71111 m .65712 .70733 L .66614 .71018 L .793 .551 .57 r
F
.66377 .70102 m .66614 .71018 L .66978 .70292 L .645 .732 .913 r
F
.66377 .70102 m .65712 .70733 L .66614 .71018 L F
0 g
.66614 .71018 m
.66769 .71039 L
s
.51129 .81016 m .51587 .80918 L .51147 .80942 L .692 .759 .904 r
F
.5026 .80696 m .49804 .80794 L .50242 .8077 L .692 .759 .903 r
F
.50732 .81186 m .51035 .81369 L .51108 .81307 L .692 .759 .904 r
F
0 g
.50984 .81233 m
.51055 .81176 L
s
.68574 .71133 m .69523 .70578 L .69499 .70955 L .597 .38 .558 r
F
.6855 .7151 m .68574 .71133 L .69499 .70955 L F
.68285 .70369 m .68574 .71133 L .69499 .70955 L .645 .732 .913 r
F
0 g
.68409 .71136 m
.68574 .71133 L
s
.51055 .81176 m
.51099 .81108 L
s
.50361 .81095 m
.50399 .81164 L
s
.52028 .80894 m .51966 .80457 L .51992 .80677 L .756 .54 0 r
F
.52054 .81114 m .52028 .80894 L .51992 .80677 L F
0 g
.51973 .81116 m
.52024 .80907 L
s
.51587 .80918 m .52028 .80894 L .51992 .80677 L .692 .759 .904 r
F
.51107 .8065 m .51451 .80424 L .51066 .80585 L .692 .759 .903 r
F
0 g
.51065 .75404 m
.51066 .80585 L
s
.51107 .8065 m .51533 .80555 L .51451 .80424 L .692 .759 .903 r
F
.51577 .81286 m .52054 .81114 L .51613 .81138 L .692 .759 .904 r
F
.51155 .81236 m .51577 .81286 L .51613 .81138 L F
.51108 .81307 m .51577 .81286 L .51155 .81236 L F
.4984 .80647 m .49365 .80818 L .49804 .80794 L .692 .759 .903 r
F
.5026 .80696 m .4984 .80647 L .49804 .80794 L F
.35669 .58899 m .34879 .60213 L .36249 .59338 L .683 .77 .917 r
F
.35669 .58899 m .34008 .59554 L .34879 .60213 L F
0 g
.34879 .60213 m
.36029 .60692 L
s
.50732 .81186 m .50345 .81348 L .50413 .81403 L .692 .759 .904 r
F
0 g
.25494 .71527 m
.25495 .71395 L
s
.51587 .80918 m .51992 .80677 L .51563 .80774 L .692 .759 .904 r
F
.51147 .80942 m .51587 .80918 L .51563 .80774 L F
.4984 .80647 m .49419 .80597 L .49365 .80818 L .692 .759 .903 r
F
0 g
.24806 .77261 m
.24806 .77217 L
s
.24806 .77129 m
.24807 .77002 L
s
.24837 .71475 m
.24838 .71358 L
s
.49439 .80816 m .49359 .80818 L .49385 .81038 L 0 0 .383 r
F
0 g
.49391 .81012 m
.49395 .81035 L
s
.49439 .80816 m .49413 .80596 L .49359 .80818 L 0 0 .383 r
F
.64946 .70319 m .65736 .70355 L .65712 .70733 L .857 .609 .563 r
F
.64946 .70319 m .64971 .69942 L .65736 .70355 L F
0 g
.65736 .70355 m
.66017 .70444 L
s
.50732 .81186 m .51108 .81307 L .51155 .81236 L .692 .759 .904 r
F
.3549 .47276 m .33758 .46224 L .3252 .47198 L .673 .757 .914 r
F
.36551 .4677 m .33758 .46224 L .3549 .47276 L F
.659 .69444 m .64984 .69934 L .65746 .70346 L .645 .732 .913 r
F
.56857 .36678 m .54687 .35117 L .53647 .35911 L .654 .726 .902 r
F
.57525 .36388 m .54687 .35117 L .56857 .36678 L F
.69499 .70955 m .69523 .70578 L .70326 .70256 L .501 .3 .54 r
F
0 g
.68946 .70688 m
.69523 .70578 L
s
.127 .923 .03 r
.69854 .70445 m
.70016 .63949 L
s
.69779 .70475 m
.70016 .63949 L
s
.49851 .81234 m .49447 .81475 L .49875 .81379 L .692 .759 .904 r
F
.49851 .81234 m .49411 .81258 L .49447 .81475 L F
0 g
.49447 .81475 m
.4957 .81672 L
s
.50307 .80626 m .4984 .80647 L .5026 .80696 L .692 .759 .903 r
F
.51147 .80942 m .51563 .80774 L .51135 .8087 L .692 .759 .904 r
F
0 g
.51099 .81108 m
.51111 .81027 L
s
.51533 .80555 m .51837 .80262 L .51451 .80424 L .692 .759 .903 r
F
.51533 .80555 m .51959 .80459 L .51837 .80262 L F
.6132 .36912 m .6234 .34866 L .60681 .36553 L .654 .726 .902 r
F
.6132 .36912 m .63618 .35584 L .6234 .34866 L F
.6892 .69866 m .69514 .70567 L .70313 .70247 L .645 .732 .913 r
F
.68306 .69984 m .69514 .70567 L .6892 .69866 L F
0 g
.50356 .81014 m
.50361 .81095 L
s
.42646 .47705 m .42944 .45877 L .41621 .47235 L .673 .757 .914 r
F
.42646 .47705 m .44481 .46584 L .42944 .45877 L F
.65786 .59353 m .649 .58422 L .63703 .59024 L .683 .77 .917 r
F
.66704 .59079 m .649 .58422 L .65786 .59353 L F
.127 .923 .03 r
.66213 .57731 m
.66416 .513 L
s
.51066 .80585 m .51317 .80315 L .50998 .8053 L .692 .759 .903 r
F
.51066 .80585 m .51451 .80424 L .51317 .80315 L F
.50706 .80966 m .51094 .80804 L .51026 .80749 L .692 .759 .904 r
F
0 g
.51066 .80619 m
.51066 .80782 L
s
.50706 .80966 m .51135 .8087 L .51094 .80804 L .692 .759 .904 r
F
0 g
.51066 .80833 m
.51066 .80923 L
s
.50732 .81186 m .50304 .81282 L .50345 .81348 L .692 .759 .904 r
F
.38004 .58624 m .37917 .59837 L .38455 .58713 L .683 .77 .917 r
F
.38004 .58624 m .37016 .59658 L .37917 .59837 L F
.43776 .58577 m .44331 .57267 L .4438 .57725 L .198 .112 .527 r
F
.43825 .59035 m .43776 .58577 L .4438 .57725 L F
.42166 .58095 m .43776 .58577 L .4438 .57725 L .683 .77 .917 r
F
.41544 .58598 m .43776 .58577 L .42166 .58095 L F
0 g
.43202 .59041 m
.43776 .58577 L
s
.40189 .57402 m .41482 .58133 L .42101 .57632 L .683 .77 .917 r
F
.45641 .47519 m .4445 .46015 L .44481 .46584 L .932 .657 .494 r
F
.45672 .48088 m .45641 .47519 L .44481 .46584 L F
0 g
.45641 .47519 m
.46346 .48619 L
s
.50292 .8121 m .49875 .81379 L .50304 .81282 L .692 .759 .904 r
F
.50292 .8121 m .49851 .81234 L .49875 .81379 L F
.51155 .81236 m .51613 .81138 L .51173 .81162 L F
.50732 .81186 m .51155 .81236 L .51173 .81162 L F
.50284 .80916 m .49825 .81014 L .50266 .8099 L F
.51992 .80677 m .51966 .80457 L .51842 .8026 L .975 .672 .303 r
F
0 g
.51966 .80457 m
.52002 .80674 L
s
.69603 .59602 m .69256 .58298 L .68705 .59423 L .683 .77 .917 r
F
.69603 .59602 m .70603 .58567 L .69256 .58298 L F
.50307 .80626 m .49933 .80506 L .4984 .80647 L .692 .759 .903 r
F
.50379 .80564 m .49933 .80506 L .50307 .80626 L F
.51624 .46054 m .52295 .46587 L .52327 .47156 L .986 .711 .379 r
F
.51624 .46054 m .51592 .45485 L .52295 .46587 L F
0 g
.52295 .46587 m
.5279 .46987 L
s
.22736 .71307 m .21374 .71626 L .22636 .717 L .644 .733 .913 r
F
.22736 .71307 m .21523 .71036 L .21374 .71626 L F
0 g
.21374 .71626 m
.21484 .72232 L
s
.52054 .81114 m .51992 .80677 L .52018 .80897 L .756 .54 0 r
F
.51613 .81138 m .52054 .81114 L .52018 .80897 L .692 .759 .904 r
F
0 g
.52 .81336 m
.52054 .81114 L
s
.51135 .8087 m .51481 .80642 L .51094 .80804 L .692 .759 .904 r
F
.51135 .8087 m .51563 .80774 L .51481 .80642 L F
.49861 .80866 m .49385 .81038 L .49825 .81014 L F
.50284 .80916 m .49861 .80866 L .49825 .81014 L F
.23948 .71578 m .22636 .717 L .23898 .71775 L .644 .733 .913 r
F
.23948 .71578 m .22736 .71307 L .22636 .717 L F
.54076 .45038 m .52328 .46575 L .54542 .45769 L .673 .757 .914 r
F
.54076 .45038 m .51629 .45479 L .52328 .46575 L F
.127 .923 .03 r
.53141 .45206 m
.53168 .38987 L
s
.5307 .45219 m
.53168 .38987 L
s
.52335 .38271 m
.53113 .45211 L
s
.25266 .71631 m .25815 .71218 L .25513 .71123 L .644 .733 .913 r
F
.2516 .71849 m .2537 .71646 L .25266 .71631 L F
.2537 .71646 m .25815 .71218 L .25266 .71631 L F
.25278 .71633 m .25146 .76864 L .25249 .76868 L .734 .477 .54 r
F
.25181 .76865 m .25307 .7684 L .25202 .76817 L .692 .759 .903 r
F
.2508 .77096 m .2528 .7687 L .25181 .76865 L F
.2528 .7687 m .25307 .7684 L .25181 .76865 L F
.25146 .76864 m .25139 .7714 L .25249 .76868 L .734 .477 .54 r
F
.25112 .77077 m .25228 .77036 L .25114 .77032 L .692 .759 .903 r
F
.2508 .77096 m .25071 .77378 L .25184 .77362 L F
.2508 .77096 m .25291 .77328 L .25384 .77278 L F
.25105 .77316 m .25208 .77081 L .25112 .77077 L F
.25249 .76868 m .25163 .77079 L .25248 .77083 L .734 .477 .54 r
F
.25208 .77081 m .25228 .77036 L .25112 .77077 L .692 .759 .903 r
F
.25105 .77316 m .25333 .77058 L .25228 .77036 L F
.25248 .77083 m .25139 .7714 L .25248 .77153 L .734 .477 .54 r
F
.25163 .77079 m .25139 .7714 L .25248 .77083 L F
.2528 .71229 m .2527 .71632 L .25278 .71633 L F
.2527 .71632 m .25139 .7714 L .25278 .71633 L F
.2528 .71229 m .25171 .71216 L .25139 .7714 L F
.50998 .8053 m .51139 .80235 L .5091 .80491 L .692 .759 .903 r
F
.50998 .8053 m .51317 .80315 L .51139 .80235 L F
.2516 .71849 m .24859 .71085 L .24552 .71144 L .644 .733 .913 r
F
0 g
.24808 .76896 m
.24836 .71714 L
s
.2516 .71849 m .25187 .71078 L .24859 .71085 L .644 .733 .913 r
F
.2516 .71849 m .25513 .71123 L .25187 .71078 L F
.26422 .71923 m .27613 .71593 L .26386 .71721 L F
.26422 .71923 m .27684 .71997 L .27613 .71593 L F
.24997 .76885 m .25089 .76814 L .24975 .7683 L .692 .759 .903 r
F
.2508 .77096 m .25087 .76871 L .24997 .76885 L F
.25171 .71216 m .25035 .76879 L .2514 .76864 L .66 .416 .54 r
F
.25087 .76871 m .25089 .76814 L .24997 .76885 L .692 .759 .903 r
F
.2508 .77096 m .25202 .76817 L .25089 .76814 L F
.25035 .76879 m .25029 .77149 L .2514 .76864 L .66 .416 .54 r
F
.25018 .77096 m .25114 .77032 L .24999 .77048 L .692 .759 .903 r
F
.25105 .77316 m .25112 .77082 L .25018 .77096 L F
.2514 .76864 m .25051 .77091 L .25139 .77078 L .66 .416 .54 r
F
.25112 .77082 m .25114 .77032 L .25018 .77096 L .692 .759 .903 r
F
.25139 .77078 m .25029 .77149 L .25139 .7714 L .66 .416 .54 r
F
.25051 .77091 m .25029 .77149 L .25139 .77078 L F
.27684 .71997 m .28839 .71465 L .27613 .71593 L .644 .733 .913 r
F
.27684 .71997 m .28946 .72071 L .28839 .71465 L F
.49933 .80506 m .49419 .80597 L .4984 .80647 L .692 .759 .903 r
F
.51613 .81138 m .52018 .80897 L .51589 .80994 L .692 .759 .904 r
F
.51173 .81162 m .51613 .81138 L .51589 .80994 L F
.50732 .81186 m .50292 .8121 L .50304 .81282 L F
.57196 .46416 m .56377 .48009 L .57707 .46652 L .673 .757 .914 r
F
.57196 .46416 m .55355 .47538 L .56377 .48009 L F
.28946 .72071 m .28865 .71087 L .28839 .71465 L .933 .756 .279 r
F
0 g
.28796 .72661 m
.28946 .72071 L
s
.49465 .81036 m .49385 .81038 L .49411 .81258 L 0 0 .383 r
F
0 g
.49417 .81232 m
.49421 .81255 L
s
.49861 .80866 m .49439 .80816 L .49385 .81038 L .692 .759 .904 r
F
.49465 .81036 m .49439 .80816 L .49385 .81038 L 0 0 .383 r
F
.24107 .71021 m .22763 .70929 L .23975 .712 L .644 .733 .913 r
F
.37572 .58005 m .36201 .5888 L .36968 .592 L .683 .77 .917 r
F
.2414 .70646 m .23065 .70199 L .22802 .70554 L .645 .732 .913 r
F
.24345 .70499 m .23065 .70199 L .2414 .70646 L F
.56757 .44962 m .55309 .4639 L .5714 .45273 L .673 .757 .914 r
F
.56757 .44962 m .54542 .45769 L .55309 .4639 L F
.58337 .35494 m .57606 .33478 L .56065 .33806 L .654 .726 .902 r
F
.59157 .35468 m .57606 .33478 L .58337 .35494 L F
.26413 .71343 m .274 .70829 L .26294 .7115 L .644 .733 .913 r
F
.26413 .71343 m .27639 .71215 L .274 .70829 L F
.53647 .35911 m .50956 .34746 L .49948 .36175 L .654 .726 .902 r
F
0 g
.49561 .37742 m
.49948 .36175 L
s
.59971 .3558 m .59248 .33424 L .59157 .35468 L .654 .726 .902 r
F
.59971 .3558 m .60876 .33649 L .59248 .33424 L F
.26315 .70774 m .27028 .70113 L .26121 .70603 L .645 .732 .913 r
F
.26315 .70774 m .27416 .70454 L .27028 .70113 L F
.60735 .45783 m .62464 .4684 L .633 .46188 L .673 .757 .914 r
F
.68649 .58976 m .67744 .57818 L .67681 .5895 L .683 .77 .917 r
F
.68649 .58976 m .69197 .57857 L .67744 .57818 L F
.23065 .70199 m .21595 .70284 L .22802 .70554 L .645 .732 .913 r
F
.50379 .80564 m .50077 .80382 L .49933 .80506 L .692 .759 .903 r
F
.50471 .80514 m .50077 .80382 L .50379 .80564 L F
.66353 .7048 m .6659 .71395 L .66954 .7067 L .645 .732 .913 r
F
.127 .923 .03 r
.66191 .78612 m
.66383 .72681 L
s
.66383 .72681 m
.66427 .71344 L
s
.66353 .7048 m .65688 .71111 L .6659 .71395 L .645 .732 .913 r
F
0 g
.6659 .71395 m
.67315 .71497 L
s
.51173 .81162 m .51589 .80994 L .51161 .8109 L .692 .759 .904 r
F
.50732 .81186 m .51173 .81162 L .51161 .8109 L F
.65076 .60662 m .63785 .59929 L .62846 .60683 L .683 .77 .917 r
F
.65878 .60259 m .63785 .59929 L .65076 .60662 L F
.50331 .80846 m .49861 .80866 L .50284 .80916 L .692 .759 .904 r
F
.51563 .80774 m .51868 .8048 L .51481 .80642 L F
.51563 .80774 m .51992 .80677 L .51868 .8048 L F
.39894 .58524 m .40794 .59459 L .41593 .59056 L .683 .77 .917 r
F
.39433 .58661 m .40794 .59459 L .39894 .58524 L F
.63785 .59929 m .62796 .60224 L .62846 .60683 L .404 .259 .569 r
F
0 g
.62236 .61534 m
.62846 .60683 L
s
.63785 .59929 m .63734 .59471 L .62796 .60224 L .404 .259 .569 r
F
0 g
.62186 .61076 m
.62796 .60224 L
s
.6855 .7151 m .69499 .70955 L .69475 .71333 L .597 .38 .558 r
F
.68261 .70747 m .6855 .7151 L .69475 .71333 L .645 .732 .913 r
F
0 g
.67679 .71529 m
.6855 .7151 L
s
.5091 .80491 m .5093 .8019 L .50805 .80468 L .692 .759 .903 r
F
.5091 .80491 m .51139 .80235 L .5093 .8019 L F
.27654 .70839 m .28517 .70134 L .27416 .70454 L .645 .732 .913 r
F
.27654 .70839 m .28874 .70712 L .28517 .70134 L F
.51451 .80424 m .51635 .80099 L .51317 .80315 L .692 .759 .903 r
F
.51451 .80424 m .51837 .80262 L .51635 .80099 L F
.51094 .80804 m .51346 .80532 L .51026 .80749 L .692 .759 .904 r
F
.51094 .80804 m .51481 .80642 L .51346 .80532 L F
.65479 .47487 m .66262 .4579 L .66296 .46359 L .171 .075 .496 r
F
.63333 .46756 m .65479 .47487 L .66296 .46359 L .673 .757 .914 r
F
.62497 .47409 m .65479 .47487 L .63333 .46756 L F
0 g
.64224 .48466 m
.65479 .47487 L
s
.50732 .81186 m .5031 .81136 L .50292 .8121 L .692 .759 .904 r
F
.50732 .81186 m .50357 .81066 L .5031 .81136 L F
.50732 .81186 m .50429 .81003 L .50357 .81066 L F
0 g
.50356 .81014 m
.50409 .80911 L
s
.50732 .81186 m .50522 .80953 L .50429 .81003 L .692 .759 .904 r
F
.50732 .81186 m .5063 .80919 L .50522 .80953 L F
.50732 .81186 m .50744 .80903 L .5063 .80919 L F
.50732 .81186 m .50858 .80907 L .50744 .80903 L F
.50732 .81186 m .50963 .80929 L .50858 .80907 L F
.50732 .81186 m .51052 .80969 L .50963 .80929 L F
.50732 .81186 m .5112 .81024 L .51052 .80969 L F
0 g
.51066 .80923 m
.51104 .81011 L
s
.50732 .81186 m .51161 .8109 L .5112 .81024 L .692 .759 .904 r
F
.50471 .80514 m .50262 .80283 L .50077 .80382 L .692 .759 .903 r
F
.50578 .80481 m .50262 .80283 L .50471 .80514 L F
.68241 .37132 m .67406 .34875 L .67365 .35605 L .991 .743 .452 r
F
0 g
.68241 .37132 m
.68488 .38732 L
s
.50805 .80468 m .50704 .80184 L .50692 .80465 L .692 .759 .903 r
F
.50805 .80468 m .5093 .8019 L .50704 .80184 L F
.54729 .34388 m .50999 .34017 L .5369 .35182 L .654 .726 .902 r
F
.5031 .81136 m .49851 .81234 L .50292 .8121 L .692 .759 .904 r
F
.51992 .80677 m .51842 .8026 L .51868 .8048 L .975 .672 .303 r
F
.52018 .80897 m .51992 .80677 L .51868 .8048 L F
0 g
.51992 .80677 m
.52028 .80894 L
s
.64922 .70697 m .65712 .70733 L .65688 .71111 L .857 .609 .563 r
F
.64922 .70697 m .64946 .70319 L .65712 .70733 L F
.65866 .69827 m .65712 .70733 L .66377 .70102 L .645 .732 .913 r
F
.127 .923 .03 r
.65976 .65206 m
.65988 .64843 L
s
.65866 .69827 m .64946 .70319 L .65712 .70733 L .645 .732 .913 r
F
0 g
.65712 .70733 m
.65993 .70822 L
s
.5096 .80841 m
.51066 .80923 L
s
.51066 .80923 m
.51066 .80923 L
s
.50578 .80481 m .50476 .80215 L .50262 .80283 L .692 .759 .903 r
F
.50692 .80465 m .50476 .80215 L .50578 .80481 L F
.59157 .35468 m .59248 .33424 L .57606 .33478 L .654 .726 .902 r
F
0 g
.50409 .80911 m
.50409 .80911 L
s
.50409 .80911 m
.50522 .80833 L
s
.50692 .80465 m .50704 .80184 L .50476 .80215 L .692 .759 .903 r
F
.69499 .70955 m .70326 .70256 L .70302 .70634 L .501 .3 .54 r
F
.69475 .71333 m .69499 .70955 L .70302 .70634 L F
.68902 .70251 m .69499 .70955 L .70302 .70634 L .645 .732 .913 r
F
.68285 .70369 m .69499 .70955 L .68902 .70251 L F
0 g
.68922 .71066 m
.69499 .70955 L
s
.50331 .80846 m .49955 .80725 L .49861 .80866 L .692 .759 .904 r
F
.50403 .80783 m .49955 .80725 L .50331 .80846 L F
.49933 .80506 m .49559 .80386 L .49419 .80597 L .692 .759 .903 r
F
.49579 .80604 m .49413 .80596 L .49439 .80816 L .188 .098 .514 r
F
.49579 .80604 m .49553 .80384 L .49413 .80596 L F
0 g
.49359 .80818 m
.49413 .80596 L
s
.64624 .35753 m .6596 .33526 L .6366 .34855 L .654 .726 .902 r
F
.64624 .35753 m .67406 .34875 L .6596 .33526 L F
.51161 .8109 m .51507 .80862 L .5112 .81024 L .692 .759 .904 r
F
.51161 .8109 m .51589 .80994 L .51507 .80862 L F
.49887 .81086 m .49411 .81258 L .49851 .81234 L F
.5031 .81136 m .49887 .81086 L .49851 .81234 L F
.71745 .59047 m .71694 .58589 L .70552 .58109 L .861 .591 .528 r
F
0 g
.71694 .58589 m
.72553 .59248 L
s
.51026 .80749 m .51167 .80453 L .50937 .80709 L .692 .759 .904 r
F
.51026 .80749 m .51346 .80532 L .51167 .80453 L F
.49955 .80725 m .49439 .80816 L .49861 .80866 L F
.66704 .59079 m .66279 .58011 L .649 .58422 L .683 .77 .917 r
F
.67681 .5895 m .66279 .58011 L .66704 .59079 L F
.49887 .81086 m .49465 .81036 L .49411 .81258 L .692 .759 .904 r
F
0 g
.49411 .81258 m
.49447 .81475 L
s
.50077 .80382 m .49559 .80386 L .49933 .80506 L .692 .759 .903 r
F
.50403 .80783 m .501 .806 L .49955 .80725 L .692 .759 .904 r
F
.50496 .80733 m .501 .806 L .50403 .80783 L F
.50357 .81066 m .49887 .81086 L .5031 .81136 L F
.51589 .80994 m .51895 .807 L .51507 .80862 L F
.51589 .80994 m .52018 .80897 L .51895 .807 L F
0 g
.50852 .80803 m
.5096 .80841 L
s
.33762 .46777 m .32488 .47187 L .32518 .47756 L .384 .231 .546 r
F
.33762 .46777 m .33732 .46208 L .32488 .47187 L F
0 g
.31686 .48315 m
.32488 .47187 L
s
.43825 .59035 m .4438 .57725 L .44429 .58183 L .198 .112 .527 r
F
.42215 .58553 m .43825 .59035 L .44429 .58183 L .683 .77 .917 r
F
.41593 .59056 m .43825 .59035 L .42215 .58553 L F
0 g
.42892 .59789 m
.43825 .59035 L
s
.67681 .5895 m .67744 .57818 L .66279 .58011 L .683 .77 .917 r
F
.65828 .59801 m .64937 .58866 L .63734 .59471 L F
.66751 .59526 m .64937 .58866 L .65828 .59801 L F
0 g
.50522 .80833 m
.50633 .80799 L
s
.50937 .80709 m .50957 .80408 L .50832 .80687 L .692 .759 .904 r
F
.50937 .80709 m .51167 .80453 L .50957 .80408 L F
.40245 .57864 m .41544 .58598 L .42166 .58095 L .683 .77 .917 r
F
.51868 .8048 m .51842 .8026 L .5164 .80096 L .934 .633 .447 r
F
.127 .923 .03 r
.50224 1.8268 m
.51381 1.04391 L
s
0 g
.51842 .8026 m
.51966 .80457 L
s
.51481 .80642 m .51666 .80316 L .51346 .80532 L .692 .759 .904 r
F
.51481 .80642 m .51868 .8048 L .51666 .80316 L F
.51317 .80315 m .51368 .7998 L .51139 .80235 L .692 .759 .903 r
F
.51317 .80315 m .51635 .80099 L .51368 .7998 L F
.5112 .81024 m .51372 .80753 L .51052 .80969 L .692 .759 .904 r
F
.5112 .81024 m .51507 .80862 L .51372 .80753 L F
.69654 .6006 m .69307 .58757 L .68756 .59881 L .683 .77 .917 r
F
.69654 .6006 m .70654 .59025 L .69307 .58757 L F
.24345 .70499 m .23475 .69904 L .23065 .70199 L .645 .732 .913 r
F
.24609 .70392 m .23475 .69904 L .24345 .70499 L F
.35503 .47834 m .33762 .46777 L .32518 .47756 L .673 .757 .914 r
F
.3657 .47326 m .33762 .46777 L .35503 .47834 L F
.50496 .80733 m .50286 .805 L .501 .806 L .692 .759 .904 r
F
.50604 .80699 m .50286 .805 L .50496 .80733 L F
0 g
.50743 .80791 m
.50852 .80803 L
s
.41577 .46679 m .41095 .44901 L .40379 .46395 L .673 .757 .914 r
F
.41577 .46679 m .42894 .45328 L .41095 .44901 L F
.26121 .70603 m .26516 .69838 L .25865 .70466 L .645 .732 .913 r
F
.26121 .70603 m .27028 .70113 L .26516 .69838 L F
0 g
.50633 .80799 m
.50743 .80791 L
s
.50832 .80687 m .5073 .80401 L .50718 .80683 L .692 .759 .904 r
F
.50832 .80687 m .50957 .80408 L .5073 .80401 L F
.52018 .80897 m .51868 .8048 L .51895 .807 L .975 .672 .303 r
F
0 g
.52018 .80897 m
.52054 .81114 L
s
.24081 .71399 m .22736 .71307 L .23948 .71578 L .644 .733 .913 r
F
.42677 .48274 m .42976 .46446 L .41652 .47803 L .673 .757 .914 r
F
.42677 .48274 m .44512 .47152 L .42976 .46446 L F
.24107 .71021 m .23027 .70572 L .22763 .70929 L .644 .733 .913 r
F
.24314 .70874 m .23027 .70572 L .24107 .71021 L F
.26386 .71721 m .27374 .71206 L .26267 .71528 L F
.26386 .71721 m .27613 .71593 L .27374 .71206 L F
.50604 .80699 m .50501 .80432 L .50286 .805 L .692 .759 .904 r
F
.50718 .80683 m .50501 .80432 L .50604 .80699 L F
.50718 .80683 m .5073 .80401 L .50501 .80432 L F
.50357 .81066 m .49981 .80945 L .49887 .81086 L F
.50429 .81003 m .49981 .80945 L .50357 .81066 L F
.26294 .7115 m .2701 .70486 L .26099 .70978 L .644 .733 .913 r
F
.26294 .7115 m .274 .70829 L .2701 .70486 L F
.23027 .70572 m .2155 .70658 L .22763 .70929 L F
.57525 .36388 m .56023 .34536 L .54687 .35117 L .654 .726 .902 r
F
.58295 .36224 m .56023 .34536 L .57525 .36388 L F
.49605 .80824 m .49439 .80816 L .49465 .81036 L .188 .098 .514 r
F
.49955 .80725 m .49579 .80604 L .49439 .80816 L .692 .759 .904 r
F
.49605 .80824 m .49579 .80604 L .49439 .80816 L .188 .098 .514 r
F
0 g
.49385 .81038 m
.49439 .80816 L
s
.60681 .36553 m .60835 .34378 L .59929 .36309 L .654 .726 .902 r
F
.60681 .36553 m .6234 .34866 L .60835 .34378 L F
.23065 .70199 m .2199 .69751 L .21595 .70284 L .645 .732 .913 r
F
.37621 .58463 m .37016 .59658 L .38004 .58624 L .683 .77 .917 r
F
.37621 .58463 m .36249 .59338 L .37016 .59658 L F
.21947 .70122 m .21577 .7028 L .2155 .70658 L .068 0 .397 r
F
.21947 .70122 m .21974 .69744 L .21577 .7028 L F
0 g
.21428 .70871 m
.21577 .7028 L
s
.51052 .80969 m .51193 .80673 L .50963 .80929 L .692 .759 .904 r
F
.51052 .80969 m .51372 .80753 L .51193 .80673 L F
.27639 .71215 m .28507 .70507 L .274 .70829 L .644 .733 .913 r
F
.27639 .71215 m .28865 .71087 L .28507 .70507 L F
.45672 .48088 m .44481 .46584 L .44512 .47152 L .932 .657 .494 r
F
0 g
.45672 .48088 m
.46377 .49188 L
s
.37242 .57324 m .36166 .58413 L .37531 .57543 L .683 .77 .917 r
F
.37242 .57324 m .35589 .57976 L .36166 .58413 L F
.50077 .80382 m .49775 .802 L .49559 .80386 L .692 .759 .903 r
F
.50262 .80283 m .49775 .802 L .50077 .80382 L F
.33429 .58303 m .33912 .58638 L .3396 .59096 L .981 .69 .341 r
F
.33429 .58303 m .33381 .57845 L .33912 .58638 L F
0 g
.33912 .58638 m
.34326 .58951 L
s
.49981 .80945 m .49465 .81036 L .49887 .81086 L .692 .759 .904 r
F
.35237 .5745 m .33937 .58628 L .35589 .57976 L .683 .77 .917 r
F
.35237 .5745 m .33408 .57839 L .33937 .58628 L F
.51656 .46623 m .52327 .47156 L .52359 .47724 L .986 .711 .379 r
F
.51656 .46623 m .51624 .46054 L .52327 .47156 L F
.54084 .45611 m .52327 .47156 L .54552 .46346 L .673 .757 .914 r
F
.54084 .45611 m .51624 .46054 L .52327 .47156 L F
0 g
.52327 .47156 m
.52822 .47556 L
s
.501 .806 m .49579 .80604 L .49955 .80725 L .692 .759 .904 r
F
.68705 .59423 m .67796 .58259 L .67732 .59397 L .683 .77 .917 r
F
.68705 .59423 m .69256 .58298 L .67796 .58259 L F
.28865 .71087 m .28892 .7071 L .28534 .7013 L .989 .751 .481 r
F
0 g
.28892 .7071 m
.29 .71316 L
s
.50429 .81003 m .50126 .8082 L .49981 .80945 L .692 .759 .904 r
F
.50522 .80953 m .50126 .8082 L .50429 .81003 L F
.65842 .70204 m .65688 .71111 L .66353 .7048 L .645 .732 .913 r
F
.65842 .70204 m .64922 .70697 L .65688 .71111 L F
0 g
.65688 .71111 m
.6659 .71395 L
s
.51139 .80235 m .51055 .79912 L .5093 .8019 L .692 .759 .903 r
F
.51139 .80235 m .51368 .7998 L .51055 .79912 L F
.64368 .69805 m .64971 .69942 L .64946 .70319 L .927 .677 .54 r
F
.64368 .69805 m .64392 .69427 L .64971 .69942 L F
0 g
.64971 .69942 m
.6531 .70125 L
s
.50963 .80929 m .50983 .80628 L .50858 .80907 L .692 .759 .904 r
F
.50963 .80929 m .51193 .80673 L .50983 .80628 L F
.69475 .71333 m .70302 .70634 L .70278 .71012 L .501 .3 .54 r
F
.68878 .70628 m .69475 .71333 L .70278 .71012 L .645 .732 .913 r
F
.127 .923 .03 r
.69818 .71877 m
.6983 .71375 L
s
.6983 .71375 m
.69835 .71189 L
s
.69727 .71904 m
.69745 .714 L
s
.69745 .714 m
.69751 .71222 L
s
.68261 .70747 m .69475 .71333 L .68878 .70628 L .645 .732 .913 r
F
0 g
.6855 .7151 m
.69475 .71333 L
s
.65516 .69103 m .64984 .69934 L .659 .69444 L .645 .732 .913 r
F
.65516 .69103 m .64409 .69423 L .64984 .69934 L F
.127 .923 .03 r
.63628 .71884 m
.64865 .8116 L
s
.62729 .6514 m
.63628 .71884 L
s
.56778 .45535 m .55323 .46969 L .57163 .45847 L .673 .757 .914 r
F
.56778 .45535 m .54552 .46346 L .55323 .46969 L F
.51868 .8048 m .5164 .80096 L .51666 .80316 L .934 .633 .447 r
F
.51895 .807 m .51868 .8048 L .51666 .80316 L F
0 g
.51868 .8048 m
.51992 .80677 L
s
.51507 .80862 m .51692 .80536 L .51372 .80753 L .692 .759 .904 r
F
.51507 .80862 m .51895 .807 L .51692 .80536 L F
.51346 .80532 m .51398 .80196 L .51167 .80453 L F
.51346 .80532 m .51666 .80316 L .51398 .80196 L F
.49797 .80417 m .49553 .80384 L .49579 .80604 L .391 .24 .553 r
F
.49797 .80417 m .49771 .80197 L .49553 .80384 L F
0 g
.49413 .80596 m
.49553 .80384 L
s
.70302 .70634 m .70326 .70256 L .70952 .69812 L .354 .18 .502 r
F
0 g
.69756 .70484 m
.70326 .70256 L
s
.60768 .46352 m .62497 .47409 L .63333 .46756 L .673 .757 .914 r
F
.60232 .46606 m .62497 .47409 L .60768 .46352 L F
.69453 .69653 m .70313 .70247 L .70936 .69806 L .645 .732 .913 r
F
.6892 .69866 m .70313 .70247 L .69453 .69653 L F
.50522 .80953 m .50312 .8072 L .50126 .8082 L .692 .759 .904 r
F
.5063 .80919 m .50312 .8072 L .50522 .80953 L F
.24609 .70392 m .24004 .69691 L .23475 .69904 L .645 .732 .913 r
F
.24915 .70333 m .24004 .69691 L .24609 .70392 L F
.50858 .80907 m .50756 .80621 L .50744 .80903 L .692 .759 .904 r
F
.50858 .80907 m .50983 .80628 L .50756 .80621 L F
.50262 .80283 m .50053 .80051 L .49775 .802 L .692 .759 .903 r
F
.50476 .80215 m .50053 .80051 L .50262 .80283 L F
.25865 .70466 m .25915 .6965 L .25565 .70372 L .645 .732 .913 r
F
.25865 .70466 m .26516 .69838 L .25915 .6965 L F
.71745 .59047 m .70552 .58109 L .70603 .58567 L .861 .591 .528 r
F
.71796 .59505 m .71745 .59047 L .70603 .58567 L F
0 g
.71745 .59047 m
.72604 .59706 L
s
.5063 .80919 m .50527 .80652 L .50312 .8072 L .692 .759 .904 r
F
.50744 .80903 m .50527 .80652 L .5063 .80919 L F
.50744 .80903 m .50756 .80621 L .50527 .80652 L F
.5093 .8019 m .50715 .79902 L .50704 .80184 L .692 .759 .903 r
F
.5093 .8019 m .51055 .79912 L .50715 .79902 L F
.49981 .80945 m .49605 .80824 L .49465 .81036 L .692 .759 .904 r
F
0 g
.49411 .81258 m
.49465 .81036 L
s
.51666 .80316 m .5164 .80096 L .51372 .79976 L .861 .577 .506 r
F
0 g
.5164 .80096 m
.51842 .8026 L
s
.66751 .59526 m .66323 .58453 L .64937 .58866 L .683 .77 .917 r
F
.67732 .59397 m .66323 .58453 L .66751 .59526 L F
.50476 .80215 m .50374 .79949 L .50053 .80051 L .692 .759 .903 r
F
.50704 .80184 m .50374 .79949 L .50476 .80215 L F
.501 .806 m .49797 .80417 L .49579 .80604 L .692 .759 .904 r
F
.50286 .805 m .49797 .80417 L .501 .806 L F
.50704 .80184 m .50715 .79902 L .50374 .79949 L .692 .759 .903 r
F
.36551 .4677 m .35351 .45464 L .33758 .46224 L .673 .757 .914 r
F
.37777 .46442 m .35351 .45464 L .36551 .4677 L F
.50126 .8082 m .49605 .80824 L .49981 .80945 L .692 .759 .904 r
F
.24314 .70874 m .23439 .70276 L .23027 .70572 L .644 .733 .913 r
F
.24579 .70766 m .23439 .70276 L .24314 .70874 L F
.65878 .60259 m .64988 .59325 L .63785 .59929 L .683 .77 .917 r
F
.66802 .59984 m .64988 .59325 L .65878 .60259 L F
.40293 .58322 m .41593 .59056 L .42215 .58553 L F
.39894 .58524 m .41593 .59056 L .40293 .58322 L F
.26099 .70978 m .26496 .7021 L .25841 .70841 L .644 .733 .913 r
F
.26099 .70978 m .2701 .70486 L .26496 .7021 L F
.51167 .80453 m .51083 .80128 L .50957 .80408 L .692 .759 .904 r
F
.51167 .80453 m .51398 .80196 L .51083 .80128 L F
.67732 .59397 m .67796 .58259 L .66323 .58453 L .683 .77 .917 r
F
.24915 .70333 m .24615 .69573 L .24004 .69691 L .645 .732 .913 r
F
.2524 .70326 m .24615 .69573 L .24915 .70333 L F
.24081 .71399 m .23001 .7095 L .22736 .71307 L .644 .733 .913 r
F
.24287 .71251 m .23001 .7095 L .24081 .71399 L F
.25565 .70372 m .25267 .69559 L .2524 .70326 L .645 .732 .913 r
F
.25565 .70372 m .25915 .6965 L .25267 .69559 L F
.63246 .45612 m .66193 .45216 L .63787 .44863 L .673 .757 .914 r
F
.6111 .44884 m .63246 .45612 L .63787 .44863 L F
.26267 .71528 m .26984 .70864 L .26072 .71356 L .644 .733 .913 r
F
.26267 .71528 m .27374 .71206 L .26984 .70864 L F
.23001 .7095 m .21523 .71036 L .22736 .71307 L F
.51895 .807 m .51666 .80316 L .51692 .80536 L .934 .633 .447 r
F
0 g
.51895 .807 m
.52018 .80897 L
s
.51372 .80753 m .51424 .80416 L .51193 .80673 L .692 .759 .904 r
F
.51372 .80753 m .51692 .80536 L .51424 .80416 L F
0 g
.59358 .38132 m
.59364 .41264 L
s
.49823 .80637 m .49579 .80604 L .49605 .80824 L .391 .24 .553 r
F
.49823 .80637 m .49797 .80417 L .49579 .80604 L F
0 g
.49439 .80816 m
.49579 .80604 L
s
.23475 .69904 m .2199 .69751 L .23065 .70199 L .645 .732 .913 r
F
.58295 .36224 m .57564 .34207 L .56023 .34536 L .654 .726 .902 r
F
.59115 .36197 m .57564 .34207 L .58295 .36224 L F
.2192 .705 m .2155 .70658 L .21523 .71036 L .068 0 .397 r
F
.23027 .70572 m .21947 .70122 L .2155 .70658 L .644 .733 .913 r
F
.2192 .705 m .21947 .70122 L .2155 .70658 L .068 0 .397 r
F
0 g
.21401 .71249 m
.2155 .70658 L
s
.59929 .36309 m .59206 .34153 L .59115 .36197 L .654 .726 .902 r
F
.59929 .36309 m .60835 .34378 L .59206 .34153 L F
.27613 .71593 m .28481 .70885 L .27374 .71206 L .644 .733 .913 r
F
.27613 .71593 m .28839 .71465 L .28481 .70885 L F
.2524 .70326 m .25267 .69559 L .24615 .69573 L .645 .732 .913 r
F
0 g
.58702 .38098 m
.58708 .41252 L
s
.42101 .57632 m .44304 .57264 L .42502 .57066 L .683 .77 .917 r
F
.40499 .57152 m .42101 .57632 L .42502 .57066 L F
.27416 .70454 m .27935 .69622 L .27028 .70113 L .645 .732 .913 r
F
.27416 .70454 m .28517 .70134 L .27935 .69622 L F
.33792 .47346 m .32518 .47756 L .32548 .48325 L .384 .231 .546 r
F
.33792 .47346 m .33762 .46777 L .32518 .47756 L F
0 g
.31716 .48884 m
.32518 .47756 L
s
.50286 .805 m .50076 .80268 L .49797 .80417 L .692 .759 .904 r
F
.50501 .80432 m .50076 .80268 L .50286 .805 L F
.37282 .57785 m .36201 .5888 L .37572 .58005 L .683 .77 .917 r
F
.37282 .57785 m .35621 .58441 L .36201 .5888 L F
.68019 .69223 m .68306 .69984 L .6892 .69866 L .645 .732 .913 r
F
.28865 .71087 m .28534 .7013 L .28507 .70507 L .989 .751 .481 r
F
.28839 .71465 m .28865 .71087 L .28507 .70507 L F
0 g
.28865 .71087 m
.28973 .71693 L
s
.50076 .80268 m .49771 .80197 L .49797 .80417 L .513 .326 .564 r
F
.50076 .80268 m .5005 .80048 L .49771 .80197 L F
0 g
.49553 .80384 m
.49771 .80197 L
s
.50957 .80408 m .50742 .80118 L .5073 .80401 L .692 .759 .904 r
F
.50957 .80408 m .51083 .80128 L .50742 .80118 L F
.33477 .58761 m .3396 .59096 L .34008 .59554 L .981 .69 .341 r
F
.33477 .58761 m .33429 .58303 L .3396 .59096 L F
.35267 .57912 m .3396 .59096 L .35621 .58441 L .683 .77 .917 r
F
.35267 .57912 m .33429 .58303 L .3396 .59096 L F
0 g
.3396 .59096 m
.34375 .59409 L
s
.64344 .70183 m .64946 .70319 L .64922 .70697 L .927 .677 .54 r
F
.64344 .70183 m .64368 .69805 L .64946 .70319 L F
.65481 .69484 m .64946 .70319 L .65866 .69827 L .645 .732 .913 r
F
.65481 .69484 m .64368 .69805 L .64946 .70319 L F
0 g
.64946 .70319 m
.65286 .70503 L
s
.35533 .48403 m .33792 .47346 L .32548 .48325 L .673 .757 .914 r
F
0 g
.31746 .49453 m
.32548 .48325 L
s
.366 .47895 m .33792 .47346 L .35533 .48403 L .673 .757 .914 r
F
.51666 .80316 m .51372 .79976 L .51398 .80196 L .861 .577 .506 r
F
.51692 .80536 m .51666 .80316 L .51398 .80196 L F
0 g
.51666 .80316 m
.51868 .8048 L
s
.68756 .59881 m .67847 .58718 L .67783 .59855 L .683 .77 .917 r
F
.68756 .59881 m .69307 .58757 L .67847 .58718 L F
.54687 .35117 m .50956 .34746 L .53647 .35911 L .654 .726 .902 r
F
.50126 .8082 m .49823 .80637 L .49605 .80824 L .692 .759 .904 r
F
.127 .923 .03 r
.38426 .77118 m
.49725 8.79938 L
s
0 g
.49465 .81036 m
.49605 .80824 L
s
.50312 .8072 m .49823 .80637 L .50126 .8082 L .692 .759 .904 r
F
.41621 .47235 m .41137 .45447 L .40417 .46949 L .673 .757 .914 r
F
.41621 .47235 m .42944 .45877 L .41137 .45447 L F
.50501 .80432 m .50398 .80165 L .50076 .80268 L .692 .759 .904 r
F
.5073 .80401 m .50398 .80165 L .50501 .80432 L F
.70302 .70634 m .70952 .69812 L .70929 .7019 L .354 .18 .502 r
F
.70278 .71012 m .70302 .70634 L .70929 .7019 L F
.69437 .70036 m .70302 .70634 L .70929 .7019 L .645 .732 .913 r
F
.68902 .70251 m .70302 .70634 L .69437 .70036 L F
0 g
.69732 .70862 m
.70302 .70634 L
s
.54793 .33674 m .52633 .32119 L .51082 .33305 L .654 .726 .902 r
F
.56122 .33096 m .52633 .32119 L .54793 .33674 L F
.59115 .36197 m .59206 .34153 L .57564 .34207 L F
.5073 .80401 m .50742 .80118 L .50398 .80165 L .692 .759 .904 r
F
.51398 .80196 m .51372 .79976 L .51056 .79908 L .793 .527 .534 r
F
0 g
.51372 .79976 m
.5164 .80096 L
s
.64583 .36483 m .65919 .34256 L .63618 .35584 L .654 .726 .902 r
F
.64583 .36483 m .67365 .35605 L .65919 .34256 L F
.24579 .70766 m .23971 .70062 L .23439 .70276 L .644 .733 .913 r
F
.24886 .70707 m .23971 .70062 L .24579 .70766 L F
0 g
.59364 .41264 m
.59368 .43198 L
s
.63678 .34139 m .64058 .31744 L .62406 .33424 L .654 .726 .902 r
F
.63678 .34139 m .65966 .32817 L .64058 .31744 L F
.51193 .80673 m .51109 .80348 L .50983 .80628 L .692 .759 .904 r
F
.51193 .80673 m .51424 .80416 L .51109 .80348 L F
.25841 .70841 m .25892 .7002 L .2554 .70746 L .644 .733 .913 r
F
.25841 .70841 m .26496 .7021 L .25892 .7002 L F
0 g
.58708 .41252 m
.5871 .42652 L
s
.58713 .43975 m
.58713 .43996 L
s
.54116 .4618 m .52359 .47724 L .54584 .46914 L .673 .757 .914 r
F
.54116 .4618 m .51656 .46623 L .52359 .47724 L F
0 g
.52359 .47724 m
.53516 .48659 L
s
.64937 .58866 m .63684 .59013 L .63734 .59471 L .523 .344 .581 r
F
.64937 .58866 m .64887 .58408 L .63684 .59013 L F
0 g
.62746 .59766 m
.63684 .59013 L
s
.71796 .59505 m .70603 .58567 L .70654 .59025 L .861 .591 .528 r
F
0 g
.71796 .59505 m
.72656 .60164 L
s
.40379 .46395 m .39149 .44779 L .39082 .46314 L .673 .757 .914 r
F
.40379 .46395 m .41095 .44901 L .39149 .44779 L F
.50312 .8072 m .50102 .80488 L .49823 .80637 L .692 .759 .904 r
F
.50527 .80652 m .50102 .80488 L .50312 .8072 L F
.5681 .46104 m .55355 .47538 L .57196 .46416 L .673 .757 .914 r
F
.5681 .46104 m .54584 .46914 L .55355 .47538 L F
.24287 .71251 m .23413 .70654 L .23001 .7095 L .644 .733 .913 r
F
.24552 .71144 m .23413 .70654 L .24287 .71251 L F
.26072 .71356 m .26469 .70588 L .25815 .71218 L F
.26072 .71356 m .26984 .70864 L .26469 .70588 L F
.50398 .80165 m .5005 .80048 L .50076 .80268 L .599 .387 .564 r
F
.50398 .80165 m .50372 .79945 L .5005 .80048 L F
0 g
.49771 .80197 m
.5005 .80048 L
s
.67668 .69612 m .67629 .70383 L .68285 .70369 L .645 .732 .913 r
F
.50102 .80488 m .49797 .80417 L .49823 .80637 L .513 .326 .564 r
F
0 g
.49605 .80824 m
.49823 .80637 L
s
.50102 .80488 m .50076 .80268 L .49797 .80417 L .513 .326 .564 r
F
0 g
.49579 .80604 m
.49797 .80417 L
s
.50983 .80628 m .50768 .80338 L .50756 .80621 L .692 .759 .904 r
F
.50983 .80628 m .51109 .80348 L .50768 .80338 L F
.66802 .59984 m .66374 .58912 L .64988 .59325 L .683 .77 .917 r
F
.67783 .59855 m .66374 .58912 L .66802 .59984 L F
.4438 .57725 m .44331 .57267 L .44565 .56373 L 0 0 .385 r
F
0 g
.43956 .57795 m
.44331 .57267 L
s
.42502 .57066 m .44304 .57264 L .44537 .56374 L .683 .77 .917 r
F
.24886 .70707 m .24585 .69943 L .23971 .70062 L .644 .733 .913 r
F
.25214 .707 m .24585 .69943 L .24886 .70707 L F
.51692 .80536 m .51398 .80196 L .51424 .80416 L .861 .577 .506 r
F
0 g
.51692 .80536 m
.51895 .807 L
s
.2554 .70746 m .2524 .69929 L .25214 .707 L .644 .733 .913 r
F
.2554 .70746 m .25892 .7002 L .2524 .69929 L F
.51083 .80128 m .51056 .79908 L .50716 .79898 L .731 .481 .55 r
F
.51398 .80196 m .51056 .79908 L .51083 .80128 L .793 .527 .534 r
F
0 g
.51056 .79908 m
.51372 .79976 L
s
.50527 .80652 m .50424 .80386 L .50102 .80488 L .692 .759 .904 r
F
.50756 .80621 m .50424 .80386 L .50527 .80652 L F
.50756 .80621 m .50768 .80338 L .50424 .80386 L F
.23439 .70276 m .21947 .70122 L .23027 .70572 L .644 .733 .913 r
F
.67783 .59855 m .67847 .58718 L .66374 .58912 L .683 .77 .917 r
F
.23001 .7095 m .2192 .705 L .21523 .71036 L .644 .733 .913 r
F
0 g
.21374 .71626 m
.21523 .71036 L
s
.68326 .69164 m .6892 .69866 L .69453 .69653 L .645 .732 .913 r
F
.68019 .69223 m .6892 .69866 L .68326 .69164 L F
.25214 .707 m .2524 .69929 L .24585 .69943 L .644 .733 .913 r
F
.51424 .80416 m .51398 .80196 L .51083 .80128 L .793 .527 .534 r
F
0 g
.51398 .80196 m
.51666 .80316 L
s
.67042 .69472 m .66377 .70102 L .66978 .70292 L .645 .732 .913 r
F
.274 .70829 m .27922 .69993 L .2701 .70486 L .644 .733 .913 r
F
.274 .70829 m .28507 .70507 L .27922 .69993 L F
.67996 .69605 m .68285 .70369 L .68902 .70251 L .645 .732 .913 r
F
.67668 .69612 m .68285 .70369 L .67996 .69605 L F
.50742 .80118 m .50372 .79945 L .50398 .80165 L .668 .436 .56 r
F
.50742 .80118 m .50716 .79898 L .50372 .79945 L F
0 g
.5005 .80048 m
.50372 .79945 L
s
.28839 .71465 m .28507 .70507 L .28481 .70885 L .989 .751 .481 r
F
0 g
.28839 .71465 m
.28946 .72071 L
s
.42166 .58095 m .4438 .57725 L .42569 .57526 L .683 .77 .917 r
F
.40556 .57613 m .42166 .58095 L .42569 .57526 L F
.51083 .80128 m .50716 .79898 L .50742 .80118 L .731 .481 .55 r
F
0 g
.50372 .79945 m
.50716 .79898 L
s
.50716 .79898 m
.51056 .79908 L
s
.66262 .4579 m .66229 .45221 L .66552 .44019 L 0 0 .329 r
F
0 g
.6577 .45856 m
.66229 .45221 L
s
.65457 .69861 m .64922 .70697 L .65842 .70204 L .645 .732 .913 r
F
.127 .923 .03 r
.65965 .65568 m
.65976 .65206 L
s
.65457 .69861 m .64344 .70183 L .64922 .70697 L .645 .732 .913 r
F
0 g
.64922 .70697 m
.65688 .71111 L
s
.37777 .46442 m .3719 .44972 L .35351 .45464 L .673 .757 .914 r
F
.39082 .46314 m .3719 .44972 L .37777 .46442 L F
.63787 .44863 m .66193 .45216 L .66514 .44019 L F
.52557 .32825 m .51042 .33288 L .50999 .34017 L .338 .16 .486 r
F
.52557 .32825 m .526 .32096 L .51042 .33288 L F
0 g
.50035 .34717 m
.51042 .33288 L
s
.37331 .58244 m .36249 .59338 L .37621 .58463 L .683 .77 .917 r
F
.37331 .58244 m .35669 .58899 L .36249 .59338 L F
.3657 .47326 m .35363 .46014 L .33762 .46777 L .673 .757 .914 r
F
.37801 .46996 m .35363 .46014 L .3657 .47326 L F
.633 .46188 m .66262 .4579 L .63844 .45435 L F
.61153 .45456 m .633 .46188 L .63844 .45435 L F
.60735 .45783 m .633 .46188 L .61153 .45456 L F
.70278 .71012 m .70929 .7019 L .70905 .70568 L .354 .18 .502 r
F
.69414 .70414 m .70278 .71012 L .70905 .70568 L .645 .732 .913 r
F
.68878 .70628 m .70278 .71012 L .69414 .70414 L F
0 g
.69475 .71333 m
.70278 .71012 L
s
.35315 .5837 m .34008 .59554 L .35669 .58899 L .683 .77 .917 r
F
.35315 .5837 m .33477 .58761 L .34008 .59554 L F
0 g
.34008 .59554 m
.34879 .60213 L
s
.50424 .80386 m .50076 .80268 L .50102 .80488 L .599 .387 .564 r
F
.50424 .80386 m .50398 .80165 L .50076 .80268 L F
0 g
.49797 .80417 m
.50076 .80268 L
s
.49823 .80637 m
.50102 .80488 L
s
.24552 .71144 m .23944 .70439 L .23413 .70654 L .644 .733 .913 r
F
.24859 .71085 m .23944 .70439 L .24552 .71144 L F
.25815 .71218 m .25865 .70398 L .25513 .71123 L F
.25815 .71218 m .26469 .70588 L .25865 .70398 L F
.67406 .34875 m .67446 .34146 L .66001 .32797 L .93 .67 .523 r
F
0 g
.6116 .2529 m
.61685 .25952 L
s
.67446 .34146 m
.68322 .35673 L
s
.39082 .46314 m .39149 .44779 L .3719 .44972 L .673 .757 .914 r
F
.56524 .44597 m .54542 .45769 L .56757 .44962 L F
.56524 .44597 m .54076 .45038 L .54542 .45769 L F
.51109 .80348 m .51083 .80128 L .50742 .80118 L .731 .481 .55 r
F
.51424 .80416 m .51083 .80128 L .51109 .80348 L .793 .527 .534 r
F
0 g
.51083 .80128 m
.51398 .80196 L
s
.51424 .80416 m
.51692 .80536 L
s
.127 .923 .03 r
.51381 1.04391 m
.51769 .78128 L
s
.44481 .46584 m .4445 .46015 L .42913 .45308 L .86 .596 .538 r
F
0 g
.4445 .46015 m
.4561 .46951 L
s
.64988 .59325 m .63734 .59471 L .63785 .59929 L .523 .344 .581 r
F
0 g
.62846 .60683 m
.63785 .59929 L
s
.64988 .59325 m .64937 .58866 L .63734 .59471 L .523 .344 .581 r
F
0 g
.62796 .60224 m
.63734 .59471 L
s
.23475 .69904 m .22605 .69309 L .2199 .69751 L .645 .732 .913 r
F
.24004 .69691 m .22605 .69309 L .23475 .69904 L F
.127 .923 .03 r
.23514 .63557 m
.23631 .69589 L
s
.50768 .80338 m .50398 .80165 L .50424 .80386 L .668 .436 .56 r
F
.50768 .80338 m .50742 .80118 L .50398 .80165 L F
.127 .923 .03 r
.5021 3.59477 m
.50552 .772 L
s
0 g
.50076 .80268 m
.50398 .80165 L
s
.70603 .58567 m .70552 .58109 L .69205 .5784 L .794 .541 .555 r
F
0 g
.70552 .58109 m
.71694 .58589 L
s
.41652 .47803 m .41168 .46017 L .40448 .47518 L .673 .757 .914 r
F
.41652 .47803 m .42976 .46446 L .41168 .46017 L F
.27028 .70113 m .27168 .69211 L .26516 .69838 L .645 .732 .913 r
F
.27028 .70113 m .27935 .69622 L .27168 .69211 L F
.51109 .80348 m .50742 .80118 L .50768 .80338 L .731 .481 .55 r
F
0 g
.50398 .80165 m
.50742 .80118 L
s
.50742 .80118 m
.51083 .80128 L
s
.51109 .80348 m
.51424 .80416 L
s
.37066 .57061 m .35589 .57976 L .37242 .57324 L .683 .77 .917 r
F
.37066 .57061 m .35237 .5745 L .35589 .57976 L F
.24859 .71085 m .24558 .70321 L .23944 .70439 L .644 .733 .913 r
F
.25187 .71078 m .24558 .70321 L .24859 .71085 L F
.64018 .69225 m .64392 .69427 L .64368 .69805 L .99 .751 .473 r
F
.64018 .69225 m .64042 .68847 L .64392 .69427 L F
0 g
.64392 .69427 m
.64707 .69707 L
s
.25513 .71123 m .25214 .70307 L .25187 .71078 L .644 .733 .913 r
F
.25513 .71123 m .25865 .70398 L .25214 .70307 L F
.65284 .68718 m .64409 .69423 L .65516 .69103 L .645 .732 .913 r
F
.65284 .68718 m .6406 .68845 L .64409 .69423 L F
.68305 .69546 m .68902 .70251 L .69437 .70036 L F
.67996 .69605 m .68902 .70251 L .68305 .69546 L F
.23413 .70654 m .2192 .705 L .23001 .7095 L .644 .733 .913 r
F
.4438 .57725 m .44565 .56373 L .44614 .56831 L 0 0 .385 r
F
.44429 .58183 m .4438 .57725 L .44614 .56831 L F
.42569 .57526 m .4438 .57725 L .44614 .56831 L .683 .77 .917 r
F
0 g
.44005 .58254 m
.4438 .57725 L
s
.70929 .7019 m .70952 .69812 L .7136 .69277 L .088 0 .409 r
F
0 g
.70484 .70144 m
.70952 .69812 L
s
.25187 .71078 m .25214 .70307 L .24558 .70321 L .644 .733 .913 r
F
.69868 .69358 m .70936 .69806 L .71342 .69272 L .645 .732 .913 r
F
.69453 .69653 m .70936 .69806 L .69868 .69358 L F
0 g
.50102 .80488 m
.50424 .80386 L
s
.67018 .69849 m .66954 .7067 L .67319 .69944 L .645 .732 .913 r
F
.67018 .69849 m .66353 .7048 L .66954 .7067 L F
.27374 .71206 m .27896 .70371 L .26984 .70864 L .644 .733 .913 r
F
.27374 .71206 m .28481 .70885 L .27896 .70371 L F
.67972 .69983 m .68261 .70747 L .68878 .70628 L .645 .732 .913 r
F
.67644 .6999 m .68261 .70747 L .67972 .69983 L F
.22565 .69678 m .21974 .69744 L .21947 .70122 L .346 .172 .497 r
F
.127 .923 .03 r
.23902 1.54834 m
.24094 1.63885 L
s
.22565 .69678 m .22592 .69301 L .21974 .69744 L .346 .172 .497 r
F
0 g
.21577 .7028 m
.21974 .69744 L
s
.50768 .80338 m
.51109 .80348 L
s
.28507 .70507 m .28534 .7013 L .27949 .69615 L .925 .676 .544 r
F
0 g
.28534 .7013 m
.28892 .7071 L
s
.40417 .46949 m .39181 .45325 L .39114 .46867 L .673 .757 .914 r
F
.40417 .46949 m .41137 .45447 L .39181 .45325 L F
.66623 .68783 m .65516 .69103 L .659 .69444 L .645 .732 .913 r
F
.42215 .58553 m .44429 .58183 L .42618 .57985 L .683 .77 .917 r
F
.40604 .58071 m .42215 .58553 L .42618 .57985 L F
.40293 .58322 m .42215 .58553 L .40604 .58071 L F
.68592 .69058 m .69453 .69653 L .69868 .69358 L .645 .732 .913 r
F
.68326 .69164 m .69453 .69653 L .68592 .69058 L F
0 0 0 r
2.5 Mabswid
.37884 .58981 Mdot
0 g
.5 Mabswid
.50424 .80386 m
.50768 .80338 L
s
0 0 0 r
2.5 Mabswid
.37969 .58949 Mdot
.54729 .34388 m .52557 .32825 L .50999 .34017 L .654 .726 .902 r
F
.56065 .33806 m .52557 .32825 L .54729 .34388 L F
.6366 .34855 m .64042 .32448 L .62381 .34137 L F
.6366 .34855 m .6596 .33526 L .64042 .32448 L F
.66262 .4579 m .66552 .44019 L .66585 .44588 L 0 0 .329 r
F
.66296 .46359 m .66262 .4579 L .66585 .44588 L F
.63844 .45435 m .66262 .4579 L .66585 .44588 L .673 .757 .914 r
F
0 g
.5 Mabswid
.65803 .46425 m
.66262 .4579 L
s
.366 .47895 m .35393 .46583 L .33792 .47346 L .673 .757 .914 r
F
.37832 .47565 m .35393 .46583 L .366 .47895 L F
.23439 .70276 m .22565 .69678 L .21947 .70122 L .644 .733 .913 r
F
.23971 .70062 m .22565 .69678 L .23439 .70276 L F
.127 .923 .03 r
.23635 .69802 m
.23638 .69971 L
s
.37801 .46996 m .37212 .45518 L .35363 .46014 L .673 .757 .914 r
F
.39114 .46867 m .37212 .45518 L .37801 .46996 L F
.63333 .46756 m .66296 .46359 L .63877 .46004 L F
.61186 .46025 m .63333 .46756 L .63877 .46004 L F
.60768 .46352 m .63333 .46756 L .61186 .46025 L F
.2701 .70486 m .27151 .69579 L .26496 .7021 L .644 .733 .913 r
F
.2701 .70486 m .27922 .69993 L .27151 .69579 L F
.63993 .69602 m .64368 .69805 L .64344 .70183 L .99 .751 .473 r
F
.63993 .69602 m .64018 .69225 L .64368 .69805 L F
.65247 .69097 m .64368 .69805 L .65481 .69484 L .645 .732 .913 r
F
.65247 .69097 m .64018 .69225 L .64368 .69805 L F
0 g
.64368 .69805 m
.64683 .70085 L
s
.127 .923 .03 r
.622 3.66464 m
.67521 1.5185 L
s
.69651 .65933 m
.69815 .59316 L
s
.4947 8.79935 m
.622 3.66464 L
s
0 0 0 r
2.5 Mabswid
.69815 .59316 Mdot
.127 .923 .03 r
.5 Mabswid
.61162 2.99943 m
.67421 1.25904 L
s
.69577 .65955 m
.69815 .59316 L
s
.40215 8.82444 m
.61162 2.99943 L
s
.66763 .69711 m .66353 .7048 L .67018 .69849 L .645 .732 .913 r
F
.66763 .69711 m .65842 .70204 L .66353 .7048 L F
.70603 .58567 m .69205 .5784 L .69256 .58298 L .794 .541 .555 r
F
.70654 .59025 m .70603 .58567 L .69256 .58298 L F
0 g
.70603 .58567 m
.71745 .59047 L
s
.68281 .69923 m .68878 .70628 L .69414 .70414 L .645 .732 .913 r
F
.67972 .69983 m .68878 .70628 L .68281 .69923 L F
.37106 .57521 m .35621 .58441 L .37282 .57785 L .683 .77 .917 r
F
.37106 .57521 m .35267 .57912 L .35621 .58441 L F
.56544 .45168 m .54552 .46346 L .56778 .45535 L .673 .757 .914 r
F
.56544 .45168 m .54084 .45611 L .54552 .46346 L F
.70929 .7019 m .7136 .69277 L .71336 .69654 L .088 0 .409 r
F
.70905 .70568 m .70929 .7019 L .71336 .69654 L F
.69855 .6974 m .70929 .7019 L .71336 .69654 L .645 .732 .913 r
F
.69437 .70036 m .70929 .7019 L .69855 .6974 L F
0 g
.7046 .70522 m
.70929 .7019 L
s
.42502 .57066 m .44537 .56374 L .42657 .56473 L .683 .77 .917 r
F
.40699 .56869 m .42502 .57066 L .42657 .56473 L F
.40499 .57152 m .42502 .57066 L .40699 .56869 L F
.22538 .70056 m .21947 .70122 L .2192 .705 L .346 .172 .497 r
F
.22538 .70056 m .22565 .69678 L .21947 .70122 L F
0 g
.2155 .70658 m
.21947 .70122 L
s
.24004 .69691 m .23398 .68989 L .22605 .69309 L .645 .732 .913 r
F
.24615 .69573 m .23398 .68989 L .24004 .69691 L F
.39114 .46867 m .39181 .45325 L .37212 .45518 L .673 .757 .914 r
F
.44481 .46584 m .42913 .45308 L .42944 .45877 L .86 .596 .538 r
F
.44512 .47152 m .44481 .46584 L .42944 .45877 L F
0 g
.44481 .46584 m
.45641 .47519 L
s
.44429 .58183 m .44614 .56831 L .44663 .57289 L 0 0 .385 r
F
.42618 .57985 m .44429 .58183 L .44663 .57289 L .683 .77 .917 r
F
0 g
.43825 .59035 m
.44429 .58183 L
s
.26516 .69838 m .26266 .68927 L .25915 .6965 L .645 .732 .913 r
F
.26516 .69838 m .27168 .69211 L .26266 .68927 L F
.28507 .70507 m .27949 .69615 L .27922 .69993 L .925 .676 .544 r
F
.28481 .70885 m .28507 .70507 L .27922 .69993 L F
0 g
.28507 .70507 m
.28865 .71087 L
s
.66594 .69162 m .65866 .69827 L .66787 .69334 L .645 .732 .913 r
F
.66594 .69162 m .65481 .69484 L .65866 .69827 L F
.68573 .69438 m .69437 .70036 L .69855 .6974 L F
.68305 .69546 m .69437 .70036 L .68573 .69438 L F
.66323 .58453 m .64887 .58408 L .64937 .58866 L .606 .404 .582 r
F
.66323 .58453 m .66272 .57995 L .64887 .58408 L F
0 g
.63684 .59013 m
.64887 .58408 L
s
.127 .923 .03 r
.66199 .58168 m
.66213 .57731 L
s
.52515 .33555 m .50999 .34017 L .50956 .34746 L .338 .16 .486 r
F
.52515 .33555 m .52557 .32825 L .50999 .34017 L F
0 g
.49991 .35446 m
.50999 .34017 L
s
.67406 .34875 m .66001 .32797 L .6596 .33526 L .93 .67 .523 r
F
.67365 .35605 m .67406 .34875 L .6596 .33526 L F
0 g
.67406 .34875 m
.68282 .36402 L
s
.56122 .33096 m .54627 .31251 L .52633 .32119 L .654 .726 .902 r
F
.57656 .32768 m .54627 .31251 L .56122 .33096 L F
.35363 .46014 m .33732 .46208 L .33762 .46777 L .514 .328 .566 r
F
.35363 .46014 m .35333 .45445 L .33732 .46208 L F
0 g
.32488 .47187 m
.33732 .46208 L
s
.40448 .47518 m .39212 .45894 L .39144 .47436 L .673 .757 .914 r
F
.40448 .47518 m .41168 .46017 L .39212 .45894 L F
.62406 .33424 m .61811 .31014 L .60909 .32939 L .654 .726 .902 r
F
.62406 .33424 m .64058 .31744 L .61811 .31014 L F
.23413 .70654 m .22538 .70056 L .2192 .705 L .644 .733 .913 r
F
0 g
.21523 .71036 m
.2192 .705 L
s
.23944 .70439 m .22538 .70056 L .23413 .70654 L .644 .733 .913 r
F
.127 .923 .03 r
.23642 .70163 m
.23646 .70358 L
s
.26984 .70864 m .27124 .69957 L .26469 .70588 L .644 .733 .913 r
F
.26984 .70864 m .27896 .70371 L .27124 .69957 L F
.65223 .69474 m .64344 .70183 L .65457 .69861 L .645 .732 .913 r
F
.65223 .69474 m .63993 .69602 L .64344 .70183 L F
0 g
.64344 .70183 m
.64922 .70697 L
s
.33273 .57429 m .33381 .57845 L .33429 .58303 L .784 .568 0 r
F
.33273 .57429 m .33225 .56971 L .33381 .57845 L F
0 g
.33381 .57845 m
.33655 .58255 L
s
.35134 .5687 m .33408 .57839 L .35237 .5745 L .683 .77 .917 r
F
.35134 .5687 m .33253 .56969 L .33408 .57839 L F
.63787 .44863 m .66514 .44019 L .64 .44065 L .673 .757 .914 r
F
.6138 .44509 m .63787 .44863 L .64 .44065 L F
.6111 .44884 m .63787 .44863 L .6138 .44509 L F
.24615 .69573 m .24315 .68813 L .23398 .68989 L .645 .732 .913 r
F
.25267 .69559 m .24315 .68813 L .24615 .69573 L F
.25915 .6965 m .25293 .68791 L .25267 .69559 L F
.25915 .6965 m .26266 .68927 L .25293 .68791 L F
.70905 .70568 m .71336 .69654 L .71313 .70032 L .088 0 .409 r
F
.69831 .70118 m .70905 .70568 L .71313 .70032 L .645 .732 .913 r
F
.69414 .70414 m .70905 .70568 L .69831 .70118 L F
0 g
.70278 .71012 m
.70905 .70568 L
s
.51424 .44861 m .51592 .45485 L .51624 .46054 L .827 .624 .073 r
F
.51424 .44861 m .51392 .44292 L .51592 .45485 L F
0 g
.51592 .45485 m
.51921 .46001 L
s
.53944 .44246 m .51629 .45479 L .54076 .45038 L .673 .757 .914 r
F
.53944 .44246 m .5143 .44291 L .51629 .45479 L F
.127 .923 .03 r
.5306 .45795 m
.53066 .45475 L
s
.66507 .6859 m .65516 .69103 L .66623 .68783 L .645 .732 .913 r
F
.66507 .6859 m .65284 .68718 L .65516 .69103 L F
.70654 .59025 m .69256 .58298 L .69307 .58757 L .794 .541 .555 r
F
0 g
.70654 .59025 m
.71796 .59505 L
s
.69256 .58298 m .69205 .5784 L .67745 .57801 L .733 .497 .57 r
F
0 g
.69205 .5784 m
.70552 .58109 L
s
.37154 .57979 m .35669 .58899 L .37331 .58244 L .683 .77 .917 r
F
.37154 .57979 m .35315 .5837 L .35669 .58899 L F
.23971 .70062 m .23362 .69357 L .22565 .69678 L .644 .733 .913 r
F
.24585 .69943 m .23362 .69357 L .23971 .70062 L F
.66296 .46359 m .66585 .44588 L .66619 .45156 L 0 0 .329 r
F
.63877 .46004 m .66296 .46359 L .66619 .45156 L .673 .757 .914 r
F
0 g
.65479 .47487 m
.66296 .46359 L
s
.69868 .69358 m .71342 .69272 L .70138 .69003 L .645 .732 .913 r
F
.688 .6891 m .69868 .69358 L .70138 .69003 L F
.68592 .69058 m .69868 .69358 L .688 .6891 L F
.42569 .57526 m .44614 .56831 L .42725 .5693 L .683 .77 .917 r
F
.40757 .57328 m .42569 .57526 L .42725 .5693 L F
.40556 .57613 m .42569 .57526 L .40757 .57328 L F
.26496 .7021 m .26245 .69294 L .25892 .7002 L .644 .733 .913 r
F
.26496 .7021 m .27151 .69579 L .26245 .69294 L F
.28481 .70885 m .27922 .69993 L .27896 .70371 L .925 .676 .544 r
F
0 g
.28481 .70885 m
.28839 .71465 L
s
.37832 .47565 m .37242 .46087 L .35393 .46583 L .673 .757 .914 r
F
.39144 .47436 m .37242 .46087 L .37832 .47565 L F
.6657 .6954 m .65842 .70204 L .66763 .69711 L .645 .732 .913 r
F
.6657 .6954 m .65457 .69861 L .65842 .70204 L F
.127 .923 .03 r
.65668 .74956 m
.65823 .70071 L
s
.25267 .69559 m .25293 .68791 L .24315 .68813 L .645 .732 .913 r
F
.68549 .69816 m .69414 .70414 L .69831 .70118 L F
.68281 .69923 m .69414 .70414 L .68549 .69816 L F
.56577 .45737 m .54584 .46914 L .5681 .46104 L .673 .757 .914 r
F
.56577 .45737 m .54116 .4618 L .54584 .46914 L F
.66374 .58912 m .64937 .58866 L .64988 .59325 L .606 .404 .582 r
F
0 g
.63785 .59929 m
.64988 .59325 L
s
.66374 .58912 m .66323 .58453 L .64937 .58866 L .606 .404 .582 r
F
0 g
.63734 .59471 m
.64937 .58866 L
s
.127 .923 .03 r
.65988 .64843 m
.66185 .58606 L
s
.66185 .58606 m
.66199 .58168 L
s
0 0 0 r
2.5 Mabswid
.23649 .70524 Mdot
.127 .923 .03 r
.5 Mabswid
.23649 .70524 m
.23758 .76161 L
s
.2547 1.64738 m
.2565 1.74071 L
s
.2565 1.74071 m
.2599 1.91662 L
s
.2599 1.91662 m
.3934 8.82495 L
s
.39144 .47436 m .39212 .45894 L .37242 .46087 L .673 .757 .914 r
F
.44512 .47152 m .42944 .45877 L .42976 .46446 L .86 .596 .538 r
F
0 g
.44512 .47152 m
.45672 .48088 L
s
.54687 .35117 m .52515 .33555 L .50956 .34746 L .654 .726 .902 r
F
0 g
.49948 .36175 m
.50956 .34746 L
s
.56023 .34536 m .52515 .33555 L .54687 .35117 L .654 .726 .902 r
F
.63618 .35584 m .64001 .33178 L .6234 .34866 L F
.63618 .35584 m .65919 .34256 L .64001 .33178 L F
.23362 .69357 m .22592 .69301 L .22565 .69678 L .498 .296 .537 r
F
.23362 .69357 m .23389 .68979 L .22592 .69301 L F
0 g
.21974 .69744 m
.22592 .69301 L
s
.127 .923 .03 r
.22821 .68841 m
.22833 .69202 L
s
.22465 .62308 m
.22993 .69127 L
s
.27922 .69993 m .27949 .69615 L .27177 .69201 L .856 .609 .565 r
F
0 g
.27949 .69615 m
.28534 .7013 L
s
.67796 .58259 m .66272 .57995 L .66323 .58453 L .673 .453 .578 r
F
.67796 .58259 m .67745 .57801 L .66272 .57995 L F
0 g
.64887 .58408 m
.66272 .57995 L
s
.63918 .68618 m .64042 .68847 L .64018 .69225 L .921 .747 .26 r
F
.63918 .68618 m .63942 .6824 L .64042 .68847 L F
0 g
.64042 .68847 m
.64255 .692 L
s
.65218 .68315 m .6406 .68845 L .65284 .68718 L .645 .732 .913 r
F
.65218 .68315 m .63961 .68241 L .6406 .68845 L F
.24585 .69943 m .24284 .69179 L .23362 .69357 L .644 .733 .913 r
F
.2524 .69929 m .24284 .69179 L .24585 .69943 L F
.66477 .68968 m .65481 .69484 L .66594 .69162 L .645 .732 .913 r
F
.66477 .68968 m .65247 .69097 L .65481 .69484 L F
.25892 .7002 m .25267 .69158 L .2524 .69929 L .644 .733 .913 r
F
.25892 .7002 m .26245 .69294 L .25267 .69158 L F
.33321 .57888 m .33429 .58303 L .33477 .58761 L .784 .568 0 r
F
.33321 .57888 m .33273 .57429 L .33429 .58303 L F
.35164 .57329 m .33429 .58303 L .35267 .57912 L .683 .77 .917 r
F
.35164 .57329 m .33273 .57429 L .33429 .58303 L F
0 g
.33429 .58303 m
.33704 .58713 L
s
.37015 .56771 m .35237 .5745 L .37066 .57061 L .683 .77 .917 r
F
.37015 .56771 m .35134 .5687 L .35237 .5745 L F
.71336 .69654 m .7136 .69277 L .7152 .68685 L 0 0 .156 r
F
0 g
.7106 .6967 m
.7136 .69277 L
s
.69855 .6974 m .71336 .69654 L .70127 .69383 L .645 .732 .913 r
F
.68781 .6929 m .69855 .6974 L .70127 .69383 L F
.68573 .69438 m .69855 .6974 L .68781 .6929 L F
.70138 .69003 m .71342 .69272 L .71501 .68684 L F
.23944 .70439 m .23335 .69734 L .22538 .70056 L .644 .733 .913 r
F
.24558 .70321 m .23335 .69734 L .23944 .70439 L F
.69256 .58298 m .67745 .57801 L .67796 .58259 L .733 .497 .57 r
F
0 g
.66272 .57995 m
.67745 .57801 L
s
.67745 .57801 m
.69205 .5784 L
s
.35393 .46583 m .33762 .46777 L .33792 .47346 L .514 .328 .566 r
F
0 g
.32548 .48325 m
.33792 .47346 L
s
.35393 .46583 m .35363 .46014 L .33762 .46777 L .514 .328 .566 r
F
0 g
.32518 .47756 m
.33762 .46777 L
s
.26469 .70588 m .26218 .69672 L .25865 .70398 L .644 .733 .913 r
F
.26469 .70588 m .27124 .69957 L .26218 .69672 L F
.40699 .56869 m .42657 .56473 L .40776 .56572 L .683 .77 .917 r
F
.67933 .6903 m .68005 .68973 L .68005 .68996 L .359 .181 .499 r
F
.68022 .68972 m .68573 .69438 L .68781 .6929 L .645 .732 .913 r
F
.67707 .6884 m .67981 .69029 L .68022 .68972 L F
.67981 .69029 m .68573 .69438 L .68022 .68972 L F
.68005 .68973 m .68049 .68904 L .68049 .68935 L .082 0 .419 r
F
.67981 .69029 m .68305 .69546 L .68573 .69438 L .645 .732 .913 r
F
.67933 .6903 m .68005 .68996 L .67933 .69045 L .359 .181 .499 r
F
.67707 .6884 m .67928 .69101 L .67981 .69029 L .645 .732 .913 r
F
.67928 .69101 m .68305 .69546 L .67981 .69029 L F
.679 .69068 m .67996 .69605 L .68305 .69546 L F
.68005 .68996 m .6805 .69292 L .68009 .69349 L .082 0 .419 r
F
.68005 .68973 m .68007 .68992 L .68005 .68996 L F
.68007 .68992 m .6805 .69292 L .68005 .68996 L F
.68007 .68992 m .68049 .68935 L .6805 .69292 L F
.68005 .68973 m .68049 .68935 L .68007 .68992 L F
.68009 .69349 m .6805 .69292 L .68071 .7483 L F
.68052 .68918 m .68781 .6929 L .68917 .69112 L .645 .732 .913 r
F
.67707 .6884 m .68041 .6898 L .68052 .68918 L F
.68041 .6898 m .68781 .6929 L .68052 .68918 L F
.68049 .68904 m .68061 .68823 L .68061 .68862 L 0 0 .152 r
F
.6805 .6893 m .68061 .68862 L .68062 .69218 L F
.68049 .68904 m .68061 .68862 L .6805 .6893 L F
.68037 .69366 m .68549 .69816 L .68758 .69668 L .645 .732 .913 r
F
.6783 .69073 m .67838 .69436 L .67831 .69438 L .517 .303 .528 r
F
.67815 .69127 m .67996 .69605 L .679 .69068 L .645 .732 .913 r
F
.6783 .69073 m .67933 .6903 L .67935 .69402 L .517 .303 .528 r
F
.67944 .69399 m .67867 .69435 L .67984 .69426 L .645 .732 .913 r
F
.67861 .69428 m .67867 .69435 L .67944 .69399 L F
.67874 .69444 m .67888 .69516 L .6791 .69486 L F
.67888 .69516 m .67972 .69983 L .6791 .69486 L F
.6779 .69501 m .67972 .69983 L .67874 .69444 L F
.67838 .69436 m .67935 .69402 L .67956 .74955 L .517 .303 .528 r
F
.6783 .69073 m .67935 .69402 L .67838 .69436 L F
.6767 .69094 m .6783 .69073 L .67831 .69438 L .641 .401 .54 r
F
.67683 .69218 m .67861 .69428 L .67944 .69399 L .645 .732 .913 r
F
.67683 .69218 m .67944 .69399 L .68037 .69366 L F
.6805 .69292 m .68084 .74748 L .68071 .7483 L 0 0 .152 r
F
.68049 .68904 m .68051 .69287 L .6805 .69292 L F
.68051 .69287 m .68084 .74748 L .6805 .69292 L F
.67944 .69399 m .68023 .69453 L .68037 .69366 L .645 .732 .913 r
F
.68023 .69453 m .68549 .69816 L .68038 .69367 L F
.68023 .69453 m .68038 .69367 L .68037 .69366 L F
.67756 .74736 m .67852 .75 L .68067 .74932 L .692 .759 .904 r
F
.67752 .74733 m .67753 .74737 L .67756 .74736 L F
.67753 .74737 m .67852 .75 L .67756 .74736 L F
.67956 .74856 m .67887 .74921 L .6798 .74871 L F
.67851 .74691 m .67923 .74872 L .67852 .74905 L .517 .303 .528 r
F
.67638 .74749 m .67852 .75 L .67752 .74733 L .692 .759 .904 r
F
.67767 .74922 m .67665 .74971 L .67779 .74955 L F
.67691 .74721 m .67804 .74915 L .67692 .74936 L .641 .401 .54 r
F
.67678 .74687 m .67666 .74941 L .67767 .74922 L .692 .759 .904 r
F
.67666 .74941 m .67665 .74971 L .67767 .74922 L F
.67624 .75032 m .67953 .75267 L .67852 .75 L F
.67665 .74971 m .6788 .75223 L .67779 .74955 L F
.67692 .74936 m .67853 .74999 L .67693 .75019 L .641 .401 .54 r
F
.6787 .74902 m .67779 .74955 L .67887 .74921 L .692 .759 .904 r
F
.6785 .74906 m .67804 .74915 L .67691 .74721 L .641 .401 .54 r
F
.67678 .74687 m .67767 .74922 L .6787 .74902 L .692 .759 .904 r
F
.67767 .74922 m .67779 .74955 L .6787 .74902 L F
.67851 .74691 m .67752 .74733 L .67859 .747 L F
.67744 .74711 m .67752 .74733 L .67851 .74691 L F
.67843 .74692 m .6785 .74906 L .67691 .74721 L .641 .401 .54 r
F
.67852 .75 m .68275 .75165 L .68067 .74932 L .692 .759 .904 r
F
.67779 .74955 m .68096 .75155 L .67887 .74921 L F
.6785 .74906 m .67853 .74999 L .67804 .74915 L .641 .401 .54 r
F
.67804 .74915 m .67853 .74999 L .67692 .74936 L F
.6767 .69094 m .67843 .74692 L .67691 .74721 L F
.67651 .74467 m .67744 .74711 L .67851 .74691 L .692 .759 .904 r
F
.67678 .74687 m .67867 .74898 L .67956 .74856 L F
.67867 .74898 m .67887 .74921 L .67956 .74856 L F
.67852 .74905 m .67956 .74955 L .67853 .74999 L .517 .303 .528 r
F
.67887 .74921 m .68283 .75055 L .6798 .74871 L .692 .759 .904 r
F
.67923 .74872 m .67956 .74955 L .67852 .74905 L .517 .303 .528 r
F
.67831 .69438 m .67949 .74645 L .67851 .74691 L F
.67934 .74725 m .68067 .74932 L .68253 .74833 L .692 .759 .904 r
F
.67859 .747 m .67912 .74759 L .67934 .74725 L F
.67912 .74759 m .68067 .74932 L .67934 .74725 L F
.67933 .7466 m .68253 .74833 L .67952 .7465 L F
.67859 .747 m .67878 .74706 L .67933 .7466 L F
.67878 .74706 m .68253 .74833 L .67933 .7466 L F
.68025 .74799 m .6798 .74871 L .68053 .74808 L F
.67752 .74733 m .68067 .74932 L .67859 .747 L F
.67678 .74687 m .67956 .74856 L .68025 .74799 L F
.67956 .74856 m .6798 .74871 L .68025 .74799 L F
.67956 .74857 m .68027 .74898 L .67956 .74955 L .359 .181 .499 r
F
.67955 .74642 m .68004 .74816 L .67956 .74857 L F
.68004 .74816 m .68027 .74898 L .67956 .74857 L F
.68074 .69306 m .68758 .69668 L .68893 .6949 L .645 .732 .913 r
F
.67933 .6903 m .67939 .69399 L .67935 .69402 L .359 .181 .499 r
F
.67683 .69218 m .68006 .69353 L .68074 .69306 L .645 .732 .913 r
F
.68061 .68861 m .68917 .69112 L .6897 .68914 L F
.67707 .6884 m .6809 .68926 L .68061 .68861 L F
.6809 .68926 m .68917 .69112 L .68061 .68861 L F
.68061 .68823 m .68016 .68718 L .68017 .68764 L .982 .725 .331 r
F
.68057 .68852 m .68017 .68764 L .68018 .69121 L F
.68061 .68823 m .68017 .68764 L .68057 .68852 L F
.68006 .69353 m .68068 .74518 L .68026 .74583 L .082 0 .419 r
F
.68005 .68973 m .68009 .69349 L .68006 .69353 L F
.68009 .69349 m .68068 .74518 L .68006 .69353 L F
.68087 .69242 m .68893 .6949 L .68947 .69292 L .645 .732 .913 r
F
.67933 .69045 m .68006 .69353 L .67939 .69399 L .359 .181 .499 r
F
.67683 .69218 m .68045 .69299 L .68087 .69242 L .645 .732 .913 r
F
.68045 .69299 m .68893 .6949 L .68087 .69242 L F
.67867 .69435 m .68281 .69923 L .67984 .69426 L F
.68091 .69176 m .68947 .69292 L .68914 .6909 L F
.67933 .69045 m .68005 .68996 L .68006 .69353 L .359 .181 .499 r
F
.67683 .69218 m .68187 .69248 L .68091 .69176 L .645 .732 .913 r
F
.68187 .69248 m .68947 .69292 L .68091 .69176 L F
.67935 .69402 m .68022 .74586 L .67955 .74642 L .359 .181 .499 r
F
.6791 .69486 m .67956 .69856 L .68 .69592 L .645 .732 .913 r
F
.67956 .69856 m .67972 .69983 L .68 .69592 L F
.67939 .69399 m .68006 .69353 L .68027 .74898 L .359 .181 .499 r
F
.67651 .74467 m .68072 .74517 L .6809 .74443 L .692 .759 .904 r
F
.67651 .74467 m .6809 .74443 L .68079 .74371 L F
.68018 .69121 m .67933 .74561 L .68039 .74644 L .91 .629 .497 r
F
.68016 .68718 m .68011 .69115 L .68018 .69121 L F
.68011 .69115 m .67933 .74561 L .68018 .69121 L F
.68059 .69212 m .68018 .69121 L .68039 .74644 L .982 .725 .331 r
F
.68049 .68904 m .68062 .69218 L .68051 .69287 L 0 0 .152 r
F
.68061 .68823 m .68018 .69121 L .68059 .69212 L .982 .725 .331 r
F
.68006 .69353 m .68152 .69414 L .68074 .69306 L .645 .732 .913 r
F
.68152 .69414 m .68758 .69668 L .68111 .69325 L F
.68152 .69414 m .68111 .69325 L .68074 .69306 L F
.67939 .69399 m .68022 .74586 L .67935 .69402 L .359 .181 .499 r
F
.67952 .7465 m .68253 .74833 L .68398 .74708 L .692 .759 .904 r
F
.68022 .74586 m .68026 .74798 L .67955 .74642 L .359 .181 .499 r
F
.68026 .74583 m .68057 .74751 L .68027 .74797 L .082 0 .419 r
F
.67678 .74687 m .681 .74737 L .68119 .74663 L .692 .759 .904 r
F
.681 .74737 m .68101 .74737 L .68101 .74736 L F
.681 .74737 m .68101 .74736 L .68119 .74663 L F
.68026 .74798 m .68027 .74898 L .68004 .74816 L .359 .181 .499 r
F
.68026 .74798 m .68004 .74816 L .67955 .74642 L F
.68068 .74733 m .68053 .74808 L .68101 .74737 L .692 .759 .904 r
F
.67949 .74645 m .67956 .74955 L .67851 .74691 L .517 .303 .528 r
F
.67678 .74687 m .68026 .74799 L .68068 .74733 L .692 .759 .904 r
F
.68026 .74799 m .68053 .74808 L .68068 .74733 L F
.6798 .74871 m .68429 .74929 L .68053 .74808 L F
.68027 .74797 m .68071 .7483 L .68027 .74898 L .082 0 .419 r
F
.68057 .74751 m .68071 .7483 L .68027 .74797 L F
.67952 .7465 m .68398 .74708 L .68025 .74587 L .692 .759 .904 r
F
.68068 .74518 m .6807 .7473 L .68026 .74583 L .082 0 .419 r
F
.67678 .74687 m .68114 .74663 L .68108 .7459 L .692 .759 .904 r
F
.68114 .74663 m .68119 .74663 L .68118 .74656 L F
.68114 .74663 m .68118 .74656 L .68108 .7459 L F
.6807 .7473 m .68071 .7483 L .68057 .74751 L .082 0 .419 r
F
.6807 .7473 m .68057 .74751 L .68026 .74583 L F
.67838 .69436 m .67956 .74955 L .67831 .69438 L .517 .303 .528 r
F
.68051 .69287 m .68062 .69218 L .68084 .74748 L 0 0 .152 r
F
.68062 .69218 m .68039 .74644 L .68084 .74748 L .982 .725 .331 r
F
.68061 .68823 m .68059 .69212 L .68062 .69218 L F
.68059 .69212 m .68039 .74644 L .68062 .69218 L F
.67984 .69426 m .68281 .69923 L .68367 .69889 L .645 .732 .913 r
F
.68236 .696 m .68367 .69889 L .68549 .69816 L F
.67984 .69426 m .68367 .69889 L .68236 .696 L F
.67683 .69218 m .67644 .6999 L .67972 .69983 L F
.67681 .6945 m .67831 .69438 L .67853 .74999 L .641 .401 .54 r
F
.6767 .69094 m .67831 .69438 L .67681 .6945 L F
.68 .69592 m .67972 .69983 L .68281 .69923 L .645 .732 .913 r
F
.67683 .69218 m .6779 .69501 L .67874 .69444 L F
.67707 .6884 m .67815 .69127 L .679 .69068 L F
.69307 .58757 m .69256 .58298 L .67796 .58259 L .733 .497 .57 r
F
0 g
.69256 .58298 m
.70603 .58567 L
s
.2524 .69929 m .25267 .69158 L .24284 .69179 L .644 .733 .913 r
F
.127 .923 .03 r
.66584 .68117 m
.66707 .62258 L
s
.42618 .57985 m .44663 .57289 L .42773 .57389 L .683 .77 .917 r
F
.40805 .57786 m .42618 .57985 L .42773 .57389 L F
.40604 .58071 m .42618 .57985 L .40805 .57786 L F
.63844 .45435 m .66585 .44588 L .64059 .44633 L .673 .757 .914 r
F
.61425 .4508 m .63844 .45435 L .64059 .44633 L F
.61153 .45456 m .63844 .45435 L .61425 .4508 L F
.51456 .4543 m .51624 .46054 L .51656 .46623 L .827 .624 .073 r
F
.51456 .4543 m .51424 .44861 L .51624 .46054 L F
.53951 .44815 m .51624 .46054 L .54084 .45611 L .673 .757 .914 r
F
.53951 .44815 m .51424 .44861 L .51624 .46054 L F
.127 .923 .03 r
.53051 .46372 m
.53057 .46021 L
s
0 g
.51624 .46054 m
.51953 .4657 L
s
.67365 .35605 m .6596 .33526 L .65919 .34256 L .93 .67 .523 r
F
0 g
.67365 .35605 m
.68241 .37132 L
s
.57656 .32768 m .56928 .30759 L .54627 .31251 L .654 .726 .902 r
F
.59288 .32715 m .56928 .30759 L .57656 .32768 L F
.23335 .69734 m .22565 .69678 L .22538 .70056 L .498 .296 .537 r
F
0 g
.2192 .705 m
.22538 .70056 L
s
.23335 .69734 m .23362 .69357 L .22565 .69678 L .498 .296 .537 r
F
.127 .923 .03 r
.22844 .69562 m
.23032 .75226 L
s
0 g
.21947 .70122 m
.22565 .69678 L
s
.127 .923 .03 r
.22833 .69202 m
.22844 .69562 L
s
.56458 .44201 m .54076 .45038 L .56524 .44597 L .673 .757 .914 r
F
.56458 .44201 m .53944 .44246 L .54076 .45038 L F
.60909 .32939 m .59379 .30678 L .59288 .32715 L .654 .726 .902 r
F
.60909 .32939 m .61811 .31014 L .59379 .30678 L F
.44614 .56831 m .44565 .56373 L .44413 .55498 L .778 .563 0 r
F
0 g
.44443 .5684 m
.44553 .56421 L
s
.42657 .56473 m .44537 .56374 L .44386 .55504 L .683 .77 .917 r
F
.56065 .33806 m .54562 .31952 L .52557 .32825 L .654 .726 .902 r
F
.57606 .33478 m .54562 .31952 L .56065 .33806 L F
.127 .923 .03 r
.22993 .69127 m
.23001 .69224 L
s
0 0 0 r
2.5 Mabswid
.22993 .69127 Mdot
.27922 .69993 m .27177 .69201 L .27151 .69579 L .856 .609 .565 r
F
.27896 .70371 m .27922 .69993 L .27151 .69579 L F
0 g
.5 Mabswid
.27922 .69993 m
.28507 .70507 L
s
.62381 .34137 m .61783 .31715 L .60876 .33649 L .654 .726 .902 r
F
.62381 .34137 m .64042 .32448 L .61783 .31715 L F
.63894 .68996 m .64018 .69225 L .63993 .69602 L .921 .747 .26 r
F
.63894 .68996 m .63918 .68618 L .64018 .69225 L F
.65181 .68692 m .64018 .69225 L .65247 .69097 L .645 .732 .913 r
F
.65181 .68692 m .63918 .68618 L .64018 .69225 L F
0 g
.64018 .69225 m
.64231 .69578 L
s
.24558 .70321 m .24257 .69557 L .23335 .69734 L .644 .733 .913 r
F
.25214 .70307 m .24257 .69557 L .24558 .70321 L F
.66453 .69346 m .65457 .69861 L .6657 .6954 L .645 .732 .913 r
F
.66453 .69346 m .65223 .69474 L .65457 .69861 L F
.25865 .70398 m .2524 .69535 L .25214 .70307 L .644 .733 .913 r
F
.25865 .70398 m .26218 .69672 L .2524 .69535 L F
.42944 .45877 m .42913 .45308 L .41106 .44879 L .794 .544 .558 r
F
0 g
.42913 .45308 m
.4445 .46015 L
s
.67847 .58718 m .66323 .58453 L .66374 .58912 L .673 .453 .578 r
F
0 g
.64988 .59325 m
.66374 .58912 L
s
.67847 .58718 m .67796 .58259 L .66323 .58453 L .673 .453 .578 r
F
0 g
.64937 .58866 m
.66323 .58453 L
s
.71336 .69654 m .7152 .68685 L .71497 .69063 L 0 0 .156 r
F
.71313 .70032 m .71336 .69654 L .71497 .69063 L F
.70127 .69383 m .71336 .69654 L .71497 .69063 L .645 .732 .913 r
F
0 g
.71037 .70048 m
.71336 .69654 L
s
.66474 .68389 m .65284 .68718 L .66507 .6859 L .645 .732 .913 r
F
.66474 .68389 m .65218 .68315 L .65284 .68718 L F
.127 .923 .03 r
.66349 .68381 m
.66544 .62321 L
s
.69831 .70118 m .71313 .70032 L .70103 .69761 L .645 .732 .913 r
F
.68758 .69668 m .69831 .70118 L .70103 .69761 L F
.68549 .69816 m .69831 .70118 L .68758 .69668 L F
.35212 .57788 m .33477 .58761 L .35315 .5837 L .683 .77 .917 r
F
.35212 .57788 m .33321 .57888 L .33477 .58761 L F
0 g
.33477 .58761 m
.34008 .59554 L
s
.70138 .69003 m .71501 .68684 L .70245 .6861 L .645 .732 .913 r
F
.68935 .68733 m .70138 .69003 L .70245 .6861 L F
.688 .6891 m .70138 .69003 L .68935 .68733 L F
.37054 .5723 m .35267 .57912 L .37106 .57521 L .683 .77 .917 r
F
.37054 .5723 m .35164 .57329 L .35267 .57912 L F
.25214 .70307 m .2524 .69535 L .24257 .69557 L .644 .733 .913 r
F
.69307 .58757 m .67796 .58259 L .67847 .58718 L .733 .497 .57 r
F
0 g
.66323 .58453 m
.67796 .58259 L
s
.67796 .58259 m
.69256 .58298 L
s
.69307 .58757 m
.70654 .59025 L
s
.42657 .56473 m .44386 .55504 L .42555 .55893 L .683 .77 .917 r
F
.40776 .56572 m .42657 .56473 L .42555 .55893 L F
.40757 .57328 m .42725 .5693 L .40834 .5703 L F
0 g
.67847 .58718 m
.69307 .58757 L
s
.59288 .32715 m .59379 .30678 L .56928 .30759 L .654 .726 .902 r
F
.6138 .44509 m .64 .44065 L .61486 .4411 L .673 .757 .914 r
F
.63877 .46004 m .66619 .45156 L .64092 .45202 L F
.61458 .45649 m .63877 .46004 L .64092 .45202 L F
.61186 .46025 m .63877 .46004 L .61458 .45649 L F
.24284 .69179 m .23389 .68979 L .23362 .69357 L .596 .379 .557 r
F
.24284 .69179 m .24311 .68801 L .23389 .68979 L F
0 g
.22592 .69301 m
.23389 .68979 L
s
0 0 0 r
2.5 Mabswid
.53048 .46566 Mdot
.40776 .56572 m .42555 .55893 L .40725 .56283 L .683 .77 .917 r
F
.27896 .70371 m .27151 .69579 L .27124 .69957 L .856 .609 .565 r
F
0 g
.5 Mabswid
.27896 .70371 m
.28481 .70885 L
s
.27151 .69579 m .27177 .69201 L .26272 .68916 L .793 .551 .571 r
F
0 g
.27177 .69201 m
.27949 .69615 L
s
.53983 .45384 m .51656 .46623 L .54116 .4618 L .673 .757 .914 r
F
.53983 .45384 m .51456 .4543 L .51656 .46623 L F
0 g
.51656 .46623 m
.52359 .47724 L
s
.127 .923 .03 r
.5295 .52788 m
.53048 .46566 L
s
.65157 .6907 m .63993 .69602 L .65223 .69474 L .645 .732 .913 r
F
.65157 .6907 m .63894 .68996 L .63993 .69602 L F
0 g
.63993 .69602 m
.64344 .70183 L
s
.44614 .56831 m .44413 .55498 L .44462 .55956 L .778 .563 0 r
F
.127 .923 .03 r
.51763 1.28238 m
.5295 .52788 L
s
.39896 8.82367 m
.51763 1.28238 L
s
.42725 .5693 m .44614 .56831 L .44462 .55956 L .683 .77 .917 r
F
.44663 .57289 m .44614 .56831 L .44462 .55956 L .778 .563 0 r
F
0 g
.44492 .57298 m
.44602 .56879 L
s
.66444 .68766 m .65247 .69097 L .66477 .68968 L .645 .732 .913 r
F
.66444 .68766 m .65181 .68692 L .65247 .69097 L F
.127 .923 .03 r
.66337 .6876 m
.6634 .68656 L
s
.71313 .70032 m .71497 .69063 L .71473 .69441 L 0 0 .156 r
F
.70103 .69761 m .71313 .70032 L .71473 .69441 L .645 .732 .913 r
F
0 g
.70905 .70568 m
.71313 .70032 L
s
.70127 .69383 m .71497 .69063 L .70233 .68989 L .645 .732 .913 r
F
.68917 .69112 m .70127 .69383 L .70233 .68989 L F
.68781 .6929 m .70127 .69383 L .68917 .69112 L F
0 g
.66374 .58912 m
.67847 .58718 L
s
.56478 .4477 m .54084 .45611 L .56544 .45168 L .673 .757 .914 r
F
.56478 .4477 m .53951 .44815 L .54084 .45611 L F
.68935 .68733 m .70245 .6861 L .68988 .68536 L .645 .732 .913 r
F
.37102 .57688 m .35315 .5837 L .37154 .57979 L .683 .77 .917 r
F
.37102 .57688 m .35212 .57788 L .35315 .5837 L F
.38896 .56672 m .38457 .55603 L .37999 .5574 L F
.42725 .5693 m .44462 .55956 L .42623 .56348 L F
.40834 .5703 m .42725 .5693 L .42623 .56348 L F
.37212 .45518 m .35333 .45445 L .35363 .46014 L .602 .395 .573 r
F
.37212 .45518 m .37181 .44949 L .35333 .45445 L F
0 g
.33732 .46208 m
.35333 .45445 L
s
.40805 .57786 m .42773 .57389 L .40883 .57488 L .683 .77 .917 r
F
.42944 .45877 m .41106 .44879 L .41137 .45447 L .794 .544 .558 r
F
.42976 .46446 m .42944 .45877 L .41137 .45447 L F
0 g
.42944 .45877 m
.44481 .46584 L
s
.127 .923 .03 r
.23056 .69933 m
.23241 .75587 L
s
.26476 1.74237 m
.27283 1.98856 L
s
.27283 1.98856 m
.29224 2.58044 L
s
.29224 2.58044 m
.49617 8.79995 L
s
0 0 0 r
2.5 Mabswid
.23056 .69933 Mdot
.54562 .31952 m .526 .32096 L .52557 .32825 L .491 .283 .525 r
F
.54562 .31952 m .54604 .31223 L .526 .32096 L F
0 g
.5 Mabswid
.51042 .33288 m
.526 .32096 L
s
.44892 .31276 m
.54645 .27687 L
s
.66585 .44588 m .66552 .44019 L .66358 .42824 L .819 .617 .062 r
F
0 g
.66398 .44591 m
.66525 .44119 L
s
.24257 .69557 m .23362 .69357 L .23335 .69734 L .596 .379 .557 r
F
0 g
.22538 .70056 m
.23335 .69734 L
s
.24257 .69557 m .24284 .69179 L .23362 .69357 L .596 .379 .557 r
F
0 g
.22565 .69678 m
.23362 .69357 L
s
.64 .44065 m .66514 .44019 L .66321 .42831 L .673 .757 .914 r
F
.27151 .69579 m .26272 .68916 L .26245 .69294 L .793 .551 .571 r
F
.27124 .69957 m .27151 .69579 L .26245 .69294 L F
0 g
.27151 .69579 m
.27922 .69993 L
s
.37092 .56474 m .35134 .5687 L .37015 .56771 L .683 .77 .917 r
F
0 g
.67691 .74572 m
.67691 .74684 L
s
.6767 .69094 m
.67671 .69203 L
s
.6767 .69094 m
.6767 .69094 L
s
.127 .923 .03 r
.54569 4.88316 m
.69556 .76594 L
s
.69556 .76594 m
.697 .72623 L
s
.6596 .33526 m .66001 .32797 L .64083 .31718 L .859 .601 .547 r
F
0 g
.61685 .25952 m
.6414 .29048 L
s
.6414 .29048 m
.68699 .34799 L
s
.66001 .32797 m
.67446 .34146 L
s
.56023 .34536 m .54519 .32682 L .52515 .33555 L .654 .726 .902 r
F
.57564 .34207 m .54519 .32682 L .56023 .34536 L F
.57606 .33478 m .56875 .31458 L .54562 .31952 L F
.59248 .33424 m .56875 .31458 L .57606 .33478 L F
.60876 .33649 m .59338 .31377 L .59248 .33424 L F
.60876 .33649 m .61783 .31715 L .59338 .31377 L F
.40834 .5703 m .42623 .56348 L .40783 .56739 L .683 .77 .917 r
F
.6234 .34866 m .61742 .32445 L .60835 .34378 L .654 .726 .902 r
F
.6234 .34866 m .64001 .33178 L .61742 .32445 L F
.61425 .4508 m .64059 .44633 L .61532 .44679 L .673 .757 .914 r
F
.6642 .69144 m .65223 .69474 L .66453 .69346 L .645 .732 .913 r
F
.6642 .69144 m .65157 .6907 L .65223 .69474 L F
.127 .923 .03 r
.66324 .69138 m
.66328 .69016 L
s
.44663 .57289 m .44462 .55956 L .44511 .56415 L .778 .563 0 r
F
.42773 .57389 m .44663 .57289 L .44511 .56415 L .683 .77 .917 r
F
0 g
.44429 .58183 m
.44663 .57289 L
s
.25267 .69158 m .24311 .68801 L .24284 .69179 L .67 .442 .567 r
F
.25267 .69158 m .25294 .6878 L .24311 .68801 L F
0 g
.23389 .68979 m
.24311 .68801 L
s
.26245 .69294 m .26272 .68916 L .25294 .6878 L .733 .497 .571 r
F
0 g
.26272 .68916 m
.27177 .69201 L
s
.70103 .69761 m .71473 .69441 L .7021 .69366 L .645 .732 .913 r
F
.68893 .6949 m .70103 .69761 L .7021 .69366 L F
.68758 .69668 m .70103 .69761 L .68893 .6949 L F
.68917 .69112 m .70233 .68989 L .6897 .68914 L F
.64077 .68026 m .63942 .6824 L .63918 .68618 L 0 0 .151 r
F
0 g
.63971 .68419 m
.64005 .68623 L
s
.65323 .67922 m .64119 .67652 L .63961 .68241 L .645 .732 .913 r
F
.64077 .68026 m .64101 .67648 L .63942 .6824 L 0 0 .151 r
F
.65323 .67922 m .63961 .68241 L .65218 .68315 L .645 .732 .913 r
F
.66527 .68192 m .65218 .68315 L .66474 .68389 L F
.66527 .68192 m .65323 .67922 L .65218 .68315 L F
.64 .44065 m .66321 .42831 L .63871 .43273 L .673 .757 .914 r
F
.127 .923 .03 r
.65528 .42974 m
.65693 .3751 L
s
.61486 .4411 m .64 .44065 L .63871 .43273 L .673 .757 .914 r
F
.67731 .68462 m .67443 .67701 L .67136 .6776 L .645 .732 .913 r
F
0 g
.67358 .6837 m
.67358 .68428 L
s
.67731 .68462 m .6777 .67694 L .67443 .67701 L .645 .732 .913 r
F
.67731 .68462 m .68094 .67739 L .6777 .67694 L F
.68988 .68536 m .70179 .68207 L .68955 .68335 L F
.68988 .68536 m .70245 .6861 L .70179 .68207 L F
.70245 .6861 m .71404 .6808 L .70179 .68207 L F
.70245 .6861 m .71501 .68684 L .71404 .6808 L F
.71497 .69063 m .7152 .68685 L .71422 .68078 L .919 .745 .256 r
F
0 g
.71419 .69058 m
.71479 .68835 L
s
.35288 .56277 m .33253 .56969 L .35134 .5687 L .683 .77 .917 r
F
.37092 .56474 m .35288 .56277 L .35134 .5687 L F
.40725 .56283 m .42205 .55366 L .4055 .56019 L F
.40725 .56283 m .42555 .55893 L .42205 .55366 L F
.26245 .69294 m .25294 .6878 L .25267 .69158 L .733 .497 .571 r
F
0 g
.25294 .6878 m
.26272 .68916 L
s
.24311 .68801 m
.25294 .6878 L
s
.42773 .57389 m .44511 .56415 L .42672 .56806 L .683 .77 .917 r
F
.40883 .57488 m .42773 .57389 L .42672 .56806 L F
.59248 .33424 m .59338 .31377 L .56875 .31458 L .654 .726 .902 r
F
.56511 .45339 m .54116 .4618 L .56577 .45737 L .673 .757 .914 r
F
.56511 .45339 m .53983 .45384 L .54116 .4618 L F
.61486 .4411 m .63871 .43273 L .61422 .43714 L F
.27124 .69957 m .26245 .69294 L .26218 .69672 L .793 .551 .571 r
F
0 g
.27124 .69957 m
.27896 .70371 L
s
.35288 .56277 m .33483 .56079 L .33253 .56969 L .683 .77 .917 r
F
.33504 .56535 m .33225 .56971 L .33273 .57429 L 0 0 .38 r
F
0 g
.33293 .57352 m
.33306 .57427 L
s
.33504 .56535 m .33456 .56076 L .33225 .56971 L 0 0 .38 r
F
.37242 .46087 m .35363 .46014 L .35393 .46583 L .602 .395 .573 r
F
0 g
.33792 .47346 m
.35393 .46583 L
s
.37242 .46087 m .37212 .45518 L .35363 .46014 L .602 .395 .573 r
F
0 g
.33762 .46777 m
.35363 .46014 L
s
.41137 .45447 m .41106 .44879 L .3915 .44756 L .733 .496 .569 r
F
0 g
.41106 .44879 m
.42913 .45308 L
s
.42976 .46446 m .41137 .45447 L .41168 .46017 L .794 .544 .558 r
F
0 g
.42976 .46446 m
.44512 .47152 L
s
0 0 0 r
2.5 Mabswid
.66317 .69377 Mdot
.37131 .56932 m .35164 .57329 L .37054 .5723 L .683 .77 .917 r
F
.2524 .69535 m .24284 .69179 L .24257 .69557 L .67 .442 .567 r
F
0 g
.5 Mabswid
.23335 .69734 m
.24257 .69557 L
s
.2524 .69535 m .25267 .69158 L .24284 .69179 L .67 .442 .567 r
F
0 g
.23362 .69357 m
.24284 .69179 L
s
.26218 .69672 m .26245 .69294 L .25267 .69158 L .733 .497 .571 r
F
0 g
.26245 .69294 m
.27151 .69579 L
s
.40883 .57488 m .42672 .56806 L .40832 .57197 L .683 .77 .917 r
F
.68893 .6949 m .7021 .69366 L .68947 .69292 L .645 .732 .913 r
F
.64053 .68404 m .63918 .68618 L .63894 .68996 L 0 0 .151 r
F
0 g
.63947 .68796 m
.63981 .69001 L
s
.65287 .68297 m .64077 .68026 L .63918 .68618 L .645 .732 .913 r
F
.64053 .68404 m .64077 .68026 L .63918 .68618 L 0 0 .151 r
F
.65287 .68297 m .63918 .68618 L .65181 .68692 L .645 .732 .913 r
F
.58973 .44155 m .57783 .42847 L .5725 .43101 L .673 .757 .914 r
F
.58973 .44155 m .58397 .42683 L .57783 .42847 L F
0 g
.58713 .44118 m
.58713 .44403 L
s
.58973 .44155 m .597 .42659 L .59051 .42619 L .673 .757 .914 r
F
.66585 .44588 m .66358 .42824 L .66392 .43393 L .819 .617 .062 r
F
.64059 .44633 m .66585 .44588 L .66392 .43393 L .673 .757 .914 r
F
.66619 .45156 m .66585 .44588 L .66392 .43393 L .819 .617 .062 r
F
0 g
.66432 .4516 m
.66558 .44688 L
s
.66497 .68569 m .65181 .68692 L .66444 .68766 L .645 .732 .913 r
F
.66497 .68569 m .65287 .68297 L .65181 .68692 L F
.67707 .6884 m .67418 .68075 L .67109 .68135 L F
.67707 .6884 m .67746 .68068 L .67418 .68075 L F
.67707 .6884 m .68072 .68114 L .67746 .68068 L F
.67707 .6884 m .68373 .68209 L .68072 .68114 L F
.67707 .6884 m .68628 .68347 L .68373 .68209 L F
.68016 .68718 m .67911 .68636 L .67911 .68684 L .91 .629 .497 r
F
.6806 .68738 m .68938 .68712 L .68821 .68519 L .645 .732 .913 r
F
.67707 .6884 m .68201 .68789 L .6806 .68738 L F
.68201 .68789 m .68938 .68712 L .6806 .68738 L F
.68201 .68789 m .6897 .68914 L .68938 .68712 L F
.67707 .6884 m .68467 .68885 L .68201 .68789 L F
.68467 .68885 m .6897 .68914 L .68201 .68789 L F
.67911 .68636 m .67803 .68598 L .67803 .68645 L .81 .54 .531 r
F
.67707 .6884 m .68004 .68755 L .67947 .68712 L .645 .732 .913 r
F
.67911 .68636 m .67803 .68645 L .6791 .68684 L .81 .54 .531 r
F
.67911 .68636 m .6791 .68684 L .67911 .68684 L F
.67696 .68963 m .68048 .68492 L .67723 .68446 L .645 .732 .913 r
F
.67803 .68598 m .67694 .68585 L .67695 .68986 L .734 .477 .539 r
F
.67683 .69218 m .67793 .69 L .67695 .68986 L .645 .732 .913 r
F
.68016 .68763 m .67911 .68684 L .67912 .69041 L .91 .629 .497 r
F
.68083 .69103 m .68914 .6909 L .68797 .68896 L .645 .732 .913 r
F
.67683 .69218 m .68242 .6916 L .68083 .69103 L F
.68242 .6916 m .68914 .6909 L .68083 .69103 L F
.6791 .68684 m .67905 .69038 L .67911 .68684 L .81 .54 .531 r
F
.67905 .69038 m .67825 .74523 L .67906 .69039 L F
.67905 .69038 m .67906 .69039 L .67911 .68684 L F
.68011 .69115 m .67912 .69041 L .67933 .74561 L .91 .629 .497 r
F
.68016 .68763 m .67912 .69041 L .68011 .69115 L F
.67955 .69073 m .68083 .69103 L .67973 .69063 L .645 .732 .913 r
F
.67683 .69218 m .68019 .69121 L .67955 .69073 L F
.68019 .69121 m .68083 .69103 L .67955 .69073 L F
.67973 .69063 m .68797 .68896 L .68604 .68725 L F
.68083 .69103 m .68797 .68896 L .67973 .69063 L F
.67651 .74467 m .68025 .74587 L .68072 .74517 L .692 .759 .904 r
F
.67912 .69041 m .6783 .74241 L .67932 .74268 L .81 .54 .531 r
F
.6785 .74246 m .67971 .7425 L .67882 .7421 L .692 .759 .904 r
F
.67651 .74467 m .67942 .7427 L .6785 .74246 L F
.67942 .7427 m .67971 .7425 L .6785 .74246 L F
.67651 .74467 m .68079 .74371 L .68038 .74305 L F
.67932 .74268 m .67852 .74461 L .67933 .74482 L .81 .54 .531 r
F
.67876 .74467 m .68 .74469 L .6791 .74429 L .692 .759 .904 r
F
.67651 .74467 m .67952 .7465 L .68025 .74587 L F
.67678 .74687 m .67967 .74491 L .67876 .74467 L F
.67967 .74491 m .68 .74469 L .67876 .74467 L F
.67933 .74482 m .67825 .74523 L .67933 .74561 L .81 .54 .531 r
F
.67852 .74461 m .67825 .74523 L .67933 .74482 L F
.67651 .74467 m .68038 .74305 L .67971 .7425 L .692 .759 .904 r
F
.6783 .74241 m .67825 .74523 L .67932 .74268 L .81 .54 .531 r
F
.67911 .68684 m .67906 .69039 L .67912 .69041 L F
.67906 .69039 m .67825 .74523 L .67912 .69041 L F
.67797 .69001 m .67695 .68986 L .67716 .74511 L .734 .477 .539 r
F
.67803 .68598 m .67695 .68986 L .67797 .69001 L F
.67695 .68986 m .67794 .68998 L .67696 .68963 L .645 .732 .913 r
F
.67793 .69 m .67794 .68998 L .67695 .68986 L F
.6791 .68684 m .67803 .68645 L .67804 .69002 L .81 .54 .531 r
F
.67794 .68998 m .68048 .68492 L .67696 .68963 L .645 .732 .913 r
F
.67905 .69038 m .67804 .69002 L .67825 .74523 L .81 .54 .531 r
F
.6791 .68684 m .67804 .69002 L .67905 .69038 L F
.68016 .68718 m .67911 .68684 L .68016 .68763 L .91 .629 .497 r
F
.67947 .68712 m .68821 .68519 L .68628 .68347 L .645 .732 .913 r
F
.68004 .68755 m .68821 .68519 L .67947 .68712 L F
.6897 .68914 m .70168 .68584 L .68938 .68712 L F
.6897 .68914 m .70233 .68989 L .70168 .68584 L F
.70233 .68989 m .71399 .68456 L .70168 .68584 L F
.70233 .68989 m .71497 .69063 L .71399 .68456 L F
.71497 .69063 m .71422 .68078 L .71399 .68456 L .919 .745 .256 r
F
.71473 .69441 m .71497 .69063 L .71399 .68456 L F
0 g
.71395 .69436 m
.71456 .69213 L
s
.66662 .68014 m .65323 .67922 L .66527 .68192 L .645 .732 .913 r
F
0 0 0 r
2.5 Mabswid
.66559 .69307 Mdot
.68955 .68335 m .69947 .67822 L .68839 .68142 L .645 .732 .913 r
F
.68955 .68335 m .70179 .68207 L .69947 .67822 L F
.61458 .45649 m .64092 .45202 L .61565 .45248 L .673 .757 .914 r
F
.37292 .56191 m .35288 .56277 L .37092 .56474 L .683 .77 .917 r
F
.26218 .69672 m .25267 .69158 L .2524 .69535 L .733 .497 .571 r
F
0 g
.5 Mabswid
.25267 .69158 m
.26245 .69294 L
s
.26218 .69672 m
.27124 .69957 L
s
.24284 .69179 m
.25267 .69158 L
s
.35318 .56733 m .33273 .57429 L .35164 .57329 L .683 .77 .917 r
F
.37131 .56932 m .35318 .56733 L .35164 .57329 L F
.38993 .57588 m .37692 .56853 L .37381 .57105 L F
.38993 .57588 m .39531 .56462 L .39044 .56449 L F
.38993 .57588 m .40656 .56932 L .40366 .56712 L F
.40783 .56739 m .4227 .55818 L .40607 .56474 L F
.40783 .56739 m .42623 .56348 L .4227 .55818 L F
.42555 .55893 m .4386 .54713 L .42205 .55366 L F
.42555 .55893 m .44386 .55504 L .4386 .54713 L F
.39181 .45325 m .37181 .44949 L .37212 .45518 L .672 .448 .573 r
F
.39181 .45325 m .3915 .44756 L .37181 .44949 L F
0 g
.35333 .45445 m
.37181 .44949 L
s
.56564 .43802 m .53944 .44246 L .56458 .44201 L .673 .757 .914 r
F
.64059 .44633 m .66392 .43393 L .63929 .43837 L F
.61532 .44679 m .64059 .44633 L .63929 .43837 L F
0 g
.67381 .74588 m
.67381 .74632 L
s
.6738 .74373 m
.67381 .745 L
s
.67359 .68727 m
.6736 .68836 L
s
.54519 .32682 m .52557 .32825 L .52515 .33555 L .491 .283 .525 r
F
0 g
.50956 .34746 m
.52515 .33555 L
s
.54519 .32682 m .54562 .31952 L .52557 .32825 L .491 .283 .525 r
F
0 g
.50999 .34017 m
.52557 .32825 L
s
.25077 .78166 m .25052 .77946 L .25395 .77898 L .668 .436 .559 r
F
.24735 .78155 m .25052 .77946 L .25077 .78166 L .731 .481 .55 r
F
.24735 .78155 m .24711 .77935 L .25052 .77946 L F
.25061 .7766 m .25052 .77941 L .25394 .77894 L .692 .759 .903 r
F
.24835 .77653 m .24712 .77931 L .25052 .77941 L F
.2542 .78118 m .25395 .77898 L .25717 .77796 L .599 .386 .564 r
F
.25077 .78166 m .25395 .77898 L .2542 .78118 L .668 .436 .559 r
F
0 g
.25052 .77946 m
.25395 .77898 L
s
.25289 .77628 m .25394 .77894 L .25714 .77792 L .692 .759 .903 r
F
.6596 .33526 m .64083 .31718 L .64042 .32448 L .859 .601 .547 r
F
.65919 .34256 m .6596 .33526 L .64042 .32448 L F
0 g
.6596 .33526 m
.67406 .34875 L
s
.57564 .34207 m .56833 .32188 L .54519 .32682 L .654 .726 .902 r
F
.59206 .34153 m .56833 .32188 L .57564 .34207 L F
.60835 .34378 m .59297 .32107 L .59206 .34153 L F
.60835 .34378 m .61742 .32445 L .59297 .32107 L F
0 g
.24257 .69557 m
.2524 .69535 L
s
.33552 .56993 m .33273 .57429 L .33321 .57888 L 0 0 .38 r
F
0 g
.33341 .57811 m
.33354 .57886 L
s
.35318 .56733 m .33504 .56535 L .33273 .57429 L .683 .77 .917 r
F
.33552 .56993 m .33504 .56535 L .33273 .57429 L 0 0 .38 r
F
0 g
.2524 .69535 m
.26218 .69672 L
s
.4055 .56019 m .41628 .54928 L .40262 .558 L .683 .77 .917 r
F
.4055 .56019 m .42205 .55366 L .41628 .54928 L F
0 0 0 r
2.5 Mabswid
.4088 .4634 Mdot
.127 .923 .03 r
.5 Mabswid
.40871 .53138 m
.4088 .4634 L
s
.24419 .78088 m .24711 .77935 L .24735 .78155 L .793 .527 .535 r
F
.24419 .78088 m .24394 .77868 L .24711 .77935 L F
0 g
.24711 .77935 m
.25052 .77946 L
s
.3718 .5739 m .35212 .57788 L .37102 .57688 L .683 .77 .917 r
F
.24625 .77608 m .24712 .77931 L .24835 .77653 L .692 .759 .903 r
F
.24625 .77608 m .24398 .77864 L .24712 .77931 L F
.41137 .45447 m .3915 .44756 L .39181 .45325 L .733 .496 .569 r
F
0 g
.37181 .44949 m
.3915 .44756 L
s
.3915 .44756 m
.41106 .44879 L
s
.54155 .43448 m .5143 .44291 L .53944 .44246 L .673 .757 .914 r
F
.56564 .43802 m .54155 .43448 L .53944 .44246 L F
.61532 .44679 m .63929 .43837 L .61467 .44281 L F
.65263 .68675 m .63894 .68996 L .65157 .6907 L .645 .732 .913 r
F
.65263 .68675 m .64053 .68404 L .63894 .68996 L F
0 g
.63894 .68996 m
.63993 .69602 L
s
.66473 .68947 m .65157 .6907 L .6642 .69144 L .645 .732 .913 r
F
.66473 .68947 m .65263 .68675 L .65157 .6907 L F
.67793 .69 m .68349 .68587 L .68048 .68492 L F
.67683 .69218 m .67897 .69016 L .67793 .69 L F
.67897 .69016 m .68349 .68587 L .67793 .69 L F
.67804 .69002 m .67721 .74235 L .67824 .74239 L .734 .477 .539 r
F
.67756 .74236 m .67882 .7421 L .67778 .74188 L .692 .759 .904 r
F
.67651 .74467 m .67855 .7424 L .67756 .74236 L F
.67855 .7424 m .67882 .7421 L .67756 .74236 L F
.67721 .74235 m .67716 .74511 L .67824 .74239 L .734 .477 .539 r
F
.67689 .74448 m .67805 .74407 L .67692 .74403 L .692 .759 .904 r
F
.67651 .74467 m .67638 .74749 L .67752 .74733 L F
.67651 .74467 m .67859 .747 L .67952 .7465 L F
.67678 .74687 m .67785 .74452 L .67689 .74448 L F
.67824 .74239 m .6774 .7445 L .67825 .74454 L .734 .477 .539 r
F
.67785 .74452 m .67805 .74407 L .67689 .74448 L .692 .759 .904 r
F
.67678 .74687 m .6791 .74429 L .67805 .74407 L F
.67825 .74454 m .67716 .74511 L .67825 .74523 L .734 .477 .539 r
F
.6774 .7445 m .67716 .74511 L .67825 .74454 L F
.67803 .68598 m .67797 .69001 L .67804 .69002 L F
.67797 .69001 m .67716 .74511 L .67804 .69002 L F
.67694 .68585 m .67584 .68594 L .67585 .6899 L .66 .416 .54 r
F
.67597 .68989 m .67723 .68446 L .67394 .68453 L .645 .732 .913 r
F
.67683 .69218 m .67695 .68986 L .67597 .68989 L F
.67694 .68585 m .67585 .6899 L .67688 .68986 L .66 .416 .54 r
F
.67695 .68986 m .67723 .68446 L .67597 .68989 L .645 .732 .913 r
F
.67688 .68986 m .67585 .6899 L .67606 .74519 L .66 .416 .54 r
F
.67683 .69218 m .67394 .68453 L .67086 .68512 L .645 .732 .913 r
F
0 g
.67361 .69083 m
.6738 .74268 L
s
.67683 .69218 m .68604 .68725 L .68349 .68587 L .645 .732 .913 r
F
0 g
.68018 .69121 m
.68038 .74305 L
s
.25742 .78016 m .25717 .77796 L .25996 .77646 L .512 .324 .562 r
F
.2542 .78118 m .25717 .77796 L .25742 .78016 L .599 .386 .564 r
F
0 g
.25395 .77898 m
.25717 .77796 L
s
.68947 .69292 m .70144 .68962 L .68914 .6909 L .645 .732 .913 r
F
.68947 .69292 m .7021 .69366 L .70144 .68962 L F
.67571 .74255 m .67665 .74184 L .67551 .742 L .692 .759 .904 r
F
.67651 .74467 m .67662 .74242 L .67571 .74255 L F
.67694 .68585 m .6761 .7425 L .67715 .74234 L .66 .416 .54 r
F
.67662 .74242 m .67665 .74184 L .67571 .74255 L .692 .759 .904 r
F
.67651 .74467 m .67778 .74188 L .67665 .74184 L F
.6761 .7425 m .67606 .74519 L .67715 .74234 L .66 .416 .54 r
F
.67595 .74467 m .67692 .74403 L .67577 .74419 L .692 .759 .904 r
F
.67678 .74687 m .67689 .74453 L .67595 .74467 L F
.67715 .74234 m .67628 .74462 L .67716 .74449 L .66 .416 .54 r
F
.67689 .74453 m .67692 .74403 L .67595 .74467 L .692 .759 .904 r
F
.67716 .74449 m .67606 .74519 L .67716 .74511 L .66 .416 .54 r
F
.67628 .74462 m .67606 .74519 L .67716 .74449 L F
.25503 .7756 m .25714 .77792 L .25991 .77643 L .692 .759 .903 r
F
.7021 .69366 m .71375 .68834 L .70144 .68962 L .645 .732 .913 r
F
.7021 .69366 m .71473 .69441 L .71375 .68834 L F
.71473 .69441 m .71399 .68456 L .71375 .68834 L .919 .745 .256 r
F
0 g
.71313 .70032 m
.71473 .69441 L
s
.66633 .6839 m .65287 .68297 L .66497 .68569 L .645 .732 .913 r
F
.41168 .46017 m .41137 .45447 L .39181 .45325 L .733 .496 .569 r
F
0 g
.41137 .45447 m
.42944 .45877 L
s
.66662 .68014 m .65593 .67566 L .65323 .67922 L .645 .732 .913 r
F
.6687 .67867 m .65593 .67566 L .66662 .68014 L F
.68938 .68712 m .69935 .68197 L .68821 .68519 L F
.68938 .68712 m .70168 .68584 L .69935 .68197 L F
.68839 .68142 m .69564 .6748 L .68647 .67971 L F
.68839 .68142 m .69947 .67822 L .69564 .6748 L F
.65593 .67566 m .64119 .67652 L .65323 .67922 L F
.25102 .78386 m .25077 .78166 L .2542 .78118 L .668 .436 .559 r
F
.2476 .78375 m .25077 .78166 L .25102 .78386 L .731 .481 .55 r
F
.2476 .78375 m .24735 .78155 L .25077 .78166 L F
.25086 .77882 m .25077 .78166 L .2542 .78118 L .692 .759 .903 r
F
.24859 .77876 m .25077 .78166 L .25086 .77882 L F
.24859 .77876 m .24735 .78155 L .25077 .78166 L F
.70179 .68207 m .71056 .67502 L .69947 .67822 L .645 .732 .913 r
F
.70179 .68207 m .71404 .6808 L .71056 .67502 L F
.25445 .78338 m .2542 .78118 L .25742 .78016 L .599 .386 .564 r
F
.25102 .78386 m .2542 .78118 L .25445 .78338 L .668 .436 .559 r
F
.25315 .77851 m .2542 .78118 L .25742 .78016 L .692 .759 .903 r
F
.25086 .77882 m .2542 .78118 L .25315 .77851 L F
0 g
.25077 .78166 m
.2542 .78118 L
s
.54155 .43448 m .51745 .43094 L .5143 .44291 L .673 .757 .914 r
F
.37332 .56647 m .35318 .56733 L .37131 .56932 L .683 .77 .917 r
F
.5174 .43657 m .51392 .44292 L .51424 .44861 L 0 0 .322 r
F
0 g
.51463 .44713 m
.51487 .4486 L
s
.5174 .43657 m .51708 .43088 L .51392 .44292 L 0 0 .322 r
F
.24149 .77968 m .24394 .77868 L .24419 .78088 L .861 .577 .507 r
F
.127 .923 .03 r
.24933 1.36974 m
.2547 1.64738 L
s
.24149 .77968 m .24124 .77748 L .24394 .77868 L .861 .577 .507 r
F
0 g
.24394 .77868 m
.24711 .77935 L
s
.59005 .44724 m .58427 .43244 L .5781 .4341 L .673 .757 .914 r
F
.35366 .57191 m .33321 .57888 L .35212 .57788 L .683 .77 .917 r
F
.3718 .5739 m .35366 .57191 L .35212 .57788 L F
.24446 .77528 m .24398 .77864 L .24625 .77608 L .692 .759 .903 r
F
.24446 .77528 m .24129 .77744 L .24398 .77864 L F
.66619 .45156 m .66392 .43393 L .66425 .43962 L .819 .617 .062 r
F
.64092 .45202 m .66619 .45156 L .66425 .43962 L .673 .757 .914 r
F
0 g
.66296 .46359 m
.66619 .45156 L
s
.59206 .34153 m .59297 .32107 L .56833 .32188 L .654 .726 .902 r
F
.24444 .78308 m .24735 .78155 L .2476 .78375 L .793 .527 .535 r
F
.24444 .78308 m .24419 .78088 L .24735 .78155 L F
.24648 .77831 m .24735 .78155 L .24859 .77876 L .692 .759 .903 r
F
.24648 .77831 m .24419 .78088 L .24735 .78155 L F
0 g
.24735 .78155 m
.25077 .78166 L
s
.40832 .57197 m .42319 .56276 L .40656 .56932 L .683 .77 .917 r
F
.40832 .57197 m .42672 .56806 L .42319 .56276 L F
.42623 .56348 m .43934 .55162 L .4227 .55818 L F
.42623 .56348 m .44462 .55956 L .43934 .55162 L F
.44462 .55956 m .44413 .55498 L .43885 .54703 L .981 .689 .337 r
F
0 g
.44413 .55498 m
.44565 .56373 L
s
.26021 .77866 m .25996 .77646 L .26212 .77459 L .388 .236 .551 r
F
.25742 .78016 m .25996 .77646 L .26021 .77866 L .512 .324 .562 r
F
0 g
.25717 .77796 m
.25996 .77646 L
s
.25767 .78236 m .25742 .78016 L .26021 .77866 L .512 .324 .562 r
F
.25445 .78338 m .25742 .78016 L .25767 .78236 L .599 .386 .564 r
F
.2553 .77783 m .25742 .78016 L .26021 .77866 L .692 .759 .903 r
F
.25315 .77851 m .25742 .78016 L .2553 .77783 L F
0 g
.2542 .78118 m
.25742 .78016 L
s
.25687 .77461 m .25991 .77643 L .26206 .77457 L .692 .759 .903 r
F
.25503 .7756 m .25991 .77643 L .25687 .77461 L F
.3913 .6419 m .38997 .64698 L .39324 .6469 L .645 .732 .913 r
F
.38982 .58647 m .39119 .64191 L .38968 .64203 L .641 .4 .539 r
F
.39027 .63927 m .39017 .64199 L .3913 .6419 L .645 .732 .913 r
F
.39017 .64199 m .38997 .64698 L .3913 .6419 L F
.38997 .64698 m .38966 .65467 L .3962 .65453 L F
.39096 .6455 m .38971 .65079 L .39299 .65072 L F
.38968 .64203 m .39127 .64539 L .38969 .64559 L .641 .4 .539 r
F
.39002 .64305 m .38992 .64558 L .39096 .6455 L .645 .732 .913 r
F
.38992 .64558 m .38971 .65079 L .39096 .6455 L F
.39119 .64191 m .39127 .64539 L .38968 .64203 L .641 .4 .539 r
F
.127 .923 .03 r
.38049 .61156 m
.38064 .6913 L
s
.39382 .64171 m .3963 .64631 L .39896 .64524 L .645 .732 .913 r
F
.39128 .6419 m .3923 .64495 L .39127 .64539 L .515 .301 .526 r
F
.39141 .58626 m .39225 .64156 L .39128 .6419 L F
.39027 .63927 m .39324 .6469 L .3963 .64631 L .645 .732 .913 r
F
.39225 .64156 m .3923 .64495 L .39128 .6419 L .515 .301 .526 r
F
.39302 .64105 m .39344 .6437 L .39301 .64438 L .069 0 .411 r
F
.39315 .58525 m .39343 .64047 L .39302 .64105 L F
.39315 .64125 m .39251 .64177 L .39382 .64171 L .645 .732 .913 r
F
.39251 .64177 m .39248 .64181 L .39382 .64171 L F
.39343 .64047 m .39344 .6437 L .39302 .64105 L .069 0 .411 r
F
.39251 .64177 m .39245 .64181 L .39248 .64181 L .645 .732 .913 r
F
.39027 .63927 m .39224 .64157 L .39315 .64125 L F
.39231 .64154 m .39301 .64438 L .3923 .64495 L .354 .175 .495 r
F
.39244 .58582 m .39298 .64108 L .39231 .64154 L F
.39231 .64154 m .39245 .64181 L .39315 .64125 L .645 .732 .913 r
F
.39225 .64158 m .39245 .64181 L .39231 .64154 L F
.39298 .64108 m .39301 .64438 L .39231 .64154 L .354 .175 .495 r
F
.39224 .64157 m .39225 .64158 L .39231 .64154 L .645 .732 .913 r
F
.39245 .64181 m .3963 .64631 L .39382 .64171 L F
.38982 .58647 m .39141 .58626 L .39128 .6419 L .641 .4 .539 r
F
.39119 .64191 m .39128 .6419 L .39127 .64539 L F
.38982 .58647 m .39128 .6419 L .39119 .64191 L F
.38899 .6419 m .38372 .64557 L .38672 .64652 L .645 .732 .913 r
F
.39016 .64212 m .38672 .64652 L .38997 .64698 L F
.38899 .6419 m .38672 .64652 L .39016 .64212 L F
.38372 .64557 m .38317 .65377 L .38672 .64652 L F
.38775 .64523 m .38086 .648 L .38343 .64939 L F
.3881 .64172 m .38967 .6456 L .38809 .64529 L .751 .491 .538 r
F
.38691 .64473 m .38645 .64498 L .38782 .64516 L .645 .732 .913 r
F
.3871 .64482 m .38809 .64533 L .3871 .64486 L .845 .571 .524 r
F
.38785 .6416 m .38116 .6442 L .38372 .64557 L .645 .732 .913 r
F
.38824 .5862 m .38959 .64201 L .3881 .64172 L .751 .491 .538 r
F
.39027 .63927 m .38685 .64113 L .38785 .6416 L .645 .732 .913 r
F
.38685 .64113 m .38116 .6442 L .38785 .6416 L F
.3871 .64125 m .38809 .64529 L .3871 .64482 L .845 .571 .524 r
F
.38724 .58573 m .38804 .6417 L .3871 .64125 L F
.38779 .64166 m .38769 .64175 L .38899 .6419 L .645 .732 .913 r
F
.38769 .64175 m .38372 .64557 L .38837 .64233 L F
.38769 .64175 m .38837 .64233 L .38899 .6419 L F
.37922 .64248 m .37205 .64912 L .38116 .6442 L F
.38558 .64352 m .37737 .64231 L .37772 .64434 L F
.38644 .64068 m .38709 .64481 L .38643 .64425 L .929 .648 .488 r
F
.38959 .64201 m .38967 .6456 L .3881 .64172 L .751 .491 .538 r
F
.39002 .64305 m .38467 .64274 L .38558 .64352 L .645 .732 .913 r
F
.38824 .5862 m .38982 .58647 L .38968 .64203 L .751 .491 .538 r
F
.38824 .5862 m .38968 .64203 L .38959 .64201 L F
.38619 .58443 m .38658 .58513 L .38644 .64068 L .989 .72 .388 r
F
.38641 .64064 m .38644 .64068 L .38643 .64426 L F
.38619 .58443 m .38644 .64068 L .38641 .64064 L F
.38673 .64119 m .37922 .64248 L .38116 .6442 L .645 .732 .913 r
F
.38685 .64113 m .38671 .64115 L .38673 .64119 L F
.38671 .64115 m .37922 .64248 L .38673 .64119 L F
.39027 .63927 m .38573 .64059 L .38685 .64113 L F
.38605 .64002 m .38643 .64426 L .38605 .64356 L .989 .72 .388 r
F
.38619 .58443 m .38641 .64064 L .38605 .64002 L F
.38573 .64059 m .38671 .64115 L .38664 .64103 L .645 .732 .913 r
F
.38641 .64064 m .38643 .64426 L .38605 .64002 L .989 .72 .388 r
F
.38573 .64059 m .37922 .64248 L .38671 .64115 L .645 .732 .913 r
F
.38664 .64103 m .38671 .64115 L .38685 .64113 L F
.38724 .58573 m .38824 .5862 L .3881 .64172 L .845 .571 .524 r
F
.38804 .6417 m .3881 .64172 L .38809 .64533 L F
.38724 .58573 m .3881 .64172 L .38804 .6417 L F
.38467 .64274 m .37737 .64231 L .38558 .64352 L .645 .732 .913 r
F
.38116 .6442 m .37717 .65187 L .38372 .64557 L F
.38645 .64498 m .37891 .64628 L .38086 .648 L F
.38959 .64201 m .38968 .64203 L .38967 .6456 L .751 .491 .538 r
F
.38706 .64121 m .3871 .64482 L .38644 .64068 L .929 .648 .488 r
F
.3871 .64482 m .3871 .64486 L .38709 .64481 L F
.3871 .64482 m .38709 .64481 L .38644 .64068 L F
.38696 .6447 m .38461 .64462 L .38645 .64498 L .645 .732 .913 r
F
.39002 .64305 m .3863 .64413 L .38696 .6447 L F
.3863 .64413 m .38461 .64462 L .38696 .6447 L F
.38461 .64462 m .37891 .64628 L .38645 .64498 L F
.38643 .64425 m .3871 .64486 L .38643 .64426 L .929 .648 .488 r
F
.38709 .64481 m .3871 .64486 L .38643 .64425 L F
.38658 .58513 m .38706 .64121 L .38644 .64068 L F
.38804 .6417 m .38809 .64529 L .3871 .64125 L .845 .571 .524 r
F
.38809 .64529 m .38809 .64533 L .3871 .64482 L F
.38782 .64516 m .38645 .64498 L .38775 .64523 L .645 .732 .913 r
F
.39002 .64305 m .38691 .64473 L .38782 .64516 L F
.38645 .64498 m .38086 .648 L .38775 .64523 L F
.38672 .64652 m .38317 .65377 L .38966 .65467 L F
.38653 .65018 m .38343 .64939 L .38645 .65034 L F
.39002 .64305 m .38627 .64665 L .38653 .65018 L F
.38627 .64665 m .38343 .64939 L .38653 .65018 L F
.38599 .64274 m .38605 .64356 L .38605 .64359 L .79 .631 .071 r
F
.37931 .6649 m .38935 .66248 L .38909 .66626 L .733 .497 .571 r
F
.37931 .6649 m .37957 .66112 L .38935 .66248 L F
.38317 .65377 m .38936 .66237 L .38966 .65467 L .645 .732 .913 r
F
.38317 .65377 m .37963 .66101 L .38936 .66237 L F
.37905 .66868 m .38909 .66626 L .38884 .67004 L .733 .497 .571 r
F
.37905 .66868 m .37931 .6649 L .38909 .66626 L F
.38288 .65762 m .38909 .66626 L .3894 .65853 L .645 .732 .913 r
F
.38288 .65762 m .37931 .6649 L .38909 .66626 L F
.38262 .6614 m .38884 .67004 L .38914 .66231 L F
.38262 .6614 m .37905 .66868 L .38884 .67004 L F
.38645 .65034 m .38288 .65762 L .3894 .65853 L F
.38619 .65412 m .38262 .6614 L .38914 .66231 L F
.3865 .65348 m .38317 .65317 L .38619 .65412 L F
.38672 .64652 m .38966 .65467 L .38997 .64698 L F
.39002 .64305 m .38645 .65034 L .38971 .65079 L F
.3871 .64486 m .38809 .64533 L .38808 .64886 L .845 .571 .524 r
F
.38779 .64872 m .38626 .6502 L .38863 .64912 L .645 .732 .913 r
F
.38802 .70179 m .38682 .70192 L .38787 .70215 L .692 .759 .903 r
F
.38787 .70215 m .38889 .70501 L .389 .70218 L F
.38927 .70402 m .38812 .70436 L .38926 .7044 L F
.38803 .70177 m .38795 .70176 L .38802 .70179 L F
.389 .70218 m .38889 .70501 L .39118 .7047 L F
.38946 .70189 m .38953 .70488 L .38795 .70176 L .751 .491 .538 r
F
.38936 .70155 m .3883 .70394 L .38927 .70402 L .692 .759 .903 r
F
.38787 .70215 m .38663 .70494 L .38889 .70501 L F
.3883 .70394 m .38812 .70436 L .38927 .70402 L F
.38663 .70494 m .38879 .70784 L .38889 .70501 L F
.38812 .70436 m .38915 .70724 L .38926 .7044 L F
.38795 .70391 m .38953 .70488 L .38794 .70462 L .751 .491 .538 r
F
.38795 .70176 m .38909 .70401 L .38795 .70391 L F
.38909 .70401 m .38953 .70488 L .38795 .70391 L F
.38619 .65412 m .38914 .66231 L .38945 .65457 L .645 .732 .913 r
F
.38343 .64939 m .38288 .65762 L .38645 .65034 L F
.38643 .64426 m .3871 .64486 L .38709 .64838 L .929 .648 .488 r
F
.38646 .64785 m .38709 .64838 L .38695 .70414 L F
.38643 .64426 m .38709 .64838 L .38646 .64785 L F
.38605 .64356 m .38643 .64426 L .38642 .64781 L .989 .72 .388 r
F
.38606 .6472 m .38642 .64781 L .38628 .70354 L F
.38605 .64356 m .38642 .64781 L .38606 .6472 L F
.38725 .64924 m .3806 .65178 L .38317 .65317 L .645 .732 .913 r
F
.38765 .64886 m .38715 .64907 L .38725 .64924 L F
.38715 .64907 m .3806 .65178 L .38725 .64924 L F
.38772 .64879 m .38761 .64884 L .38765 .64886 L F
.38583 .70009 m .38471 .69959 L .38483 .70031 L .692 .759 .903 r
F
.38714 .64904 m .3806 .65178 L .38715 .64907 L .645 .732 .913 r
F
.38657 .70107 m .38524 .70097 L .38592 .70152 L .692 .759 .903 r
F
.38655 .64857 m .3806 .65178 L .38761 .64884 L .645 .732 .913 r
F
.38721 .70147 m .38682 .70192 L .38802 .70179 L .692 .759 .903 r
F
.38645 .65034 m .3894 .65853 L .38971 .65079 L .645 .732 .913 r
F
.38863 .64912 m .38626 .6502 L .3865 .65348 L F
.38682 .70192 m .38663 .70494 L .38787 .70215 L .692 .759 .903 r
F
.38721 .70147 m .38592 .70152 L .38682 .70192 L F
.38709 .64838 m .3879 .70174 L .38696 .70137 L .845 .571 .524 r
F
.38911 .69935 m .38643 .70117 L .38721 .70147 L .692 .759 .903 r
F
.38643 .70117 m .38592 .70152 L .38721 .70147 L F
.38665 .7034 m .38616 .70373 L .38744 .70371 L F
.38682 .70192 m .38452 .70449 L .38663 .70494 L F
.38628 .703 m .38695 .70414 L .38628 .70354 L .929 .648 .488 r
F
.38629 .70085 m .3868 .7034 L .38628 .703 L F
.38734 .70382 m .38616 .70373 L .38706 .70414 L .692 .759 .903 r
F
.3868 .7034 m .38695 .70414 L .38628 .703 L .929 .648 .488 r
F
.38744 .70371 m .3872 .70371 L .38734 .70382 L .692 .759 .903 r
F
.3872 .70371 m .38616 .70373 L .38734 .70382 L F
.3879 .70174 m .38793 .7039 L .38696 .70137 L .845 .571 .524 r
F
.38936 .70155 m .38706 .70414 L .38812 .70436 L .692 .759 .903 r
F
.38793 .7039 m .38794 .70462 L .3877 .70381 L .845 .571 .524 r
F
.38793 .7039 m .3877 .70381 L .38696 .70137 L F
.38665 .7034 m .38548 .70318 L .38616 .70373 L .692 .759 .903 r
F
.38696 .70137 m .3877 .70381 L .38695 .70352 L .845 .571 .524 r
F
.38936 .70155 m .38577 .70306 L .38665 .7034 L .692 .759 .903 r
F
.38577 .70306 m .38548 .70318 L .38665 .7034 L F
.3879 .70174 m .38795 .70176 L .38794 .70462 L .845 .571 .524 r
F
.38936 .70155 m .38665 .7034 L .38744 .70371 L .692 .759 .903 r
F
.38695 .70352 m .38794 .70462 L .38695 .70414 L .845 .571 .524 r
F
.3877 .70381 m .38794 .70462 L .38695 .70352 L F
.3871 .64486 m .38715 .64841 L .38709 .64838 L F
.38715 .64841 m .38794 .70462 L .38709 .64838 L F
.38372 .64557 m .37717 .65187 L .38317 .65377 L .645 .732 .913 r
F
.38086 .648 m .37684 .65572 L .38343 .64939 L F
.3871 .64486 m .38808 .64886 L .38715 .64841 L .845 .571 .524 r
F
.37205 .64912 m .37062 .65817 L .37717 .65187 L .645 .732 .913 r
F
.38086 .648 m .3717 .65295 L .37684 .65572 L F
.38489 .64825 m .37746 .64812 L .37865 .65006 L F
.38599 .64274 m .38598 .64645 L .38598 .64641 L .79 .631 .071 r
F
.38599 .64284 m .38605 .64359 L .38604 .64716 L F
.38599 .64284 m .38604 .64716 L .38598 .64645 L F
.38599 .64274 m .38605 .64359 L .38599 .64284 L F
.38116 .6442 m .37205 .64912 L .37717 .65187 L .645 .732 .913 r
F
.38503 .6445 m .37772 .64434 L .37891 .64628 L F
.39002 .64305 m .3856 .64351 L .38503 .6445 L F
.3856 .64351 m .37772 .64434 L .38503 .6445 L F
.38652 .64171 m .38599 .64274 L .38599 .64284 L 0 0 .372 r
F
.38649 .64197 m .38599 .64284 L .38598 .64641 L F
.38652 .64171 m .38599 .64284 L .38649 .64197 L F
.38598 .64641 m .3859 .70284 L .38584 .70203 L .79 .631 .071 r
F
.38598 .64645 m .3859 .70284 L .38598 .64641 L F
.38698 .64833 m .38613 .64851 L .38615 .64878 L .645 .732 .913 r
F
.38608 .6479 m .37865 .65006 L .38698 .64833 L F
.38643 .64426 m .38646 .64785 L .38642 .64781 L .929 .648 .488 r
F
.38604 .64716 m .38627 .70082 L .3859 .70021 L .989 .72 .388 r
F
.38606 .6472 m .38628 .70354 L .38604 .64716 L F
.38598 .64645 m .38604 .64716 L .3859 .70284 L .79 .631 .071 r
F
.37891 .64628 m .3717 .65295 L .38086 .648 L .645 .732 .913 r
F
.3831 .64753 m .37711 .64609 L .37746 .64812 L F
.38602 .70064 m .38524 .70097 L .38657 .70107 L .692 .759 .903 r
F
.38809 .64533 m .38967 .6456 L .38966 .64916 L .751 .491 .538 r
F
.38475 .64654 m .37762 .64411 L .37711 .64609 L .645 .732 .913 r
F
.38976 .64683 m .38576 .64594 L .38475 .64654 L F
.38576 .64594 m .37762 .64411 L .38475 .64654 L F
.38809 .64533 m .38818 .64888 L .38808 .64886 L .751 .491 .538 r
F
.38976 .64683 m .38608 .6479 L .38698 .64833 L .645 .732 .913 r
F
.38911 .69935 m .38602 .70064 L .38657 .70107 L .692 .759 .903 r
F
.38751 .64875 m .38761 .64884 L .38772 .64879 L .645 .732 .913 r
F
.38642 .64781 m .38692 .70135 L .38629 .70085 L .929 .648 .488 r
F
.38911 .69935 m .38551 .69954 L .38583 .70009 L .692 .759 .903 r
F
.38605 .64356 m .38606 .6472 L .38604 .64716 L .989 .72 .388 r
F
.3843 .64561 m .37895 .64232 L .37762 .64411 L .645 .732 .913 r
F
.38976 .64683 m .3859 .64522 L .3843 .64561 L F
.3859 .64522 m .37895 .64232 L .3843 .64561 L F
.38539 .63978 m .37769 .63853 L .37804 .64055 L F
.38658 .58513 m .38724 .58573 L .3871 .64125 L .929 .648 .488 r
F
.38658 .58513 m .3871 .64125 L .38706 .64121 L F
.38609 .64049 m .37804 .64055 L .37922 .64248 L .645 .732 .913 r
F
.39027 .63927 m .38603 .63972 L .38609 .64049 L F
.38603 .63972 m .37804 .64055 L .38609 .64049 L F
.38614 .58361 m .38619 .58443 L .38605 .64002 L .79 .631 .071 r
F
.38605 .63998 m .38605 .64002 L .38605 .64356 L F
.38614 .58361 m .38605 .64002 L .38605 .63998 L F
.38766 .63767 m .38652 .64171 L .38765 .64092 L .398 .209 .505 r
F
.38779 .58179 m .38659 .63831 L .38766 .63767 L F
.39027 .63927 m .38546 .63899 L .38539 .63978 L .645 .732 .913 r
F
.38659 .63831 m .38652 .64171 L .38766 .63767 L .398 .209 .505 r
F
.38546 .63899 m .38439 .63893 L .38488 .63934 L .645 .732 .913 r
F
.38546 .63899 m .38488 .63934 L .38539 .63978 L F
.38439 .63893 m .37769 .63853 L .38539 .63978 L F
.38706 .64121 m .3871 .64125 L .3871 .64486 L .929 .648 .488 r
F
.38598 .63902 m .3782 .63656 L .37769 .63853 L .645 .732 .913 r
F
.39027 .63927 m .38593 .6383 L .38598 .63902 L F
.38593 .6383 m .3782 .63656 L .38598 .63902 L F
.386 .63927 m .38605 .64356 L .38599 .64274 L .79 .631 .071 r
F
.38614 .58361 m .38605 .63998 L .386 .63927 L F
.38605 .63998 m .38605 .64356 L .386 .63927 L F
.3864 .64154 m .38129 .63705 L .37921 .63854 L .645 .732 .913 r
F
.39002 .64305 m .38745 .64129 L .3864 .64154 L F
.38745 .64129 m .38129 .63705 L .3864 .64154 L F
.38876 .64058 m .38765 .64092 L .38765 .64124 L .567 .342 .533 r
F
.38489 .6419 m .37921 .63854 L .37788 .64033 L .645 .732 .913 r
F
.38765 .64092 m .38652 .64171 L .38652 .64191 L .398 .209 .505 r
F
.38756 .64129 m .38652 .64191 L .38651 .64548 L F
.38765 .64092 m .38652 .64191 L .38756 .64129 L F
.38609 .64217 m .3864 .64154 L .38489 .6419 L .645 .732 .913 r
F
.39002 .64305 m .38684 .64172 L .38609 .64217 L F
.38653 .63835 m .38599 .64274 L .38652 .64171 L 0 0 .372 r
F
.38667 .58257 m .38603 .63922 L .38653 .63835 L F
.38603 .63922 m .38599 .64274 L .38653 .63835 L F
.38667 .58257 m .38614 .58361 L .386 .63927 L F
.38603 .63922 m .386 .63927 L .38599 .64274 L F
.38667 .58257 m .386 .63927 L .38603 .63922 L F
.38683 .63783 m .38159 .6333 L .37953 .63478 L .645 .732 .913 r
F
.38877 .6374 m .38765 .64092 L .38876 .64058 L .567 .342 .533 r
F
.3889 .58145 m .38772 .63766 L .38877 .6374 L F
.39027 .63927 m .38787 .63762 L .38689 .63786 L .645 .732 .913 r
F
.39027 .63927 m .38683 .63783 L .38649 .63842 L F
.38772 .63766 m .38765 .64092 L .38877 .6374 L .567 .342 .533 r
F
.38689 .63786 m .38721 .63716 L .38683 .63783 L .645 .732 .913 r
F
.38787 .63762 m .38721 .63716 L .38689 .63786 L F
.38721 .63716 m .38159 .6333 L .38683 .63783 L F
.38649 .63842 m .37953 .63478 L .3782 .63656 L F
.38683 .63783 m .37953 .63478 L .38649 .63842 L F
.38684 .64172 m .3864 .64154 L .38609 .64217 L F
.3864 .64154 m .37921 .63854 L .38489 .6419 L F
.38809 .64533 m .38966 .64916 L .38818 .64888 L .751 .491 .538 r
F
.38808 .64886 m .38946 .70189 L .38795 .70176 L F
.38818 .64888 m .38946 .70189 L .38808 .64886 L F
.38976 .64683 m .38779 .64872 L .38863 .64912 L .645 .732 .913 r
F
.39002 .64305 m .38179 .64121 L .37737 .64231 L F
.38179 .64121 m .37788 .64033 L .37761 .64135 L F
.38179 .64121 m .37761 .64135 L .37737 .64231 L F
.39027 .63927 m .38779 .64166 L .38899 .6419 L F
.38986 .64049 m .38876 .64058 L .38876 .64097 L .66 .416 .54 r
F
.38909 .66626 m .38935 .66248 L .3992 .66227 L .67 .442 .567 r
F
.38909 .66626 m .3992 .66227 L .39894 .66605 L F
.38884 .67004 m .38909 .66626 L .39894 .66605 L F
.3894 .65853 m .38909 .66626 L .39894 .66605 L .645 .732 .913 r
F
.38884 .67004 m .39894 .66605 L .39868 .66983 L .67 .442 .567 r
F
.38914 .66231 m .38884 .67004 L .39868 .66983 L .645 .732 .913 r
F
.38914 .66231 m .39868 .66983 L .39571 .66217 L F
.38976 .64683 m .38619 .65412 L .38945 .65457 L F
.38818 .64888 m .38966 .64916 L .38953 .70488 L .751 .491 .538 r
F
.38967 .6456 m .38967 .6456 L .38809 .64529 L F
.39027 .63927 m .38899 .6419 L .39016 .64212 L .645 .732 .913 r
F
.38461 .64468 m .38103 .64083 L .37895 .64232 L F
.38976 .64683 m .38653 .64462 L .38461 .64468 L F
.38652 .64171 m .38598 .64641 L .38648 .64554 L 0 0 .372 r
F
.38653 .64462 m .38103 .64083 L .38461 .64468 L .645 .732 .913 r
F
.39002 .64305 m .38396 .63597 L .38129 .63705 L F
.38985 .64094 m .38876 .64097 L .38875 .64454 L .66 .416 .54 r
F
.38978 .64451 m .38875 .64454 L .38861 .69987 L F
.38985 .64094 m .38875 .64454 L .38978 .64451 L F
.38986 .64049 m .38876 .64097 L .38985 .64094 L F
.38652 .64171 m .38648 .64554 L .38651 .64548 L 0 0 .372 r
F
.38702 .64496 m .3837 .63976 L .38103 .64083 L .645 .732 .913 r
F
.38976 .64683 m .38796 .64473 L .38702 .64496 L F
.38796 .64473 m .3837 .63976 L .38702 .64496 L F
.38976 .64683 m .38655 .64857 L .38772 .64879 L F
.38655 .64857 m .38761 .64884 L .38751 .64875 L F
.38761 .64884 m .38714 .64904 L .38765 .64886 L F
.38714 .64904 m .38715 .64907 L .38765 .64886 L F
.38715 .64841 m .38808 .64886 L .38795 .70176 L .845 .571 .524 r
F
.38715 .64841 m .38795 .70176 L .3879 .70174 L F
.38809 .64529 m .38967 .6456 L .38809 .64533 L .751 .491 .538 r
F
.38868 .64456 m .38764 .64481 L .3875 .70021 L .567 .342 .533 r
F
.38751 .69758 m .38807 .69667 L .387 .69701 L .692 .759 .903 r
F
.38911 .69935 m .38831 .69729 L .38751 .69758 L F
.38875 .64454 m .38756 .69756 L .38862 .69718 L .567 .342 .533 r
F
.38831 .69729 m .38807 .69667 L .38751 .69758 L .692 .759 .903 r
F
.38566 .69894 m .38535 .69814 L .38488 .69884 L F
.38911 .69935 m .38632 .69845 L .38566 .69894 L F
.38632 .69845 m .38535 .69814 L .38566 .69894 L F
.38911 .69935 m .387 .69701 L .38607 .69751 L F
.3858 .69953 m .38488 .69884 L .38471 .69959 L F
.38911 .69935 m .38608 .69899 L .3858 .69953 L F
.38608 .69899 m .38488 .69884 L .3858 .69953 L F
.38911 .69935 m .38483 .70031 L .38524 .70097 L F
.38638 .69841 m .38593 .7014 L .38637 .70055 L 0 0 .372 r
F
.38587 .69938 m .38584 .70203 L .38638 .69841 L F
.38636 .70058 m .38631 .69971 L .38559 .70033 L .692 .759 .903 r
F
.38911 .69935 m .38721 .70147 L .38795 .70176 L F
.38911 .69935 m .38795 .70176 L .38803 .70177 L F
.38911 .69935 m .38787 .70215 L .389 .70218 L F
.38936 .70155 m .3867 .69994 L .38636 .70058 L F
.38911 .69935 m .38607 .69751 L .38535 .69814 L F
.38643 .69837 m .38638 .70055 L .38751 .69758 L .398 .209 .505 r
F
.38936 .70155 m .38559 .70033 L .38512 .70104 L .692 .759 .903 r
F
.38638 .70055 m .38637 .70099 L .38657 .70041 L .398 .209 .505 r
F
.38638 .70055 m .38657 .70041 L .38751 .69758 L F
.3867 .69994 m .38631 .69971 L .38636 .70057 L .692 .759 .903 r
F
.38637 .70055 m .38636 .70057 L .38636 .70058 L F
.3867 .69994 m .38636 .70057 L .38637 .70055 L F
.38627 .70082 m .38628 .70354 L .3859 .70021 L .989 .72 .388 r
F
.38692 .70135 m .38695 .70414 L .38629 .70085 L .929 .648 .488 r
F
.38936 .70155 m .38512 .70104 L .38494 .70179 L .692 .759 .903 r
F
.38637 .70055 m .38584 .70203 L .38637 .70099 L 0 0 .372 r
F
.38593 .7014 m .38584 .70203 L .38637 .70055 L F
.38651 .64548 m .38587 .69938 L .38638 .69841 L F
.38751 .69758 m .38657 .70041 L .3875 .69972 L .398 .209 .505 r
F
.38698 .70011 m .38724 .6992 L .38631 .69971 L .692 .759 .903 r
F
.38936 .70155 m .38763 .69963 L .38698 .70011 L F
.38763 .69963 m .38724 .6992 L .38698 .70011 L F
.3875 .69972 m .38637 .70099 L .3875 .70021 L .398 .209 .505 r
F
.38657 .70041 m .38637 .70099 L .3875 .69972 L F
.38764 .64481 m .38643 .69837 L .38751 .69758 L F
.38756 .69756 m .3875 .70021 L .38862 .69718 L .567 .342 .533 r
F
.38766 .69967 m .38832 .69886 L .38724 .6992 L .692 .759 .903 r
F
.38936 .70155 m .38851 .69936 L .38766 .69967 L F
.38862 .69718 m .38771 .69965 L .38862 .69932 L .567 .342 .533 r
F
.38851 .69936 m .38832 .69886 L .38766 .69967 L .692 .759 .903 r
F
.38862 .69932 m .3875 .70021 L .38861 .69987 L .567 .342 .533 r
F
.38771 .69965 m .3875 .70021 L .38862 .69932 L F
.38876 .64097 m .38868 .64456 L .38875 .64454 L F
.38868 .64456 m .3875 .70021 L .38875 .64454 L F
.38876 .64058 m .38875 .64097 L .38876 .64097 L F
.38875 .64097 m .3875 .70021 L .38876 .64097 L F
.38865 .641 m .38765 .64124 L .38764 .64481 L F
.38876 .64058 m .38765 .64124 L .38865 .641 L F
.38876 .64058 m .38764 .64481 L .38868 .64456 L F
.38765 .64092 m .38757 .64485 L .38764 .64481 L .398 .209 .505 r
F
.38757 .64485 m .38637 .70099 L .38764 .64481 L F
.38648 .64554 m .38584 .70203 L .38651 .64548 L 0 0 .372 r
F
.38548 .64728 m .38475 .64654 L .3831 .64753 L .645 .732 .913 r
F
.38976 .64683 m .38587 .64661 L .38548 .64728 L F
.38587 .64661 m .38475 .64654 L .38548 .64728 L F
.38475 .64654 m .37711 .64609 L .3831 .64753 L F
.38976 .64683 m .38548 .64728 L .38493 .64824 L F
.38646 .64785 m .38695 .70414 L .38642 .64781 L .929 .648 .488 r
F
.38757 .64485 m .38651 .64548 L .38637 .70099 L .398 .209 .505 r
F
.38765 .64092 m .38651 .64548 L .38757 .64485 L F
.38648 .64554 m .38598 .64641 L .38584 .70203 L 0 0 .372 r
F
.38493 .64824 m .38184 .64766 L .38489 .64825 L .645 .732 .913 r
F
.38548 .64728 m .38184 .64766 L .38493 .64824 L F
.38184 .64766 m .37746 .64812 L .38489 .64825 L F
.38615 .64878 m .37865 .65006 L .3806 .65178 L F
.38613 .64851 m .37865 .65006 L .38615 .64878 L F
.38551 .69954 m .38471 .69959 L .38583 .70009 L .692 .759 .903 r
F
.38592 .70152 m .38452 .70449 L .38682 .70192 L F
.38592 .70152 m .38274 .70369 L .38452 .70449 L F
.38589 .70233 m .38494 .70179 L .38506 .70252 L F
.3859 .70021 m .3862 .70287 L .3859 .70236 L .989 .72 .388 r
F
.38936 .70155 m .38554 .70176 L .38589 .70233 L .692 .759 .903 r
F
.38554 .70176 m .38494 .70179 L .38589 .70233 L F
.38936 .70155 m .38506 .70252 L .38548 .70318 L F
.3859 .70236 m .38628 .70354 L .3859 .70284 L .989 .72 .388 r
F
.3862 .70287 m .38628 .70354 L .3859 .70236 L F
.38626 .6502 m .38317 .65317 L .3865 .65348 L .645 .732 .913 r
F
0 g
.38982 .58647 m
.38983 .58137 L
s
.61422 .43714 m .63408 .4254 L .6119 .43348 L .673 .757 .914 r
F
.61422 .43714 m .63871 .43273 L .63408 .4254 L F
.37292 .56191 m .35687 .5571 L .35288 .56277 L .683 .77 .917 r
F
.37601 .55941 m .35687 .5571 L .37292 .56191 L F
.39416 .64089 m .39896 .64524 L .40102 .64376 L .645 .732 .913 r
F
.39027 .63927 m .39315 .64125 L .39416 .64089 L F
.39315 .64125 m .39896 .64524 L .39416 .64089 L F
.39141 .58626 m .39244 .58582 L .39231 .64154 L .515 .301 .526 r
F
.39225 .64156 m .39231 .64154 L .3923 .64495 L F
.39141 .58626 m .39231 .64154 L .39225 .64156 L F
.39212 .45894 m .37212 .45518 L .37242 .46087 L .672 .448 .573 r
F
0 g
.35393 .46583 m
.37242 .46087 L
s
.39212 .45894 m .39181 .45325 L .37212 .45518 L .672 .448 .573 r
F
0 g
.35363 .46014 m
.37212 .45518 L
s
.25111 .78103 m .25102 .78386 L .25445 .78338 L .692 .759 .903 r
F
.127 .923 .03 r
.23241 .75587 m
.23248 .75803 L
s
.23032 .75226 m
.23039 .75442 L
s
.24883 .78096 m .25102 .78386 L .25111 .78103 L .692 .759 .903 r
F
.127 .923 .03 r
.23758 .76161 m
.23762 .76378 L
s
.24883 .78096 m .2476 .78375 L .25102 .78386 L .692 .759 .903 r
F
.56584 .44369 m .53951 .44815 L .56478 .4477 L .673 .757 .914 r
F
.64092 .45202 m .66425 .43962 L .63962 .44406 L F
.61565 .45248 m .64092 .45202 L .63962 .44406 L F
.2534 .78071 m .25445 .78338 L .25767 .78236 L .692 .759 .903 r
F
.25111 .78103 m .25445 .78338 L .2534 .78071 L F
0 g
.25102 .78386 m
.25445 .78338 L
s
.35366 .57191 m .33552 .56993 L .33321 .57888 L .683 .77 .917 r
F
0 g
.33321 .57888 m
.33477 .58761 L
s
.39428 .64017 m .40102 .64376 L .40235 .64198 L .645 .732 .913 r
F
.39027 .63927 m .39358 .64066 L .39428 .64017 L F
.39358 .64066 m .40102 .64376 L .39428 .64017 L F
.39244 .58582 m .39315 .58525 L .39302 .64105 L .354 .175 .495 r
F
.39298 .64108 m .39302 .64105 L .39301 .64438 L F
.39244 .58582 m .39302 .64105 L .39298 .64108 L F
.40607 .56474 m .41691 .55378 L .40317 .56254 L .683 .77 .917 r
F
.40607 .56474 m .4227 .55818 L .41691 .55378 L F
.6687 .67867 m .66008 .67271 L .65593 .67566 L .645 .732 .913 r
F
.67136 .6776 m .66008 .67271 L .6687 .67867 L F
.24174 .78188 m .24419 .78088 L .24444 .78308 L .861 .577 .507 r
F
.24174 .78188 m .24149 .77968 L .24419 .78088 L F
.24468 .7775 m .24419 .78088 L .24648 .77831 L .692 .759 .903 r
F
.24468 .7775 m .24149 .77968 L .24419 .78088 L F
0 g
.24419 .78088 m
.24735 .78155 L
s
.68647 .67971 m .69056 .67205 L .68393 .67834 L .645 .732 .913 r
F
.68647 .67971 m .69564 .6748 L .69056 .67205 L F
.66609 .68768 m .65263 .68675 L .66473 .68947 L F
.66633 .6839 m .65558 .6794 L .65287 .68297 L F
.66842 .68242 m .65558 .6794 L .66633 .6839 L F
.24673 .78051 m .2476 .78375 L .24883 .78096 L .692 .759 .903 r
F
.24673 .78051 m .24444 .78308 L .2476 .78375 L F
0 g
.2476 .78375 m
.25102 .78386 L
s
.68914 .6909 m .69911 .68575 L .68797 .68896 L .645 .732 .913 r
F
.68914 .6909 m .70144 .68962 L .69911 .68575 L F
.68821 .68519 m .6955 .67853 L .68628 .68347 L F
.68821 .68519 m .69935 .68197 L .6955 .67853 L F
.65558 .6794 m .64077 .68026 L .65287 .68297 L F
.23945 .77803 m .24124 .77748 L .24149 .77968 L .933 .634 .451 r
F
.127 .923 .03 r
.24332 1.14601 m
.25365 1.45888 L
s
.24406 1.11108 m
.26476 1.74237 L
s
.24229 1.0054 m
.24933 1.36974 L
s
.23945 .77803 m .2392 .77583 L .24124 .77748 L .933 .634 .451 r
F
0 g
.24124 .77748 m
.24335 .77841 L
s
.2431 .77419 m .24129 .77744 L .24446 .77528 L .692 .759 .903 r
F
.2431 .77419 m .23926 .77581 L .24129 .77744 L F
.40262 .558 m .40865 .54609 L .3988 .55641 L .683 .77 .917 r
F
.40262 .558 m .41628 .54928 L .40865 .54609 L F
.65593 .67566 m .64523 .67118 L .64119 .67652 L .645 .732 .913 r
F
.39412 .6395 m .40235 .64198 L .40286 .64001 L F
.39027 .63927 m .39373 .64005 L .39412 .6395 L F
.39373 .64005 m .40235 .64198 L .39412 .6395 L F
.39315 .58525 m .39358 .58456 L .39345 .64044 L .069 0 .411 r
F
.39343 .64047 m .39345 .64044 L .39344 .6437 L F
.39315 .58525 m .39345 .64044 L .39343 .64047 L F
.26021 .77866 m .26212 .77459 L .26237 .77679 L .388 .236 .551 r
F
.26046 .78086 m .26021 .77866 L .26237 .77679 L F
.25767 .78236 m .26021 .77866 L .26046 .78086 L .512 .324 .562 r
F
.25716 .77683 m .26021 .77866 L .26237 .77679 L .692 .759 .903 r
F
.2553 .77783 m .26021 .77866 L .25716 .77683 L F
0 g
.25742 .78016 m
.26021 .77866 L
s
.64483 .67489 m .64101 .67648 L .64077 .68026 L .085 0 .407 r
F
.64483 .67489 m .64507 .67111 L .64101 .67648 L F
0 g
.63942 .6824 m
.64101 .67648 L
s
.25555 .78003 m .25767 .78236 L .26046 .78086 L .692 .759 .903 r
F
.2534 .78071 m .25767 .78236 L .25555 .78003 L F
0 g
.25445 .78338 m
.25767 .78236 L
s
.70168 .68584 m .71049 .67875 L .69935 .68197 L .645 .732 .913 r
F
.70168 .68584 m .71399 .68456 L .71049 .67875 L F
.41168 .46017 m .39181 .45325 L .39212 .45894 L .733 .496 .569 r
F
0 g
.37212 .45518 m
.39181 .45325 L
s
.39181 .45325 m
.41137 .45447 L
s
.41168 .46017 m
.42976 .46446 L
s
.54163 .44013 m .51424 .44861 L .53951 .44815 L .673 .757 .914 r
F
.56584 .44369 m .54163 .44013 L .53951 .44815 L F
.61565 .45248 m .63962 .44406 L .615 .4485 L F
.35687 .5571 m .33483 .56079 L .35288 .56277 L .683 .77 .917 r
F
.71399 .68456 m .71422 .68078 L .71073 .67497 L .991 .751 .471 r
F
0 g
.71422 .68078 m
.7152 .68685 L
s
.26237 .77679 m .26212 .77459 L .26351 .77246 L .18 .091 .51 r
F
0 g
.25996 .77646 m
.26212 .77459 L
s
.25831 .77336 m .26206 .77457 L .26345 .77246 L .692 .759 .903 r
F
.25687 .77461 m .26206 .77457 L .25831 .77336 L F
.37381 .57105 m .35366 .57191 L .3718 .5739 L .683 .77 .917 r
F
0 g
.39212 .45894 m
.41168 .46017 L
s
.39311 .63872 m .39204 .641 L .3931 .64183 L .909 .63 .5 r
F
.39324 .58269 m .3921 .63796 L .39311 .63872 L F
.39358 .58456 m .39356 .63974 L .39345 .64044 L 0 0 .133 r
F
.39369 .63891 m .40286 .64001 L .40251 .63799 L .645 .732 .913 r
F
.39027 .63927 m .3936 .63947 L .39369 .63891 L F
.3936 .63947 m .40286 .64001 L .39369 .63891 L F
.39358 .58456 m .3937 .58375 L .39357 .6397 L 0 0 .133 r
F
.39356 .63974 m .39357 .6397 L .39356 .64288 L F
.39358 .58456 m .39357 .6397 L .39356 .63974 L F
.3921 .63796 m .39204 .641 L .39311 .63872 L .909 .63 .5 r
F
.39123 .63731 m .39422 .63548 L .39383 .63202 L .645 .732 .913 r
F
.39204 .63792 m .39095 .64062 L .39204 .641 L .81 .54 .531 r
F
.39218 .58187 m .39102 .63755 L .39204 .63792 L F
.39027 .63927 m .39178 .63782 L .3911 .63758 L .645 .732 .913 r
F
.3937 .58375 m .39324 .58269 L .39311 .63872 L .985 .728 .342 r
F
.39314 .63877 m .39311 .63872 L .3931 .64183 L F
.3937 .58375 m .39311 .63872 L .39314 .63877 L F
.39275 .63794 m .40133 .63606 L .39939 .63434 L .645 .732 .913 r
F
.39027 .63927 m .393 .63848 L .39275 .63794 L F
.393 .63848 m .40133 .63606 L .39275 .63794 L F
.39241 .63722 m .39939 .63434 L .39683 .63297 L F
.39027 .63927 m .39275 .63794 L .39241 .63722 L F
.39275 .63794 m .39939 .63434 L .39241 .63722 L F
.39345 .64044 m .39356 .64288 L .39344 .6437 L 0 0 .133 r
F
.39356 .63974 m .39356 .64288 L .39345 .64044 L F
.39357 .6397 m .3931 .64183 L .39356 .64288 L .985 .728 .342 r
F
.3937 .58375 m .39314 .63877 L .39357 .6397 L F
.39314 .63877 m .3931 .64183 L .39357 .6397 L F
.39102 .63755 m .39095 .64062 L .39204 .63792 L .81 .54 .531 r
F
.3911 .63758 m .39184 .63777 L .39123 .63731 L .645 .732 .913 r
F
.39178 .63782 m .39184 .63777 L .3911 .63758 L F
.39184 .63777 m .39422 .63548 L .39123 .63731 L F
.39422 .63548 m .39683 .63297 L .39471 .6323 L F
.39422 .63548 m .39471 .6323 L .39383 .63202 L F
.56834 .43426 m .54155 .43448 L .56564 .43802 L .673 .757 .914 r
F
.24493 .77971 m .24444 .78308 L .24673 .78051 L .692 .759 .903 r
F
.24493 .77971 m .24174 .78188 L .24444 .78308 L F
0 g
.24444 .78308 m
.2476 .78375 L
s
.67136 .6776 m .66541 .67058 L .66008 .67271 L .645 .732 .913 r
F
.67443 .67701 m .66541 .67058 L .67136 .6776 L F
.42672 .56806 m .43983 .5562 L .42319 .56276 L .683 .77 .917 r
F
.42672 .56806 m .44511 .56415 L .43983 .5562 L F
.25095 .77599 m .25086 .77882 L .25315 .77851 L .692 .759 .903 r
F
0 g
.25122 .77647 m
.25123 .77564 L
s
.24982 .77596 m .24859 .77876 L .25086 .77882 L .692 .759 .903 r
F
.44462 .55956 m .43885 .54703 L .43934 .55162 L .981 .689 .337 r
F
.44511 .56415 m .44462 .55956 L .43934 .55162 L F
0 g
.44462 .55956 m
.44614 .56831 L
s
.68393 .67834 m .68457 .67016 L .68094 .67739 L .645 .732 .913 r
F
.68393 .67834 m .69056 .67205 L .68457 .67016 L F
.2521 .77583 m .25315 .77851 L .2553 .77783 L .692 .759 .903 r
F
.2397 .78023 m .24149 .77968 L .24174 .78188 L .933 .634 .451 r
F
.2397 .78023 m .23945 .77803 L .24149 .77968 L F
.24331 .77641 m .24149 .77968 L .24468 .7775 L .692 .759 .903 r
F
.24331 .77641 m .23945 .77803 L .24149 .77968 L F
0 g
.24149 .77968 m
.2436 .78061 L
s
.65919 .34256 m .64042 .32448 L .64001 .33178 L .859 .601 .547 r
F
0 g
.65919 .34256 m
.67365 .35605 L
s
.51772 .44227 m .51424 .44861 L .51456 .4543 L 0 0 .322 r
F
0 g
.51495 .45282 m
.51519 .45429 L
s
.54163 .44013 m .5174 .43657 L .51424 .44861 L .673 .757 .914 r
F
.51772 .44227 m .5174 .43657 L .51424 .44861 L 0 0 .322 r
F
.24876 .77573 m .24859 .77876 L .24982 .77596 L .692 .759 .903 r
F
.24876 .77573 m .24648 .77831 L .24859 .77876 L F
.59038 .45293 m .59117 .43749 L .5846 .43814 L .673 .757 .914 r
F
.26046 .78086 m .26237 .77679 L .26262 .77899 L .388 .236 .551 r
F
.25741 .77903 m .26046 .78086 L .26262 .77899 L .692 .759 .903 r
F
.25555 .78003 m .26046 .78086 L .25741 .77903 L F
0 g
.25767 .78236 m
.26046 .78086 L
s
.37332 .56647 m .35719 .56164 L .35318 .56733 L .683 .77 .917 r
F
.37643 .56395 m .35719 .56164 L .37332 .56647 L F
.25317 .77549 m .2553 .77783 L .25716 .77683 L .692 .759 .903 r
F
.37601 .55941 m .36306 .55209 L .35687 .5571 L .683 .77 .917 r
F
.37999 .5574 m .36306 .55209 L .37601 .55941 L F
.66842 .68242 m .65976 .67643 L .65558 .6794 L .645 .732 .913 r
F
.67109 .68135 m .65976 .67643 L .66842 .68242 L F
.68628 .68347 m .69039 .67577 L .68373 .68209 L F
.68628 .68347 m .6955 .67853 L .69039 .67577 L F
.26237 .77679 m .26351 .77246 L .26376 .77466 L .18 .091 .51 r
F
.26262 .77899 m .26237 .77679 L .26376 .77466 L F
.2586 .77558 m .26237 .77679 L .26376 .77466 L .692 .759 .903 r
F
.25716 .77683 m .26237 .77679 L .2586 .77558 L F
0 g
.26021 .77866 m
.26237 .77679 L
s
.67443 .67701 m .67156 .6694 L .66541 .67058 L .645 .732 .913 r
F
.6777 .67694 m .67156 .6694 L .67443 .67701 L F
.66609 .68768 m .65534 .68318 L .65263 .68675 L F
.66818 .6862 m .65534 .68318 L .66609 .68768 L F
.24695 .77257 m .2431 .77419 L .24446 .77528 L .692 .759 .903 r
F
.68094 .67739 m .67809 .66925 L .6777 .67694 L .645 .732 .913 r
F
.68094 .67739 m .68457 .67016 L .67809 .66925 L F
.40656 .56932 m .4174 .55836 L .40366 .56712 L .683 .77 .917 r
F
.40656 .56932 m .42319 .56276 L .4174 .55836 L F
.23819 .77605 m .2392 .77583 L .23945 .77803 L .976 .675 .312 r
F
.127 .923 .03 r
.23039 .75442 m
.23373 .85557 L
s
.23373 .85557 m
.24332 1.14601 L
s
.23248 .75803 m
.23571 .85652 L
s
.23571 .85652 m
.24406 1.11108 L
s
.23951 .86153 m
.24229 1.0054 L
s
.22068 .68208 m
.22363 .82162 L
s
.22363 .82162 m
.23902 1.54834 L
s
.23819 .77605 m .23794 .77385 L .2392 .77583 L .976 .675 .312 r
F
0 g
.2392 .77583 m
.24108 .77734 L
s
.24227 .77288 m .23926 .77581 L .2431 .77419 L .692 .759 .903 r
F
.24227 .77288 m .238 .77384 L .23926 .77581 L F
.61467 .44281 m .63463 .43101 L .61234 .43913 L .673 .757 .914 r
F
.61467 .44281 m .63929 .43837 L .63463 .43101 L F
.68797 .68896 m .69526 .68231 L .68604 .68725 L .645 .732 .913 r
F
.68797 .68896 m .69911 .68575 L .69526 .68231 L F
.65534 .68318 m .64053 .68404 L .65263 .68675 L F
.66008 .67271 m .64523 .67118 L .65593 .67566 L F
.24786 .77533 m .24648 .77831 L .24876 .77573 L .692 .759 .903 r
F
.24786 .77533 m .24468 .7775 L .24648 .77831 L F
.64459 .67867 m .64077 .68026 L .64053 .68404 L .085 0 .407 r
F
.65558 .6794 m .64483 .67489 L .64077 .68026 L .645 .732 .913 r
F
.64459 .67867 m .64483 .67489 L .64077 .68026 L .085 0 .407 r
F
0 g
.63918 .68618 m
.64077 .68026 L
s
.70144 .68962 m .71025 .68253 L .69911 .68575 L .645 .732 .913 r
F
.70144 .68962 m .71375 .68834 L .71025 .68253 L F
.6777 .67694 m .67809 .66925 L .67156 .6694 L F
.69947 .67822 m .70481 .66989 L .69564 .6748 L F
.69947 .67822 m .71056 .67502 L .70481 .66989 L F
.25831 .77336 m .26345 .77246 L .25923 .77196 L .692 .759 .903 r
F
.25455 .77216 m .25831 .77336 L .25923 .77196 L F
0 g
.37242 .46087 m
.39212 .45894 L
s
.2512 .77819 m .25111 .78103 L .2534 .78071 L .692 .759 .903 r
F
.25007 .77816 m .25111 .78103 L .2512 .77819 L F
.25007 .77816 m .24883 .78096 L .25111 .78103 L F
.56617 .44938 m .53983 .45384 L .56511 .45339 L .673 .757 .914 r
F
.25235 .77803 m .2534 .78071 L .25555 .78003 L .692 .759 .903 r
F
.2512 .77819 m .2534 .78071 L .25235 .77803 L F
.3988 .55641 m .39967 .5443 L .39431 .55551 L .683 .77 .917 r
F
.3988 .55641 m .40865 .54609 L .39967 .5443 L F
.2541 .77499 m .25716 .77683 L .2586 .77558 L .692 .759 .903 r
F
.71399 .68456 m .71073 .67497 L .71049 .67875 L .991 .751 .471 r
F
.71375 .68834 m .71399 .68456 L .71049 .67875 L F
0 g
.71399 .68456 m
.71497 .69063 L
s
.40317 .56254 m .40924 .55057 L .39934 .56094 L .683 .77 .917 r
F
.40317 .56254 m .41691 .55378 L .40924 .55057 L F
.63871 .43273 m .65627 .41732 L .63408 .4254 L .673 .757 .914 r
F
.63871 .43273 m .66321 .42831 L .65627 .41732 L F
.127 .923 .03 r
.6551 .43552 m
.65519 .43257 L
s
.24356 .77861 m .24174 .78188 L .24493 .77971 L .692 .759 .903 r
F
.24356 .77861 m .2397 .78023 L .24174 .78188 L F
0 g
.24174 .78188 m
.24444 .78308 L
s
.56875 .31458 m .54604 .31223 L .54562 .31952 L .591 .366 .543 r
F
.56875 .31458 m .56917 .30729 L .54604 .31223 L F
0 g
.526 .32096 m
.54604 .31223 L
s
.58823 .55336 m .58772 .54878 L .60246 .54684 L .673 .452 .578 r
F
.127 .923 .03 r
.58372 .69335 m
.58513 .63108 L
s
.58951 1.0866 m
.5934 .77032 L
s
.59613 .54767 m
.59641 .5251 L
s
.57536 1.37519 m
.58922 .7861 L
s
.59482 .54785 m
.59523 .53025 L
s
.57361 .55297 m .58772 .54878 L .58823 .55336 L .733 .497 .57 r
F
.127 .923 .03 r
.58698 .549 m
.5883 .49083 L
s
.58169 .55057 m
.5823 .49325 L
s
.57361 .55297 m .57311 .54839 L .58772 .54878 L .733 .497 .57 r
F
.39285 .63852 m .40251 .63799 L .40133 .63606 L .645 .732 .913 r
F
.39027 .63927 m .39341 .63894 L .39285 .63852 L F
.39341 .63894 m .40251 .63799 L .39285 .63852 L F
.39324 .58269 m .39218 .58187 L .39204 .63792 L .909 .63 .5 r
F
.3921 .63796 m .39204 .63792 L .39204 .641 L F
.39324 .58269 m .39204 .63792 L .3921 .63796 L F
0 g
.39312 .63346 m
.39324 .58269 L
s
.39324 .58269 m
.39326 .57458 L
s
.26376 .77466 m .26351 .77246 L .26403 .77024 L 0 0 .373 r
F
0 g
.26212 .77459 m
.26351 .77246 L
s
.25923 .77196 m .26345 .77246 L .26397 .77024 L .692 .759 .903 r
F
.24901 .77793 m .24883 .78096 L .25007 .77816 L F
.24901 .77793 m .24673 .78051 L .24883 .78096 L F
.38781 .63758 m .38425 .63223 L .38159 .6333 L .645 .732 .913 r
F
.38987 .63737 m .38876 .64058 L .38986 .64049 L .66 .416 .54 r
F
.39 .58136 m .38883 .6374 L .38987 .63737 L F
.39027 .63927 m .38868 .63741 L .38781 .63758 L .645 .732 .913 r
F
.38883 .6374 m .38876 .64058 L .38987 .63737 L .66 .416 .54 r
F
.38868 .63741 m .38848 .63718 L .38806 .63743 L .645 .732 .913 r
F
.38868 .63741 m .38806 .63743 L .38781 .63758 L F
.38848 .63718 m .38425 .63223 L .38781 .63758 L F
.38779 .58179 m .38667 .58257 L .38653 .63835 L .398 .209 .505 r
F
.38659 .63831 m .38653 .63835 L .38652 .64171 L F
.38779 .58179 m .38653 .63835 L .38659 .63831 L F
0 g
.38654 .63491 m
.38667 .58257 L
s
.38667 .58257 m
.38669 .5749 L
s
.58833 .53726 m .58773 .54861 L .6024 .54668 L .683 .77 .917 r
F
.57863 .537 m .58773 .54861 L .58833 .53726 L F
.57863 .537 m .57319 .54822 L .58773 .54861 L F
.64042 .32448 m .64083 .31718 L .61825 .30985 L .794 .542 .556 r
F
0 g
.64083 .31718 m
.66001 .32797 L
s
.35719 .56164 m .33504 .56535 L .35318 .56733 L .683 .77 .917 r
F
.42205 .55366 m .42996 .54055 L .41628 .54928 L F
.42205 .55366 m .4386 .54713 L .42996 .54055 L F
.25342 .77769 m .25555 .78003 L .25741 .77903 L .692 .759 .903 r
F
.25235 .77803 m .25555 .78003 L .25342 .77769 L F
.60296 .55142 m .60246 .54684 L .61632 .5427 L .606 .404 .582 r
F
.58823 .55336 m .60246 .54684 L .60296 .55142 L .673 .452 .578 r
F
0 g
.58772 .54878 m
.60246 .54684 L
s
.67109 .68135 m .66511 .67428 L .65976 .67643 L .645 .732 .913 r
F
.67418 .68075 m .66511 .67428 L .67109 .68135 L F
.68373 .68209 m .68437 .67387 L .68072 .68114 L F
.68373 .68209 m .69039 .67577 L .68437 .67387 L F
.26262 .77899 m .26376 .77466 L .26401 .77687 L .18 .091 .51 r
F
.25885 .77778 m .26262 .77899 L .26401 .77687 L .692 .759 .903 r
F
.25741 .77903 m .26262 .77899 L .25885 .77778 L F
0 g
.26046 .78086 m
.26262 .77899 L
s
.24718 .77478 m .24468 .7775 L .24786 .77533 L .692 .759 .903 r
F
.24718 .77478 m .24331 .77641 L .24468 .7775 L F
.24653 .77192 m .2431 .77419 L .24695 .77257 L F
.24653 .77192 m .24227 .77288 L .2431 .77419 L F
.23844 .77825 m .23945 .77803 L .2397 .78023 L .976 .675 .312 r
F
.23844 .77825 m .23819 .77605 L .23945 .77803 L F
.24248 .77509 m .23945 .77803 L .24331 .77641 L .692 .759 .903 r
F
.24248 .77509 m .23819 .77605 L .23945 .77803 L F
0 g
.23945 .77803 m
.24133 .77955 L
s
.5981 .53597 m .6024 .54668 L .61618 .54256 L .683 .77 .917 r
F
.58833 .53726 m .6024 .54668 L .5981 .53597 L F
.6119 .43348 m .62642 .41918 L .60807 .43037 L .673 .757 .914 r
F
.6119 .43348 m .63408 .4254 L .62642 .41918 L F
.54195 .44582 m .51456 .4543 L .53983 .45384 L F
.56617 .44938 m .54195 .44582 L .53983 .45384 L F
.24811 .77753 m .24673 .78051 L .24901 .77793 L .692 .759 .903 r
F
.24811 .77753 m .24493 .77971 L .24673 .78051 L F
.39218 .58187 m .3911 .58149 L .39095 .64062 L .81 .54 .531 r
F
.44511 .56415 m .43934 .55162 L .43983 .5562 L .981 .689 .337 r
F
0 g
.44511 .56415 m
.44663 .57289 L
s
.37999 .5574 m .37101 .54807 L .36306 .55209 L .683 .77 .917 r
F
.38457 .55603 m .37101 .54807 L .37999 .5574 L F
.3889 .58145 m .38779 .58179 L .38765 .64092 L .567 .342 .533 r
F
.2586 .77558 m .26376 .77466 L .25952 .77416 L .692 .759 .903 r
F
.25482 .77437 m .2586 .77558 L .25952 .77416 L F
.25923 .77196 m .26397 .77024 L .25958 .77048 L F
.25501 .77146 m .25923 .77196 L .25958 .77048 L F
.25455 .77216 m .25923 .77196 L .25501 .77146 L F
.25435 .77719 m .25741 .77903 L .25885 .77778 L F
.25342 .77769 m .25741 .77903 L .25435 .77719 L F
.66818 .6862 m .65952 .68021 L .65534 .68318 L .645 .732 .913 r
F
.67086 .68512 m .65952 .68021 L .66818 .6862 L F
.3911 .58149 m .38986 .64049 L .39095 .64062 L .734 .477 .539 r
F
.3911 .58149 m .39 .58136 L .38986 .64049 L F
.68604 .68725 m .69015 .67955 L .68349 .68587 L .645 .732 .913 r
F
.68604 .68725 m .69526 .68231 L .69015 .67955 L F
.37381 .57105 m .35768 .56622 L .35366 .57191 L .683 .77 .917 r
F
.37692 .56853 m .35768 .56622 L .37381 .57105 L F
.39 .58136 m .3889 .58145 L .38876 .64058 L .66 .416 .54 r
F
.56856 .43992 m .54163 .44013 L .56584 .44369 L .673 .757 .914 r
F
.26376 .77466 m .26403 .77024 L .26428 .77244 L 0 0 .373 r
F
.26401 .77687 m .26376 .77466 L .26428 .77244 L F
.25952 .77416 m .26376 .77466 L .26428 .77244 L .692 .759 .903 r
F
0 g
.26237 .77679 m
.26376 .77466 L
s
.67418 .68075 m .67129 .6731 L .66511 .67428 L .645 .732 .913 r
F
.67746 .68068 m .67129 .6731 L .67418 .68075 L F
.39431 .55551 m .38997 .54404 L .38946 .55538 L .683 .77 .917 r
F
.39431 .55551 m .39967 .5443 L .38997 .54404 L F
.68072 .68114 m .67786 .67296 L .67746 .68068 L .645 .732 .913 r
F
.68072 .68114 m .68437 .67387 L .67786 .67296 L F
.37643 .56395 m .36341 .5566 L .35719 .56164 L .683 .77 .917 r
F
.38043 .56193 m .36341 .5566 L .37643 .56395 L F
.23781 .77388 m .23794 .77385 L .23819 .77605 L .773 .554 0 r
F
.127 .923 .03 r
.23798 .78222 m
.23951 .86153 L
s
.23781 .77388 m .23756 .77168 L .23794 .77385 L .773 .554 0 r
F
0 g
.23794 .77385 m
.23919 .77583 L
s
.24202 .77143 m .238 .77384 L .24227 .77288 L .692 .759 .903 r
F
.24202 .77143 m .23763 .77167 L .238 .77384 L F
.65976 .67643 m .64483 .67489 L .65558 .6794 L .645 .732 .913 r
F
.65534 .68318 m .64459 .67867 L .64053 .68404 L F
0 g
.63894 .68996 m
.64053 .68404 L
s
.67746 .68068 m .67786 .67296 L .67129 .6731 L .645 .732 .913 r
F
.54195 .44582 m .51772 .44227 L .51456 .4543 L .673 .757 .914 r
F
0 g
.51456 .4543 m
.51656 .46623 L
s
.69935 .68197 m .70471 .67359 L .6955 .67853 L .645 .732 .913 r
F
.69935 .68197 m .71049 .67875 L .70471 .67359 L F
.24743 .77698 m .24493 .77971 L .24811 .77753 L .692 .759 .903 r
F
.24743 .77698 m .24356 .77861 L .24493 .77971 L F
.24676 .77412 m .24331 .77641 L .24718 .77478 L F
.24676 .77412 m .24248 .77509 L .24331 .77641 L F
.71375 .68834 m .71049 .67875 L .71025 .68253 L .991 .751 .471 r
F
0 g
.71375 .68834 m
.71473 .69441 L
s
.24272 .77729 m .2397 .78023 L .24356 .77861 L .692 .759 .903 r
F
.24272 .77729 m .23844 .77825 L .2397 .78023 L F
0 g
.2397 .78023 m
.24174 .78188 L
s
.38457 .55603 m .38019 .54532 L .37101 .54807 L .683 .77 .917 r
F
.38946 .55538 m .38019 .54532 L .38457 .55603 L F
.24641 .7712 m .24227 .77288 L .24653 .77192 L .692 .759 .903 r
F
.24641 .7712 m .24202 .77143 L .24227 .77288 L F
.25501 .77146 m .25958 .77048 L .25519 .77072 L F
.38946 .55538 m .38997 .54404 L .38019 .54532 L .683 .77 .917 r
F
.56011 .55028 m .57311 .54839 L .57361 .55297 L .794 .541 .555 r
F
.56011 .55028 m .55961 .54569 L .57311 .54839 L F
0 g
.57311 .54839 m
.58772 .54878 L
s
.39934 .56094 m .40022 .54877 L .39483 .56004 L .683 .77 .917 r
F
.39934 .56094 m .40924 .55057 L .40022 .54877 L F
.40366 .56712 m .40973 .55515 L .39982 .56552 L F
.40366 .56712 m .4174 .55836 L .40973 .55515 L F
.25885 .77778 m .26401 .77687 L .25977 .77636 L .692 .759 .903 r
F
.25507 .77657 m .25885 .77778 L .25977 .77636 L F
.25435 .77719 m .25885 .77778 L .25507 .77657 L F
.35687 .5571 m .34082 .55229 L .33483 .56079 L .683 .77 .917 r
F
0 g
.25122 .77647 m
.25282 .77627 L
s
.25122 .77647 m
.25122 .77647 L
s
.24964 .77621 m
.25122 .77647 L
s
.58873 .55794 m .58823 .55336 L .60296 .55142 L .673 .452 .578 r
F
.57411 .55755 m .58823 .55336 L .58873 .55794 L .733 .497 .57 r
F
.127 .923 .03 r
.58164 .55532 m
.58166 .55319 L
s
.58687 .55376 m
.58688 .55333 L
s
.57411 .55755 m .57361 .55297 L .58823 .55336 L .733 .497 .57 r
F
.58882 .54196 m .58823 .55336 L .60296 .55142 L .683 .77 .917 r
F
.57907 .5417 m .58823 .55336 L .58882 .54196 L F
.57907 .5417 m .57361 .55297 L .58823 .55336 L F
.56967 .53521 m .57319 .54822 L .57863 .537 L F
.56967 .53521 m .55975 .54554 L .57319 .54822 L F
.34106 .5568 m .33456 .56076 L .33504 .56535 L .194 .109 .525 r
F
.34106 .5568 m .34057 .55222 L .33456 .56076 L F
0 g
.33225 .56971 m
.33456 .56076 L
s
.26428 .77244 m .26403 .77024 L .26365 .76806 L .771 .553 0 r
F
0 g
.26351 .77246 m
.26399 .77041 L
s
.25958 .77048 m .26397 .77024 L .26359 .76808 L .692 .759 .903 r
F
.25952 .77416 m .26428 .77244 L .25987 .77268 L F
.25528 .77366 m .25952 .77416 L .25987 .77268 L F
.25482 .77437 m .25952 .77416 L .25528 .77366 L F
.615 .4485 m .63497 .4367 L .61267 .44482 L .673 .757 .914 r
F
.615 .4485 m .63962 .44406 L .63497 .4367 L F
.56834 .43426 m .54694 .42697 L .54155 .43448 L F
.5725 .43101 m .54694 .42697 L .56834 .43426 L F
.67086 .68512 m .66487 .67806 L .65952 .68021 L .645 .732 .913 r
F
.67394 .68453 m .66487 .67806 L .67086 .68512 L F
.68349 .68587 m .68413 .67765 L .68048 .68492 L F
.68349 .68587 m .69015 .67955 L .68413 .67765 L F
.35768 .56622 m .33552 .56993 L .35366 .57191 L .683 .77 .917 r
F
.25958 .77048 m .26359 .76808 L .25933 .76904 L .692 .759 .903 r
F
.25519 .77072 m .25958 .77048 L .25933 .76904 L F
.26401 .77687 m .26428 .77244 L .26453 .77464 L 0 0 .373 r
F
.25977 .77636 m .26401 .77687 L .26453 .77464 L .692 .759 .903 r
F
0 g
.26262 .77899 m
.26401 .77687 L
s
.4227 .55818 m .43065 .54501 L .41691 .55378 L .683 .77 .917 r
F
.4227 .55818 m .43934 .55162 L .43065 .54501 L F
.2513 .77536 m .2512 .77819 L .25235 .77803 L .692 .759 .903 r
F
.2513 .77536 m .25007 .77816 L .2512 .77819 L F
.2513 .77536 m .25235 .77803 L .25342 .77769 L F
0 g
.25282 .77627 m
.25384 .77583 L
s
.60296 .55142 m .61632 .5427 L .61682 .54728 L .606 .404 .582 r
F
.60347 .556 m .60296 .55142 L .61682 .54728 L F
.58873 .55794 m .60296 .55142 L .60347 .556 L .673 .452 .578 r
F
.59865 .54066 m .60296 .55142 L .61682 .54728 L .683 .77 .917 r
F
.58882 .54196 m .60296 .55142 L .59865 .54066 L F
0 g
.58823 .55336 m
.60296 .55142 L
s
.23806 .77608 m .23819 .77605 L .23844 .77825 L .773 .554 0 r
F
.23806 .77608 m .23781 .77388 L .23819 .77605 L F
.24222 .77364 m .23819 .77605 L .24248 .77509 L .692 .759 .903 r
F
.24222 .77364 m .23781 .77388 L .23819 .77605 L F
0 g
.23819 .77605 m
.23944 .77803 L
s
.25519 .77072 m .25933 .76904 L .25506 .77 L .692 .759 .903 r
F
.2513 .77536 m .24901 .77793 L .25007 .77816 L F
0 g
.24864 .77574 m
.24964 .77621 L
s
.63929 .43837 m .65694 .42289 L .63463 .43101 L .673 .757 .914 r
F
.63929 .43837 m .66392 .43393 L .65694 .42289 L F
.127 .923 .03 r
.65493 .4413 m
.65503 .43804 L
s
.2513 .77536 m .25342 .77769 L .25435 .77719 L .692 .759 .903 r
F
.66008 .67271 m .65146 .66676 L .64523 .67118 L .645 .732 .913 r
F
.66541 .67058 m .65146 .66676 L .66008 .67271 L F
.24701 .77632 m .24356 .77861 L .24743 .77698 L .692 .759 .903 r
F
.24701 .77632 m .24272 .77729 L .24356 .77861 L F
.2513 .77536 m .24811 .77753 L .24901 .77793 L F
0 g
.24798 .77515 m
.24864 .77574 L
s
.69564 .6748 m .69719 .66576 L .69056 .67205 L .645 .732 .913 r
F
.69564 .6748 m .70481 .66989 L .69719 .66576 L F
.38043 .56193 m .3714 .55256 L .36341 .5566 L .683 .77 .917 r
F
.38504 .56055 m .3714 .55256 L .38043 .56193 L F
.24663 .7734 m .24248 .77509 L .24676 .77412 L .692 .759 .903 r
F
.24663 .7734 m .24222 .77364 L .24248 .77509 L F
.25528 .77366 m .25987 .77268 L .25546 .77292 L F
.24658 .77046 m .24202 .77143 L .24641 .7712 L F
.67394 .68453 m .67105 .67688 L .66487 .67806 L .645 .732 .913 r
F
.67723 .68446 m .67105 .67688 L .67394 .68453 L F
.2513 .77536 m .25435 .77719 L .25507 .77657 L .692 .759 .903 r
F
0 g
.25384 .77583 m
.25455 .77527 L
s
.68048 .68492 m .67762 .67674 L .67723 .68446 L .645 .732 .913 r
F
.68048 .68492 m .68413 .67765 L .67762 .67674 L F
0 g
.25455 .77527 m
.25498 .77458 L
s
.66392 .43393 m .66358 .42824 L .65661 .4172 L .986 .71 .374 r
F
0 g
.66358 .42824 m
.66552 .44019 L
s
.24759 .77445 m
.24798 .77515 L
s
.65952 .68021 m .64459 .67867 L .65534 .68318 L .645 .732 .913 r
F
.26428 .77244 m .26365 .76806 L .2639 .77026 L .771 .553 0 r
F
.26453 .77464 m .26428 .77244 L .2639 .77026 L F
0 g
.26376 .77466 m
.26424 .77261 L
s
.25987 .77268 m .26428 .77244 L .2639 .77026 L .692 .759 .903 r
F
.25506 .77 m .25849 .76773 L .25464 .76934 L F
0 g
.25465 .76934 m
.25493 .71751 L
s
.25506 .77 m .25933 .76904 L .25849 .76773 L .692 .759 .903 r
F
.25977 .77636 m .26453 .77464 L .26012 .77488 L F
.25553 .77586 m .25977 .77636 L .26012 .77488 L F
.25507 .77657 m .25977 .77636 L .25553 .77586 L F
.24236 .76996 m .23763 .77167 L .24202 .77143 L F
.24658 .77046 m .24236 .76996 L .24202 .77143 L F
.61682 .54728 m .61632 .5427 L .62835 .53664 L .522 .344 .58 r
F
0 g
.60968 .54468 m
.61632 .5427 L
s
.67723 .68446 m .67762 .67674 L .67105 .67688 L .645 .732 .913 r
F
.61234 .43913 m .62694 .42475 L .60849 .436 L .673 .757 .914 r
F
.61234 .43913 m .63463 .43101 L .62694 .42475 L F
.54694 .42697 m .51745 .43094 L .54155 .43448 L F
.37692 .56853 m .36389 .56118 L .35768 .56622 L .683 .77 .917 r
F
.38091 .56652 m .36389 .56118 L .37692 .56853 L F
.2513 .77536 m .24743 .77698 L .24811 .77753 L .692 .759 .903 r
F
.69911 .68575 m .70448 .67737 L .69526 .68231 L .645 .732 .913 r
F
.69911 .68575 m .71025 .68253 L .70448 .67737 L F
.39483 .56004 m .39046 .54851 L .38995 .55991 L .683 .77 .917 r
F
.39483 .56004 m .40022 .54877 L .39046 .54851 L F
.6073 .53323 m .61618 .54256 L .62816 .53653 L F
.5981 .53597 m .61618 .54256 L .6073 .53323 L F
.65109 .67044 m .64507 .67111 L .64483 .67489 L .352 .179 .501 r
F
.65109 .67044 m .65133 .66667 L .64507 .67111 L F
0 g
.64101 .67648 m
.64507 .67111 L
s
.25987 .77268 m .2639 .77026 L .25962 .77123 L .692 .759 .903 r
F
.25546 .77292 m .25987 .77268 L .25962 .77123 L F
.24236 .76996 m .23815 .76946 L .23763 .77167 L F
.23833 .77165 m .23756 .77168 L .23781 .77388 L 0 0 .372 r
F
0 g
.23789 .77355 m
.23794 .77385 L
s
.23833 .77165 m .23808 .76945 L .23756 .77168 L 0 0 .372 r
F
.36306 .55209 m .34082 .55229 L .35687 .5571 L .683 .77 .917 r
F
.2513 .77536 m .25507 .77657 L .25553 .77586 L .692 .759 .903 r
F
.24247 .77584 m .23844 .77825 L .24272 .77729 L F
.24247 .77584 m .23806 .77608 L .23844 .77825 L F
0 g
.23844 .77825 m
.2397 .78023 L
s
.24704 .76975 m .24236 .76996 L .24658 .77046 L .692 .759 .903 r
F
.25546 .77292 m .25962 .77123 L .25533 .77219 L F
.71049 .67875 m .71073 .67497 L .70495 .66981 L .927 .677 .54 r
F
0 g
.71073 .67497 m
.71422 .68078 L
s
.25498 .77458 m
.25509 .77377 L
s
.25933 .76904 m .26234 .76611 L .25849 .76773 L .692 .759 .903 r
F
.25933 .76904 m .26359 .76808 L .26234 .76611 L F
.56833 .32188 m .54562 .31952 L .54519 .32682 L .591 .366 .543 r
F
0 g
.52515 .33555 m
.54519 .32682 L
s
.56833 .32188 m .56875 .31458 L .54562 .31952 L .591 .366 .543 r
F
0 g
.52557 .32825 m
.54562 .31952 L
s
.24753 .77363 m
.24759 .77445 L
s
.56888 .44561 m .54195 .44582 L .56617 .44938 L .673 .757 .914 r
F
.38504 .56055 m .38063 .5498 L .3714 .55256 L .683 .77 .917 r
F
.38995 .55991 m .38063 .5498 L .38504 .56055 L F
.25464 .76934 m .25714 .76663 L .25397 .7688 L .692 .759 .903 r
F
.25464 .76934 m .25849 .76773 L .25714 .76663 L F
.25105 .77316 m .25491 .77153 L .25423 .77099 L F
0 g
.25464 .77131 m
.25465 .76968 L
s
.25105 .77316 m .25533 .77219 L .25491 .77153 L .692 .759 .903 r
F
0 g
.25463 .77273 m
.25464 .77183 L
s
.2513 .77536 m .24701 .77632 L .24743 .77698 L .692 .759 .903 r
F
.60807 .43037 m .61625 .41447 L .60298 .42802 L .673 .757 .914 r
F
.60807 .43037 m .62642 .41918 L .61625 .41447 L F
.64042 .32448 m .61825 .30985 L .61783 .31715 L .794 .542 .556 r
F
.64001 .33178 m .64042 .32448 L .61783 .31715 L F
0 g
.64042 .32448 m
.6596 .33526 L
s
.5606 .55486 m .57361 .55297 L .57411 .55755 L .794 .541 .555 r
F
.5606 .55486 m .56011 .55028 L .57361 .55297 L F
.57007 .5399 m .57361 .55297 L .57907 .5417 L .683 .77 .917 r
F
.57007 .5399 m .56011 .55028 L .57361 .55297 L F
0 g
.57361 .55297 m
.58823 .55336 L
s
.38995 .55991 m .39046 .54851 L .38063 .5498 L .683 .77 .917 r
F
.39982 .56552 m .4007 .55335 L .39531 .56462 L F
.39982 .56552 m .40973 .55515 L .4007 .55335 L F
.24688 .7756 m .24272 .77729 L .24701 .77632 L .692 .759 .903 r
F
.24688 .7756 m .24247 .77584 L .24272 .77729 L F
.58932 .54654 m .58873 .55794 L .60347 .556 L .683 .77 .917 r
F
.127 .923 .03 r
.59585 .57082 m
.59602 .55698 L
s
.59427 .57142 m
.5946 .55717 L
s
.57957 .54628 m .58873 .55794 L .58932 .54654 L .683 .77 .917 r
F
.127 .923 .03 r
.58513 .63108 m
.58667 .56266 L
s
.58667 .56266 m
.58678 .55789 L
s
.58154 .5649 m
.58161 .55775 L
s
.57957 .54628 m .57411 .55755 L .58873 .55794 L .683 .77 .917 r
F
.25553 .77586 m .26012 .77488 L .25571 .77512 L .692 .759 .903 r
F
.2513 .77536 m .25553 .77586 L .25571 .77512 L F
.24681 .77266 m .24222 .77364 L .24663 .7734 L F
.2639 .77026 m .26365 .76806 L .2624 .76608 L .976 .674 .311 r
F
0 g
.26365 .76806 m
.26403 .77024 L
s
.34154 .56139 m .33504 .56535 L .33552 .56993 L .194 .109 .525 r
F
.35719 .56164 m .34106 .5568 L .33504 .56535 L .683 .77 .917 r
F
.34154 .56139 m .34106 .5568 L .33504 .56535 L .194 .109 .525 r
F
0 g
.33273 .57429 m
.33504 .56535 L
s
.24704 .76975 m .24328 .76855 L .24236 .76996 L .692 .759 .903 r
F
.24776 .76913 m .24328 .76855 L .24704 .76975 L F
.26453 .77464 m .2639 .77026 L .26415 .77247 L .771 .553 0 r
F
.26012 .77488 m .26453 .77464 L .26415 .77247 L .692 .759 .903 r
F
0 g
.26401 .77687 m
.26453 .77464 L
s
.25533 .77219 m .25878 .76991 L .25491 .77153 L .692 .759 .903 r
F
.25533 .77219 m .25962 .77123 L .25878 .76991 L F
.24257 .77215 m .23781 .77388 L .24222 .77364 L F
.24681 .77266 m .24257 .77215 L .24222 .77364 L F
.42319 .56276 m .43114 .54959 L .4174 .55836 L .683 .77 .917 r
F
.42319 .56276 m .43983 .5562 L .43114 .54959 L F
.25397 .7688 m .25535 .76584 L .25307 .7684 L .692 .759 .903 r
F
.25397 .7688 m .25714 .76663 L .25535 .76584 L F
.24328 .76855 m .23815 .76946 L .24236 .76996 L F
.26012 .77488 m .26415 .77247 L .25987 .77343 L F
.25571 .77512 m .26012 .77488 L .25987 .77343 L F
.2513 .77536 m .24688 .7756 L .24701 .77632 L F
.60347 .556 m .61682 .54728 L .61733 .55187 L .606 .404 .582 r
F
.59915 .54525 m .60347 .556 L .61733 .55187 L .683 .77 .917 r
F
.58932 .54654 m .60347 .556 L .59915 .54525 L F
0 g
.58873 .55794 m
.60347 .556 L
s
.23858 .77385 m .23781 .77388 L .23806 .77608 L 0 0 .372 r
F
0 g
.23814 .77575 m
.23819 .77605 L
s
.24257 .77215 m .23833 .77165 L .23781 .77388 L .692 .759 .903 r
F
.23858 .77385 m .23833 .77165 L .23781 .77388 L 0 0 .372 r
F
.127 .923 .03 r
.23762 .76378 m
.23798 .78222 L
s
.65976 .67643 m .65109 .67044 L .64483 .67489 L .645 .732 .913 r
F
.66511 .67428 m .65109 .67044 L .65976 .67643 L F
.6955 .67853 m .69705 .66945 L .69039 .67577 L F
.6955 .67853 m .70471 .67359 L .69705 .66945 L F
.24776 .76913 m .24472 .76731 L .24328 .76855 L .692 .759 .903 r
F
.24868 .76864 m .24472 .76731 L .24776 .76913 L F
.56856 .43992 m .54705 .43259 L .54163 .44013 L .673 .757 .914 r
F
.57274 .43665 m .54705 .43259 L .56856 .43992 L F
.25571 .77512 m .25987 .77343 L .25558 .7744 L .692 .759 .903 r
F
.2513 .77536 m .25571 .77512 L .25558 .7744 L F
.24727 .77195 m .24257 .77215 L .24681 .77266 L F
.25962 .77123 m .26265 .76829 L .25878 .76991 L F
.25962 .77123 m .2639 .77026 L .26265 .76829 L F
.25307 .7684 m .25325 .76539 L .25202 .76817 L F
.25307 .7684 m .25535 .76584 L .25325 .76539 L F
.25849 .76773 m .26031 .76447 L .25714 .76663 L F
.25849 .76773 m .26234 .76611 L .26031 .76447 L F
.38091 .56652 m .37189 .55715 L .36389 .56118 L .683 .77 .917 r
F
.38552 .56514 m .37189 .55715 L .38091 .56652 L F
.25491 .77153 m .25742 .76881 L .25423 .77099 L .692 .759 .903 r
F
.25491 .77153 m .25878 .76991 L .25742 .76881 L F
0 0 0 r
2.5 Mabswid
.65486 .44351 Mdot
.127 .923 .03 r
.5 Mabswid
.40128 8.82346 m
.53802 4.30472 L
s
.53802 4.30472 m
.61746 1.67954 L
s
.2513 .77536 m .24706 .77486 L .24688 .7756 L .692 .759 .903 r
F
.2513 .77536 m .24752 .77415 L .24706 .77486 L F
.2513 .77536 m .24824 .77353 L .24752 .77415 L F
0 g
.24753 .77363 m
.24806 .77261 L
s
.2513 .77536 m .24917 .77303 L .24824 .77353 L .692 .759 .903 r
F
.2513 .77536 m .25024 .77268 L .24917 .77303 L F
.2513 .77536 m .25139 .77253 L .25024 .77268 L F
.2513 .77536 m .25253 .77256 L .25139 .77253 L F
.2513 .77536 m .25358 .77279 L .25253 .77256 L F
.2513 .77536 m .25448 .77319 L .25358 .77279 L F
.2513 .77536 m .25516 .77374 L .25448 .77319 L F
0 g
.25463 .77273 m
.25503 .77363 L
s
.25509 .77377 m
.25509 .77377 L
s
.2513 .77536 m .25558 .7744 L .25516 .77374 L .692 .759 .903 r
F
.24868 .76864 m .24656 .76631 L .24472 .76731 L F
.24975 .7683 m .24656 .76631 L .24868 .76864 L F
.5725 .43101 m .55525 .42046 L .54694 .42697 L .673 .757 .914 r
F
.57783 .42847 m .55525 .42046 L .5725 .43101 L F
.65085 .67422 m .64483 .67489 L .64459 .67867 L .352 .179 .501 r
F
.65085 .67422 m .65109 .67044 L .64483 .67489 L F
0 g
.64077 .68026 m
.64483 .67489 L
s
.66541 .67058 m .65946 .66355 L .65146 .66676 L .645 .732 .913 r
F
.67156 .6694 m .65946 .66355 L .66541 .67058 L F
.25202 .76817 m .25098 .76532 L .25089 .76814 L .692 .759 .903 r
F
.25202 .76817 m .25325 .76539 L .25098 .76532 L F
.24706 .77486 m .24247 .77584 L .24688 .7756 L F
.2639 .77026 m .2624 .76608 L .26265 .76829 L .976 .674 .311 r
F
.26415 .77247 m .2639 .77026 L .26265 .76829 L F
0 g
.2639 .77026 m
.26428 .77244 L
s
.63962 .44406 m .65728 .42858 L .63497 .4367 L .673 .757 .914 r
F
.63962 .44406 m .66425 .43962 L .65728 .42858 L F
.127 .923 .03 r
.65028 .59495 m
.65486 .44351 L
s
0 g
.25356 .7719 m
.25463 .77273 L
s
.25463 .77273 m
.25463 .77273 L
s
.43934 .55162 m .43885 .54703 L .43016 .54042 L .933 .647 .475 r
F
0 g
.43885 .54703 m
.44413 .55498 L
s
.69056 .67205 m .68821 .66292 L .68457 .67016 L .645 .732 .913 r
F
.69056 .67205 m .69719 .66576 L .68821 .66292 L F
.61682 .54728 m .62835 .53664 L .62886 .54123 L .522 .344 .58 r
F
.61733 .55187 m .61682 .54728 L .62886 .54123 L F
.60789 .5379 m .61682 .54728 L .62886 .54123 L .683 .77 .917 r
F
.59865 .54066 m .61682 .54728 L .60789 .5379 L F
0 g
.61018 .54927 m
.61682 .54728 L
s
.41628 .54928 m .41851 .53576 L .40865 .54609 L .683 .77 .917 r
F
.41628 .54928 m .42996 .54055 L .41851 .53576 L F
.24975 .7683 m .2487 .76563 L .24656 .76631 L .692 .759 .903 r
F
.25089 .76814 m .2487 .76563 L .24975 .7683 L F
0 g
.24806 .77261 m
.24806 .77261 L
s
.24806 .77261 m
.24918 .77182 L
s
.25089 .76814 m .25098 .76532 L .2487 .76563 L .692 .759 .903 r
F
.24727 .77195 m .2435 .77074 L .24257 .77215 L F
.24799 .77132 m .2435 .77074 L .24727 .77195 L F
.39531 .56462 m .39094 .55309 L .39044 .56449 L .683 .77 .917 r
F
.39531 .56462 m .4007 .55335 L .39094 .55309 L F
.71049 .67875 m .70495 .66981 L .70471 .67359 L .927 .677 .54 r
F
.71025 .68253 m .71049 .67875 L .70471 .67359 L F
0 g
.71049 .67875 m
.71399 .68456 L
s
.24328 .76855 m .23953 .76735 L .23815 .76946 L .692 .759 .903 r
F
.23972 .76953 m .23808 .76945 L .23833 .77165 L .179 .09 .51 r
F
.23972 .76953 m .23947 .76733 L .23808 .76945 L F
0 g
.23756 .77168 m
.23808 .76945 L
s
.25558 .7744 m .25903 .77211 L .25516 .77374 L .692 .759 .903 r
F
.25558 .7744 m .25987 .77343 L .25903 .77211 L F
.24282 .77436 m .23806 .77608 L .24247 .77584 L F
.24706 .77486 m .24282 .77436 L .24247 .77584 L F
.25423 .77099 m .25562 .76801 L .25333 .77058 L F
.25423 .77099 m .25742 .76881 L .25562 .76801 L F
.36341 .5566 m .34106 .5568 L .35719 .56164 L .683 .77 .917 r
F
.59338 .31377 m .56917 .30729 L .56875 .31458 L .667 .43 .553 r
F
.59338 .31377 m .5938 .30647 L .56917 .30729 L F
0 g
.54604 .31223 m
.56917 .30729 L
s
.2435 .77074 m .23833 .77165 L .24257 .77215 L .692 .759 .903 r
F
.24282 .77436 m .23858 .77385 L .23806 .77608 L F
0 g
.23806 .77608 m
.23844 .77825 L
s
.61783 .31715 m .61825 .30985 L .5938 .30647 L .732 .486 .557 r
F
0 g
.61825 .30985 m
.64083 .31718 L
s
.24472 .76731 m .23953 .76735 L .24328 .76855 L .692 .759 .903 r
F
.66392 .43393 m .65661 .4172 L .65694 .42289 L .986 .71 .374 r
F
.66425 .43962 m .66392 .43393 L .65694 .42289 L F
0 g
.66392 .43393 m
.66585 .44588 L
s
.24799 .77132 m .24494 .76949 L .2435 .77074 L .692 .759 .903 r
F
.24892 .77082 m .24494 .76949 L .24799 .77132 L F
.61267 .44482 m .62727 .43045 L .60882 .44169 L .673 .757 .914 r
F
.61267 .44482 m .63497 .4367 L .62727 .43045 L F
.38552 .56514 m .38111 .55439 L .37189 .55715 L .683 .77 .917 r
F
.39044 .56449 m .38111 .55439 L .38552 .56514 L F
.24752 .77415 m .24282 .77436 L .24706 .77486 L .692 .759 .903 r
F
.25987 .77343 m .2629 .77049 L .25903 .77211 L F
.25987 .77343 m .26415 .77247 L .2629 .77049 L F
0 g
.25248 .77153 m
.25356 .7719 L
s
.54705 .43259 m .5174 .43657 L .54163 .44013 L .673 .757 .914 r
F
.57057 .54448 m .57411 .55755 L .57957 .54628 L .683 .77 .917 r
F
.57057 .54448 m .5606 .55486 L .57411 .55755 L F
0 g
.57411 .55755 m
.58873 .55794 L
s
.24918 .77182 m
.25029 .77149 L
s
.25333 .77058 m .25351 .76756 L .25228 .77036 L .692 .759 .903 r
F
.25333 .77058 m .25562 .76801 L .25351 .76756 L F
.39044 .56449 m .39094 .55309 L .38111 .55439 L .683 .77 .917 r
F
.54863 .54546 m .55961 .54569 L .56011 .55028 L .861 .591 .529 r
F
.54863 .54546 m .54813 .54088 L .55961 .54569 L F
0 g
.55961 .54569 m
.56372 .54651 L
s
.26265 .76829 m .2624 .76608 L .26035 .76444 L .933 .634 .45 r
F
0 g
.2624 .76608 m
.26365 .76806 L
s
.25878 .76991 m .2606 .76664 L .25742 .76881 L .692 .759 .903 r
F
.25878 .76991 m .26265 .76829 L .2606 .76664 L F
.25714 .76663 m .25762 .76327 L .25535 .76584 L F
.25714 .76663 m .26031 .76447 L .25762 .76327 L F
.25516 .77374 m .25767 .77101 L .25448 .77319 L F
.25516 .77374 m .25903 .77211 L .25767 .77101 L F
.35768 .56622 m .34154 .56139 L .33552 .56993 L .683 .77 .917 r
F
0 g
.33321 .57888 m
.33552 .56993 L
s
.56206 .53201 m .55975 .54554 L .56967 .53521 L .683 .77 .917 r
F
.56206 .53201 m .54834 .54074 L .55975 .54554 L F
.24892 .77082 m .24679 .76849 L .24494 .76949 L .692 .759 .903 r
F
.24999 .77048 m .24679 .76849 L .24892 .77082 L F
0 g
.25139 .7714 m
.25248 .77153 L
s
.25029 .77149 m
.25139 .7714 L
s
.25228 .77036 m .25123 .76749 L .25114 .77032 L .692 .759 .903 r
F
.25228 .77036 m .25351 .76756 L .25123 .76749 L F
.26415 .77247 m .26265 .76829 L .2629 .77049 L .976 .674 .311 r
F
0 g
.26415 .77247 m
.26453 .77464 L
s
.65952 .68021 m .65085 .67422 L .64459 .67867 L .645 .732 .913 r
F
.127 .923 .03 r
.65017 .59861 m
.65028 .59495 L
s
0 g
.64053 .68404 m
.64459 .67867 L
s
.66487 .67806 m .65085 .67422 L .65952 .68021 L .645 .732 .913 r
F
.24999 .77048 m .24894 .76781 L .24679 .76849 L .692 .759 .903 r
F
.25114 .77032 m .24894 .76781 L .24999 .77048 L F
.25114 .77032 m .25123 .76749 L .24894 .76781 L F
.69526 .68231 m .69681 .67323 L .69015 .67955 L .645 .732 .913 r
F
.69526 .68231 m .70448 .67737 L .69681 .67323 L F
.24752 .77415 m .24374 .77294 L .24282 .77436 L .692 .759 .903 r
F
.24824 .77353 m .24374 .77294 L .24752 .77415 L F
.60298 .42802 m .60427 .41162 L .597 .42659 L .673 .757 .914 r
F
.60298 .42802 m .61625 .41447 L .60427 .41162 L F
.23997 .77173 m .23833 .77165 L .23858 .77385 L .179 .09 .51 r
F
.2435 .77074 m .23972 .76953 L .23833 .77165 L .692 .759 .903 r
F
.23997 .77173 m .23972 .76953 L .23833 .77165 L .179 .09 .51 r
F
0 g
.23781 .77388 m
.23833 .77165 L
s
.60849 .436 m .61672 .42003 L .60338 .43364 L .673 .757 .914 r
F
.60849 .436 m .62694 .42475 L .61672 .42003 L F
.25448 .77319 m .25587 .77021 L .25358 .77279 L .692 .759 .903 r
F
.25448 .77319 m .25767 .77101 L .25587 .77021 L F
.67156 .6694 m .66868 .66178 L .65946 .66355 L .645 .732 .913 r
F
.67809 .66925 m .66868 .66178 L .67156 .6694 L F
.24472 .76731 m .24168 .76548 L .23953 .76735 L .692 .759 .903 r
F
.24656 .76631 m .24168 .76548 L .24472 .76731 L F
.68457 .67016 m .67848 .66156 L .67809 .66925 L .645 .732 .913 r
F
.68457 .67016 m .68821 .66292 L .67848 .66156 L F
.24374 .77294 m .23858 .77385 L .24282 .77436 L .692 .759 .903 r
F
.24494 .76949 m .23972 .76953 L .2435 .77074 L F
.24824 .77353 m .24519 .77169 L .24374 .77294 L F
.24917 .77303 m .24519 .77169 L .24824 .77353 L F
.25535 .76584 m .25447 .7626 L .25325 .76539 L F
.25535 .76584 m .25762 .76327 L .25447 .7626 L F
.66511 .67428 m .65913 .66722 L .65109 .67044 L .645 .732 .913 r
F
.67129 .6731 m .65913 .66722 L .66511 .67428 L F
.69039 .67577 m .68802 .66659 L .68437 .67387 L F
.69039 .67577 m .69705 .66945 L .68802 .66659 L F
.25358 .77279 m .25376 .76976 L .25253 .77256 L .692 .759 .903 r
F
.25358 .77279 m .25587 .77021 L .25376 .76976 L F
.26265 .76829 m .26035 .76444 L .2606 .76664 L .933 .634 .45 r
F
.2629 .77049 m .26265 .76829 L .2606 .76664 L F
0 g
.26265 .76829 m
.2639 .77026 L
s
.71025 .68253 m .70471 .67359 L .70448 .67737 L .927 .677 .54 r
F
0 g
.71025 .68253 m
.71375 .68834 L
s
.25903 .77211 m .26085 .76884 L .25767 .77101 L .692 .759 .903 r
F
.25903 .77211 m .2629 .77049 L .26085 .76884 L F
.25742 .76881 m .25791 .76544 L .25562 .76801 L F
.25742 .76881 m .2606 .76664 L .25791 .76544 L F
.24188 .76765 m .23947 .76733 L .23972 .76953 L .388 .236 .55 r
F
.24188 .76765 m .24163 .76545 L .23947 .76733 L F
0 g
.23808 .76945 m
.23947 .76733 L
s
.67809 .66925 m .67848 .66156 L .66868 .66178 L .645 .732 .913 r
F
.43934 .55162 m .43016 .54042 L .43065 .54501 L .933 .647 .475 r
F
.43983 .5562 m .43934 .55162 L .43065 .54501 L F
0 g
.43934 .55162 m
.44462 .55956 L
s
.61733 .55187 m .62886 .54123 L .62936 .54581 L .522 .344 .58 r
F
.6084 .54249 m .61733 .55187 L .62936 .54581 L .683 .77 .917 r
F
.59915 .54525 m .61733 .55187 L .6084 .54249 L F
0 g
.60347 .556 m
.61733 .55187 L
s
.24917 .77303 m .24704 .77069 L .24519 .77169 L .692 .759 .903 r
F
.25024 .77268 m .24704 .77069 L .24917 .77303 L F
.57783 .42847 m .56592 .41538 L .55525 .42046 L .673 .757 .914 r
F
.58397 .42683 m .56592 .41538 L .57783 .42847 L F
.56888 .44561 m .54737 .43828 L .54195 .44582 L F
.57306 .44234 m .54737 .43828 L .56888 .44561 L F
.41691 .55378 m .41915 .54019 L .40924 .55057 L .683 .77 .917 r
F
.41691 .55378 m .43065 .54501 L .41915 .54019 L F
.25253 .77256 m .25148 .76969 L .25139 .77253 L .692 .759 .903 r
F
.25253 .77256 m .25376 .76976 L .25148 .76969 L F
.24656 .76631 m .24445 .76399 L .24168 .76548 L F
.2487 .76563 m .24445 .76399 L .24656 .76631 L F
.63408 .4254 m .64479 .40797 L .62642 .41918 L .673 .757 .914 r
F
.63408 .4254 m .65627 .41732 L .64479 .40797 L F
.25024 .77268 m .24919 .77001 L .24704 .77069 L .692 .759 .903 r
F
.25139 .77253 m .24919 .77001 L .25024 .77268 L F
.61783 .31715 m .5938 .30647 L .59338 .31377 L .732 .486 .557 r
F
0 g
.5938 .30647 m
.61825 .30985 L
s
.56917 .30729 m
.5938 .30647 L
s
.25139 .77253 m .25148 .76969 L .24919 .77001 L .692 .759 .903 r
F
.25325 .76539 m .25107 .7625 L .25098 .76532 L F
.25325 .76539 m .25447 .7626 L .25107 .7625 L F
.36389 .56118 m .34154 .56139 L .35768 .56622 L .683 .77 .917 r
F
.24374 .77294 m .23997 .77173 L .23858 .77385 L .692 .759 .903 r
F
0 g
.23806 .77608 m
.23858 .77385 L
s
.64001 .33178 m .61783 .31715 L .61742 .32445 L .794 .542 .556 r
F
0 g
.64001 .33178 m
.65919 .34256 L
s
.2606 .76664 m .26035 .76444 L .25766 .76323 L .861 .577 .507 r
F
0 g
.26035 .76444 m
.2624 .76608 L
s
.57274 .43665 m .5554 .42604 L .54705 .43259 L .673 .757 .914 r
F
.5781 .4341 m .5554 .42604 L .57274 .43665 L F
.127 .923 .03 r
.3971 8.82463 m
.42913 .96835 L
s
.42913 .96835 m
.4304 .65658 L
s
.38261 .65359 m
.38263 .65489 L
s
.38402 .75377 m
.38425 .77034 L
s
.38323 .69781 m
.38331 .7033 L
s
.38332 .70395 m
.38402 .75377 L
s
.38283 .6692 m
.38323 .69781 L
s
.2487 .76563 m .24765 .76297 L .24445 .76399 L .692 .759 .903 r
F
.25098 .76532 m .24765 .76297 L .2487 .76563 L F
.24494 .76949 m .24188 .76765 L .23972 .76953 L F
.24679 .76849 m .24188 .76765 L .24494 .76949 L F
.25098 .76532 m .25107 .7625 L .24765 .76297 L F
.58892 .5259 m .58833 .53726 L .5981 .53597 L .683 .77 .917 r
F
.58892 .5259 m .5981 .53597 L .59381 .52526 L F
.58942 .53055 m .58882 .54196 L .59865 .54066 L F
.58942 .53055 m .59865 .54066 L .59433 .5299 L F
.58873 .47503 m .59031 .47529 L .59039 .51743 L .751 .49 .538 r
F
.591 .51826 m .58892 .5259 L .59381 .52526 L .683 .77 .917 r
F
.5913 .52232 m .58942 .53055 L .59433 .5299 L F
.59057 .5186 m .58892 .5259 L .591 .51826 L F
.59062 .51775 m .58892 .5259 L .59077 .51768 L F
.58935 .51761 m .58892 .5259 L .59064 .51745 L F
.59039 .51743 m .59064 .51745 L .59065 .51738 L F
.58935 .51761 m .59064 .51745 L .59039 .51743 L F
.58708 .47395 m .58774 .47455 L .58782 .51693 L .93 .648 .485 r
F
.58827 .5171 m .58796 .51773 L .58936 .51749 L .683 .77 .917 r
F
.58665 .47242 m .5867 .47325 L .58678 .51584 L .777 .62 .057 r
F
.58703 .51965 m .58407 .52577 L .58712 .52099 L .683 .77 .917 r
F
.57959 .52488 m .57863 .537 L .58407 .52577 L F
.58693 .52233 m .57621 .52791 L .58004 .52951 L F
.58737 .51677 m .58736 .51677 L .58827 .5171 L F
.58933 .51805 m .58407 .52577 L .58892 .5259 L F
.58869 .52186 m .58454 .53041 L .58943 .52241 L F
.58407 .52577 m .58833 .53726 L .58892 .5259 L F
.58821 .51722 m .5829 .52193 L .58407 .52577 L F
.5829 .52193 m .57959 .52488 L .58109 .52518 L F
.5829 .52193 m .58109 .52518 L .58407 .52577 L F
.58665 .47242 m .58676 .51563 L .58673 .51511 L .777 .62 .057 r
F
.5867 .47325 m .58705 .51627 L .58678 .51584 L .988 .719 .381 r
F
.58665 .47242 m .58678 .51584 L .58676 .51563 L .777 .62 .057 r
F
.5867 .47325 m .58708 .47395 L .58715 .51644 L .988 .719 .381 r
F
.58719 .47139 m .58665 .47242 L .58673 .51511 L 0 0 .377 r
F
.5868 .52039 m .586 .5207 L .58685 .52113 L .683 .77 .917 r
F
.58774 .47455 m .58853 .51719 L .58782 .51693 L .846 .571 .522 r
F
.58708 .47395 m .58782 .51693 L .58763 .51679 L .93 .648 .485 r
F
.58774 .47455 m .58873 .47503 L .58881 .51729 L .846 .571 .522 r
F
.58774 .47455 m .58881 .51729 L .58872 .51726 L F
.58687 .51729 m .58694 .51829 L .58782 .5175 L .683 .77 .917 r
F
.58972 .5248 m .58454 .53041 L .58942 .53055 L F
.58407 .52577 m .57863 .537 L .58833 .53726 L F
.58454 .53041 m .57907 .5417 L .58882 .54196 L F
.58004 .52951 m .57907 .5417 L .58454 .53041 L F
.5887 .52745 m .58054 .5341 L .58504 .535 L F
.58861 .52151 m .58882 .52158 L .58883 .52587 L .846 .571 .522 r
F
.58454 .53041 m .58882 .54196 L .58942 .53055 L .683 .77 .917 r
F
.59037 .52644 m .58504 .535 L .58992 .53513 L F
.58936 .51749 m .58911 .51789 L .58933 .51805 L F
.58988 .52167 m .58973 .52192 L .58987 .52196 L F
.58979 .5235 m .58942 .53055 L .5913 .52232 L F
.58994 .51739 m .59018 .52598 L .58881 .51729 L .751 .49 .538 r
F
.5904 .526 m .58937 .52607 L .59037 .52644 L .683 .77 .917 r
F
.58944 .52592 m .58937 .52607 L .5904 .526 L F
.59018 .52598 m .59042 .53431 L .58963 .52594 L .751 .49 .538 r
F
.58987 .52196 m .5889 .5235 L .58972 .5248 L .683 .77 .917 r
F
.58869 .52186 m .58943 .52241 L .58988 .52167 L F
.59018 .52598 m .58963 .52594 L .58881 .51729 L .751 .49 .538 r
F
.58988 .52167 m .58979 .5235 L .59108 .52177 L .683 .77 .917 r
F
.59006 .52169 m .5904 .52171 L .59042 .53431 L .751 .49 .538 r
F
.59052 .52371 m .58944 .52592 L .5904 .526 L .683 .77 .917 r
F
.58937 .52607 m .58504 .535 L .59037 .52644 L F
.58783 .52551 m .58884 .53404 L .58785 .53356 L .846 .571 .522 r
F
.58736 .51677 m .58782 .5175 L .58827 .5171 L .683 .77 .917 r
F
.58796 .51773 m .58703 .51965 L .58858 .51871 L F
.58911 .51789 m .58407 .52577 L .58933 .51805 L F
.58782 .51693 m .58808 .52131 L .58783 .52122 L .846 .571 .522 r
F
.59001 .51912 m .5868 .52039 L .58683 .52086 L .683 .77 .917 r
F
.58712 .52096 m .58683 .52086 L .58685 .52113 L F
.59001 .51912 m .58683 .52086 L .58712 .52096 L F
.58973 .52192 m .58454 .53041 L .58987 .52196 L F
.58783 .52122 m .58834 .52569 L .58783 .52551 L .846 .571 .522 r
F
.58869 .52186 m .58004 .52951 L .58454 .53041 L .683 .77 .917 r
F
.58881 .51729 m .58922 .52162 L .58882 .52158 L .751 .49 .538 r
F
.59001 .51912 m .58793 .5213 L .58869 .52186 L .683 .77 .917 r
F
.58793 .5213 m .58004 .52951 L .58869 .52186 L F
.58736 .51677 m .58687 .51729 L .58782 .5175 L F
.58703 .51965 m .58712 .52099 L .58858 .51871 L F
.58763 .51679 m .58769 .52112 L .58715 .51644 L .93 .648 .485 r
F
.5889 .5235 m .58454 .53041 L .58972 .5248 L .683 .77 .917 r
F
.58708 .47395 m .58763 .51679 L .58715 .51644 L .93 .648 .485 r
F
.58817 .51719 m .57959 .52488 L .58821 .51722 L .683 .77 .917 r
F
.58774 .47455 m .58872 .51726 L .58853 .51719 L .846 .571 .522 r
F
.58873 .47503 m .58994 .51739 L .58881 .51729 L .751 .49 .538 r
F
.58951 .51454 m .58294 .51713 L .57578 .52328 L .683 .77 .917 r
F
.58294 .51713 m .57291 .52108 L .57494 .52264 L F
.58294 .51713 m .57494 .52264 L .57578 .52328 L F
.58832 .47059 m .58719 .47139 L .58727 .51414 L .4 .211 .506 r
F
.58769 .52112 m .58733 .52085 L .58715 .51644 L .93 .648 .485 r
F
.58359 .5207 m .57578 .52328 L .57959 .52488 L .683 .77 .917 r
F
.57578 .52328 m .56206 .53201 L .56967 .53521 L F
.58128 .52257 m .57158 .52304 L .57333 .5257 L F
.58688 .51484 m .58684 .5192 L .58727 .51414 L 0 0 .377 r
F
.58678 .52013 m .58692 .52463 L .58679 .52441 L .988 .719 .381 r
F
.58685 .52113 m .57621 .52791 L .58693 .52233 L .683 .77 .917 r
F
.58688 .52028 m .58699 .52473 L .58678 .52013 L .988 .719 .381 r
F
.588 .52633 m .58054 .5341 L .5887 .52745 L .683 .77 .917 r
F
.58699 .52473 m .58719 .53296 L .58692 .52463 L .988 .719 .381 r
F
.58699 .52473 m .58692 .52463 L .58678 .52013 L F
.57578 .52328 m .56967 .53521 L .57959 .52488 L .683 .77 .917 r
F
.58685 .52113 m .57333 .5257 L .57621 .52791 L F
.58684 .52449 m .57159 .52471 L .57208 .52763 L F
.58677 .51998 m .58678 .52013 L .58679 .52441 L .777 .62 .057 r
F
.58004 .52951 m .57007 .5399 L .57907 .5417 L .683 .77 .917 r
F
.58142 .53318 m .57671 .53249 L .58054 .5341 L F
.59052 .52371 m .58463 .52745 L .58142 .53318 L F
.58463 .52745 m .57671 .53249 L .58142 .53318 L F
.58679 .52441 m .58719 .53296 L .58681 .53226 L .988 .719 .381 r
F
.58768 .52155 m .58685 .52113 L .58693 .52233 L .683 .77 .917 r
F
.58294 .51713 m .57117 .51844 L .57291 .52108 L F
.58628 .51932 m .57188 .51713 L .57109 .52012 L F
.58708 .5206 m .58695 .52039 L .58678 .51584 L .988 .719 .381 r
F
.58745 .51401 m .58737 .51837 L .58758 .51393 L .4 .211 .506 r
F
.58763 .51679 m .58783 .52122 L .58769 .52112 L .93 .648 .485 r
F
.59001 .51912 m .58646 .51988 L .586 .5207 L .683 .77 .917 r
F
.58737 .51837 m .58728 .52272 L .58743 .51833 L .4 .211 .506 r
F
.58737 .51837 m .58743 .51833 L .58758 .51393 L F
.58705 .51627 m .58716 .52073 L .58708 .5206 L .988 .719 .381 r
F
.59001 .51912 m .58679 .51877 L .58628 .51932 L .683 .77 .917 r
F
.58687 .51729 m .57959 .52488 L .58694 .51829 L F
.58679 .51877 m .58587 .51867 L .58619 .51918 L F
.58679 .51877 m .58619 .51918 L .58628 .51932 L F
.5865 .51645 m .57578 .52328 L .58737 .51677 L F
.58587 .51867 m .57188 .51713 L .58628 .51932 L F
.58705 .51627 m .58708 .5206 L .58678 .51584 L .988 .719 .381 r
F
.58708 .5206 m .58712 .52494 L .58695 .52039 L F
.58712 .52494 m .58719 .53296 L .58699 .52473 L F
.58712 .52494 m .58699 .52473 L .58678 .51584 L F
.57959 .52488 m .56967 .53521 L .57863 .537 L .683 .77 .917 r
F
.58718 .52502 m .57208 .52763 L .57383 .53028 L F
.58861 .52151 m .58883 .52587 L .58869 .52582 L .846 .571 .522 r
F
.58708 .5206 m .58716 .52073 L .58719 .53296 L .988 .719 .381 r
F
.59052 .52371 m .58684 .52449 L .58718 .52502 L .683 .77 .917 r
F
.58684 .52449 m .57208 .52763 L .58718 .52502 L F
.58728 .52272 m .58676 .53144 L .5873 .5304 L 0 0 .377 r
F
.58726 .52088 m .58685 .52113 L .58768 .52155 L .683 .77 .917 r
F
.58716 .52073 m .58785 .53356 L .58719 .53296 L .93 .648 .485 r
F
.58715 .51644 m .58733 .52085 L .58716 .52073 L F
.58733 .52085 m .58785 .53356 L .58716 .52073 L F
.58507 .51806 m .57578 .52328 L .58359 .5207 L .683 .77 .917 r
F
.58611 .51995 m .57109 .52012 L .57158 .52304 L F
.58727 .51843 m .587 .52323 L .58728 .52272 L 0 0 .377 r
F
.58727 .51414 m .58713 .51869 L .58727 .51843 L F
.58713 .51869 m .587 .52323 L .58727 .51843 L F
.58646 .51988 m .58533 .51937 L .58611 .51995 L .683 .77 .917 r
F
.58763 .51679 m .58782 .51693 L .58783 .52122 L .93 .648 .485 r
F
.59001 .51912 m .58679 .51929 L .58646 .51988 L .683 .77 .917 r
F
.58679 .51929 m .58533 .51937 L .58646 .51988 L F
.58533 .51937 m .57109 .52012 L .58611 .51995 L F
.58777 .52546 m .57881 .52856 L .57671 .53249 L F
.58692 .52463 m .58719 .53296 L .58679 .52441 L .988 .719 .381 r
F
.587 .52323 m .58676 .53144 L .58728 .52272 L 0 0 .377 r
F
.58679 .52432 m .58679 .52441 L .58681 .53226 L .777 .62 .057 r
F
.58677 .51998 m .58679 .52441 L .58679 .52432 L F
.59052 .52371 m .58676 .52391 L .58684 .52449 L .683 .77 .917 r
F
.58676 .52391 m .58648 .52392 L .58679 .52441 L F
.58676 .52391 m .58679 .52441 L .58684 .52449 L F
.58648 .52392 m .57159 .52471 L .58684 .52449 L F
.5846 .52027 m .57158 .52304 L .58128 .52257 L F
.586 .5207 m .57333 .5257 L .58551 .52159 L F
.58695 .52332 m .57442 .51886 L .57238 .52171 L F
.58937 .52607 m .588 .52633 L .5887 .52745 L F
.58854 .52577 m .588 .52633 L .58937 .52607 L F
.58827 .5171 m .58817 .51719 L .58821 .51722 L F
.58853 .51719 m .58861 .52151 L .58782 .51693 L .846 .571 .522 r
F
.58861 .52151 m .58884 .53404 L .58808 .52131 L F
.58861 .52151 m .58808 .52131 L .58782 .51693 L F
.58853 .51719 m .58882 .52158 L .58861 .52151 L F
.59001 .51912 m .58726 .52088 L .58737 .52105 L .683 .77 .917 r
F
.58796 .52127 m .58737 .52105 L .58768 .52155 L F
.59001 .51912 m .58737 .52105 L .58796 .52127 L F
.59052 .52371 m .58728 .52273 L .58695 .52332 L F
.586 .5207 m .5846 .52027 L .58128 .52257 L F
.58728 .52273 m .57442 .51886 L .58695 .52332 L F
.58684 .5192 m .58681 .52356 L .58713 .51869 L 0 0 .377 r
F
.58681 .52356 m .58676 .53144 L .587 .52323 L F
.58681 .52356 m .587 .52323 L .58713 .51869 L F
.58705 .51627 m .58715 .51644 L .58716 .52073 L .988 .719 .381 r
F
.58684 .5192 m .58713 .51869 L .58727 .51414 L 0 0 .377 r
F
.58646 .51988 m .5846 .52027 L .586 .5207 L .683 .77 .917 r
F
.58769 .52112 m .58774 .52544 L .58733 .52085 L .93 .648 .485 r
F
.5875 .51827 m .58728 .52272 L .58743 .52262 L .4 .211 .506 r
F
.58758 .51393 m .58743 .51833 L .5875 .51827 L F
.58743 .51833 m .58728 .52272 L .5875 .51827 L F
.58832 .47059 m .58745 .51401 L .58758 .51393 L F
.58951 .51454 m .58544 .5154 L .58294 .51713 L .683 .77 .917 r
F
.58544 .5154 m .57117 .51844 L .58294 .51713 L F
.58737 .51677 m .58507 .51806 L .58359 .5207 L F
.58676 .51563 m .58678 .51584 L .58678 .52013 L .777 .62 .057 r
F
.58774 .52544 m .58785 .53356 L .58751 .52527 L .93 .648 .485 r
F
.58834 .52569 m .58884 .53404 L .58783 .52551 L .846 .571 .522 r
F
.58841 .52194 m .5873 .5304 L .58843 .52961 L .4 .211 .506 r
F
.58951 .51454 m .5865 .51645 L .58737 .51677 L .683 .77 .917 r
F
.58951 .51454 m .58737 .51677 L .58827 .5171 L F
.58544 .5154 m .57068 .51553 L .57117 .51844 L F
.58951 .51454 m .58646 .5147 L .58544 .5154 L F
.58646 .5147 m .57068 .51553 L .58544 .5154 L F
.5884 .51336 m .58743 .52262 L .58841 .52194 L .4 .211 .506 r
F
.58832 .47059 m .58758 .51393 L .5884 .51336 L F
.5875 .51827 m .58791 .51799 L .5884 .51336 L F
.58745 .51401 m .58727 .51414 L .58727 .51843 L F
.58719 .47139 m .58688 .51484 L .58727 .51414 L 0 0 .377 r
F
.5867 .47325 m .58715 .51644 L .58705 .51627 L .988 .719 .381 r
F
.58719 .47139 m .58673 .51511 L .58688 .51484 L 0 0 .377 r
F
.58781 .51357 m .58061 .50518 L .57661 .50719 L .683 .77 .917 r
F
.58951 .51454 m .5884 .51336 L .58781 .51357 L F
.5884 .51336 m .58061 .50518 L .58781 .51357 L F
.58943 .47025 m .58832 .47059 L .5884 .51336 L .567 .342 .533 r
F
.58769 .52112 m .58783 .52122 L .58785 .53356 L .93 .648 .485 r
F
.59052 .52371 m .58718 .52502 L .58777 .52546 L .683 .77 .917 r
F
.58553 .51863 m .57392 .51427 L .57188 .51713 L F
.58678 .51584 m .58688 .52028 L .58678 .52013 L .988 .719 .381 r
F
.58676 .51563 m .58678 .52013 L .58677 .51998 L .777 .62 .057 r
F
.59001 .51912 m .58687 .51817 L .58553 .51863 L .683 .77 .917 r
F
.58687 .51817 m .57392 .51427 L .58553 .51863 L F
.5887 .51326 m .5884 .51336 L .58841 .51765 L .567 .342 .533 r
F
.586 .5207 m .58551 .52159 L .58685 .52113 L .683 .77 .917 r
F
.58676 .51563 m .58679 .52432 L .58673 .51511 L .777 .62 .057 r
F
.58679 .52432 m .58681 .53226 L .58677 .52406 L F
.58679 .52432 m .58677 .52406 L .58673 .51511 L F
.58796 .51773 m .58858 .51871 L .58936 .51749 L .683 .77 .917 r
F
.58872 .51726 m .58882 .52158 L .58853 .51719 L .846 .571 .522 r
F
.58688 .51484 m .58673 .51939 L .58684 .5192 L 0 0 .377 r
F
.58673 .51511 m .58675 .51958 L .58673 .51939 L .777 .62 .057 r
F
.58872 .51726 m .58881 .51729 L .58882 .52158 L .846 .571 .522 r
F
.5841 .51482 m .57147 .51255 L .57068 .51553 L .683 .77 .917 r
F
.58951 .51454 m .58606 .51416 L .5841 .51482 L F
.58606 .51416 m .57147 .51255 L .5841 .51482 L F
.58951 .51454 m .58827 .5171 L .58936 .51749 L F
.58951 .51299 m .58863 .51758 L .58952 .51728 L .567 .342 .533 r
F
.58943 .47025 m .5887 .51326 L .58951 .51299 L F
.5887 .51326 m .58863 .51758 L .58951 .51299 L F
.58687 .51817 m .57705 .51174 L .57392 .51427 L .683 .77 .917 r
F
.59001 .51912 m .5878 .51786 L .58687 .51817 L F
.5878 .51786 m .57705 .51174 L .58687 .51817 L F
.58869 .52582 m .58883 .52587 L .58884 .53404 L .846 .571 .522 r
F
.58963 .52594 m .58936 .52592 L .58882 .52158 L .751 .49 .538 r
F
.59052 .52371 m .58854 .52577 L .58883 .52587 L .683 .77 .917 r
F
.58944 .52592 m .58883 .52587 L .58937 .52607 L F
.59052 .52371 m .58883 .52587 L .58944 .52592 L F
.58882 .52158 m .58869 .52186 L .58988 .52167 L F
.58922 .52162 m .58963 .52594 L .58882 .52158 L .751 .49 .538 r
F
.58963 .52594 m .59042 .53431 L .58936 .52592 L F
.58882 .52158 m .59042 .53431 L .58884 .53404 L F
.58952 .51728 m .58843 .52961 L .58954 .52927 L .567 .342 .533 r
F
.59052 .52371 m .58873 .52183 L .58779 .52215 L .683 .77 .917 r
F
.59001 .51912 m .5892 .5171 L .58853 .51757 L F
.59001 .51912 m .58853 .51757 L .58797 .51796 L F
.5875 .51827 m .58743 .52262 L .58791 .51799 L .4 .211 .506 r
F
.58951 .51454 m .5735 .50971 L .57147 .51255 L .683 .77 .917 r
F
.58951 .51454 m .57661 .50719 L .5735 .50971 L F
.58797 .51796 m .58106 .50972 L .57705 .51174 L F
.58745 .51401 m .58727 .51843 L .58737 .51837 L .4 .211 .506 r
F
.58688 .51484 m .58673 .51511 L .58673 .51939 L 0 0 .377 r
F
.58853 .51757 m .58106 .50972 L .58797 .51796 L .683 .77 .917 r
F
.58737 .51837 m .58727 .51843 L .58728 .52272 L .4 .211 .506 r
F
.58873 .52183 m .58619 .51292 L .58157 .51431 L .683 .77 .917 r
F
.58873 .47503 m .59039 .51743 L .58994 .51739 L .751 .49 .538 r
F
.58943 .47025 m .5884 .51336 L .5887 .51326 L .567 .342 .533 r
F
.59001 .51912 m .59012 .51719 L .58929 .51731 L .683 .77 .917 r
F
.58994 .51739 m .59039 .51743 L .5904 .52171 L .751 .49 .538 r
F
.59064 .51745 m .58892 .5259 L .59068 .51745 L .683 .77 .917 r
F
.58994 .51739 m .5904 .52171 L .59006 .52169 L .751 .49 .538 r
F
.59001 .51912 m .58988 .52167 L .59108 .52177 L .683 .77 .917 r
F
.58951 .51454 m .58935 .51761 L .59065 .51738 L F
.59191 .47509 m .59294 .47464 L .59302 .51668 L .516 .301 .527 r
F
.59065 .51738 m .59381 .52526 L .59199 .51714 L .683 .77 .917 r
F
.59381 .52526 m .5981 .53597 L .6073 .53323 L F
.59366 .52295 m .59433 .5299 L .59896 .52852 L F
.59433 .5299 m .59865 .54066 L .60789 .5379 L F
.5937 .52705 m .59484 .53448 L .59946 .5331 L F
.59333 .52501 m .59433 .5299 L .59366 .52295 L F
.59419 .52405 m .59433 .53158 L .59421 .5324 L 0 0 .146 r
F
.59409 .47338 m .59421 .47256 L .59429 .51474 L F
.59362 .51886 m .59381 .52526 L .59841 .52389 L .683 .77 .917 r
F
.59381 .52526 m .6073 .53323 L .59841 .52389 L F
.59392 .52135 m .59896 .52852 L .60297 .5265 L F
.5932 .52147 m .59381 .52526 L .59362 .51886 L F
.59313 .51659 m .59327 .5168 L .59333 .51671 L F
.59218 .51734 m .59841 .52389 L .59313 .51659 L F
.59353 .51628 m .59359 .52053 L .59302 .51668 L .356 .178 .497 r
F
.59312 .52089 m .59366 .52295 L .59392 .52135 L .683 .77 .917 r
F
.59841 .52389 m .6073 .53323 L .61529 .52921 L F
.59896 .52852 m .61592 .53386 L .60297 .5265 L F
.59376 .52469 m .60348 .53108 L .60661 .52856 L F
.59248 .52225 m .59433 .5299 L .5927 .52194 L F
.59225 .5183 m .59381 .52526 L .5926 .51778 L F
.59359 .52053 m .59374 .52041 L .59377 .53308 L .356 .178 .497 r
F
.5911 .52183 m .59433 .5299 L .59215 .5214 L .683 .77 .917 r
F
.592 .52143 m .59215 .5214 L .59214 .52136 L F
.5911 .52183 m .59215 .5214 L .592 .52143 L F
.59153 .51722 m .59199 .51714 L .592 .52143 L .641 .4 .539 r
F
.59244 .52572 m .59317 .53032 L .5937 .52705 L .683 .77 .917 r
F
.59143 .52597 m .58992 .53513 L .59484 .53448 L F
.59037 .52644 m .58992 .53513 L .59143 .52597 L F
.59041 .526 m .59202 .5341 L .59042 .53431 L .641 .4 .539 r
F
.59108 .52177 m .58979 .5235 L .5913 .52232 L .683 .77 .917 r
F
.59039 .51743 m .59122 .52586 L .59041 .526 L .641 .4 .539 r
F
.59137 .52583 m .59037 .52644 L .59143 .52597 L .683 .77 .917 r
F
.5904 .526 m .59037 .52644 L .59137 .52583 L F
.59122 .52586 m .59202 .5341 L .59041 .526 L .641 .4 .539 r
F
.59052 .52371 m .5904 .526 L .59137 .52583 L .683 .77 .917 r
F
.59201 .52571 m .59306 .53366 L .59202 .5341 L .516 .301 .527 r
F
.59214 .52136 m .59221 .52161 L .59231 .52153 L .683 .77 .917 r
F
.59199 .51714 m .59253 .52548 L .59201 .52571 L .516 .301 .527 r
F
.59237 .52565 m .59239 .52576 L .59244 .52572 L .683 .77 .917 r
F
.59137 .52583 m .59317 .53032 L .59237 .52565 L F
.59253 .52548 m .59306 .53366 L .59201 .52571 L .516 .301 .527 r
F
.59304 .52525 m .59377 .53308 L .59306 .53366 L .356 .178 .497 r
F
.5927 .52194 m .59333 .52501 L .59366 .52295 L .683 .77 .917 r
F
.59303 .52096 m .59328 .52506 L .59304 .52525 L .356 .178 .497 r
F
.59328 .52506 m .59377 .53308 L .59304 .52525 L F
.59239 .52576 m .59317 .53032 L .59244 .52572 L .683 .77 .917 r
F
.59077 .51768 m .59057 .5186 L .591 .51826 L F
.59068 .51745 m .59062 .51775 L .59077 .51768 L F
.59065 .51738 m .59064 .51745 L .59068 .51745 L F
.59153 .51722 m .59165 .52149 L .59039 .51743 L .641 .4 .539 r
F
.59101 .5216 m .5911 .52183 L .592 .52143 L .683 .77 .917 r
F
.59165 .52149 m .59202 .5341 L .5908 .52164 L .641 .4 .539 r
F
.59165 .52149 m .5908 .52164 L .59039 .51743 L F
.59001 .51912 m .59101 .5216 L .59214 .52136 L .683 .77 .917 r
F
.59153 .51722 m .592 .52143 L .59165 .52149 L .641 .4 .539 r
F
.59101 .5216 m .592 .52143 L .59214 .52136 L .683 .77 .917 r
F
.59052 .52371 m .59137 .52583 L .59237 .52565 L F
.59165 .52149 m .592 .52143 L .59201 .52571 L .641 .4 .539 r
F
.59178 .52576 m .59201 .52571 L .59202 .5341 L F
.59165 .52149 m .59201 .52571 L .59178 .52576 L F
.59321 .52082 m .59377 .53308 L .59303 .52096 L .356 .178 .497 r
F
.59199 .51714 m .59225 .5183 L .5926 .51778 L .683 .77 .917 r
F
.59231 .52153 m .59248 .52225 L .5927 .52194 L F
.59272 .51681 m .59281 .52106 L .59199 .51714 L .516 .301 .527 r
F
.59365 .47407 m .59409 .47338 L .59417 .51548 L .076 0 .415 r
F
.59365 .47407 m .59417 .51548 L .59405 .51566 L F
.59333 .51671 m .59841 .52389 L .59871 .52374 L .683 .77 .917 r
F
.59601 .51823 m .59871 .52374 L .6024 .52187 L F
.59333 .51671 m .59871 .52374 L .59601 .51823 L F
.59421 .47256 m .59376 .47151 L .59385 .51382 L .983 .725 .333 r
F
.59405 .51566 m .59409 .5199 L .59374 .51612 L .076 0 .415 r
F
.59841 .52389 m .61529 .52921 L .6024 .52187 L .683 .77 .917 r
F
.59428 .52041 m .60297 .5265 L .6061 .52397 L F
.59366 .52295 m .59896 .52852 L .59392 .52135 L F
.59415 .52411 m .60661 .52856 L .60864 .5257 L F
.59281 .52106 m .59289 .52532 L .59226 .52131 L .516 .301 .527 r
F
.59289 .52532 m .59253 .52548 L .59226 .52131 L F
.59386 .52024 m .59421 .5324 L .59374 .52041 L .076 0 .415 r
F
.59221 .52161 m .59433 .5299 L .59231 .52153 L .683 .77 .917 r
F
.59052 .52371 m .59376 .52468 L .59415 .52411 L F
.59376 .52468 m .60661 .52856 L .59415 .52411 L F
.59409 .5199 m .59413 .52414 L .59386 .52024 L .076 0 .415 r
F
.5923 .52558 m .59874 .53234 L .59315 .5252 L .683 .77 .917 r
F
.59433 .5299 m .60789 .5379 L .59896 .52852 L F
.59874 .53234 m .59946 .5331 L .59856 .53197 L F
.59874 .53234 m .59856 .53197 L .59315 .5252 L F
.59413 .52414 m .59421 .5324 L .59397 .52437 L .076 0 .415 r
F
.59501 .51619 m .6024 .52187 L .60552 .51936 L .683 .77 .917 r
F
.58951 .51454 m .59601 .51823 L .59501 .51619 L F
.59601 .51823 m .6024 .52187 L .59501 .51619 L F
.59409 .5199 m .59386 .52024 L .59374 .51612 L .076 0 .415 r
F
.59272 .51681 m .59303 .52096 L .59281 .52106 L .516 .301 .527 r
F
.5926 .51778 m .5932 .52147 L .59362 .51886 L .683 .77 .917 r
F
.59302 .51668 m .59321 .52082 L .59303 .52096 L .356 .178 .497 r
F
.59001 .51912 m .59383 .52027 L .5943 .51959 L .683 .77 .917 r
F
.59397 .51408 m .59386 .5224 L .59393 .52252 L .983 .725 .333 r
F
.59421 .47256 m .59392 .51398 L .59397 .51408 L F
.59392 .51398 m .59385 .51382 L .59386 .5224 L F
.59405 .51566 m .59417 .51548 L .59418 .51976 L .076 0 .415 r
F
.59405 .51566 m .59418 .51976 L .59409 .5199 L F
.59426 .51495 m .59429 .51474 L .5943 .51902 L 0 0 .146 r
F
.59426 .51495 m .5943 .51902 L .59428 .51918 L F
.59409 .47338 m .59429 .51474 L .59426 .51495 L F
.59417 .51548 m .59428 .51918 L .59418 .51976 L F
.59409 .47338 m .59426 .51495 L .59417 .51548 L F
.59426 .51495 m .59428 .51918 L .59417 .51548 L F
.59424 .51506 m .60552 .51936 L .60754 .51652 L .683 .77 .917 r
F
.59191 .47509 m .59272 .51681 L .59199 .51714 L .516 .301 .527 r
F
.58951 .51454 m .5941 .51592 L .59424 .51506 L .683 .77 .917 r
F
.5941 .51592 m .60552 .51936 L .59424 .51506 L F
.59429 .51474 m .59395 .5183 L .5943 .51902 L .983 .725 .333 r
F
.59421 .47256 m .59397 .51408 L .59429 .51474 L F
.59397 .51408 m .59395 .5183 L .59429 .51474 L F
.59408 .5143 m .60754 .51652 L .60834 .51354 L .683 .77 .917 r
F
.59191 .47509 m .59302 .51668 L .59272 .51681 L .516 .301 .527 r
F
.58951 .51454 m .59446 .51508 L .59408 .5143 L .683 .77 .917 r
F
.59446 .51508 m .60754 .51652 L .59408 .5143 L F
.59351 .52075 m .60297 .5265 L .59428 .52041 L F
.59315 .52091 m .59333 .52101 L .59351 .52075 L F
.59333 .52101 m .60297 .5265 L .59351 .52075 L F
.59312 .52519 m .60348 .53108 L .59376 .52469 L F
.59359 .52053 m .59365 .52477 L .59321 .52082 L .356 .178 .497 r
F
.59365 .52477 m .59377 .53308 L .5934 .52497 L F
.59365 .52477 m .5934 .52497 L .59321 .52082 L F
.59359 .52053 m .59321 .52082 L .59302 .51668 L F
.59231 .52153 m .59366 .52295 L .59312 .52089 L .683 .77 .917 r
F
.59374 .51612 m .59386 .52024 L .59374 .52041 L .076 0 .415 r
F
.59365 .47407 m .59405 .51566 L .59374 .51612 L F
.59367 .51617 m .59374 .51612 L .59374 .52041 L .356 .178 .497 r
F
.59294 .47464 m .59374 .51612 L .59367 .51617 L F
.59353 .51628 m .59374 .52041 L .59359 .52053 L F
.59294 .47464 m .59367 .51617 L .59353 .51628 L F
.59367 .51617 m .59374 .52041 L .59353 .51628 L F
.59809 .51271 m .60834 .51354 L .60786 .51063 L .683 .77 .917 r
F
.59052 .52371 m .59312 .52519 L .59376 .52469 L F
.59503 .51886 m .60814 .52112 L .60894 .51812 L F
.59327 .5168 m .59841 .52389 L .59333 .51671 L F
.59001 .51912 m .59659 .51985 L .59503 .51886 L F
.59659 .51985 m .60814 .52112 L .59503 .51886 L F
.59386 .51811 m .59282 .52969 L .59388 .53052 L .911 .629 .497 r
F
.59385 .51382 m .59358 .51794 L .59386 .51811 L F
.59409 .51826 m .60894 .51812 L .60845 .5152 L .683 .77 .917 r
F
.59001 .51912 m .59503 .51886 L .59409 .51826 L F
.59503 .51886 m .60894 .51812 L .59409 .51826 L F
.59294 .47464 m .59353 .51628 L .59302 .51668 L .356 .178 .497 r
F
.59308 .51334 m .59301 .51758 L .59385 .51382 L .911 .629 .497 r
F
.59281 .52106 m .59303 .52096 L .59306 .53366 L .516 .301 .527 r
F
.59331 .52205 m .59349 .52216 L .59386 .51811 L .911 .629 .497 r
F
.59621 .51418 m .60834 .51354 L .59809 .51271 L .683 .77 .917 r
F
.58951 .51454 m .59455 .51427 L .5936 .51367 L F
.59289 .52532 m .59306 .53366 L .59253 .52548 L .516 .301 .527 r
F
.59294 .47464 m .59365 .47407 L .59374 .51612 L .356 .178 .497 r
F
.59272 .51681 m .59302 .51668 L .59303 .52096 L .516 .301 .527 r
F
.59376 .47151 m .5927 .47067 L .59279 .51315 L .911 .629 .497 r
F
.59551 .52344 m .60864 .5257 L .60945 .52271 L .683 .77 .917 r
F
.59409 .5199 m .59418 .51976 L .59419 .52405 L .076 0 .415 r
F
.59413 .52414 m .59419 .52405 L .59421 .5324 L F
.59409 .5199 m .59419 .52405 L .59413 .52414 L F
.59457 .52349 m .59707 .52443 L .59551 .52344 L .683 .77 .917 r
F
.59052 .52371 m .59415 .52411 L .59457 .52349 L F
.59415 .52411 m .59707 .52443 L .59457 .52349 L F
.59707 .52443 m .60864 .5257 L .59551 .52344 L F
.59308 .51334 m .59279 .51315 L .59279 .51744 L .911 .629 .497 r
F
.59031 .47529 m .59199 .51714 L .59153 .51722 L .641 .4 .539 r
F
.58951 .51454 m .59218 .51734 L .59313 .51659 L .683 .77 .917 r
F
.5928 .52173 m .59174 .52931 L .59282 .52969 L .81 .54 .53 r
F
.59001 .51912 m .59365 .51769 L .59363 .51765 L .683 .77 .917 r
F
.59301 .51758 m .59358 .51794 L .59385 .51382 L .911 .629 .497 r
F
.5927 .51741 m .59363 .51765 L .59332 .51702 L .683 .77 .917 r
F
.59281 .52106 m .59226 .52131 L .59199 .51714 L .516 .301 .527 r
F
.59001 .51912 m .59363 .51765 L .5927 .51741 L .683 .77 .917 r
F
.59001 .51912 m .59315 .52091 L .59428 .52041 L F
.59279 .51744 m .59186 .52149 L .5928 .52173 L .81 .54 .53 r
F
.59376 .47151 m .59308 .51334 L .59385 .51382 L .911 .629 .497 r
F
.59421 .47256 m .59385 .51382 L .59392 .51398 L .983 .725 .333 r
F
.59031 .47529 m .59191 .47509 L .59199 .51714 L .641 .4 .539 r
F
.59031 .47529 m .59153 .51722 L .59039 .51743 L F
.59001 .51912 m .59231 .52153 L .59312 .52089 L .683 .77 .917 r
F
.5927 .47067 m .59162 .47029 L .5917 .51288 L .81 .54 .53 r
F
.59201 .51295 m .5917 .51288 L .59172 .52146 L F
.59194 .51722 m .59172 .52146 L .59186 .52149 L F
.59201 .51295 m .59186 .51721 L .59194 .51722 L F
.59337 .5178 m .59516 .51803 L .59371 .51767 L .683 .77 .917 r
F
.59001 .51912 m .59409 .51826 L .59337 .5178 L F
.59409 .51826 m .59516 .51803 L .59337 .5178 L F
.59301 .51758 m .5928 .52173 L .59295 .52182 L .911 .629 .497 r
F
.59308 .51334 m .59294 .51753 L .59301 .51758 L F
.59294 .51753 m .5928 .52173 L .59301 .51758 L F
.59186 .51721 m .59172 .52146 L .59194 .51722 L .81 .54 .53 r
F
.59371 .51767 m .60845 .5152 L .60671 .51254 L .683 .77 .917 r
F
.59516 .51803 m .60845 .5152 L .59371 .51767 L F
.59279 .51315 m .59194 .51722 L .59279 .51744 L .81 .54 .53 r
F
.59201 .51295 m .59194 .51722 L .59279 .51315 L F
.5917 .51288 m .60325 .50579 L .59122 .51276 L .683 .77 .917 r
F
.5927 .47067 m .5917 .51288 L .59201 .51295 L .81 .54 .53 r
F
.592 .51295 m .59209 .5129 L .5917 .51288 L .683 .77 .917 r
F
.59209 .5129 m .60325 .50579 L .5917 .51288 L F
.5917 .51288 m .59064 .52918 L .59174 .52931 L .734 .476 .539 r
F
.59162 .47029 m .59091 .51285 L .5917 .51288 L F
.59077 .52142 m .59115 .52143 L .5917 .51288 L F
.59064 .52141 m .59162 .52143 L .59065 .52119 L .683 .77 .917 r
F
.59052 .52371 m .59161 .52145 L .59064 .52141 L F
.59161 .52145 m .59162 .52143 L .59064 .52141 L F
.58951 .51454 m .592 .51295 L .59122 .51276 L F
.58951 .51454 m .59065 .51738 L .59199 .51714 L F
.59098 .51714 m .59207 .51698 L .59129 .51649 L F
.59001 .51912 m .59188 .51717 L .59098 .51714 L F
.59188 .51717 m .59207 .51698 L .59098 .51714 L F
.59091 .51285 m .59084 .51713 L .5917 .51288 L .734 .476 .539 r
F
.59084 .51713 m .59077 .52142 L .59124 .51715 L F
.59084 .51713 m .59124 .51715 L .5917 .51288 L F
.59052 .52371 m .5923 .52558 L .59315 .5252 L .683 .77 .917 r
F
.59077 .52142 m .59064 .52918 L .59115 .52143 L .734 .476 .539 r
F
.59061 .51284 m .58954 .52927 L .59064 .52918 L .66 .415 .539 r
F
.59053 .47016 m .58981 .51295 L .59061 .51284 L F
.58951 .51454 m .59122 .51276 L .59046 .51257 L .683 .77 .917 r
F
.58981 .51295 m .58967 .52154 L .59061 .51284 L .66 .415 .539 r
F
.58967 .52154 m .59005 .52149 L .59033 .51716 L F
.59014 .51719 m .59033 .51716 L .59061 .51284 L F
.59001 .51912 m .59101 .51707 L .59012 .51719 L .683 .77 .917 r
F
.58967 .52154 m .59033 .51716 L .59014 .51719 L .66 .415 .539 r
F
.59353 .51295 m .60786 .51063 L .60612 .50799 L .683 .77 .917 r
F
.58951 .51454 m .59641 .51307 L .59353 .51295 L F
.59641 .51307 m .60786 .51063 L .59353 .51295 L F
.59162 .47029 m .59053 .47016 L .59061 .51284 L .734 .476 .539 r
F
.59071 .51284 m .59061 .51284 L .59062 .51712 L F
.59162 .47029 m .59061 .51284 L .59071 .51284 L F
.59084 .51713 m .59062 .51712 L .59064 .52918 L F
.59162 .47029 m .59062 .51712 L .59084 .51713 L F
.59376 .47151 m .59279 .51315 L .59308 .51334 L .911 .629 .497 r
F
.59046 .51257 m .59542 .50795 L .5928 .50775 L .683 .77 .917 r
F
.59542 .50795 m .59945 .50419 L .5928 .50775 L F
.5928 .50775 m .59945 .50419 L .59496 .50329 L F
.59122 .51276 m .59945 .50419 L .59046 .51257 L F
.5927 .47067 m .59201 .51295 L .59279 .51315 L .81 .54 .53 r
F
.5908 .51189 m .59496 .50329 L .58969 .51119 L .683 .77 .917 r
F
.59012 .5171 m .59549 .50782 L .59061 .50769 L F
.59012 .51719 m .59017 .51711 L .59012 .5171 L F
.59017 .51711 m .59549 .50782 L .59012 .5171 L F
.58951 .51454 m .59555 .51216 L .59262 .51256 L F
.59101 .51707 m .59549 .50782 L .59012 .51719 L F
.58951 .51454 m .5908 .51189 L .58969 .51119 L F
.58892 .51307 m .59011 .50316 L .58521 .5038 L F
.58951 .51454 m .58959 .51298 L .58892 .51307 L F
.59053 .47016 m .58943 .47025 L .58952 .51728 L .66 .415 .539 r
F
.58959 .51298 m .59011 .50316 L .58892 .51307 L .683 .77 .917 r
F
.59001 .51912 m .58882 .52158 L .58988 .52167 L F
.58981 .51295 m .58953 .52156 L .58967 .52154 L .66 .415 .539 r
F
.59053 .47016 m .58969 .51296 L .58981 .51295 L F
.58969 .51296 m .58953 .52156 L .58981 .51295 L F
.58929 .51731 m .59061 .50769 L .58569 .50834 L .683 .77 .917 r
F
.59012 .51719 m .59061 .50769 L .58929 .51731 L F
.58961 .51726 m .58952 .51728 L .58953 .52156 L .66 .415 .539 r
F
.58863 .51758 m .58856 .52189 L .58952 .51728 L .567 .342 .533 r
F
.5887 .51326 m .58841 .51765 L .58863 .51758 L F
.58758 .51393 m .5875 .51827 L .5884 .51336 L .4 .211 .506 r
F
.5892 .5171 m .58569 .50834 L .58853 .51757 L .683 .77 .917 r
F
.58965 .52155 m .59111 .51228 L .58619 .51292 L F
.59052 .52371 m .59064 .52141 L .58965 .52155 L F
.59064 .52141 m .59111 .51228 L .58965 .52155 L F
.58967 .52154 m .58954 .52927 L .59005 .52149 L .66 .415 .539 r
F
.59262 .51256 m .60612 .50799 L .60325 .50579 L .683 .77 .917 r
F
.59555 .51216 m .60612 .50799 L .59262 .51256 L F
.59129 .51649 m .6 .50872 L .59549 .50782 L F
.59455 .51427 m .59621 .51418 L .5936 .51367 L F
.59207 .51698 m .6 .50872 L .59129 .51649 L F
.59308 .51334 m .59279 .51744 L .59294 .51753 L .911 .629 .497 r
F
.59392 .51398 m .59389 .51819 L .59397 .51408 L .983 .725 .333 r
F
.59065 .52119 m .596 .51241 L .59111 .51228 L .683 .77 .917 r
F
.59194 .51722 m .59186 .52149 L .59279 .51744 L .81 .54 .53 r
F
.59294 .51753 m .59279 .51744 L .5928 .52173 L .911 .629 .497 r
F
.59162 .52143 m .596 .51241 L .59065 .52119 L .683 .77 .917 r
F
.59186 .52149 m .59172 .52146 L .59174 .52931 L .81 .54 .53 r
F
.59122 .51276 m .60325 .50579 L .59945 .50419 L .683 .77 .917 r
F
.59052 .52371 m .59322 .52199 L .5928 .52173 L F
.59052 .52371 m .5928 .52173 L .59249 .52165 L F
.59052 .52371 m .59385 .52239 L .59322 .52199 L F
.59186 .52149 m .59174 .52931 L .5928 .52173 L .81 .54 .53 r
F
.59249 .52165 m .5928 .52173 L .59256 .52158 L .683 .77 .917 r
F
.59295 .52182 m .5928 .52173 L .59282 .52969 L .911 .629 .497 r
F
.58969 .51119 m .59496 .50329 L .59011 .50316 L .683 .77 .917 r
F
.59256 .52158 m .60433 .51492 L .6005 .51331 L F
.59322 .52199 m .60433 .51492 L .59256 .52158 L F
.59301 .51758 m .59295 .52182 L .59358 .51794 L .911 .629 .497 r
F
.59295 .52182 m .59282 .52969 L .59331 .52205 L F
.59295 .52182 m .59331 .52205 L .59358 .51794 L F
.59322 .52199 m .60721 .51713 L .60433 .51492 L .683 .77 .917 r
F
.59428 .51918 m .5943 .51902 L .59431 .52331 L 0 0 .146 r
F
.59315 .5252 m .59856 .53197 L .59605 .52686 L .683 .77 .917 r
F
.59429 .52342 m .59431 .52331 L .59433 .53158 L 0 0 .146 r
F
.59428 .51918 m .59431 .52331 L .59429 .52342 L F
.6024 .52187 m .62152 .52419 L .60552 .51936 L .683 .77 .917 r
F
.5943 .51959 m .6061 .52397 L .60814 .52112 L F
.59438 .52289 m .60945 .52271 L .60896 .51979 L F
.59428 .51918 m .59433 .53158 L .59418 .51976 L 0 0 .146 r
F
.59052 .52371 m .59428 .52351 L .59438 .52289 L .683 .77 .917 r
F
.59428 .52351 m .60945 .52271 L .59438 .52289 L F
.59418 .51976 m .59423 .5238 L .59419 .52405 L 0 0 .146 r
F
.5943 .51902 m .59416 .523 L .59431 .52331 L .983 .725 .333 r
F
.59385 .52239 m .60721 .51713 L .59322 .52199 L .683 .77 .917 r
F
.59358 .51794 m .59331 .52205 L .59386 .51811 L .911 .629 .497 r
F
.59331 .52205 m .59282 .52969 L .59349 .52216 L F
.5936 .51367 m .59621 .51418 L .59809 .51271 L .683 .77 .917 r
F
.59332 .51702 m .60671 .51254 L .60382 .51033 L F
.59389 .51819 m .59392 .51824 L .59397 .51408 L .983 .725 .333 r
F
.59365 .51769 m .60671 .51254 L .59332 .51702 L .683 .77 .917 r
F
.59389 .51819 m .59386 .5224 L .59392 .51824 L .983 .725 .333 r
F
.59423 .5238 m .59433 .53158 L .59419 .52405 L 0 0 .146 r
F
.59431 .52331 m .59388 .53052 L .59433 .53158 L .983 .725 .333 r
F
.59416 .523 m .59388 .53052 L .59431 .52331 L F
.59413 .52414 m .59397 .52437 L .59386 .52024 L .076 0 .415 r
F
.59383 .52027 m .6061 .52397 L .5943 .51959 L .683 .77 .917 r
F
.59317 .53032 m .59484 .53448 L .5937 .52705 L F
.59374 .52041 m .59421 .5324 L .59377 .53308 L .076 0 .415 r
F
.59393 .52252 m .59386 .5224 L .59388 .53052 L .983 .725 .333 r
F
.59605 .52686 m .59946 .5331 L .60348 .53108 L .683 .77 .917 r
F
.59856 .53197 m .59946 .5331 L .59605 .52686 L F
.59386 .52239 m .60896 .51979 L .60721 .51713 L F
.59052 .52371 m .59413 .52294 L .59386 .52239 L F
.59413 .52294 m .60896 .51979 L .59386 .52239 L F
.59395 .5183 m .59393 .52252 L .5943 .51902 L .983 .725 .333 r
F
.59393 .52252 m .59388 .53052 L .59416 .523 L F
.59393 .52252 m .59416 .523 L .5943 .51902 L F
.59053 .47016 m .58952 .51728 L .58961 .51726 L .66 .415 .539 r
F
.59052 .52371 m .58965 .52155 L .58873 .52183 L .683 .77 .917 r
F
.58967 .52154 m .58953 .52156 L .58954 .52927 L .66 .415 .539 r
F
.58965 .52155 m .58964 .52153 L .58953 .52156 L .683 .77 .917 r
F
.58965 .52155 m .58953 .52156 L .58873 .52183 L F
.58856 .52189 m .58913 .5217 L .58952 .51728 L .567 .342 .533 r
F
.58863 .51758 m .58841 .51765 L .58841 .52194 L F
.58863 .51758 m .58841 .52194 L .58856 .52189 L F
.58964 .52153 m .58619 .51292 L .58873 .52183 L .683 .77 .917 r
F
.58856 .52189 m .58843 .52961 L .58913 .5217 L .567 .342 .533 r
F
.58659 .52148 m .58157 .51431 L .57755 .51633 L .683 .77 .917 r
F
.58779 .52215 m .58653 .52057 L .58659 .52148 L F
.58653 .52057 m .58157 .51431 L .58659 .52148 L F
.58873 .52183 m .58157 .51431 L .58779 .52215 L F
.58856 .52189 m .58841 .52194 L .58843 .52961 L .567 .342 .533 r
F
.58853 .51757 m .58569 .50834 L .58106 .50972 L .683 .77 .917 r
F
.58774 .52544 m .58751 .52527 L .58733 .52085 L .93 .648 .485 r
F
.58808 .52131 m .58834 .52569 L .58783 .52122 L .846 .571 .522 r
F
.58743 .52262 m .5873 .5304 L .58841 .52194 L .4 .211 .506 r
F
.58718 .52502 m .57962 .528 L .58777 .52546 L .683 .77 .917 r
F
.57621 .52791 m .57007 .5399 L .58004 .52951 L F
.57962 .528 m .57383 .53028 L .57881 .52856 L F
.57962 .528 m .57881 .52856 L .58777 .52546 L F
.58832 .47059 m .58727 .51414 L .58745 .51401 L .4 .211 .506 r
F
.58743 .52262 m .58728 .52272 L .5873 .5304 L F
.57881 .52856 m .57383 .53028 L .575 .53118 L .683 .77 .917 r
F
.57881 .52856 m .575 .53118 L .57671 .53249 L F
.58673 .51939 m .58681 .53226 L .58676 .53144 L .777 .62 .057 r
F
.58675 .51958 m .58677 .52406 L .58673 .51939 L F
.58677 .52406 m .58681 .53226 L .58676 .52394 L F
.58677 .52406 m .58676 .52394 L .58673 .51939 L F
.58676 .52391 m .57238 .52171 L .57159 .52471 L .683 .77 .917 r
F
.58684 .5192 m .58673 .51939 L .58674 .52368 L 0 0 .377 r
F
.58681 .52356 m .58674 .52368 L .58676 .53144 L F
.58684 .5192 m .58674 .52368 L .58681 .52356 L F
.59052 .52371 m .58695 .52332 L .58676 .52391 L .683 .77 .917 r
F
.58695 .52332 m .58672 .52329 L .58674 .52368 L F
.58695 .52332 m .58674 .52368 L .58676 .52391 L F
.58672 .52329 m .57238 .52171 L .58676 .52391 L F
.36306 .55209 m .35009 .54477 L .34082 .55229 L F
.37101 .54807 m .35009 .54477 L .36306 .55209 L F
.38966 .65467 m .38936 .66237 L .39915 .66216 L .645 .732 .913 r
F
.24519 .77169 m .23997 .77173 L .24374 .77294 L .692 .759 .903 r
F
.54694 .42697 m .52553 .41967 L .51745 .43094 L .673 .757 .914 r
F
.54913 .55004 m .56011 .55028 L .5606 .55486 L .861 .591 .529 r
F
.54913 .55004 m .54863 .54546 L .56011 .55028 L F
.56242 .53668 m .56011 .55028 L .57007 .5399 L .683 .77 .917 r
F
.56242 .53668 m .54863 .54546 L .56011 .55028 L F
0 g
.56011 .55028 m
.56422 .5511 L
s
.52552 .42526 m .51708 .43088 L .5174 .43657 L .165 .07 .493 r
F
.52552 .42526 m .5252 .41956 L .51708 .43088 L F
0 g
.51392 .44292 m
.51708 .43088 L
s
.62886 .54123 m .62835 .53664 L .63775 .52908 L .403 .259 .569 r
F
0 g
.62155 .54007 m
.62835 .53664 L
s
.25562 .76801 m .25474 .76476 L .25351 .76756 L .692 .759 .903 r
F
.25562 .76801 m .25791 .76544 L .25474 .76476 L F
.65913 .66722 m .65133 .66667 L .65109 .67044 L .5 .299 .539 r
F
.65913 .66722 m .65937 .66344 L .65133 .66667 L F
0 g
.64507 .67111 m
.65133 .66667 L
s
.597 .42659 m .5913 .4108 L .59051 .42619 L .673 .757 .914 r
F
.597 .42659 m .60427 .41162 L .5913 .4108 L F
.61529 .52921 m .62816 .53653 L .63751 .52901 L .683 .77 .917 r
F
.6073 .53323 m .62816 .53653 L .61529 .52921 L F
.2629 .77049 m .2606 .76664 L .26085 .76884 L .933 .634 .45 r
F
0 g
.2629 .77049 m
.26415 .77247 L
s
.25767 .77101 m .25816 .76764 L .25587 .77021 L .692 .759 .903 r
F
.25767 .77101 m .26085 .76884 L .25816 .76764 L F
.66425 .43962 m .65694 .42289 L .65728 .42858 L .986 .71 .374 r
F
0 g
.66425 .43962 m
.66619 .45156 L
s
.70471 .67359 m .70495 .66981 L .69729 .66567 L .857 .609 .562 r
F
0 g
.70495 .66981 m
.71073 .67497 L
s
.24213 .76986 m .23972 .76953 L .23997 .77173 L .388 .236 .55 r
F
.24213 .76986 m .24188 .76765 L .23972 .76953 L F
0 g
.23833 .77165 m
.23972 .76953 L
s
.67129 .6731 m .66839 .66544 L .65913 .66722 L .645 .732 .913 r
F
.67786 .67296 m .66839 .66544 L .67129 .6731 L F
.54737 .43828 m .51772 .44227 L .54195 .44582 L .673 .757 .914 r
F
.37026 .66204 m .37957 .66112 L .37931 .6649 L .793 .551 .571 r
F
.127 .923 .03 r
.32539 .64512 m
.32542 .64876 L
s
.32508 .60873 m
.32539 .64512 L
s
.37026 .66204 m .37052 .65826 L .37957 .66112 L .793 .551 .571 r
F
0 g
.37957 .66112 m
.38106 .66133 L
s
.24679 .76849 m .24467 .76615 L .24188 .76765 L .692 .759 .903 r
F
.24894 .76781 m .24467 .76615 L .24679 .76849 L F
.68437 .67387 m .67825 .66523 L .67786 .67296 L .645 .732 .913 r
F
.68437 .67387 m .68802 .66659 L .67825 .66523 L F
.39894 .66605 m .3992 .66227 L .40844 .66049 L .596 .379 .557 r
F
0 g
.39578 .66234 m
.3992 .66227 L
s
.58397 .42683 m .57822 .41209 L .56592 .41538 L .673 .757 .914 r
F
.59051 .42619 m .57822 .41209 L .58397 .42683 L F
.37717 .65187 m .37963 .66101 L .38317 .65377 L .645 .732 .913 r
F
.127 .923 .03 r
.37969 .58949 m
.38031 .63422 L
s
.37884 .58981 m
.37894 .63557 L
s
.37717 .65187 m .37062 .65817 L .37963 .66101 L .645 .732 .913 r
F
.24467 .76615 m .24163 .76545 L .24188 .76765 L .512 .324 .562 r
F
.24467 .76615 m .24442 .76395 L .24163 .76545 L F
0 g
.23947 .76733 m
.24163 .76545 L
s
.3962 .65453 m .39915 .66216 L .40834 .66038 L .645 .732 .913 r
F
.38966 .65467 m .39915 .66216 L .3962 .65453 L F
.25351 .76756 m .25132 .76466 L .25123 .76749 L .692 .759 .903 r
F
.25351 .76756 m .25474 .76476 L .25132 .76466 L F
.66487 .67806 m .65889 .671 L .65085 .67422 L .645 .732 .913 r
F
.67105 .67688 m .65889 .671 L .66487 .67806 L F
.69015 .67955 m .68779 .67037 L .68413 .67765 L F
.69015 .67955 m .69681 .67323 L .68779 .67037 L F
.2606 .76664 m .25766 .76323 L .25791 .76544 L .861 .577 .507 r
F
.26085 .76884 m .2606 .76664 L .25791 .76544 L F
0 g
.2606 .76664 m
.26265 .76829 L
s
.59051 .42619 m .5913 .4108 L .57822 .41209 L .673 .757 .914 r
F
.24519 .77169 m .24213 .76986 L .23997 .77173 L .692 .759 .903 r
F
0 g
.23858 .77385 m
.23997 .77173 L
s
.24704 .77069 m .24213 .76986 L .24519 .77169 L .692 .759 .903 r
F
.24894 .76781 m .24789 .76513 L .24467 .76615 L F
.25123 .76749 m .24789 .76513 L .24894 .76781 L F
.25123 .76749 m .25132 .76466 L .24789 .76513 L F
.67786 .67296 m .67825 .66523 L .66839 .66544 L .645 .732 .913 r
F
.25791 .76544 m .25766 .76323 L .25449 .76256 L .793 .527 .535 r
F
0 g
.25766 .76323 m
.26035 .76444 L
s
.60338 .43364 m .60468 .41716 L .59736 .43221 L .673 .757 .914 r
F
.60338 .43364 m .61672 .42003 L .60468 .41716 L F
.60882 .44169 m .61705 .42572 L .60371 .43933 L F
.60882 .44169 m .62727 .43045 L .61705 .42572 L F
.25587 .77021 m .25499 .76696 L .25376 .76976 L .692 .759 .903 r
F
.25587 .77021 m .25816 .76764 L .25499 .76696 L F
.40865 .54609 m .40504 .53307 L .39967 .5443 L .683 .77 .917 r
F
.40865 .54609 m .41851 .53576 L .40504 .53307 L F
.127 .923 .03 r
.4088 .4634 m
.40947 .52673 L
s
.59297 .32107 m .56875 .31458 L .56833 .32188 L .667 .43 .553 r
F
0 g
.54519 .32682 m
.56833 .32188 L
s
.59297 .32107 m .59338 .31377 L .56875 .31458 L .667 .43 .553 r
F
0 g
.54562 .31952 m
.56875 .31458 L
s
.43983 .5562 m .43065 .54501 L .43114 .54959 L .933 .647 .475 r
F
0 g
.43983 .5562 m
.44511 .56415 L
s
.61742 .32445 m .61783 .31715 L .59338 .31377 L .732 .486 .557 r
F
0 g
.61783 .31715 m
.64042 .32448 L
s
.4174 .55836 m .41963 .54477 L .40973 .55515 L .683 .77 .917 r
F
.4174 .55836 m .43114 .54959 L .41963 .54477 L F
.24704 .77069 m .24492 .76836 L .24213 .76986 L .692 .759 .903 r
F
.24919 .77001 m .24492 .76836 L .24704 .77069 L F
.24789 .76513 m .24442 .76395 L .24467 .76615 L .599 .386 .563 r
F
.24789 .76513 m .24764 .76293 L .24442 .76395 L F
0 g
.24163 .76545 m
.24442 .76395 L
s
.24492 .76836 m .24188 .76765 L .24213 .76986 L .512 .324 .562 r
F
0 g
.23997 .77173 m
.24213 .76986 L
s
.24492 .76836 m .24467 .76615 L .24188 .76765 L .512 .324 .562 r
F
0 g
.23972 .76953 m
.24188 .76765 L
s
.25376 .76976 m .25157 .76686 L .25148 .76969 L .692 .759 .903 r
F
.25376 .76976 m .25499 .76696 L .25157 .76686 L F
.65889 .671 m .65109 .67044 L .65085 .67422 L .5 .299 .539 r
F
0 g
.64459 .67867 m
.65085 .67422 L
s
.65889 .671 m .65913 .66722 L .65109 .67044 L .5 .299 .539 r
F
0 g
.64483 .67489 m
.65109 .67044 L
s
.26085 .76884 m .25791 .76544 L .25816 .76764 L .861 .577 .507 r
F
0 g
.26085 .76884 m
.2629 .77049 L
s
.5781 .4341 m .56613 .42094 L .5554 .42604 L .673 .757 .914 r
F
.58427 .43244 m .56613 .42094 L .5781 .4341 L F
.36341 .5566 m .35038 .54924 L .34106 .5568 L .683 .77 .917 r
F
.3714 .55256 m .35038 .54924 L .36341 .5566 L F
.25474 .76476 m .25449 .76256 L .25107 .76245 L .731 .481 .55 r
F
.25791 .76544 m .25449 .76256 L .25474 .76476 L .793 .527 .535 r
F
0 g
.25449 .76256 m
.25766 .76323 L
s
.70471 .67359 m .69729 .66567 L .69705 .66945 L .857 .609 .562 r
F
.70448 .67737 m .70471 .67359 L .69705 .66945 L F
0 g
.70471 .67359 m
.71049 .67875 L
s
.35038 .54924 m .34057 .55222 L .34106 .5568 L .4 .255 .567 r
F
.35038 .54924 m .3499 .54466 L .34057 .55222 L F
0 g
.33456 .56076 m
.34057 .55222 L
s
.24919 .77001 m .24814 .76733 L .24492 .76836 L .692 .759 .903 r
F
.25148 .76969 m .24814 .76733 L .24919 .77001 L F
.56292 .54127 m .5606 .55486 L .57057 .54448 L .683 .77 .917 r
F
.56292 .54127 m .54913 .55004 L .5606 .55486 L F
0 g
.5606 .55486 m
.57411 .55755 L
s
0 0 0 r
2.5 Mabswid
.56158 .32475 Mdot
.63463 .43101 m .6454 .4135 L .62694 .42475 L .673 .757 .914 r
F
.63463 .43101 m .65694 .42289 L .6454 .4135 L F
.25148 .76969 m .25157 .76686 L .24814 .76733 L .692 .759 .903 r
F
.127 .923 .03 r
.5 Mabswid
.53592 .59034 m
.53857 .56296 L
s
.62886 .54123 m .63775 .52908 L .63826 .53366 L .403 .259 .569 r
F
.62936 .54581 m .62886 .54123 L .63826 .53366 L F
.61592 .53386 m .62886 .54123 L .63826 .53366 L .683 .77 .917 r
F
.60789 .5379 m .62886 .54123 L .61592 .53386 L F
0 g
.62205 .54465 m
.62886 .54123 L
s
0 0 0 r
2.5 Mabswid
.56271 .32477 Mdot
.127 .923 .03 r
.5 Mabswid
.39953 8.82281 m
.55388 .78468 L
s
.56142 .39177 m
.56271 .32477 L
s
0 g
.59372 .45172 m
.59376 .47151 L
s
.25816 .76764 m .25791 .76544 L .25474 .76476 L .793 .527 .535 r
F
.127 .923 .03 r
.08551 5.25235 m
.1372 4.71738 L
s
0 g
.25791 .76544 m
.2606 .76664 L
s
.67105 .67688 m .66815 .66922 L .65889 .671 L .645 .732 .913 r
F
.67762 .67674 m .66815 .66922 L .67105 .67688 L F
.37 .66582 m .37931 .6649 L .37905 .66868 L .793 .551 .571 r
F
.37 .66582 m .37026 .66204 L .37931 .6649 L F
.37684 .65572 m .37931 .6649 L .38288 .65762 L .645 .732 .913 r
F
.37684 .65572 m .37026 .66204 L .37931 .6649 L F
0 g
.37931 .6649 m
.3808 .66511 L
s
.58715 .45183 m
.58719 .47139 L
s
.68413 .67765 m .67801 .66901 L .67762 .67674 L .645 .732 .913 r
F
.68413 .67765 m .68779 .67037 L .67801 .66901 L F
.57306 .44234 m .55573 .43174 L .54737 .43828 L .673 .757 .914 r
F
.57842 .43979 m .55573 .43174 L .57306 .44234 L F
.39894 .66605 m .40844 .66049 L .40818 .66427 L .596 .379 .557 r
F
.39868 .66983 m .39894 .66605 L .40818 .66427 L F
.39597 .65839 m .39894 .66605 L .40818 .66427 L .645 .732 .913 r
F
.127 .923 .03 r
.4086 .6059 m
.4086 .60225 L
s
.3894 .65853 m .39894 .66605 L .39597 .65839 L .645 .732 .913 r
F
0 g
.39723 .66609 m
.39894 .66605 L
s
.25132 .76466 m .24764 .76293 L .24789 .76513 L .668 .436 .559 r
F
.25132 .76466 m .25107 .76245 L .24764 .76293 L F
0 g
.24442 .76395 m
.24764 .76293 L
s
.55525 .42046 m .52553 .41967 L .54694 .42697 L .673 .757 .914 r
F
.25474 .76476 m .25107 .76245 L .25132 .76466 L .731 .481 .55 r
F
0 g
.24764 .76293 m
.25107 .76245 L
s
.25107 .76245 m
.25449 .76256 L
s
.54705 .43259 m .52552 .42526 L .5174 .43657 L .673 .757 .914 r
F
.52585 .43095 m .5174 .43657 L .51772 .44227 L .165 .07 .493 r
F
.52585 .43095 m .52552 .42526 L .5174 .43657 L F
0 g
.51424 .44861 m
.5174 .43657 L
s
.36255 .6579 m .37052 .65826 L .37026 .66204 L .856 .609 .564 r
F
.127 .923 .03 r
.32612 .73155 m
.37917 6.95567 L
s
.32542 .64876 m
.32612 .73155 L
s
.36255 .6579 m .36281 .65412 L .37052 .65826 L .856 .609 .564 r
F
0 g
.37052 .65826 m
.37328 .65914 L
s
.67762 .67674 m .67801 .66901 L .66815 .66922 L .645 .732 .913 r
F
.59736 .43221 m .59164 .41634 L .59084 .4318 L .673 .757 .914 r
F
.59736 .43221 m .60468 .41716 L .59164 .41634 L F
.37205 .64912 m .36295 .65404 L .37062 .65817 L .645 .732 .913 r
F
.40818 .66427 m .40844 .66049 L .41644 .65726 L .498 .297 .538 r
F
0 g
.40265 .66161 m
.40844 .66049 L
s
.24814 .76733 m .24467 .76615 L .24492 .76836 L .599 .386 .563 r
F
.24814 .76733 m .24789 .76513 L .24467 .76615 L F
0 g
.24188 .76765 m
.24467 .76615 L
s
.24213 .76986 m
.24492 .76836 L
s
.40232 .65335 m .40834 .66038 L .41631 .65717 L .645 .732 .913 r
F
.3962 .65453 m .40834 .66038 L .40232 .65335 L F
0 g
.59376 .47151 m
.59383 .50326 L
s
.37101 .54807 m .36202 .53874 L .35009 .54477 L .683 .77 .917 r
F
.38019 .54532 m .36202 .53874 L .37101 .54807 L F
.25499 .76696 m .25474 .76476 L .25132 .76466 L .731 .481 .55 r
F
.25816 .76764 m .25474 .76476 L .25499 .76696 L .793 .527 .535 r
F
0 g
.25474 .76476 m
.25791 .76544 L
s
.25816 .76764 m
.26085 .76884 L
s
.58719 .47139 m
.58725 .50354 L
s
.61742 .32445 m .59338 .31377 L .59297 .32107 L .732 .486 .557 r
F
0 g
.59338 .31377 m
.61783 .31715 L
s
.61742 .32445 m
.64001 .33178 L
s
.56875 .31458 m
.59338 .31377 L
s
.58427 .43244 m .57849 .41763 L .56613 .42094 L .673 .757 .914 r
F
.59084 .4318 m .57849 .41763 L .58427 .43244 L F
.40924 .55057 m .40561 .53749 L .40022 .54877 L .683 .77 .917 r
F
.40924 .55057 m .41915 .54019 L .40561 .53749 L F
.25157 .76686 m .24789 .76513 L .24814 .76733 L .668 .436 .559 r
F
.25157 .76686 m .25132 .76466 L .24789 .76513 L F
0 g
.24467 .76615 m
.24789 .76513 L
s
.59084 .4318 m .59164 .41634 L .57849 .41763 L .673 .757 .914 r
F
.25499 .76696 m .25132 .76466 L .25157 .76686 L .731 .481 .55 r
F
0 g
.24789 .76513 m
.25132 .76466 L
s
.25132 .76466 m
.25474 .76476 L
s
.25499 .76696 m
.25816 .76764 L
s
.60371 .43933 m .60501 .42285 L .59769 .4379 L .673 .757 .914 r
F
.60371 .43933 m .61705 .42572 L .60501 .42285 L F
.66839 .66544 m .65937 .66344 L .65913 .66722 L .596 .38 .557 r
F
.66839 .66544 m .66863 .66166 L .65937 .66344 L F
0 g
.65133 .66667 m
.65937 .66344 L
s
.70448 .67737 m .69705 .66945 L .69681 .67323 L .857 .609 .562 r
F
0 g
.70448 .67737 m
.71025 .68253 L
s
.69705 .66945 m .69729 .66567 L .68826 .66281 L .794 .551 .57 r
F
0 g
.69729 .66567 m
.70495 .66981 L
s
.39967 .5443 m .39047 .53268 L .38997 .54404 L .683 .77 .917 r
F
.39967 .5443 m .40504 .53307 L .39047 .53268 L F
0 g
.24492 .76836 m
.24814 .76733 L
s
.37658 .6595 m .37905 .66868 L .38262 .6614 L .645 .732 .913 r
F
.37658 .6595 m .37 .66582 L .37905 .66868 L F
0 g
.37905 .66868 m
.38592 .66964 L
s
.53997 .53885 m .54813 .54088 L .54863 .54546 L .934 .647 .473 r
F
.53997 .53885 m .53947 .53426 L .54813 .54088 L F
0 g
.54813 .54088 m
.55277 .54282 L
s
.36389 .56118 m .35086 .55383 L .34154 .56139 L .683 .77 .917 r
F
.37189 .55715 m .35086 .55383 L .36389 .56118 L F
.35086 .55383 m .34106 .5568 L .34154 .56139 L .4 .255 .567 r
F
0 g
.33552 .56993 m
.34154 .56139 L
s
.35086 .55383 m .35038 .54924 L .34106 .5568 L .4 .255 .567 r
F
0 g
.33504 .56535 m
.34106 .5568 L
s
.39868 .66983 m .40818 .66427 L .40792 .66805 L .596 .379 .557 r
F
.39571 .66217 m .39868 .66983 L .40792 .66805 L .645 .732 .913 r
F
.127 .923 .03 r
.40859 .60956 m
.4086 .6059 L
s
0 g
.38961 .67003 m
.39868 .66983 L
s
.55631 .52762 m .54834 .54074 L .56206 .53201 L .683 .77 .917 r
F
.55631 .52762 m .53972 .53416 L .54834 .54074 L F
.62936 .54581 m .63826 .53366 L .63876 .53825 L .403 .259 .569 r
F
.61642 .53845 m .62936 .54581 L .63876 .53825 L .683 .77 .917 r
F
.6084 .54249 m .62936 .54581 L .61642 .53845 L F
0 g
.61733 .55187 m
.62936 .54581 L
s
.25157 .76686 m
.25499 .76696 L
s
.36229 .66168 m .37026 .66204 L .37 .66582 L .856 .609 .564 r
F
.36229 .66168 m .36255 .6579 L .37026 .66204 L F
.3717 .65295 m .37026 .66204 L .37684 .65572 L .645 .732 .913 r
F
.3717 .65295 m .36255 .6579 L .37026 .66204 L F
0 g
.37026 .66204 m
.37302 .66292 L
s
.57842 .43979 m .56645 .42663 L .55573 .43174 L .673 .757 .914 r
F
.5846 .43814 m .56645 .42663 L .57842 .43979 L F
0 g
.24814 .76733 m
.25157 .76686 L
s
.40818 .66427 m .41644 .65726 L .41618 .66104 L .498 .297 .538 r
F
.40792 .66805 m .40818 .66427 L .41618 .66104 L F
.40213 .6572 m .40818 .66427 L .41618 .66104 L .645 .732 .913 r
F
.127 .923 .03 r
.41026 .60184 m
.4103 .60548 L
s
.39597 .65839 m .40818 .66427 L .40213 .6572 L .645 .732 .913 r
F
0 g
.40239 .66538 m
.40818 .66427 L
s
.63497 .4367 m .64573 .41919 L .62727 .43045 L .673 .757 .914 r
F
.63497 .4367 m .65728 .42858 L .64573 .41919 L F
.43065 .54501 m .43016 .54042 L .41866 .5356 L .86 .591 .529 r
F
0 g
.43016 .54042 m
.43885 .54703 L
s
.38019 .54532 m .3758 .53461 L .36202 .53874 L .683 .77 .917 r
F
.38997 .54404 m .3758 .53461 L .38019 .54532 L F
0 g
.56833 .32188 m
.59297 .32107 L
s
.5554 .42604 m .52552 .42526 L .54705 .43259 L .673 .757 .914 r
F
0 g
.59297 .32107 m
.61742 .32445 L
s
.38997 .54404 m .39047 .53268 L .3758 .53461 L .683 .77 .917 r
F
.54737 .43828 m .52585 .43095 L .51772 .44227 L .673 .757 .914 r
F
0 g
.51456 .4543 m
.51772 .44227 L
s
.3714 .55256 m .36237 .54318 L .35038 .54924 L .683 .77 .917 r
F
.38063 .5498 m .36237 .54318 L .3714 .55256 L F
.59769 .4379 m .59196 .42203 L .59117 .43749 L .673 .757 .914 r
F
.59769 .4379 m .60501 .42285 L .59196 .42203 L F
.40973 .55515 m .4061 .54207 L .4007 .55335 L .683 .77 .917 r
F
.40973 .55515 m .41963 .54477 L .4061 .54207 L F
.66815 .66922 m .65913 .66722 L .65889 .671 L .596 .38 .557 r
F
0 g
.65085 .67422 m
.65889 .671 L
s
.66815 .66922 m .66839 .66544 L .65913 .66722 L .596 .38 .557 r
F
0 g
.65109 .67044 m
.65913 .66722 L
s
.127 .923 .03 r
.65823 .70071 m
.65965 .65568 L
s
.69705 .66945 m .68826 .66281 L .68802 .66659 L .794 .551 .57 r
F
.127 .923 .03 r
.69633 .66655 m
.69642 .66294 L
s
.69642 .66294 m
.69651 .65933 L
s
.69564 .66317 m
.69577 .65955 L
s
.69681 .67323 m .69705 .66945 L .68802 .66659 L .794 .551 .57 r
F
0 g
.69705 .66945 m
.70471 .67359 L
s
.5846 .43814 m .57881 .42332 L .56645 .42663 L .673 .757 .914 r
F
.59117 .43749 m .57881 .42332 L .5846 .43814 L F
.62642 .41918 m .62954 .40091 L .61625 .41447 L F
.62642 .41918 m .64479 .40797 L .62954 .40091 L F
.67825 .66523 m .66863 .66166 L .66839 .66544 L .67 .442 .567 r
F
.67825 .66523 m .67849 .66145 L .66863 .66166 L F
0 g
.65937 .66344 m
.66863 .66166 L
s
.54047 .54343 m .54863 .54546 L .54913 .55004 L .934 .647 .473 r
F
.54047 .54343 m .53997 .53885 L .54863 .54546 L F
.55665 .53227 m .54863 .54546 L .56242 .53668 L .683 .77 .917 r
F
.127 .923 .03 r
.55986 .47316 m
.55995 .46873 L
s
.55665 .53227 m .53997 .53885 L .54863 .54546 L .683 .77 .917 r
F
0 g
.54863 .54546 m
.55327 .54741 L
s
.127 .923 .03 r
.54714 .47426 m
.54757 .4698 L
s
.68802 .66659 m .68826 .66281 L .67849 .66145 L .733 .497 .571 r
F
0 g
.68826 .66281 m
.69729 .66567 L
s
.40022 .54877 m .39096 .5371 L .39046 .54851 L .683 .77 .917 r
F
.40022 .54877 m .40561 .53749 L .39096 .5371 L F
.59117 .43749 m .59196 .42203 L .57881 .42332 L .673 .757 .914 r
F
.37144 .65673 m .37 .66582 L .37658 .6595 L .645 .732 .913 r
F
.37144 .65673 m .36229 .66168 L .37 .66582 L F
0 g
.37 .66582 m
.37905 .66868 L
s
.35671 .65273 m .36281 .65412 L .36255 .6579 L .926 .677 .542 r
F
.35671 .65273 m .35697 .64896 L .36281 .65412 L F
0 g
.36281 .65412 m
.36618 .65593 L
s
.65694 .42289 m .65661 .4172 L .64507 .40781 L .934 .657 .491 r
F
0 g
.65661 .4172 m
.66358 .42824 L
s
.40792 .66805 m .41618 .66104 L .41592 .66482 L .498 .297 .538 r
F
.40187 .66098 m .40792 .66805 L .41592 .66482 L .645 .732 .913 r
F
.127 .923 .03 r
.4103 .60548 m
.41034 .60913 L
s
.39571 .66217 m .40792 .66805 L .40187 .66098 L .645 .732 .913 r
F
0 g
.39868 .66983 m
.40792 .66805 L
s
.36818 .6457 m .36295 .65404 L .37205 .64912 L .645 .732 .913 r
F
.36818 .6457 m .35713 .64891 L .36295 .65404 L F
.41618 .66104 m .41644 .65726 L .42266 .65281 L .348 .174 .498 r
F
.127 .923 .03 r
.44261 3.67897 m
.49645 8.80049 L
s
0 g
.41075 .65956 m
.41644 .65726 L
s
.40763 .65121 m .41631 .65717 L .4225 .65274 L .645 .732 .913 r
F
.40232 .65335 m .41631 .65717 L .40763 .65121 L F
.63826 .53366 m .63775 .52908 L .64387 .52052 L .203 .117 .529 r
F
0 g
.63199 .53372 m
.63775 .52908 L
s
.43065 .54501 m .41866 .5356 L .41915 .54019 L .86 .591 .529 r
F
.43114 .54959 m .43065 .54501 L .41915 .54019 L F
0 g
.43065 .54501 m
.43934 .55162 L
s
.68802 .66659 m .67849 .66145 L .67825 .66523 L .733 .497 .571 r
F
0 g
.67849 .66145 m
.68826 .66281 L
s
.66863 .66166 m
.67849 .66145 L
s
.62152 .52419 m .63751 .52901 L .6436 .52049 L .683 .77 .917 r
F
.61529 .52921 m .63751 .52901 L .62152 .52419 L F
.38063 .5498 m .37622 .53904 L .36237 .54318 L F
.39046 .54851 m .37622 .53904 L .38063 .5498 L F
.37189 .55715 m .36286 .54777 L .35086 .55383 L F
.38111 .55439 m .36286 .54777 L .37189 .55715 L F
.69681 .67323 m .68802 .66659 L .68779 .67037 L .794 .551 .57 r
F
0 g
.69681 .67323 m
.70448 .67737 L
s
.127 .923 .03 r
.69551 .66679 m
.69564 .66317 L
s
.69369 .71725 m
.69551 .66679 L
s
.69509 .71666 m
.69633 .66655 L
s
.39046 .54851 m .39096 .5371 L .37622 .53904 L .683 .77 .917 r
F
.58992 .53513 m .58932 .54654 L .59915 .54525 L F
.58504 .535 m .58932 .54654 L .58992 .53513 L F
.58504 .535 m .57957 .54628 L .58932 .54654 L F
.127 .923 .03 r
.37898 .65384 m
.37898 .65639 L
s
.59896 .52852 m .60789 .5379 L .61592 .53386 L .683 .77 .917 r
F
.55573 .43174 m .52585 .43095 L .54737 .43828 L .673 .757 .914 r
F
.67801 .66901 m .66839 .66544 L .66815 .66922 L .67 .442 .567 r
F
0 g
.65889 .671 m
.66815 .66922 L
s
.67801 .66901 m .67825 .66523 L .66839 .66544 L .67 .442 .567 r
F
0 g
.65913 .66722 m
.66839 .66544 L
s
.59484 .53448 m .59915 .54525 L .6084 .54249 L .683 .77 .917 r
F
.58992 .53513 m .59915 .54525 L .59484 .53448 L F
.68779 .67037 m .68802 .66659 L .67825 .66523 L .733 .497 .571 r
F
0 g
.68802 .66659 m
.69705 .66945 L
s
.39324 .6469 m .3962 .65453 L .40232 .65335 L .645 .732 .913 r
F
.38997 .64698 m .3962 .65453 L .39324 .6469 L F
.35644 .65652 m .36255 .6579 L .36229 .66168 L .926 .677 .542 r
F
.35644 .65652 m .35671 .65273 L .36255 .6579 L F
.36781 .64951 m .36255 .6579 L .3717 .65295 L .645 .732 .913 r
F
.36781 .64951 m .35671 .65273 L .36255 .6579 L F
0 g
.36255 .6579 m
.36592 .65971 L
s
.55715 .53686 m .54913 .55004 L .56292 .54127 L .683 .77 .917 r
F
.127 .923 .03 r
.55978 .4776 m
.55986 .47316 L
s
.55715 .53686 m .54047 .54343 L .54913 .55004 L .683 .77 .917 r
F
0 g
.54913 .55004 m
.5606 .55486 L
s
.127 .923 .03 r
.54671 .47873 m
.54714 .47426 L
s
.4007 .55335 m .39145 .54168 L .39094 .55309 L .683 .77 .917 r
F
.4007 .55335 m .4061 .54207 L .39145 .54168 L F
.41618 .66104 m .42266 .65281 L .4224 .65659 L .348 .174 .498 r
F
.41592 .66482 m .41618 .66104 L .4224 .65659 L F
.40746 .65505 m .41618 .66104 L .4224 .65659 L .645 .732 .913 r
F
.40213 .6572 m .41618 .66104 L .40746 .65505 L F
0 g
.41049 .66334 m
.41618 .66104 L
s
.55525 .42046 m .53799 .40989 L .52553 .41967 L .673 .757 .914 r
F
.56592 .41538 m .53799 .40989 L .55525 .42046 L F
.68779 .67037 m .67825 .66523 L .67801 .66901 L .733 .497 .571 r
F
0 g
.67825 .66523 m
.68802 .66659 L
s
.68779 .67037 m
.69681 .67323 L
s
.66839 .66544 m
.67825 .66523 L
s
.62694 .42475 m .63007 .4064 L .61672 .42003 L .673 .757 .914 r
F
.62694 .42475 m .6454 .4135 L .63007 .4064 L F
.36237 .54318 m .3499 .54466 L .35038 .54924 L .521 .342 .579 r
F
.36237 .54318 m .36189 .5386 L .3499 .54466 L F
0 g
.34057 .55222 m
.3499 .54466 L
s
.58054 .5341 m .57957 .54628 L .58504 .535 L .683 .77 .917 r
F
.58054 .5341 m .57057 .54448 L .57957 .54628 L F
.63826 .53366 m .64387 .52052 L .64437 .5251 L .203 .117 .529 r
F
.63876 .53825 m .63826 .53366 L .64437 .5251 L F
.62218 .52882 m .63826 .53366 L .64437 .5251 L .683 .77 .917 r
F
.61592 .53386 m .63826 .53366 L .62218 .52882 L F
0 g
.63249 .5383 m
.63826 .53366 L
s
.43114 .54959 m .41915 .54019 L .41963 .54477 L .86 .591 .529 r
F
0 g
.43114 .54959 m
.43983 .5562 L
s
.6024 .52187 m .61529 .52921 L .62152 .52419 L .683 .77 .917 r
F
.65694 .42289 m .64507 .40781 L .6454 .4135 L .934 .657 .491 r
F
.65728 .42858 m .65694 .42289 L .6454 .4135 L F
0 g
.65694 .42289 m
.66392 .43393 L
s
.38971 .65079 m .3894 .65853 L .39597 .65839 L .645 .732 .913 r
F
.38111 .55439 m .3767 .54362 L .36286 .54777 L .683 .77 .917 r
F
.39094 .55309 m .3767 .54362 L .38111 .55439 L F
.67638 .75538 m .67611 .75318 L .67955 .75271 L .668 .436 .559 r
F
.67296 .75528 m .67611 .75318 L .67638 .75538 L .731 .481 .55 r
F
.67296 .75528 m .6727 .75308 L .67611 .75318 L F
.67624 .75032 m .67611 .75314 L .67953 .75267 L .692 .759 .904 r
F
.67398 .75025 m .67272 .75304 L .67611 .75314 L F
.67981 .75491 m .67955 .75271 L .68278 .75168 L .599 .387 .564 r
F
.67638 .75538 m .67955 .75271 L .67981 .75491 L .668 .436 .559 r
F
0 g
.67611 .75318 m
.67955 .75271 L
s
.67852 .75 m .67953 .75267 L .68275 .75165 L .692 .759 .904 r
F
.39094 .55309 m .39145 .54168 L .3767 .54362 L .683 .77 .917 r
F
.3963 .64631 m .40232 .65335 L .40763 .65121 L .645 .732 .913 r
F
.39324 .6469 m .40232 .65335 L .3963 .64631 L F
.57621 .52791 m .56242 .53668 L .57007 .5399 L .683 .77 .917 r
F
0 g
.66815 .66922 m
.67801 .66901 L
s
.38343 .64939 m .37684 .65572 L .38288 .65762 L .645 .732 .913 r
F
.127 .923 .03 r
.37898 .65747 m
.37899 .66026 L
s
0 g
.67801 .66901 m
.68779 .67037 L
s
.39299 .65072 m .39597 .65839 L .40213 .6572 L .645 .732 .913 r
F
.38971 .65079 m .39597 .65839 L .39299 .65072 L F
.59946 .5331 m .6084 .54249 L .61642 .53845 L .683 .77 .917 r
F
.59484 .53448 m .6084 .54249 L .59946 .5331 L F
.66981 .7546 m .6727 .75308 L .67296 .75528 L .794 .527 .533 r
F
.66981 .7546 m .66954 .7524 L .6727 .75308 L F
0 g
.6727 .75308 m
.67611 .75318 L
s
.67189 .7498 m .67272 .75304 L .67398 .75025 L .692 .759 .904 r
F
.67189 .7498 m .66958 .75236 L .67272 .75304 L F
.36755 .65329 m .36229 .66168 L .37144 .65673 L .645 .732 .913 r
F
.36755 .65329 m .35644 .65652 L .36229 .66168 L F
0 g
.36229 .66168 m
.37 .66582 L
s
.68305 .75388 m .68278 .75168 L .68558 .75018 L .514 .326 .564 r
F
.67981 .75491 m .68278 .75168 L .68305 .75388 L .599 .387 .564 r
F
0 g
.67955 .75271 m
.68278 .75168 L
s
.68067 .74932 m .68275 .75165 L .68554 .75015 L .692 .759 .904 r
F
.41592 .66482 m .4224 .65659 L .42215 .66037 L .348 .174 .498 r
F
.40721 .65883 m .41592 .66482 L .42215 .66037 L .645 .732 .913 r
F
.40187 .66098 m .41592 .66482 L .40721 .65883 L F
0 g
.40792 .66805 m
.41592 .66482 L
s
.67664 .75759 m .67638 .75538 L .67981 .75491 L .668 .436 .559 r
F
.67323 .75748 m .67638 .75538 L .67664 .75759 L .731 .481 .55 r
F
.67323 .75748 m .67296 .75528 L .67638 .75538 L F
.67651 .75255 m .67638 .75538 L .67981 .75491 L .692 .759 .904 r
F
.127 .923 .03 r
.69504 .71884 m
.69509 .71666 L
s
.69361 .71944 m
.69369 .71725 L
s
.67424 .75248 m .67638 .75538 L .67651 .75255 L .692 .759 .904 r
F
.67424 .75248 m .67296 .75528 L .67638 .75538 L F
.68008 .75711 m .67981 .75491 L .68305 .75388 L .599 .387 .564 r
F
.67664 .75759 m .67981 .75491 L .68008 .75711 L .668 .436 .559 r
F
.6788 .75223 m .67981 .75491 L .68305 .75388 L .692 .759 .904 r
F
.67651 .75255 m .67981 .75491 L .6788 .75223 L F
0 g
.67638 .75538 m
.67981 .75491 L
s
.6116 .2529 m
.61185 .35638 L
s
.66714 .7534 m .66954 .7524 L .66981 .7546 L .862 .577 .504 r
F
.66714 .7534 m .66687 .7512 L .66954 .7524 L F
0 g
.66954 .7524 m
.6727 .75308 L
s
.67011 .749 m .66958 .75236 L .67189 .7498 L .692 .759 .904 r
F
.67011 .749 m .66692 .75116 L .66958 .75236 L F
.36286 .54777 m .35038 .54924 L .35086 .55383 L .521 .342 .579 r
F
0 g
.34154 .56139 m
.35086 .55383 L
s
.36286 .54777 m .36237 .54318 L .35038 .54924 L .521 .342 .579 r
F
0 g
.34106 .5568 m
.35038 .54924 L
s
.53806 .41543 m .5252 .41956 L .52552 .42526 L .386 .233 .548 r
F
.53806 .41543 m .53773 .40974 L .5252 .41956 L F
0 g
.51708 .43088 m
.5252 .41956 L
s
.67008 .7568 m .67296 .75528 L .67323 .75748 L .794 .527 .533 r
F
.67008 .7568 m .66981 .7546 L .67296 .75528 L F
.67214 .75203 m .67296 .75528 L .67424 .75248 L .692 .759 .904 r
F
.67214 .75203 m .66981 .7546 L .67296 .75528 L F
0 g
.67296 .75528 m
.67638 .75538 L
s
.41915 .54019 m .41866 .5356 L .40512 .5329 L .794 .541 .555 r
F
0 g
.41866 .5356 m
.43016 .54042 L
s
.63876 .53825 m .64437 .5251 L .64488 .52969 L .203 .117 .529 r
F
.62269 .5334 m .63876 .53825 L .64488 .52969 L .683 .77 .917 r
F
.61642 .53845 m .63876 .53825 L .62269 .5334 L F
0 g
.62936 .54581 m
.63876 .53825 L
s
.38945 .65457 m .38914 .66231 L .39571 .66217 L .645 .732 .913 r
F
.60297 .5265 m .61592 .53386 L .62218 .52882 L .683 .77 .917 r
F
.35313 .64691 m .35697 .64896 L .35671 .65273 L .989 .751 .479 r
F
.35313 .64691 m .35339 .64313 L .35697 .64896 L F
0 g
.35697 .64896 m
.36012 .65174 L
s
.68585 .75238 m .68558 .75018 L .68777 .7483 L .393 .241 .554 r
F
.68305 .75388 m .68558 .75018 L .68585 .75238 L .514 .326 .564 r
F
0 g
.68278 .75168 m
.68558 .75018 L
s
.36581 .64183 m .35713 .64891 L .36818 .6457 L .645 .732 .913 r
F
.36581 .64183 m .35358 .64311 L .35713 .64891 L F
.68332 .75609 m .68305 .75388 L .68585 .75238 L .514 .326 .564 r
F
.68008 .75711 m .68305 .75388 L .68332 .75609 L .599 .387 .564 r
F
.68096 .75155 m .68305 .75388 L .68585 .75238 L .692 .759 .904 r
F
.6788 .75223 m .68305 .75388 L .68096 .75155 L F
0 g
.67981 .75491 m
.68305 .75388 L
s
.68253 .74833 m .68554 .75015 L .68771 .74829 L .692 .759 .904 r
F
.68067 .74932 m .68554 .75015 L .68253 .74833 L F
.5554 .42604 m .53806 .41543 L .52552 .42526 L .673 .757 .914 r
F
.56613 .42094 m .53806 .41543 L .5554 .42604 L F
.61625 .41447 m .61156 .39662 L .60427 .41162 L F
.61625 .41447 m .62954 .40091 L .61156 .39662 L F
.39607 .65013 m .40213 .6572 L .40746 .65505 L .645 .732 .913 r
F
.39299 .65072 m .40213 .6572 L .39607 .65013 L F
.4224 .65659 m .42266 .65281 L .42668 .64743 L .075 0 .401 r
F
.127 .923 .03 r
.1372 4.71738 m
.45968 1.37946 L
s
.45968 1.37946 m
.53592 .59034 L
s
.42043 1.56891 m
.44261 3.67897 L
s
0 g
.41801 .65614 m
.42266 .65281 L
s
.62727 .43045 m .6304 .4121 L .61705 .42572 L .673 .757 .914 r
F
.62727 .43045 m .64573 .41919 L .6304 .4121 L F
.41176 .64825 m .4225 .65274 L .4265 .64739 L .645 .732 .913 r
F
.40763 .65121 m .4225 .65274 L .41176 .64825 L F
.38317 .65317 m .38262 .6614 L .38619 .65412 L F
.38317 .65317 m .37658 .6595 L .38262 .6614 L F
.39273 .6545 m .39571 .66217 L .40187 .66098 L F
.38945 .65457 m .39571 .66217 L .39273 .6545 L F
0 0 0 r
2.5 Mabswid
.37899 .6611 Mdot
.127 .923 .03 r
.5 Mabswid
.3841 3.0933 m
.39612 8.82436 L
s
.37911 .71648 m
.3841 3.0933 L
s
.37899 .6611 m
.37911 .71648 L
s
.67678 .75475 m .67664 .75759 L .68008 .75711 L .692 .759 .904 r
F
.127 .923 .03 r
.69353 .72163 m
.69361 .71944 L
s
.69498 .72102 m
.69504 .71884 L
s
.6745 .75468 m .67664 .75759 L .67678 .75475 L .692 .759 .904 r
F
.6745 .75468 m .67323 .75748 L .67664 .75759 L F
.57671 .53249 m .57057 .54448 L .58054 .5341 L .683 .77 .917 r
F
.57671 .53249 m .56292 .54127 L .57057 .54448 L F
.65728 .42858 m .6454 .4135 L .64573 .41919 L .934 .657 .491 r
F
0 g
.65728 .42858 m
.66425 .43962 L
s
.57291 .52108 m .56206 .53201 L .57578 .52328 L .683 .77 .917 r
F
.57291 .52108 m .55631 .52762 L .56206 .53201 L F
.67907 .75443 m .68008 .75711 L .68332 .75609 L .692 .759 .904 r
F
.67678 .75475 m .68008 .75711 L .67907 .75443 L F
0 g
.67664 .75759 m
.68008 .75711 L
s
.53472 .53088 m .53947 .53426 L .53997 .53885 L .98 .688 .334 r
F
.53472 .53088 m .53422 .5263 L .53947 .53426 L F
0 g
.53947 .53426 m
.5436 .53741 L
s
.55283 .52234 m .53972 .53416 L .55631 .52762 L .683 .77 .917 r
F
.55283 .52234 m .53449 .52624 L .53972 .53416 L F
.37922 .64248 m .36818 .6457 L .37205 .64912 L .645 .732 .913 r
F
.6674 .7556 m .66981 .7546 L .67008 .7568 L .862 .577 .504 r
F
.6674 .7556 m .66714 .7534 L .66981 .7546 L F
.67035 .75122 m .66981 .7546 L .67214 .75203 L .692 .759 .904 r
F
.67035 .75122 m .66714 .7534 L .66981 .7546 L F
0 g
.66981 .7546 m
.67296 .75528 L
s
.39896 .64524 m .40763 .65121 L .41176 .64825 L .645 .732 .913 r
F
.3963 .64631 m .40763 .65121 L .39896 .64524 L F
.6724 .75423 m .67323 .75748 L .6745 .75468 L .692 .759 .904 r
F
.6724 .75423 m .67008 .7568 L .67323 .75748 L F
0 g
.67323 .75748 m
.67664 .75759 L
s
.127 .923 .03 r
.38642 1.07425 m
.49363 8.79926 L
s
.38144 .71553 m
.38642 1.07425 L
s
.38067 .66063 m
.38144 .71553 L
s
0 0 0 r
2.5 Mabswid
.38067 .66063 Mdot
.66512 .75175 m .66687 .7512 L .66714 .7534 L .935 .633 .444 r
F
.66512 .75175 m .66485 .74955 L .66687 .7512 L F
.127 .923 .03 r
.5 Mabswid
.6651 .74975 m
.66566 .72318 L
s
0 g
.66687 .7512 m
.66898 .75215 L
s
.66877 .74791 m .66692 .75116 L .67011 .749 L .692 .759 .904 r
F
.66877 .74791 m .66491 .74952 L .66692 .75116 L F
.68585 .75238 m .68777 .7483 L .68804 .75051 L .393 .241 .554 r
F
.68612 .75458 m .68585 .75238 L .68804 .75051 L F
.68332 .75609 m .68585 .75238 L .68612 .75458 L .514 .326 .564 r
F
.68283 .75055 m .68585 .75238 L .68804 .75051 L .692 .759 .904 r
F
.68096 .75155 m .68585 .75238 L .68283 .75055 L F
0 g
.68305 .75388 m
.68585 .75238 L
s
.68123 .75375 m .68332 .75609 L .68612 .75458 L .692 .759 .904 r
F
.67907 .75443 m .68332 .75609 L .68123 .75375 L F
0 g
.68008 .75711 m
.68332 .75609 L
s
.68804 .75051 m .68777 .7483 L .68919 .74618 L .193 .102 .517 r
F
0 g
.68558 .75018 m
.68777 .7483 L
s
.68398 .74708 m .68771 .74829 L .68913 .74617 L .692 .759 .904 r
F
.68253 .74833 m .68771 .74829 L .68398 .74708 L F
.35287 .65069 m .35671 .65273 L .35644 .65652 L .989 .751 .479 r
F
.35287 .65069 m .35313 .64691 L .35671 .65273 L F
.36542 .64563 m .35671 .65273 L .36781 .64951 L .645 .732 .913 r
F
.36542 .64563 m .35313 .64691 L .35671 .65273 L F
0 g
.35671 .65273 m
.35986 .65552 L
s
.56592 .41538 m .554 .40227 L .53799 .40989 L .673 .757 .914 r
F
.57822 .41209 m .554 .40227 L .56592 .41538 L F
.3806 .65178 m .37658 .6595 L .38317 .65317 L .645 .732 .913 r
F
.3806 .65178 m .37144 .65673 L .37658 .6595 L F
.41915 .54019 m .40512 .5329 L .40561 .53749 L .794 .541 .555 r
F
.127 .923 .03 r
.4087 .53578 m
.40871 .53138 L
s
.40947 .52673 m
.40956 .53547 L
s
.41963 .54477 m .41915 .54019 L .40561 .53749 L .794 .541 .555 r
F
0 g
.41915 .54019 m
.43065 .54501 L
s
.67062 .75342 m .67008 .7568 L .6724 .75423 L .692 .759 .904 r
F
.67062 .75342 m .6674 .7556 L .67008 .7568 L F
0 g
.67008 .7568 m
.67323 .75748 L
s
.60348 .53108 m .61642 .53845 L .62269 .5334 L .683 .77 .917 r
F
.59946 .5331 m .61642 .53845 L .60348 .53108 L F
.39581 .65391 m .40187 .66098 L .40721 .65883 L .645 .732 .913 r
F
.39273 .6545 m .40187 .66098 L .39581 .65391 L F
.67665 .74971 m .67651 .75255 L .6788 .75223 L .692 .759 .904 r
F
0 g
.67692 .74936 m
.67693 .75019 L
s
.67551 .74967 m .67424 .75248 L .67651 .75255 L .692 .759 .904 r
F
.4224 .65659 m .42668 .64743 L .42642 .65122 L .075 0 .401 r
F
.42215 .66037 m .4224 .65659 L .42642 .65122 L F
.41161 .65208 m .4224 .65659 L .42642 .65122 L .645 .732 .913 r
F
.40746 .65505 m .4224 .65659 L .41161 .65208 L F
0 g
.41775 .65992 m
.4224 .65659 L
s
.67779 .74955 m .6788 .75223 L .68096 .75155 L .692 .759 .904 r
F
.66538 .75395 m .66714 .7534 L .6674 .7556 L .935 .633 .444 r
F
.66538 .75395 m .66512 .75175 L .66714 .7534 L F
.669 .75012 m .66714 .7534 L .67035 .75122 L .692 .759 .904 r
F
.669 .75012 m .66512 .75175 L .66714 .7534 L F
0 g
.66714 .7534 m
.66925 .75435 L
s
.67446 .74945 m .67424 .75248 L .67551 .74967 L .692 .759 .904 r
F
.67446 .74945 m .67214 .75203 L .67424 .75248 L F
.68612 .75458 m .68804 .75051 L .68831 .75271 L .393 .241 .554 r
F
.6831 .75275 m .68612 .75458 L .68831 .75271 L .692 .759 .904 r
F
.68123 .75375 m .68612 .75458 L .6831 .75275 L F
0 g
.68332 .75609 m
.68612 .75458 L
s
.62152 .52419 m .6436 .52049 L .62557 .51851 L .683 .77 .917 r
F
.60552 .51936 m .62152 .52419 L .62557 .51851 L F
.53838 .42112 m .52552 .42526 L .52585 .43095 L .386 .233 .548 r
F
.53838 .42112 m .53806 .41543 L .52552 .42526 L F
0 g
.5174 .43657 m
.52552 .42526 L
s
.67887 .74921 m .68096 .75155 L .68283 .75055 L .692 .759 .904 r
F
.37891 .64628 m .36781 .64951 L .3717 .65295 L .645 .732 .913 r
F
.57333 .5257 m .56242 .53668 L .57621 .52791 L .683 .77 .917 r
F
.57333 .5257 m .55665 .53227 L .56242 .53668 L F
.39874 .64905 m .40746 .65505 L .41161 .65208 L .645 .732 .913 r
F
.39607 .65013 m .40746 .65505 L .39874 .64905 L F
.37622 .53904 m .36189 .5386 L .36237 .54318 L .605 .403 .581 r
F
.37622 .53904 m .37573 .53445 L .36189 .5386 L F
0 g
.3499 .54466 m
.36189 .5386 L
s
.53521 .53547 m .53997 .53885 L .54047 .54343 L .98 .688 .334 r
F
.53521 .53547 m .53472 .53088 L .53997 .53885 L F
.55315 .52696 m .53997 .53885 L .55665 .53227 L .683 .77 .917 r
F
.55315 .52696 m .53472 .53088 L .53997 .53885 L F
0 g
.53997 .53885 m
.5441 .542 L
s
.68804 .75051 m .68919 .74618 L .68946 .74838 L .193 .102 .517 r
F
.68831 .75271 m .68804 .75051 L .68946 .74838 L F
.68429 .74929 m .68804 .75051 L .68946 .74838 L .692 .759 .904 r
F
.68283 .75055 m .68804 .75051 L .68429 .74929 L F
0 g
.68585 .75238 m
.68804 .75051 L
s
.55573 .43174 m .53838 .42112 L .52585 .43095 L .673 .757 .914 r
F
0 g
.51772 .44227 m
.52585 .43095 L
s
.56645 .42663 m .53838 .42112 L .55573 .43174 L .673 .757 .914 r
F
.67264 .74629 m .66877 .74791 L .67011 .749 L .692 .759 .904 r
F
.66389 .74977 m .66485 .74955 L .66512 .75175 L .973 .67 .296 r
F
.66389 .74977 m .66362 .74757 L .66485 .74955 L F
0 g
.66485 .74955 m
.66672 .75108 L
s
.66796 .74659 m .66491 .74952 L .66877 .74791 L .692 .759 .904 r
F
.66796 .74659 m .66369 .74755 L .66491 .74952 L F
.127 .923 .03 r
.66446 .74738 m
.66559 .69307 L
s
.61672 .42003 m .612 .40209 L .60468 .41716 L .673 .757 .914 r
F
0 g
.61185 .35638 m
.61186 .36171 L
s
.61672 .42003 m .63007 .4064 L .612 .40209 L .673 .757 .914 r
F
.67357 .74905 m .67214 .75203 L .67446 .74945 L .692 .759 .904 r
F
.67357 .74905 m .67035 .75122 L .67214 .75203 L F
.68398 .74708 m .68913 .74617 L .68492 .74567 L F
.68025 .74587 m .68398 .74708 L .68492 .74567 L F
.67691 .75191 m .67678 .75475 L .67907 .75443 L F
.67578 .75188 m .67678 .75475 L .67691 .75191 L F
.67578 .75188 m .6745 .75468 L .67678 .75475 L F
.67806 .75175 m .67907 .75443 L .68123 .75375 L F
.67691 .75191 m .67907 .75443 L .67806 .75175 L F
.6798 .74871 m .68283 .75055 L .68429 .74929 L F
.66927 .75233 m .6674 .7556 L .67062 .75342 L F
.66927 .75233 m .66538 .75395 L .6674 .7556 L F
0 g
.6674 .7556 m
.67008 .7568 L
s
.68946 .74838 m .68919 .74618 L .68975 .74395 L 0 0 .39 r
F
0 g
.68777 .7483 m
.68919 .74618 L
s
.68492 .74567 m .68913 .74617 L .68968 .74395 L .692 .759 .904 r
F
.67473 .75165 m .6745 .75468 L .67578 .75188 L F
.67473 .75165 m .6724 .75423 L .6745 .75468 L F
.36516 .64941 m .35644 .65652 L .36755 .65329 L .645 .732 .913 r
F
.36516 .64941 m .35287 .65069 L .35644 .65652 L F
0 g
.35644 .65652 m
.36229 .66168 L
s
.67914 .75141 m .68123 .75375 L .6831 .75275 L .692 .759 .904 r
F
.67806 .75175 m .68123 .75375 L .67914 .75141 L F
.60427 .41162 m .59209 .3954 L .5913 .4108 L .673 .757 .914 r
F
.60427 .41162 m .61156 .39662 L .59209 .3954 L F
.42215 .66037 m .42642 .65122 L .42617 .655 L .075 0 .401 r
F
.41135 .65586 m .42215 .66037 L .42617 .655 L .645 .732 .913 r
F
.40721 .65883 m .42215 .66037 L .41135 .65586 L F
0 g
.41592 .66482 m
.42215 .66037 L
s
.64437 .5251 m .64387 .52052 L .64628 .51154 L 0 0 .393 r
F
0 g
.64008 .52582 m
.64387 .52052 L
s
.68831 .75271 m .68946 .74838 L .68973 .75058 L .193 .102 .517 r
F
.68456 .7515 m .68831 .75271 L .68973 .75058 L .692 .759 .904 r
F
.6831 .75275 m .68831 .75271 L .68456 .7515 L F
0 g
.68612 .75458 m
.68831 .75271 L
s
.67289 .7485 m .67035 .75122 L .67357 .74905 L .692 .759 .904 r
F
.67289 .7485 m .669 .75012 L .67035 .75122 L F
.62557 .51851 m .6436 .52049 L .646 .51156 L .683 .77 .917 r
F
.67224 .74563 m .66877 .74791 L .67264 .74629 L .692 .759 .904 r
F
.67224 .74563 m .66796 .74659 L .66877 .74791 L F
.66416 .75197 m .66512 .75175 L .66538 .75395 L .973 .67 .296 r
F
.127 .923 .03 r
.66506 .75176 m
.66506 .75166 L
s
.66416 .75197 m .66389 .74977 L .66512 .75175 L .973 .67 .296 r
F
.66819 .7488 m .66512 .75175 L .669 .75012 L .692 .759 .904 r
F
.66819 .7488 m .66389 .74977 L .66512 .75175 L F
0 g
.66512 .75175 m
.66699 .75328 L
s
.37804 .64055 m .36818 .6457 L .37922 .64248 L .645 .732 .913 r
F
.37804 .64055 m .36581 .64183 L .36818 .6457 L F
.41963 .54477 m .40561 .53749 L .4061 .54207 L .794 .541 .555 r
F
0 g
.41963 .54477 m
.43114 .54959 L
s
.127 .923 .03 r
.4086 .60225 m
.4087 .53578 L
s
.40956 .53547 m
.41026 .60184 L
s
.40561 .53749 m .40512 .5329 L .39048 .53251 L .733 .497 .57 r
F
0 g
.40512 .5329 m
.41866 .5356 L
s
.67383 .75125 m .6724 .75423 L .67473 .75165 L .692 .759 .904 r
F
.67383 .75125 m .67062 .75342 L .6724 .75423 L F
.41176 .64825 m .4265 .64739 L .41443 .64469 L .645 .732 .913 r
F
.40102 .64376 m .41176 .64825 L .41443 .64469 L F
.39896 .64524 m .41176 .64825 L .40102 .64376 L F
.68429 .74929 m .68946 .74838 L .68523 .74788 L .692 .759 .904 r
F
.68053 .74808 m .68429 .74929 L .68523 .74788 L F
.37865 .65006 m .37144 .65673 L .3806 .65178 L .645 .732 .913 r
F
.37865 .65006 m .36755 .65329 L .37144 .65673 L F
.68492 .74567 m .68968 .74395 L .68529 .74419 L .692 .759 .904 r
F
.68072 .74517 m .68492 .74567 L .68529 .74419 L F
.68025 .74587 m .68492 .74567 L .68072 .74517 L F
.68007 .75091 m .6831 .75275 L .68456 .7515 L F
.67914 .75141 m .6831 .75275 L .68007 .75091 L F
.62218 .52882 m .64437 .5251 L .62626 .52311 L .683 .77 .917 r
F
.6061 .52397 m .62218 .52882 L .62626 .52311 L F
.60297 .5265 m .62218 .52882 L .6061 .52397 L F
.39848 .65283 m .40721 .65883 L .41135 .65586 L .645 .732 .913 r
F
.39581 .65391 m .40721 .65883 L .39848 .65283 L F
.57822 .41209 m .57245 .39733 L .554 .40227 L .673 .757 .914 r
F
.127 .923 .03 r
.55508 .39211 m
.56158 .32475 L
s
.5913 .4108 m .57245 .39733 L .57822 .41209 L .673 .757 .914 r
F
.68946 .74838 m .68975 .74395 L .69002 .74615 L 0 0 .39 r
F
.68973 .75058 m .68946 .74838 L .69002 .74615 L F
.68523 .74788 m .68946 .74838 L .69002 .74615 L .692 .759 .904 r
F
0 g
.68804 .75051 m
.68946 .74838 L
s
.57383 .53028 m .56292 .54127 L .57671 .53249 L .683 .77 .917 r
F
.57383 .53028 m .55715 .53686 L .56292 .54127 L F
.56613 .42094 m .55415 .40777 L .53806 .41543 L .673 .757 .914 r
F
.57849 .41763 m .55415 .40777 L .56613 .42094 L F
.3767 .54362 m .36237 .54318 L .36286 .54777 L .605 .403 .581 r
F
0 g
.35086 .55383 m
.36286 .54777 L
s
.3767 .54362 m .37622 .53904 L .36237 .54318 L .605 .403 .581 r
F
0 g
.35038 .54924 m
.36237 .54318 L
s
.55365 .53155 m .54047 .54343 L .55715 .53686 L .683 .77 .917 r
F
.55365 .53155 m .53521 .53547 L .54047 .54343 L F
0 g
.54047 .54343 m
.54913 .55004 L
s
.66354 .74759 m .66362 .74757 L .66389 .74977 L .746 .532 0 r
F
.66354 .74759 m .66328 .74539 L .66362 .74757 L F
0 g
.66362 .74757 m
.66485 .74955 L
s
.66773 .74514 m .66369 .74755 L .66796 .74659 L .692 .759 .904 r
F
.66773 .74514 m .66334 .74538 L .66369 .74755 L F
.127 .923 .03 r
.66441 .74965 m
.66445 .74754 L
s
.67316 .7507 m .67062 .75342 L .67383 .75125 L .692 .759 .904 r
F
.67316 .7507 m .66927 .75233 L .67062 .75342 L F
.67248 .74784 m .669 .75012 L .67289 .7485 L F
.67248 .74784 m .66819 .7488 L .669 .75012 L F
.66846 .751 m .66538 .75395 L .66927 .75233 L F
.66846 .751 m .66416 .75197 L .66538 .75395 L F
0 g
.66538 .75395 m
.6674 .7556 L
s
.127 .923 .03 r
.66128 .93249 m
.66433 .78671 L
s
.66433 .78671 m
.66503 .75337 L
s
.5913 .4108 m .59209 .3954 L .57245 .39733 L .673 .757 .914 r
F
.67212 .74491 m .66796 .74659 L .67224 .74563 L .692 .759 .904 r
F
.67212 .74491 m .66773 .74514 L .66796 .74659 L F
.68072 .74517 m .68529 .74419 L .6809 .74443 L F
.6454 .4135 m .64507 .40781 L .62974 .40071 L .861 .596 .537 r
F
0 g
.64507 .40781 m
.65661 .4172 L
s
.68456 .7515 m .68973 .75058 L .6855 .75008 L .692 .759 .904 r
F
.6808 .75028 m .68456 .7515 L .6855 .75008 L F
.68007 .75091 m .68456 .7515 L .6808 .75028 L F
0 g
.67693 .75019 m
.67853 .74999 L
s
.67693 .75019 m
.67693 .75019 L
s
.67535 .74993 m
.67693 .75019 L
s
.69002 .74615 m .68975 .74395 L .6894 .74177 L .744 .531 0 r
F
.127 .923 .03 r
.69183 .76897 m
.69353 .72163 L
s
.67421 1.25904 m
.69183 .76897 L
s
.69346 .78256 m
.69498 .72102 L
s
.67521 1.5185 m
.69346 .78256 L
s
0 g
.68919 .74618 m
.68972 .74405 L
s
.68529 .74419 m .68968 .74395 L .68934 .74178 L .692 .759 .904 r
F
.68523 .74788 m .69002 .74615 L .68561 .74639 L F
.68101 .74737 m .68523 .74788 L .68561 .74639 L F
.68053 .74808 m .68523 .74788 L .68101 .74737 L F
.39096 .5371 m .37573 .53445 L .37622 .53904 L .673 .452 .578 r
F
.39096 .5371 m .39048 .53251 L .37573 .53445 L F
0 g
.36189 .5386 m
.37573 .53445 L
s
.61705 .42572 m .61233 .40779 L .60501 .42285 L .673 .757 .914 r
F
0 g
.61186 .36171 m
.61188 .36704 L
s
.61705 .42572 m .6304 .4121 L .61233 .40779 L .673 .757 .914 r
F
.35207 .64083 m .35339 .64313 L .35313 .64691 L .93 .754 .275 r
F
.35207 .64083 m .35233 .63704 L .35339 .64313 L F
0 g
.35339 .64313 m
.35556 .64666 L
s
.3651 .63779 m .35358 .64311 L .36581 .64183 L .645 .732 .913 r
F
.3651 .63779 m .35252 .63706 L .35358 .64311 L F
.68529 .74419 m .68934 .74178 L .68506 .74275 L .692 .759 .904 r
F
.6809 .74443 m .68529 .74419 L .68506 .74275 L F
.57117 .51844 m .55631 .52762 L .57291 .52108 L .683 .77 .917 r
F
.57117 .51844 m .55283 .52234 L .55631 .52762 L F
.68973 .75058 m .69002 .74615 L .69029 .74835 L 0 0 .39 r
F
.6855 .75008 m .68973 .75058 L .69029 .74835 L .692 .759 .904 r
F
0 g
.68831 .75271 m
.68973 .75058 L
s
.37772 .64434 m .36781 .64951 L .37891 .64628 L .645 .732 .913 r
F
.37772 .64434 m .36542 .64563 L .36781 .64951 L F
.67705 .74907 m .67691 .75191 L .67806 .75175 L .692 .759 .904 r
F
.67705 .74907 m .67578 .75188 L .67691 .75191 L F
.67705 .74907 m .67806 .75175 L .67914 .75141 L F
0 g
.67853 .74999 m
.67956 .74955 L
s
.42642 .65122 m .42668 .64743 L .42822 .6415 L 0 0 .137 r
F
0 g
.42374 .65137 m
.42668 .64743 L
s
.41161 .65208 m .42642 .65122 L .41429 .64849 L .645 .732 .913 r
F
.40082 .64757 m .41161 .65208 L .41429 .64849 L F
.39874 .64905 m .41161 .65208 L .40082 .64757 L F
.41443 .64469 m .4265 .64739 L .42803 .64149 L F
.66381 .74979 m .66389 .74977 L .66416 .75197 L .746 .532 0 r
F
.66381 .74979 m .66354 .74759 L .66389 .74977 L F
.66796 .74735 m .66389 .74977 L .66819 .7488 L .692 .759 .904 r
F
.66796 .74735 m .66354 .74759 L .66389 .74977 L F
0 g
.66389 .74977 m
.66512 .75175 L
s
.6809 .74443 m .68506 .74275 L .68079 .74371 L .692 .759 .904 r
F
.67705 .74907 m .67473 .75165 L .67578 .75188 L F
0 g
.67436 .74945 m
.67535 .74993 L
s
.64437 .5251 m .64628 .51154 L .64679 .51613 L 0 0 .393 r
F
.64488 .52969 m .64437 .5251 L .64679 .51613 L F
.62626 .52311 m .64437 .5251 L .64679 .51613 L .683 .77 .917 r
F
0 g
.64058 .53041 m
.64437 .5251 L
s
.40561 .53749 m .39048 .53251 L .39096 .5371 L .733 .497 .57 r
F
0 g
.37573 .53445 m
.39048 .53251 L
s
.39048 .53251 m
.40512 .5329 L
s
.67705 .74907 m .67914 .75141 L .68007 .75091 L .692 .759 .904 r
F
.39347 .64383 m .40082 .64757 L .40215 .64577 L .645 .732 .913 r
F
.39002 .64305 m .39337 .64446 L .39347 .64383 L F
.39337 .64446 m .40082 .64757 L .39347 .64383 L F
.39344 .6437 m .39356 .64288 L .39356 .64327 L 0 0 .133 r
F
.39301 .64438 m .39301 .64461 L .39301 .64462 L .069 0 .411 r
F
.39429 .64484 m .39874 .64905 L .40082 .64757 L .645 .732 .913 r
F
.39301 .64438 m .39344 .6437 L .39344 .64401 L .069 0 .411 r
F
.39303 .64815 m .39344 .64758 L .39331 .70298 L F
.39205 .64952 m .39581 .65391 L .39258 .64878 L .645 .732 .913 r
F
.39446 .6488 m .39848 .65283 L .40056 .65135 L F
.39226 .64567 m .39299 .65072 L .39607 .65013 L F
.38976 .64683 m .39533 .65067 L .39446 .6488 L F
.39533 .65067 m .39848 .65283 L .39446 .6488 L F
.39318 .64438 m .39508 .64653 L .39429 .64484 L F
.39345 .64395 m .39356 .64327 L .39355 .64683 L 0 0 .133 r
F
.39356 .64326 m .39352 .64677 L .39356 .64327 L .985 .728 .342 r
F
.39338 .64765 m .40056 .65135 L .4019 .64956 L .645 .732 .913 r
F
.39146 .64679 m .39299 .65072 L .39226 .64567 L F
.39127 .64539 m .3923 .64495 L .39229 .64868 L .515 .301 .526 r
F
.39156 .64894 m .39205 .64952 L .39239 .64864 L .645 .732 .913 r
F
.39124 .65066 m .39273 .6545 L .39205 .64952 L F
.39133 .64902 m .39229 .64868 L .39216 .70423 L .515 .301 .526 r
F
.39127 .64539 m .39229 .64868 L .39133 .64902 L F
.39239 .64864 m .39205 .64952 L .39258 .64878 L .645 .732 .913 r
F
.38967 .6456 m .39127 .64539 L .39126 .64904 L .641 .4 .539 r
F
.39063 .64909 m .39124 .65066 L .39162 .64901 L .645 .732 .913 r
F
.38976 .64683 m .38945 .65457 L .39273 .6545 L F
.38976 .64916 m .39126 .64904 L .39113 .70467 L .641 .4 .539 r
F
.38967 .6456 m .39126 .64904 L .38976 .64916 L F
.39162 .64901 m .39124 .65066 L .39205 .64952 L .645 .732 .913 r
F
.38976 .64683 m .39063 .64909 L .39162 .64901 L F
.38976 .64683 m .39156 .64894 L .39239 .64864 L F
.38976 .64683 m .393 .64819 L .39338 .64765 L F
.39325 .64527 m .39607 .65013 L .39874 .64905 L F
.39002 .64305 m .39304 .64659 L .39325 .64527 L F
.39304 .64659 m .39607 .65013 L .39325 .64527 L F
.39344 .644 m .39355 .64683 L .39344 .64753 L 0 0 .133 r
F
.39344 .6437 m .39345 .64395 L .39344 .644 L F
.39277 .64495 m .39508 .64653 L .39318 .64438 L .645 .732 .913 r
F
.39345 .64395 m .39355 .64683 L .39344 .644 L 0 0 .133 r
F
.39344 .64758 m .39342 .70216 L .39331 .70298 L F
.39344 .6437 m .39344 .64753 L .39344 .64758 L F
.39344 .64753 m .39342 .70216 L .39344 .64758 L F
.393 .64819 m .39332 .64832 L .39338 .64765 L .645 .732 .913 r
F
.39332 .64832 m .40056 .65135 L .39342 .64767 L F
.39332 .64832 m .39342 .64767 L .39338 .64765 L F
.39301 .64461 m .39303 .64815 L .39301 .64462 L .069 0 .411 r
F
.39303 .64815 m .39331 .70298 L .39303 .64815 L F
.39303 .64815 m .39303 .64815 L .39301 .64462 L F
.39352 .64677 m .39296 .70111 L .39352 .64677 L .985 .728 .342 r
F
.39352 .64677 m .39352 .64677 L .39356 .64327 L F
.39344 .64753 m .39355 .64683 L .39342 .70216 L 0 0 .133 r
F
.39355 .64683 m .39296 .70111 L .39342 .70216 L .985 .728 .342 r
F
.39356 .64327 m .39352 .64677 L .39355 .64683 L F
.39352 .64677 m .39296 .70111 L .39355 .64683 L F
.39258 .64878 m .39581 .65391 L .39668 .65356 L .645 .732 .913 r
F
.39533 .65067 m .39668 .65356 L .39848 .65283 L F
.39258 .64878 m .39668 .65356 L .39533 .65067 L F
.39301 .64461 m .39344 .64401 L .39344 .64758 L .069 0 .411 r
F
.39301 .64461 m .39344 .64758 L .39303 .64815 L F
.39301 .64438 m .39344 .64401 L .39301 .64461 L F
.39002 .64305 m .39277 .64495 L .39318 .64438 L .645 .732 .913 r
F
.39508 .64653 m .39874 .64905 L .39429 .64484 L F
.39356 .64288 m .39356 .64326 L .39356 .64327 L .985 .728 .342 r
F
.39344 .6437 m .39356 .64327 L .39345 .64395 L 0 0 .133 r
F
.39297 .65059 m .39273 .6545 L .39581 .65391 L .645 .732 .913 r
F
.39205 .64952 m .39256 .65323 L .39297 .65059 L F
.39256 .65323 m .39273 .6545 L .39297 .65059 L F
.39197 .70194 m .39332 .70402 L .39518 .70302 L .692 .759 .903 r
F
.39121 .70168 m .39175 .70228 L .39197 .70194 L F
.39175 .70228 m .39332 .70402 L .39197 .70194 L F
.39195 .70129 m .39518 .70302 L .39214 .70118 L F
.39121 .70168 m .3914 .70174 L .39195 .70129 L F
.3914 .70174 m .39518 .70302 L .39195 .70129 L F
.39043 .70193 m .39332 .70402 L .39121 .70168 L F
.39014 .70202 m .39018 .70205 L .39043 .70193 L F
.39018 .70205 m .39332 .70402 L .39043 .70193 L F
.39014 .70202 m .39118 .7047 L .39332 .70402 L F
.39217 .70325 m .39148 .7039 L .39241 .70339 L F
.39114 .70159 m .39184 .70341 L .39113 .70374 L .515 .301 .526 r
F
.389 .70218 m .39118 .7047 L .39014 .70202 L .692 .759 .903 r
F
.39028 .70391 m .38926 .7044 L .3904 .70424 L F
.38954 .7019 m .39065 .70383 L .38953 .70405 L .641 .4 .539 r
F
.38936 .70155 m .38927 .7041 L .39028 .70391 L .692 .759 .903 r
F
.38927 .7041 m .38926 .7044 L .39028 .70391 L F
.38889 .70501 m .39221 .70737 L .39118 .7047 L F
.38926 .7044 m .39145 .70693 L .3904 .70424 L F
.38953 .70405 m .39113 .70467 L .38953 .70488 L .641 .4 .539 r
F
.39131 .70371 m .3904 .70424 L .39148 .7039 L .692 .759 .903 r
F
.39111 .70375 m .39065 .70383 L .38954 .7019 L .641 .4 .539 r
F
.38936 .70155 m .39028 .70391 L .39131 .70371 L .692 .759 .903 r
F
.39028 .70391 m .3904 .70424 L .39131 .70371 L F
.39114 .70159 m .39014 .70202 L .39121 .70168 L F
.39006 .7018 m .39014 .70202 L .39114 .70159 L F
.39105 .70161 m .39111 .70375 L .38954 .7019 L .641 .4 .539 r
F
.39118 .7047 m .39543 .70635 L .39332 .70402 L .692 .759 .903 r
F
.3904 .70424 m .3936 .70624 L .39148 .7039 L F
.39111 .70375 m .39113 .70467 L .39065 .70383 L .641 .4 .539 r
F
.39065 .70383 m .39113 .70467 L .38953 .70405 L F
.38967 .6456 m .39105 .70161 L .38954 .7019 L F
.38911 .69935 m .39006 .7018 L .39114 .70159 L .692 .759 .903 r
F
.38936 .70155 m .39128 .70367 L .39217 .70325 L F
.39128 .70367 m .39148 .7039 L .39217 .70325 L F
.39113 .70374 m .39216 .70423 L .39113 .70467 L .515 .301 .526 r
F
.39148 .7039 m .39546 .70524 L .39241 .70339 L .692 .759 .903 r
F
.39184 .70341 m .39216 .70423 L .39113 .70374 L .515 .301 .526 r
F
.39643 .64723 m .4019 .64956 L .40241 .64758 L .645 .732 .913 r
F
.39356 .64326 m .40215 .64577 L .40267 .6438 L F
.39002 .64305 m .39386 .64391 L .39356 .64326 L F
.39386 .64391 m .40215 .64577 L .39356 .64326 L F
.39356 .64288 m .3931 .64183 L .3931 .64229 L .985 .728 .342 r
F
.39351 .64317 m .3931 .64229 L .39309 .64585 L F
.39356 .64288 m .3931 .64229 L .39351 .64317 L F
.393 .64818 m .39329 .69987 L .39288 .70051 L .069 0 .411 r
F
.39303 .64815 m .39331 .70298 L .393 .64818 L F
.39586 .6462 m .40241 .64758 L .40206 .64555 L .645 .732 .913 r
F
.39301 .64462 m .39303 .64815 L .393 .64818 L .069 0 .411 r
F
.39298 .64219 m .40231 .64177 L .40113 .63982 L .645 .732 .913 r
F
.39002 .64305 m .39362 .64268 L .39298 .64219 L F
.39362 .64268 m .40231 .64177 L .39298 .64219 L F
.3931 .64183 m .39204 .641 L .39204 .64149 L .909 .63 .5 r
F
.39362 .64268 m .40267 .6438 L .40231 .64177 L .645 .732 .913 r
F
.39002 .64305 m .39448 .64331 L .39362 .64268 L F
.39448 .64331 m .40267 .6438 L .39362 .64268 L F
.39229 .64868 m .39284 .70054 L .39217 .7011 L .354 .175 .495 r
F
.3923 .64495 m .39301 .64438 L .393 .64818 L F
.39234 .64865 m .393 .64818 L .39287 .70366 L F
.3923 .64495 m .393 .64818 L .39234 .64865 L F
.38976 .64683 m .39368 .64771 L .39366 .64706 L .645 .732 .913 r
F
.39368 .64771 m .39399 .64778 L .39389 .64757 L F
.39368 .64771 m .39389 .64757 L .39366 .64706 L F
.3931 .64183 m .39203 .64506 L .39302 .6458 L .909 .63 .5 r
F
.39179 .64488 m .39892 .64188 L .39635 .6405 L .645 .732 .913 r
F
.39002 .64305 m .39146 .64679 L .39226 .64567 L F
.39175 .64138 m .39918 .6381 L .39661 .63672 L F
.39002 .64305 m .39256 .64168 L .39175 .64138 L F
.39256 .64168 m .39918 .6381 L .39175 .64138 L F
.39204 .641 m .39095 .64062 L .39095 .6411 L .81 .54 .531 r
F
.3931 .64183 m .3931 .64228 L .3931 .64229 L .909 .63 .5 r
F
.3931 .64183 m .39204 .64149 L .39298 .6422 L F
.39256 .64168 m .40113 .63982 L .39918 .6381 L .645 .732 .913 r
F
.39002 .64305 m .39354 .64203 L .39256 .64168 L F
.39354 .64203 m .40113 .63982 L .39256 .64168 L F
.39126 .64904 m .39211 .70113 L .39114 .70159 L .515 .301 .526 r
F
.39133 .64902 m .39211 .70113 L .39126 .64904 L F
.3931 .64228 m .39302 .6458 L .3931 .64229 L .909 .63 .5 r
F
.39302 .6458 m .3919 .70029 L .39303 .64581 L F
.39302 .6458 m .39303 .64581 L .3931 .64229 L F
.3931 .64586 m .40206 .64555 L .40087 .6436 L .645 .732 .913 r
F
.38976 .64683 m .39383 .64641 L .3931 .64586 L F
.39383 .64641 m .40206 .64555 L .3931 .64586 L F
.39264 .64528 m .40087 .6436 L .39892 .64188 L F
.38976 .64683 m .39375 .64567 L .39264 .64528 L F
.39356 .64288 m .39309 .64585 L .39352 .64677 L .985 .728 .342 r
F
.39375 .64567 m .40087 .6436 L .39264 .64528 L .645 .732 .913 r
F
.38911 .69935 m .39286 .70056 L .39333 .69985 L .692 .759 .903 r
F
.39203 .64506 m .39087 .69708 L .3919 .69735 L .81 .54 .531 r
F
.39108 .69713 m .39229 .69718 L .3914 .69677 L .692 .759 .903 r
F
.38911 .69935 m .392 .69738 L .39108 .69713 L F
.392 .69738 m .39229 .69718 L .39108 .69713 L F
.38911 .69935 m .39351 .69911 L .39338 .69838 L F
.38911 .69935 m .39338 .69838 L .39297 .69772 L F
.3919 .69735 m .39108 .69928 L .3919 .6995 L .81 .54 .531 r
F
.38911 .69935 m .39333 .69985 L .39351 .69911 L .692 .759 .903 r
F
.39133 .69935 m .39256 .69937 L .39167 .69896 L F
.38911 .69935 m .39214 .70118 L .39286 .70056 L F
.38936 .70155 m .39224 .69959 L .39133 .69935 L F
.38936 .70155 m .39366 .70058 L .39324 .69992 L F
.39297 .70021 m .3919 .70029 L .39296 .70111 L .909 .63 .5 r
F
.39234 .64865 m .39284 .70054 L .39229 .64868 L .354 .175 .495 r
F
.39309 .64585 m .39191 .69951 L .39297 .70021 L .909 .63 .5 r
F
.38911 .69935 m .39121 .70168 L .39214 .70118 L .692 .759 .903 r
F
.38936 .70155 m .39324 .69992 L .39256 .69937 L F
.39191 .69951 m .3919 .70029 L .39297 .70021 L .909 .63 .5 r
F
.39224 .69959 m .39256 .69937 L .39168 .69935 L .692 .759 .903 r
F
.3919 .6995 m .39168 .69935 L .39133 .69935 L F
.39224 .69959 m .39168 .69935 L .3919 .6995 L F
.3919 .6995 m .39081 .69991 L .3919 .70029 L .81 .54 .531 r
F
.39108 .69928 m .39081 .69991 L .3919 .6995 L F
.38911 .69935 m .39297 .69772 L .39229 .69718 L .692 .759 .903 r
F
.39087 .69708 m .39081 .69991 L .3919 .69735 L .81 .54 .531 r
F
.39204 .64149 m .39196 .64503 L .39203 .64506 L F
.39196 .64503 m .39081 .69991 L .39203 .64506 L F
.39204 .641 m .39203 .64148 L .39204 .64149 L F
.39203 .64148 m .39081 .69991 L .39204 .64149 L F
.39191 .64144 m .39095 .6411 L .39094 .64466 L F
.39204 .641 m .39095 .6411 L .39191 .64144 L F
.38976 .64683 m .39246 .64538 L .39203 .64506 L .645 .732 .913 r
F
.38976 .64683 m .39203 .64506 L .39172 .64495 L F
.39127 .64539 m .39133 .64902 L .39126 .64904 L .515 .301 .526 r
F
.39195 .64503 m .39094 .64466 L .39081 .69991 L .81 .54 .531 r
F
.39204 .641 m .39094 .64466 L .39195 .64503 L F
.39172 .64495 m .39203 .64506 L .39179 .64488 L .645 .732 .913 r
F
.3931 .64229 m .39303 .64581 L .39309 .64585 L .909 .63 .5 r
F
.39246 .64538 m .39892 .64188 L .39179 .64488 L .645 .732 .913 r
F
.39303 .64581 m .3919 .70029 L .39309 .64585 L .909 .63 .5 r
F
.39298 .6422 m .39204 .64149 L .39203 .64506 L F
.38976 .64683 m .39454 .64711 L .39466 .64703 L .645 .732 .913 r
F
.38976 .64683 m .39466 .64703 L .39383 .64641 L F
.3923 .64495 m .39234 .64865 L .39229 .64868 L .354 .175 .495 r
F
.39302 .6458 m .39203 .64506 L .3919 .70029 L .909 .63 .5 r
F
.39383 .64641 m .39466 .64703 L .39586 .6462 L .645 .732 .913 r
F
.39454 .64711 m .40241 .64758 L .39586 .6462 L F
.39352 .64677 m .39309 .64585 L .39296 .70111 L .985 .728 .342 r
F
.39366 .64706 m .39451 .6479 L .39643 .64723 L .645 .732 .913 r
F
.39399 .64778 m .39451 .6479 L .39366 .64706 L F
.39451 .6479 m .4019 .64956 L .39643 .64723 L F
.39214 .70326 m .39184 .70341 L .39114 .70159 L .515 .301 .526 r
F
.39216 .70325 m .39287 .70366 L .39216 .70423 L .354 .175 .495 r
F
.39217 .7011 m .39265 .70285 L .39216 .70325 L F
.39217 .70325 m .39217 .70325 L .39285 .70267 L .692 .759 .903 r
F
.39217 .70325 m .39241 .70339 L .39309 .70281 L F
.39265 .70285 m .39287 .70366 L .39216 .70325 L .354 .175 .495 r
F
.39285 .70267 m .39217 .70325 L .39314 .70277 L .692 .759 .903 r
F
.38936 .70155 m .39217 .70325 L .39285 .70267 L F
.39217 .70325 m .39309 .70281 L .39314 .70277 L F
.39211 .70113 m .39214 .70326 L .39114 .70159 L .515 .301 .526 r
F
.39214 .70326 m .39216 .70423 L .39184 .70341 L F
.39214 .70118 m .39518 .70302 L .39662 .70177 L .692 .759 .903 r
F
.39284 .70054 m .39286 .70267 L .39217 .7011 L .354 .175 .495 r
F
.39288 .70051 m .39317 .70219 L .39287 .70266 L .069 0 .411 r
F
.38936 .70155 m .39359 .70205 L .39378 .70131 L .692 .759 .903 r
F
.39359 .70205 m .39361 .70206 L .39361 .70204 L F
.39359 .70205 m .39361 .70204 L .39378 .70131 L F
.39286 .70267 m .39287 .70366 L .39265 .70285 L .354 .175 .495 r
F
.39286 .70267 m .39265 .70285 L .39217 .7011 L F
.39328 .70202 m .39314 .70277 L .39361 .70206 L .692 .759 .903 r
F
.38936 .70155 m .39286 .70268 L .39328 .70202 L F
.39286 .70268 m .39314 .70277 L .39328 .70202 L F
.39241 .70339 m .39691 .70398 L .39314 .70277 L F
.39287 .70266 m .39331 .70298 L .39287 .70366 L .069 0 .411 r
F
.39317 .70219 m .39331 .70298 L .39287 .70266 L F
.39214 .70118 m .39662 .70177 L .39286 .70056 L .692 .759 .903 r
F
.39329 .69987 m .3933 .70199 L .39288 .70051 L .069 0 .411 r
F
.38936 .70155 m .39373 .70131 L .39366 .70058 L .692 .759 .903 r
F
.39373 .70131 m .39378 .70131 L .39377 .70124 L F
.39373 .70131 m .39377 .70124 L .39366 .70058 L F
.3933 .70199 m .39331 .70298 L .39317 .70219 L .069 0 .411 r
F
.3933 .70199 m .39317 .70219 L .39288 .70051 L F
.4061 .54207 m .40561 .53749 L .39096 .5371 L .733 .497 .57 r
F
0 g
.40561 .53749 m
.41915 .54019 L
s
.67275 .75004 m .66927 .75233 L .67316 .7507 L .692 .759 .904 r
F
.67275 .75004 m .66846 .751 L .66927 .75233 L F
.67705 .74907 m .67383 .75125 L .67473 .75165 L F
0 g
.6737 .74886 m
.67436 .74945 L
s
.67237 .74711 m .66819 .7488 L .67248 .74784 L .692 .759 .904 r
F
.67237 .74711 m .66796 .74735 L .66819 .7488 L F
.68101 .74737 m .68561 .74639 L .68119 .74663 L F
.67231 .74417 m .66773 .74514 L .67212 .74491 L F
.67705 .74907 m .68007 .75091 L .6808 .75028 L F
0 g
.67956 .74955 m
.68027 .74898 L
s
.60468 .41716 m .59243 .40086 L .59164 .41634 L .673 .757 .914 r
F
.60468 .41716 m .612 .40209 L .59243 .40086 L F
0 g
.68027 .74898 m
.68071 .7483 L
s
.62269 .5334 m .64488 .52969 L .62676 .52769 L .683 .77 .917 r
F
.60661 .52856 m .62269 .5334 L .62676 .52769 L F
.60348 .53108 m .62269 .5334 L .60661 .52856 L F
0 g
.67332 .74816 m
.6737 .74886 L
s
.69002 .74615 m .6894 .74177 L .68967 .74397 L .744 .531 0 r
F
.69029 .74835 m .69002 .74615 L .68967 .74397 L F
0 g
.68946 .74838 m
.68999 .74625 L
s
.68561 .74639 m .69002 .74615 L .68967 .74397 L .692 .759 .904 r
F
.68079 .74371 m .68425 .74143 L .68038 .74305 L F
.68079 .74371 m .68506 .74275 L .68425 .74143 L F
.6855 .75008 m .69029 .74835 L .68587 .74859 L F
.68128 .74958 m .6855 .75008 L .68587 .74859 L F
.6808 .75028 m .6855 .75008 L .68128 .74958 L F
.6681 .74367 m .66334 .74538 L .66773 .74514 L F
.67231 .74417 m .6681 .74367 L .66773 .74514 L F
.67705 .74907 m .67316 .7507 L .67383 .75125 L F
.68561 .74639 m .68967 .74397 L .68537 .74494 L F
.68119 .74663 m .68561 .74639 L .68537 .74494 L F
.6681 .74367 m .66389 .74317 L .66334 .74538 L F
.6641 .74536 m .66328 .74539 L .66354 .74759 L 0 0 .389 r
F
0 g
.66359 .74739 m
.66362 .74757 L
s
.6641 .74536 m .66383 .74316 L .66328 .74539 L 0 0 .389 r
F
.67705 .74907 m .6808 .75028 L .68128 .74958 L .692 .759 .904 r
F
.66822 .74955 m .66416 .75197 L .66846 .751 L F
.66822 .74955 m .66381 .74979 L .66416 .75197 L F
0 g
.66416 .75197 m
.66538 .75395 L
s
.127 .923 .03 r
.66441 .74976 m
.66441 .74971 L
s
.67278 .74346 m .6681 .74367 L .67231 .74417 L .692 .759 .904 r
F
.68119 .74663 m .68537 .74494 L .68108 .7459 L F
0 g
.68071 .7483 m
.68084 .74748 L
s
.68506 .74275 m .68812 .73981 L .68425 .74143 L .692 .759 .904 r
F
.68506 .74275 m .68934 .74178 L .68812 .73981 L F
.127 .923 .03 r
.66433 .75342 m
.66436 .75188 L
s
.49587 8.79989 m
.66433 .75342 L
s
0 0 0 r
2.5 Mabswid
.66436 .75188 Mdot
0 g
.5 Mabswid
.67327 .74735 m
.67332 .74816 L
s
.68038 .74305 m .68291 .74034 L .67971 .7425 L .692 .759 .904 r
F
.68038 .74305 m .68425 .74143 L .68291 .74034 L F
.67678 .74687 m .68067 .74524 L .68 .74469 L F
0 g
.68038 .74339 m
.68039 .74501 L
s
.67678 .74687 m .68108 .7459 L .68067 .74524 L .692 .759 .904 r
F
0 g
.68039 .74554 m
.68039 .74644 L
s
.67705 .74907 m .67275 .75004 L .67316 .7507 L .692 .759 .904 r
F
.56645 .42663 m .55447 .41346 L .53838 .42112 L .673 .757 .914 r
F
.57881 .42332 m .55447 .41346 L .56645 .42663 L F
.57849 .41763 m .57269 .4028 L .55415 .40777 L F
.59164 .41634 m .57269 .4028 L .57849 .41763 L F
.35181 .64461 m .35313 .64691 L .35287 .65069 L .93 .754 .275 r
F
.35181 .64461 m .35207 .64083 L .35313 .64691 L F
.36472 .64157 m .35313 .64691 L .36542 .64563 L .645 .732 .913 r
F
.36472 .64157 m .35207 .64083 L .35313 .64691 L F
0 g
.35313 .64691 m
.3553 .65044 L
s
.67264 .74931 m .66846 .751 L .67275 .75004 L .692 .759 .904 r
F
.67264 .74931 m .66822 .74955 L .66846 .751 L F
.37746 .64812 m .36755 .65329 L .37865 .65006 L .645 .732 .913 r
F
.37746 .64812 m .36516 .64941 L .36755 .65329 L F
.68128 .74958 m .68587 .74859 L .68146 .74883 L .692 .759 .904 r
F
.67705 .74907 m .68128 .74958 L .68146 .74883 L F
.67255 .74637 m .66796 .74735 L .67237 .74711 L F
.68967 .74397 m .6894 .74177 L .68818 .73979 L .973 .67 .295 r
F
0 g
.6894 .74177 m
.68975 .74395 L
s
.39145 .54168 m .37622 .53904 L .3767 .54362 L .673 .452 .578 r
F
0 g
.36286 .54777 m
.3767 .54362 L
s
.39145 .54168 m .39096 .5371 L .37622 .53904 L .673 .452 .578 r
F
0 g
.36237 .54318 m
.37622 .53904 L
s
.42642 .65122 m .42822 .6415 L .42796 .64528 L 0 0 .137 r
F
.42617 .655 m .42642 .65122 L .42796 .64528 L F
.41429 .64849 m .42642 .65122 L .42796 .64528 L .645 .732 .913 r
F
0 g
.42348 .65515 m
.42642 .65122 L
s
.37769 .63853 m .36581 .64183 L .37804 .64055 L .645 .732 .913 r
F
.37769 .63853 m .3651 .63779 L .36581 .64183 L F
.67278 .74346 m .66904 .74226 L .6681 .74367 L .692 .759 .904 r
F
.6735 .74284 m .66904 .74226 L .67278 .74346 L F
.41135 .65586 m .42617 .655 L .41403 .65228 L .645 .732 .913 r
F
.40056 .65135 m .41135 .65586 L .41403 .65228 L F
.39848 .65283 m .41135 .65586 L .40056 .65135 L F
.69029 .74835 m .68967 .74397 L .68994 .74617 L .744 .531 0 r
F
.68587 .74859 m .69029 .74835 L .68994 .74617 L .692 .759 .904 r
F
0 g
.68973 .75058 m
.69029 .74835 L
s
.57158 .52304 m .55665 .53227 L .57333 .5257 L .683 .77 .917 r
F
.57158 .52304 m .55315 .52696 L .55665 .53227 L F
.68108 .7459 m .68456 .74362 L .68067 .74524 L .692 .759 .904 r
F
.68108 .7459 m .68537 .74494 L .68456 .74362 L F
.66833 .74586 m .66354 .74759 L .66796 .74735 L F
.67255 .74637 m .66833 .74586 L .66796 .74735 L F
.41443 .64469 m .42803 .64149 L .41545 .64075 L .645 .732 .913 r
F
.40235 .64198 m .41443 .64469 L .41545 .64075 L F
.40102 .64376 m .41443 .64469 L .40235 .64198 L F
.67971 .7425 m .68114 .73954 L .67882 .7421 L .692 .759 .904 r
F
.67971 .7425 m .68291 .74034 L .68114 .73954 L F
.62557 .51851 m .646 .51156 L .62717 .51255 L .683 .77 .917 r
F
.60754 .51652 m .62557 .51851 L .62717 .51255 L F
.60552 .51936 m .62557 .51851 L .60754 .51652 L F
.66904 .74226 m .66389 .74317 L .6681 .74367 L .692 .759 .904 r
F
.59164 .41634 m .59243 .40086 L .57269 .4028 L .673 .757 .914 r
F
.68587 .74859 m .68994 .74617 L .68564 .74714 L .692 .759 .904 r
F
.68146 .74883 m .68587 .74859 L .68564 .74714 L F
.67705 .74907 m .67264 .74931 L .67275 .75004 L F
.6454 .4135 m .62974 .40071 L .63007 .4064 L .861 .596 .537 r
F
.64573 .41919 m .6454 .4135 L .63007 .4064 L F
0 g
.6454 .4135 m
.65694 .42289 L
s
.66437 .74756 m .66354 .74759 L .66381 .74979 L 0 0 .389 r
F
0 g
.66386 .74959 m
.66389 .74977 L
s
.66833 .74586 m .6641 .74536 L .66354 .74759 L .692 .759 .904 r
F
.66437 .74756 m .6641 .74536 L .66354 .74759 L 0 0 .389 r
F
.64488 .52969 m .64679 .51613 L .6473 .52071 L 0 0 .393 r
F
.62676 .52769 m .64488 .52969 L .6473 .52071 L .683 .77 .917 r
F
0 g
.63876 .53825 m
.64488 .52969 L
s
.4061 .54207 m .39096 .5371 L .39145 .54168 L .733 .497 .57 r
F
0 g
.37622 .53904 m
.39096 .5371 L
s
.39096 .5371 m
.40561 .53749 L
s
.4061 .54207 m
.41963 .54477 L
s
.6735 .74284 m .67049 .74101 L .66904 .74226 L .692 .759 .904 r
F
.67443 .74234 m .67049 .74101 L .6735 .74284 L F
.68146 .74883 m .68564 .74714 L .68135 .74811 L F
.67705 .74907 m .68146 .74883 L .68135 .74811 L F
0 g
.39145 .54168 m
.4061 .54207 L
s
.67303 .74566 m .66833 .74586 L .67255 .74637 L .692 .759 .904 r
F
.68537 .74494 m .68845 .74199 L .68456 .74362 L F
.68537 .74494 m .68967 .74397 L .68845 .74199 L F
.67882 .7421 m .67904 .73909 L .67778 .74188 L F
.67882 .7421 m .68114 .73954 L .67904 .73909 L F
.68425 .74143 m .68611 .73817 L .68291 .74034 L F
.68425 .74143 m .68812 .73981 L .68611 .73817 L F
.68067 .74524 m .68321 .74252 L .68 .74469 L F
.68067 .74524 m .68456 .74362 L .68321 .74252 L F
.67705 .74907 m .67282 .74857 L .67264 .74931 L F
.67705 .74907 m .6733 .74786 L .67282 .74857 L F
.67705 .74907 m .67402 .74723 L .6733 .74786 L F
0 g
.67327 .74735 m
.67381 .74632 L
s
.67705 .74907 m .67496 .74673 L .67402 .74723 L .692 .759 .904 r
F
.67705 .74907 m .67604 .74639 L .67496 .74673 L F
.67705 .74907 m .67718 .74623 L .67604 .74639 L F
.67705 .74907 m .67832 .74627 L .67718 .74623 L F
.67705 .74907 m .67937 .74649 L .67832 .74627 L F
.67705 .74907 m .68027 .7469 L .67937 .74649 L F
.67705 .74907 m .68094 .74745 L .68027 .7469 L F
0 g
.68039 .74644 m
.68076 .7473 L
s
.67705 .74907 m .68135 .74811 L .68094 .74745 L .692 .759 .904 r
F
.67443 .74234 m .67235 .74001 L .67049 .74101 L F
.67551 .742 m .67235 .74001 L .67443 .74234 L F
.67778 .74188 m .67678 .73902 L .67665 .74184 L F
.67778 .74188 m .67904 .73909 L .67678 .73902 L F
.67282 .74857 m .66822 .74955 L .67264 .74931 L F
.68967 .74397 m .68818 .73979 L .68845 .74199 L .973 .67 .295 r
F
.68994 .74617 m .68967 .74397 L .68845 .74199 L F
0 g
.68967 .74397 m
.69002 .74615 L
s
.67933 .74561 m
.68039 .74644 L
s
.68039 .74644 m
.68039 .74644 L
s
.67551 .742 m .6745 .73933 L .67235 .74001 L .692 .759 .904 r
F
.67665 .74184 m .6745 .73933 L .67551 .742 L F
0 g
.67381 .74632 m
.67381 .74632 L
s
.67381 .74632 m
.67495 .74553 L
s
.67665 .74184 m .67678 .73902 L .6745 .73933 L .692 .759 .904 r
F
.67303 .74566 m .66927 .74445 L .66833 .74586 L F
.67376 .74503 m .66927 .74445 L .67303 .74566 L F
.66904 .74226 m .66531 .74105 L .66389 .74317 L F
.66552 .74323 m .66383 .74316 L .6641 .74536 L .192 .101 .516 r
F
.66552 .74323 m .66525 .74103 L .66383 .74316 L F
0 g
.66328 .74539 m
.66383 .74316 L
s
.68135 .74811 m .68483 .74582 L .68094 .74745 L .692 .759 .904 r
F
.68135 .74811 m .68564 .74714 L .68483 .74582 L F
.66859 .74807 m .66381 .74979 L .66822 .74955 L F
.67282 .74857 m .66859 .74807 L .66822 .74955 L F
.68 .74469 m .68143 .74171 L .6791 .74429 L F
.68 .74469 m .68321 .74252 L .68143 .74171 L F
.55415 .40777 m .53773 .40974 L .53806 .41543 L .514 .328 .566 r
F
.55415 .40777 m .55382 .40207 L .53773 .40974 L F
0 g
.5252 .41956 m
.53773 .40974 L
s
.60501 .42285 m .59276 .40656 L .59196 .42203 L .673 .757 .914 r
F
.60501 .42285 m .61233 .40779 L .59276 .40656 L F
.66927 .74445 m .6641 .74536 L .66833 .74586 L .692 .759 .904 r
F
.66859 .74807 m .66437 .74756 L .66381 .74979 L F
0 g
.66381 .74979 m
.66416 .75197 L
s
.67049 .74101 m .66531 .74105 L .66904 .74226 L .692 .759 .904 r
F
.36446 .64535 m .35287 .65069 L .36516 .64941 L .645 .732 .913 r
F
.36446 .64535 m .35181 .64461 L .35287 .65069 L F
0 g
.35287 .65069 m
.35644 .65652 L
s
.67376 .74503 m .67073 .74319 L .66927 .74445 L .692 .759 .904 r
F
.67469 .74453 m .67073 .74319 L .67376 .74503 L F
.6733 .74786 m .66859 .74807 L .67282 .74857 L F
.68564 .74714 m .68872 .74419 L .68483 .74582 L F
.68564 .74714 m .68994 .74617 L .68872 .74419 L F
.53323 .52211 m .53422 .5263 L .53472 .53088 L .772 .558 0 r
F
.53323 .52211 m .53273 .51753 L .53422 .5263 L F
0 g
.53422 .5263 m
.53693 .53041 L
s
.67825 .74523 m
.67933 .74561 L
s
.55185 .51652 m .53449 .52624 L .55283 .52234 L .683 .77 .917 r
F
.55185 .51652 m .53301 .51751 L .53449 .52624 L F
.37737 .64231 m .36542 .64563 L .37772 .64434 L .645 .732 .913 r
F
.37737 .64231 m .36472 .64157 L .36542 .64563 L F
0 g
.67495 .74553 m
.67606 .74519 L
s
.42617 .655 m .42796 .64528 L .42771 .64906 L 0 0 .137 r
F
.41403 .65228 m .42617 .655 L .42771 .64906 L .645 .732 .913 r
F
0 g
.42215 .66037 m
.42617 .655 L
s
.6791 .74429 m .67933 .74126 L .67805 .74407 L .692 .759 .904 r
F
.6791 .74429 m .68143 .74171 L .67933 .74126 L F
.68845 .74199 m .68818 .73979 L .68616 .73814 L .935 .633 .443 r
F
0 g
.68818 .73979 m
.6894 .74177 L
s
.68456 .74362 m .68643 .74034 L .68321 .74252 L .692 .759 .904 r
F
.68456 .74362 m .68845 .74199 L .68643 .74034 L F
.68291 .74034 m .68345 .73697 L .68114 .73954 L F
.68291 .74034 m .68611 .73817 L .68345 .73697 L F
.68094 .74745 m .68348 .74472 L .68027 .7469 L F
.68094 .74745 m .68483 .74582 L .68348 .74472 L F
.41429 .64849 m .42796 .64528 L .41531 .64454 L .645 .732 .913 r
F
.40215 .64577 m .41429 .64849 L .41531 .64454 L F
.40082 .64757 m .41429 .64849 L .40215 .64577 L F
0 g
.3767 .54362 m
.39145 .54168 L
s
.67469 .74453 m .6726 .74219 L .67073 .74319 L .692 .759 .904 r
F
.67577 .74419 m .6726 .74219 L .67469 .74453 L F
0 g
.67716 .74511 m
.67825 .74523 L
s
.67606 .74519 m
.67716 .74511 L
s
.67805 .74407 m .67705 .74119 L .67692 .74403 L .692 .759 .904 r
F
.67805 .74407 m .67933 .74126 L .67705 .74119 L F
.40235 .64198 m .41545 .64075 L .40286 .64001 L .645 .732 .913 r
F
.68994 .74617 m .68845 .74199 L .68872 .74419 L .973 .67 .295 r
F
0 g
.68994 .74617 m
.69029 .74835 L
s
.57208 .52763 m .55715 .53686 L .57383 .53028 L .683 .77 .917 r
F
.57208 .52763 m .55365 .53155 L .55715 .53686 L F
.62626 .52311 m .64679 .51613 L .62787 .51713 L F
.60814 .52112 m .62626 .52311 L .62787 .51713 L F
.6061 .52397 m .62626 .52311 L .60814 .52112 L F
.67577 .74419 m .67476 .74151 L .6726 .74219 L .692 .759 .904 r
F
.67692 .74403 m .67476 .74151 L .67577 .74419 L F
.67692 .74403 m .67705 .74119 L .67476 .74151 L F
.6733 .74786 m .66954 .74665 L .66859 .74807 L F
.67402 .74723 m .66954 .74665 L .6733 .74786 L F
.57881 .42332 m .57302 .40849 L .55447 .41346 L .673 .757 .914 r
F
.59196 .42203 m .57302 .40849 L .57881 .42332 L F
.66579 .74544 m .6641 .74536 L .66437 .74756 L .192 .101 .516 r
F
.66927 .74445 m .66552 .74323 L .6641 .74536 L .692 .759 .904 r
F
.66579 .74544 m .66552 .74323 L .6641 .74536 L .192 .101 .516 r
F
0 g
.66354 .74759 m
.6641 .74536 L
s
.68027 .7469 m .6817 .74392 L .67937 .74649 L .692 .759 .904 r
F
.68027 .7469 m .68348 .74472 L .6817 .74392 L F
.67049 .74101 m .66748 .73918 L .66531 .74105 L F
.67235 .74001 m .66748 .73918 L .67049 .74101 L F
.66954 .74665 m .66437 .74756 L .66859 .74807 L F
.67073 .74319 m .66552 .74323 L .66927 .74445 L F
.67402 .74723 m .671 .7454 L .66954 .74665 L F
.67496 .74673 m .671 .7454 L .67402 .74723 L F
.68114 .73954 m .68031 .7363 L .67904 .73909 L F
.68114 .73954 m .68345 .73697 L .68031 .7363 L F
.67937 .74649 m .67959 .74346 L .67832 .74627 L F
.67937 .74649 m .6817 .74392 L .67959 .74346 L F
.59196 .42203 m .59276 .40656 L .57302 .40849 L .673 .757 .914 r
F
.64573 .41919 m .63007 .4064 L .6304 .4121 L .861 .596 .537 r
F
0 g
.64573 .41919 m
.65728 .42858 L
s
.68845 .74199 m .68616 .73814 L .68643 .74034 L .935 .633 .443 r
F
.68872 .74419 m .68845 .74199 L .68643 .74034 L F
0 g
.68845 .74199 m
.68967 .74397 L
s
.68483 .74582 m .6867 .74254 L .68348 .74472 L .692 .759 .904 r
F
.68483 .74582 m .68872 .74419 L .6867 .74254 L F
.68321 .74252 m .68375 .73913 L .68143 .74171 L F
.68321 .74252 m .68643 .74034 L .68375 .73913 L F
.66771 .74136 m .66525 .74103 L .66552 .74323 L .393 .241 .553 r
F
.66771 .74136 m .66744 .73915 L .66525 .74103 L F
0 g
.66383 .74316 m
.66525 .74103 L
s
.67496 .74673 m .67287 .74439 L .671 .7454 L .692 .759 .904 r
F
.67604 .74639 m .67287 .74439 L .67496 .74673 L F
.67832 .74627 m .67732 .74339 L .67718 .74623 L F
.67832 .74627 m .67959 .74346 L .67732 .74339 L F
.67235 .74001 m .67027 .73769 L .66748 .73918 L F
.6745 .73933 m .67027 .73769 L .67235 .74001 L F
0 g
.38954 .70135 m
.38954 .70047 L
s
.127 .923 .03 r
.38076 .75507 m
.39615 8.82491 L
s
.38064 .6913 m
.38076 .75507 L
s
.38105 .74298 m
.39616 8.82474 L
s
.38092 .67297 m
.38105 .74298 L
s
.67604 .74639 m .67503 .74371 L .67287 .74439 L .692 .759 .904 r
F
.67718 .74623 m .67503 .74371 L .67604 .74639 L F
.67718 .74623 m .67732 .74339 L .67503 .74371 L F
.67904 .73909 m .67692 .73619 L .67678 .73902 L F
.67904 .73909 m .68031 .7363 L .67692 .73619 L F
.66954 .74665 m .66579 .74544 L .66437 .74756 L F
0 g
.66381 .74979 m
.66437 .74756 L
s
.37711 .64609 m .36516 .64941 L .37746 .64812 L .645 .732 .913 r
F
.37711 .64609 m .36446 .64535 L .36516 .64941 L F
.68643 .74034 m .68616 .73814 L .68348 .73693 L .862 .577 .504 r
F
0 g
.68616 .73814 m
.68818 .73979 L
s
.6745 .73933 m .67349 .73667 L .67027 .73769 L .692 .759 .904 r
F
.67678 .73902 m .67349 .73667 L .6745 .73933 L F
.67073 .74319 m .66771 .74136 L .66552 .74323 L F
.6726 .74219 m .66771 .74136 L .67073 .74319 L F
.67678 .73902 m .67692 .73619 L .67349 .73667 L F
.41403 .65228 m .42771 .64906 L .41506 .64832 L .645 .732 .913 r
F
.4019 .64956 m .41403 .65228 L .41506 .64832 L F
.40056 .65135 m .41403 .65228 L .4019 .64956 L F
.53372 .5267 m .53472 .53088 L .53521 .53547 L .772 .558 0 r
F
.53372 .5267 m .53323 .52211 L .53472 .53088 L F
.55216 .52112 m .53472 .53088 L .55315 .52696 L .683 .77 .917 r
F
.55216 .52112 m .53323 .52211 L .53472 .53088 L F
0 g
.53472 .53088 m
.53743 .535 L
s
.671 .7454 m .66579 .74544 L .66954 .74665 L .692 .759 .904 r
F
.57068 .51553 m .55283 .52234 L .57117 .51844 L .683 .77 .917 r
F
.57068 .51553 m .55185 .51652 L .55283 .52234 L F
.40215 .64577 m .41531 .64454 L .40267 .6438 L .645 .732 .913 r
F
.35359 .63489 m .35233 .63704 L .35207 .64083 L 0 0 .133 r
F
0 g
.35262 .63869 m
.353 .64088 L
s
.36612 .63386 m .35404 .63115 L .35252 .63706 L .645 .732 .913 r
F
.35359 .63489 m .35385 .63111 L .35233 .63704 L 0 0 .133 r
F
.36612 .63386 m .35252 .63706 L .3651 .63779 L .645 .732 .913 r
F
.68143 .74171 m .6806 .73846 L .67933 .74126 L .692 .759 .904 r
F
.68143 .74171 m .68375 .73913 L .6806 .73846 L F
.3782 .63656 m .3651 .63779 L .37769 .63853 L .645 .732 .913 r
F
.3782 .63656 m .36612 .63386 L .3651 .63779 L F
.55447 .41346 m .53806 .41543 L .53838 .42112 L .514 .328 .566 r
F
0 g
.52585 .43095 m
.53838 .42112 L
s
.55447 .41346 m .55415 .40777 L .53806 .41543 L .514 .328 .566 r
F
0 g
.52552 .42526 m
.53806 .41543 L
s
.39027 .63927 m .38731 .63164 L .38425 .63223 L .645 .732 .913 r
F
0 g
.38653 .63898 m
.38653 .63835 L
s
.39027 .63927 m .39058 .63156 L .38731 .63164 L .645 .732 .913 r
F
.39027 .63927 m .39383 .63202 L .39058 .63156 L F
0 g
.39311 .64008 m
.39311 .63872 L
s
.40286 .64001 m .41475 .63671 L .40251 .63799 L .645 .732 .913 r
F
.40286 .64001 m .41545 .64075 L .41475 .63671 L F
.68872 .74419 m .68643 .74034 L .6867 .74254 L .935 .633 .443 r
F
0 g
.68872 .74419 m
.68994 .74617 L
s
.60754 .51652 m .62717 .51255 L .60834 .51354 L .683 .77 .917 r
F
.41545 .64075 m .42699 .63543 L .41475 .63671 L .645 .732 .913 r
F
.41545 .64075 m .42803 .64149 L .42699 .63543 L F
.68348 .74472 m .68402 .74134 L .6817 .74392 L .692 .759 .904 r
F
.68348 .74472 m .6867 .74254 L .68402 .74134 L F
.66797 .74356 m .66552 .74323 L .66579 .74544 L .393 .241 .553 r
F
.66797 .74356 m .66771 .74136 L .66552 .74323 L F
0 g
.6641 .74536 m
.66552 .74323 L
s
.42796 .64528 m .42822 .6415 L .42717 .63541 L .928 .752 .271 r
F
0 g
.42725 .64524 m
.42779 .64315 L
s
.62676 .52769 m .6473 .52071 L .62837 .52171 L .683 .77 .917 r
F
.60864 .5257 m .62676 .52769 L .62837 .52171 L F
.60661 .52856 m .62676 .52769 L .60864 .5257 L F
.6726 .74219 m .67051 .73985 L .66771 .74136 L .692 .759 .904 r
F
.67476 .74151 m .67051 .73985 L .6726 .74219 L F
.67051 .73985 m .66744 .73915 L .66771 .74136 L .514 .326 .564 r
F
.67051 .73985 m .67024 .73765 L .66744 .73915 L F
0 g
.66525 .74103 m
.66744 .73915 L
s
.67933 .74126 m .67719 .73835 L .67705 .74119 L .692 .759 .904 r
F
.67933 .74126 m .6806 .73846 L .67719 .73835 L F
.68643 .74034 m .68348 .73693 L .68375 .73913 L .862 .577 .504 r
F
.6867 .74254 m .68643 .74034 L .68375 .73913 L F
0 g
.68643 .74034 m
.68845 .74199 L
s
.671 .7454 m .66797 .74356 L .66579 .74544 L .692 .759 .904 r
F
0 g
.66437 .74756 m
.66579 .74544 L
s
.67287 .74439 m .66797 .74356 L .671 .7454 L .692 .759 .904 r
F
.67476 .74151 m .67375 .73883 L .67051 .73985 L F
.67705 .74119 m .67375 .73883 L .67476 .74151 L F
.67705 .74119 m .67719 .73835 L .67375 .73883 L F
.68375 .73913 m .68348 .73693 L .68033 .73625 L .794 .527 .533 r
F
0 g
.68348 .73693 m
.68616 .73814 L
s
.6817 .74392 m .68087 .74066 L .67959 .74346 L .692 .759 .904 r
F
.6817 .74392 m .68402 .74134 L .68087 .74066 L F
.64679 .51613 m .64628 .51154 L .64483 .50277 L .765 .552 0 r
F
0 g
.64502 .51622 m
.64618 .51194 L
s
.62717 .51255 m .646 .51156 L .64456 .50283 L .683 .77 .917 r
F
.127 .923 .03 r
.42655 .65132 m
.42663 .65967 L
s
.42663 .65967 m
.49608 8.79957 L
s
0 0 0 r
2.5 Mabswid
.42655 .65132 Mdot
.127 .923 .03 r
.5 Mabswid
.42652 .66137 m
.42655 .65132 L
s
.67287 .74439 m .67078 .74205 L .66797 .74356 L .692 .759 .904 r
F
.67503 .74371 m .67078 .74205 L .67287 .74439 L F
.63007 .4064 m .62974 .40071 L .61167 .3964 L .795 .543 .558 r
F
0 g
.62974 .40071 m
.64507 .40781 L
s
.67375 .73883 m .67024 .73765 L .67051 .73985 L .599 .387 .564 r
F
.67375 .73883 m .67348 .73663 L .67024 .73765 L F
0 g
.66744 .73915 m
.67024 .73765 L
s
.4019 .64956 m .41506 .64832 L .40241 .64758 L .645 .732 .913 r
F
.67078 .74205 m .66771 .74136 L .66797 .74356 L .514 .326 .564 r
F
0 g
.66579 .74544 m
.66797 .74356 L
s
.67078 .74205 m .67051 .73985 L .66771 .74136 L .514 .326 .564 r
F
0 g
.66552 .74323 m
.66771 .74136 L
s
.35333 .63867 m .35207 .64083 L .35181 .64461 L 0 0 .133 r
F
0 g
.35236 .64247 m
.35274 .64466 L
s
.36573 .63761 m .35359 .63489 L .35207 .64083 L .645 .732 .913 r
F
.35333 .63867 m .35359 .63489 L .35207 .64083 L 0 0 .133 r
F
.36573 .63761 m .35207 .64083 L .36472 .64157 L .645 .732 .913 r
F
.67959 .74346 m .67745 .74055 L .67732 .74339 L .692 .759 .904 r
F
.67959 .74346 m .68087 .74066 L .67745 .74055 L F
.37788 .64033 m .36472 .64157 L .37737 .64231 L .645 .732 .913 r
F
.37788 .64033 m .36573 .63761 L .36472 .64157 L F
.6867 .74254 m .68375 .73913 L .68402 .74134 L .862 .577 .504 r
F
0 g
.6867 .74254 m
.68872 .74419 L
s
.39002 .64305 m .38704 .63538 L .38396 .63597 L .645 .732 .913 r
F
.39002 .64305 m .39032 .63531 L .38704 .63538 L F
.39002 .64305 m .39359 .63576 L .39032 .63531 L F
.39002 .64305 m .39661 .63672 L .39359 .63576 L F
.55266 .5257 m .53521 .53547 L .55365 .53155 L .683 .77 .917 r
F
.55266 .5257 m .53372 .5267 L .53521 .53547 L F
0 g
.53521 .53547 m
.54047 .54343 L
s
.57109 .52012 m .55315 .52696 L .57158 .52304 L .683 .77 .917 r
F
.57109 .52012 m .55216 .52112 L .55315 .52696 L F
.40267 .6438 m .41462 .64048 L .40231 .64177 L .645 .732 .913 r
F
.40267 .6438 m .41531 .64454 L .41462 .64048 L F
.6806 .73846 m .68033 .73625 L .67692 .73615 L .731 .481 .55 r
F
.68375 .73913 m .68033 .73625 L .6806 .73846 L .794 .527 .533 r
F
0 g
.68033 .73625 m
.68348 .73693 L
s
.41531 .64454 m .42692 .63919 L .41462 .64048 L .645 .732 .913 r
F
.41531 .64454 m .42796 .64528 L .42692 .63919 L F
.67503 .74371 m .67401 .74103 L .67078 .74205 L .692 .759 .904 r
F
.67732 .74339 m .67401 .74103 L .67503 .74371 L F
.42796 .64528 m .42717 .63541 L .42692 .63919 L .928 .752 .271 r
F
.42771 .64906 m .42796 .64528 L .42692 .63919 L F
0 g
.42699 .64902 m
.42754 .64693 L
s
.37953 .63478 m .36612 .63386 L .3782 .63656 L .645 .732 .913 r
F
.67732 .74339 m .67745 .74055 L .67401 .74103 L .692 .759 .904 r
F
.40251 .63799 m .41239 .63284 L .40133 .63606 L .645 .732 .913 r
F
.40251 .63799 m .41475 .63671 L .41239 .63284 L F
.68402 .74134 m .68375 .73913 L .6806 .73846 L .794 .527 .533 r
F
0 g
.68375 .73913 m
.68643 .74034 L
s
.62717 .51255 m .64456 .50283 L .6262 .50673 L .683 .77 .917 r
F
.60834 .51354 m .62717 .51255 L .6262 .50673 L F
.60814 .52112 m .62787 .51713 L .60894 .51812 L F
.67719 .73835 m .67348 .73663 L .67375 .73883 L .668 .436 .559 r
F
.67719 .73835 m .67692 .73615 L .67348 .73663 L F
0 g
.67024 .73765 m
.67348 .73663 L
s
.6806 .73846 m .67692 .73615 L .67719 .73835 L .731 .481 .55 r
F
0 g
.67348 .73663 m
.67692 .73615 L
s
.67692 .73615 m
.68033 .73625 L
s
.3931 .64362 m
.3931 .64229 L
s
.38637 .70099 m
.38637 .70055 L
s
.38638 .69967 m
.38638 .69841 L
s
.38652 .64305 m
.38652 .64191 L
s
.67401 .74103 m .67051 .73985 L .67078 .74205 L .599 .387 .564 r
F
.67401 .74103 m .67375 .73883 L .67051 .73985 L F
0 g
.66771 .74136 m
.67051 .73985 L
s
.66797 .74356 m
.67078 .74205 L
s
.68087 .74066 m .6806 .73846 L .67719 .73835 L .731 .481 .55 r
F
.68402 .74134 m .6806 .73846 L .68087 .74066 L .794 .527 .533 r
F
0 g
.6806 .73846 m
.68375 .73913 L
s
.68402 .74134 m
.6867 .74254 L
s
.60834 .51354 m .6262 .50673 L .60786 .51063 L .683 .77 .917 r
F
.64679 .51613 m .64483 .50277 L .64534 .50735 L .765 .552 0 r
F
.62787 .51713 m .64679 .51613 L .64534 .50735 L .683 .77 .917 r
F
.6473 .52071 m .64679 .51613 L .64534 .50735 L .765 .552 0 r
F
0 g
.64553 .52081 m
.64668 .51653 L
s
.67745 .74055 m .67375 .73883 L .67401 .74103 L .668 .436 .559 r
F
.67745 .74055 m .67719 .73835 L .67375 .73883 L F
0 g
.67051 .73985 m
.67375 .73883 L
s
.36547 .64139 m .35181 .64461 L .36446 .64535 L .645 .732 .913 r
F
.36547 .64139 m .35333 .63867 L .35181 .64461 L F
0 g
.35181 .64461 m
.35287 .65069 L
s
.68087 .74066 m .67719 .73835 L .67745 .74055 L .731 .481 .55 r
F
0 g
.67375 .73883 m
.67719 .73835 L
s
.67719 .73835 m
.6806 .73846 L
s
.68087 .74066 m
.68402 .74134 L
s
.37762 .64411 m .36446 .64535 L .37711 .64609 L .645 .732 .913 r
F
.37762 .64411 m .36547 .64139 L .36446 .64535 L F
.39083 .64465 m .39635 .6405 L .39333 .63954 L F
.38976 .64683 m .39187 .6448 L .39083 .64465 L F
.39187 .6448 m .39635 .6405 L .39083 .64465 L F
.39094 .64466 m .38978 .69702 L .39082 .69706 L .734 .477 .539 r
F
.39013 .69703 m .3914 .69677 L .39035 .69655 L .692 .759 .903 r
F
.38911 .69935 m .39113 .69708 L .39013 .69703 L F
.39113 .69708 m .3914 .69677 L .39013 .69703 L F
.38978 .69702 m .38972 .69978 L .39082 .69706 L .734 .477 .539 r
F
.38945 .69915 m .39061 .69874 L .38947 .6987 L .692 .759 .903 r
F
.38911 .69935 m .389 .70218 L .39014 .70202 L F
.38936 .70155 m .39041 .69919 L .38945 .69915 L F
.39082 .69706 m .38996 .69917 L .39081 .69921 L .734 .477 .539 r
F
.39041 .69919 m .39061 .69874 L .38945 .69915 L .692 .759 .903 r
F
.38936 .70155 m .39167 .69896 L .39061 .69874 L F
.39081 .69921 m .38972 .69978 L .39081 .69991 L .734 .477 .539 r
F
.38996 .69917 m .38972 .69978 L .39081 .69921 L F
.39095 .64062 m .39087 .64465 L .39094 .64466 L F
.39087 .64465 m .38972 .69978 L .39094 .64466 L F
.39095 .64062 m .38986 .64049 L .38972 .69978 L F
.38976 .64683 m .38678 .63916 L .3837 .63976 L .645 .732 .913 r
F
0 g
.38638 .69734 m
.38651 .64548 L
s
.38976 .64683 m .39006 .63909 L .38678 .63916 L .645 .732 .913 r
F
.38976 .64683 m .39333 .63954 L .39006 .63909 L F
.40241 .64758 m .41436 .64426 L .40206 .64555 L F
.40241 .64758 m .41506 .64832 L .41436 .64426 L F
.38828 .69722 m .38921 .69651 L .38807 .69667 L .692 .759 .903 r
F
.38911 .69935 m .38919 .69709 L .38828 .69722 L F
.38986 .64049 m .38867 .69717 L .38972 .69702 L .66 .416 .54 r
F
.38919 .69709 m .38921 .69651 L .38828 .69722 L .692 .759 .903 r
F
.38911 .69935 m .39035 .69655 L .38921 .69651 L F
.38867 .69717 m .38861 .69987 L .38972 .69702 L .66 .416 .54 r
F
.38851 .69934 m .38947 .6987 L .38832 .69886 L .692 .759 .903 r
F
.38936 .70155 m .38945 .6992 L .38851 .69934 L F
.38972 .69702 m .38884 .69929 L .38972 .69916 L .66 .416 .54 r
F
.38945 .6992 m .38947 .6987 L .38851 .69934 L .692 .759 .903 r
F
.38972 .69916 m .38861 .69987 L .38972 .69978 L .66 .416 .54 r
F
.38884 .69929 m .38861 .69987 L .38972 .69916 L F
.41506 .64832 m .42666 .64297 L .41436 .64426 L .645 .732 .913 r
F
.41506 .64832 m .42771 .64906 L .42666 .64297 L F
.42771 .64906 m .42692 .63919 L .42666 .64297 L .928 .752 .271 r
F
0 g
.42617 .655 m
.42771 .64906 L
s
.37921 .63854 m .36573 .63761 L .37788 .64033 L .645 .732 .913 r
F
.37953 .63478 m .36878 .63028 L .36612 .63386 L F
.38159 .6333 m .36878 .63028 L .37953 .63478 L F
.40231 .64177 m .41224 .63659 L .40113 .63982 L F
.40231 .64177 m .41462 .64048 L .41224 .63659 L F
.40133 .63606 m .40851 .62942 L .39939 .63434 L F
.40133 .63606 m .41239 .63284 L .40851 .62942 L F
.36878 .63028 m .35404 .63115 L .36612 .63386 L F
0 g
.67078 .74205 m
.67401 .74103 L
s
.57159 .52471 m .55365 .53155 L .57208 .52763 L .683 .77 .917 r
F
.57159 .52471 m .55266 .5257 L .55365 .53155 L F
.58951 .51454 m .58521 .5038 L .58061 .50518 L F
.41475 .63671 m .42345 .62963 L .41239 .63284 L .645 .732 .913 r
F
.41475 .63671 m .42699 .63543 L .42345 .62963 L F
0 g
.67745 .74055 m
.68087 .74066 L
s
.62787 .51713 m .64534 .50735 L .62689 .51128 L .683 .77 .917 r
F
.60894 .51812 m .62787 .51713 L .62689 .51128 L F
.57269 .4028 m .55382 .40207 L .55415 .40777 L .602 .395 .573 r
F
.127 .923 .03 r
.54757 .4698 m
.55401 .40317 L
s
.57269 .4028 m .57237 .3971 L .55382 .40207 L .602 .395 .573 r
F
.127 .923 .03 r
.56121 .40278 m
.56142 .39177 L
s
0 g
.53773 .40974 m
.55382 .40207 L
s
.127 .923 .03 r
.55454 .39764 m
.55508 .39211 L
s
.60864 .5257 m .62837 .52171 L .60945 .52271 L .683 .77 .917 r
F
.63007 .4064 m .61167 .3964 L .612 .40209 L .795 .543 .558 r
F
.6304 .4121 m .63007 .4064 L .612 .40209 L F
0 g
.63007 .4064 m
.6454 .4135 L
s
.67401 .74103 m
.67745 .74055 L
s
.57147 .51255 m .55185 .51652 L .57068 .51553 L .683 .77 .917 r
F
.60894 .51812 m .62689 .51128 L .60845 .5152 L F
.6473 .52071 m .64534 .50735 L .64585 .51194 L .765 .552 0 r
F
.62837 .52171 m .6473 .52071 L .64585 .51194 L .683 .77 .917 r
F
0 g
.64488 .52969 m
.6473 .52071 L
s
.38159 .6333 m .3729 .62732 L .36878 .63028 L .645 .732 .913 r
F
.38425 .63223 m .3729 .62732 L .38159 .6333 L F
.39939 .63434 m .4034 .62666 L .39683 .63297 L F
.39939 .63434 m .40851 .62942 L .4034 .62666 L F
.37895 .64232 m .36547 .64139 L .37762 .64411 L F
.37921 .63854 m .36841 .63402 L .36573 .63761 L F
.38129 .63705 m .36841 .63402 L .37921 .63854 L F
.40206 .64555 m .41198 .64037 L .40087 .6436 L F
.40206 .64555 m .41436 .64426 L .41198 .64037 L F
.40113 .63982 m .40835 .63315 L .39918 .6381 L F
.40113 .63982 m .41224 .63659 L .40835 .63315 L F
.36841 .63402 m .35359 .63489 L .36573 .63761 L F
.36878 .63028 m .35802 .62579 L .35404 .63115 L F
.3576 .6295 m .35385 .63111 L .35359 .63489 L .072 0 .399 r
F
.3576 .6295 m .35786 .62572 L .35385 .63111 L F
0 g
.35233 .63704 m
.35385 .63111 L
s
.55343 .51057 m .53301 .51751 L .55185 .51652 L .683 .77 .917 r
F
.57147 .51255 m .55343 .51057 L .55185 .51652 L F
.41462 .64048 m .42336 .63336 L .41224 .63659 L .645 .732 .913 r
F
.41462 .64048 m .42692 .63919 L .42336 .63336 L F
.59001 .51912 m .60382 .51033 L .6 .50872 L .683 .77 .917 r
F
0 g
.59386 .51811 m
.59386 .52023 L
s
.60786 .51063 m .62274 .50144 L .60612 .50799 L .683 .77 .917 r
F
.60786 .51063 m .6262 .50673 L .62274 .50144 L F
.42692 .63919 m .42717 .63541 L .42361 .62958 L .99 .751 .477 r
F
0 g
.42717 .63541 m
.42822 .6415 L
s
.62837 .52171 m .64585 .51194 L .6274 .51586 L .683 .77 .917 r
F
.60945 .52271 m .62837 .52171 L .6274 .51586 L F
.38425 .63223 m .37821 .62518 L .3729 .62732 L .645 .732 .913 r
F
.38731 .63164 m .37821 .62518 L .38425 .63223 L F
.39683 .63297 m .39738 .62476 L .39383 .63202 L F
.39683 .63297 m .4034 .62666 L .39738 .62476 L F
.55343 .51057 m .53538 .50858 L .53301 .51751 L .683 .77 .917 r
F
.53561 .51314 m .53273 .51753 L .53323 .52211 L 0 0 .388 r
F
0 g
.5334 .52147 m
.5335 .5221 L
s
.53561 .51314 m .53511 .50855 L .53273 .51753 L 0 0 .388 r
F
.57302 .40849 m .55415 .40777 L .55447 .41346 L .602 .395 .573 r
F
0 g
.53838 .42112 m
.55447 .41346 L
s
.57302 .40849 m .57269 .4028 L .55415 .40777 L .602 .395 .573 r
F
0 g
.53806 .41543 m
.55415 .40777 L
s
.127 .923 .03 r
.55995 .46873 m
.56121 .40278 L
s
.55401 .40317 m
.55454 .39764 L
s
.612 .40209 m .61167 .3964 L .5921 .39517 L .733 .496 .568 r
F
0 g
.61167 .3964 m
.62974 .40071 L
s
.6304 .4121 m .612 .40209 L .61233 .40779 L .795 .543 .558 r
F
0 g
.6304 .4121 m
.64573 .41919 L
s
.57188 .51713 m .55216 .52112 L .57109 .52012 L .683 .77 .917 r
F
.60945 .52271 m .6274 .51586 L .60896 .51979 L F
.38129 .63705 m .37255 .63105 L .36841 .63402 L .645 .732 .913 r
F
.38396 .63597 m .37255 .63105 L .38129 .63705 L F
.39918 .6381 m .4032 .63038 L .39661 .63672 L F
.39918 .6381 m .40835 .63315 L .4032 .63038 L F
.38731 .63164 m .38435 .62399 L .37821 .62518 L F
.39058 .63156 m .38435 .62399 L .38731 .63164 L F
.37895 .64232 m .36815 .6378 L .36547 .64139 L F
.38103 .64083 m .36815 .6378 L .37895 .64232 L F
.39383 .63202 m .39089 .62385 L .39058 .63156 L F
.39383 .63202 m .39738 .62476 L .39089 .62385 L F
.40087 .6436 m .40809 .63693 L .39892 .64188 L F
.40087 .6436 m .41198 .64037 L .40809 .63693 L F
.36815 .6378 m .35333 .63867 L .36547 .64139 L F
.3729 .62732 m .35802 .62579 L .36878 .63028 L F
.35734 .63328 m .35359 .63489 L .35333 .63867 L .072 0 .399 r
F
.36841 .63402 m .3576 .6295 L .35359 .63489 L .645 .732 .913 r
F
.35734 .63328 m .3576 .6295 L .35359 .63489 L .072 0 .399 r
F
0 g
.35207 .64083 m
.35359 .63489 L
s
.41436 .64426 m .4231 .63714 L .41198 .64037 L .645 .732 .913 r
F
.41436 .64426 m .42666 .64297 L .4231 .63714 L F
.39058 .63156 m .39089 .62385 L .38435 .62399 L F
.41239 .63284 m .41764 .62448 L .40851 .62942 L F
.41239 .63284 m .42345 .62963 L .41764 .62448 L F
.5735 .50971 m .55343 .51057 L .57147 .51255 L .683 .77 .917 r
F
.42692 .63919 m .42361 .62958 L .42336 .63336 L .99 .751 .477 r
F
.42666 .64297 m .42692 .63919 L .42336 .63336 L F
0 g
.42692 .63919 m
.42796 .64528 L
s
.55375 .51513 m .53323 .52211 L .55216 .52112 L .683 .77 .917 r
F
.57188 .51713 m .55375 .51513 L .55216 .52112 L F
.59052 .52371 m .57755 .51633 L .57442 .51886 L F
.59052 .52371 m .6005 .51331 L .596 .51241 L F
.60845 .5152 m .62341 .50596 L .60671 .51254 L F
.60845 .5152 m .62689 .51128 L .62341 .50596 L F
.6262 .50673 m .63936 .49489 L .62274 .50144 L F
.6262 .50673 m .64456 .50283 L .63936 .49489 L F
.59243 .40086 m .57237 .3971 L .57269 .4028 L .671 .448 .573 r
F
.59243 .40086 m .5921 .39517 L .57237 .3971 L F
0 g
.55382 .40207 m
.57237 .3971 L
s
.38396 .63597 m .37789 .62889 L .37255 .63105 L .645 .732 .913 r
F
.38704 .63538 m .37789 .62889 L .38396 .63597 L F
.39661 .63672 m .39716 .62847 L .39359 .63576 L F
.39661 .63672 m .4032 .63038 L .39716 .62847 L F
.5361 .51772 m .53323 .52211 L .53372 .5267 L 0 0 .388 r
F
0 g
.5339 .52605 m
.534 .52669 L
s
.55375 .51513 m .53561 .51314 L .53323 .52211 L .683 .77 .917 r
F
.5361 .51772 m .53561 .51314 L .53323 .52211 L 0 0 .388 r
F
.60612 .50799 m .617 .49704 L .60325 .50579 L .683 .77 .917 r
F
.60612 .50799 m .62274 .50144 L .617 .49704 L F
.38103 .64083 m .37229 .63483 L .36815 .6378 L .645 .732 .913 r
F
.3837 .63976 m .37229 .63483 L .38103 .64083 L F
.57238 .52171 m .55266 .5257 L .57159 .52471 L .683 .77 .917 r
F
.39892 .64188 m .40295 .63416 L .39635 .6405 L .645 .732 .913 r
F
.39892 .64188 m .40809 .63693 L .40295 .63416 L F
.612 .40209 m .5921 .39517 L .59243 .40086 L .733 .496 .568 r
F
0 g
.57237 .3971 m
.5921 .39517 L
s
.5921 .39517 m
.61167 .3964 L
s
.38704 .63538 m .38406 .6277 L .37789 .62889 L .645 .732 .913 r
F
.39032 .63531 m .38406 .6277 L .38704 .63538 L F
.39359 .63576 m .39063 .62756 L .39032 .63531 L F
.39359 .63576 m .39716 .62847 L .39063 .62756 L F
.37255 .63105 m .3576 .6295 L .36841 .63402 L F
.36815 .6378 m .35734 .63328 L .35333 .63867 L F
0 g
.35181 .64461 m
.35333 .63867 L
s
.61233 .40779 m .612 .40209 L .59243 .40086 L .733 .496 .568 r
F
0 g
.612 .40209 m
.63007 .4064 L
s
.39032 .63531 m .39063 .62756 L .38406 .6277 L .645 .732 .913 r
F
.41224 .63659 m .41752 .62819 L .40835 .63315 L F
.41224 .63659 m .42336 .63336 L .41752 .62819 L F
.42666 .64297 m .42336 .63336 L .4231 .63714 L .99 .751 .477 r
F
0 g
.42666 .64297 m
.42771 .64906 L
s
.127 .923 .03 r
.3846 1.13604 m
.49525 8.79912 L
s
0 0 0 r
2.5 Mabswid
.37743 .63968 Mdot
.127 .923 .03 r
.5 Mabswid
.37797 .8762 m
.39609 8.82405 L
s
.57392 .51427 m .55375 .51513 L .57188 .51713 L .683 .77 .917 r
F
.55425 .51972 m .53372 .5267 L .55266 .5257 L F
.57238 .52171 m .55425 .51972 L .55266 .5257 L F
.60896 .51979 m .62391 .51055 L .60721 .51713 L F
.60896 .51979 m .6274 .51586 L .62391 .51055 L F
.3837 .63976 m .37763 .63267 L .37229 .63483 L .645 .732 .913 r
F
.38678 .63916 m .37763 .63267 L .3837 .63976 L F
.62689 .51128 m .64011 .49938 L .62341 .50596 L .683 .77 .917 r
F
.62689 .51128 m .64534 .50735 L .64011 .49938 L F
.39635 .6405 m .3969 .63225 L .39333 .63954 L .645 .732 .913 r
F
.39635 .6405 m .40295 .63416 L .3969 .63225 L F
.64534 .50735 m .64483 .50277 L .63961 .49479 L .98 .687 .329 r
F
0 g
.64483 .50277 m
.64628 .51154 L
s
.59215 .58977 m .59078 .59487 L .59405 .59479 L .645 .732 .913 r
F
.59042 .53431 m .59204 .58978 L .59053 .5899 L .641 .4 .539 r
F
.59115 .58713 m .59102 .58986 L .59215 .58977 L .645 .732 .913 r
F
.59102 .58986 m .59078 .59487 L .59215 .58977 L F
.59078 .59487 m .59041 .60259 L .59696 .60245 L F
.59183 .59337 m .59053 .59869 L .59382 .59862 L F
.59053 .5899 m .59214 .59326 L .59055 .59347 L .641 .4 .539 r
F
.5909 .59092 m .59078 .59345 L .59183 .59337 L .645 .732 .913 r
F
.59078 .59487 m .59696 .60245 L .59405 .59479 L F
.59078 .59345 m .59053 .59869 L .59183 .59337 L F
.59204 .58978 m .59214 .59326 L .59053 .5899 L .641 .4 .539 r
F
.127 .923 .03 r
.5927 .63798 m
.59353 .60253 L
s
.59374 .59396 m
.59427 .57142 L
s
.59468 .58958 m .59713 .5942 L .5998 .59313 L .645 .732 .913 r
F
.59213 .58978 m .59317 .59282 L .59214 .59326 L .516 .301 .527 r
F
.59202 .5341 m .59311 .58943 L .59213 .58978 L F
.59115 .58713 m .59405 .59479 L .59713 .5942 L .645 .732 .913 r
F
.59311 .58943 m .59317 .59282 L .59213 .58978 L .516 .301 .527 r
F
.59388 .58892 m .59433 .59156 L .59389 .59225 L .076 0 .415 r
F
.59377 .53308 m .5943 .58834 L .59388 .58892 L F
.59401 .58912 m .59336 .58964 L .59468 .58958 L .645 .732 .913 r
F
.59336 .58964 m .59333 .58968 L .59468 .58958 L F
.5943 .58834 m .59433 .59156 L .59388 .58892 L .076 0 .415 r
F
.59336 .58964 m .59331 .58968 L .59333 .58968 L .645 .732 .913 r
F
.59115 .58713 m .5931 .58944 L .59401 .58912 L F
.59317 .58941 m .59389 .59225 L .59317 .59282 L .356 .178 .497 r
F
.59306 .53366 m .59384 .58895 L .59317 .58941 L F
.59317 .58941 m .59331 .58968 L .59401 .58912 L .645 .732 .913 r
F
.59311 .58945 m .59331 .58968 L .59317 .58941 L F
.59384 .58895 m .59389 .59225 L .59317 .58941 L .356 .178 .497 r
F
.5931 .58944 m .59311 .58945 L .59317 .58941 L .645 .732 .913 r
F
.59331 .58968 m .59713 .5942 L .59468 .58958 L F
.59042 .53431 m .59202 .5341 L .59213 .58978 L .641 .4 .539 r
F
.59204 .58978 m .59213 .58978 L .59214 .59326 L F
.59042 .53431 m .59213 .58978 L .59204 .58978 L F
.58984 .58977 m .58453 .59346 L .58753 .59441 L .645 .732 .913 r
F
.59101 .58999 m .58753 .59441 L .59078 .59487 L F
.58984 .58977 m .58753 .59441 L .59101 .58999 L F
.58453 .59346 m .58392 .60168 L .58753 .59441 L F
.58862 .5931 m .58168 .59589 L .58425 .59728 L F
.58895 .5896 m .59054 .59347 L .58895 .59317 L .751 .49 .538 r
F
.58785 .53356 m .58884 .53404 L .58895 .5896 L .846 .571 .522 r
F
.58889 .58957 m .58895 .5896 L .58895 .59321 L F
.58785 .53356 m .58895 .5896 L .58889 .58957 L F
.5887 .58948 m .58197 .59208 L .58453 .59346 L .645 .732 .913 r
F
.58884 .53404 m .59043 .58988 L .58895 .5896 L .751 .49 .538 r
F
.59115 .58713 m .58769 .58899 L .5887 .58948 L .645 .732 .913 r
F
.58769 .58899 m .58197 .59208 L .5887 .58948 L F
.5909 .59092 m .58731 .59285 L .58862 .5931 L F
.58731 .59285 m .58168 .59589 L .58862 .5931 L F
.58753 .59441 m .58392 .60168 L .59041 .60259 L F
.58735 .59807 m .58425 .59728 L .58727 .59823 L F
.5909 .59092 m .58712 .59453 L .58735 .59807 L F
.58712 .59453 m .58425 .59728 L .58735 .59807 L F
.58687 .59061 m .58692 .59143 L .58692 .59146 L .777 .62 .057 r
F
.58001 .61284 m .59004 .61043 L .5898 .61421 L .733 .497 .57 r
F
.58001 .61284 m .58025 .60906 L .59004 .61043 L F
.58392 .60168 m .59005 .61032 L .59041 .60259 L .645 .732 .913 r
F
.58392 .60168 m .58031 .60895 L .59005 .61032 L F
.57976 .61663 m .5898 .61421 L .58955 .618 L .733 .497 .57 r
F
.57976 .61663 m .58001 .61284 L .5898 .61421 L F
.58364 .60554 m .5898 .61421 L .59017 .60645 L .645 .732 .913 r
F
.58364 .60554 m .58001 .61284 L .5898 .61421 L F
.58339 .60932 m .58955 .618 L .58992 .61024 L F
.58339 .60932 m .57976 .61663 L .58955 .618 L F
.58727 .59823 m .58364 .60554 L .59017 .60645 L F
.58702 .60201 m .58339 .60932 L .58992 .61024 L F
.58734 .60138 m .584 .60106 L .58702 .60201 L F
.58753 .59441 m .59041 .60259 L .59078 .59487 L F
.5909 .59092 m .58727 .59823 L .59053 .59869 L F
.58796 .59273 m .58895 .59321 L .58896 .59674 L .846 .571 .522 r
F
.58867 .5966 m .58712 .59808 L .58951 .597 L .645 .732 .913 r
F
.58913 .64969 m .58792 .64983 L .58897 .65005 L .692 .759 .903 r
F
.58897 .65005 m .58998 .65293 L .59011 .65009 L F
.59039 .65193 m .58923 .65227 L .59037 .65231 L F
.58914 .64967 m .58906 .64967 L .58913 .64969 L F
.59011 .65009 m .58998 .65293 L .59227 .65261 L F
.59057 .6498 m .59065 .65279 L .58906 .64967 L .751 .49 .538 r
F
.5905 .64945 m .58942 .65185 L .59039 .65193 L .692 .759 .903 r
F
.58942 .65185 m .58923 .65227 L .59039 .65193 L F
.58897 .65005 m .58771 .65286 L .58998 .65293 L F
.58771 .65286 m .58985 .65577 L .58998 .65293 L F
.58923 .65227 m .59025 .65516 L .59037 .65231 L F
.58906 .65181 m .59065 .65279 L .58907 .65252 L .751 .49 .538 r
F
.58906 .64967 m .59021 .65192 L .58906 .65181 L F
.59021 .65192 m .59065 .65279 L .58906 .65181 L F
.58702 .60201 m .58992 .61024 L .59029 .60247 L .645 .732 .913 r
F
.58425 .59728 m .58364 .60554 L .58727 .59823 L F
.5873 .59213 m .58796 .59273 L .58797 .59626 L .93 .648 .485 r
F
.58734 .59572 m .58797 .59626 L .58807 .65205 L F
.5873 .59213 m .58797 .59626 L .58734 .59572 L F
.58692 .59143 m .5873 .59213 L .5873 .59569 L .988 .719 .381 r
F
.58695 .59507 m .5873 .59569 L .58741 .65145 L F
.58692 .59143 m .5873 .59569 L .58695 .59507 L F
.58813 .59712 m .58144 .59967 L .584 .60106 L .645 .732 .913 r
F
.58852 .59674 m .58803 .59694 L .58813 .59712 L F
.58803 .59694 m .58144 .59967 L .58813 .59712 L F
.5886 .59667 m .58849 .59671 L .58852 .59674 L F
.58695 .64799 m .58583 .64748 L .58595 .64821 L .692 .759 .903 r
F
.58801 .59691 m .58144 .59967 L .58803 .59694 L .645 .732 .913 r
F
.58769 .64898 m .58636 .64887 L .58703 .64942 L .692 .759 .903 r
F
.58743 .59644 m .58144 .59967 L .58849 .59671 L .645 .732 .913 r
F
.58832 .64938 m .58792 .64983 L .58913 .64969 L .692 .759 .903 r
F
.58727 .59823 m .59017 .60645 L .59053 .59869 L .645 .732 .913 r
F
.58951 .597 m .58712 .59808 L .58734 .60138 L F
.58792 .64983 m .58771 .65286 L .58897 .65005 L .692 .759 .903 r
F
.58832 .64938 m .58703 .64942 L .58792 .64983 L F
.58797 .59626 m .58901 .64965 L .58807 .64928 L .846 .571 .522 r
F
.59023 .64725 m .58754 .64907 L .58832 .64938 L .692 .759 .903 r
F
.58754 .64907 m .58703 .64942 L .58832 .64938 L F
.58777 .65131 m .58728 .65164 L .58856 .65162 L F
.58792 .64983 m .58561 .65241 L .58771 .65286 L F
.5874 .6509 m .58807 .65205 L .58741 .65145 L .93 .648 .485 r
F
.5874 .64875 m .58792 .65131 L .5874 .6509 L F
.58846 .65173 m .58728 .65164 L .58818 .65204 L .692 .759 .903 r
F
.58792 .65131 m .58807 .65205 L .5874 .6509 L .93 .648 .485 r
F
.58856 .65162 m .58832 .65162 L .58846 .65173 L .692 .759 .903 r
F
.58832 .65162 m .58728 .65164 L .58846 .65173 L F
.58901 .64965 m .58905 .65181 L .58807 .64928 L .846 .571 .522 r
F
.5905 .64945 m .58818 .65204 L .58923 .65227 L .692 .759 .903 r
F
.58905 .65181 m .58907 .65252 L .58882 .65172 L .846 .571 .522 r
F
.58905 .65181 m .58882 .65172 L .58807 .64928 L F
.58777 .65131 m .5866 .65109 L .58728 .65164 L .692 .759 .903 r
F
.58807 .64928 m .58882 .65172 L .58807 .65143 L .846 .571 .522 r
F
.5905 .64945 m .58689 .65097 L .58777 .65131 L .692 .759 .903 r
F
.58689 .65097 m .5866 .65109 L .58777 .65131 L F
.58901 .64965 m .58906 .64967 L .58907 .65252 L .846 .571 .522 r
F
.5905 .64945 m .58777 .65131 L .58856 .65162 L .692 .759 .903 r
F
.58807 .65143 m .58907 .65252 L .58807 .65205 L .846 .571 .522 r
F
.58882 .65172 m .58907 .65252 L .58807 .65143 L F
.58796 .59273 m .58803 .59629 L .58797 .59626 L F
.58803 .59629 m .58907 .65252 L .58797 .59626 L F
.58453 .59346 m .57791 .59978 L .58392 .60168 L .645 .732 .913 r
F
.58168 .59589 m .5776 .60363 L .58425 .59728 L F
.58796 .59273 m .58896 .59674 L .58803 .59629 L .846 .571 .522 r
F
.57281 .59702 m .5713 .6061 L .57791 .59978 L .645 .732 .913 r
F
.58168 .59589 m .57247 .60085 L .5776 .60363 L F
.58577 .59612 m .57832 .59599 L .5795 .59794 L F
.58687 .5907 m .58688 .59432 L .58687 .59427 L .777 .62 .057 r
F
.58197 .59208 m .57791 .59978 L .58453 .59346 L .645 .732 .913 r
F
.58702 .59301 m .57974 .59416 L .58168 .59589 L F
.59043 .58988 m .59053 .5899 L .59054 .59347 L .751 .49 .538 r
F
.58796 .59269 m .58895 .59321 L .58796 .59273 L .846 .571 .522 r
F
.58681 .53226 m .58719 .53296 L .58729 .58855 L .988 .719 .381 r
F
.58727 .58851 m .58729 .58855 L .5873 .59213 L F
.58681 .53226 m .58729 .58855 L .58727 .58851 L F
.58758 .58906 m .58005 .59036 L .58197 .59208 L .645 .732 .913 r
F
.58769 .58899 m .58756 .58902 L .58758 .58906 L F
.58756 .58902 m .58005 .59036 L .58758 .58906 L F
.58785 .53356 m .58889 .58957 L .58795 .58912 L .846 .571 .522 r
F
.59115 .58713 m .58658 .58846 L .58769 .58899 L .645 .732 .913 r
F
.58691 .58789 m .5873 .59213 L .58692 .59143 L .988 .719 .381 r
F
.58681 .53226 m .58727 .58851 L .58691 .58789 L F
.58658 .58846 m .58756 .58902 L .58749 .5889 L .645 .732 .913 r
F
.58727 .58851 m .5873 .59213 L .58691 .58789 L .988 .719 .381 r
F
.58658 .58846 m .58005 .59036 L .58756 .58902 L .645 .732 .913 r
F
.58749 .5889 m .58756 .58902 L .58769 .58899 L F
.58795 .58912 m .58895 .59317 L .58796 .59269 L .846 .571 .522 r
F
.58863 .58954 m .58854 .58963 L .58984 .58977 L .645 .732 .913 r
F
.58854 .58963 m .58453 .59346 L .58921 .5902 L F
.58854 .58963 m .58921 .5902 L .58984 .58977 L F
.58645 .59138 m .57823 .59017 L .57857 .59221 L F
.58729 .58855 m .58795 .59268 L .5873 .59212 L .93 .648 .485 r
F
.58687 .59061 m .58692 .59146 L .58687 .5907 L .777 .62 .057 r
F
.59043 .58988 m .59054 .59347 L .58895 .5896 L .751 .49 .538 r
F
.5909 .59092 m .58554 .5906 L .58645 .59138 L .645 .732 .913 r
F
.58554 .5906 m .57823 .59017 L .58645 .59138 L F
.5909 .59092 m .58697 .59221 L .58778 .5926 L F
.5873 .59212 m .58796 .59273 L .5873 .59213 L .93 .648 .485 r
F
.58795 .59268 m .58796 .59273 L .5873 .59212 L F
.58719 .53296 m .58791 .58908 L .58729 .58855 L F
.58791 .58908 m .58796 .59273 L .58729 .58855 L F
.58889 .58957 m .58895 .59317 L .58795 .58912 L .846 .571 .522 r
F
.58895 .59317 m .58895 .59321 L .58796 .59269 L F
.5909 .59092 m .58696 .59206 L .58697 .59221 L .645 .732 .913 r
F
.58778 .5926 m .58697 .59221 L .58702 .59301 L F
.58696 .59206 m .57974 .59416 L .58702 .59301 L F
.58687 .5907 m .58692 .59146 L .58692 .59503 L .777 .62 .057 r
F
.58687 .5907 m .58692 .59503 L .58688 .59432 L F
.58197 .59208 m .57281 .59702 L .57791 .59978 L .645 .732 .913 r
F
.5859 .59237 m .57857 .59221 L .57974 .59416 L F
.5909 .59092 m .58647 .59138 L .5859 .59237 L F
.58647 .59138 m .57857 .59221 L .5859 .59237 L F
.58741 .58957 m .58687 .59061 L .58687 .5907 L 0 0 .377 r
F
.58738 .58983 m .58687 .5907 L .58687 .59427 L F
.58741 .58957 m .58687 .5907 L .58738 .58983 L F
.58687 .59427 m .58703 .65075 L .58698 .64993 L .777 .62 .057 r
F
.58688 .59432 m .58703 .65075 L .58687 .59427 L F
.58786 .59621 m .58701 .59638 L .58703 .59666 L .645 .732 .913 r
F
.58696 .59578 m .5795 .59794 L .58786 .59621 L F
.5873 .59213 m .58734 .59572 L .5873 .59569 L .93 .648 .485 r
F
.58692 .59503 m .58738 .64872 L .58702 .64811 L .988 .719 .381 r
F
.58695 .59507 m .58741 .65145 L .58692 .59503 L F
.58688 .59432 m .58692 .59503 L .58703 .65075 L .777 .62 .057 r
F
.57974 .59416 m .57247 .60085 L .58168 .59589 L .645 .732 .913 r
F
.58398 .5954 m .57798 .59396 L .57832 .59599 L F
.58714 .64854 m .58636 .64887 L .58769 .64898 L .692 .759 .903 r
F
.58895 .59321 m .59054 .59347 L .59054 .59704 L .751 .49 .538 r
F
.58005 .59036 m .57281 .59702 L .58197 .59208 L .645 .732 .913 r
F
.58564 .59441 m .57851 .59197 L .57798 .59396 L F
.59065 .5947 m .58665 .5938 L .58564 .59441 L F
.58665 .5938 m .57851 .59197 L .58564 .59441 L F
.59023 .64725 m .58714 .64854 L .58769 .64898 L .692 .759 .903 r
F
.58839 .59663 m .58849 .59671 L .5886 .59667 L .645 .732 .913 r
F
.5873 .59569 m .58803 .64925 L .5874 .64875 L .93 .648 .485 r
F
.59023 .64725 m .58663 .64744 L .58695 .64799 L .692 .759 .903 r
F
.58692 .59143 m .58695 .59507 L .58692 .59503 L .988 .719 .381 r
F
.58519 .59347 m .57986 .59017 L .57851 .59197 L .645 .732 .913 r
F
.59065 .5947 m .58681 .59309 L .58519 .59347 L F
.58681 .59309 m .57986 .59017 L .58519 .59347 L F
.58884 .53404 m .59042 .53431 L .59053 .5899 L .751 .49 .538 r
F
.58884 .53404 m .59053 .5899 L .59043 .58988 L F
.58625 .58765 m .57854 .58639 L .57887 .58842 L .645 .732 .913 r
F
.58719 .53296 m .58785 .53356 L .58795 .58912 L .93 .648 .485 r
F
.58719 .53296 m .58795 .58912 L .58791 .58908 L F
.58694 .58836 m .57887 .58842 L .58005 .59036 L .645 .732 .913 r
F
.59115 .58713 m .58689 .58758 L .58694 .58836 L F
.58689 .58758 m .57887 .58842 L .58694 .58836 L F
.58676 .53144 m .58681 .53226 L .58691 .58789 L .777 .62 .057 r
F
.58691 .58784 m .58691 .58789 L .58692 .59143 L F
.58676 .53144 m .58691 .58789 L .58691 .58784 L F
.58853 .58553 m .58741 .58957 L .58854 .58878 L .4 .211 .506 r
F
.58843 .52961 m .58746 .58617 L .58853 .58553 L F
.59115 .58713 m .58632 .58685 L .58625 .58765 L .645 .732 .913 r
F
.58746 .58617 m .58741 .58957 L .58853 .58553 L .4 .211 .506 r
F
.58632 .58685 m .58525 .58679 L .58573 .5872 L .645 .732 .913 r
F
.58632 .58685 m .58573 .5872 L .58625 .58765 L F
.58525 .58679 m .57854 .58639 L .58625 .58765 L F
.58791 .58908 m .58795 .58912 L .58796 .59273 L .93 .648 .485 r
F
.58684 .58688 m .57906 .58442 L .57854 .58639 L .645 .732 .913 r
F
.59115 .58713 m .5868 .58616 L .58684 .58688 L F
.5868 .58616 m .57906 .58442 L .58684 .58688 L F
.58686 .58713 m .58692 .59143 L .58687 .59061 L .777 .62 .057 r
F
.58676 .53144 m .58691 .58784 L .58686 .58713 L F
.58691 .58784 m .58692 .59143 L .58686 .58713 L F
.58728 .5894 m .5822 .58489 L .58011 .58639 L .645 .732 .913 r
F
.5909 .59092 m .58834 .58915 L .58728 .5894 L F
.58834 .58915 m .5822 .58489 L .58728 .5894 L F
.58965 .58844 m .58854 .58878 L .58854 .5891 L .567 .342 .533 r
F
.58577 .58976 m .58011 .58639 L .57875 .58819 L .645 .732 .913 r
F
.58854 .58878 m .58741 .58957 L .58741 .58978 L .4 .211 .506 r
F
.58845 .58915 m .58741 .58978 L .58741 .59335 L F
.58854 .58878 m .58741 .58978 L .58845 .58915 L F
.58697 .59004 m .58728 .5894 L .58577 .58976 L .645 .732 .913 r
F
.5909 .59092 m .58773 .58959 L .58697 .59004 L F
.5874 .58621 m .58687 .59061 L .58741 .58957 L 0 0 .377 r
F
.5873 .5304 m .58689 .58708 L .5874 .58621 L F
.58689 .58708 m .58687 .59061 L .5874 .58621 L F
.5873 .5304 m .58676 .53144 L .58686 .58713 L F
.58689 .58708 m .58686 .58713 L .58687 .59061 L F
.5873 .5304 m .58686 .58713 L .58689 .58708 L F
.5877 .58569 m .58249 .58114 L .58041 .58263 L .645 .732 .913 r
F
.58965 .58526 m .58854 .58878 L .58965 .58844 L .567 .342 .533 r
F
.58954 .52927 m .58859 .58551 L .58965 .58526 L F
.59115 .58713 m .58875 .58548 L .58776 .58571 L .645 .732 .913 r
F
.59115 .58713 m .5877 .58569 L .58736 .58628 L F
.58859 .58551 m .58854 .58878 L .58965 .58526 L .567 .342 .533 r
F
.58776 .58571 m .58809 .58502 L .5877 .58569 L .645 .732 .913 r
F
.58875 .58548 m .58809 .58502 L .58776 .58571 L F
.58809 .58502 m .58249 .58114 L .5877 .58569 L F
.58736 .58628 m .58041 .58263 L .57906 .58442 L F
.5877 .58569 m .58041 .58263 L .58736 .58628 L F
.58773 .58959 m .58728 .5894 L .58697 .59004 L F
.58728 .5894 m .58011 .58639 L .58577 .58976 L F
.58896 .59674 m .59057 .6498 L .58906 .64967 L .751 .49 .538 r
F
.58905 .59675 m .59057 .6498 L .58896 .59674 L F
.58895 .59321 m .59054 .59704 L .58905 .59675 L F
.59065 .5947 m .58867 .5966 L .58951 .597 L .645 .732 .913 r
F
.5909 .59092 m .58267 .58907 L .57823 .59017 L F
.58267 .58907 m .57875 .58819 L .57848 .58921 L F
.58267 .58907 m .57848 .58921 L .57823 .59017 L F
.59115 .58713 m .58863 .58954 L .58984 .58977 L F
.59076 .58835 m .58965 .58844 L .58965 .58883 L .66 .415 .539 r
F
.5898 .61421 m .59004 .61043 L .59991 .61022 L .67 .442 .566 r
F
.59041 .60259 m .59005 .61032 L .59987 .6101 L .645 .732 .913 r
F
.5898 .61421 m .59991 .61022 L .59967 .614 L .67 .442 .566 r
F
.58955 .618 m .5898 .61421 L .59967 .614 L F
.59017 .60645 m .5898 .61421 L .59967 .614 L .645 .732 .913 r
F
.58955 .618 m .59967 .614 L .59942 .61778 L .67 .442 .566 r
F
.59017 .60645 m .59967 .614 L .59675 .60631 L .645 .732 .913 r
F
.58992 .61024 m .58955 .618 L .59942 .61778 L F
.58992 .61024 m .59942 .61778 L .5965 .61009 L F
.59029 .60247 m .58992 .61024 L .5965 .61009 L F
.59065 .5947 m .58702 .60201 L .59029 .60247 L F
.58905 .59675 m .59054 .59704 L .59065 .65279 L .751 .49 .538 r
F
.59054 .59347 m .59054 .59347 L .58895 .59317 L F
.59115 .58713 m .58984 .58977 L .59101 .58999 L .645 .732 .913 r
F
.58551 .59254 m .58195 .58868 L .57986 .59017 L F
.59065 .5947 m .58744 .59248 L .58551 .59254 L F
.58741 .58957 m .58687 .59427 L .58738 .59341 L 0 0 .377 r
F
.58744 .59248 m .58195 .58868 L .58551 .59254 L .645 .732 .913 r
F
.5909 .59092 m .58488 .58381 L .5822 .58489 L F
.59075 .58879 m .58965 .58883 L .58966 .5924 L .66 .415 .539 r
F
.59069 .59237 m .58966 .5924 L .58977 .64776 L F
.59075 .58879 m .58966 .5924 L .59069 .59237 L F
.59076 .58835 m .58965 .58883 L .59075 .58879 L F
.58741 .58957 m .58738 .59341 L .58741 .59335 L 0 0 .377 r
F
.58793 .59282 m .58463 .5876 L .58195 .58868 L .645 .732 .913 r
F
.59065 .5947 m .58887 .59259 L .58793 .59282 L F
.58887 .59259 m .58463 .5876 L .58793 .59282 L F
.59065 .5947 m .58743 .59644 L .5886 .59667 L F
.58895 .59321 m .58905 .59675 L .58896 .59674 L .751 .49 .538 r
F
.58743 .59644 m .58849 .59671 L .58839 .59663 L .645 .732 .913 r
F
.58849 .59671 m .58801 .59691 L .58852 .59674 L F
.58801 .59691 m .58803 .59694 L .58852 .59674 L F
.58803 .59629 m .58896 .59674 L .58906 .64967 L .846 .571 .522 r
F
.58803 .59629 m .58906 .64967 L .58901 .64965 L F
.58895 .59317 m .59054 .59347 L .58895 .59321 L .751 .49 .538 r
F
.58959 .59242 m .58855 .59267 L .58865 .6481 L .567 .342 .533 r
F
.58865 .64547 m .58921 .64456 L .58814 .6449 L .692 .759 .903 r
F
.59023 .64725 m .58945 .64518 L .58865 .64547 L F
.58966 .5924 m .5887 .64545 L .58976 .64507 L .567 .342 .533 r
F
.58945 .64518 m .58921 .64456 L .58865 .64547 L .692 .759 .903 r
F
.58679 .64683 m .58648 .64603 L .58601 .64674 L F
.59023 .64725 m .58745 .64634 L .58679 .64683 L F
.58745 .64634 m .58648 .64603 L .58679 .64683 L F
.59023 .64725 m .58814 .6449 L .58721 .6454 L F
.58692 .64742 m .58601 .64674 L .58583 .64748 L F
.59023 .64725 m .58721 .64688 L .58692 .64742 L F
.58721 .64688 m .58601 .64674 L .58692 .64742 L F
.59023 .64725 m .58595 .64821 L .58636 .64887 L F
.58751 .6463 m .58707 .6493 L .58752 .64845 L 0 0 .377 r
F
.587 .64728 m .58698 .64993 L .58751 .6463 L F
.5875 .64848 m .58746 .6476 L .58673 .64823 L .692 .759 .903 r
F
.59023 .64725 m .58832 .64938 L .58906 .64967 L F
.59023 .64725 m .58906 .64967 L .58914 .64967 L F
.59023 .64725 m .58897 .65005 L .59011 .65009 L F
.5905 .64945 m .58784 .64783 L .5875 .64848 L F
.59023 .64725 m .58721 .6454 L .58648 .64603 L F
.58756 .64626 m .58752 .64844 L .58865 .64547 L .4 .211 .506 r
F
.5905 .64945 m .58673 .64823 L .58625 .64894 L .692 .759 .903 r
F
.58752 .64844 m .58752 .64889 L .58771 .64831 L .4 .211 .506 r
F
.58752 .64844 m .58771 .64831 L .58865 .64547 L F
.58784 .64783 m .58746 .6476 L .5875 .64846 L .692 .759 .903 r
F
.58752 .64845 m .5875 .64846 L .5875 .64848 L F
.58784 .64783 m .5875 .64846 L .58752 .64845 L F
.58738 .64872 m .58741 .65145 L .58702 .64811 L .988 .719 .381 r
F
.58803 .64925 m .58807 .65205 L .5874 .64875 L .93 .648 .485 r
F
.5905 .64945 m .58625 .64894 L .58607 .64969 L .692 .759 .903 r
F
.58752 .64845 m .58698 .64993 L .58752 .64889 L 0 0 .377 r
F
.58707 .6493 m .58698 .64993 L .58752 .64845 L F
.58741 .59335 m .587 .64728 L .58751 .6463 L F
.58865 .64547 m .58771 .64831 L .58865 .64762 L .4 .211 .506 r
F
.58812 .648 m .58839 .64709 L .58746 .6476 L .692 .759 .903 r
F
.5905 .64945 m .58878 .64752 L .58812 .648 L F
.58878 .64752 m .58839 .64709 L .58812 .648 L F
.58865 .64762 m .58752 .64889 L .58865 .6481 L .4 .211 .506 r
F
.58771 .64831 m .58752 .64889 L .58865 .64762 L F
.58855 .59267 m .58756 .64626 L .58865 .64547 L F
.5887 .64545 m .58865 .6481 L .58976 .64507 L .567 .342 .533 r
F
.58881 .64756 m .58948 .64675 L .58839 .64709 L .692 .759 .903 r
F
.5905 .64945 m .58966 .64725 L .58881 .64756 L F
.58976 .64507 m .58886 .64754 L .58977 .64722 L .567 .342 .533 r
F
.58966 .64725 m .58948 .64675 L .58881 .64756 L .692 .759 .903 r
F
.58977 .64722 m .58865 .6481 L .58977 .64776 L .567 .342 .533 r
F
.58886 .64754 m .58865 .6481 L .58977 .64722 L F
.58965 .58883 m .58959 .59242 L .58966 .5924 L F
.58959 .59242 m .58865 .6481 L .58966 .5924 L F
.58965 .58844 m .58965 .58883 L .58965 .58883 L F
.58965 .58883 m .58865 .6481 L .58965 .58883 L F
.58954 .58886 m .58854 .5891 L .58855 .59267 L F
.58965 .58844 m .58854 .5891 L .58954 .58886 L F
.58965 .58844 m .58855 .59267 L .58959 .59242 L F
.58854 .58878 m .58847 .59271 L .58855 .59267 L .4 .211 .506 r
F
.59065 .5947 m .58696 .59578 L .58786 .59621 L .645 .732 .913 r
F
.58847 .59271 m .58752 .64889 L .58855 .59267 L .4 .211 .506 r
F
.58738 .59341 m .58698 .64993 L .58741 .59335 L 0 0 .377 r
F
.58636 .59515 m .58564 .59441 L .58398 .5954 L .645 .732 .913 r
F
.59065 .5947 m .58676 .59447 L .58636 .59515 L F
.58676 .59447 m .58564 .59441 L .58636 .59515 L F
.58564 .59441 m .57798 .59396 L .58398 .5954 L F
.59065 .5947 m .58636 .59515 L .5858 .59611 L F
.58734 .59572 m .58807 .65205 L .5873 .59569 L .93 .648 .485 r
F
.58847 .59271 m .58741 .59335 L .58752 .64889 L .4 .211 .506 r
F
.58854 .58878 m .58741 .59335 L .58847 .59271 L F
.58738 .59341 m .58687 .59427 L .58698 .64993 L 0 0 .377 r
F
.5858 .59611 m .58271 .59553 L .58577 .59612 L .645 .732 .913 r
F
.58636 .59515 m .58271 .59553 L .5858 .59611 L F
.58271 .59553 m .57832 .59599 L .58577 .59612 L F
.58703 .59666 m .5795 .59794 L .58144 .59967 L F
.58701 .59638 m .5795 .59794 L .58703 .59666 L F
.58663 .64744 m .58583 .64748 L .58695 .64799 L .692 .759 .903 r
F
.58703 .64942 m .58561 .65241 L .58792 .64983 L F
.58703 .64942 m .58383 .6516 L .58561 .65241 L F
.58701 .65024 m .58607 .64969 L .58619 .65042 L F
.58702 .64811 m .58733 .65077 L .58702 .65026 L .988 .719 .381 r
F
.5905 .64945 m .58667 .64966 L .58701 .65024 L .692 .759 .903 r
F
.58667 .64966 m .58607 .64969 L .58701 .65024 L F
.5905 .64945 m .58619 .65042 L .5866 .65109 L F
.58702 .65026 m .58741 .65145 L .58703 .65075 L .988 .719 .381 r
F
.58733 .65077 m .58741 .65145 L .58702 .65026 L F
.58712 .59808 m .584 .60106 L .58734 .60138 L .645 .732 .913 r
F
0 g
.59041 .5292 m
.59042 .53431 L
s
.5735 .50971 m .55747 .50488 L .55343 .51057 L .683 .77 .917 r
F
.57661 .50719 m .55747 .50488 L .5735 .50971 L F
.59502 .58876 m .5998 .59313 L .60188 .59164 L .645 .732 .913 r
F
.59115 .58713 m .59401 .58912 L .59502 .58876 L F
.59401 .58912 m .5998 .59313 L .59502 .58876 L F
.59202 .5341 m .59306 .53366 L .59317 .58941 L .516 .301 .527 r
F
.59311 .58943 m .59317 .58941 L .59317 .59282 L F
.59202 .5341 m .59317 .58941 L .59311 .58943 L F
.3729 .62732 m .36421 .62135 L .35802 .62579 L .645 .732 .913 r
F
.37821 .62518 m .36421 .62135 L .3729 .62732 L F
.59276 .40656 m .57269 .4028 L .57302 .40849 L .671 .448 .573 r
F
0 g
.55447 .41346 m
.57302 .40849 L
s
.59276 .40656 m .59243 .40086 L .57269 .4028 L .671 .448 .573 r
F
0 g
.55415 .40777 m
.57269 .4028 L
s
.40851 .62942 m .40996 .62035 L .4034 .62666 L .645 .732 .913 r
F
.40851 .62942 m .41764 .62448 L .40996 .62035 L F
.55425 .51972 m .5361 .51772 L .53372 .5267 L .683 .77 .917 r
F
0 g
.53372 .5267 m
.53521 .53547 L
s
.38678 .63916 m .3838 .63148 L .37763 .63267 L .645 .732 .913 r
F
.39006 .63909 m .3838 .63148 L .38678 .63916 L F
.127 .923 .03 r
.59503 .63733 m
.59527 .61787 L
s
.59541 .60634 m
.59546 .60248 L
s
.59551 .59862 m
.59556 .5945 L
s
.59562 .58901 m
.59585 .57082 L
s
.59515 .58804 m .60188 .59164 L .60323 .58985 L .645 .732 .913 r
F
.59115 .58713 m .59445 .58852 L .59515 .58804 L F
.59445 .58852 m .60188 .59164 L .59515 .58804 L F
.59306 .53366 m .59377 .53308 L .59388 .58892 L .356 .178 .497 r
F
.59384 .58895 m .59388 .58892 L .59389 .59225 L F
.59306 .53366 m .59388 .58892 L .59384 .58895 L F
.39333 .63954 m .39037 .63134 L .39006 .63909 L .645 .732 .913 r
F
.39333 .63954 m .3969 .63225 L .39037 .63134 L F
.60671 .51254 m .61764 .50154 L .60382 .51033 L .683 .77 .917 r
F
.60671 .51254 m .62341 .50596 L .61764 .50154 L F
.37229 .63483 m .35734 .63328 L .36815 .6378 L .645 .732 .913 r
F
.39006 .63909 m .39037 .63134 L .3838 .63148 L F
.41198 .64037 m .41726 .63197 L .40809 .63693 L F
.41198 .64037 m .4231 .63714 L .41726 .63197 L F
.36382 .62504 m .35786 .62572 L .3576 .6295 L .347 .173 .497 r
F
.36382 .62504 m .36408 .62126 L .35786 .62572 L F
0 g
.35385 .63111 m
.35786 .62572 L
s
.60325 .50579 m .60939 .49383 L .59945 .50419 L .683 .77 .917 r
F
.60325 .50579 m .617 .49704 L .60939 .49383 L F
.595 .58736 m .60323 .58985 L .60375 .58787 L .645 .732 .913 r
F
.59115 .58713 m .5946 .58791 L .595 .58736 L F
.5946 .58791 m .60323 .58985 L .595 .58736 L F
.59377 .53308 m .59421 .5324 L .59432 .58831 L .076 0 .415 r
F
.5943 .58834 m .59432 .58831 L .59433 .59156 L F
.59377 .53308 m .59432 .58831 L .5943 .58834 L F
.42336 .63336 m .42361 .62958 L .41778 .62441 L .926 .677 .542 r
F
0 g
.42361 .62958 m
.42717 .63541 L
s
.61233 .40779 m .59243 .40086 L .59276 .40656 L .733 .496 .568 r
F
0 g
.57269 .4028 m
.59243 .40086 L
s
.59243 .40086 m
.612 .40209 L
s
.61233 .40779 m
.6304 .4121 L
s
.61188 .36704 m
.61205 .43828 L
s
.55747 .50488 m .53538 .50858 L .55343 .51057 L .683 .77 .917 r
F
.57442 .51886 m .55425 .51972 L .57238 .52171 L F
0 g
.59276 .40656 m
.61233 .40779 L
s
.59399 .58658 m .59294 .58886 L .594 .58969 L .911 .629 .497 r
F
.59388 .53052 m .59298 .58582 L .59399 .58658 L F
.59421 .5324 m .59443 .5876 L .59432 .58831 L 0 0 .146 r
F
.59457 .58678 m .60375 .58787 L .60342 .58585 L .645 .732 .913 r
F
.59115 .58713 m .59448 .58733 L .59457 .58678 L F
.59448 .58733 m .60375 .58787 L .59457 .58678 L F
.59421 .5324 m .59433 .53158 L .59444 .58756 L 0 0 .146 r
F
.59443 .5876 m .59444 .58756 L .59445 .59074 L F
.59421 .5324 m .59444 .58756 L .59443 .5876 L F
.59298 .58582 m .59294 .58886 L .59399 .58658 L .911 .629 .497 r
F
.59433 .53158 m .59388 .53052 L .59399 .58658 L .983 .725 .333 r
F
.59402 .58663 m .59399 .58658 L .594 .58969 L F
.59433 .53158 m .59399 .58658 L .59402 .58663 L F
.59432 .58831 m .59445 .59074 L .59433 .59156 L 0 0 .146 r
F
.59443 .5876 m .59445 .59074 L .59432 .58831 L F
.59444 .58756 m .594 .58969 L .59445 .59074 L .983 .725 .333 r
F
.59433 .53158 m .59402 .58663 L .59444 .58756 L F
.59402 .58663 m .594 .58969 L .59444 .58756 L F
.5933 .58507 m .60032 .58219 L .59777 .5808 L .645 .732 .913 r
F
.59293 .58578 m .59185 .58848 L .59294 .58886 L .81 .54 .53 r
F
.59282 .52969 m .5919 .5854 L .59293 .58578 L F
.59115 .58713 m .59337 .58594 L .59267 .58568 L .645 .732 .913 r
F
.59115 .58713 m .59273 .58562 L .59212 .58517 L F
.59324 .58601 m .60225 .58391 L .60032 .58219 L F
.59115 .58713 m .59373 .58638 L .59324 .58601 L F
.59373 .58638 m .60225 .58391 L .59324 .58601 L F
.59388 .53052 m .59282 .52969 L .59293 .58578 L .911 .629 .497 r
F
.59422 .58624 m .60342 .58585 L .60225 .58391 L .645 .732 .913 r
F
.59115 .58713 m .59544 .58668 L .59422 .58624 L F
.59544 .58668 m .60342 .58585 L .59422 .58624 L F
.59282 .52969 m .59174 .52931 L .59185 .58538 L .81 .54 .53 r
F
.5919 .5854 m .59185 .58538 L .59185 .58848 L F
.59282 .52969 m .59185 .58538 L .5919 .5854 L F
.59298 .58582 m .59293 .58578 L .59294 .58886 L .911 .629 .497 r
F
.59388 .53052 m .59293 .58578 L .59298 .58582 L F
.5919 .5854 m .59185 .58848 L .59293 .58578 L .81 .54 .53 r
F
.59267 .58568 m .59363 .58579 L .5933 .58507 L .645 .732 .913 r
F
.59337 .58594 m .59363 .58579 L .59267 .58568 L F
.59363 .58579 m .60032 .58219 L .5933 .58507 L F
.59276 .58388 m .59513 .58333 L .59476 .57985 L F
.59212 .58517 m .59308 .58458 L .59276 .58388 L F
.59308 .58458 m .59513 .58333 L .59276 .58388 L F
.59273 .58562 m .59513 .58333 L .59212 .58517 L F
.59513 .58333 m .59777 .5808 L .59564 .58013 L F
.59513 .58333 m .59564 .58013 L .59476 .57985 L F
.6274 .51586 m .64062 .50396 L .62391 .51055 L .683 .77 .917 r
F
.6274 .51586 m .64585 .51194 L .64062 .50396 L F
.64534 .50735 m .63961 .49479 L .64011 .49938 L .98 .687 .329 r
F
.64585 .51194 m .64534 .50735 L .64011 .49938 L F
0 g
.64534 .50735 m
.64679 .51613 L
s
.37255 .63105 m .36382 .62504 L .3576 .6295 L .645 .732 .913 r
F
.37789 .62889 m .36382 .62504 L .37255 .63105 L F
.57392 .51427 m .55781 .50942 L .55375 .51513 L .683 .77 .917 r
F
.57705 .51174 m .55781 .50942 L .57392 .51427 L F
.40835 .63315 m .4098 .62403 L .4032 .63038 L .645 .732 .913 r
F
.40835 .63315 m .41752 .62819 L .4098 .62403 L F
0 g
.59386 .5224 m
.59388 .53052 L
s
.57661 .50719 m .5637 .49985 L .55747 .50488 L .683 .77 .917 r
F
.58061 .50518 m .5637 .49985 L .57661 .50719 L F
.60721 .51713 m .61815 .50613 L .60433 .51492 L F
.60721 .51713 m .62391 .51055 L .61815 .50613 L F
.36356 .62882 m .3576 .6295 L .35734 .63328 L .347 .173 .497 r
F
.36356 .62882 m .36382 .62504 L .3576 .6295 L F
0 g
.35359 .63489 m
.3576 .6295 L
s
.37821 .62518 m .37218 .61813 L .36421 .62135 L .645 .732 .913 r
F
.38435 .62399 m .37218 .61813 L .37821 .62518 L F
.4034 .62666 m .40094 .6175 L .39738 .62476 L F
.4034 .62666 m .40996 .62035 L .40094 .6175 L F
0 g
.57302 .40849 m
.59276 .40656 L
s
.42336 .63336 m .41778 .62441 L .41752 .62819 L .926 .677 .542 r
F
.4231 .63714 m .42336 .63336 L .41752 .62819 L F
0 g
.42336 .63336 m
.42692 .63919 L
s
.59945 .50419 m .60042 .49203 L .59496 .50329 L .683 .77 .917 r
F
.59945 .50419 m .60939 .49383 L .60042 .49203 L F
.60382 .51033 m .60999 .49831 L .6 .50872 L F
.60382 .51033 m .61764 .50154 L .60999 .49831 L F
0 g
.59388 .53052 m
.59398 .58142 L
s
.58869 .58543 m .58516 .58006 L .58249 .58114 L .645 .732 .913 r
F
.59075 .58522 m .58965 .58844 L .59076 .58835 L .66 .415 .539 r
F
.59064 .52918 m .58971 .58526 L .59075 .58522 L F
.59115 .58713 m .58956 .58526 L .58869 .58543 L .645 .732 .913 r
F
.58971 .58526 m .58965 .58844 L .59075 .58522 L .66 .415 .539 r
F
.58956 .58526 m .58936 .58503 L .58894 .58528 L .645 .732 .913 r
F
.58956 .58526 m .58894 .58528 L .58869 .58543 L F
.58936 .58503 m .58516 .58006 L .58869 .58543 L F
.58843 .52961 m .5873 .5304 L .5874 .58621 L .4 .211 .506 r
F
.58746 .58617 m .5874 .58621 L .58741 .58957 L F
.58843 .52961 m .5874 .58621 L .58746 .58617 L F
0 g
.5873 .5304 m
.58739 .5827 L
s
.58728 .52272 m
.5873 .5304 L
s
.55781 .50942 m .53561 .51314 L .55375 .51513 L .683 .77 .917 r
F
.62274 .50144 m .63075 .48828 L .617 .49704 L F
.62274 .50144 m .63936 .49489 L .63075 .48828 L F
.37229 .63483 m .36356 .62882 L .35734 .63328 L .645 .732 .913 r
F
0 g
.35333 .63867 m
.35734 .63328 L
s
.37763 .63267 m .36356 .62882 L .37229 .63483 L .645 .732 .913 r
F
.64585 .51194 m .64011 .49938 L .64062 .50396 L .98 .687 .329 r
F
0 g
.64585 .51194 m
.6473 .52071 L
s
.58061 .50518 m .57169 .49582 L .5637 .49985 L .683 .77 .917 r
F
.58521 .5038 m .57169 .49582 L .58061 .50518 L F
.58954 .52927 m .58843 .52961 L .58854 .58878 L .567 .342 .533 r
F
.40809 .63693 m .40955 .62782 L .40295 .63416 L .645 .732 .913 r
F
.40809 .63693 m .41726 .63197 L .40955 .62782 L F
.59174 .52931 m .59076 .58835 L .59185 .58848 L .734 .476 .539 r
F
.59174 .52931 m .59064 .52918 L .59076 .58835 L F
.57442 .51886 m .55831 .514 L .55425 .51972 L .683 .77 .917 r
F
.57755 .51633 m .55831 .514 L .57442 .51886 L F
.59064 .52918 m .58954 .52927 L .58965 .58844 L .66 .415 .539 r
F
.38435 .62399 m .38138 .61635 L .37218 .61813 L .645 .732 .913 r
F
.39089 .62385 m .38138 .61635 L .38435 .62399 L F
.39738 .62476 m .39119 .61613 L .39089 .62385 L F
.39738 .62476 m .40094 .6175 L .39119 .61613 L F
.59496 .50329 m .5907 .49177 L .59011 .50316 L .683 .77 .917 r
F
.59496 .50329 m .60042 .49203 L .5907 .49177 L F
.57705 .51174 m .56407 .50436 L .55781 .50942 L F
.58106 .50972 m .56407 .50436 L .57705 .51174 L F
.37789 .62889 m .37183 .6218 L .36382 .62504 L .645 .732 .913 r
F
.38406 .6277 m .37183 .6218 L .37789 .62889 L F
.4032 .63038 m .40074 .62117 L .39716 .62847 L F
.4032 .63038 m .4098 .62403 L .40074 .62117 L F
.4231 .63714 m .41752 .62819 L .41726 .63197 L .926 .677 .542 r
F
0 g
.4231 .63714 m
.42666 .64297 L
s
.39089 .62385 m .39119 .61613 L .38138 .61635 L .645 .732 .913 r
F
.58521 .5038 m .5809 .49306 L .57169 .49582 L .683 .77 .917 r
F
.59011 .50316 m .5809 .49306 L .58521 .5038 L F
.59011 .50316 m .5907 .49177 L .5809 .49306 L F
.6 .50872 m .60097 .49651 L .59549 .50782 L F
.6 .50872 m .60999 .49831 L .60097 .49651 L F
.60433 .51492 m .6105 .5029 L .6005 .51331 L F
.60433 .51492 m .61815 .50613 L .6105 .5029 L F
.55747 .50488 m .54144 .50004 L .53538 .50858 L F
.5417 .50456 m .53511 .50855 L .53561 .51314 L .199 .113 .527 r
F
.5417 .50456 m .5412 .49997 L .53511 .50855 L F
0 g
.53273 .51753 m
.53511 .50855 L
s
.55831 .514 m .5361 .51772 L .55425 .51972 L .683 .77 .917 r
F
.62341 .50596 m .63147 .49274 L .61764 .50154 L F
.62341 .50596 m .64011 .49938 L .63147 .49274 L F
.37183 .6218 m .36408 .62126 L .36382 .62504 L .498 .296 .537 r
F
.37183 .6218 m .37209 .61802 L .36408 .62126 L F
0 g
.35786 .62572 m
.36408 .62126 L
s
.41752 .62819 m .41778 .62441 L .41006 .62025 L .857 .609 .563 r
F
0 g
.41778 .62441 m
.42361 .62958 L
s
.58106 .50972 m .57211 .50031 L .56407 .50436 L .683 .77 .917 r
F
.58569 .50834 m .57211 .50031 L .58106 .50972 L F
.38406 .6277 m .38108 .62002 L .37183 .6218 L .645 .732 .913 r
F
.39063 .62756 m .38108 .62002 L .38406 .6277 L F
.39716 .62847 m .39094 .6198 L .39063 .62756 L F
.39716 .62847 m .40074 .62117 L .39094 .6198 L F
.37763 .63267 m .37157 .62559 L .36356 .62882 L F
.3838 .63148 m .37157 .62559 L .37763 .63267 L F
.40295 .63416 m .40048 .62495 L .3969 .63225 L F
.40295 .63416 m .40955 .62782 L .40048 .62495 L F
.57755 .51633 m .56457 .50895 L .55831 .514 L .683 .77 .917 r
F
.58157 .51431 m .56457 .50895 L .57755 .51633 L F
.59549 .50782 m .59121 .49624 L .59061 .50769 L F
.59549 .50782 m .60097 .49651 L .59121 .49624 L F
.39063 .62756 m .39094 .6198 L .38108 .62002 L .645 .732 .913 r
F
.5637 .49985 m .54144 .50004 L .55747 .50488 L .683 .77 .917 r
F
.58569 .50834 m .58136 .49754 L .57211 .50031 L F
.59061 .50769 m .58136 .49754 L .58569 .50834 L F
.59061 .50769 m .59121 .49624 L .58136 .49754 L F
.6005 .51331 m .60148 .5011 L .596 .51241 L F
.6005 .51331 m .6105 .5029 L .60148 .5011 L F
.5422 .50915 m .53561 .51314 L .5361 .51772 L .199 .113 .527 r
F
.55781 .50942 m .5417 .50456 L .53561 .51314 L .683 .77 .917 r
F
.5422 .50915 m .5417 .50456 L .53561 .51314 L .199 .113 .527 r
F
0 g
.53323 .52211 m
.53561 .51314 L
s
.37157 .62559 m .36382 .62504 L .36356 .62882 L .498 .296 .537 r
F
0 g
.35734 .63328 m
.36356 .62882 L
s
.37157 .62559 m .37183 .6218 L .36382 .62504 L .498 .296 .537 r
F
0 g
.3576 .6295 m
.36382 .62504 L
s
.62391 .51055 m .63197 .49733 L .61815 .50613 L .683 .77 .917 r
F
.62391 .51055 m .64062 .50396 L .63197 .49733 L F
.41752 .62819 m .41006 .62025 L .4098 .62403 L .857 .609 .563 r
F
.41726 .63197 m .41752 .62819 L .4098 .62403 L F
0 g
.41752 .62819 m
.42336 .63336 L
s
.3838 .63148 m .38082 .6238 L .37157 .62559 L .645 .732 .913 r
F
.39037 .63134 m .38082 .6238 L .3838 .63148 L F
.3969 .63225 m .39068 .62358 L .39037 .63134 L F
.3969 .63225 m .40048 .62495 L .39068 .62358 L F
.58157 .51431 m .57261 .5049 L .56457 .50895 L .683 .77 .917 r
F
.58619 .51292 m .57261 .5049 L .58157 .51431 L F
.39037 .63134 m .39068 .62358 L .38082 .6238 L .645 .732 .913 r
F
.64011 .49938 m .63961 .49479 L .63096 .48815 L .934 .647 .471 r
F
0 g
.63961 .49479 m
.64483 .50277 L
s
.61787 2.85992 m
.63161 8.57547 L
s
.127 .923 .03 r
.49649 8.79864 m
.53611 .5204 L
s
.53611 .5204 m
.53612 .51858 L
s
0 0 0 r
2.5 Mabswid
.53612 .51858 Mdot
.127 .923 .03 r
.5 Mabswid
.53492 .59077 m
.53609 .52027 L
s
.53609 .52027 m
.53612 .51858 L
s
.617 .49704 m .61933 .48347 L .60939 .49383 L .683 .77 .917 r
F
.617 .49704 m .63075 .48828 L .61933 .48347 L F
.596 .51241 m .59171 .50083 L .59111 .51228 L F
.596 .51241 m .60148 .5011 L .59171 .50083 L F
.56407 .50436 m .5417 .50456 L .55781 .50942 L F
.58619 .51292 m .58187 .50213 L .57261 .5049 L F
.59111 .51228 m .58187 .50213 L .58619 .51292 L F
.59111 .51228 m .59171 .50083 L .58187 .50213 L F
.55831 .514 m .5422 .50915 L .5361 .51772 L F
0 g
.53372 .5267 m
.5361 .51772 L
s
.38108 .62002 m .37209 .61802 L .37183 .6218 L .596 .378 .556 r
F
.38108 .62002 m .38134 .61623 L .37209 .61802 L F
0 g
.36408 .62126 m
.37209 .61802 L
s
.41726 .63197 m .4098 .62403 L .40955 .62782 L .857 .609 .563 r
F
0 g
.41726 .63197 m
.4231 .63714 L
s
.127 .923 .03 r
.41034 .60913 m
.42043 1.56891 L
s
.4098 .62403 m .41006 .62025 L .401 .61739 L .793 .551 .57 r
F
0 g
.41006 .62025 m
.41778 .62441 L
s
.64011 .49938 m .63096 .48815 L .63147 .49274 L .934 .647 .471 r
F
.64062 .50396 m .64011 .49938 L .63147 .49274 L F
0 g
.64011 .49938 m
.64534 .50735 L
s
.61764 .50154 m .61999 .4879 L .60999 .49831 L .683 .77 .917 r
F
.61764 .50154 m .63147 .49274 L .61999 .4879 L F
.56457 .50895 m .5422 .50915 L .55831 .514 L F
.127 .923 .03 r
.58016 .69509 m
.58077 .63703 L
s
.58077 .63703 m
.58099 .6168 L
s
.58107 .60918 m
.58107 .60906 L
s
.58109 .60738 m
.58116 .60081 L
s
.58136 .58195 m
.58154 .5649 L
s
.58356 .65584 m
.58442 .61728 L
s
.5637 .49985 m .55078 .49249 L .54144 .50004 L .683 .77 .917 r
F
.57169 .49582 m .55078 .49249 L .5637 .49985 L F
.38082 .6238 m .37183 .6218 L .37157 .62559 L .596 .378 .556 r
F
0 g
.36356 .62882 m
.37157 .62559 L
s
.38082 .6238 m .38108 .62002 L .37183 .6218 L .596 .378 .556 r
F
0 g
.36382 .62504 m
.37183 .6218 L
s
.4098 .62403 m .401 .61739 L .40074 .62117 L .793 .551 .57 r
F
.40955 .62782 m .4098 .62403 L .40074 .62117 L F
0 g
.4098 .62403 m
.41752 .62819 L
s
.39094 .6198 m .38134 .61623 L .38108 .62002 L .67 .442 .566 r
F
.39094 .6198 m .3912 .61602 L .38134 .61623 L F
0 g
.37209 .61802 m
.38134 .61623 L
s
.57095 .60998 m .58025 .60906 L .58001 .61284 L .794 .551 .57 r
F
.57095 .60998 m .5712 .6062 L .58025 .60906 L F
0 g
.58025 .60906 m
.58178 .60928 L
s
.40074 .62117 m .401 .61739 L .3912 .61602 L .733 .497 .571 r
F
0 g
.401 .61739 m
.41006 .62025 L
s
.59967 .614 m .59991 .61022 L .60918 .60843 L .596 .379 .557 r
F
0 g
.59824 .61025 m
.59991 .61022 L
s
.57791 .59978 m .58031 .60895 L .58392 .60168 L .645 .732 .913 r
F
.57791 .59978 m .5713 .6061 L .58031 .60895 L F
.59696 .60245 m .59987 .6101 L .60909 .60832 L F
.59041 .60259 m .59987 .6101 L .59696 .60245 L F
.40074 .62117 m .3912 .61602 L .39094 .6198 L .733 .497 .571 r
F
0 g
.3912 .61602 m
.401 .61739 L
s
.38134 .61623 m
.3912 .61602 L
s
0 0 0 r
2.5 Mabswid
.59526 .5086 Mdot
.60939 .49383 m .60587 .48077 L .60042 .49203 L .683 .77 .917 r
F
.60939 .49383 m .61933 .48347 L .60587 .48077 L F
.64062 .50396 m .63147 .49274 L .63197 .49733 L .934 .647 .471 r
F
0 g
.5 Mabswid
.64062 .50396 m
.64585 .51194 L
s
.61815 .50613 m .6205 .49249 L .6105 .5029 L .683 .77 .917 r
F
.61815 .50613 m .63197 .49733 L .6205 .49249 L F
.40955 .62782 m .40074 .62117 L .40048 .62495 L .793 .551 .57 r
F
0 g
.40955 .62782 m
.41726 .63197 L
s
.56407 .50436 m .55109 .49697 L .5417 .50456 L .683 .77 .917 r
F
.57211 .50031 m .55109 .49697 L .56407 .50436 L F
.55109 .49697 m .5412 .49997 L .5417 .50456 L .402 .257 .568 r
F
.55109 .49697 m .55059 .49238 L .5412 .49997 L F
0 g
.53511 .50855 m
.5412 .49997 L
s
.39068 .62358 m .38108 .62002 L .38082 .6238 L .67 .442 .566 r
F
0 g
.37157 .62559 m
.38082 .6238 L
s
.39068 .62358 m .39094 .6198 L .38108 .62002 L .67 .442 .566 r
F
0 g
.37183 .6218 m
.38108 .62002 L
s
.57071 .61376 m .58001 .61284 L .57976 .61663 L .794 .551 .57 r
F
.57071 .61376 m .57095 .60998 L .58001 .61284 L F
.5776 .60363 m .58001 .61284 L .58364 .60554 L .645 .732 .913 r
F
.5776 .60363 m .57095 .60998 L .58001 .61284 L F
0 g
.58001 .61284 m
.58153 .61306 L
s
.40048 .62495 m .40074 .62117 L .39094 .6198 L .733 .497 .571 r
F
0 g
.40074 .62117 m
.4098 .62403 L
s
.59967 .614 m .60918 .60843 L .60894 .61221 L .596 .379 .557 r
F
.59942 .61778 m .59967 .614 L .60894 .61221 L F
.59675 .60631 m .59967 .614 L .60894 .61221 L .645 .732 .913 r
F
0 g
.598 .61404 m
.59967 .614 L
s
.56326 .60582 m .5712 .6062 L .57095 .60998 L .857 .609 .563 r
F
.56326 .60582 m .56351 .60204 L .5712 .6062 L F
0 g
.5712 .6062 m
.57399 .60708 L
s
.57281 .59702 m .56364 .60196 L .5713 .6061 L .645 .732 .913 r
F
.60894 .61221 m .60918 .60843 L .61723 .60519 L .499 .298 .538 r
F
0 g
.60342 .60954 m
.60918 .60843 L
s
.60311 .60126 m .60909 .60832 L .6171 .6051 L .645 .732 .913 r
F
.59696 .60245 m .60909 .60832 L .60311 .60126 L F
.40048 .62495 m .39094 .6198 L .39068 .62358 L .733 .497 .571 r
F
0 g
.39094 .6198 m
.40074 .62117 L
s
.40048 .62495 m
.40955 .62782 L
s
.38108 .62002 m
.39094 .6198 L
s
.57169 .49582 m .56277 .48644 L .55078 .49249 L .683 .77 .917 r
F
.5809 .49306 m .56277 .48644 L .57169 .49582 L F
.60999 .49831 m .60646 .48519 L .60097 .49651 L F
.60999 .49831 m .61999 .4879 L .60646 .48519 L F
.38904 .71009 m .38879 .70789 L .39223 .70741 L .668 .435 .559 r
F
.38562 .70999 m .38879 .70789 L .38904 .71009 L .731 .481 .55 r
F
.38562 .70999 m .38537 .70778 L .38879 .70789 L F
.38889 .70501 m .38879 .70784 L .39221 .70737 L .692 .759 .903 r
F
.38663 .70494 m .38538 .70774 L .38879 .70784 L F
.39249 .70961 m .39223 .70741 L .39546 .70638 L .599 .386 .563 r
F
.38904 .71009 m .39223 .70741 L .39249 .70961 L .668 .435 .559 r
F
0 g
.38879 .70789 m
.39223 .70741 L
s
.39118 .7047 m .39221 .70737 L .39543 .70635 L .692 .759 .903 r
F
0 g
.38082 .6238 m
.39068 .62358 L
s
.60042 .49203 m .5913 .48037 L .5907 .49177 L .683 .77 .917 r
F
.60042 .49203 m .60587 .48077 L .5913 .48037 L F
.57735 .60741 m .57976 .61663 L .58339 .60932 L .645 .732 .913 r
F
.57735 .60741 m .57071 .61376 L .57976 .61663 L F
0 g
.57976 .61663 m
.58692 .61763 L
s
.39068 .62358 m
.40048 .62495 L
s
.56457 .50895 m .55159 .50156 L .5422 .50915 L .683 .77 .917 r
F
.57261 .5049 m .55159 .50156 L .56457 .50895 L F
.55159 .50156 m .5417 .50456 L .5422 .50915 L .402 .257 .568 r
F
0 g
.5361 .51772 m
.5422 .50915 L
s
.55159 .50156 m .55109 .49697 L .5417 .50456 L .402 .257 .568 r
F
0 g
.53561 .51314 m
.5417 .50456 L
s
.127 .923 .03 r
.53857 .56296 m
.54671 .47873 L
s
.59942 .61778 m .60894 .61221 L .60869 .61599 L .596 .379 .557 r
F
.5965 .61009 m .59942 .61778 L .60869 .61599 L .645 .732 .913 r
F
0 g
.59058 .61797 m
.59942 .61778 L
s
.38246 .70931 m .38537 .70778 L .38562 .70999 L .794 .527 .534 r
F
.38246 .70931 m .3822 .7071 L .38537 .70778 L F
0 g
.38537 .70778 m
.38879 .70789 L
s
.38452 .70449 m .38538 .70774 L .38663 .70494 L .692 .759 .903 r
F
.38452 .70449 m .38223 .70706 L .38538 .70774 L F
.39572 .70859 m .39546 .70638 L .39826 .70488 L .512 .324 .562 r
F
.127 .923 .03 r
.39703 8.82419 m
.4258 .85907 L
s
.4258 .85907 m
.42652 .66137 L
s
.39249 .70961 m .39546 .70638 L .39572 .70859 L .599 .386 .563 r
F
0 g
.39223 .70741 m
.39546 .70638 L
s
.39332 .70402 m .39543 .70635 L .39821 .70485 L .692 .759 .903 r
F
.127 .923 .03 r
.40852 .65972 m
.40859 .60956 L
s
.56301 .6096 m .57095 .60998 L .57071 .61376 L .857 .609 .563 r
F
.56301 .6096 m .56326 .60582 L .57095 .60998 L F
.57247 .60085 m .57095 .60998 L .5776 .60363 L .645 .732 .913 r
F
.57247 .60085 m .56326 .60582 L .57095 .60998 L F
0 g
.57095 .60998 m
.57374 .61086 L
s
.60894 .61221 m .61723 .60519 L .61698 .60897 L .499 .298 .538 r
F
.60869 .61599 m .60894 .61221 L .61698 .60897 L F
.60293 .60512 m .60894 .61221 L .61698 .60897 L .645 .732 .913 r
F
.59675 .60631 m .60894 .61221 L .60293 .60512 L F
0 g
.60317 .61332 m
.60894 .61221 L
s
.63147 .49274 m .63096 .48815 L .61948 .48331 L .861 .591 .528 r
F
0 g
.63096 .48815 m
.63961 .49479 L
s
.3893 .71229 m .38904 .71009 L .39249 .70961 L .668 .435 .559 r
F
.38588 .71219 m .38904 .71009 L .3893 .71229 L .731 .481 .55 r
F
.38588 .71219 m .38562 .70999 L .38904 .71009 L F
.38915 .70724 m .38904 .71009 L .39249 .70961 L .692 .759 .903 r
F
.38687 .70717 m .38904 .71009 L .38915 .70724 L F
.38687 .70717 m .38562 .70999 L .38904 .71009 L F
.39274 .71182 m .39249 .70961 L .39572 .70859 L .599 .386 .563 r
F
.3893 .71229 m .39249 .70961 L .39274 .71182 L .668 .435 .559 r
F
.39145 .70693 m .39249 .70961 L .39572 .70859 L .692 .759 .903 r
F
.38915 .70724 m .39249 .70961 L .39145 .70693 L F
0 g
.38904 .71009 m
.39249 .70961 L
s
.5809 .49306 m .57659 .48231 L .56277 .48644 L .683 .77 .917 r
F
.5907 .49177 m .57659 .48231 L .5809 .49306 L F
.37976 .7081 m .3822 .7071 L .38246 .70931 L .861 .577 .506 r
F
.127 .923 .03 r
.38272 1.00552 m
.3846 1.13604 L
s
.37976 .7081 m .3795 .70589 L .3822 .7071 L .861 .577 .506 r
F
0 g
.3822 .7071 m
.38537 .70778 L
s
.38274 .70369 m .38223 .70706 L .38452 .70449 L .692 .759 .903 r
F
.38274 .70369 m .37955 .70586 L .38223 .70706 L F
.38271 .71151 m .38562 .70999 L .38588 .71219 L .794 .527 .534 r
F
.38271 .71151 m .38246 .70931 L .38562 .70999 L F
.38476 .70672 m .38562 .70999 L .38687 .70717 L .692 .759 .903 r
F
.38476 .70672 m .38246 .70931 L .38562 .70999 L F
0 g
.38562 .70999 m
.38904 .71009 L
s
.5907 .49177 m .5913 .48037 L .57659 .48231 L .683 .77 .917 r
F
.57211 .50031 m .56314 .49089 L .55109 .49697 L F
.58136 .49754 m .56314 .49089 L .57211 .50031 L F
.6105 .5029 m .60697 .48978 L .60148 .5011 L F
.6105 .5029 m .6205 .49249 L .60697 .48978 L F
0 g
.6122 .50236 m
.61221 .50594 L
s
.39851 .70708 m .39826 .70488 L .40043 .703 L .389 .237 .551 r
F
.127 .923 .03 r
.39909 8.82337 m
.52745 1.04402 L
s
.52745 1.04402 m
.53492 .59077 L
s
.39572 .70859 m .39826 .70488 L .39851 .70708 L .512 .324 .562 r
F
0 g
.39546 .70638 m
.39826 .70488 L
s
.39597 .71079 m .39572 .70859 L .39851 .70708 L .512 .324 .562 r
F
.39274 .71182 m .39572 .70859 L .39597 .71079 L .599 .386 .563 r
F
.3936 .70624 m .39572 .70859 L .39851 .70708 L .692 .759 .903 r
F
.127 .923 .03 r
.40852 .66193 m
.40852 .65972 L
s
.39145 .70693 m .39572 .70859 L .3936 .70624 L .692 .759 .903 r
F
0 g
.39249 .70961 m
.39572 .70859 L
s
.39518 .70302 m .39821 .70485 L .40037 .70298 L .692 .759 .903 r
F
.39332 .70402 m .39821 .70485 L .39518 .70302 L F
.38941 .70945 m .3893 .71229 L .39274 .71182 L F
.38713 .70938 m .3893 .71229 L .38941 .70945 L F
.38713 .70938 m .38588 .71219 L .3893 .71229 L F
.3917 .70913 m .39274 .71182 L .39597 .71079 L F
.38941 .70945 m .39274 .71182 L .3917 .70913 L F
0 g
.3893 .71229 m
.39274 .71182 L
s
.60097 .49651 m .59181 .48479 L .59121 .49624 L .683 .77 .917 r
F
.60097 .49651 m .60646 .48519 L .59181 .48479 L F
.38002 .7103 m .38246 .70931 L .38271 .71151 L .861 .577 .506 r
F
.38002 .7103 m .37976 .7081 L .38246 .70931 L F
.38296 .70592 m .38246 .70931 L .38476 .70672 L .692 .759 .903 r
F
.38296 .70592 m .37976 .7081 L .38246 .70931 L F
0 g
.38246 .70931 m
.38562 .70999 L
s
.57222 .60464 m .57071 .61376 L .57735 .60741 L .645 .732 .913 r
F
.57222 .60464 m .56301 .6096 L .57071 .61376 L F
0 g
.57071 .61376 m
.57976 .61663 L
s
.55744 .60064 m .56351 .60204 L .56326 .60582 L .927 .677 .54 r
F
.55744 .60064 m .55769 .59686 L .56351 .60204 L F
0 g
.56351 .60204 m
.56688 .60386 L
s
.38501 .70892 m .38588 .71219 L .38713 .70938 L .692 .759 .903 r
F
.38501 .70892 m .38271 .71151 L .38588 .71219 L F
0 g
.38588 .71219 m
.3893 .71229 L
s
.60869 .61599 m .61698 .60897 L .61674 .61276 L .499 .298 .538 r
F
.60268 .6089 m .60869 .61599 L .61674 .61276 L .645 .732 .913 r
F
0 g
.61221 .50594 m
.61222 .50951 L
s
.5965 .61009 m .60869 .61599 L .60268 .6089 L .645 .732 .913 r
F
0 g
.59942 .61778 m
.60869 .61599 L
s
.56895 .59358 m .56364 .60196 L .57281 .59702 L .645 .732 .913 r
F
.56895 .59358 m .55786 .59681 L .56364 .60196 L F
.37772 .70644 m .3795 .70589 L .37976 .7081 L .934 .633 .447 r
F
.127 .923 .03 r
.38033 .84026 m
.38272 1.00552 L
s
.37782 .80752 m
.37797 .8762 L
s
.37772 .70644 m .37746 .70424 L .3795 .70589 L .934 .633 .447 r
F
0 g
.3795 .70589 m
.38161 .70684 L
s
.38138 .70259 m .37955 .70586 L .38274 .70369 L .692 .759 .903 r
F
.38138 .70259 m .37752 .70422 L .37955 .70586 L F
.127 .923 .03 r
.37743 .63968 m
.37756 .69445 L
s
.61698 .60897 m .61723 .60519 L .6235 .60072 L .351 .177 .5 r
F
0 g
.61154 .60748 m
.61723 .60519 L
s
.127 .923 .03 r
.61746 1.67954 m
.6333 1.1562 L
s
.6333 1.1562 m
.65017 .59861 L
s
.39851 .70708 m .40043 .703 L .40069 .7052 L .389 .237 .551 r
F
.39877 .70928 m .39851 .70708 L .40069 .7052 L F
.39597 .71079 m .39851 .70708 L .39877 .70928 L .512 .324 .562 r
F
.39546 .70524 m .39851 .70708 L .40069 .7052 L .692 .759 .903 r
F
.3936 .70624 m .39851 .70708 L .39546 .70524 L F
0 g
.39572 .70859 m
.39851 .70708 L
s
.60845 .59911 m .6171 .6051 L .62334 .60065 L .645 .732 .913 r
F
.60311 .60126 m .6171 .6051 L .60845 .59911 L F
.39386 .70844 m .39597 .71079 L .39877 .70928 L .692 .759 .903 r
F
.127 .923 .03 r
.40851 .66413 m
.40852 .66193 L
s
.3917 .70913 m .39597 .71079 L .39386 .70844 L .692 .759 .903 r
F
0 g
.39274 .71182 m
.39597 .71079 L
s
.63147 .49274 m .61948 .48331 L .61999 .4879 L .861 .591 .528 r
F
.63197 .49733 m .63147 .49274 L .61999 .4879 L F
0 g
.63147 .49274 m
.64011 .49938 L
s
.40069 .7052 m .40043 .703 L .40183 .70086 L .183 .093 .512 r
F
0 g
.39826 .70488 m
.40043 .703 L
s
.127 .923 .03 r
.40154 8.82484 m
.60496 2.5029 L
s
.60496 2.5029 m
.66317 .69377 L
s
.39662 .70177 m .40037 .70298 L .40177 .70086 L .692 .759 .903 r
F
.39518 .70302 m .40037 .70298 L .39662 .70177 L F
.58136 .49754 m .57703 .48674 L .56314 .49089 L .683 .77 .917 r
F
.59121 .49624 m .57703 .48674 L .58136 .49754 L F
.38322 .70812 m .38271 .71151 L .38501 .70892 L .692 .759 .903 r
F
.38322 .70812 m .38002 .7103 L .38271 .71151 L F
0 g
.38271 .71151 m
.38588 .71219 L
s
.57261 .5049 m .56364 .49548 L .55159 .50156 L .683 .77 .917 r
F
.58187 .50213 m .56364 .49548 L .57261 .5049 L F
.38926 .7044 m .38915 .70724 L .39145 .70693 L .692 .759 .903 r
F
0 g
.38953 .70488 m
.38953 .70405 L
s
.38812 .70436 m .38687 .70717 L .38915 .70724 L .692 .759 .903 r
F
.59121 .49624 m .59181 .48479 L .57703 .48674 L .683 .77 .917 r
F
.3904 .70424 m .39145 .70693 L .3936 .70624 L .692 .759 .903 r
F
.37797 .70865 m .37976 .7081 L .38002 .7103 L .934 .633 .447 r
F
.37797 .70865 m .37772 .70644 L .37976 .7081 L F
.3816 .70481 m .37976 .7081 L .38296 .70592 L .692 .759 .903 r
F
.3816 .70481 m .37772 .70644 L .37976 .7081 L F
0 g
.37976 .7081 m
.38186 .70904 L
s
.38706 .70414 m .38687 .70717 L .38812 .70436 L .692 .759 .903 r
F
.38706 .70414 m .38476 .70672 L .38687 .70717 L F
.39877 .70928 m .40069 .7052 L .40095 .7074 L .389 .237 .551 r
F
.39572 .70744 m .39877 .70928 L .40095 .7074 L .692 .759 .903 r
F
.39386 .70844 m .39877 .70928 L .39572 .70744 L F
0 g
.39597 .71079 m
.39877 .70928 L
s
.39148 .7039 m .3936 .70624 L .39546 .70524 L .692 .759 .903 r
F
.59405 .59479 m .59696 .60245 L .60311 .60126 L .645 .732 .913 r
F
.40069 .7052 m .40183 .70086 L .40209 .70307 L .183 .093 .512 r
F
.40095 .7074 m .40069 .7052 L .40209 .70307 L F
.39691 .70398 m .40069 .7052 L .40209 .70307 L .692 .759 .903 r
F
.39546 .70524 m .40069 .7052 L .39691 .70398 L F
0 g
.39851 .70708 m
.40069 .7052 L
s
.55719 .60442 m .56326 .60582 L .56301 .6096 L .927 .677 .54 r
F
.55719 .60442 m .55744 .60064 L .56326 .60582 L F
.56859 .5974 m .56326 .60582 L .57247 .60085 L .645 .732 .913 r
F
.56859 .5974 m .55744 .60064 L .56326 .60582 L F
0 g
.56326 .60582 m
.56664 .60765 L
s
.127 .923 .03 r
.55853 .54264 m
.5586 .53896 L
s
.38524 .70097 m .38274 .70369 L .38592 .70152 L .692 .759 .903 r
F
.38524 .70097 m .38138 .70259 L .38274 .70369 L F
.37647 .70445 m .37746 .70424 L .37772 .70644 L .975 .673 .306 r
F
.127 .923 .03 r
.37769 .7507 m
.37782 .80752 L
s
.37647 .70445 m .37621 .70225 L .37746 .70424 L .975 .673 .306 r
F
0 g
.37746 .70424 m
.37934 .70576 L
s
.38055 .70127 m .37752 .70422 L .38138 .70259 L .692 .759 .903 r
F
.38055 .70127 m .37628 .70224 L .37752 .70422 L F
.60148 .5011 m .59231 .48938 L .59171 .50083 L .683 .77 .917 r
F
.60148 .5011 m .60697 .48978 L .59231 .48938 L F
.61698 .60897 m .6235 .60072 L .62326 .6045 L .351 .177 .5 r
F
.61674 .61276 m .61698 .60897 L .62326 .6045 L F
.60829 .60296 m .61698 .60897 L .62326 .6045 L .645 .732 .913 r
F
.60293 .60512 m .61698 .60897 L .60829 .60296 L F
0 g
.6113 .61126 m
.61698 .60897 L
s
.38616 .70373 m .38476 .70672 L .38706 .70414 L .692 .759 .903 r
F
.38616 .70373 m .38296 .70592 L .38476 .70672 L F
.39662 .70177 m .40177 .70086 L .39755 .70035 L F
.39286 .70056 m .39662 .70177 L .39755 .70035 L F
.38951 .7066 m .38941 .70945 L .3917 .70913 L F
.38837 .70657 m .38941 .70945 L .38951 .7066 L F
.38837 .70657 m .38713 .70938 L .38941 .70945 L F
.39066 .70644 m .3917 .70913 L .39386 .70844 L F
.38951 .7066 m .3917 .70913 L .39066 .70644 L F
.39241 .70339 m .39546 .70524 L .39691 .70398 L F
.38185 .70702 m .38002 .7103 L .38322 .70812 L F
.38185 .70702 m .37797 .70865 L .38002 .7103 L F
0 g
.38002 .7103 m
.38271 .71151 L
s
.56314 .49089 m .55059 .49238 L .55109 .49697 L .521 .343 .58 r
F
.56314 .49089 m .56264 .4863 L .55059 .49238 L F
0 g
.5412 .49997 m
.55059 .49238 L
s
.40209 .70307 m .40183 .70086 L .40237 .69863 L 0 0 .378 r
F
0 g
.40043 .703 m
.40183 .70086 L
s
.39755 .70035 m .40177 .70086 L .4023 .69863 L .692 .759 .903 r
F
.38732 .70634 m .38713 .70938 L .38837 .70657 L F
.38732 .70634 m .38501 .70892 L .38713 .70938 L F
.63197 .49733 m .61999 .4879 L .6205 .49249 L .861 .591 .528 r
F
0 g
.63197 .49733 m
.64062 .50396 L
s
.39174 .7061 m .39386 .70844 L .39572 .70744 L .692 .759 .903 r
F
.39066 .70644 m .39386 .70844 L .39174 .7061 L F
.59053 .59869 m .59017 .60645 L .59675 .60631 L .645 .732 .913 r
F
.58187 .50213 m .57753 .49133 L .56364 .49548 L .683 .77 .917 r
F
.59171 .50083 m .57753 .49133 L .58187 .50213 L F
.40095 .7074 m .40209 .70307 L .40235 .70527 L .183 .093 .512 r
F
.39717 .70619 m .40095 .7074 L .40235 .70527 L .692 .759 .903 r
F
.39572 .70744 m .40095 .7074 L .39717 .70619 L F
0 g
.39877 .70928 m
.40095 .7074 L
s
.38548 .70318 m .38296 .70592 L .38616 .70373 L .692 .759 .903 r
F
.38548 .70318 m .3816 .70481 L .38296 .70592 L F
.38483 .70031 m .38138 .70259 L .38524 .70097 L F
.38483 .70031 m .38055 .70127 L .38138 .70259 L F
.37672 .70666 m .37772 .70644 L .37797 .70865 L .975 .673 .306 r
F
.37672 .70666 m .37647 .70445 L .37772 .70644 L F
.38077 .70349 m .37772 .70644 L .3816 .70481 L .692 .759 .903 r
F
.38077 .70349 m .37647 .70445 L .37772 .70644 L F
0 g
.37772 .70644 m
.3796 .70796 L
s
.38642 .70594 m .38501 .70892 L .38732 .70634 L .692 .759 .903 r
F
.38642 .70594 m .38322 .70812 L .38501 .70892 L F
.59171 .50083 m .59231 .48938 L .57753 .49133 L .683 .77 .917 r
F
.59713 .5942 m .60311 .60126 L .60845 .59911 L .645 .732 .913 r
F
.59405 .59479 m .60311 .60126 L .59713 .5942 L F
.39691 .70398 m .40209 .70307 L .39785 .70256 L .692 .759 .903 r
F
.39314 .70277 m .39691 .70398 L .39785 .70256 L F
.58425 .59728 m .5776 .60363 L .58364 .60554 L .645 .732 .913 r
F
.59382 .59862 m .59675 .60631 L .60293 .60512 L F
.59053 .59869 m .59675 .60631 L .59382 .59862 L F
.39755 .70035 m .4023 .69863 L .3979 .69887 L .692 .759 .903 r
F
.39333 .69985 m .39755 .70035 L .3979 .69887 L F
.39286 .70056 m .39755 .70035 L .39333 .69985 L F
0 g
.39296 .70111 m
.39297 .70021 L
s
.39267 .7056 m .39572 .70744 L .39717 .70619 L .692 .759 .903 r
F
.39174 .7061 m .39572 .70744 L .39267 .7056 L F
.56834 .60118 m .56301 .6096 L .57222 .60464 L .645 .732 .913 r
F
.56834 .60118 m .55719 .60442 L .56301 .6096 L F
0 g
.56301 .6096 m
.57071 .61376 L
s
.127 .923 .03 r
.55846 .54633 m
.55853 .54264 L
s
.40209 .70307 m .40237 .69863 L .40263 .70083 L 0 0 .378 r
F
.40235 .70527 m .40209 .70307 L .40263 .70083 L F
.39785 .70256 m .40209 .70307 L .40263 .70083 L .692 .759 .903 r
F
0 g
.40069 .7052 m
.40209 .70307 L
s
.61674 .61276 m .62326 .6045 L .62301 .60829 L .351 .177 .5 r
F
.60805 .60674 m .61674 .61276 L .62301 .60829 L .645 .732 .913 r
F
.60268 .6089 m .61674 .61276 L .60805 .60674 L F
0 g
.60869 .61599 m
.61674 .61276 L
s
.3761 .70227 m .37621 .70225 L .37647 .70445 L .764 .547 0 r
F
.3761 .70227 m .37584 .70007 L .37621 .70225 L F
0 g
.37621 .70225 m
.37746 .70423 L
s
.38031 .69982 m .37628 .70224 L .38055 .70127 L .692 .759 .903 r
F
.38031 .69982 m .37591 .70006 L .37628 .70224 L F
.38574 .70538 m .38322 .70812 L .38642 .70594 L F
.38574 .70538 m .38185 .70702 L .38322 .70812 L F
.38506 .70252 m .3816 .70481 L .38548 .70318 L F
.38506 .70252 m .38077 .70349 L .3816 .70481 L F
.38102 .70569 m .37797 .70865 L .38185 .70702 L F
.38102 .70569 m .37672 .70666 L .37797 .70865 L F
0 g
.37797 .70865 m
.38002 .7103 L
s
.38471 .69959 m .38055 .70127 L .38483 .70031 L .692 .759 .903 r
F
.38471 .69959 m .38031 .69982 L .38055 .70127 L F
.39333 .69985 m .3979 .69887 L .39351 .69911 L F
.39717 .70619 m .40235 .70527 L .39811 .70476 L F
.39339 .70497 m .39717 .70619 L .39811 .70476 L F
.39267 .7056 m .39717 .70619 L .39339 .70497 L F
0 g
.38953 .70488 m
.39113 .70467 L
s
.38953 .70488 m
.38953 .70488 L
s
.38794 .70462 m
.38953 .70488 L
s
.40263 .70083 m .40237 .69863 L .402 .69644 L .762 .545 0 r
F
.127 .923 .03 r
.40836 .76734 m
.40851 .66413 L
s
.39669 8.82359 m
.40836 .76734 L
s
0 g
.40183 .70086 m
.40233 .69878 L
s
.3979 .69887 m .4023 .69863 L .40194 .69646 L .692 .759 .903 r
F
.39785 .70256 m .40263 .70083 L .39821 .70107 L F
.39361 .70206 m .39785 .70256 L .39821 .70107 L F
.39314 .70277 m .39785 .70256 L .39361 .70206 L F
.56364 .49548 m .55109 .49697 L .55159 .50156 L .521 .343 .58 r
F
0 g
.5422 .50915 m
.55159 .50156 L
s
.56364 .49548 m .56314 .49089 L .55109 .49697 L .521 .343 .58 r
F
0 g
.5417 .50456 m
.55109 .49697 L
s
.127 .923 .03 r
.5586 .53896 m
.55978 .4776 L
s
.61999 .4879 m .61948 .48331 L .60596 .4806 L .795 .541 .554 r
F
0 g
.61948 .48331 m
.63096 .48815 L
s
.3979 .69887 m .40194 .69646 L .39766 .69742 L .692 .759 .903 r
F
.39351 .69911 m .3979 .69887 L .39766 .69742 L F
.40235 .70527 m .40263 .70083 L .40288 .70304 L 0 0 .378 r
F
.39811 .70476 m .40235 .70527 L .40288 .70304 L .692 .759 .903 r
F
0 g
.40095 .7074 m
.40235 .70527 L
s
.5539 .5948 m .55769 .59686 L .55744 .60064 L .99 .751 .474 r
F
.5539 .5948 m .55415 .59101 L .55769 .59686 L F
0 g
.55769 .59686 m
.56083 .59966 L
s
.5666 .58971 m .55786 .59681 L .56895 .59358 L .645 .732 .913 r
F
.5666 .58971 m .55434 .59099 L .55786 .59681 L F
.38962 .70375 m .38951 .7066 L .39066 .70644 L .692 .759 .903 r
F
.38962 .70375 m .38837 .70657 L .38951 .7066 L F
.38962 .70375 m .39066 .70644 L .39174 .7061 L F
0 g
.39113 .70467 m
.39216 .70423 L
s
.59692 .59802 m .60293 .60512 L .60829 .60296 L .645 .732 .913 r
F
.59382 .59862 m .60293 .60512 L .59692 .59802 L F
.37635 .70447 m .37647 .70445 L .37672 .70666 L .764 .547 0 r
F
.37635 .70447 m .3761 .70227 L .37647 .70445 L F
.38052 .70203 m .37647 .70445 L .38077 .70349 L .692 .759 .903 r
F
.38052 .70203 m .3761 .70227 L .37647 .70445 L F
0 g
.37647 .70445 m
.37771 .70644 L
s
.39351 .69911 m .39766 .69742 L .39338 .69838 L .692 .759 .903 r
F
.38962 .70375 m .38732 .70634 L .38837 .70657 L F
0 g
.38695 .70414 m
.38794 .70462 L
s
.62326 .6045 m .6235 .60072 L .62757 .59532 L .082 0 .405 r
F
0 g
.61883 .60405 m
.6235 .60072 L
s
.61261 .59615 m .62334 .60065 L .62739 .59528 L .645 .732 .913 r
F
.60845 .59911 m .62334 .60065 L .61261 .59615 L F
.38962 .70375 m .39174 .7061 L .39267 .7056 L .692 .759 .903 r
F
.584 .60106 m .58339 .60932 L .58702 .60201 L .645 .732 .913 r
F
.584 .60106 m .57735 .60741 L .58339 .60932 L F
.59358 .6024 m .5965 .61009 L .60268 .6089 L F
.59029 .60247 m .5965 .61009 L .59358 .6024 L F
.38532 .70472 m .38185 .70702 L .38574 .70538 L .692 .759 .903 r
F
.38532 .70472 m .38102 .70569 L .38185 .70702 L F
.38962 .70375 m .38642 .70594 L .38732 .70634 L F
0 g
.38628 .70354 m
.38695 .70414 L
s
.38494 .70179 m .38077 .70349 L .38506 .70252 L .692 .759 .903 r
F
.38494 .70179 m .38052 .70203 L .38077 .70349 L F
.39361 .70206 m .39821 .70107 L .39378 .70131 L F
.38488 .69884 m .38031 .69982 L .38471 .69959 L F
.38962 .70375 m .39267 .7056 L .39339 .70497 L F
0 g
.39216 .70423 m
.39287 .70366 L
s
.39287 .70366 m
.39331 .70298 L
s
.58005 .59036 m .56895 .59358 L .57281 .59702 L .645 .732 .913 r
F
0 g
.3859 .70284 m
.38628 .70354 L
s
.40263 .70083 m .402 .69644 L .40226 .69865 L .762 .545 0 r
F
.40288 .70304 m .40263 .70083 L .40226 .69865 L F
0 g
.40209 .70307 m
.40259 .70098 L
s
.39821 .70107 m .40263 .70083 L .40226 .69865 L .692 .759 .903 r
F
.39338 .69838 m .39683 .6961 L .39297 .69772 L F
0 g
.39297 .69772 m
.39309 .64585 L
s
.39297 .69969 m
.39297 .69807 L
s
.39338 .69838 m .39766 .69742 L .39683 .6961 L .692 .759 .903 r
F
.39811 .70476 m .40288 .70304 L .39846 .70327 L F
.39386 .70426 m .39811 .70476 L .39846 .70327 L F
.39339 .70497 m .39811 .70476 L .39386 .70426 L F
.38066 .69834 m .37591 .70006 L .38031 .69982 L F
.38488 .69884 m .38066 .69834 L .38031 .69982 L F
.5998 .59313 m .60845 .59911 L .61261 .59615 L .645 .732 .913 r
F
.59713 .5942 m .60845 .59911 L .5998 .59313 L F
.38962 .70375 m .38574 .70538 L .38642 .70594 L .692 .759 .903 r
F
.39821 .70107 m .40226 .69865 L .39796 .69961 L F
.39378 .70131 m .39821 .70107 L .39796 .69961 L F
.38066 .69834 m .37644 .69784 L .37591 .70006 L F
.37663 .70003 m .37584 .70007 L .3761 .70227 L 0 0 .377 r
F
0 g
.37617 .70198 m
.37621 .70225 L
s
.37663 .70003 m .37638 .69783 L .37584 .70007 L 0 0 .377 r
F
.38962 .70375 m .39339 .70497 L .39386 .70426 L .692 .759 .903 r
F
.38078 .70423 m .37672 .70666 L .38102 .70569 L F
.38078 .70423 m .37635 .70447 L .37672 .70666 L F
0 g
.37672 .70666 m
.37797 .70865 L
s
.38535 .69814 m .38066 .69834 L .38488 .69884 L .692 .759 .903 r
F
.39378 .70131 m .39796 .69961 L .39366 .70058 L F
0 g
.39331 .70298 m
.39342 .70216 L
s
.39766 .69742 m .4007 .69448 L .39683 .6961 L .692 .759 .903 r
F
.39766 .69742 m .40194 .69646 L .4007 .69448 L F
0 g
.38584 .70203 m
.3859 .70284 L
s
.39297 .69772 m .39548 .695 L .39229 .69718 L .692 .759 .903 r
F
.39297 .69772 m .39683 .6961 L .39548 .695 L F
.38962 .70375 m .38532 .70472 L .38574 .70538 L F
.3852 .70399 m .38102 .70569 L .38532 .70472 L F
.3852 .70399 m .38078 .70423 L .38102 .70569 L F
.39386 .70426 m .39846 .70327 L .39404 .70351 L F
.38962 .70375 m .39386 .70426 L .39404 .70351 L F
.38512 .70104 m .38052 .70203 L .38494 .70179 L F
.40226 .69865 m .402 .69644 L .40075 .69445 L .975 .673 .305 r
F
0 g
.402 .69644 m
.40237 .69863 L
s
.55366 .59858 m .55744 .60064 L .55719 .60442 L .99 .751 .474 r
F
.55366 .59858 m .5539 .5948 L .55744 .60064 L F
.56623 .5935 m .55744 .60064 L .56859 .5974 L .645 .732 .913 r
F
.56623 .5935 m .5539 .5948 L .55744 .60064 L F
0 g
.55744 .60064 m
.56058 .60344 L
s
.58144 .59967 m .57735 .60741 L .584 .60106 L .645 .732 .913 r
F
.58144 .59967 m .57222 .60464 L .57735 .60741 L F
.61999 .4879 m .60596 .4806 L .60646 .48519 L .795 .541 .554 r
F
.6205 .49249 m .61999 .4879 L .60646 .48519 L F
0 g
.61999 .4879 m
.63147 .49274 L
s
.38535 .69814 m .38159 .69693 L .38066 .69834 L .692 .759 .903 r
F
.38607 .69751 m .38159 .69693 L .38535 .69814 L F
.59667 .6018 m .60268 .6089 L .60805 .60674 L .645 .732 .913 r
F
.59358 .6024 m .60268 .6089 L .59667 .6018 L F
.40288 .70304 m .40226 .69865 L .40252 .70085 L .762 .545 0 r
F
.39846 .70327 m .40288 .70304 L .40252 .70085 L .692 .759 .903 r
F
0 g
.40235 .70527 m
.40288 .70304 L
s
.39366 .70058 m .39713 .69829 L .39324 .69992 L .692 .759 .903 r
F
.39366 .70058 m .39796 .69961 L .39713 .69829 L F
.38088 .70054 m .3761 .70227 L .38052 .70203 L F
.38512 .70104 m .38088 .70054 L .38052 .70203 L F
.62326 .6045 m .62757 .59532 L .62733 .59911 L .082 0 .405 r
F
.62301 .60829 m .62326 .6045 L .62733 .59911 L F
.61247 .59998 m .62326 .6045 L .62733 .59911 L .645 .732 .913 r
F
.60829 .60296 m .62326 .6045 L .61247 .59998 L F
0 g
.61859 .60783 m
.62326 .6045 L
s
.39229 .69718 m .39369 .6942 L .3914 .69677 L .692 .759 .903 r
F
.39229 .69718 m .39548 .695 L .39369 .6942 L F
.38159 .69693 m .37644 .69784 L .38066 .69834 L F
.39846 .70327 m .40252 .70085 L .39822 .70182 L F
.39404 .70351 m .39846 .70327 L .39822 .70182 L F
.38962 .70375 m .3852 .70399 L .38532 .70472 L F
.37689 .70224 m .3761 .70227 L .37635 .70447 L 0 0 .377 r
F
0 g
.37642 .70418 m
.37647 .70445 L
s
.38088 .70054 m .37663 .70003 L .3761 .70227 L .692 .759 .903 r
F
.37689 .70224 m .37663 .70003 L .3761 .70227 L 0 0 .377 r
F
.38607 .69751 m .38303 .69568 L .38159 .69693 L .692 .759 .903 r
F
.387 .69701 m .38303 .69568 L .38607 .69751 L F
.39404 .70351 m .39822 .70182 L .39392 .70279 L F
.38962 .70375 m .39404 .70351 L .39392 .70279 L F
.38559 .70033 m .38088 .70054 L .38512 .70104 L F
.39796 .69961 m .40101 .69666 L .39713 .69829 L F
.39796 .69961 m .40226 .69865 L .40101 .69666 L F
.57974 .59416 m .56859 .5974 L .57247 .60085 L .645 .732 .913 r
F
.3914 .69677 m .39159 .69375 L .39035 .69655 L .692 .759 .903 r
F
.3914 .69677 m .39369 .6942 L .39159 .69375 L F
.5996 .59694 m .60829 .60296 L .61247 .59998 L .645 .732 .913 r
F
.59692 .59802 m .60829 .60296 L .5996 .59694 L F
.39683 .6961 m .39866 .69283 L .39548 .695 L .692 .759 .903 r
F
.39683 .6961 m .4007 .69448 L .39866 .69283 L F
.57703 .48674 m .56264 .4863 L .56314 .49089 L .605 .403 .581 r
F
.57703 .48674 m .57653 .48215 L .56264 .4863 L F
0 g
.55059 .49238 m
.56264 .4863 L
s
.39324 .69992 m .39577 .69718 L .39256 .69937 L .692 .759 .903 r
F
.39324 .69992 m .39713 .69829 L .39577 .69718 L F
.38962 .70375 m .38538 .70325 L .3852 .70399 L F
.38962 .70375 m .38584 .70254 L .38538 .70325 L F
.38962 .70375 m .38657 .70191 L .38584 .70254 L F
0 g
.38584 .70203 m
.38637 .70099 L
s
.38962 .70375 m .3875 .70141 L .38657 .70191 L .692 .759 .903 r
F
.38962 .70375 m .38858 .70107 L .3875 .70141 L F
.38962 .70375 m .38973 .70091 L .38858 .70107 L F
.38962 .70375 m .39087 .70094 L .38973 .70091 L F
.38962 .70375 m .39192 .70117 L .39087 .70094 L F
.38962 .70375 m .39282 .70157 L .39192 .70117 L F
.38962 .70375 m .3935 .70212 L .39282 .70157 L F
0 g
.39296 .70111 m
.39335 .702 L
s
.39342 .70216 m
.39342 .70216 L
s
.38962 .70375 m .39392 .70279 L .3935 .70212 L .692 .759 .903 r
F
.387 .69701 m .38489 .69468 L .38303 .69568 L F
.38807 .69667 m .38489 .69468 L .387 .69701 L F
.39035 .69655 m .38932 .69368 L .38921 .69651 L F
.39035 .69655 m .39159 .69375 L .38932 .69368 L F
.38538 .70325 m .38078 .70423 L .3852 .70399 L F
.40226 .69865 m .40075 .69445 L .40101 .69666 L .975 .673 .305 r
F
.40252 .70085 m .40226 .69865 L .40101 .69666 L F
0 g
.40226 .69865 m
.40263 .70083 L
s
.3919 .70029 m
.39296 .70111 L
s
.39296 .70111 m
.39296 .70111 L
s
.38807 .69667 m .38703 .694 L .38489 .69468 L .692 .759 .903 r
F
.38921 .69651 m .38703 .694 L .38807 .69667 L F
0 g
.38637 .70099 m
.38637 .70099 L
s
.38637 .70099 m
.3875 .70021 L
s
.38921 .69651 m .38932 .69368 L .38703 .694 L .692 .759 .903 r
F
.38559 .70033 m .38181 .69912 L .38088 .70054 L F
.38631 .69971 m .38181 .69912 L .38559 .70033 L F
.38159 .69693 m .37783 .69572 L .37644 .69784 L F
.37803 .6979 m .37638 .69783 L .37663 .70003 L .182 .092 .511 r
F
.37803 .6979 m .37778 .6957 L .37638 .69783 L F
0 g
.37584 .70007 m
.37638 .69783 L
s
.127 .923 .03 r
.37756 .69445 m
.37756 .69664 L
s
.39392 .70279 m .39738 .70049 L .3935 .70212 L .692 .759 .903 r
F
.39392 .70279 m .39822 .70182 L .39738 .70049 L F
.38113 .70274 m .37635 .70447 L .38078 .70423 L F
.38538 .70325 m .38113 .70274 L .38078 .70423 L F
.39256 .69937 m .39397 .69638 L .39167 .69896 L F
.39256 .69937 m .39577 .69718 L .39397 .69638 L F
.38181 .69912 m .37663 .70003 L .38088 .70054 L F
.38113 .70274 m .37689 .70224 L .37635 .70447 L F
0 g
.37635 .70447 m
.37672 .70666 L
s
.38303 .69568 m .37783 .69572 L .38159 .69693 L .692 .759 .903 r
F
.38631 .69971 m .38326 .69786 L .38181 .69912 L F
.38724 .6992 m .38326 .69786 L .38631 .69971 L F
.56599 .59729 m .55719 .60442 L .56834 .60118 L .645 .732 .913 r
F
.56599 .59729 m .55366 .59858 L .55719 .60442 L F
0 g
.55719 .60442 m
.56301 .6096 L
s
.38584 .70254 m .38113 .70274 L .38538 .70325 L .692 .759 .903 r
F
.39822 .70182 m .40127 .69886 L .39738 .70049 L F
.39822 .70182 m .40252 .70085 L .40127 .69886 L F
0 g
.39081 .69991 m
.3919 .70029 L
s
.3875 .70021 m
.38861 .69987 L
s
.39167 .69896 m .39186 .69592 L .39061 .69874 L .692 .759 .903 r
F
.39167 .69896 m .39397 .69638 L .39186 .69592 L F
.40101 .69666 m .40075 .69445 L .39871 .6928 L .934 .633 .447 r
F
0 g
.40075 .69445 m
.402 .69644 L
s
.39713 .69829 m .39897 .695 L .39577 .69718 L .692 .759 .903 r
F
.39713 .69829 m .40101 .69666 L .39897 .695 L F
.39548 .695 m .39598 .69163 L .39369 .6942 L F
.39548 .695 m .39866 .69283 L .39598 .69163 L F
.3935 .70212 m .39602 .69939 L .39282 .70157 L F
.3935 .70212 m .39738 .70049 L .39602 .69939 L F
.62301 .60829 m .62733 .59911 L .62708 .60289 L .082 0 .405 r
F
.61223 .60376 m .62301 .60829 L .62708 .60289 L .645 .732 .913 r
F
.60805 .60674 m .62301 .60829 L .61223 .60376 L F
0 g
.61674 .61276 m
.62301 .60829 L
s
.57887 .58842 m .56895 .59358 L .58005 .59036 L .645 .732 .913 r
F
.57887 .58842 m .5666 .58971 L .56895 .59358 L F
.38724 .6992 m .38512 .69686 L .38326 .69786 L .692 .759 .903 r
F
.38832 .69886 m .38512 .69686 L .38724 .6992 L F
0 g
.38972 .69978 m
.39081 .69991 L
s
.6205 .49249 m .60646 .48519 L .60697 .48978 L .795 .541 .554 r
F
0 g
.6205 .49249 m
.63197 .49733 L
s
.61205 .43828 m
.6122 .50236 L
s
.38861 .69987 m
.38972 .69978 L
s
.60646 .48519 m .60596 .4806 L .5913 .4802 L .734 .496 .569 r
F
0 g
.60596 .4806 m
.61948 .48331 L
s
.39061 .69874 m .38958 .69585 L .38947 .6987 L .692 .759 .903 r
F
.39061 .69874 m .39186 .69592 L .38958 .69585 L F
.40252 .70085 m .40101 .69666 L .40127 .69886 L .975 .673 .305 r
F
0 g
.40252 .70085 m
.40288 .70304 L
s
.61261 .59615 m .62739 .59528 L .61531 .59257 L .645 .732 .913 r
F
.60188 .59164 m .61261 .59615 L .61531 .59257 L F
.5998 .59313 m .61261 .59615 L .60188 .59164 L F
.38832 .69886 m .38728 .69617 L .38512 .69686 L .692 .759 .903 r
F
.38947 .6987 m .38728 .69617 L .38832 .69886 L F
.38947 .6987 m .38958 .69585 L .38728 .69617 L F
.38584 .70254 m .38207 .70132 L .38113 .70274 L F
.38657 .70191 m .38207 .70132 L .38584 .70254 L F
.37829 .7001 m .37663 .70003 L .37689 .70224 L .182 .092 .511 r
F
.38181 .69912 m .37803 .6979 L .37663 .70003 L .692 .759 .903 r
F
.37829 .7001 m .37803 .6979 L .37663 .70003 L .182 .092 .511 r
F
0 g
.3761 .70227 m
.37663 .70003 L
s
.127 .923 .03 r
.37756 .69664 m
.37757 .69883 L
s
.5795 .59794 m .57222 .60464 L .58144 .59967 L .645 .732 .913 r
F
.5795 .59794 m .56834 .60118 L .57222 .60464 L F
.39282 .70157 m .39423 .69858 L .39192 .70117 L .692 .759 .903 r
F
.39282 .70157 m .39602 .69939 L .39423 .69858 L F
.59935 .60072 m .60805 .60674 L .61223 .60376 L .645 .732 .913 r
F
.59667 .6018 m .60805 .60674 L .59935 .60072 L F
.38303 .69568 m .38 .69384 L .37783 .69572 L .692 .759 .903 r
F
.38489 .69468 m .38 .69384 L .38303 .69568 L F
.38207 .70132 m .37689 .70224 L .38113 .70274 L F
.38326 .69786 m .37803 .6979 L .38181 .69912 L F
.38657 .70191 m .38352 .70006 L .38207 .70132 L F
.3875 .70141 m .38352 .70006 L .38657 .70191 L F
.39369 .6942 m .39283 .69095 L .39159 .69375 L F
.39369 .6942 m .39598 .69163 L .39283 .69095 L F
.57753 .49133 m .56314 .49089 L .56364 .49548 L .605 .403 .581 r
F
0 g
.55159 .50156 m
.56364 .49548 L
s
.57753 .49133 m .57703 .48674 L .56314 .49089 L .605 .403 .581 r
F
0 g
.55109 .49697 m
.56314 .49089 L
s
.39192 .70117 m .39211 .69813 L .39087 .70094 L .692 .759 .903 r
F
.39192 .70117 m .39423 .69858 L .39211 .69813 L F
.40101 .69666 m .39871 .6928 L .39897 .695 L .934 .633 .447 r
F
.40127 .69886 m .40101 .69666 L .39897 .695 L F
0 g
.40101 .69666 m
.40226 .69865 L
s
.39738 .70049 m .39923 .6972 L .39602 .69939 L .692 .759 .903 r
F
.39738 .70049 m .40127 .69886 L .39923 .6972 L F
.39577 .69718 m .39627 .69379 L .39397 .69638 L F
.39577 .69718 m .39897 .695 L .39627 .69379 L F
.38021 .69602 m .37778 .6957 L .37803 .6979 L .388 .236 .551 r
F
.38021 .69602 m .37995 .69381 L .37778 .6957 L F
0 g
.37638 .69783 m
.37778 .6957 L
s
.127 .923 .03 r
.37806 .68286 m
.37822 .69419 L
s
.37743 .63968 m
.37806 .68286 L
s
.3875 .70141 m .38538 .69906 L .38352 .70006 L .692 .759 .903 r
F
.38858 .70107 m .38538 .69906 L .3875 .70141 L F
.39087 .70094 m .38983 .69806 L .38973 .70091 L F
.39087 .70094 m .39211 .69813 L .38983 .69806 L F
.38489 .69468 m .38278 .69234 L .38 .69384 L F
.38703 .694 m .38278 .69234 L .38489 .69468 L F
.38858 .70107 m .38754 .69838 L .38538 .69906 L F
.38973 .70091 m .38754 .69838 L .38858 .70107 L F
.38973 .70091 m .38983 .69806 L .38754 .69838 L F
.39159 .69375 m .38942 .69084 L .38932 .69368 L F
.39159 .69375 m .39283 .69095 L .38942 .69084 L F
.38207 .70132 m .37829 .7001 L .37689 .70224 L F
0 g
.37635 .70447 m
.37689 .70224 L
s
.127 .923 .03 r
.37757 .69883 m
.37769 .7507 L
s
.59181 .48479 m .57653 .48215 L .57703 .48674 L .673 .452 .578 r
F
.59181 .48479 m .5913 .4802 L .57653 .48215 L F
0 g
.56264 .4863 m
.57653 .48215 L
s
.39897 .695 m .39871 .6928 L .39602 .69159 L .861 .577 .505 r
F
0 g
.39871 .6928 m
.40075 .69445 L
s
.55289 .58869 m .55415 .59101 L .5539 .5948 L .924 .749 .264 r
F
.55289 .58869 m .55313 .5849 L .55415 .59101 L F
0 g
.55415 .59101 m
.55629 .59455 L
s
.56593 .58565 m .55434 .59099 L .5666 .58971 L .645 .732 .913 r
F
.56593 .58565 m .55332 .58491 L .55434 .59099 L F
.38703 .694 m .386 .69132 L .38278 .69234 L .692 .759 .903 r
F
.38932 .69368 m .386 .69132 L .38703 .694 L F
.38326 .69786 m .38021 .69602 L .37803 .6979 L F
.38512 .69686 m .38021 .69602 L .38326 .69786 L F
.38932 .69368 m .38942 .69084 L .386 .69132 L F
.57857 .59221 m .56859 .5974 L .57974 .59416 L .645 .732 .913 r
F
.57857 .59221 m .56623 .5935 L .56859 .5974 L F
.38352 .70006 m .37829 .7001 L .38207 .70132 L .692 .759 .903 r
F
.62733 .59911 m .62757 .59532 L .62916 .58937 L 0 0 .149 r
F
0 g
.6246 .59927 m
.62757 .59532 L
s
.61247 .59998 m .62733 .59911 L .61519 .59638 L .645 .732 .913 r
F
.60169 .59545 m .61247 .59998 L .61519 .59638 L F
.5996 .59694 m .61247 .59998 L .60169 .59545 L F
.61531 .59257 m .62739 .59528 L .62897 .58935 L F
.39397 .69638 m .3931 .69311 L .39186 .69592 L .692 .759 .903 r
F
.39397 .69638 m .39627 .69379 L .3931 .69311 L F
.60646 .48519 m .5913 .4802 L .59181 .48479 L .734 .496 .569 r
F
0 g
.57653 .48215 m
.5913 .4802 L
s
.5913 .4802 m
.60596 .4806 L
s
.40127 .69886 m .39897 .695 L .39923 .6972 L .934 .633 .447 r
F
0 g
.40127 .69886 m
.40252 .70085 L
s
.59317 .59282 m .59389 .59225 L .59389 .59249 L .356 .178 .497 r
F
.59406 .59225 m .5996 .59694 L .60169 .59545 L .645 .732 .913 r
F
.5909 .59092 m .59365 .59282 L .59406 .59225 L F
.59365 .59282 m .5996 .59694 L .59406 .59225 L F
.59389 .59225 m .59433 .59156 L .59433 .59188 L .076 0 .415 r
F
.59365 .59282 m .59692 .59802 L .5996 .59694 L .645 .732 .913 r
F
.59317 .59282 m .59389 .59249 L .59317 .59298 L .356 .178 .497 r
F
.5909 .59092 m .59313 .59355 L .59365 .59282 L .645 .732 .913 r
F
.59313 .59355 m .59692 .59802 L .59365 .59282 L F
.59284 .59321 m .59382 .59862 L .59692 .59802 L F
.59389 .59248 m .59433 .59545 L .59392 .59602 L .076 0 .415 r
F
.59389 .59225 m .59392 .59245 L .59389 .59248 L F
.59392 .59245 m .59433 .59545 L .59389 .59248 L F
.59392 .59245 m .59433 .59188 L .59433 .59545 L F
.59389 .59225 m .59433 .59188 L .59392 .59245 L F
.59392 .59602 m .59433 .59545 L .59445 .65088 L F
.59436 .59169 m .60169 .59545 L .60304 .59365 L .645 .732 .913 r
F
.5909 .59092 m .59425 .59233 L .59436 .59169 L F
.59425 .59233 m .60169 .59545 L .59436 .59169 L F
.59433 .59156 m .59445 .59074 L .59445 .59113 L 0 0 .146 r
F
.59434 .59182 m .59445 .59113 L .59446 .5947 L F
.59433 .59156 m .59445 .59113 L .59434 .59182 L F
.59421 .59619 m .59935 .60072 L .60144 .59923 L .645 .732 .913 r
F
.59214 .59326 m .59221 .59689 L .59215 .59692 L .516 .301 .527 r
F
.59199 .5938 m .59382 .59862 L .59284 .59321 L .645 .732 .913 r
F
.59214 .59326 m .59317 .59282 L .59318 .59655 L .516 .301 .527 r
F
.59328 .59652 m .59251 .59689 L .59368 .5968 L .645 .732 .913 r
F
.59244 .59681 m .59251 .59689 L .59328 .59652 L F
.59258 .59697 m .59271 .5977 L .59293 .59739 L F
.59271 .5977 m .59358 .6024 L .59293 .59739 L F
.59174 .59755 m .59358 .6024 L .59258 .59697 L F
.59221 .59689 m .59318 .59655 L .59329 .65214 L .516 .301 .527 r
F
.59214 .59326 m .59318 .59655 L .59221 .59689 L F
.59054 .59347 m .59214 .59326 L .59215 .59692 L .641 .4 .539 r
F
.59065 .5947 m .59244 .59681 L .59328 .59652 L .645 .732 .913 r
F
.59065 .5947 m .59328 .59652 L .59421 .59619 L F
.59433 .59545 m .59457 .65006 L .59445 .65088 L 0 0 .146 r
F
.59433 .59156 m .59434 .5954 L .59433 .59545 L F
.59434 .5954 m .59457 .65006 L .59433 .59545 L F
.59328 .59652 m .59407 .59707 L .59421 .59619 L .645 .732 .913 r
F
.59407 .59707 m .59935 .60072 L .59421 .5962 L F
.59407 .59707 m .59421 .5962 L .59421 .59619 L F
.59129 .64996 m .59227 .65261 L .59442 .65193 L .692 .759 .903 r
F
.59125 .64993 m .59127 .64997 L .59129 .64996 L F
.59127 .64997 m .59227 .65261 L .59129 .64996 L F
.5933 .65115 m .5926 .65181 L .59354 .6513 L F
.59225 .6495 m .59296 .65131 L .59225 .65165 L .516 .301 .527 r
F
.59011 .65009 m .59227 .65261 L .59125 .64993 L .692 .759 .903 r
F
.5914 .65181 m .59037 .65231 L .59152 .65215 L F
.59064 .64981 m .59177 .65174 L .59065 .65196 L .641 .4 .539 r
F
.5905 .64945 m .59039 .65201 L .5914 .65181 L .692 .759 .903 r
F
.59039 .65201 m .59037 .65231 L .5914 .65181 L F
.58998 .65293 m .59329 .6553 L .59227 .65261 L F
.59037 .65231 m .59254 .65485 L .59152 .65215 L F
.59065 .65196 m .59226 .65258 L .59065 .65279 L .641 .4 .539 r
F
.59243 .65162 m .59152 .65215 L .5926 .65181 L .692 .759 .903 r
F
.59223 .65166 m .59177 .65174 L .59064 .64981 L .641 .4 .539 r
F
.5905 .64945 m .5914 .65181 L .59243 .65162 L .692 .759 .903 r
F
.5914 .65181 m .59152 .65215 L .59243 .65162 L F
.59225 .6495 m .59125 .64993 L .59233 .64959 L F
.59117 .64971 m .59125 .64993 L .59225 .6495 L F
.59217 .64952 m .59223 .65166 L .59064 .64981 L .641 .4 .539 r
F
.59227 .65261 m .59651 .65427 L .59442 .65193 L .692 .759 .903 r
F
.59152 .65215 m .59471 .65416 L .5926 .65181 L F
.59223 .65166 m .59226 .65258 L .59177 .65174 L .641 .4 .539 r
F
.59177 .65174 m .59226 .65258 L .59065 .65196 L F
.59054 .59347 m .59217 .64952 L .59064 .64981 L F
.59023 .64725 m .59117 .64971 L .59225 .6495 L .692 .759 .903 r
F
.5905 .64945 m .5924 .65158 L .5933 .65115 L F
.5924 .65158 m .5926 .65181 L .5933 .65115 L F
.59225 .65165 m .59329 .65214 L .59226 .65258 L .516 .301 .527 r
F
.5926 .65181 m .59658 .65315 L .59354 .6513 L .692 .759 .903 r
F
.59296 .65131 m .59329 .65214 L .59225 .65165 L .516 .301 .527 r
F
.59215 .59692 m .59323 .64904 L .59225 .6495 L F
.59308 .64985 m .59442 .65193 L .59628 .65093 L .692 .759 .903 r
F
.59233 .64959 m .59286 .65019 L .59308 .64985 L F
.59286 .65019 m .59442 .65193 L .59308 .64985 L F
.59307 .64919 m .59628 .65093 L .59326 .64909 L F
.59233 .64959 m .59251 .64965 L .59307 .64919 L F
.59251 .64965 m .59628 .65093 L .59307 .64919 L F
.59398 .65058 m .59354 .6513 L .59427 .65067 L F
.59125 .64993 m .59442 .65193 L .59233 .64959 L F
.5905 .64945 m .59329 .65115 L .59398 .65058 L F
.59329 .65115 m .59354 .6513 L .59398 .65058 L F
.59329 .65116 m .59401 .65157 L .59329 .65214 L .356 .178 .497 r
F
.59328 .64901 m .59378 .65075 L .59329 .65116 L F
.59378 .65075 m .59401 .65157 L .59329 .65116 L F
.59458 .59558 m .60144 .59923 L .6028 .59743 L .645 .732 .913 r
F
.59317 .59282 m .59323 .59652 L .59318 .59655 L .356 .178 .497 r
F
.59065 .5947 m .59389 .59606 L .59458 .59558 L .645 .732 .913 r
F
.59445 .59113 m .60304 .59365 L .60357 .59166 L F
.5909 .59092 m .59475 .59178 L .59445 .59113 L F
.59475 .59178 m .60304 .59365 L .59445 .59113 L F
.59445 .59074 m .594 .58969 L .594 .59015 L .983 .725 .333 r
F
.5944 .59103 m .594 .59015 L .59401 .59372 L F
.59445 .59074 m .594 .59015 L .5944 .59103 L F
.5939 .59606 m .59442 .64776 L .594 .64841 L .076 0 .415 r
F
.59389 .59225 m .59392 .59602 L .5939 .59606 L F
.59392 .59602 m .59442 .64776 L .5939 .59606 L F
.5947 .59494 m .6028 .59743 L .60333 .59545 L .645 .732 .913 r
F
.59317 .59298 m .5939 .59606 L .59323 .59652 L .356 .178 .497 r
F
.59065 .5947 m .59428 .59552 L .5947 .59494 L .645 .732 .913 r
F
.59428 .59552 m .6028 .59743 L .5947 .59494 L F
.59251 .59689 m .59667 .6018 L .59368 .5968 L F
.59474 .59427 m .60333 .59545 L .60299 .59341 L F
.59317 .59298 m .59389 .59249 L .5939 .59606 L .356 .178 .497 r
F
.59065 .5947 m .5957 .595 L .59474 .59427 L .645 .732 .913 r
F
.5957 .595 m .60333 .59545 L .59474 .59427 L F
.59318 .59655 m .59396 .64844 L .59328 .64901 L .356 .178 .497 r
F
.59293 .59739 m .59341 .60112 L .59385 .59847 L .645 .732 .913 r
F
.59341 .60112 m .59358 .6024 L .59385 .59847 L F
.59323 .59652 m .5939 .59606 L .59401 .65157 L .356 .178 .497 r
F
.59023 .64725 m .59446 .64775 L .59464 .64701 L .692 .759 .903 r
F
.59023 .64725 m .59464 .64701 L .59452 .64628 L F
.59401 .59372 m .59305 .64818 L .59412 .64901 L .911 .629 .497 r
F
.594 .58969 m .59393 .59366 L .59401 .59372 L F
.59393 .59366 m .59305 .64818 L .59401 .59372 L F
.59443 .59464 m .59401 .59372 L .59412 .64901 L .983 .725 .333 r
F
.59433 .59156 m .59446 .5947 L .59434 .5954 L 0 0 .146 r
F
.59445 .59074 m .59401 .59372 L .59443 .59464 L .983 .725 .333 r
F
.59389 .59606 m .59536 .59668 L .59458 .59558 L .645 .732 .913 r
F
.59536 .59668 m .60144 .59923 L .59495 .59578 L F
.59536 .59668 m .59495 .59578 L .59458 .59558 L F
.59323 .59652 m .59396 .64844 L .59318 .59655 L .356 .178 .497 r
F
.59326 .64909 m .59628 .65093 L .59774 .64968 L .692 .759 .903 r
F
.59396 .64844 m .59399 .65057 L .59328 .64901 L .356 .178 .497 r
F
.594 .64841 m .5943 .65009 L .594 .65056 L .076 0 .415 r
F
.5905 .64945 m .59473 .64996 L .59493 .64921 L .692 .759 .903 r
F
.59473 .64996 m .59474 .64996 L .59475 .64995 L F
.59473 .64996 m .59475 .64995 L .59493 .64921 L F
.59399 .65057 m .59401 .65157 L .59378 .65075 L .356 .178 .497 r
F
.59399 .65057 m .59378 .65075 L .59328 .64901 L F
.59442 .64992 m .59427 .65067 L .59474 .64996 L .692 .759 .903 r
F
.59323 .64904 m .59329 .65214 L .59225 .6495 L .516 .301 .527 r
F
.5905 .64945 m .59399 .65058 L .59442 .64992 L .692 .759 .903 r
F
.59399 .65058 m .59427 .65067 L .59442 .64992 L F
.59354 .6513 m .59804 .65189 L .59427 .65067 L F
.594 .65056 m .59445 .65088 L .59401 .65157 L .076 0 .415 r
F
.5943 .65009 m .59445 .65088 L .594 .65056 L F
.59326 .64909 m .59774 .64968 L .59398 .64846 L .692 .759 .903 r
F
.59442 .64776 m .59444 .64989 L .594 .64841 L .076 0 .415 r
F
.5905 .64945 m .59487 .64921 L .59481 .64848 L .692 .759 .903 r
F
.59487 .64921 m .59493 .64921 L .59491 .64914 L F
.59487 .64921 m .59491 .64914 L .59481 .64848 L F
.59444 .64989 m .59445 .65088 L .5943 .65009 L .076 0 .415 r
F
.59444 .64989 m .5943 .65009 L .594 .64841 L F
.59221 .59689 m .59329 .65214 L .59215 .59692 L .516 .301 .527 r
F
.59434 .5954 m .59446 .5947 L .59457 .65006 L 0 0 .146 r
F
.59446 .5947 m .59412 .64901 L .59457 .65006 L .983 .725 .333 r
F
.59445 .59074 m .59443 .59464 L .59446 .5947 L F
.59443 .59464 m .59412 .64901 L .59446 .5947 L F
.59368 .5968 m .59667 .6018 L .59754 .60145 L .645 .732 .913 r
F
.59621 .59855 m .59754 .60145 L .59935 .60072 L F
.59368 .5968 m .59754 .60145 L .59621 .59855 L F
.59065 .5947 m .59029 .60247 L .59358 .6024 L F
.59064 .59703 m .59215 .59692 L .59226 .65258 L .641 .4 .539 r
F
.59054 .59347 m .59215 .59692 L .59064 .59703 L F
.59385 .59847 m .59358 .6024 L .59667 .6018 L .645 .732 .913 r
F
.59065 .5947 m .59174 .59755 L .59258 .59697 L F
.5909 .59092 m .59199 .5938 L .59284 .59321 L F
.39602 .69939 m .39653 .69599 L .39423 .69858 L .692 .759 .903 r
F
.39602 .69939 m .39923 .6972 L .39653 .69599 L F
.60697 .48978 m .60646 .48519 L .59181 .48479 L .734 .496 .569 r
F
0 g
.60646 .48519 m
.61999 .4879 L
s
.38046 .69822 m .37803 .6979 L .37829 .7001 L .388 .236 .551 r
F
.38046 .69822 m .38021 .69602 L .37803 .6979 L F
0 g
.37663 .70003 m
.37803 .6979 L
s
.127 .923 .03 r
.37825 .69637 m
.37828 .69855 L
s
.37822 .69419 m
.37825 .69637 L
s
.38512 .69686 m .383 .69451 L .38021 .69602 L .692 .759 .903 r
F
.38728 .69617 m .383 .69451 L .38512 .69686 L F
.383 .69451 m .37995 .69381 L .38021 .69602 L .512 .324 .562 r
F
.383 .69451 m .38275 .69231 L .37995 .69381 L F
0 g
.37778 .6957 m
.37995 .69381 L
s
.39186 .69592 m .38968 .69301 L .38958 .69585 L .692 .759 .903 r
F
.39186 .69592 m .3931 .69311 L .38968 .69301 L F
.39897 .695 m .39602 .69159 L .39627 .69379 L .861 .577 .505 r
F
.39923 .6972 m .39897 .695 L .39627 .69379 L F
0 g
.39897 .695 m
.40101 .69666 L
s
.38352 .70006 m .38046 .69822 L .37829 .7001 L .692 .759 .903 r
F
.127 .923 .03 r
.37828 .69855 m
.38033 .84026 L
s
0 g
.37689 .70224 m
.37829 .7001 L
s
.38538 .69906 m .38046 .69822 L .38352 .70006 L .692 .759 .903 r
F
.38728 .69617 m .38624 .69348 L .383 .69451 L F
.38958 .69585 m .38624 .69348 L .38728 .69617 L F
.38958 .69585 m .38968 .69301 L .38624 .69348 L F
.39627 .69379 m .39602 .69159 L .39285 .69091 L .794 .527 .534 r
F
0 g
.39602 .69159 m
.39871 .6928 L
s
.39423 .69858 m .39336 .69531 L .39211 .69813 L .692 .759 .903 r
F
.39423 .69858 m .39653 .69599 L .39336 .69531 L F
.55264 .59247 m .5539 .5948 L .55366 .59858 L .924 .749 .264 r
F
.55264 .59247 m .55289 .58869 L .5539 .5948 L F
.56556 .58943 m .5539 .5948 L .56623 .5935 L .645 .732 .913 r
F
.56556 .58943 m .55289 .58869 L .5539 .5948 L F
0 g
.5539 .5948 m
.55604 .59833 L
s
.38538 .69906 m .38326 .69671 L .38046 .69822 L .692 .759 .903 r
F
.38754 .69838 m .38326 .69671 L .38538 .69906 L F
.57832 .59599 m .56834 .60118 L .5795 .59794 L .645 .732 .913 r
F
.57832 .59599 m .56599 .59729 L .56834 .60118 L F
.59231 .48938 m .57703 .48674 L .57753 .49133 L .673 .452 .578 r
F
0 g
.56364 .49548 m
.57753 .49133 L
s
.59231 .48938 m .59181 .48479 L .57703 .48674 L .673 .452 .578 r
F
0 g
.56314 .49089 m
.57703 .48674 L
s
.38624 .69348 m .38275 .69231 L .383 .69451 L .598 .385 .563 r
F
.38624 .69348 m .38598 .69128 L .38275 .69231 L F
0 g
.37995 .69381 m
.38275 .69231 L
s
.62733 .59911 m .62916 .58937 L .62891 .59315 L 0 0 .149 r
F
.62708 .60289 m .62733 .59911 L .62891 .59315 L F
.61519 .59638 m .62733 .59911 L .62891 .59315 L .645 .732 .913 r
F
0 g
.62435 .60305 m
.62733 .59911 L
s
.57854 .58639 m .5666 .58971 L .57887 .58842 L .645 .732 .913 r
F
.57854 .58639 m .56593 .58565 L .5666 .58971 L F
.38326 .69671 m .38021 .69602 L .38046 .69822 L .512 .324 .562 r
F
0 g
.37829 .7001 m
.38046 .69822 L
s
.38326 .69671 m .383 .69451 L .38021 .69602 L .512 .324 .562 r
F
0 g
.37803 .6979 m
.38021 .69602 L
s
.61223 .60376 m .62708 .60289 L .61494 .60016 L .645 .732 .913 r
F
.60144 .59923 m .61223 .60376 L .61494 .60016 L F
.59935 .60072 m .61223 .60376 L .60144 .59923 L F
.39211 .69813 m .38994 .69521 L .38983 .69806 L .692 .759 .903 r
F
.39211 .69813 m .39336 .69531 L .38994 .69521 L F
.39923 .6972 m .39627 .69379 L .39653 .69599 L .861 .577 .505 r
F
0 g
.39923 .6972 m
.40127 .69886 L
s
.61531 .59257 m .62897 .58935 L .61636 .58861 L .645 .732 .913 r
F
.60323 .58985 m .61531 .59257 L .61636 .58861 L F
.60188 .59164 m .61531 .59257 L .60323 .58985 L F
.3931 .69311 m .39285 .69091 L .38942 .6908 L .731 .481 .55 r
F
.39627 .69379 m .39285 .69091 L .3931 .69311 L .794 .527 .534 r
F
0 g
.39285 .69091 m
.39602 .69159 L
s
.38754 .69838 m .38649 .69569 L .38326 .69671 L .692 .759 .903 r
F
.38983 .69806 m .38649 .69569 L .38754 .69838 L F
.38983 .69806 m .38994 .69521 L .38649 .69569 L F
.60697 .48978 m .59181 .48479 L .59231 .48938 L .734 .496 .569 r
F
0 g
.57703 .48674 m
.59181 .48479 L
s
.59181 .48479 m
.60646 .48519 L
s
.60697 .48978 m
.6205 .49249 L
s
.39653 .69599 m .39627 .69379 L .3931 .69311 L .794 .527 .534 r
F
0 g
.39627 .69379 m
.39897 .695 L
s
.59231 .48938 m
.60697 .48978 L
s
.38968 .69301 m .38598 .69128 L .38624 .69348 L .668 .435 .559 r
F
.38968 .69301 m .38942 .6908 L .38598 .69128 L F
0 g
.38275 .69231 m
.38598 .69128 L
s
.3931 .69311 m .38942 .6908 L .38968 .69301 L .731 .481 .55 r
F
0 g
.38598 .69128 m
.38942 .6908 L
s
.38942 .6908 m
.39285 .69091 L
s
.38649 .69569 m .383 .69451 L .38326 .69671 L .598 .385 .563 r
F
.38649 .69569 m .38624 .69348 L .383 .69451 L F
0 g
.38021 .69602 m
.383 .69451 L
s
.38046 .69822 m
.38326 .69671 L
s
.39336 .69531 m .3931 .69311 L .38968 .69301 L .731 .481 .55 r
F
.39653 .69599 m .3931 .69311 L .39336 .69531 L .794 .527 .534 r
F
0 g
.3931 .69311 m
.39627 .69379 L
s
.39653 .69599 m
.39923 .6972 L
s
.56531 .59321 m .55366 .59858 L .56599 .59729 L .645 .732 .913 r
F
.56531 .59321 m .55264 .59247 L .55366 .59858 L F
0 g
.55366 .59858 m
.55719 .60442 L
s
.38994 .69521 m .38624 .69348 L .38649 .69569 L .668 .435 .559 r
F
.38994 .69521 m .38968 .69301 L .38624 .69348 L F
0 g
.383 .69451 m
.38624 .69348 L
s
.57823 .59017 m .56623 .5935 L .57857 .59221 L .645 .732 .913 r
F
.57823 .59017 m .56556 .58943 L .56623 .5935 L F
.62708 .60289 m .62891 .59315 L .62867 .59693 L 0 0 .149 r
F
.61494 .60016 m .62708 .60289 L .62867 .59693 L .645 .732 .913 r
F
0 g
.62301 .60829 m
.62708 .60289 L
s
.39336 .69531 m .38968 .69301 L .38994 .69521 L .731 .481 .55 r
F
0 g
.38624 .69348 m
.38968 .69301 L
s
.38968 .69301 m
.3931 .69311 L
s
.39336 .69531 m
.39653 .69599 L
s
.61519 .59638 m .62891 .59315 L .61624 .59241 L .645 .732 .913 r
F
.60304 .59365 m .61519 .59638 L .61624 .59241 L F
.60169 .59545 m .61519 .59638 L .60304 .59365 L F
0 g
.57753 .49133 m
.59231 .48938 L
s
.60323 .58985 m .61636 .58861 L .60375 .58787 L .645 .732 .913 r
F
0 g
.38326 .69671 m
.38649 .69569 L
s
.38994 .69521 m
.39336 .69531 L
s
.38649 .69569 m
.38994 .69521 L
s
.59064 .64832 m
.59064 .64942 L
s
.127 .923 .03 r
.58922 .7861 m
.59122 .70102 L
s
.59122 .70102 m
.59231 .6546 L
s
.59235 .65283 m
.59236 .65267 L
s
.57798 .59396 m .56599 .59729 L .57832 .59599 L .645 .732 .913 r
F
.57798 .59396 m .56531 .59321 L .56599 .59729 L F
.61494 .60016 m .62867 .59693 L .616 .59619 L F
.6028 .59743 m .61494 .60016 L .616 .59619 L F
.60144 .59923 m .61494 .60016 L .6028 .59743 L F
.127 .923 .03 r
.5934 .77032 m
.59426 .69979 L
s
.59426 .69979 m
.59483 .65362 L
s
.59485 .6521 m
.59485 .6517 L
s
.59489 .64875 m
.59503 .63733 L
s
.60304 .59365 m .61624 .59241 L .60357 .59166 L .645 .732 .913 r
F
.55446 .58273 m .55313 .5849 L .55289 .58869 L 0 0 .144 r
F
.127 .923 .03 r
.55388 .78468 m
.55547 .70199 L
s
0 g
.55342 .58664 m
.55377 .58874 L
s
.56698 .5817 m .55489 .57898 L .55332 .58491 L .645 .732 .913 r
F
.55446 .58273 m .55471 .57894 L .55313 .5849 L 0 0 .144 r
F
.56698 .5817 m .55332 .58491 L .56593 .58565 L .645 .732 .913 r
F
.57906 .58442 m .56593 .58565 L .57854 .58639 L F
.57906 .58442 m .56698 .5817 L .56593 .58565 L F
.59115 .58713 m .58823 .57947 L .58516 .58006 L F
0 g
.5874 .58621 m
.5874 .58679 L
s
.59115 .58713 m .59151 .5794 L .58823 .57947 L .645 .732 .913 r
F
.59115 .58713 m .59476 .57985 L .59151 .5794 L F
.60375 .58787 m .61569 .58456 L .60342 .58585 L F
.60375 .58787 m .61636 .58861 L .61569 .58456 L F
.61636 .58861 m .62797 .58327 L .61569 .58456 L F
.61636 .58861 m .62897 .58935 L .62797 .58327 L F
.62891 .59315 m .62916 .58937 L .62816 .58325 L .921 .747 .26 r
F
0 g
.62816 .5931 m
.62874 .59092 L
s
.127 .923 .03 r
.59449 1.34616 m
.60967 .76086 L
s
.60967 .76086 m
.61284 .6383 L
s
.6028 .59743 m .616 .59619 L .60333 .59545 L .645 .732 .913 r
F
.55421 .58651 m .55289 .58869 L .55264 .59247 L 0 0 .144 r
F
0 g
.55318 .59043 m
.55353 .59252 L
s
.56661 .58546 m .55446 .58273 L .55289 .58869 L .645 .732 .913 r
F
.55421 .58651 m .55446 .58273 L .55289 .58869 L 0 0 .144 r
F
.56661 .58546 m .55289 .58869 L .56556 .58943 L .645 .732 .913 r
F
.57875 .58819 m .56556 .58943 L .57823 .59017 L F
.57875 .58819 m .56661 .58546 L .56556 .58943 L F
.5909 .59092 m .58797 .58322 L .58488 .58381 L F
.5909 .59092 m .59127 .58314 L .58797 .58322 L F
.5909 .59092 m .59454 .5836 L .59127 .58314 L F
.5909 .59092 m .59756 .58456 L .59454 .5836 L F
.5909 .59092 m .60012 .58595 L .59756 .58456 L F
.594 .58969 m .59294 .58886 L .59294 .58935 L .911 .629 .497 r
F
.59444 .58989 m .60324 .58962 L .60206 .58768 L .645 .732 .913 r
F
.5909 .59092 m .59585 .5904 L .59444 .58989 L F
.59585 .5904 m .60324 .58962 L .59444 .58989 L F
.59585 .5904 m .60357 .59166 L .60324 .58962 L F
.5909 .59092 m .59852 .59137 L .59585 .5904 L F
.59852 .59137 m .60357 .59166 L .59585 .5904 L F
.59294 .58886 m .59185 .58848 L .59185 .58895 L .81 .54 .53 r
F
.5909 .59092 m .59387 .59005 L .5933 .58962 L .645 .732 .913 r
F
.59294 .58886 m .59185 .58895 L .59293 .58934 L .81 .54 .53 r
F
.59294 .58886 m .59293 .58934 L .59294 .58935 L F
.59078 .59213 m .59429 .58739 L .59102 .58693 L .645 .732 .913 r
F
.59185 .58848 m .59076 .58835 L .59077 .59236 L .734 .476 .539 r
F
.59065 .5947 m .59174 .59251 L .59076 .59236 L .645 .732 .913 r
F
.59399 .59014 m .59294 .58935 L .59294 .59292 L .911 .629 .497 r
F
.59466 .59354 m .60299 .59341 L .60181 .59146 L .645 .732 .913 r
F
.59065 .5947 m .59626 .59411 L .59466 .59354 L F
.59626 .59411 m .60299 .59341 L .59466 .59354 L F
.59293 .58934 m .59287 .59289 L .59294 .58935 L .81 .54 .53 r
F
.59287 .59289 m .59197 .6478 L .59288 .59289 L F
.59287 .59289 m .59288 .59289 L .59294 .58935 L F
.59393 .59366 m .59294 .59292 L .59305 .64818 L .911 .629 .497 r
F
.59399 .59014 m .59294 .59292 L .59393 .59366 L F
.59337 .59324 m .59466 .59354 L .59356 .59314 L .645 .732 .913 r
F
.59065 .5947 m .59402 .59373 L .59337 .59324 L F
.59402 .59373 m .59466 .59354 L .59337 .59324 L F
.59356 .59314 m .60181 .59146 L .59988 .58973 L F
.59466 .59354 m .60181 .59146 L .59356 .59314 L F
.59023 .64725 m .59398 .64846 L .59446 .64775 L .692 .759 .903 r
F
.59294 .59292 m .59202 .64497 L .59305 .64524 L .81 .54 .53 r
F
.59222 .64502 m .59344 .64507 L .59254 .64466 L .692 .759 .903 r
F
.59023 .64725 m .59314 .64527 L .59222 .64502 L F
.59314 .64527 m .59344 .64507 L .59222 .64502 L F
.59023 .64725 m .59452 .64628 L .59411 .64562 L F
.59305 .64524 m .59223 .64717 L .59305 .64739 L .81 .54 .53 r
F
.59248 .64724 m .59372 .64726 L .59282 .64686 L .692 .759 .903 r
F
.59023 .64725 m .59326 .64909 L .59398 .64846 L F
.5905 .64945 m .59339 .64748 L .59248 .64724 L F
.59339 .64748 m .59372 .64726 L .59248 .64724 L F
.59305 .64739 m .59197 .6478 L .59305 .64818 L .81 .54 .53 r
F
.59223 .64717 m .59197 .6478 L .59305 .64739 L F
.59023 .64725 m .59411 .64562 L .59344 .64507 L .692 .759 .903 r
F
.59202 .64497 m .59197 .6478 L .59305 .64524 L .81 .54 .53 r
F
.59294 .58935 m .59288 .59289 L .59294 .59292 L F
.59288 .59289 m .59197 .6478 L .59294 .59292 L F
.59179 .59251 m .59077 .59236 L .59087 .64767 L .734 .476 .539 r
F
.59185 .58848 m .59077 .59236 L .59179 .59251 L F
.59076 .59236 m .59175 .59249 L .59078 .59213 L .645 .732 .913 r
F
.59174 .59251 m .59175 .59249 L .59076 .59236 L F
.59293 .58934 m .59185 .58895 L .59186 .59252 L .81 .54 .53 r
F
.59175 .59249 m .59429 .58739 L .59078 .59213 L .645 .732 .913 r
F
.59287 .59289 m .59186 .59252 L .59197 .6478 L .81 .54 .53 r
F
.59293 .58934 m .59186 .59252 L .59287 .59289 L F
.594 .58969 m .59294 .58935 L .59399 .59014 L .911 .629 .497 r
F
.5933 .58962 m .60206 .58768 L .60012 .58595 L .645 .732 .913 r
F
.59387 .59005 m .60206 .58768 L .5933 .58962 L F
.60357 .59166 m .61557 .58833 L .60324 .58962 L F
.60357 .59166 m .61624 .59241 L .61557 .58833 L F
.61624 .59241 m .62791 .58704 L .61557 .58833 L F
.61624 .59241 m .62891 .59315 L .62791 .58704 L F
.62891 .59315 m .62816 .58325 L .62791 .58704 L .921 .747 .26 r
F
.62867 .59693 m .62891 .59315 L .62791 .58704 L F
0 g
.62792 .59689 m
.6285 .5947 L
s
.58041 .58263 m .56698 .5817 L .57906 .58442 L .645 .732 .913 r
F
.60342 .58585 m .61335 .58068 L .60225 .58391 L F
.60342 .58585 m .61569 .58456 L .61335 .58068 L F
0 g
.58752 .64845 m
.58752 .64889 L
s
.58751 .6463 m
.58751 .64757 L
s
.58741 .58978 m
.58741 .59087 L
s
.56636 .58924 m .55264 .59247 L .56531 .59321 L .645 .732 .913 r
F
.56636 .58924 m .55421 .58651 L .55264 .59247 L F
0 g
.55264 .59247 m
.55366 .59858 L
s
.57851 .59197 m .56531 .59321 L .57798 .59396 L .645 .732 .913 r
F
.57851 .59197 m .56636 .58924 L .56531 .59321 L F
.59174 .59251 m .59731 .58834 L .59429 .58739 L F
.59065 .5947 m .59279 .59266 L .59174 .59251 L F
.59279 .59266 m .59731 .58834 L .59174 .59251 L F
.59186 .59252 m .59092 .64491 L .59196 .64495 L .734 .476 .539 r
F
.59128 .64492 m .59254 .64466 L .59149 .64444 L .692 .759 .903 r
F
.59023 .64725 m .59227 .64497 L .59128 .64492 L F
.59227 .64497 m .59254 .64466 L .59128 .64492 L F
.59092 .64491 m .59087 .64767 L .59196 .64495 L .734 .476 .539 r
F
.59061 .64704 m .59177 .64663 L .59063 .64659 L .692 .759 .903 r
F
.59023 .64725 m .59011 .65009 L .59125 .64993 L F
.59023 .64725 m .59233 .64959 L .59326 .64909 L F
.5905 .64945 m .59156 .64708 L .59061 .64704 L F
.59196 .64495 m .59112 .64707 L .59197 .6471 L .734 .476 .539 r
F
.59156 .64708 m .59177 .64663 L .59061 .64704 L .692 .759 .903 r
F
.5905 .64945 m .59282 .64686 L .59177 .64663 L F
.59197 .6471 m .59087 .64767 L .59197 .6478 L .734 .476 .539 r
F
.59112 .64707 m .59087 .64767 L .59197 .6471 L F
.59185 .58848 m .59179 .59251 L .59186 .59252 L F
.59179 .59251 m .59087 .64767 L .59186 .59252 L F
.59065 .5947 m .58773 .587 L .58463 .5876 L .645 .732 .913 r
F
0 g
.58741 .59335 m
.58751 .64524 L
s
.59065 .5947 m .59102 .58693 L .58773 .587 L .645 .732 .913 r
F
.59065 .5947 m .59988 .58973 L .59731 .58834 L F
.60333 .59545 m .61533 .59212 L .60299 .59341 L F
.60333 .59545 m .616 .59619 L .61533 .59212 L F
.58943 .64512 m .59036 .6444 L .58921 .64456 L .692 .759 .903 r
F
.59023 .64725 m .59033 .64498 L .58943 .64512 L F
.59076 .58835 m .58981 .64506 L .59087 .64491 L .66 .415 .539 r
F
.59033 .64498 m .59036 .6444 L .58943 .64512 L .692 .759 .903 r
F
.59023 .64725 m .59149 .64444 L .59036 .6444 L F
.58981 .64506 m .58977 .64776 L .59087 .64491 L .66 .415 .539 r
F
.58966 .64723 m .59063 .64659 L .58948 .64675 L .692 .759 .903 r
F
.5905 .64945 m .5906 .64709 L .58966 .64723 L F
.59087 .64491 m .58999 .64718 L .59087 .64705 L .66 .415 .539 r
F
.5906 .64709 m .59063 .64659 L .58966 .64723 L .692 .759 .903 r
F
.59087 .64705 m .58977 .64776 L .59087 .64767 L .66 .415 .539 r
F
.58999 .64718 m .58977 .64776 L .59087 .64705 L F
.616 .59619 m .62767 .59082 L .61533 .59212 L .645 .732 .913 r
F
.616 .59619 m .62867 .59693 L .62767 .59082 L F
.62867 .59693 m .62791 .58704 L .62767 .59082 L .921 .747 .26 r
F
0 g
.62708 .60289 m
.62867 .59693 L
s
.58011 .58639 m .56661 .58546 L .57875 .58819 L .645 .732 .913 r
F
.58041 .58263 m .56967 .57812 L .56698 .5817 L F
.58249 .58114 m .56967 .57812 L .58041 .58263 L F
.60324 .58962 m .61322 .58443 L .60206 .58768 L F
.60324 .58962 m .61557 .58833 L .61322 .58443 L F
.60225 .58391 m .6095 .57724 L .60032 .58219 L F
.60225 .58391 m .61335 .58068 L .6095 .57724 L F
.56967 .57812 m .55489 .57898 L .56698 .5817 L F
.61569 .58456 m .62446 .57745 L .61335 .58068 L F
.61569 .58456 m .62797 .58327 L .62446 .57745 L F
0 0 0 r
2.5 Mabswid
.58451 .59292 Mdot
.58249 .58114 m .57383 .57514 L .56967 .57812 L .645 .732 .913 r
F
.58516 .58006 m .57383 .57514 L .58249 .58114 L F
.60032 .58219 m .60439 .57447 L .59777 .5808 L F
.60032 .58219 m .6095 .57724 L .60439 .57447 L F
0 0 0 r
.58516 .59242 Mdot
.57986 .59017 m .56636 .58924 L .57851 .59197 L .645 .732 .913 r
F
.58011 .58639 m .56931 .58185 L .56661 .58546 L F
.5822 .58489 m .56931 .58185 L .58011 .58639 L F
.60299 .59341 m .61298 .58822 L .60181 .59146 L F
.60299 .59341 m .61533 .59212 L .61298 .58822 L F
.60206 .58768 m .60935 .58097 L .60012 .58595 L F
.60206 .58768 m .61322 .58443 L .60935 .58097 L F
.56931 .58185 m .55446 .58273 L .56661 .58546 L F
.56967 .57812 m .55893 .5736 L .55489 .57898 L F
.55852 .57732 m .55471 .57894 L .55446 .58273 L .079 0 .403 r
F
.55852 .57732 m .55876 .57354 L .55471 .57894 L F
0 g
.5 Mabswid
.55313 .5849 m
.55471 .57894 L
s
.61557 .58833 m .62439 .58119 L .61322 .58443 L .645 .732 .913 r
F
.61557 .58833 m .62791 .58704 L .62439 .58119 L F
.62791 .58704 m .62816 .58325 L .62463 .5774 L .991 .751 .472 r
F
0 g
.62816 .58325 m
.62916 .58937 L
s
.58516 .58006 m .57917 .57299 L .57383 .57514 L .645 .732 .913 r
F
.58823 .57947 m .57917 .57299 L .58516 .58006 L F
.59777 .5808 m .59838 .57257 L .59476 .57985 L F
.59777 .5808 m .60439 .57447 L .59838 .57257 L F
.5822 .58489 m .57349 .57887 L .56931 .58185 L F
.58488 .58381 m .57349 .57887 L .5822 .58489 L F
.60012 .58595 m .60421 .57819 L .59756 .58456 L F
.60012 .58595 m .60935 .58097 L .60421 .57819 L F
.58823 .57947 m .58532 .5718 L .57917 .57299 L F
.59151 .5794 m .58532 .5718 L .58823 .57947 L F
.57986 .59017 m .56907 .58564 L .56636 .58924 L F
.58195 .58868 m .56907 .58564 L .57986 .59017 L F
.59476 .57985 m .59188 .57166 L .59151 .5794 L F
.59476 .57985 m .59838 .57257 L .59188 .57166 L F
.127 .923 .03 r
.59377 .57192 m
.59526 .5086 L
s
.59451 .57202 m
.59526 .5086 L
s
.60181 .59146 m .6091 .58476 L .59988 .58973 L .645 .732 .913 r
F
.60181 .59146 m .61298 .58822 L .6091 .58476 L F
.56907 .58564 m .55421 .58651 L .56636 .58924 L F
.57383 .57514 m .55893 .5736 L .56967 .57812 L F
.55827 .58111 m .55446 .58273 L .55421 .58651 L .079 0 .403 r
F
.56931 .58185 m .55852 .57732 L .55446 .58273 L .645 .732 .913 r
F
.55827 .58111 m .55852 .57732 L .55446 .58273 L .079 0 .403 r
F
0 g
.55289 .58869 m
.55446 .58273 L
s
.61533 .59212 m .62414 .58497 L .61298 .58822 L .645 .732 .913 r
F
.61533 .59212 m .62767 .59082 L .62414 .58497 L F
.59151 .5794 m .59188 .57166 L .58532 .5718 L F
.61335 .58068 m .61868 .57229 L .6095 .57724 L F
.61335 .58068 m .62446 .57745 L .61868 .57229 L F
.62791 .58704 m .62463 .5774 L .62439 .58119 L .991 .751 .472 r
F
.62767 .59082 m .62791 .58704 L .62439 .58119 L F
0 g
.62791 .58704 m
.62891 .59315 L
s
.58488 .58381 m .57886 .5767 L .57349 .57887 L .645 .732 .913 r
F
.58797 .58322 m .57886 .5767 L .58488 .58381 L F
.59756 .58456 m .59817 .57628 L .59454 .5836 L F
.59756 .58456 m .60421 .57819 L .59817 .57628 L F
.58195 .58868 m .57325 .58265 L .56907 .58564 L F
.58463 .5876 m .57325 .58265 L .58195 .58868 L F
.59988 .58973 m .60397 .58198 L .59731 .58834 L F
.59988 .58973 m .6091 .58476 L .60397 .58198 L F
.58797 .58322 m .58505 .57551 L .57886 .5767 L F
.59127 .58314 m .58505 .57551 L .58797 .58322 L F
.59454 .5836 m .59163 .57536 L .59127 .58314 L F
.59454 .5836 m .59817 .57628 L .59163 .57536 L F
.57349 .57887 m .55852 .57732 L .56931 .58185 L F
.56907 .58564 m .55827 .58111 L .55421 .58651 L F
0 g
.55264 .59247 m
.55421 .58651 L
s
.59127 .58314 m .59163 .57536 L .58505 .57551 L .645 .732 .913 r
F
.61322 .58443 m .61858 .576 L .60935 .58097 L F
.61322 .58443 m .62439 .58119 L .61858 .576 L F
.62767 .59082 m .62439 .58119 L .62414 .58497 L .991 .751 .472 r
F
0 g
.62767 .59082 m
.62867 .59693 L
s
.58463 .5876 m .57861 .58049 L .57325 .58265 L .645 .732 .913 r
F
.58773 .587 m .57861 .58049 L .58463 .5876 L F
.59731 .58834 m .59793 .58006 L .59429 .58739 L F
.59731 .58834 m .60397 .58198 L .59793 .58006 L F
.57383 .57514 m .56516 .56915 L .55893 .5736 L F
.57917 .57299 m .56516 .56915 L .57383 .57514 L F
.6095 .57724 m .61102 .56814 L .60439 .57447 L F
.6095 .57724 m .61868 .57229 L .61102 .56814 L F
.58773 .587 m .5848 .57929 L .57861 .58049 L F
.59102 .58693 m .5848 .57929 L .58773 .587 L F
.59429 .58739 m .59139 .57915 L .59102 .58693 L F
.59429 .58739 m .59793 .58006 L .59139 .57915 L F
.57325 .58265 m .55827 .58111 L .56907 .58564 L F
.59102 .58693 m .59139 .57915 L .5848 .57929 L F
.61298 .58822 m .61833 .57978 L .6091 .58476 L F
.61298 .58822 m .62414 .58497 L .61833 .57978 L F
.56478 .57284 m .55876 .57354 L .55852 .57732 L .349 .175 .499 r
F
.56478 .57284 m .56503 .56906 L .55876 .57354 L F
0 g
.55471 .57894 m
.55876 .57354 L
s
.62439 .58119 m .62463 .5774 L .61882 .57221 L .927 .677 .539 r
F
0 g
.62463 .5774 m
.62816 .58325 L
s
.57349 .57887 m .56478 .57284 L .55852 .57732 L .645 .732 .913 r
F
.57886 .5767 m .56478 .57284 L .57349 .57887 L F
.60935 .58097 m .61088 .57182 L .60421 .57819 L F
.60935 .58097 m .61858 .576 L .61088 .57182 L F
.127 .923 .03 r
.59369 .57565 m
.59372 .5743 L
s
.59446 .57576 m
.59448 .57411 L
s
.56454 .57663 m .55852 .57732 L .55827 .58111 L .349 .175 .499 r
F
.56454 .57663 m .56478 .57284 L .55852 .57732 L F
0 g
.55446 .58273 m
.55852 .57732 L
s
.57917 .57299 m .57317 .56591 L .56516 .56915 L .645 .732 .913 r
F
.58532 .5718 m .57317 .56591 L .57917 .57299 L F
.60439 .57447 m .602 .56528 L .59838 .57257 L F
.60439 .57447 m .61102 .56814 L .602 .56528 L F
.62439 .58119 m .61882 .57221 L .61858 .576 L .927 .677 .539 r
F
.62414 .58497 m .62439 .58119 L .61858 .576 L F
0 g
.62439 .58119 m
.62791 .58704 L
s
.57325 .58265 m .56454 .57663 L .55827 .58111 L .645 .732 .913 r
F
.127 .923 .03 r
.55547 .70199 m
.55846 .54633 L
s
0 g
.55421 .58651 m
.55827 .58111 L
s
.57861 .58049 m .56454 .57663 L .57325 .58265 L .645 .732 .913 r
F
.6091 .58476 m .61063 .57561 L .60397 .58198 L F
.6091 .58476 m .61833 .57978 L .61063 .57561 L F
.127 .923 .03 r
.5936 .57946 m
.59363 .57797 L
s
.58532 .5718 m .58241 .56413 L .57317 .56591 L .645 .732 .913 r
F
.59188 .57166 m .58241 .56413 L .58532 .5718 L F
.59838 .57257 m .59224 .56391 L .59188 .57166 L F
.59838 .57257 m .602 .56528 L .59224 .56391 L F
.127 .923 .03 r
.59442 .57957 m
.59444 .57776 L
s
.57886 .5767 m .57283 .56959 L .56478 .57284 L .645 .732 .913 r
F
.58505 .57551 m .57283 .56959 L .57886 .5767 L F
.60421 .57819 m .60181 .56895 L .59817 .57628 L F
.60421 .57819 m .61088 .57182 L .60181 .56895 L F
.62414 .58497 m .61858 .576 L .61833 .57978 L .927 .677 .539 r
F
0 g
.62414 .58497 m
.62767 .59082 L
s
.59188 .57166 m .59224 .56391 L .58241 .56413 L .645 .732 .913 r
F
.57283 .56959 m .56503 .56906 L .56478 .57284 L .498 .297 .538 r
F
.57283 .56959 m .57308 .56581 L .56503 .56906 L F
0 g
.55876 .57354 m
.56503 .56906 L
s
.61858 .576 m .61882 .57221 L .61112 .56804 L .857 .609 .562 r
F
0 g
.61882 .57221 m
.62463 .5774 L
s
.58505 .57551 m .58212 .5678 L .57283 .56959 L .645 .732 .913 r
F
.59163 .57536 m .58212 .5678 L .58505 .57551 L F
0 0 0 r
2.5 Mabswid
.59355 .58163 Mdot
.127 .923 .03 r
.5 Mabswid
.59229 .63501 m
.59355 .58163 L
s
.4002 8.8233 m
.58282 1.03884 L
s
.59817 .57628 m .592 .56758 L .59163 .57536 L .645 .732 .913 r
F
.59817 .57628 m .60181 .56895 L .592 .56758 L F
.57861 .58049 m .57259 .57338 L .56454 .57663 L F
.5848 .57929 m .57259 .57338 L .57861 .58049 L F
.127 .923 .03 r
.59376 .63445 m
.59439 .58142 L
s
.49633 8.80045 m
.58713 1.19053 L
s
0 0 0 r
2.5 Mabswid
.59439 .58142 Mdot
.60397 .58198 m .60157 .57274 L .59793 .58006 L .645 .732 .913 r
F
.60397 .58198 m .61063 .57561 L .60157 .57274 L F
.59163 .57536 m .592 .56758 L .58212 .5678 L F
.57259 .57338 m .56478 .57284 L .56454 .57663 L .498 .297 .538 r
F
0 g
.5 Mabswid
.55827 .58111 m
.56454 .57663 L
s
.57259 .57338 m .57283 .56959 L .56478 .57284 L .498 .297 .538 r
F
0 g
.55852 .57732 m
.56478 .57284 L
s
.61858 .576 m .61112 .56804 L .61088 .57182 L .857 .609 .562 r
F
.61833 .57978 m .61858 .576 L .61088 .57182 L F
0 g
.61858 .576 m
.62439 .58119 L
s
.5848 .57929 m .58187 .57158 L .57259 .57338 L .645 .732 .913 r
F
.59139 .57915 m .58187 .57158 L .5848 .57929 L F
.59793 .58006 m .59176 .57137 L .59139 .57915 L F
.59793 .58006 m .60157 .57274 L .59176 .57137 L F
.59139 .57915 m .59176 .57137 L .58187 .57158 L F
.58212 .5678 m .57308 .56581 L .57283 .56959 L .596 .378 .556 r
F
.58212 .5678 m .58236 .56401 L .57308 .56581 L F
0 g
.56503 .56906 m
.57308 .56581 L
s
.61833 .57978 m .61088 .57182 L .61063 .57561 L .857 .609 .562 r
F
0 g
.61833 .57978 m
.62414 .58497 L
s
.61222 .50951 m
.61787 2.85992 L
s
.61088 .57182 m .61112 .56804 L .60206 .56517 L .794 .551 .57 r
F
0 g
.61112 .56804 m
.61882 .57221 L
s
.58187 .57158 m .57283 .56959 L .57259 .57338 L .596 .378 .556 r
F
0 g
.56454 .57663 m
.57259 .57338 L
s
.58187 .57158 m .58212 .5678 L .57283 .56959 L .596 .378 .556 r
F
0 g
.56478 .57284 m
.57283 .56959 L
s
.61088 .57182 m .60206 .56517 L .60181 .56895 L .794 .551 .57 r
F
.61063 .57561 m .61088 .57182 L .60181 .56895 L F
0 g
.61088 .57182 m
.61858 .576 L
s
.592 .56758 m .58236 .56401 L .58212 .5678 L .67 .441 .566 r
F
.592 .56758 m .59225 .56379 L .58236 .56401 L F
0 g
.57308 .56581 m
.58236 .56401 L
s
.60181 .56895 m .60206 .56517 L .59225 .56379 L .733 .497 .57 r
F
0 g
.60206 .56517 m
.61112 .56804 L
s
.60181 .56895 m .59225 .56379 L .592 .56758 L .733 .497 .57 r
F
0 g
.59225 .56379 m
.60206 .56517 L
s
.58236 .56401 m
.59225 .56379 L
s
.61063 .57561 m .60181 .56895 L .60157 .57274 L .794 .551 .57 r
F
0 g
.61063 .57561 m
.61833 .57978 L
s
.59176 .57137 m .58212 .5678 L .58187 .57158 L .67 .441 .566 r
F
0 g
.57259 .57338 m
.58187 .57158 L
s
.59176 .57137 m .592 .56758 L .58212 .5678 L .67 .441 .566 r
F
0 g
.57283 .56959 m
.58212 .5678 L
s
.60157 .57274 m .60181 .56895 L .592 .56758 L .733 .497 .57 r
F
0 g
.60181 .56895 m
.61088 .57182 L
s
.60157 .57274 m .592 .56758 L .59176 .57137 L .733 .497 .57 r
F
0 g
.592 .56758 m
.60181 .56895 L
s
.60157 .57274 m
.61063 .57561 L
s
.58212 .5678 m
.592 .56758 L
s
.59012 .65802 m .58985 .65582 L .5933 .65534 L .668 .435 .559 r
F
.58669 .65791 m .58985 .65582 L .59012 .65802 L .731 .481 .549 r
F
.58669 .65791 m .58643 .65571 L .58985 .65582 L F
.58998 .65293 m .58985 .65577 L .59329 .6553 L .692 .759 .903 r
F
.58771 .65286 m .58645 .65567 L .58985 .65577 L F
.59357 .65754 m .5933 .65534 L .59654 .65431 L .599 .386 .563 r
F
.59012 .65802 m .5933 .65534 L .59357 .65754 L .668 .435 .559 r
F
0 g
.58985 .65582 m
.5933 .65534 L
s
.59227 .65261 m .59329 .6553 L .59651 .65427 L .692 .759 .903 r
F
0 g
.58187 .57158 m
.59176 .57137 L
s
.59176 .57137 m
.60157 .57274 L
s
.58353 .65723 m .58643 .65571 L .58669 .65791 L .794 .526 .533 r
F
.58353 .65723 m .58326 .65503 L .58643 .65571 L F
0 g
.58643 .65571 m
.58985 .65582 L
s
.58561 .65241 m .58645 .65567 L .58771 .65286 L .692 .759 .903 r
F
.58561 .65241 m .5833 .65499 L .58645 .65567 L F
.59681 .65651 m .59654 .65431 L .59935 .6528 L .512 .324 .563 r
F
.59357 .65754 m .59654 .65431 L .59681 .65651 L .599 .386 .563 r
F
0 g
.5933 .65534 m
.59654 .65431 L
s
.59442 .65193 m .59651 .65427 L .59931 .65277 L .692 .759 .903 r
F
.59038 .66022 m .59012 .65802 L .59357 .65754 L .668 .435 .559 r
F
.58696 .66012 m .59012 .65802 L .59038 .66022 L .731 .481 .549 r
F
.58696 .66012 m .58669 .65791 L .59012 .65802 L F
.59025 .65516 m .59012 .65802 L .59357 .65754 L .692 .759 .903 r
F
.127 .923 .03 r
.59224 .63722 m
.59229 .63501 L
s
.59374 .63665 m
.59376 .63445 L
s
.58796 .65509 m .59012 .65802 L .59025 .65516 L .692 .759 .903 r
F
.58796 .65509 m .58669 .65791 L .59012 .65802 L F
.59383 .65975 m .59357 .65754 L .59681 .65651 L .599 .386 .563 r
F
.59038 .66022 m .59357 .65754 L .59383 .65975 L .668 .435 .559 r
F
.59254 .65485 m .59357 .65754 L .59681 .65651 L .692 .759 .903 r
F
.59025 .65516 m .59357 .65754 L .59254 .65485 L F
0 g
.59012 .65802 m
.59357 .65754 L
s
.58084 .65602 m .58326 .65503 L .58353 .65723 L .862 .577 .504 r
F
.127 .923 .03 r
.58282 1.03884 m
.58409 .98466 L
s
.58084 .65602 m .58057 .65381 L .58326 .65503 L .862 .577 .504 r
F
0 g
.58326 .65503 m
.58643 .65571 L
s
.58383 .6516 m .5833 .65499 L .58561 .65241 L .692 .759 .903 r
F
.58383 .6516 m .58062 .65378 L .5833 .65499 L F
.5838 .65944 m .58669 .65791 L .58696 .66012 L .794 .526 .533 r
F
.5838 .65944 m .58353 .65723 L .58669 .65791 L F
.58585 .65464 m .58669 .65791 L .58796 .65509 L .692 .759 .903 r
F
.58585 .65464 m .58353 .65723 L .58669 .65791 L F
0 g
.58669 .65791 m
.59012 .65802 L
s
.59962 .655 m .59935 .6528 L .60154 .65091 L .39 .239 .552 r
F
.59681 .65651 m .59935 .6528 L .59962 .655 L .512 .324 .563 r
F
0 g
.59654 .65431 m
.59935 .6528 L
s
.59707 .65872 m .59681 .65651 L .59962 .655 L .512 .324 .563 r
F
.59383 .65975 m .59681 .65651 L .59707 .65872 L .599 .386 .563 r
F
.59471 .65416 m .59681 .65651 L .59962 .655 L .692 .759 .903 r
F
.59254 .65485 m .59681 .65651 L .59471 .65416 L F
0 g
.59357 .65754 m
.59681 .65651 L
s
.59628 .65093 m .59931 .65277 L .60149 .65089 L .692 .759 .903 r
F
.59442 .65193 m .59931 .65277 L .59628 .65093 L F
.59051 .65737 m .59038 .66022 L .59383 .65975 L .692 .759 .904 r
F
.58823 .6573 m .59038 .66022 L .59051 .65737 L F
.58823 .6573 m .58696 .66012 L .59038 .66022 L F
.59281 .65705 m .59383 .65975 L .59707 .65872 L F
.59051 .65737 m .59383 .65975 L .59281 .65705 L F
0 g
.59038 .66022 m
.59383 .65975 L
s
.5811 .65822 m .58353 .65723 L .5838 .65944 L .862 .577 .504 r
F
.127 .923 .03 r
.58352 .65723 m
.58352 .65723 L
s
.5811 .65822 m .58084 .65602 L .58353 .65723 L .862 .577 .504 r
F
.58406 .65383 m .58353 .65723 L .58585 .65464 L .692 .759 .903 r
F
.58406 .65383 m .58084 .65602 L .58353 .65723 L F
0 g
.58353 .65723 m
.58669 .65791 L
s
.58612 .65684 m .58696 .66012 L .58823 .6573 L .692 .759 .904 r
F
.58612 .65684 m .5838 .65944 L .58696 .66012 L F
0 g
.58696 .66012 m
.59038 .66022 L
s
.57881 .65436 m .58057 .65381 L .58084 .65602 L .935 .633 .444 r
F
.57881 .65436 m .57854 .65215 L .58057 .65381 L F
0 g
.58057 .65381 m
.58268 .65477 L
s
.58248 .6505 m .58062 .65378 L .58383 .6516 L .692 .759 .903 r
F
.58248 .6505 m .5786 .65213 L .58062 .65378 L F
.59962 .655 m .60154 .65091 L .60181 .65311 L .39 .239 .552 r
F
.59989 .65721 m .59962 .655 L .60181 .65311 L F
.59707 .65872 m .59962 .655 L .59989 .65721 L .512 .324 .563 r
F
.59658 .65315 m .59962 .655 L .60181 .65311 L .692 .759 .903 r
F
.59471 .65416 m .59962 .655 L .59658 .65315 L F
0 g
.59681 .65651 m
.59962 .655 L
s
.59497 .65636 m .59707 .65872 L .59989 .65721 L .692 .759 .904 r
F
.59281 .65705 m .59707 .65872 L .59497 .65636 L F
0 g
.59383 .65975 m
.59707 .65872 L
s
.60181 .65311 m .60154 .65091 L .60296 .64877 L .188 .098 .514 r
F
0 g
.59935 .6528 m
.60154 .65091 L
s
.59774 .64968 m .60149 .65089 L .6029 .64876 L .692 .759 .903 r
F
.59628 .65093 m .60149 .65089 L .59774 .64968 L F
.58432 .65603 m .5838 .65944 L .58612 .65684 L .692 .759 .904 r
F
.58432 .65603 m .5811 .65822 L .5838 .65944 L F
0 g
.5838 .65944 m
.58696 .66012 L
s
.127 .923 .03 r
.56876 1.31415 m
.58217 .71737 L
s
.58217 .71737 m
.58348 .65929 L
s
.59037 .65231 m .59025 .65516 L .59254 .65485 L .692 .759 .903 r
F
0 g
.59065 .65196 m
.59065 .65279 L
s
.58923 .65227 m .58796 .65509 L .59025 .65516 L .692 .759 .903 r
F
.59152 .65215 m .59254 .65485 L .59471 .65416 L F
.57907 .65656 m .58084 .65602 L .5811 .65822 L .935 .633 .444 r
F
.57907 .65656 m .57881 .65436 L .58084 .65602 L F
.5827 .65272 m .58084 .65602 L .58406 .65383 L .692 .759 .903 r
F
.5827 .65272 m .57881 .65436 L .58084 .65602 L F
0 g
.58084 .65602 m
.58295 .65697 L
s
.58818 .65204 m .58796 .65509 L .58923 .65227 L .692 .759 .903 r
F
.58818 .65204 m .58585 .65464 L .58796 .65509 L F
.59989 .65721 m .60181 .65311 L .60208 .65532 L .39 .239 .552 r
F
.59685 .65536 m .59989 .65721 L .60208 .65532 L .692 .759 .904 r
F
.59497 .65636 m .59989 .65721 L .59685 .65536 L F
0 g
.59707 .65872 m
.59989 .65721 L
s
.5926 .65181 m .59471 .65416 L .59658 .65315 L .692 .759 .903 r
F
.60181 .65311 m .60296 .64877 L .60323 .65098 L .188 .098 .514 r
F
.60208 .65532 m .60181 .65311 L .60323 .65098 L F
.59804 .65189 m .60181 .65311 L .60323 .65098 L .692 .759 .903 r
F
.59658 .65315 m .60181 .65311 L .59804 .65189 L F
0 g
.59962 .655 m
.60181 .65311 L
s
.58636 .64887 m .58383 .6516 L .58703 .64942 L .692 .759 .903 r
F
.58636 .64887 m .58248 .6505 L .58383 .6516 L F
.57757 .65236 m .57854 .65215 L .57881 .65436 L .974 .67 .297 r
F
.57757 .65236 m .57731 .65016 L .57854 .65215 L F
0 g
.57854 .65215 m
.58041 .65368 L
s
.58166 .64918 m .5786 .65213 L .58248 .6505 L .692 .759 .903 r
F
.58166 .64918 m .57737 .65014 L .5786 .65213 L F
.58728 .65164 m .58585 .65464 L .58818 .65204 L F
.58728 .65164 m .58406 .65383 L .58585 .65464 L F
.59774 .64968 m .6029 .64876 L .59868 .64826 L F
.59398 .64846 m .59774 .64968 L .59868 .64826 L F
.59064 .65451 m .59051 .65737 L .59281 .65705 L .692 .759 .904 r
F
.5895 .65448 m .59051 .65737 L .59064 .65451 L F
.5895 .65448 m .58823 .6573 L .59051 .65737 L F
.59179 .65435 m .59281 .65705 L .59497 .65636 L F
.59064 .65451 m .59281 .65705 L .59179 .65435 L F
.59354 .6513 m .59658 .65315 L .59804 .65189 L .692 .759 .903 r
F
.58297 .65493 m .5811 .65822 L .58432 .65603 L .692 .759 .904 r
F
.58297 .65493 m .57907 .65656 L .5811 .65822 L F
0 g
.5811 .65822 m
.5838 .65944 L
s
.60323 .65098 m .60296 .64877 L .60351 .64653 L 0 0 .386 r
F
0 g
.60154 .65091 m
.60296 .64877 L
s
.59868 .64826 m .6029 .64876 L .60345 .64653 L .692 .759 .903 r
F
.58844 .65425 m .58823 .6573 L .5895 .65448 L .692 .759 .904 r
F
.58844 .65425 m .58612 .65684 L .58823 .6573 L F
.59287 .65401 m .59497 .65636 L .59685 .65536 L F
.59179 .65435 m .59497 .65636 L .59287 .65401 L F
.60208 .65532 m .60323 .65098 L .60349 .65318 L .188 .098 .514 r
F
.59831 .6541 m .60208 .65532 L .60349 .65318 L .692 .759 .904 r
F
.59685 .65536 m .60208 .65532 L .59831 .6541 L F
0 g
.59989 .65721 m
.60208 .65532 L
s
.5866 .65109 m .58406 .65383 L .58728 .65164 L .692 .759 .903 r
F
.5866 .65109 m .5827 .65272 L .58406 .65383 L F
.58595 .64821 m .58248 .6505 L .58636 .64887 L F
.58595 .64821 m .58166 .64918 L .58248 .6505 L F
.57784 .65457 m .57881 .65436 L .57907 .65656 L .974 .67 .297 r
F
.57784 .65457 m .57757 .65236 L .57881 .65436 L F
.58188 .65139 m .57881 .65436 L .5827 .65272 L .692 .759 .903 r
F
.58188 .65139 m .57757 .65236 L .57881 .65436 L F
0 g
.57881 .65436 m
.58068 .65589 L
s
.58754 .65384 m .58612 .65684 L .58844 .65425 L .692 .759 .904 r
F
.58754 .65384 m .58432 .65603 L .58612 .65684 L F
.59804 .65189 m .60323 .65098 L .59899 .65047 L .692 .759 .903 r
F
.59427 .65067 m .59804 .65189 L .59899 .65047 L F
.59868 .64826 m .60345 .64653 L .59904 .64677 L F
.59446 .64775 m .59868 .64826 L .59904 .64677 L F
.59398 .64846 m .59868 .64826 L .59446 .64775 L F
.59381 .65351 m .59685 .65536 L .59831 .6541 L .692 .759 .904 r
F
.59287 .65401 m .59685 .65536 L .59381 .65351 L F
.60323 .65098 m .60351 .64653 L .60378 .64873 L 0 0 .386 r
F
.60349 .65318 m .60323 .65098 L .60378 .64873 L F
.59899 .65047 m .60323 .65098 L .60378 .64873 L .692 .759 .903 r
F
0 g
.60181 .65311 m
.60323 .65098 L
s
.57722 .65017 m .57731 .65016 L .57757 .65236 L .75 .536 0 r
F
.57722 .65017 m .57695 .64796 L .57731 .65016 L F
0 g
.57731 .65016 m
.57854 .65215 L
s
.58142 .64772 m .57737 .65014 L .58166 .64918 L .692 .759 .903 r
F
.58142 .64772 m .57702 .64796 L .57737 .65014 L F
.58687 .65329 m .58432 .65603 L .58754 .65384 L .692 .759 .904 r
F
.58687 .65329 m .58297 .65493 L .58432 .65603 L F
.58619 .65042 m .5827 .65272 L .5866 .65109 L .692 .759 .903 r
F
.58619 .65042 m .58188 .65139 L .5827 .65272 L F
.58215 .6536 m .57907 .65656 L .58297 .65493 L .692 .759 .904 r
F
.58215 .6536 m .57784 .65457 L .57907 .65656 L F
0 g
.57907 .65656 m
.5811 .65822 L
s
.58583 .64748 m .58166 .64918 L .58595 .64821 L .692 .759 .903 r
F
.58583 .64748 m .58142 .64772 L .58166 .64918 L F
.59446 .64775 m .59904 .64677 L .59464 .64701 L F
.59831 .6541 m .60349 .65318 L .59925 .65267 L .692 .759 .904 r
F
.59453 .65288 m .59831 .6541 L .59925 .65267 L F
.59381 .65351 m .59831 .6541 L .59453 .65288 L F
0 g
.59065 .65279 m
.59226 .65258 L
s
.59065 .65279 m
.59065 .65279 L
s
.58907 .65252 m
.59065 .65279 L
s
.60378 .64873 m .60351 .64653 L .60316 .64433 L .749 .534 0 r
F
0 g
.60296 .64877 m
.60349 .64664 L
s
.59904 .64677 m .60345 .64653 L .6031 .64435 L .692 .759 .903 r
F
.59899 .65047 m .60378 .64873 L .59935 .64897 L F
.59474 .64996 m .59899 .65047 L .59935 .64897 L F
.59427 .65067 m .59899 .65047 L .59474 .64996 L F
.59904 .64677 m .6031 .64435 L .59881 .64531 L F
.59464 .64701 m .59904 .64677 L .59881 .64531 L F
.60349 .65318 m .60378 .64873 L .60405 .65094 L 0 0 .386 r
F
.59925 .65267 m .60349 .65318 L .60405 .65094 L .692 .759 .904 r
F
0 g
.60208 .65532 m
.60349 .65318 L
s
.59076 .65166 m .59064 .65451 L .59179 .65435 L .692 .759 .904 r
F
.59076 .65166 m .5895 .65448 L .59064 .65451 L F
.59076 .65166 m .59179 .65435 L .59287 .65401 L F
0 g
.59226 .65258 m
.59329 .65214 L
s
.57748 .65237 m .57757 .65236 L .57784 .65457 L .75 .536 0 r
F
.57748 .65237 m .57722 .65017 L .57757 .65236 L F
.58164 .64993 m .57757 .65236 L .58188 .65139 L .692 .759 .903 r
F
.58164 .64993 m .57722 .65017 L .57757 .65236 L F
0 g
.57757 .65236 m
.5788 .65435 L
s
.59464 .64701 m .59881 .64531 L .59452 .64628 L .692 .759 .903 r
F
.59076 .65166 m .58844 .65425 L .5895 .65448 L .692 .759 .904 r
F
0 g
.58807 .65205 m
.58907 .65252 L
s
.59076 .65166 m .59287 .65401 L .59381 .65351 L .692 .759 .904 r
F
.58645 .65263 m .58297 .65493 L .58687 .65329 L F
.58645 .65263 m .58215 .6536 L .58297 .65493 L F
.59076 .65166 m .58754 .65384 L .58844 .65425 L F
0 g
.58741 .65145 m
.58807 .65205 L
s
.58607 .64969 m .58188 .65139 L .58619 .65042 L .692 .759 .903 r
F
.58607 .64969 m .58164 .64993 L .58188 .65139 L F
.59474 .64996 m .59935 .64897 L .59493 .64921 L F
.58601 .64674 m .58142 .64772 L .58583 .64748 L F
.127 .923 .03 r
.58391 .64719 m
.58451 .59292 L
s
.59076 .65166 m .59381 .65351 L .59453 .65288 L .692 .759 .904 r
F
0 g
.59329 .65214 m
.59401 .65157 L
s
.59401 .65157 m
.59445 .65088 L
s
.58703 .65075 m
.58741 .65145 L
s
.60378 .64873 m .60316 .64433 L .60343 .64654 L .749 .534 0 r
F
.60405 .65094 m .60378 .64873 L .60343 .64654 L F
0 g
.60323 .65098 m
.60375 .64885 L
s
.59935 .64897 m .60378 .64873 L .60343 .64654 L .692 .759 .903 r
F
.59452 .64628 m .59799 .64399 L .59411 .64562 L F
0 g
.59401 .59372 m
.59411 .64562 L
s
.59452 .64628 m .59881 .64531 L .59799 .64399 L .692 .759 .903 r
F
.59925 .65267 m .60405 .65094 L .59962 .65118 L .692 .759 .904 r
F
.59501 .65216 m .59925 .65267 L .59962 .65118 L F
.59453 .65288 m .59925 .65267 L .59501 .65216 L F
.58179 .64623 m .57702 .64796 L .58142 .64772 L .692 .759 .903 r
F
.58601 .64674 m .58179 .64623 L .58142 .64772 L F
.127 .923 .03 r
.58395 .64649 m
.58516 .59242 L
s
.59076 .65166 m .58687 .65329 L .58754 .65384 L .692 .759 .904 r
F
.59935 .64897 m .60343 .64654 L .59912 .64751 L .692 .759 .903 r
F
.59493 .64921 m .59935 .64897 L .59912 .64751 L F
.58179 .64623 m .57756 .64573 L .57702 .64796 L F
.57777 .64792 m .57695 .64796 L .57722 .65017 L 0 0 .385 r
F
0 g
.57727 .64994 m
.57731 .65016 L
s
.57777 .64792 m .5775 .64572 L .57695 .64796 L 0 0 .385 r
F
.59076 .65166 m .59453 .65288 L .59501 .65216 L .692 .759 .904 r
F
.58191 .65213 m .57784 .65457 L .58215 .6536 L F
.58191 .65213 m .57748 .65237 L .57784 .65457 L F
0 g
.57784 .65457 m
.57907 .65656 L
s
.58648 .64603 m .58179 .64623 L .58601 .64674 L .692 .759 .903 r
F
.59493 .64921 m .59912 .64751 L .59481 .64848 L F
0 g
.59445 .65088 m
.59457 .65006 L
s
.59881 .64531 m .60187 .64236 L .59799 .64399 L .692 .759 .903 r
F
.59881 .64531 m .6031 .64435 L .60187 .64236 L F
0 g
.58698 .64993 m
.58703 .65075 L
s
.59411 .64562 m .59664 .64289 L .59344 .64507 L .692 .759 .903 r
F
.59411 .64562 m .59799 .64399 L .59664 .64289 L F
.5905 .64945 m .5944 .64781 L .59372 .64726 L F
0 g
.59411 .64596 m
.59412 .64758 L
s
.5905 .64945 m .59481 .64848 L .5944 .64781 L .692 .759 .903 r
F
0 g
.59412 .64811 m
.59412 .64901 L
s
.59076 .65166 m .58645 .65263 L .58687 .65329 L .692 .759 .904 r
F
.58634 .65189 m .58215 .6536 L .58645 .65263 L F
.58634 .65189 m .58191 .65213 L .58215 .6536 L F
.59501 .65216 m .59962 .65118 L .59519 .65142 L F
.59076 .65166 m .59501 .65216 L .59519 .65142 L F
.58625 .64894 m .58164 .64993 L .58607 .64969 L .692 .759 .903 r
F
.127 .923 .03 r
.58389 .64945 m
.58391 .64746 L
s
.60343 .64654 m .60316 .64433 L .60193 .64234 L .973 .67 .296 r
F
0 g
.60316 .64433 m
.60351 .64653 L
s
.58648 .64603 m .58273 .64481 L .58179 .64623 L .692 .759 .903 r
F
.58721 .6454 m .58273 .64481 L .58648 .64603 L F
.60405 .65094 m .60343 .64654 L .60369 .64874 L .749 .534 0 r
F
.59962 .65118 m .60405 .65094 L .60369 .64874 L .692 .759 .904 r
F
0 g
.60349 .65318 m
.60405 .65094 L
s
.59481 .64848 m .59829 .64618 L .5944 .64781 L .692 .759 .903 r
F
.59481 .64848 m .59912 .64751 L .59829 .64618 L F
.58201 .64843 m .57722 .65017 L .58164 .64993 L F
.58625 .64894 m .58201 .64843 L .58164 .64993 L F
.127 .923 .03 r
.5839 .64866 m
.58393 .64713 L
s
.59344 .64507 m .59486 .64208 L .59254 .64466 L .692 .759 .903 r
F
.59344 .64507 m .59664 .64289 L .59486 .64208 L F
.58273 .64481 m .57756 .64573 L .58179 .64623 L F
.59962 .65118 m .60369 .64874 L .59938 .64971 L .692 .759 .904 r
F
.59519 .65142 m .59962 .65118 L .59938 .64971 L F
.59076 .65166 m .58634 .65189 L .58645 .65263 L F
.57803 .65013 m .57722 .65017 L .57748 .65237 L 0 0 .385 r
F
0 g
.57754 .65215 m
.57757 .65236 L
s
.58201 .64843 m .57777 .64792 L .57722 .65017 L .692 .759 .903 r
F
.57803 .65013 m .57777 .64792 L .57722 .65017 L 0 0 .385 r
F
.58721 .6454 m .58418 .64356 L .58273 .64481 L .692 .759 .903 r
F
.58814 .6449 m .58418 .64356 L .58721 .6454 L F
.59519 .65142 m .59938 .64971 L .59507 .65068 L .692 .759 .904 r
F
.59076 .65166 m .59519 .65142 L .59507 .65068 L F
.58673 .64823 m .58201 .64843 L .58625 .64894 L .692 .759 .903 r
F
.59912 .64751 m .60219 .64454 L .59829 .64618 L F
.59912 .64751 m .60343 .64654 L .60219 .64454 L F
.59254 .64466 m .59276 .64163 L .59149 .64444 L F
.59254 .64466 m .59486 .64208 L .59276 .64163 L F
.59799 .64399 m .59985 .64071 L .59664 .64289 L F
.59799 .64399 m .60187 .64236 L .59985 .64071 L F
.5944 .64781 m .59694 .64507 L .59372 .64726 L F
.5944 .64781 m .59829 .64618 L .59694 .64507 L F
.59076 .65166 m .58652 .65115 L .58634 .65189 L .692 .759 .904 r
F
.59076 .65166 m .58699 .65043 L .58652 .65115 L F
.59076 .65166 m .58772 .6498 L .58699 .65043 L F
0 g
.58698 .64993 m
.58752 .64889 L
s
.59076 .65166 m .58866 .6493 L .58772 .6498 L .692 .759 .904 r
F
.59076 .65166 m .58974 .64896 L .58866 .6493 L F
.59076 .65166 m .59089 .6488 L .58974 .64896 L F
.59076 .65166 m .59203 .64883 L .59089 .6488 L F
.59076 .65166 m .59309 .64906 L .59203 .64883 L F
.59076 .65166 m .59398 .64947 L .59309 .64906 L F
.59076 .65166 m .59466 .65002 L .59398 .64947 L F
0 g
.59412 .64901 m
.59449 .64988 L
s
.59457 .65006 m
.59457 .65006 L
s
.59076 .65166 m .59507 .65068 L .59466 .65002 L .692 .759 .904 r
F
.58814 .6449 m .58605 .64256 L .58418 .64356 L .692 .759 .903 r
F
.58921 .64456 m .58605 .64256 L .58814 .6449 L F
.59149 .64444 m .59049 .64156 L .59036 .6444 L F
.59149 .64444 m .59276 .64163 L .59049 .64156 L F
.58652 .65115 m .58191 .65213 L .58634 .65189 L .692 .759 .904 r
F
.127 .923 .03 r
.58387 .65172 m
.58389 .64966 L
s
.60343 .64654 m .60193 .64234 L .60219 .64454 L .973 .67 .296 r
F
.60369 .64874 m .60343 .64654 L .60219 .64454 L F
0 g
.60343 .64654 m
.60378 .64873 L
s
.59305 .64818 m
.59412 .64901 L
s
.59412 .64901 m
.59412 .64901 L
s
.58921 .64456 m .5882 .64187 L .58605 .64256 L .692 .759 .903 r
F
.59036 .6444 m .5882 .64187 L .58921 .64456 L F
0 g
.58752 .64889 m
.58752 .64889 L
s
.58752 .64889 m
.58865 .6481 L
s
.59036 .6444 m .59049 .64156 L .5882 .64187 L .692 .759 .903 r
F
.58673 .64823 m .58296 .64701 L .58201 .64843 L F
.58746 .6476 m .58296 .64701 L .58673 .64823 L F
.58273 .64481 m .57898 .6436 L .57756 .64573 L F
.57918 .64579 m .5775 .64572 L .57777 .64792 L .187 .097 .514 r
F
.57918 .64579 m .57892 .64358 L .5775 .64572 L F
0 g
.57695 .64796 m
.5775 .64572 L
s
.59507 .65068 m .59856 .64838 L .59466 .65002 L .692 .759 .904 r
F
.59507 .65068 m .59938 .64971 L .59856 .64838 L F
.58228 .65064 m .57748 .65237 L .58191 .65213 L F
.58652 .65115 m .58228 .65064 L .58191 .65213 L F
.127 .923 .03 r
.58385 .65083 m
.58388 .64934 L
s
.58333 .70124 m
.58386 .65186 L
s
.49625 8.80051 m
.58333 .70124 L
s
0 0 0 r
2.5 Mabswid
.58386 .65186 Mdot
.59372 .64726 m .59515 .64426 L .59282 .64686 L .692 .759 .903 r
F
.59372 .64726 m .59694 .64507 L .59515 .64426 L F
.58296 .64701 m .57777 .64792 L .58201 .64843 L F
.58228 .65064 m .57803 .65013 L .57748 .65237 L .692 .759 .904 r
F
0 g
.5 Mabswid
.57748 .65237 m
.57784 .65457 L
s
.58418 .64356 m .57898 .6436 L .58273 .64481 L .692 .759 .903 r
F
0 0 0 r
2.5 Mabswid
.58383 .65155 Mdot
.127 .923 .03 r
.5 Mabswid
.40004 8.82345 m
.58286 .69496 L
s
.58286 .69496 m
.58383 .65155 L
s
.58746 .6476 m .58442 .64575 L .58296 .64701 L .692 .759 .903 r
F
.58839 .64709 m .58442 .64575 L .58746 .6476 L F
.58699 .65043 m .58228 .65064 L .58652 .65115 L .692 .759 .904 r
F
.59938 .64971 m .60246 .64675 L .59856 .64838 L F
.59938 .64971 m .60369 .64874 L .60246 .64675 L F
0 g
.59197 .6478 m
.59305 .64818 L
s
.58865 .6481 m
.58977 .64776 L
s
.59282 .64686 m .59304 .6438 L .59177 .64663 L .692 .759 .903 r
F
.59282 .64686 m .59515 .64426 L .59304 .6438 L F
.60219 .64454 m .60193 .64234 L .5999 .64067 L .935 .633 .443 r
F
0 g
.60193 .64234 m
.60316 .64433 L
s
.59829 .64618 m .60016 .64288 L .59694 .64507 L .692 .759 .903 r
F
.59829 .64618 m .60219 .64454 L .60016 .64288 L F
.59664 .64289 m .59717 .6395 L .59486 .64208 L F
.59664 .64289 m .59985 .64071 L .59717 .6395 L F
.59466 .65002 m .59721 .64727 L .59398 .64947 L .692 .759 .904 r
F
.59466 .65002 m .59856 .64838 L .59721 .64727 L F
.58839 .64709 m .58629 .64474 L .58442 .64575 L .692 .759 .903 r
F
.58948 .64675 m .58629 .64474 L .58839 .64709 L F
0 g
.59087 .64767 m
.59197 .6478 L
s
.58977 .64776 m
.59087 .64767 L
s
.59177 .64663 m .59075 .64373 L .59063 .64659 L .692 .759 .903 r
F
.59177 .64663 m .59304 .6438 L .59075 .64373 L F
.60369 .64874 m .60219 .64454 L .60246 .64675 L .973 .67 .296 r
F
0 g
.60369 .64874 m
.60405 .65094 L
s
.58948 .64675 m .58845 .64405 L .58629 .64474 L .692 .759 .903 r
F
.59063 .64659 m .58845 .64405 L .58948 .64675 L F
.59063 .64659 m .59075 .64373 L .58845 .64405 L F
.58699 .65043 m .58322 .64921 L .58228 .65064 L .692 .759 .904 r
F
.58772 .6498 m .58322 .64921 L .58699 .65043 L F
.57945 .64799 m .57777 .64792 L .57803 .65013 L .187 .097 .514 r
F
.58296 .64701 m .57918 .64579 L .57777 .64792 L .692 .759 .903 r
F
.57945 .64799 m .57918 .64579 L .57777 .64792 L .187 .097 .514 r
F
0 g
.57722 .65017 m
.57777 .64792 L
s
.59398 .64947 m .59541 .64647 L .59309 .64906 L .692 .759 .904 r
F
.59398 .64947 m .59721 .64727 L .59541 .64647 L F
.58418 .64356 m .58115 .64172 L .57898 .6436 L .692 .759 .903 r
F
.58605 .64256 m .58115 .64172 L .58418 .64356 L F
.58322 .64921 m .57803 .65013 L .58228 .65064 L .692 .759 .904 r
F
.58442 .64575 m .57918 .64579 L .58296 .64701 L .692 .759 .903 r
F
.58772 .6498 m .58468 .64795 L .58322 .64921 L .692 .759 .904 r
F
.58866 .6493 m .58468 .64795 L .58772 .6498 L F
.59486 .64208 m .59402 .63882 L .59276 .64163 L .692 .759 .903 r
F
.59486 .64208 m .59717 .6395 L .59402 .63882 L F
.59309 .64906 m .5933 .64601 L .59203 .64883 L .692 .759 .904 r
F
.59309 .64906 m .59541 .64647 L .5933 .64601 L F
.60219 .64454 m .5999 .64067 L .60016 .64288 L .935 .633 .443 r
F
.60246 .64675 m .60219 .64454 L .60016 .64288 L F
0 g
.60219 .64454 m
.60343 .64654 L
s
.59856 .64838 m .60043 .64508 L .59721 .64727 L .692 .759 .904 r
F
.59856 .64838 m .60246 .64675 L .60043 .64508 L F
.59694 .64507 m .59747 .64167 L .59515 .64426 L .692 .759 .903 r
F
.59694 .64507 m .60016 .64288 L .59747 .64167 L F
.58137 .64389 m .57892 .64358 L .57918 .64579 L .39 .238 .552 r
F
.58137 .64389 m .58111 .64169 L .57892 .64358 L F
0 g
.5775 .64572 m
.57892 .64358 L
s
.58866 .6493 m .58656 .64694 L .58468 .64795 L .692 .759 .904 r
F
.58974 .64896 m .58656 .64694 L .58866 .6493 L F
.59203 .64883 m .59102 .64594 L .59089 .6488 L F
.59203 .64883 m .5933 .64601 L .59102 .64594 L F
.58605 .64256 m .58395 .64021 L .58115 .64172 L .692 .759 .903 r
F
.5882 .64187 m .58395 .64021 L .58605 .64256 L F
.58974 .64896 m .58872 .64626 L .58656 .64694 L .692 .759 .904 r
F
.59089 .6488 m .58872 .64626 L .58974 .64896 L F
.59089 .6488 m .59102 .64594 L .58872 .64626 L F
.59276 .64163 m .59061 .63871 L .59049 .64156 L .692 .759 .903 r
F
.59276 .64163 m .59402 .63882 L .59061 .63871 L F
.58322 .64921 m .57945 .64799 L .57803 .65013 L .692 .759 .904 r
F
0 g
.57748 .65237 m
.57803 .65013 L
s
.60016 .64288 m .5999 .64067 L .5972 .63946 L .862 .577 .503 r
F
0 g
.5999 .64067 m
.60193 .64234 L
s
.5882 .64187 m .58718 .63919 L .58395 .64021 L .692 .759 .903 r
F
.59049 .64156 m .58718 .63919 L .5882 .64187 L F
.58442 .64575 m .58137 .64389 L .57918 .64579 L F
.58629 .64474 m .58137 .64389 L .58442 .64575 L F
.59049 .64156 m .59061 .63871 L .58718 .63919 L F
.58468 .64795 m .57945 .64799 L .58322 .64921 L .692 .759 .904 r
F
.59515 .64426 m .5943 .64098 L .59304 .6438 L .692 .759 .903 r
F
.59515 .64426 m .59747 .64167 L .5943 .64098 L F
.60246 .64675 m .60016 .64288 L .60043 .64508 L .935 .633 .443 r
F
0 g
.60246 .64675 m
.60369 .64874 L
s
.59721 .64727 m .59774 .64387 L .59541 .64647 L .692 .759 .904 r
F
.59721 .64727 m .60043 .64508 L .59774 .64387 L F
.58164 .6461 m .57918 .64579 L .57945 .64799 L .39 .238 .552 r
F
.58164 .6461 m .58137 .64389 L .57918 .64579 L F
0 g
.57777 .64792 m
.57918 .64579 L
s
.58629 .64474 m .58419 .64238 L .58137 .64389 L .692 .759 .903 r
F
.58845 .64405 m .58419 .64238 L .58629 .64474 L F
.58419 .64238 m .58111 .64169 L .58137 .64389 L .512 .324 .563 r
F
.58419 .64238 m .58392 .64018 L .58111 .64169 L F
0 g
.57892 .64358 m
.58111 .64169 L
s
.59304 .6438 m .59088 .64087 L .59075 .64373 L .692 .759 .903 r
F
.59304 .6438 m .5943 .64098 L .59088 .64087 L F
.60016 .64288 m .5972 .63946 L .59747 .64167 L .862 .577 .503 r
F
.60043 .64508 m .60016 .64288 L .59747 .64167 L F
0 g
.60016 .64288 m
.60219 .64454 L
s
.58468 .64795 m .58164 .6461 L .57945 .64799 L .692 .759 .904 r
F
0 g
.57803 .65013 m
.57945 .64799 L
s
.58656 .64694 m .58164 .6461 L .58468 .64795 L .692 .759 .904 r
F
.58845 .64405 m .58743 .64135 L .58419 .64238 L .692 .759 .903 r
F
.59075 .64373 m .58743 .64135 L .58845 .64405 L F
.59075 .64373 m .59088 .64087 L .58743 .64135 L F
.59747 .64167 m .5972 .63946 L .59404 .63878 L .794 .526 .533 r
F
0 g
.5972 .63946 m
.5999 .64067 L
s
.59541 .64647 m .59457 .64319 L .5933 .64601 L .692 .759 .904 r
F
.59541 .64647 m .59774 .64387 L .59457 .64319 L F
.58656 .64694 m .58445 .64459 L .58164 .6461 L F
.58872 .64626 m .58445 .64459 L .58656 .64694 L F
.58743 .64135 m .58392 .64018 L .58419 .64238 L .598 .385 .563 r
F
.58743 .64135 m .58716 .63915 L .58392 .64018 L F
0 g
.58111 .64169 m
.58392 .64018 L
s
.58445 .64459 m .58137 .64389 L .58164 .6461 L .512 .324 .563 r
F
0 g
.57945 .64799 m
.58164 .6461 L
s
.58445 .64459 m .58419 .64238 L .58137 .64389 L .512 .324 .563 r
F
0 g
.57918 .64579 m
.58137 .64389 L
s
.5933 .64601 m .59114 .64308 L .59102 .64594 L .692 .759 .904 r
F
.5933 .64601 m .59457 .64319 L .59114 .64308 L F
.60043 .64508 m .59747 .64167 L .59774 .64387 L .862 .577 .503 r
F
0 g
.60043 .64508 m
.60246 .64675 L
s
.5943 .64098 m .59404 .63878 L .59061 .63867 L .731 .48 .549 r
F
.59747 .64167 m .59404 .63878 L .5943 .64098 L .794 .526 .533 r
F
0 g
.59404 .63878 m
.5972 .63946 L
s
.58872 .64626 m .58769 .64356 L .58445 .64459 L .692 .759 .904 r
F
.59102 .64594 m .58769 .64356 L .58872 .64626 L F
.59102 .64594 m .59114 .64308 L .58769 .64356 L F
.59774 .64387 m .59747 .64167 L .5943 .64098 L .794 .526 .533 r
F
0 g
.59747 .64167 m
.60016 .64288 L
s
.59088 .64087 m .58716 .63915 L .58743 .64135 L .668 .435 .558 r
F
.59088 .64087 m .59061 .63867 L .58716 .63915 L F
0 g
.58392 .64018 m
.58716 .63915 L
s
.5943 .64098 m .59061 .63867 L .59088 .64087 L .731 .48 .549 r
F
0 g
.58716 .63915 m
.59061 .63867 L
s
.59061 .63867 m
.59404 .63878 L
s
.127 .923 .03 r
.59219 .63944 m
.59224 .63722 L
s
.59371 .63886 m
.59374 .63665 L
s
.58769 .64356 m .58419 .64238 L .58445 .64459 L .598 .385 .563 r
F
.58769 .64356 m .58743 .64135 L .58419 .64238 L F
0 g
.58137 .64389 m
.58419 .64238 L
s
.58164 .6461 m
.58445 .64459 L
s
.59457 .64319 m .5943 .64098 L .59088 .64087 L .731 .48 .549 r
F
.59774 .64387 m .5943 .64098 L .59457 .64319 L .794 .526 .533 r
F
0 g
.5943 .64098 m
.59747 .64167 L
s
.59774 .64387 m
.60043 .64508 L
s
.59114 .64308 m .58743 .64135 L .58769 .64356 L .668 .435 .558 r
F
.59114 .64308 m .59088 .64087 L .58743 .64135 L F
0 g
.58419 .64238 m
.58743 .64135 L
s
.59457 .64319 m .59088 .64087 L .59114 .64308 L .731 .48 .549 r
F
0 g
.58743 .64135 m
.59088 .64087 L
s
.59088 .64087 m
.5943 .64098 L
s
.127 .923 .03 r
.58409 .98466 m
.59219 .63944 L
s
.58713 1.19053 m
.59371 .63886 L
s
0 g
.59457 .64319 m
.59774 .64387 L
s
.58445 .64459 m
.58769 .64356 L
s
.59114 .64308 m
.59457 .64319 L
s
.58769 .64356 m
.59114 .64308 L
s
0 0 0 r
2.5 Mabswid
.67862 1.50701 Mdot
.78829 1.85904 Mdot
.44909 2.53122 Mdot
.34149 4.70583 Mdot
.08551 5.25235 Mdot
0 g
.5 Mabswid
.36293 9.01957 m
.94663 8.86555 L
s
.04255 8.73353 m
.36293 9.01957 L
s
.94663 8.86555 m
.63161 8.57547 L
s
0 0 0 r
2.5 Mabswid
.3996 8.82805 Mdot
.127 .923 .03 r
.5 Mabswid
.3996 8.8281 m
.3996 8.82805 L
s
0 0 0 r
2.5 Mabswid
.39815 8.82667 Mdot
.127 .923 .03 r
.5 Mabswid
.39815 8.82667 m
.39815 8.82667 L
s
0 0 0 r
2.5 Mabswid
.4049 8.82661 Mdot
.127 .923 .03 r
.5 Mabswid
.40489 8.82676 m
.4049 8.82661 L
s
0 0 0 r
2.5 Mabswid
.40116 8.82614 Mdot
.127 .923 .03 r
.5 Mabswid
.40116 8.82618 m
.40116 8.82614 L
s
0 0 0 r
2.5 Mabswid
.39329 8.82613 Mdot
.127 .923 .03 r
.5 Mabswid
.39329 8.82615 m
.39329 8.82613 L
s
0 0 0 r
2.5 Mabswid
.40054 8.82589 Mdot
.127 .923 .03 r
.5 Mabswid
.40054 8.82592 m
.40054 8.82589 L
s
0 0 0 r
2.5 Mabswid
.40384 8.82585 Mdot
.127 .923 .03 r
.5 Mabswid
.40384 8.82597 m
.40384 8.82585 L
s
0 0 0 r
2.5 Mabswid
.40262 8.82573 Mdot
.127 .923 .03 r
.5 Mabswid
.40261 8.82581 m
.40262 8.82573 L
s
0 0 0 r
2.5 Mabswid
.40334 8.82521 Mdot
.127 .923 .03 r
.5 Mabswid
.40334 8.82532 m
.40334 8.82521 L
s
0 0 0 r
2.5 Mabswid
.39671 8.82509 Mdot
.127 .923 .03 r
.5 Mabswid
.39671 8.82509 m
.39671 8.82509 L
s
0 0 0 r
2.5 Mabswid
.39828 8.82468 Mdot
.127 .923 .03 r
.5 Mabswid
.39828 8.8247 m
.39828 8.82468 L
s
0 0 0 r
2.5 Mabswid
.39412 8.82417 Mdot
.127 .923 .03 r
.5 Mabswid
.39412 8.82422 m
.39412 8.82417 L
s
0 0 0 r
2.5 Mabswid
.39845 8.82406 Mdot
.127 .923 .03 r
.5 Mabswid
.39845 8.8241 m
.39845 8.82406 L
s
0 0 0 r
2.5 Mabswid
.39805 8.82368 Mdot
.127 .923 .03 r
.5 Mabswid
.39805 8.82374 m
.39805 8.82368 L
s
0 0 0 r
2.5 Mabswid
.39737 8.82338 Mdot
.127 .923 .03 r
.5 Mabswid
.39737 8.82346 m
.39737 8.82338 L
s
0 0 0 r
2.5 Mabswid
.39855 8.82301 Mdot
.127 .923 .03 r
.5 Mabswid
.39854 8.82311 m
.39855 8.82301 L
s
0 0 0 r
2.5 Mabswid
.49519 8.80075 Mdot
.49499 8.80062 Mdot
.49577 8.80062 Mdot
.49608 8.8006 Mdot
.49587 8.80054 Mdot
.49566 8.80052 Mdot
.49625 8.80051 Mdot
.49533 8.8005 Mdot
.49645 8.80049 Mdot
.49618 8.80046 Mdot
.49633 8.80045 Mdot
.49728 8.80043 Mdot
.49644 8.80042 Mdot
.49478 8.80031 Mdot
.49569 8.80031 Mdot
.49451 8.80016 Mdot
.49647 8.80003 Mdot
.49478 8.79996 Mdot
.4947 8.79995 Mdot
.49617 8.79995 Mdot
.49587 8.79989 Mdot
.49498 8.79989 Mdot
.49803 8.79987 Mdot
.49419 8.79983 Mdot
.49806 8.79983 Mdot
.4981 8.79982 Mdot
.49582 8.79963 Mdot
.49426 8.7996 Mdot
.49362 8.7996 Mdot
.49596 8.79958 Mdot
.49608 8.79957 Mdot
.49551 8.79957 Mdot
.49472 8.79955 Mdot
.49551 8.79951 Mdot
.49627 8.79949 Mdot
.4962 8.79943 Mdot
.49725 8.79938 Mdot
.4947 8.79935 Mdot
.49674 8.79934 Mdot
.49653 8.79933 Mdot
.49676 8.79933 Mdot
.49363 8.79926 Mdot
.4958 8.79919 Mdot
.49723 8.79917 Mdot
.49525 8.79912 Mdot
.49738 8.7991 Mdot
.49731 8.79909 Mdot
.49657 8.79907 Mdot
.49646 8.79878 Mdot
.49666 8.79866 Mdot
.49649 8.79864 Mdot
0 g
.5 Mabswid
.63161 8.57547 m
.04255 8.73353 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 2674.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000:LR000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00[P3oool200000700oooo002[0?ooo`<0000000<0oooo000000000000K`3oool00:P0oooo
0`0000040?ooo`030000003oool0000006h0oooo002U0?ooo`<000001`3oool00`000000oooo0000
001^0?ooo`00X`3oool2000000X0oooo00@000000?ooo`3oool00000K@3oool00:00oooo0`00000<
0?ooo`050000003oool0oooo0?ooo`000000K03oool009d0oooo0`00000?0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0J@3oool009/0oooo0P00000B0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0J03oool009P0oooo0`00000D0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0J03oool009H0oooo0P00000G0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0I`3oool009<0oooo0`00000I0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0IP3oool00940oooo0P00000L0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0I@3oool008h0oooo0`00000G0?ooo`<00000103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo06D0oooo002;0?ooo`<000006P3oool00`000000chZ7000000040?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0I03oool008T0oooo0P00000M0?ooo`030000
003?RXL0000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1S0?ooo`00QP3o
ool3000001l0oooo00<000000<n:Q`000000103oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0680oooo00240?ooo`8000006P3oool@000000/0oooo00<000000?ooo`3oool0HP3oool0
0840oooo0`00000G0?ooo`D000000`2GGH/70:Y^S@D0^gb>1@0000080?ooo`030000003oool0oooo
0640oooo001o0?ooo`800000603oool20000000307e8QP2GGH/0Uef;00<0Uef;3`000000102kO8h0
bhZ>0<^:SP3;RXh3000000H0oooo00<000000?ooo`3oool0H03oool007`0oooo0`00000H0?ooo`80
00000`1mB8H209MMR`<000000P2GGH/70:Y^S@D0^gb>1@0000030<^:SP8000001@3oool00`000000
oooo0?ooo`1O0?ooo`00N@3oool3000001T0oooo0P00000407e8QP<000000`2GGH/?000000040;]l
SP3;RXh0bhZ>0<^:SP<000000P3KVH`2000000@0oooo00<000000?ooo`3oool0GP3oool007H0oooo
0`00000K0?ooo`040000001F:7`0ODR607e8QP<0000000<0ODR609MMR`2GGH/00`0000000`0Pk0L0
YkWV0:NiiP0;0:NiiPD000000`3;RXh200000080fiV<0P0000020?ooo`030000003oool0oooo05h0
oooo001c0?ooo`<000007@3oool00`000000ERQl00000002000000<0ODR60`0000020:NiiP030000
000Pk0L0YkWV00`0YkWV00<000000:NiiP2W^NH00P2W^NH300000080fiV<0P0000020=^IS0040000
003oool0oooo000005l0oooo001`0?ooo`<000007`3oool010000000ERQl0000001F:7`207e8QP<0
00001P2W^NH00`0Pk0L0YkWV0:NiiP0;0:NiiP030000002W^NH0YkWV00D0YkWV0P0000020=^IS080
000000D0kZ^50000003oool0oooo0000001N0?ooo`00K@3oool300000280oooo0P00000205HXO080
00002@2W^NH00`0Pk0L0YkWV0:NiiP0;0:NiiP030000002W^NH0YkWV00L0YkWV0P0000020=^IS003
0000003^ZhD000000080oooo00<000000?ooo`3oool0F`3oool006X0oooo0`00000T0?ooo`800000
0P1F:7`00`000000YkWV0:NiiP090:NiiP03023/1`2W^NH0YkWV00/0YkWV00<000000:NiiP2W^NH0
2@2W^NH2000000060>j[Q@000000kZ^50000003oool00000G@3oool006L0oooo0`00000V0?ooo`05
0000000@06@0000005HXO0000000302W^NH00`0Pk0L0YkWV0:NiiP0;0:NiiP030000002W^NH0YkWV
00/0YkWV00L000000>j[Q@000000kZ^50000003oool0000005`0oooo001U0?ooo`800000203oool3
000001d0oooo00D000000100I0000000ERQl0000000<0:NiiP808>`73@2W^NH00`000000YkWV0:Ni
iP0<0:NiiP040000003^ZhD0000000000080oooo00<000000?ooo`3oool0F@3oool006<0oooo0P00
00090?ooo`80000000<0j:5o0000003oool0703oool2000000030100I0000000YkWV00`0YkWV0P0P
k0L=0:NiiP030000002W^NH0YkWV00d0YkWV00@000000>j[Q@00000000000P3oool00`000000oooo
0?ooo`1H0?ooo`00H@3oool2000000/0oooo00@0001O0000003XXGl000007@3oool2000000030100
I0000000YkWV00`0YkWV0P0Pk0L=0:NiiP030000002W^NH0YkWV00h0YkWV0P000000103m_W<00000
0?ooo`00001J0?ooo`00GP3oool3000000d0oooo00@0001O0000003XXGl00000703oool200000003
0100I0000000YkWV00d0YkWV0P0Pk0L=0:NiiP030000002W^NH0YkWV00l0YkWV0P000000103m_W<0
00000?ooo`00001I0?ooo`00F`3oool3000000X0oooo3@00000I0?ooo`<000003`2W^NH2023/1`d0
YkWV00<000000:NiiP2W^NH03`2W^NH2000000050?fnL`000000oooo0?ooo`000000F03oool005P0
oooo0`00000:0?ooo`<0000000<0Uef;0:Y^S@2ZKXd01@2ZKXd50;]lSPD00000503oool200000100
YkWV0P0Pk0L=0:NiiP030000002W^NH0YkWV0100YkWV0`0000030?ooo`030000003oool0oooo05D0
oooo001F0?ooo`8000002P3oool3000000<0Uef;3@0000020;]lSP<0bhZ>0`00000A0?ooo`800000
402W^NH2023/1`d0YkWV00<000000:NiiP2W^NH0402W^NH3000000<0oooo00<000000?ooo`3oool0
E@3oool005<0oooo0`0000090?ooo`<0000000<0ODR609MMR`2GGH/00`0000000`2GGH/0ZVj=0:Y^
S@050:Y^S@D0^gb>1@0000030<^:SP<000003P3oool200000100YkWV0P0Pk0L;0:NiiP030:bli@2W
^NH0000001<0YkWV0P0000040?ooo`030000003oool0oooo05@0oooo001A0?ooo`8000002@3oool3
000000<0ODR60`00000209MMR`h000000P2kO8h30<^:SP<0000000<0bhZ>0=^IS03KVH`00P00000<
0?ooo`030000002W^NH0YkWV00l0YkWV0P0Pk0L20:NiiP80[;cU2@2W^NH00`000000YkWV0:NiiP09
0:NiiP8000001P2W^NH2000000D0oooo00<000000?ooo`3oool0D`3oool004l0oooo0P00000:0?oo
o`040000001F:7`0ODR607e8QP<0000000<0ODR609MMR`0000000P00000>0:NiiPD000000`3;RXh3
00000080fiV<00<000000?ooo`3oool02@3oool00`000000YkWV0:NiiP0>0:NiiP03023/1`2W^NH0
8>`700@0YkWV00@0[;cU0:NiiP2W^NH0chZ71@2W^NH00`000000YkWV0:NiiP090:NiiP030000000P
k0L0YkWV00D0YkWV0P0000050?ooo`030000003oool0oooo05<0oooo001<0?ooo`<000002`3oool0
0`000000ERQl0000000200000080ODR60`00000F0:NiiP<0000000<0bhZ>0=^IS03KVH`00P000000
0`3KVH`00000000000090?ooo`030000002W^NH0YkWV00h0YkWV00<08>`70:NiiP0Pk0L00`2W^NH0
1P2/_>D0YkWV0:NiiP000000chZ7000000@0YkWV00<000000:NiiP2W^NH02P2W^NH00`0Pk0L0YkWV
0:NiiP050:NiiP030000003oool0oooo00@0oooo00<000000?ooo`3oool0DP3oool004T0oooo0`00
000=0?ooo`050000001F:7`0000005HXO01mB8H00`00000L0:NiiP<000000P3KVH`010000000kJ^6
0>f[QP0000080?ooo`030000002W^NH0YkWV00@0YkWV00<00000023/1`2W^NH01`2W^NH00`0Pk0L0
YkWV023/1`030:NiiP80[;cU00@0YkWV0000003?RXL00000102W^NH00`000000YkWV0:NiiP0:0:Ni
iP03023/1`2W^NH0YkWV00D0YkWV00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1A0?oo
o`00AP3oool300000100oooo0P0000000`1F:7`000000000000R0:NiiP80000000D0fiV<0000003]
ZhH0kJ^6000000070?ooo`030000002W^NH0YkWV00D0YkWV00<08>`70:NiiP2W^NH01P2W^NH00`0P
k0L0YkWV023/1`050:NiiP030:bli@000000chZ7008000000`2W^NH00`000000YkWV0:NiiP0:0:Ni
iP03023/1`2W^NH0YkWV00D0YkWV00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1@0?oo
o`00@`3oool300000180oooo0P0000000`1F:7`000000:NiiP0U0:NiiP030000003]ZhH000000080
kJ^600<000000?ooo`3oool0103oool00`000000YkWV0:NiiP050:NiiP03023/1`0000008>`700H0
YkWV00<08>`70:NiiP0Pk0L01P2W^NH00`000000YkWV000000040:NiiP030000002W^NH0YkWV00X0
YkWV00<08>`70:NiiP2W^NH01@2W^NH00`000000oooo0?ooo`060?ooo`030000003oool0oooo0500
oooo00100?ooo`<00000503oool20000000305HXO0000000YkWV02L0YkWV00<000000>f[QP000000
0P3]ZhH00`000000oooo0?ooo`030?ooo`030000002W^NH0YkWV00D0YkWV00<08>`70000000Pk0L0
1P2W^NH00`0Pk0L0YkWV023/1`050:NiiPH000000P2W^NH00`000000YkWV0:NiiP0:0:NiiP03023/
1`2W^NH0YkWV00D0YkWV00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1?0?ooo`00?@3o
ool3000001L0oooo0`00000Z0:NiiP050000003]ZhH000000>f[QP0000001@3oool00`000000YkWV
0:NiiP050:NiiP03023/1`2W^NH08>`700H0YkWV00<08>`70:NiiP0000001@0000020:]bTP@0^gjA
1P0000090:NiiP03023/1`2W^NH0YkWV00@0YkWV00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1>0?ooo`00>P3oool3000001T0oooo0`00000/0:NiiP050000003]ZhH000000?fnM0000000
1@3oool00`000000YkWV0:NiiP040:NiiP03023/1`2W^NH08>`700@0YkWV100000000`0Pk0L0VVFB
0000000B000000H0YkWV00<08>`70:NiiP2W^NH0102W^NH00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo04d0oooo000g0?ooo`<00000703oool3000002d0YkWV0P0000000`3m_W@000000?oo
o`050?ooo`030000002W^NH0YkWV00@0YkWV0P0Pk0L20:NiiP80000000<0Pe>@09YUTP0Pk0L00`00
00000`2JII80Zg:B0:]bTP040:]bTPD0^gjA00@000000<^;SP3;Rhh0bh^>1P0000030:NiiP03023/
1`2W^NH0YkWV00@0YkWV1@0000090?ooo`030000003oool0oooo04`0oooo000d0?ooo`<000007`3o
ool2000002l0YkWV0P0000000`3m_W@000000?ooo`050?ooo`030000002W^NH0000000<0YkWV0P0P
k0L2000000<0Pe>@0P0000000`2JII808>`709YUTP0@000000030<^;SP3LV8T0g9R90080000000D0
g9R90000002W^NH0YkWV023/1`050:NiiP030000002kO8h0^gb>00<0^gb>1@0000050?ooo`030000
003oool0oooo04/0oooo000b0?ooo`8000008@3oool200000300YkWV00@000000?fnM00000000000
1`3oool00`000000YkWV0:NiiP020:NiiP04023/1`000000HS^<08=CT0<0000000<0Pe>@09YUTP00
00000P00000<0:c1j@040000002/`NT0[<7Y0:c1j@<000000P3LV8T01@000000kjQm0000002W^NH0
8>`700@0YkWV00<000000:NiiP0000000`0000030;]lSP<0bhZ>0`0000030?ooo`030000003oool0
oooo04X0oooo000_0?ooo`<000008`3oool00`000000YkWV0:NiiP0`0:NiiP030000003m_W@00000
00P0oooo00H000000:NiiP2W^NH0YkWV0000001R>h`2000000<0Pe>@0P0000000`2/`NT08>`70:c1
j@0<0:c1j@030000002/`NT0[<7Y00@0[<7Y1P0000001P0Pk0L0YkWV0:NiiP2W^NH000000:NiiPD0
^gb>1@0000040<^:SP8000000P3oool00`000000oooo0?ooo`190?ooo`00;03oool3000001P0oooo
0`00000;0?ooo`030000002W^NH0YkWV0340YkWV0`0000080?ooo`070000002W^NH00000068kS000
0000HS^<08=CT003000000040:c1j@0Pk0L0[<7Y023/1`d0[<7Y00<000000:c1j@2/`NT01`2/`NT0
10000000kjQm0000000000030:NiiPL000000P2kO8h30<^:SP<0000000<0bhZ>0=^IS03KVH`00P00
00000`3oool000000?ooo`190?ooo`00:@3oool3000001/0oooo00<000000;]jRP0000002`3oool0
0`000000YkWV0:NiiP0b0:NiiP8000002@3oool300000003068kS0000000000000@0[<7Y00<08>`7
0:c1j@0Pk0L03@2/`NT00`000000[<7Y0:c1j@080:c1j@030000003_Z7d0000000X0YkWV1@000003
0<^:SP<000000P3KVH`2000004X0oooo000W0?ooo`8000007P3oool00`000000^gZ:0000000:0?oo
o`030000002W^NH0YkWV01@0YkWV00<0[;cU0:NiiP2W^NH0702W^NH2000000T0oooo0P0000000`1R
>h`000000:c1j@040:c1j@04023/1`2/`NT0[<7Y023/1`d0[<7Y00<000000:c1j@2/`NT02@2/`NT3
000000h0YkWV0`0000000`3;RXh0fiV<0=^IS00200000080fiV<00<000000?ooo`3oool0A`3oool0
02@0oooo0`00000P0?ooo`030000002kNXX0000000X0oooo00<000000:NiiP2W^NH04`2W^NH40:bl
iA`0YkWV0P0000090?ooo`<000001P2/`NT0100Pk0L0[<7Y0:c1j@0Pk0L=0:c1j@030000002/`NT0
[<7Y00X0[<7Y0`00000@0:NiiP<000000P3KVH`010000000fiV<0>j[Q@0000180?ooo`008@3oool3
000001/0oooo3`0000060?ooo`030000002W^NH0YkWV01@0YkWV0P2/_>D0102W^NH0001O00000000
000J0:NiiP030000003oool0oooo00H0oooo0`0000070:c1j@04023/1`2/`NT0[<7Y023/1`d0[<7Y
00<000000:c1j@2/`NT02P2/`NT00`000000o;EO0000000C0:NiiP80000000D0fiV<000000000000
kZ^5000000170?ooo`00803oool00`000000oooo0?ooo`0G0?ooo`D000000`2GGH/70:Y^S@D0^gb>
1`00000G0:NiiP030:bli@2W^NH0001O0080000000<0[;cU0:NiiP2W^NH05`2W^NH00`000000oooo
0?ooo`060?ooo`030000000Z4Gh0000000L0[<7Y00<08>`70:c1j@0Pk0L03P2/`NT00`000000[<7Y
0:c1j@0;0:c1j@<00000502W^NH01P000000kZ^50>j[Q@000000kZ^5000004H0oooo000P0?ooo`03
0000003oool0oooo01D0oooo0P0000000`1mB8H0Uef;09MMR`0209MMR`l000000P2kO8h40<^:SP80
00005`2W^NH0102/_>D0001O00000000000J0:NiiP030000003oool0oooo00D0oooo0`0000080:c1
j@03023/1`2/`NT08>`700h0[<7Y00<000000:c1j@2/`NT0302/`NT2000001D0YkWV00H000000>j[
Q@3^ZhD000000>j[Q@0000150?ooo`00803oool2000001D0oooo00<0000007e8QP1mB8H01@000003
09MMR`L0ZVj=1@2kO8h6000000030<^:SP000000YkWV01L0YkWV00<0001O0000000000006P2W^NH0
0`000000oooo0?ooo`050?ooo`8000002@2/`NT00`0Pk0L0[<7Y023/1`0>0:c1j@030000002/`NT0
[<7Y00T0[<7Y00<08>`70000002/`NT00P00000F0:NiiP030000003^ZhD0kZ^500800000A@3oool0
0200oooo00<000000?ooo`0000004P3oool20000000407e8QP000000000007e8QP@0Uef;3`000002
0;]lSP@0bhZ>0P00000G0:NiiPL000005`2W^NH00`000000oooo0?ooo`050?ooo`8000002@2/`NT0
0`0Pk0L0[<7Y023/1`0>0:c1j@030000002/`NT0[<7Y00T0[<7Y00D08>`70000002/`NT0[<7Y0000
000G0:NiiP030000003^ZhD0kZ^500800000A03oool00200oooo00@000000?ooo`3oool000003`3o
ool20000000305DWN`00000000000080ODR61@00000?0:NiiPD000000`3;RXh200000100YkWV1@00
00030:abTP@0^gjA1@00000A0:NiiP030000003oool0oooo00H0oooo00<000000:c1j@2/`NT0202/
`NT00`0Pk0L0[<7Y023/1`080:c1j@030<n:Q`2/`NT0[<7Y00<0[<7Y00<000000:c1j@2/`NT02@2/
`NT01@0Pk0L0[<7Y0:c1j@2/`NT0000001P0YkWV00<000000>j[Q@0000000P0000130?ooo`00803o
ool01@000000oooo0?ooo`3oool0000000d0oooo00@0000005DWN`00000000000P1mB8H2000001T0
YkWV0`0000020=^IS08000002P2W^NH40000000309YUTP000000000000d0000000<0bh^>00000000
00000P00000=0:NiiP030000003oool0oooo00@0oooo00<000000?ooo`0000002P2/`NT00`0Pk0L0
[<7Y023/1`070:c1j@030000003?RXL0000000@0[<7Y00<000000:c1j@2/`NT02@2/`NT01@0Pk0L0
[<7Y0:c1j@2/`NT0000001T0YkWV00<000000?fnL`0000000P0000120?ooo`00803oool01@000000
oooo0?ooo`3oool0000000`0oooo00D0000005DWN`000000EBMk07e8QP02000001h0YkWV0P000002
0=^IS08000001@2W^NH30000000308=CT02JII8000000080000000<0VVFB0:abTP2/LY80102/LY86
0;]nT@80bh^>0`0000020=bHR@8000002`2W^NH00`000000oooo0?ooo`030?ooo`040000003?RXP0
0000000000T0[<7Y00@08>`70:c1j@2/`NT08>`71`2/`NT00`000000chZ7000000040:c1j@030000
002/`NT0[<7Y00T0[<7Y00D08>`70:c1j@2/`NT0[<7Y0000000I0:NiiP060000003m_W<000000000
003oool00000@@3oool00200oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?oo
o`80000000<0EBMk0000000000008P2W^NH200000080fiV<00D000000:NiiP2W^NH0YkWV00000003
08=CT08000000`2JII8A000000030<^;SP00000000000080g9R900<000000:NiiP2W^NH01`2W^NH0
0`000000oooo0?ooo`040?ooo`040000003?RXP00000000000T0[<7Y00@08>`70:c1j@2/`NT08>`7
1`2/`NT00`000000chZ7000000040:c1j@030000002/`NT0[<7Y00T0[<7Y00D08>`70:c1j@2/`NT0
0000023/1`0J0:NiiP050000003m_W<000000?ooo`000000@@3oool00200oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`80000000<0EBMk0000002W^NH09@2W^NH200000005
0>f[QP000000YkWV00000023Di000`0000000`23Di00VVFB00000002000000/0[<7Y00<00000023/
1`2/`NT00`2/`NT5000000030>jXOP000000YkWV00H0YkWV00<000000?ooo`3oool01@3oool01@00
0000chZ80000003oool0000000P0[<7Y00@08>`70:c1j@2/`NT08>`71`2/`NT00`000000Q4f60000
00040:c1j@030000002/`NT0[<7Y00T0[<7Y00D08>`70:c1j@2/`NT00000023/1`0K0:NiiP@00000
@@3oool00200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`040000000=
06800000000002P0YkWV0P000000103]ZhH00000068kR`00000308=CT08000003P2/`NT00`000000
8>`70:c1j@060:c1j@D000001P2W^NH=00000080[<7Y00<00000023/1`2/`NT00`2/`NT0100Pk0L0
[<7Y0:c1j@0Pk0L70:c1j@030000003?RXL0000000@0[<7Y00<000000:c1j@2/`NT02@2/`NT01@0P
k0L0[<7Y0000002W^NH08>`701`0YkWV0P0000000`3oool000000?ooo`0o0?ooo`00803oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00@0000000d0HP0000000000:@2W^NH0
1P0000008>`70000001R>h/0000008=CT0<000004@2/`NT00`0Pk0L0[<7Y0:c1j@070:c1j@@00000
0`2W^NH300000080Uej;1`2ZKXd20;]lSP050000002/`NT0[<7Y0:c1j@0Pk0L0102/`NT0100Pk0L0
[<7Y0:c1j@0Pk0L70:c1j@030000003?RXL0000000@0[<7Y00<000000:c1j@2/`NT02@2/`NT0100P
k0L000000:NiiP0Pk0LM0:NiiP8000000P3oool00`000000oooo0?ooo`0m0?ooo`00803oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P0000000`0=068000000:NiiP0Y0:Ni
iP05023/1`0000000000068kR`000000502/`NT00`0Pk0L0[<7Y0:c1j@090:c1j@80000000<0YkWV
0000000000000`2GGX/=00000080[<7Y00<08>`70:c1j@2/`NT00P2/`NT0100Pk0L0[<7Y0:c1j@0P
k0L70:c1j@030000003?RXL0000000@0[<7Y00<000000:c1j@2/`NT02@2/`NT0100Pk0L0[;cU0:bl
i@0Pk0LM0:NiiP8000000`3oool00`000000oooo0?ooo`0l0?ooo`00803oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<0000000d0HP000000:`2W^NH200000003068kR`00
0000[<7Y01@0[<7Y00<08>`70:c1j@2/`NT02P2/`NT200000080Uej;0`00000209MNR`L0ZVj=102k
O8h00`000000[<7Y023/1`030:c1j@05023/1`2/`NT0[<7Y0:c1j@0Pk0L01`2/`NT00`000000chZ7
000000040:c1j@030000002/`NT0[<7Y00P0[<7Y00L00000023/1`2W^NH0YkWV023/1`0000008>`7
008000006P2W^NH00`000000oooo0?ooo`020?ooo`030000003oool0oooo03/0oooo000P0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`00000[0:NiiP040000000X47d000000000
01H0[<7Y00<08>`70:c1j@2/`NT02`2/`NT3000000D0Uej;102ZKXd900000005023/1`2/`NT0[<7Y
0:c1j@0Pk0L00`2/`NT00`0Pk0L0[<7Y0:c1j@0=000000T0[<7Y00<000000:NiiP0Pk0L00P2W^NH0
0`0Pk0L00000023/1`02000001X0YkWV00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0j
0?ooo`00803oool00`000000oooo0?ooo`080?ooo`040000003oool00000000000P0YkWV00<08>`7
0000002W^NH0802W^NH010000000:11m00000000000G0:c1j@03023/1`2/`NT0[<7Y00/0[<7Y00<0
00000?bfH@0000000P2GGX/7000000L0YkWV00<08>`70000000Pk0L00P2/`NT00`0000008>`70:c1
j@020:c1j@<000000P2JIi@20:acT`d000000`2/`NT200000080YkWV00H08>`70:NiiP2W^NH08>`7
0:bli@0Pk0L2000001X0YkWV00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0j0?ooo`00
803oool00`000000oooo0?ooo`090?ooo`<00000202W^NH00`0Pk0L0YkWV0:NiiP0P0:NiiP800000
00<0:11m0000002/`NT05P2/`NT00`0Pk0L0[<7Y0:c1j@0<0:c1j@@000003P2W^NH00`0Pk0L00000
023/1`02000000060:c1j@0Pk0L0[<7Y0:c1j@0000008>`70P2JIi@D000000@0YkWV00H08>`70:Ni
iP2W^NH08>`70:NiiP0Pk0L2000001X0YkWV00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0i0?ooo`00803oool00`000000oooo0?ooo`0:0?ooo`800000202W^NH00`0Pk0L0YkWV0:NiiP0P
0:NiiP<00000602/`NT00`0Pk0L0[<7Y0:c1j@0=0:c1j@030000002W^NH0YkWV00h0YkWV00<08>`7
0:NiiP0Pk0L00P2W^NH01@0000008>`7000000000000QEND00L00000202^aNX00`000000[/GZ0000
0005000000@0YkWV00@08>`70:NiiP2W^NH08>`71`00000F0:NiiP030000003oool0oooo00H0oooo
00<000000?ooo`3oool0>03oool00200oooo00<000000?ooo`3oool02P3oool00`000000YkWV0:Ni
iP070:NiiP03023/1`2W^NH0YkWV00T0YkWV00<0[;cU0:NiiP2W^NH0502W^NH2000001T0[<7Y00<0
8>`70:c1j@2/`NT03@2/`NT00`000000YkWV0:NiiP0>0:NiiP03023/1`2W^NH08>`700<0YkWV00<0
000006I1T@0000001000000<0:k5jP030000002^aNX0[/GZ0080[/GZ00@000000>nUN00000000000
0P2W^NH00`0000008>`700000002000000<0[7:B102kOY4600000100YkWV00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0g0?ooo`00803oool00`000000oooo0?ooo`0:0?ooo`030000002W
^NH0YkWV00L0YkWV00<08>`70:NiiP2W^NH0802W^NH200000180[<7Y00<0001O0000002/`NT0102/
`NT00`0Pk0L0[<7Y0:c1j@0=0:c1j@030000002W^NH0YkWV00h0YkWV0P0Pk0L30:NiiP060000000P
k0L0000008EGU00000008>`73P2^aNX00`000000[/GZ0:k5jP030:k5jPD0000000<0VVFB023/1`2/
LY800`2/LY8:00000080bh^>0`00000=0:NiiP030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0=P3oool00200oooo00<000000?ooo`3oool02P3oool00`000000YkWV0:NiiP070:NiiP03023/
1`2W^NH0YkWV00/0YkWV00<0[;cU0:NiiP2W^NH04P2W^NH00`000000[<7Y0:c1j@0C0:c1j@030000
002/`NT0[<7Y0080[<7Y00<08>`70:c1j@2/`NT03@2/`NT00`000000YkWV0:NiiP0>0:NiiP808>`7
0`2W^NH01P0Pk0L00000000000000000[/GZ023/1`h0[/GZ00<000000:k5jP2^aNX01@2^aNX40000
0003023/1`0000000000008000000P2/LY860;]nT@80bh^>0`0000020=bHR@8000002P2W^NH00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo03H0oooo000P0?ooo`030000003oool0oooo00X0
oooo00<000000:NiiP2W^NH01`2W^NH00`0Pk0L0YkWV0:NiiP090:NiiP80[;cU0P2W^NH00`000000
YkWV0000000@0:NiiP030000002/`NT0[<7Y0140[<7Y00<0001O000000000000102/`NT00`0Pk0L0
[<7Y0:c1j@0=0:c1j@030000002W^NH0YkWV00h0YkWV0P0Pk0L20:NiiP<000000`2^aNX00`0Pk0L0
[/GZ0:k5jP0<0:k5jP030000002^aNX0[/GZ00D0[/GZ00D000000?Z_E0000000VVFB023/1`0@0000
00030<^;SP00000000000080g9R90P0000080:NiiP030000003oool0oooo00X0oooo00<000000?oo
o`3oool0=@3oool00200oooo00<000000?ooo`3oool02P3oool00`000000YkWV0:NiiP070:NiiP03
023/1`2W^NH0YkWV00d0YkWV00<000000<n:R0000000402W^NH010000000[<7Y0000000Pk0L@0:c1
j@030000G`000000000000@0[<7Y00<08>`70:c1j@2/`NT03@2/`NT00`000000YkWV0:NiiP0>0:Ni
iP808>`700@0YkWV0000000000000000102^aNX00`0Pk0L0[/GZ0:k5jP070:k5jP03023/1`000000
[/GZ0080[/GZ00<000000:k5jP2^aNX01P2^aNX300000003023/1`2/`^T0[<;Y00h0[<;Y1@000002
0>nXO@030000002W^NH0YkWV00@0YkWV00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0d
0?ooo`00803oool00`000000oooo0?ooo`0;0?ooo`030000002W^NH0YkWV00H0YkWV00<08>`70:Ni
iP2W^NH03@2W^NH00`000000chZ80000000@0:NiiP040000002/`NT00000023/1a00[<7Y00<0001O
000000000000102/`NT00`0Pk0L0[<7Y0:c1j@0<0:c1j@030000002W^NH0YkWV00l0YkWV0P0Pk0L0
102W^NH000000000000Pk0L40:k5jP03023/1`2^aNX0[/GZ00L0[/GZ00<08>`70000002^aNX00P2^
aNX00`000000[/GZ0:k5jP070:k5jP060000002/`^T08>`70:c2j@0000008>`7402/`^T400000003
0>nXO@000000YkWV00@0YkWV00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0c0?ooo`00
803oool00`000000oooo0?ooo`0;0?ooo`030000002W^NH0YkWV00L0YkWV00<08>`70:NiiP2W^NH0
302W^NH00`000000chZ80000000>0:NiiP030000000Pk0L000000080[<7Y00<08>`70:c1j@2/`NT0
2`2/`NT0100000008>`70:c1j@0005l2000000@0[<7Y00<08>`70:c1j@2/`NT0302/`NT00`000000
YkWV0:NiiP0?0:NiiP808>`70P0000000`2^aNX08>`70:k5jP030:k5jP03023/1`2^aNX0[/GZ00L0
[/GZ00<08>`70:k5jP2^aNX00P2^aNX00`000000[/GZ0:k5jP070:k5jP060000002/`^T08>`70:c2
j@0000008>`74P2/`^T500000080YkWV0P00000A0?ooo`030000003oool0oooo0380oooo000P0?oo
o`030000003oool0oooo00/0oooo00<000000:NiiP2W^NH01`2W^NH00`0Pk0L0YkWV0:NiiP0;0:Ni
iPX00000202W^NH00`0000008>`7000000020:c1j@03023/1`2/`NT0[<7Y00/0[<7Y00@00000023/
1`2/`NT0001O0P0000040:c1j@03023/1`2/`NT0[<7Y00`0[<7Y00<000000:NiiP2W^NH03`2W^NH2
023/1`040000H`0000000000023/1`@0[/GZ00<08>`70:k5jP2^aNX01P2^aNX00`3?RXL08>`70:k5
jP030:k5jP030000002^aNX0[/GZ00L0[/GZ00<000000:c2j@0Pk0L00P2/`^T00`0Pk0L0[<;Y0:c2
j@0B0:c2j@030000003_Z7d0000000800000503oool00`000000oooo0?ooo`0a0?ooo`00803oool0
0`000000oooo0?ooo`0<0?ooo`030000002W^NH0YkWV00H0YkWV00<08>`70:NiiP2W^NH01@2W^NH6
00000080[7:B1P2kOY420<^;S`<000001P2W^NH01@0Pk0L000000:c1j@2/`NT08>`700h0[<7Y00<0
8>`70:c1j@0005l00P0000040:c1j@03023/1`2/`NT0[<7Y00/0[<7Y00<000000:NiiP2W^NH0402W
^NH2023/1`040:NiiP000000[/GZ023/1`@0[/GZ00<08>`70:k5jP2^aNX01@2^aNX00`000000[/GZ
023/1`040:k5jP030000002^aNX0[/GZ00L0[/GZ00<00000023/1`2/`^T00P2/`^T00`0Pk0L0[<;Y
0:c2j@0C0:c2j@<000005@3oool00`000000oooo0?ooo`0a0?ooo`00803oool00`000000oooo0?oo
o`0<0?ooo`030000002W^NH0YkWV00H0YkWV00@08>`70:NiiP2W^NH0YkWV1000000209YUTQ000000
00<0bh^?000000000000102W^NH2023/1`030000002/`NT08>`700h0[<7Y00<08>`70:c1j@0005l0
0P0000040:c1j@03023/1`2/`NT0[<7Y00T0[<7Y0P00000C0:NiiP808>`700@0YkWV0000002^aNX0
8>`7102^aNX00`0Pk0L0[/GZ0:k5jP050:k5jP030000003?RXL08>`700@0[/GZ00<000000:k5jP2^
aNX01`2^aNX00`0000008>`70:c2j@020:c2j@03023/1`2/`^T0[<;Y01@0[<;Y0`00000E0?ooo`03
0000003oool0oooo0300oooo000P0?ooo`030000003oool0oooo00`0oooo00<000000:NiiP2W^NH0
0`2W^NH2000000030:NiiP0Pk0L0YkWV0080000000<0Pe>@09YUTP2JII800`000000102JII80[7:B
0:abTP2/LY8600000080^gjA103;Rhl500000080YkWV0P0Pk0L00`2W^NH00000023/1`0>0:c1j@03
023/1`2/`NT0001O00800000102/`NT00`0Pk0L0[<7Y0:c1j@080:c1j@030000002W^NH0YkWV00T0
YkWV00<0Fbn20:NiiP2W^NH01`2W^NH2023/1`040:NiiP0Pk0L0[/GZ023/1`@0[/GZ00<08>`70:k5
jP2^aNX01@2^aNX200000003023/1`2^aNX0[/GZ0080[/GZ00<000000:k5jP2^aNX01`2^aNX00`00
00008>`70:c2j@020:c2j@03023/1`2/`^T0[<;Y01@0[<;Y00<000000?beG`0000005P3oool00`00
0000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`0=0?ooo`8000000`2W^NH00`000000
8>`70:NiiP0200000080Pe>@0`00000209YUTPD000001P2/`NT6000000030<^;S`3KV8X0fiR:00@0
00000P0Pk0L00`2W^NH08>`7023/1`02000000T0[<7Y3P0000030:c1j@030000000Pk0L0[<7Y0080
[<7Y00<000000:NiiP2W^NH02P2W^NH20:bli@P0YkWV0P0Pk0L0102W^NH08>`70:k5jP0Pk0L40:k5
jP03023/1`2^aNX0[/GZ00D0[/GZ00<0TEN80<n:Q`0Pk0L0102^aNX00`000000[/GZ0:k5jP060:k5
jP030000002/`^T08>`700<0[<;Y00<08>`70:c2j@2/`^T05@2/`^T2000001L0oooo00<000000?oo
o`3oool0;P3oool00200oooo00<000000?ooo`3oool03`3oool020000000YkWV0:NiiP2W^NH08>`7
0000001R>X/0Pe>@0P0000000`23Di0000000000000200000140[<7Y0`0000030=^HRP<0000000<0
YkWV023/1`0Pk0L00P2W^NH2000000@0[<7Y0`00000209YWU0<0[7>C3@000000100Pk0L0[<7Y0000
0000000=0:NiiP030:bli@2W^NH0[;cU00D0YkWV00P0[;cU0:NiiP0Pk0L08>`70:NiiP0Pk0L0[/GZ
023/1`@0[/GZ00<08>`70:k5jP2^aNX01@2^aNX00`2AEhP0chZ7023/1`040:k5jP030000002^aNX0
[/GZ00D0[/GZ00@000000:c2j@2/`^T08>`70`2/`^T0100Pk0L0[<;Y0:c2j@2/`NTE0:c2j@030000
003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00200oooo00<000000?ooo`3oool0403o
ool01@000000YkWV0:NiiP000000HSZ;00H0000000<08>`70:c1j@2/`NT0502/`NT3000000040>jX
O`000000kZQo000000808>`71P0000000`2/`NT0000008EGU00309YWU1<00000402W^NH20:bli@04
0:NiiP000000YkWV000000<0YkWV0P0Pk0L0102W^NH08>`70000000Pk0L40:k5jP03023/1`2^aNX0
[/GZ00D0[/GZ00<0TEN80<n:Q`0Pk0L0102^aNX00`000000[/GZ0:k5jP040:k5jP050000002/`^T0
[<;Y0:c2j@0Pk0L00`2/`^T00`0Pk0L0[<;Y0:c2j@040:c2j@030:c1j@2/`^T0[<;Y00l0[<;Y1000
000=0?ooo`03023/1`000000oooo00D0oooo00<000000?ooo`3oool0;@3oool00200oooo00<00000
0?ooo`3oool04@3oool200000004068jR`0000000000000000<0[<7Y00<00000023/1`2/`NT0602/
`NT010000000kZQo000000000002023/1`030:NiiP2kO8l0^gb?0080^gb?0P0000000`25Ei@00000
00000006000000L0[/GZ00<08>`70:k5jP0000000P0000000`3LUhL000000000000@0:NiiP80[;cU
00@0YkWV0000002W^NH000000`2W^NH2023/1`040:NiiP0Pk0L08>`7000000@0[/GZ00<08>`70:k5
jP2^aNX01@2^aNX00`2AEhP0chZ7023/1`040:k5jP030000002^aNX0[/GZ00<0[/GZ00<000000:c2
j@2/`^T00P2/`^T01@0Pk0L0[<;Y0:c2j@2/`^T08>`700D0[<;Y00<0[<7Y0:c2j@2/`^T0402/`^T0
10000000^gb>0;]lSP2kO8h5000000P0oooo00<08>`70000003oool01P3oool00`000000oooo0?oo
o`0/0?ooo`00803oool00`000000oooo0?ooo`0B0?ooo`<000001P2/`NT00`0Pk0L0[<7Y0:c1j@0H
0:c1j@050000003^Z7l000000000000Pk0L01@000000101V@I40000000000025Ei@3000000/0[/GZ
00<08>`70:k5jP2^aNX00P2^aNX010000000kZEi0>jUN@00000@0:NiiP80[;cU00<000000<n:R000
00000`2W^NH2023/1`050:NiiP0Pk0L08>`70:NiiP0000000`2^aNX00`0Pk0L0[/GZ0:k5jP050:k5
jP03095GR03?RXL08>`700@0[/GZ00@000000:k5jP2^aNX0[/GZ0P0000050:c2j@05023/1`2/`^T0
[<;Y0:c2j@0Pk0L02@2/`^T00`2/`NT0[<;Y0:c2j@0<0:c2j@@000000P2kO8h30<^:SP<000001@3o
ool00`0Pk0L0oooo0?ooo`070?ooo`030000003oool0oooo02/0oooo000P0?ooo`030000003oool0
oooo0140oooo0`0000070:c1j@03023/1`2/`NT0[<7Y01T0[<7Y0P000002023/1`<0^gb?00@00000
06I1T@000000QEND0P00000>0:k5jP03023/1`2^aNX0[/GZ00<0[/GZ100000000`2W^NH00000023/
1`0>0:NiiP030000003?RXP0000000<0YkWV0P0Pk0L00`2W^NH08>`7023/1`020:NiiP<0000000<0
8>`70:k5jP2^aNX01@2^aNX00`2AEhP0chZ7023/1`040:k5jP@000001`2/`^T0100Pk0L0[<7Y0:c2
j@2/`^T2023/1`80000000D0j:5o0000002/`NT0[<7Y0:c2j@020:c1j@h0[<;Y00@000000;]lSP2k
O8h0^gb>1@0000030<^:SP<000000P3oool00`0Pk0L0oooo0?ooo`080?ooo`030000003oool0oooo
02X0oooo000P0?ooo`030000003oool0oooo0100oooo00<0000002P?O@000000202/`NT00`0Pk0L0
0000023/1`0J0:c1j@80000000<08>`70000000000000`0000000`1V@I4000000:k5jP0?0:k5jP03
023/1`2^aNX0[/GZ00H0[/GZ0`0000000`0Pk0L0YkWV0:NiiP0<0:NiiP030000003?RXP0000000<0
YkWV0P0Pk0L00`2W^NH08>`7023/1`030:NiiP03023/1`2W^NH08>`7008000001@2^aNX00`2AEhP0
chZ7023/1`05000000X0[<;Y00@08>`70:c1j@2/`^T0[<;Y0P0Pk0L2000000030>RQO`000000[<;Y
0080[<;Y0P2/`NT>0:c2j@@000000P2kO8h30<^:SP<0000000<0bhZ>0=^IS03KVH`00P0000000`0P
k0L0oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo000P0?ooo`030000003oool0oooo0100
oooo0`0000000`2/`NT00000000000050:c1j@03023/1`0000008>`701T0[<7Y0P000002023/1`80
YkWV0P0000000`1V@I4000000:k5jP0@0:k5jP03023/1`2^aNX0[/GZ00H0[/GZ0P0000000`2W^NH0
8>`70:NiiP070:NiiP`000000P0Pk0L00`0000008>`7023/1`030:NiiP05023/1`2W^NH08>`70:Ni
iP0Pk0L01@0000001@2AEhP0chZ7023/1`0Pk0L000000080[<;Y00<000000:c2j@2/`^T0202/`^T0
100Pk0L0[<7Y0:c1j@2/`NT2023/1`060:c2j@000000j:5o0000002/`^T0[<7Y0P2/`^T00`2/`NT0
[<;Y0:c2j@0;0:c2j@030000002W^NH0YkWV0080YkWV1@0000030<^:SP<000000P3KVH`00`000000
oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo000P0?ooo`030000003oool0oooo0100oooo
0P0000020:c1j@030000000Pk0L0[<7Y00@0[<7Y00@08>`70:c1j@0Pk0L0[<7Y0P00000F0:c1j@04
0000000Pk0L00000023/1`80YkWV0`00000B0:k5jP03023/1`2^aNX0[/GZ00L0[/GZ00<000000:Ni
iP0Pk0L0102W^NH400000080VVFB0`2/LY87000000808>`700<00000023/1`0Pk0L00`0000001@0P
k0L0YkWV023/1`2W^NH08>`700<0YkWV0P0Pk0L01@2AEhP0chZ7023/1`0Pk0L000000080[<;Y00<0
00000:c2j@2/`^T0202/`^T0100Pk0L0[<;Y0:c1j@2/`NT2023/1`050:c2j@000000j:5o0000002/
`^T00`2/`NT>0:c2j@030000002W^NH0YkWV00L0YkWV0`0000000`3;RXh0fiV<0=^IS00200000003
0=^IS0000000oooo00X0oooo00<000000?ooo`3oool0:03oool00200oooo00<000000?ooo`3oool0
3`3oool2000000@0[<7Y00<08>`70:c1j@2/`NT00`2/`NT3023/1`030:c1j@0000008>`701L0[<7Y
0`0Pk0L010000000YkWV00000000000C0:k5jP03023/1`2^aNX0[/GZ00L0[/GZ0P0000000`0Pk0L0
YkWV0:NiiP020000000408=DT@2JII80VVFB09YUTPD000000`2/LY840;]nT@808>`700@0bh^?023/
1`0Pk0L000000P3LV8T01@0Pk0L00000023/1`2W^NH08>`700d000002P2/`^T0100Pk0L0[<;Y0:c2
j@2/`^T2023/1`050:c2j@000000j:5o0000002/`NT04@2/`^T00`000000YkWV0:NiiP0:0:NiiP80
00000`3KVH`00`000000kJ^60000000;0?ooo`030000003oool0oooo02L0oooo000P0?ooo`030000
003oool0oooo00l0oooo0P0000040:c1j@03023/1`2/`NT0[<7Y00<0[<7Y100Pk0L00`2/`NT08>`7
0:c1j@0F0:c1j@<08>`70`00000D0:k5jP03023/1`2^aNX0[/GZ00L0[/GZ0P0000000`0Pk0L0YkWV
0000000208=DT@@0000000<0VVFB0000000000002P0000001@0Pk0L00000023/1`0Pk0L0bh^?0080
000000<08>`70=bHR@0Pk0L04@0000080:c2j@04023/1`2/`^T0[<;Y0:c2j@808>`700@0[<7Y0000
003XXGl000004@2/`^T00`000000YkWV0:NiiP0=0:NiiP8000000P3KVH`00`000000kJ^60000000;
0?ooo`030000003oool0oooo02H0oooo000P0?ooo`030000003oool0oooo00l0oooo0P0000040:c1
j@03023/1`2/`NT0[<7Y00<0[<7Y100Pk0L00`2/`NT08>`70:c1j@0F0:c1j@<08>`70`00000D0:k5
jP03023/1`2^aNX0[/GZ00P0[/GZ1P0000000`23E940VVFB00000002000000D0[<;Y0P0000040:c2
j@808>`700<0[<;Y023/1`0Pk0L00`000000100Pk0L000000000001I;7l@000000P0[<;Y00@08>`7
0:c2j@2/`^T0[<;Y0P0Pk0L0102/`^T000000>RQO`00000?0:c2j@8000004P2W^NH2000000040>f[
QP000000kJ^6000000X0oooo00<000000?ooo`3oool09P3oool00200oooo00<000000?ooo`3oool0
3`3oool00`000000[<7Y0:c1j@030:c1j@03023/1`2/`NT0[<7Y00<0[<7Y100Pk0L00`2/`NT08>`7
0:c1j@020:c1j@030000002/`NT000000140[<7Y0`0Pk0L2000000h0[/GZ00<000000:k5jP000000
102^aNX00`0Pk0L0[/GZ0:k5jP080:k5jP030000001S>h`0000000<0PeBA0P0000080:c2j@030000
000Pk0L0[<;Y00<0[<;Y0P0Pk0L00`2/`^T08>`7023/1`030:c2j@03023/1`0000008>`700800000
302U^nT4000000L0[<;Y00@08>`70:c2j@2/`^T0[<;Y0P0Pk0L0102/`NT000000>RQO`00000>0:c2
j@030000002W^NH0YkWV01@0YkWV00D000000>f[QP000000kJ^60000000:0?ooo`030000003oool0
oooo02D0oooo000P0?ooo`030000003oool0oooo00l0oooo00<000000:c1j@2/`NT00`2/`NT00`0P
k0L0[<7Y0:c1j@030:c1j@@08>`700<0[<7Y023/1`2/`NT00P2/`NT00`000000chZ80000000A0:c1
j@<08>`70P00000>0:k5jP030000002kNXT0000000@0[/GZ00<08>`70:k5jP2^aNX01`2^aNX01000
0000Hc^<00000023E943000000/0[<;Y00<08>`70:c2j@2/`^T00P2/`^T2023/1`030:c2j@0Pk0L0
[<;Y00<0[<;Y00@08>`700000000000000003@2U^nT00`000000YK_Y00000002000000H0[<;Y00<0
8>`70:c2j@000000300000080:c2j@030000002W^NH0YkWV01<0YkWV00D00000023/1`2W^NH00000
0>f[QP02000000/0oooo00<000000?ooo`3oool0903oool00200oooo00<000000?ooo`3oool03`3o
ool00`000000[<7Y0:c1j@030:c1j@03023/1`2/`NT0[<7Y00<0[<7Y100Pk0L00`2/`NT08>`70:c1
j@020:c1j@030000003?RXP000000140[<7Y0`0Pk0L00`2W^NH000000:k5jP0=0:k5jP<00000102^
aNX00`0Pk0L0[/GZ0:k5jP070:k5jP80000000<0Hc^<0000002/`^T03@2/`^T0100Pk0L0[<;Y0:c2
j@000003023/1`030:c2j@0Pk0L0[<;Y00<0[<;Y00<08>`7000000000000202U^nT2000000@0YK_Y
00<000000:Fkj@2U^nT00`0000040:c2j@050000000Pk0L0000009]WU00Pk0L00P2/Li<=00000080
[<;Y0P00000F0:NiiP060000000Pk0L0YkWV0:NiiP000000kJ^60P00000;0?ooo`030000003oool0
oooo02<0oooo000P0?ooo`030000003oool0oooo0100oooo00<000000:c1j@2/`NT00P2/`NT00`0P
k0L0[<7Y0:c1j@030:c1j@@08>`700<0[<7Y023/1`2/`NT00P2/`NT00`000000chZ80000000A0:c1
j@<08>`700<0YkWV0<RA000000003@2^aNX00`000000^gZ9000000040:k5jP03023/1`2^aNX0[/GZ
00H0[/GZ0P0000000`1S>h`000000:c2j@0>0:c2j@808>`700<0[<;Y0000000Pk0L00P0Pk0L00`2/
`^T08>`70:c2j@030:c2j@80000000<08>`70:Fkj@2U^nT01P2U^nT00`0000008>`70:Fkj@030:Fk
j@040000002U^nT0YK_Y0:Fkj@<0000000H0[<;Y000000000000QERD023/1`2KIi@C000001T0YkWV
00@08>`70:NiiP2W^NH0YkWV0P0000000`3m_W<000000?ooo`0:0?ooo`030000003oool0oooo0280
oooo000P0?ooo`030000003oool0oooo0100oooo00<000000:c1j@2/`NT00P2/`NT00`0Pk0L0[<7Y
0:c1j@030:c1j@<08>`700<0[<7Y023/1`0Pk0L00`2/`NT00`000000chZ80000000A0:c1j@<08>`7
0P2W^NH00`000000[/GZ0:k5jP080:k5jP060000000Pk0L000000000002kNXT00000102^aNX00`0P
k0L0[/GZ0:k5jP050:k5jP80000000<0Hc^<0000002/`^T03`2/`^T2023/1`80[<;Y0`0Pk0L00`2/
`^T08>`70:c2j@030:c2j@80000000<08>`70:Fkj@2U^nT01`2U^nT00`0Pk0L0YK_Y0:Fkj@020:Fk
j@030000002U^nT0YK_Y0080YK_Y00<000000=^IS00000000P25F9@00`0000008>`7000000040000
00T0[/GZ0`000000103LUhL0000000000000000H0:NiiP03023/1`2W^NH0YkWV0080YkWV0P000000
0`3m_W<000000?ooo`090?ooo`8000008`3oool00200oooo00<000000?ooo`3oool0403oool00`00
0000[<7Y0:c1j@020:c1j@03023/1`2/`NT0[<7Y00<0[<7Y0`0Pk0L00`2/`NT08>`7023/1`030:c1
j@030000003?RXP0000000l0[<7Y00<00000023/1`0Pk0L00P0Pk0L20:NiiP030000002^aNX0[/GZ
00P0[/GZ00H00000023/1`00000000000;]jR@0000040:k5jP03023/1`2^aNX0[/GZ00@0[/GZ0P00
00000`0Z4Wh000000:c2j@0@0:c2j@808>`70P2/`^T3023/1`030:c2j@0Pk0L0[<;Y00<0[<;Y00<0
00000:Fkj@0Pk0L01P2U^nT0100Pk0L000000<n:Q`0000040:Fkj@030000002U^nT0YK_Y0080YK_Y
0P0000002025F9@000000000000000008>`70000002^aNX08>`72@2^aNX00`0000008>`70:k5jP02
0:k5jP80000000<0kjEh0000000000005`2W^NH00`0Pk0L0YkWV0:NiiP020:NiiP040000003m_W<0
0000000000L0oooo0`0000000`3oool000000?ooo`0R0?ooo`00803oool00`000000oooo0?ooo`0A
0?ooo`050000002/`NT0[<7Y0:c1j@0Pk0L01@2/`NT0100Pk0L0[<7Y023/1`2/`NT2023/1`<0[<7Y
00<000000<n:R0000000402/`NT4023/1`<0YkWV0P0000090:k5jP05023/1`2^aNX000000;]jR@00
0000102^aNX00`0Pk0L0[/GZ0:k5jP020:k5jP<0000000<0:Q9n0000002/`^T04@2/`^T2023/1`80
[<;Y0`0Pk0L00`2/`^T08>`70:c2j@030:c2j@030000002U^nT08>`700H0YK_Y00@08>`70000002U
^nT00000102U^nT00`000000YK_Y0:Fkj@020:Fkj@070000001W@Y40000008EHU0000000[/GZ023/
1`020:k5jP03023/1`2^aNX0[/GZ00L0[/GZ00<00000023/1`2^aNX0102^aNX00`000000kjEh0000
000G0:NiiP03023/1`2W^NH0YkWV00<0YkWV00<000000?fnL`000000103oool3000000@0oooo00<0
00000?ooo`3oool08@3oool00200oooo00<000000?ooo`3oool04P3oool010000000[<7Y0:c1j@0P
k0L50:c1j@04023/1`2/`NT08>`70:c1j@808>`70`2/`NT00`000000chZ8000000060:c1j@030000
000Pk0L0[<7Y00H0[<7Y0P000003023/1`D0YkWV00<000000:k5jP2^aNX01P2^aNX01@0Pk0L0[/GZ
0000002kNXT0000000@0[/GZ00<08>`70:k5jP2^aNX00P000000103oool08>`700000000000C0:c2
j@808>`70P2/`^T3023/1`030:c2j@0Pk0L0[<;Y00<0[<;Y00<000000:Fkj@0Pk0L01@2U^nT2023/
1`030000003?RXL0000000@0YK_Y00<000000:Fkj@2U^nT00P2U^nT400000080[/GZ00@08>`70:k5
jP2^aNX08>`72P2^aNX00`0Pk0L0[/GZ0:k5jP040:k5jP<000005P2W^NH00`0Pk0L0YkWV0:NiiP03
0:NiiP040000003m_W<000000?ooo`<000001`3oool00`000000oooo0?ooo`0Q0?ooo`00803oool0
0`000000oooo0?ooo`0C0?ooo`030000002/`NT08>`700D0[<7Y00@08>`70:c1j@0Pk0L0[<7Y0P0P
k0L20:c1j@T0000000<0[<7Y0000000Pk0L01P2/`NT00`000000YkWV023/1`03023/1`D0YkWV00@0
8>`700000000000000001@2^aNX01@0Pk0L0[/GZ0000002kNXT0000000@0[/GZ00P08>`700000000
00000000023/1`3oool08>`700000180[<;Y00H0[<7Y0:c2j@0Pk0L0[<;Y023/1`2/`^T3023/1`03
0:c2j@0Pk0L0[<;Y00<0[<;Y00<08>`70000000Pk0L01P2U^nT0100Pk0L000000<n:Q`0000040:Fk
j@040000002U^nT0YK_Y0:Fkj@<00000102^aNX0100Pk0L0[/GZ0:k5jP0Pk0L:0:k5jP03023/1`2^
aNX0[/GZ00D0[/GZ0P00000F0:NiiP03023/1`2W^NH0YkWV00@0YkWV0`00000:0?ooo`030000003o
ool0oooo0240oooo000P0?ooo`030000003oool0oooo01<0oooo0P0000000`0Pk0L0[<7Y00000003
0:c1j@04023/1`2/`NT08>`70:c1j@@000000P2/Li<40;]oT@<0bhZ>0`0000040:c1j@8000000P2/
_>D4023/1`D0YkWV00@08>`70:NiiP2W^NH0YkWV0`0000020:k5jP04023/1`2^aNX000000;]jR@D0
000000P08>`70:NiiP0000000000023/1`3oool08>`7000001<0[<;Y00D0[<7Y023/1`2/`^T08>`7
0:c2j@03023/1`030:c2j@0Pk0L0[<;Y00<0[<;Y00<08>`70:c2j@0Pk0L01P2U^nT0100Pk0L00000
0<n:Q`0000040:Fkj@030000002U^nT0YK_Y00<000001@2^aNX0100Pk0L0[/GZ0:k5jP0Pk0L:0:k5
jP03023/1`2^aNX0[/GZ00H0[/GZ0P00000E0:NiiP03023/1`2W^NH0YkWV00@0YkWV0P00000;0?oo
o`030000003oool0oooo0240oooo000P0?ooo`030000003oool0oooo01<0oooo0P0000000`0Pk0L0
00000:c1j@030:c1j@03023/1`000000000000h0000000D0bhZ>0=bGQ`3LUhL000000:c1j@020000
00@0YkWV100Pk0L50:NiiP03023/1`2W^NH0YkWV0080YkWV00@08>`70:NiiP00000000000P0Pk0L0
0`000000^gZ9000000040:NiiP07023/1`2W^NH000000000000Pk0L0oooo023/1`0E0:c2j@04023/
1`2/`^T08>`70:c2j@D08>`7102/`^T00`0Pk0L0[<;Y023/1`02000000@0YK_Y00@08>`70000000P
k0L00000102U^nT00`000000YK_Y0:Fkj@02000000H0[/GZ00@08>`70:k5jP2^aNX08>`72P2^aNX0
0`0Pk0L0[/GZ0:k5jP070:k5jP050000002W^NH0YkWV0:NiiP2/_>D0402W^NH00`0Pk0L0YkWV0:Ni
iP050:NiiP8000002`3oool00`000000oooo0?ooo`0Q0?ooo`00803oool00`000000oooo0?ooo`0C
0?ooo`<08>`700<0oooo0000000000001P00000209YWU080[7>C400000020:NiiP80[;cU100Pk0L0
0`000000YkWV0:NiiP020:NiiP03023/1`2W^NH0YkWV0080YkWV00@08>`70:NiiP2W^NH0YkWV0P0P
k0L00`000000^gZ9000000040:NiiP07023/1`2W^NH000000000000Pk0L0oooo023/1`0>0:c2j@<0
[<7Y00P0[<;Y0:c1j@2/`^T00000023/1`0000008>`70:c2j@D08>`7102/`^T01@0Pk0L0[<;Y023/
1`2/`^T08>`700<0000000D0YK_Y023/1`0000008>`7000000040:Fkj@@000001`2^aNX0100Pk0L0
[/GZ0:k5jP0Pk0L:0:k5jP03023/1`2^aNX0[/GZ00L0[/GZ00D000000:bli@000000YkWV0000000@
0:NiiP03023/1`2W^NH0YkWV00H0YkWV00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Q
0?ooo`00803oool00`000000oooo0?ooo`0C0?ooo`<08>`70`3oool30000000308EGU02JIi@0VVND
00@000002@2^aNX6000000030>jUNP000000YkWV0080YkWV100Pk0L00`000000YkWV0:NiiP020:Ni
iP03023/1`2W^NH0YkWV0080YkWV00<08>`70000000000002P0000001`0Pk0L0YkWV0:NiiP000000
8>`70?ooo`0Pk0L03P2/`^T20:c1j@<0[<;Y00H0[<7Y0000000Pk0L00000023/1`2/`^T5023/1`@0
[<;Y00`08>`70:c2j@0Pk0L0[<;Y023/1`2/`^T08>`70:c2j@0000008>`70000000Pk0L600000003
0:NiiP000000000000L0[/GZ00@08>`70:k5jP2^aNX08>`7102^aNX00`3XXGl0[/GZ0:k5jP030:k5
jP03023/1`2^aNX0[/GZ00L0[/GZ00D000000:NiiP000000chZ80000000@0:NiiP03023/1`2W^NH0
YkWV00H0YkWV00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Q0?ooo`00803oool00`00
0000oooo0?ooo`0D0?ooo`808>`70P3oool20000000308EGU00Pk0L00000008000004@2^aNX40000
00<0YkWV100Pk0L00`000000YkWV0:NiiP020:NiiP04023/1`2W^NH0YkWV0:NiiPh0000000L08>`7
0000002W^NH00000023/1`3oool08>`700l0[<;Y0P2/`NT01`2/`^T0[<7Y0:c2j@0000008>`70000
002/`^T01P0Pk0L40:c2j@08023/1`2/`^T08>`70:c2j@0Pk0L0[<;Y023/1`2/`^T2023/1`050000
000Pk0L000000:NiiP0Pk0L00P2W^NH00`000000YkWV000000080:k5jP04023/1`2^aNX0[/GZ023/
1`80000000@0[/GZ0000002^aNX00000102^aNX00`0Pk0L0[/GZ0:k5jP070:k5jP050000002W^NH0
00000<n:R0000000402W^NH00`0Pk0L0YkWV0:NiiP060:NiiP030000003oool0oooo00T0oooo00<0
00000?ooo`3oool08@3oool00200oooo00<000000?ooo`3oool0503oool2023/1`040?ooo`000000
000006I1T@<0000000<08>`70:k5jP2^aNX04P2^aNX300000080YkWV100Pk0L00`000000YkWV0:Ni
iP020:NiiP05023/1`2W^NH0YkWV0000001H;7l03@000000200Pk0L000000000000000008>`70?oo
o`0Pk0L000000`2/`^T00`0000008>`70:c2j@0=0:c2j@040000000Pk0L000000:c2j@H08>`7102/
`^T0200Pk0L0[<;Y023/1`2/`^T08>`70:c2j@0Pk0L0[<;Y0P0Pk0L01@0000008>`70000002W^NH0
8>`70080YkWV00<000000:NiiP000000202^aNX00`0Pk0L0[/GZ0:k5jP03023/1`040:k5jP000000
j:5o000000@0[/GZ00<08>`70:k5jP2^aNX01P2^aNX01P000000YkWV0:NiiP000000chZ800000100
YkWV00<08>`70:NiiP2W^NH01P2W^NH00`000000oooo0?ooo`090?ooo`030000003oool0oooo0240
oooo000P0?ooo`030000003oool0oooo01@0oooo0P0Pk0L20000000706I1T@000000[/GZ023/1`2^
aNX08>`70000000D0:k5jP8000000P2W^NH4023/1`030000002W^NH0YkWV0080YkWV00<08>`70:Ni
iP2W^NH00`00000<0:Fkj@08023/1`00000000000000000Pk0L0oooo023/1`0000030:c2j@030000
000Pk0L0[<;Y00d0[<;Y00@00000023/1`000000[<;Y1P0Pk0L40:c2j@808>`70P2/`^T0100Pk0L0
[<;Y023/1`2/`^T2023/1`050000000Pk0L000000:NiiP0Pk0L00P2W^NH00`000000YkWV00000008
0:k5jP03023/1`2^aNX0[/GZ00<08>`700@0[/GZ00000000000000000`2^aNX00`0Pk0L0[/GZ0:k5
jP070:k5jP030000002W^NH0000000X000002@2W^NH00`0Pk0L0YkWV0:NiiP060:NiiP030000003o
ool0oooo00T0oooo00<000000?ooo`3oool08@3oool00200oooo00<000000?ooo`3oool0503oool0
0`0Pk0L00000030KQP0200000080[/GZ00@08>`70:k5jP0Pk0L000005@2^aNX3000000@08>`71@00
00000`0Pk0L0000000000002000000d0YK_Y00<08>`70:Fkj@0000000P0000000`3oool08>`70000
00040:c2j@03023/1`2/`^T0[<;Y00/0[<;Y00D0[<7Y0000000Pk0L000000:c2j@06023/1`@0[<;Y
0P0Pk0L20:c2j@04023/1`2/`^T08>`7000000808>`700D00000023/1`000000YkWV023/1`020:Ni
iP040000002W^NH0YkWV000000L0[/GZ00<08>`70:k5jP2^aNX00`0Pk0L0102^aNX0Z6Z:0>RQO`00
00030:k5jP03023/1`2^aNX0[/GZ00H0[/GZ0`0000030:abTPD0^gjA0`3;Rhl3000000H0YkWV00<0
8>`70:NiiP2W^NH01@2W^NH00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0240oooo000P
0?ooo`030000003oool0oooo01@0oooo0P0Pk0L2000000<0[/GZ00H08>`70:k5jP0Pk0L0[/GZ0000
000Pk0LC0:k5jP80000000<0[7:B023/1`0Pk0L00P0Pk0L300000080^gnA00@08>`70<^;S`000000
00003P2U^nT00`0Pk0L0YK_Y0:Fkj@0300000003023/1`3oool0000000<0[<;Y00<08>`70:c2j@2/
`^T0302/`^T0100000008>`70000002/`^T6023/1`@0[<;Y0P0Pk0L20:c2j@04023/1`0000008>`7
0:NiiP808>`700D00000023/1`000000YkWV023/1`020:NiiP040000002W^NH0YkWV000000L0[/GZ
00<08>`70:k5jP2^aNX00`0Pk0L0102^aNX0Z6Z:0>RQO`0000030:k5jP03023/1`2^aNX0[/GZ00D0
[/GZ400000020<^;S`800000102W^NH00`0Pk0L0YkWV0:NiiP050:NiiP030000003oool0oooo00X0
oooo00<000000?ooo`3oool08@3oool001l0oooo00<000000?ooo`3oool05@3oool3000000@0[/GZ
00H08>`70:k5jP0Pk0L0[/GZ0000000Pk0L40:k5jP030>RQP02^aNX0[/GZ00d0[/GZ0P000004023/
1`<0^gnA0P0000000`0Pk0L00000000000050:Fkj@030000000Pk0L0YK_Y00L0YK_Y00@08>`70:Fk
j@2U^nT0YK_Y0P0000000`0Pk0L0oooo0?ooo`02000000030:c2j@0Pk0L0[<;Y00d0[<;Y00<00000
023/1`0000000P2/`^T5023/1`@0[<;Y0P0Pk0L20:c2j@<08>`700@0YkWV023/1`0Pk0L000000P0P
k0L01@0000008>`70:NiiP2W^NH000000080YkWV00<000000:k5jP2^aNX01@2^aNX00`0Pk0L0[/GZ
0:k5jP03023/1`040:k5jP2XJXX0j:5o000000<0[/GZ0P0Pk0L00`000000[/GZ0:k5jP020:k5jP03
0000002JII<0[7:B0080[7:B1`0000000`2kOY40bh^?0<^;S`020<^;S`H000000P2W^NH00`0Pk0L0
YkWV0:NiiP050:NiiP030000003oool0oooo00X0oooo00<000000?ooo`3oool08@3oool001l0oooo
00<000000?ooo`3oool05@3oool2000000D0[/GZ00<08>`70:k5jP0Pk0L00P2^aNX01@0Pk0L0[/GZ
0:k5jP2^aNX000000100[/GZ0P000004023/1`P000001@2U^nT00`0000008>`70:Fkj@070:Fkj@03
023/1`2U^nT0YK_Y0080YK_Y00P00000023/1`0000000000023/1`3oool00000023/1`X0[<;Y1@00
00000`0Pk0L0000000000002000000@08>`7102/`^T2023/1`030:c2j@0000008>`700808>`700<0
YkWV0000000000001@0000020:NiiP040000002W^NH0YkWV0:NiiP8000001@2^aNX00`0Pk0L0[/GZ
0:k5jP03023/1`040:k5jP2XJXX0j:5o000000<0[/GZ0P0Pk0L00`000000[/GZ0:k5jP07000000L0
[<;Z1P0000000`3;Rhl0g9R90=bHR@0400000003023/1`2W^NH0YkWV00@0YkWV00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0Q0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`030000
000Pk0L0[/GZ00@0[/GZ00<08>`70:k5jP0Pk0L00P2^aNX01`0Pk0L0[/GZ0:k5jP2^aNX000000>RQ
P00000003P2^aNX00`000000[<;Y023/1`03023/1`D0[<;Y00<08>`70000002U^nT01P2U^nT01@0P
k0L0YK_Y0000002U^nT0000000@0YK_Y00<08>`70:Fkj@2U^nT00P2U^nT01@0000008>`70;]lS`2k
O8l08>`70080000000<08>`70000000000001P2/`^T20000000309]WU02/Li@0[7>D00L000000P0P
k0L0100000008>`70000000000020:c2j@808>`700<000000:bli@0Pk0L00P0Pk0L4000000808>`7
0`0000000`2W^NH000000:NiiP020:NiiP808>`700<000000:k5jP2^aNX00P2^aNX00`0Pk0L0[/GZ
0:k5jP03023/1`040:k5jP2XJXX0j:5o000000<0[/GZ0P0Pk0L00`2^aNX000000000000200000180
[<;Z0`0000020=bHR@030000003^Z7h0000000D0YkWV00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0Q0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`030000G`0Pk0L0[/GZ00D0[/GZ
0P0Pk0L20:k5jP07023/1`2^aNX0[/GZ0:k5jP000000j:600000000>0:k5jP030000002/`^T08>`7
00<08>`71@2/`^T00`0Pk0L000000:Fkj@060:Fkj@05023/1`2U^nT000000;]jR@000000102U^nT0
0`0Pk0L0YK_Y0:Fkj@020:Fkj@090000000Pk0L000000;]lS`0Pk0L0^gb?0<^;S`0Pk0L0bh^?00<0
00000P2/`^T20000000309]WU000000000000080000000<0[7>D0000000000000`0000001@2kOi40
8>`7023/1`3;RXh08>`700@000000P0Pk0L00`2W^NH0[;cU023/1`02023/1`8000000P2a`^L2023/
1`80/L;W00<000000:NiiP0000000`2W^NH3023/1`<0000000@0[/GZ023/1`2^aNX0[/GZ0`0Pk0L0
102^aNX0Z6Z:0>RQO`0000030:k5jP808>`700<000000:c2jP2/`^X05`2/`^X2000000040>jXOP00
00008>`700000080YkWV0P00000?0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003o
ool0oooo01D0oooo0P0Pk0L60:k5jP808>`70P2^aNX0100Pk0L0[/GZ0:k5jP2^aNX3000000d0[/GZ
00<000000:c2j@2/`^T01@0Pk0L40:c2j@03023/1`2/`^T0000000H0YK_Y0P0Pk0L00`000000^gZ9
000000040:Fkj@04023/1`2U^nT0YK_Y0:Fkj@80000000<08>`70;]lS`0000000`000000100Pk0L0
bh^?0<^;S`3;Rhl;000000040:k5jP0Pk0L0[/GZ0:k5jP<0000000<08>`70000000Pk0L010000002
023/1`80YkWV0`0Pk0L200000080/L;W0P0Pk0L20;72i`030000002W^NH0000000<0YkWV0`0Pk0L3
0:NiiP040000000Pk0L000000:k5jP<08>`700<0[/GZ0:QZRP3XXGl010000002023/1a`0[<;Z00H0
00000>jXOP00000000000:NiiP00000A0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000
003oool0oooo01D0oooo0P0Pk0L60:k5jP808>`70P2^aNX01`0Pk0L0[/GZ0:k5jP2^aNX0TEN80>RQ
P0000000302^aNX200000080[<;Y1@0Pk0L40:c2j@04023/1`2/`^T0[<;Y000000D0YK_Y00D08>`7
0:Fkj@000000^gZ9000000040:Fkj@04023/1`2U^nT0YK_Y0:Fkj@80000000@08>`70;]lS`2kO8l0
8>`70P3;Rhl01P0Pk0L00000000000000000Id:A08EHU0@000001P2^aNX0100Pk0L0[/GZ0:k5jP00
0003023/1`060:k5jP0Pk0L0[/GZ0:k5jP000000kZEi0P0Pk0L20:NiiP<08>`70P0000001P0Pk0L0
/L;W023/1`0Pk0L0/L;W00000080YkWV00@000000:NiiP2W^NH0YkWV0`0Pk0L40:NiiP03023/1`2W
^NH0000000<08>`700<000000:QZRP3XXGl00`0000000`2/`^X08>`7023/1`0M0:c2jP040000000P
k0L0000000000180oooo00<000000?ooo`3oool08@3oool001l0oooo00<000000?ooo`3oool05@3o
ool2023/1`H0[/GZ00D08>`70:k5jP0Pk0L0[/GZ023/1`030:k5jP03095GR0000000000000`0[/GZ
00@000000:c2j@2/`^T0[<;Y1P0Pk0L30:c2j@04023/1`2/`^T0[<;Y00000080YK_Y00@000000:Fk
j@2U^nT08>`70P0000000`2kNXT000000:Fkj@030:Fkj@05023/1`2U^nT0YK_Y0:Fkj@0000000P0P
k0L500000004023/1`3;Rhl0000006M2T@<000002@2^aNX0100Pk0L0[/GZ0:k5jP2^aNX3023/1`03
0:k5jP0Pk0L0[/GZ0080[/GZ00D00000023/1`0Pk0L000000:NiiP03023/1`80000000H08>`70;72
i`0Pk0L08>`70000000Pk0L20:NiiP040000002W^NH0YkWV0:NiiP<08>`70`2W^NH00`0Pk0L0YkWV
0:NiiP04023/1`030:NiiP2XJXX0j:5o008000000P2/`^X2023/1ah0[<;Z0P0000000`3l]El00000
0?ooo`0@0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003oool0oooo01D0oooo0P0P
k0L00`000000[/GZ0:k5jP030:k5jP05023/1`2^aNX08>`70:k5jP0Pk0L00`2^aNX00`2AEhP0j:60
0000000;0:k5jP8000000`2/`^T6023/1`<0[<;Y00@08>`70:c2j@2/`^T0[<;Y0`0000020:Fkj@05
023/1`00000000000;]jR@000000102U^nT0100Pk0L0YK_Y0:Fkj@000003023/1`80YkWV00@08>`7
0:NiiP2W^NH08>`71@00000:0:k5jP04023/1`2^aNX0[/GZ0:k5jP<08>`700<0[/GZ023/1`2^aNX0
0`2^aNX2023/1`030?Z`E@0000008>`700808>`700@00000023/1`0Pk0L000000P0Pk0L01@2W^NH0
8>`70:NiiP2W^NH0000000<0YkWV0`0Pk0L30:NiiP03023/1`2W^NH0YkWV00/000000P0Pk0LN0:c2
jP04023/1`000000000000000140oooo00<000000?ooo`3oool08@3oool001l0oooo00<000000?oo
o`3oool05@3oool2023/1`030?ooo`000000000000<0[/GZ00D08>`70:k5jP0Pk0L0[/GZ023/1`03
0:k5jP03095GR03XXH00000000X0[/GZ00<000000:c2j@2/`^T00`2/`^T6023/1`<0[<;Y00<08>`7
0:c2j@2/`^T00P2/`^T0100Pk0L0[<;Y000000000002023/1`030000002kNXT0000000@0YK_Y00@0
8>`7000000000000YkWV0`0Pk0L20:NiiP04023/1`2W^NH0YkWV023/1`<00000302^aNX0100Pk0L0
[/GZ0:k5jP2^aNX3023/1`030:k5jP0Pk0L0[/GZ00<0[/GZ0P0Pk0L2000000<08>`700@0[7>C023/
1`0Pk0L0^gnA0P0Pk0L5000000<0YkWV0`0Pk0L30:NiiP03023/1`000000000000h000007@2/`^X0
100Pk0L000000?beG`00000A0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003oool0
oooo01D0oooo0P0Pk0L20?ooo`090000002^aNX0[/GZ0:k5jP0Pk0L0[/GZ023/1`2^aNX08>`700<0
[/GZ00<0TEN80>RQP00000001P2^aNX0100000008>`70000000000060:c2j@H08>`70`2/`^T00`0P
k0L0[<;Y0:c2j@020:c2j@04023/1`2/`^T0[<;Y0:c2j@808>`700<000000;]jR@00000010000000
100Pk0L0YkWV0:NiiP2W^NH3023/1`80YkWV00<08>`70:NiiP2W^NH00`00000=0:k5jP04023/1`2^
aNX0[/GZ0:k5jP<08>`700<0[/GZ023/1`2^aNX00`2^aNX2023/1`8000000`0Pk0L0100000008>`7
023/1`000002023/1`<0000000<0bh^?0000000000000P000003023/1`<0YkWV00<08>`700000000
00002`000000100Pk0L0000000000000000L0:c2jP03023/1`2/`^X0000000800000403oool00`00
0000oooo0?ooo`0Q0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`808>`70`3oool200000005
0:k5jP0Pk0L0[/GZ023/1`2^aNX00P0Pk0L20:k5jP03095GR03XXH00000000H0[/GZ00@00000023/
1`2/`^T08>`71P2/`^T6023/1`<0[<;Y00<08>`70:c2j@2/`^T00P2/`^T0100Pk0L0[<;Y0:c2j@2/
`^T2023/1`050000002kNXT000000:c2j@0000000P2W^NH0100Pk0L0YkWV0:NiiP2W^NH3023/1`80
YkWV00H08>`70:NiiP2W^NH000000:k5jP00000=0:k5jP04023/1`2^aNX0[/GZ0:k5jP<08>`700<0
[/GZ023/1`2^aNX00`2^aNX2023/1`060:k5jP0000008>`70000000Pk0L0[7>C0P0Pk0L0102kOi40
8>`7023/1`2kOi420<^;S`<000000P3KV8T3023/1`80YkWV00H00000023/1`00000000000:Fkj@0P
k0L90:Fkj@@00000202/`^X01@2/`^T0[<;Z0:c2jP2/`^X0[<;Y00l0[<;Z00<08>`70:c2jP2/`^X0
0P00000@0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003oool0oooo01D0oooo0P0P
k0L50?ooo`050000000Pk0L0[/GZ023/1`2^aNX00P0Pk0L20:k5jP03095GR03XXH00000000@0[/GZ
0`0000000`0Pk0L0[<;Y023/1`060:c2j@H08>`70`2/`^T00`0Pk0L0[<;Y0:c2j@020:c2j@04023/
1`2/`^T0[<;Y0:c2j@808>`700D000000;]jR@000000[<;Y000000020:NiiP04023/1`2W^NH0YkWV
0:NiiP<08>`70P2W^NH00`0Pk0L0YkWV0:NiiP02000000h0[/GZ00@08>`70:k5jP2^aNX0[/GZ0`0P
k0L00`2^aNX08>`70:k5jP030:k5jP808>`700H0[/GZ0000000Pk0L00000023/1`000002023/1`03
0000000Pk0L08>`700D0000000<0bh^?0000000000000`0Pk0L300000005023/1`2U^nT0YK_Y0:Fk
j@0Pk0L02@2U^nT00`0Pk0L0YK_Y0:Fkj@02000001/0[<;Z00<08>`70:c2jP2/`^X00P00000@0?oo
o`030000003oool0oooo0240oooo000O0?ooo`030000003oool0oooo01D0oooo0P0Pk0L60?ooo`04
023/1`0000008>`7000000808>`70P0000000`2AEhP0j:6000000004000000<0[<;Y00<08>`70:c2
j@0Pk0L01P2/`^T6023/1`<0[<;Y00<08>`70:c2j@2/`^T00P2/`^T00`0Pk0L0[<;Y00000003023/
1`050000002kNXT000000:c2j@0000000P2W^NH0100Pk0L0YkWV0:NiiP2W^NH3023/1`80YkWV00<0
8>`70:NiiP2W^NH00P00000=0:k5jP03095GR00Pk0L0[/GZ0080[/GZ0`0Pk0L00`2^aNX08>`70:k5
jP030:k5jP808>`700<0[/GZ0000000Pk0L00P0Pk0L0102/`^X08>`7023/1`2/`^X2023/1`040000
000Pk0L0[<;Z0:c2jP@000000`0Pk0L0103^Z7h000000000000Pk0L20:Fkj@03023/1`2U^nT0YK_Y
00P0YK_Y00<08>`70:Fkj@2U^nT00`0000020:c2jP80[<;Y1@2/`^X00`2/`^T0[<;Z0:c2jP0=0:c2
jP03023/1`2/`^X0[<;Z0080[<;Z00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Q0?oo
o`007`3oool00`000000oooo0?ooo`0E0?ooo`808>`71P3oool0100Pk0L0oooo023/1`3oool2023/
1`80oooo00<0TEN80>RQP00000001`2/`^T00`0Pk0L0[<;Y023/1`060:c2j@H08>`700@0[<;Y0:c1
j@2/`^T08>`7102/`^T00`0Pk0L0[<;Y00000003023/1`030000002kNXT000000080[<;Y00<00000
0:NiiP0Pk0L00`2W^NH3023/1`80YkWV00<08>`70:NiiP2W^NH00P00000=0:k5jP030000000Pk0L0
00000080[/GZ0P0Pk0L20:k5jP03023/1`2^aNX0[/GZ0080[/GZ0P0Pk0L00`2^aNX00000023/1`02
023/1`040:c2jP0Pk0L08>`70:c2jP808>`700D00000023/1`2/`^X0[<;Z000000030:c2jP<08>`7
0P0000001@2U^nT08>`70:Fkj@2U^nT08>`700X0YK_Y00@08>`70:Fkj@2U^nT0YK_Y0P0000001@2/
`^X0[<;Y0:c2j@2/`^X0[<;Y0080[<;Z00@000000:c2jP000000[<;Z0P2/`^T<0:c2jP03023/1`2/
`^X0[<;Z0080[<;Z00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Q0?ooo`007`3oool0
0`000000oooo0?ooo`0E0?ooo`808>`71P3oool01@0Pk0L0oooo023/1`3oool08>`700L000001P2/
`^T00`0Pk0L0[<;Y023/1`020:c2j@<0[<7Y00<0[<;Y023/1`0Pk0L0100Pk0L30:c2j@03023/1`2/
`^T0[<;Y0080[<;Y00<08>`70:c2j@2/`^T00`0Pk0L00`000000^gZ9000000020:c2j@030000002W
^NH08>`700<0YkWV0`0Pk0L20:NiiP04023/1`2W^NH0YkWV000000h0[/GZ00<00000023/1`000000
0P2^aNX2023/1`80[/GZ00<08>`70:k5jP2^aNX00P2^aNX2023/1`030:k5jP0000008>`700808>`7
00@0[<;Z023/1`0Pk0L0[<;Z0P0Pk0L01@2/`^X08>`70:c2jP2/`^X0000000<0[<;Z0`0Pk0L20000
00050:Fkj@0Pk0L0YK_Y0:Fkj@0Pk0L02P2U^nT00`0Pk0L0YK_Y0:Fkj@020:Fkj@80000000<0[<;Y
0:c2jP2/`^X00`2/`^X01@000000^gZ:0000002/`^X0[<;Y00d0[<;Z00<08>`70:c2jP2/`^X00P2/
`^X00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003oool0
oooo01D0oooo0P0Pk0L60?ooo`03023/1`3oool0000000d000000P2/`^T00`0Pk0L0[<;Y023/1`02
0:c2j@80[<7Y0P2/`^T6023/1`040:c2j@2/`NT0[<;Y023/1`@0[<;Y00<08>`70:c2j@2/`^T00`0P
k0L4000000040:c2j@000000YkWV023/1`<0YkWV0`0Pk0L20:NiiP04023/1`2W^NH0YkWV000000h0
[/GZ00L00000023/1`000000[/GZ023/1`2^aNX08>`70080[/GZ00<08>`70:k5jP2^aNX00P2^aNX2
023/1`030:k5jP0000008>`700808>`700@0[<;Z023/1`0Pk0L0[<;Z0P0Pk0L01@2/`^X08>`70:c2
jP2/`^X0000000<0[<;Z0`0Pk0L0102/`^X000000:Fkj@0Pk0L20:Fkj@03023/1`2U^nT0YK_Y0080
YK_Y00<000000>RQO`0000000`2U^nT00`0Pk0L0YK_Y0:Fkj@020:Fkj@8000000P2/`^T30:c2jP04
0:c2j@000000^gZ:000000@0[<;Z00<0[<;Y0:c2jP2/`^X0202/`^X01@0Pk0L0[<;Z0:c2jP2/`^X0
00000140oooo00<000000?ooo`3oool08@3oool001l0oooo00<000000?ooo`3oool05@3oool2023/
1`H0oooo00<08>`70000000000002`0000001`3;SI80fi^@0000002/`^T08>`70:c2j@0Pk0L00`2/
`^T00`2/`NT0[<;Y0:c2j@06023/1`<0[<;Y00<08>`70:c2j@2/`^T00P2/`^T00`0Pk0L0[<;Y0:c2
j@02023/1`L0000000<0YkWV023/1`2W^NH00P2W^NH3023/1`80YkWV00@08>`70:NiiP2W^NH00000
3P2^aNX01`2AEhP08>`70000002^aNX08>`70:k5jP0Pk0L00P2^aNX00`0Pk0L0[/GZ0:k5jP020:k5
jP808>`700<000000:c2jP0Pk0L00P0Pk0L0102/`^X08>`7023/1`2/`^X2023/1`050:c2jP0Pk0L0
[<;Z0:c2jP0000000`2/`^X3023/1`040:c2jP000000YK_Y023/1`80YK_Y00P08>`70000000Pk0L0
8>`70:Fkj@000000j:5o000000<0YK_Y00<08>`70:Fkj@2U^nT00`2U^nT010000000[<;Z0:c2j@2/
`^T30:c2jP030000002TIhX0000000l0[<;Z00D08>`70:c2jP2/`^X0[<;Z0000000A0?ooo`030000
003oool0oooo0240oooo000O0?ooo`030000003oool0oooo01D0oooo0P0Pk0L60?ooo`03023/1`00
00000000008000001`2T^nT600000003023/1`2/`^T08>`700@0[<;Y00<0[<7Y0:c2j@0Pk0L01@0P
k0L0102/`^T0[<7Y0:c1j@0Pk0L40:c2j@04023/1`2/`^T0[<;Y023/1`<000000P2a`^L300000003
0:NiiP0Pk0L0YkWV0080YkWV0`0Pk0L20:NiiP04023/1`2W^NH0YkWV000000h0[/GZ00L0TEN8023/
1`000000[/GZ023/1`2^aNX08>`70080[/GZ00<08>`70:k5jP2^aNX00P2^aNX2023/1`80[<;Z0`0P
k0L0102/`^X08>`7023/1`2/`^X2023/1`050:c2jP0Pk0L0[<;Z0:c2jP0000000`2/`^X3023/1`04
0:c2jP000000YK_Y023/1`80YK_Y00P08>`70000000Pk0L08>`70:Fkj@000000j:5o000000<0YK_Y
00<08>`70:Fkj@2U^nT00`2U^nT010000000[<;Z0:c2jP2/`^T30:c2jP030000002kNXX0000000l0
[<;Z00D08>`70:c2jP000000[<;Z0000000A0?ooo`030000003oool0oooo0240oooo000O0?ooo`03
0000003oool0oooo01D0oooo0P0Pk0L50?ooo`030000000Pk0L00000008000002P2T^nT500000003
0:c2j@0Pk0L0[<;Y00D0[<;Y1P0Pk0L30:c2j@03023/1`2/`^T0[<;Y0080[<;Y00<08>`70:c2j@2/
`^T00P0000060;72i`030000002W^NH08>`700<0YkWV0`0Pk0L20:NiiP05023/1`2W^NH0YkWV023/
1`0000003@2^aNX01`2AEhP08>`70000002^aNX08>`70:k5jP0Pk0L00P2^aNX01@0Pk0L0[/GZ0:k5
jP2^aNX0000000808>`70P2/`^X3023/1`040:c2jP0Pk0L08>`70:c2jP808>`700D0[<;Z023/1`2/
`^X08>`7000000030:c2jP<08>`70P2/`^X01P0000008>`70:Fkj@2U^nT08>`70:Fkj@808>`700@0
YK_Y0000003XXGl000000`2U^nT00`0Pk0L0YK_Y0:Fkj@020:Fkj@030000002/`^X0[<;Z00@0[<;Z
00@0[<;Y0000002kNXX000003`2/`^X0100Pk0L0[<;Z0:c2jP00000B0?ooo`030000003oool0oooo
0240oooo000O0?ooo`030000003oool0oooo01D0oooo00<08>`70?ooo`0Pk0L00`3oool200000004
023/1`2T^nT08>`7023/1`d0Y;_Y0P0000000`2/`^T08>`70:c2j@050:c2j@H08>`70`2/`^T00`0P
k0L0[<;Y0:c2j@020:c2j@03023/1`2/`^T0[<;Y00808>`71P2a`^L00`000000YkWV023/1`030:Ni
iP<08>`70P2W^NH01P0Pk0L0YkWV0:NiiP0Pk0L0YkWV000000`0[/GZ00P0TEN8023/1`000000[/GZ
023/1`2^aNX08>`70:k5jP808>`700@0[/GZ000000000000[<;Z0P0Pk0L20:c2jP<08>`700@0[<;Z
023/1`0Pk0L0[<;Z0P0Pk0L01@2/`^X08>`70:c2jP0Pk0L0000000<0[<;Z00@08>`70:c2jP0Pk0L0
8>`70P2/`^X01@0Pk0L0YK_Y0:Fkj@0Pk0L0YK_Y00808>`700@0YK_Y0000003XXGl000000`2U^nT0
1@0Pk0L0YK_Y0:Fkj@2U^nT0000000L0[<;Z00@0[<;Y0000002kNXX000003`2/`^X0100Pk0L0[<;Z
0:c2jP00000B0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003oool0oooo01D0oooo
0`0Pk0L30?ooo`80000000<08>`70:Bkj@0Pk0L00P0Pk0L00`000000Y;_Y0:Bkj@0:0:Bkj@800000
00<08>`70:c2j@2/`^T0102/`^T6023/1`80[<;Y0P0Pk0L40:c2j@03023/1`2/`^T0[<;Y00808>`7
1@2a`^L2000000030:bli@0Pk0L0YkWV0080YkWV0`0Pk0L20:NiiP04023/1`2W^NH0YkWV023/1`80
YkWV00<00000023/1`2^aNX02@2^aNX2023/1`060000002^aNX08>`70:k5jP0Pk0L0[/GZ0P0Pk0L0
10000000[<;Z0:c2jP2/`^X2023/1`030:c2jP0Pk0L08>`700808>`700@0[<;Z023/1`0Pk0L0[<;Z
0P0Pk0L01@2/`^X08>`70:c2jP0Pk0L0000000<0[<;Z00@08>`70:c2jP0Pk0L08>`70P2/`^X01@0P
k0L000000000000Pk0L0YK_Y00808>`700@0YK_Y0000003XXGl000000`2U^nT0100Pk0L0YK_Y0:Fk
j@0000090:c2jP030000002kNXX0000000X0[<;Z00<00000023/1`2/`^X00P2/`^X00`0Pk0L00000
0000000C0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003oool0oooo01D0oooo0`0P
k0L30?ooo`040000002T^nT08>`70:Bkj@<08>`73@2T^nT200000003023/1`2/`^T0[<;Y00@0[<;Y
1P0Pk0L20:c2j@808>`7102/`^T00`0Pk0L0[<;Y0:c2j@02023/1`D000000P2W^NH00`2/_>D08>`7
0:NiiP020:NiiP<08>`70P2W^NH0100Pk0L0YkWV0:NiiP0Pk0L20:NiiP04023/1`00000000000000
00L0[/GZ00T00000023/1`0Pk0L000000:k5jP0Pk0L0[/GZ023/1`0000000P0Pk0L40:c2jP808>`7
00<0[<;Z023/1`0Pk0L00P0Pk0L0102/`^X08>`7023/1`2/`^X2023/1`050:c2jP0Pk0L0[<;Z023/
1`0000000`2/`^X4023/1`80[<;Z00D08>`70:c2jP0Pk0L08>`700000002023/1`040:Fkj@000000
j:5o000000<0YK_Y00<08>`70000000000002P2/`^X5000000P0[<;Z00H00000023/1`2/`^X0[<;Z
0000000Pk0LE0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003oool0oooo01D0oooo
0`0Pk0L30?ooo`040000002T^nT08>`70:Bkj@<08>`71@2T^nT00`000000Y;_Y0:Bkj@060:Bkj@80
000000@08>`70:c2j@2/`^T0[<;Y0P000005023/1`D00000102/`^T00`0Pk0L0[<;Y00000005023/
1`@0YkWV00D0[;cU023/1`2W^NH000000:NiiP03023/1`80YkWV00@08>`70:NiiP2W^NH08>`70P2W
^NH2023/1`80YkWV100000040:k5jP808>`70P0000000`0Pk0L00000023/1`03023/1`@0[<;Z0P0P
k0L0102/`^X08>`7023/1`0Pk0L20:c2jP808>`700P0[<;Y023/1`0Pk0L08>`70:c2j@2/`^X08>`7
000000<0[<;Z100Pk0L20:c2jP03023/1`2/`^X08>`700@08>`70P0000000`3XXGl0000000000002
000000808>`71P2/`^X500000080[7BD0`2kOi8700000080[<;Z00D08>`7000000000000oooo023/
1`0E0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003oool0oooo01D0oooo0`0Pk0L3
0?ooo`040000002T^nT08>`70:Bkj@<08>`70`2T^nT00`000000Y;_Y000000080:Bkj@80000000H0
8>`70:c2j@000000000009]WU02/Li@5023/1`T0000000<08>`70:c2j@0000001@0Pk0L50:NiiP04
023/1`2W^NH000000:NiiP<08>`70P2W^NH0100Pk0L0YkWV0:NiiP0Pk0L20:NiiP808>`70`2W^NH0
0`0Pk0L0YkWV0:NiiP04000000808>`700<000000:c2jP0Pk0L01@0Pk0L40:c2jP808>`700H0[<;Z
023/1`0Pk0L08>`70:c2jP000002023/1`080:c2j@0Pk0L08>`7023/1`2/`^T0[<;Z023/1`000003
0:c2jPD08>`700<0[<;Z023/1`2/`^X01@0Pk0L01`3oool000000>RQO`000000oooo023/1`000000
0P0Pk0L30:c2jP<0000000<0VfNE0000000000002`0000000`3;RXh0g9N70=bGQ`0200000005023/
1`3oool0oooo0?ooo`0Pk0L05@3oool00`000000oooo0?ooo`0Q0?ooo`007`3oool00`000000oooo
0?ooo`0E0?ooo`<08>`70`3oool010000000Y;_Y023/1`2T^nT3023/1`<0Y;_Y00<000000>RQP000
00002@2T^nT0100000008>`70000002KIi@3000000D08>`70P2kOi820<^:SP03023/1`0000000000
00D000001@0Pk0L50:NiiP04023/1`2/_>D000000>RQP0<08>`70P2W^NH0100Pk0L0YkWV0:NiiP0P
k0L20:NiiP808>`70`2W^NH00`0Pk0L0YkWV0:NiiP020:NiiP06023/1`2W^NH08>`7023/1`000000
[<;Z1P0Pk0L40:c2jP808>`700H0[<;Z023/1`0Pk0L08>`70:c2jP000002023/1`080:c2jP0Pk0L0
8>`7023/1`2/`^T0[<;Z023/1`0000030:c2jPD08>`700<0[<;Z023/1`2/`^X01@0Pk0L01`3oool0
00000>RQO`000000oooo023/1`3oool00P0Pk0L010000000[<;Z00000026F9@300000080VfNE0P2/
M9@>00000005023/1`3oool0oooo0?ooo`0Pk0L05@3oool00`000000oooo0?ooo`0Q0?ooo`007`3o
ool00`000000oooo0?ooo`0E0?ooo`<08>`70`3oool010000000Y;_Y023/1`2T^nT3023/1`<0Y;_Y
00<000000>RQP0000000202T^nT00`000000QERD00000005000000D08>`720000000103KUhP00000
000000000005023/1`D0YkWV00@08>`70:NiiP000000j:600`0Pk0L20:NiiP04023/1`2W^NH0YkWV
023/1`80YkWV0P0Pk0L30:NiiP03023/1`2W^NH0000000D0000000<08>`70000000000001P0Pk0L4
0:c2jP808>`700H0[<;Z023/1`0Pk0L08>`70:c2jP000002023/1`080:c2j@0Pk0L08>`7023/1`2/
`^T0[<;Z023/1`0000030:c2jPD08>`700<0[<;Z023/1`2/`^X01@0Pk0L01`3oool000000>RQO`00
0000oooo023/1`3oool00P0Pk0L40000000308IHU02KIiD0VfNE00@000002@2^aNX6000000<0oooo
00<08>`70?ooo`3oool04`3oool00`000000oooo0?ooo`0Q0?ooo`007`3oool00`000000oooo0?oo
o`0E0?ooo`<08>`7103oool0100000008>`70:Bkj@2T^nT2023/1`<0Y;_Y00<000000>RQP0000000
202T^nT5000000<0[/GZ1@0Pk0L200000080[/GZ00@08>`70:k5jP2^aNX0[/GZ0P0000000`3^YGX0
000000000004023/1`D0YkWV00@08>`70:NiiP000000j:600`0Pk0L20:NiiP04023/1`2W^NH0YkWV
023/1`80YkWV0P0Pk0L30:NiiP03023/1`000000000000D0000000<08>`70000000000000`0Pk0L0
0`0000008>`7023/1`040:c2jP808>`700H0[<;Z023/1`0Pk0L08>`70:c2j@000006023/1`80[<;Z
00<08>`70000002/`^X00P2/`^X5023/1`030:c2jP0Pk0L0000000D08>`700L0oooo0000003XXGl0
00000?ooo`0Pk0L0oooo00808>`70P0000000`26F9@000000000000200000140[/GZ0`0000020?oo
o`03023/1`3oool0oooo01<0oooo00<000000?ooo`3oool08@3oool001l0oooo00<000000?ooo`3o
ool05@3oool3023/1`D0oooo00<08>`70000000000000P0Pk0L30:Bkj@030000003XXH00000000H0
Y;_Y100000000`0Pk0L0[/GZ0:k5jP030:k5jPD08>`70P0000020:k5jP03023/1`2^aNX0[/GZ0080
[/GZ00@08>`70000003^YGX00000100Pk0L00`2W^NH000000000000200000004023/1`0000000000
000000<08>`70P000000100Pk0L000000000000Pk0L20:NiiP808>`70`2W^NH<000000808>`700<0
0000023/1`0Pk0L0102/`^X2023/1`060:c2jP0Pk0L0[<;Z023/1`2/`^X000001P0Pk0L20:c2jP03
023/1`000000[<;Z0080[<;Z0`0Pk0L01@2/`^X08>`70:c2jP0Pk0L0000000D08>`700L0oooo0000
003XXGl000000?ooo`0Pk0L0oooo00808>`700<0J4>B0000000000005`2^aNX2000000030?ooo`0P
k0L0oooo01@0oooo00<000000?ooo`3oool08@3oool001l0oooo00<000000?ooo`3oool05@3oool3
023/1`D0oooo00H08>`70?ooo`3oool08>`70000000Pk0L20:Bkj@030000003XXH00000000@0Y;_Y
0`000000100Pk0L000000:k5jP0Pk0L50:k5jPH08>`70`2^aNX00`0Pk0L0[/GZ0:k5jP020:k5jP04
023/1`2^aNX00000000000<08>`70P0000001@2JII<0[7>C0:acT`2/Li<08>`700<000000`0Pk0L2
0;]oTP04023/1`3;Rhl0bh^?023/1`<0000000<08>`70:NiiP2W^NH00`0000060:Fkj@03023/1`2U
^nT0YK_Y00<08>`700@00000023/1`0Pk0L000000`2/`^X2023/1`060:c2jP0Pk0L0[<;Z023/1`2/
`^T000001P0Pk0L20:c2jP03023/1`000000[<;Z0080[<;Z0`0Pk0L01@2/`^X08>`70:c2jP0Pk0L0
000000D08>`700<0oooo0000000000000P0000001P0Pk0L0oooo023/1`0Pk0L0J4>B000001T0[/GZ
0P0000000`0Pk0L0oooo0?ooo`0C0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003o
ool0oooo01D0oooo0`0Pk0L50?ooo`06023/1`3oool0oooo023/1`3oool08>`70`000000103XXH00
00000:Bkj@2T^nT500000004023/1`2^aNX0[/GZ023/1`D0[/GZ1P0Pk0L30:k5jP03023/1`2^aNX0
[/GZ0080[/GZ00@08>`70:k5jP2^aNX000000`0Pk0L00`2JII<000000000000300000004023/1`2/
Li<0[7>C0;]oTP<08>`70P0000001P0Pk0L000000000000Pk0L0bh^?0=^HRP808>`7100000070:Fk
j@03023/1`2U^nT0YK_Y00<08>`700<0YK_Y023/1`0Pk0L00P0000020:c2jP808>`700H0[<;Z023/
1`2/`^X08>`70:c2j@000006023/1`80[<;Z00<08>`70000002/`^X00P2/`^X3023/1`030:c2jP0P
k0L0[<;Z00808>`700@0oooo023/1`0Pk0L08>`720000002023/1`030000002^aNX0[/GZ01P0[/GZ
0P0000000`0Pk0L0oooo0?ooo`0C0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003o
ool0oooo01D0oooo0`0Pk0L50?ooo`05023/1`3oool0oooo023/1`3oool00P0Pk0L00`3oool00000
0>RQP003000000060?ooo`00000000000000002^aNX08>`70P2^aNX00`0Pk0L0[/GZ0:k5jP030:k5
jPH08>`70`2^aNX00`0Pk0L0[/GZ0:k5jP020:k5jP04023/1`2^aNX0[/GZ0:k5jP<08>`700<00000
09YUT`2JII<00`000000100Pk0L00000000000000003023/1`D0000000H08>`70000000000000000
023/1`3KV8X2000000P0YK_Y00<08>`70:Fkj@2U^nT00`0Pk0L00`2U^nT08>`7023/1`03000000<0
8>`700H0[<;Z023/1`2/`^X08>`70:c2j@000006023/1`80[<;Z00<08>`70000002/`^X00P2/`^X3
023/1`030:c2jP0Pk0L0000000808>`700@0oooo023/1`0Pk0L08>`70`0000020;72i`<000000P0P
k0LL0:k5jP030000003oool0oooo01@0oooo00<000000?ooo`3oool08@3oool001l0oooo00<00000
0?ooo`3oool05@3oool3023/1`D0oooo00D08>`70?ooo`3oool08>`70?ooo`02023/1`040?ooo`2X
JXX0j:60000000<0oooo00D000000:k5jP000000[/GZ023/1`020:k5jP03023/1`2^aNX0[/GZ00<0
[/GZ1P0Pk0L30:k5jP03023/1`2^aNX0[/GZ0080[/GZ00@08>`70:k5jP00000000000`0Pk0L30000
00<0[<;Z00@08>`70:c2jP2/`^X0[<;Z0`0Pk0L20:c2jP04023/1`2/`^X0[<;Z023/1`<0000000<0
8>`70000000000002@2U^nT00`0Pk0L0YK_Y0:Fkj@03023/1`040:Fkj@0Pk0L08>`70:Fkj@800000
0P0Pk0L20:c2jP05023/1`2/`^X08>`70:c2jP0000001P0Pk0L20:c2jP03023/1`000000[<;Z0080
[<;Z0`0Pk0L00`0000008>`70?ooo`02023/1`050?ooo`0Pk0L08>`7023/1`0000001P2a`^L00`00
00008>`7023/1`0L0:k5jP030000003oool0oooo01@0oooo00<000000?ooo`3oool08@3oool001l0
oooo00<000000?ooo`3oool05@3oool3023/1`D0oooo00D08>`70?ooo`3oool08>`70?ooo`02023/
1`040?ooo`2XJXX0j:6000000080oooo0`0000020:k5jP04023/1`2^aNX0[/GZ023/1`D0[/GZ1P0P
k0L30:k5jP03023/1`2^aNX0[/GZ0080[/GZ00<08>`70:k5jP0000001@0Pk0L50:c2jP04023/1`2/
`^X0[<;Z0:c2jP<08>`700<0[<;Z023/1`2/`^X00P2/`^X00`0Pk0L0[<;Z0:c2jP02023/1`800000
2@2U^nT00`0Pk0L0YK_Y0:Fkj@03023/1`030:Fkj@0Pk0L08>`70080YK_Y00P00000023/1`0Pk0L0
[<;Z0000000Pk0L00000023/1`8000001@0Pk0L300000003023/1`000000[<;Z0080[<;Z1@0Pk0L0
103oool08>`7023/1`3oool2023/1`030000002a`^L0/L;W00@0/L;W0P000002023/1a`0[/GZ0P00
000E0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003oool0oooo01D0oooo0`0Pk0L5
0?ooo`05023/1`3oool0oooo023/1`3oool00P0Pk0L0103oool0Z6Z:0>RQP00000020?ooo`030000
H@000000[/GZ0080[/GZ00D08>`70:k5jP2^aNX0[/GZ023/1`040:k5jPH08>`70`2^aNX00`0Pk0L0
[/GZ0:k5jP020:k5jP03023/1`2^aNX0[/GZ00D08>`71@2/`^X0100Pk0L0[<;Z0:c2jP2/`^X3023/
1`030:c2jP0Pk0L0[<;Z0080[<;Z00<08>`70:c2jP2/`^X00P0Pk0L00`000000YK_Y0:Fkj@070:Fk
j@040000000Pk0L000000:Fkj@<08>`700<00000023/1`0Pk0L00P2U^nT0200000008>`7023/1`00
0000VfNE023/1`0000008>`70P000005023/1`80000000@0bhZ>023/1`00000000000P2/`^X5023/
1`040?ooo`0Pk0L08>`70?ooo`808>`700<000000;72i`2a`^L0102a`^L0100000008>`7023/1`0P
k0L;0:k5jP030000002^aNX0000000h0[/GZ00<08>`70000003oool0503oool00`000000oooo0?oo
o`0Q0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`<08>`71P3oool0100Pk0L0oooo023/1`3o
ool2023/1`040?ooo`2XJXX0j:60000000<0oooo00D000000:k5jP2^aNX0[/GZ023/1`030:k5jP03
023/1`2^aNX0[/GZ0080[/GZ1P0Pk0L30:k5jP03023/1`2^aNX0[/GZ0080[/GZ00<08>`70:k5jP2^
aNX01@0Pk0L50:c2jP04023/1`2/`^X0[<;Z0:c2jP<08>`700<0[<;Z023/1`2/`^X00P2/`^X00`0P
k0L0[<;Z0:c2jP02023/1`030000002U^nT0YK_Y00L0YK_Y00@00000023/1`000000YK_Y0`0Pk0L0
0`2U^nT08>`7023/1`020:Fkj@030000000Pk0L08>`70080000000<08>`70:adU00Pk0L00P000005
023/1`<0000000<08>`70000000000000P000004023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0P
k0L7000000<08>`72`2^aNX00`000000^gZ:0000000>0:k5jP03023/1`000000oooo01@0oooo00<0
00000?ooo`3oool08@3oool001l0oooo00<000000?ooo`3oool05@3oool3023/1`H0oooo00@08>`7
0?ooo`0Pk0L0oooo0P0Pk0L0103oool0Z6Z:0>RQP00000030?ooo`050000002^aNX0[/GZ0:k5jP0P
k0L00`2^aNX00`0Pk0L0[/GZ0:k5jP020:k5jPH08>`70`2^aNX00`0Pk0L0[/GZ0:k5jP020:k5jP03
023/1`2^aNX0[/GZ00D08>`71@2/`^X0100Pk0L0[<;Z0:c2jP2/`^X3023/1`030:c2jP0Pk0L0[<;Z
0080[<;Z00<08>`70:c2jP2/`^X00P0Pk0L00`2/`^X000000:Fkj@070:Fkj@040000000Pk0L00000
0:Fkj@<08>`700<0YK_Y023/1`0Pk0L00P2U^nT0200000008>`7023/1`2KIiD00000023/1`000000
8>`70P2^aNX6023/1`030:k5jP0000008>`700@00000100Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00<08>`700<0oooo023/1`3oool00P3oool00`0Pk0L00000023/1`02023/1`/0[/GZ0`00000>0:k5
jP03023/1`3oool0oooo01@0oooo00<000000?ooo`3oool08@3oool001l0oooo00<000000?ooo`3o
ool05@3oool3023/1`H0oooo00@08>`70?ooo`0Pk0L0oooo0P0Pk0L500000080oooo00D000000:k5
jP2^aNX0[/GZ023/1`030:k5jP03023/1`2^aNX0[/GZ0080[/GZ1`0Pk0L20:k5jP03023/1`2^aNX0
[/GZ0080[/GZ00<08>`70:k5jP2^aNX01@0Pk0L50:c2jP04023/1`2/`^X0[<;Z0:c2jP<08>`700<0
[<;Z023/1`2/`^X00P2/`^X00`0Pk0L0[<;Z0:c2jP02023/1`80[<;Z00<000000:Fkj@2U^nT01@2U
^nT0100000008>`70000002U^nT3023/1`040:Fkj@0Pk0L08>`70:Fkj@8000000P0Pk0L01@000000
[/GZ023/1`2^aNX08>`70080[/GZ1P0Pk0L20:k5jP03023/1`000000[/GZ0080000000D08>`70000
000Pk0L08>`70?ooo`03023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70`3oool00`0Pk0L00000
023/1`02023/1`/0[/GZ00<000000;]jRP0000003@2^aNX00`0000008>`70?ooo`0E0?ooo`030000
003oool0oooo0240oooo000O0?ooo`030000003oool0oooo01H0oooo0P0Pk0L60?ooo`04023/1`3o
ool08>`70?ooo`P0000000<0oooo0000002^aNX00P2^aNX01@0Pk0L0[/GZ0:k5jP2^aNX08>`700@0
[/GZ1`0Pk0L20:k5jP03023/1`2^aNX0[/GZ0080[/GZ00<08>`70:k5jP2^aNX01@0Pk0L50:c2jP04
023/1`2/`^X0[<;Z0:c2jP<08>`700<0[<;Z023/1`2/`^X00P2/`^X00`0Pk0L0[<;Z0:c2jP02023/
1`80[<;Z00<000000:Fkj@2U^nT01@2U^nT0100000008>`70000002U^nT3023/1`060:Fkj@0Pk0L0
8>`700000026F9@000000P0Pk0L20:k5jP03023/1`2^aNX08>`70080[/GZ1P0Pk0L20:k5jP03023/
1`000000[/GZ0080[/GZ00D08>`70000000Pk0L08>`70?ooo`03023/1`060?ooo`0Pk0L08>`7023/
1`3oool08>`70`3oool00`0Pk0L0oooo023/1`02023/1`/0[/GZ00<000000;]jRP0000003@2^aNX0
0`0000008>`70?ooo`0E0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003oool0oooo
01H0oooo0P0Pk0L60?ooo`04023/1`3oool08>`70?ooo`800000102a`^L2000000030?ooo`000000
[/GZ0080[/GZ00D08>`70:k5jP2^aNX0[/GZ023/1`040:k5jPL08>`70P2^aNX00`0Pk0L0[/GZ0:k5
jP020:k5jP03023/1`2^aNX0000000D08>`71@2/`^X0100Pk0L0[<;Z0:c2jP2/`^X3023/1`030:c2
jP0Pk0L0[<;Z0080[<;Z00<08>`70:c2jP2/`^X00P0Pk0L30:c2jP8000001@2U^nT0100000008>`7
0000002U^nT3023/1`030:Fkj@0Pk0L08>`70080000000<0[/GZ023/1`0Pk0L00P2^aNX3023/1`80
[/GZ1P0Pk0L20:k5jP03023/1`000000[/GZ0080[/GZ00T08>`70000000Pk0L08>`70?ooo`0Pk0L0
oooo023/1`3oool00`0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool08>`700808>`72`2^
aNX00`000000^gZ:0000000;0:k5jP80000000<0oooo023/1`3oool05@3oool00`000000oooo0?oo
o`0Q0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`808>`71P3oool01@0Pk0L0oooo023/1`3o
ool0000000H0/L;W00@000000?ooo`3oool000000P2^aNX01@0Pk0L0[/GZ0:k5jP2^aNX08>`700@0
[/GZ1`0Pk0L20:k5jP03023/1`2^aNX0[/GZ0080[/GZ00<08>`70000002/`^X01@0Pk0L50:c2jP80
8>`70P2/`^X3023/1`030:c2jP0Pk0L0[<;Z0080[<;Z00@08>`70:c2jP2/`^X08>`7102/`^X00`0P
k0L0[<;Z00000002000000060:Fkj@0000000000023/1`000000YK_Y0`0Pk0L00`2U^nT08>`7023/
1`030:k5jP808>`70P2^aNX3023/1`80[/GZ1P0Pk0L20:k5jP03023/1`000000[/GZ0080[/GZ100P
k0L00`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`0Pk0L00P0P
k0L;0:k5jP030000002kNXX0000000X0[/GZ00D00000023/1`3oool0oooo023/1`0F0?ooo`030000
003oool0oooo0240oooo000O0?ooo`030000003oool0oooo01H0oooo0P0Pk0L60?ooo`05023/1`3o
ool08>`70?ooo`0000000`2a`^L010000000/L;W0;72i`0000030?ooo`030000002^aNX08>`700<0
[/GZ00<08>`70:k5jP2^aNX00P2^aNX7023/1`80[/GZ00H08>`70:k5jP2^aNX0[/GZ0000000Pk0L2
0:c2jPD08>`71@2/`^X2023/1`030:c2jP2/`^T08>`700808>`700D0[<;Z023/1`2/`^X0[<;Z023/
1`030:c2jP03023/1`2/`^X0[<;Z0080[<;Z00@08>`70:c2jP2/`^X0[<;Z100000000`0Pk0L00000
00000006023/1`<0[/GZ0P0Pk0L00`2^aNX00000023/1`02023/1`80[/GZ1P0Pk0L20:k5jP03023/
1`000000[/GZ0080[/GZ0`0Pk0L010000000oooo023/1`3oool5023/1`030?ooo`0Pk0L0oooo0080
oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`000000[/GZ0:k5jP080:k5jP030000002kNXX0000000P0
[/GZ0P0000001@0Pk0L0oooo0?ooo`3oool08>`701H0oooo00<000000?ooo`3oool08@3oool001l0
oooo00<000000?ooo`3oool05P3oool2023/1`H0oooo00H08>`70?ooo`0Pk0L0oooo023/1`000003
0;72i`8000001@3oool00`0000008>`70:k5jP020:k5jP03023/1`2^aNX0[/GZ0080[/GZ1`0Pk0L0
0`2^aNX00000023/1`020:k5jP030000002/`^X08>`70080[<;Z1@0Pk0L50:c2jP808>`700<00000
0:c2j@0Pk0L00P0Pk0L01@2/`^X08>`70:c2jP2/`^X08>`700<0[<;Z00<08>`70:c2jP2/`^X00P2/
`^X02`0Pk0L0[<;Z0:c2jP2/`^X00000023/1`3oool00000023/1`000000oooo00H08>`70`2^aNX2
023/1`030:k5jP0000008>`700808>`70P2^aNX6023/1`80[/GZ00<08>`70000002^aNX00P2^aNX3
023/1`030000003oool08>`700H08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo023/1`02
023/1`030?ooo`000000000000P0[/GZ00<000000;]jRP0000001`2^aNX010000000oooo0?ooo`0P
k0L30?ooo`03023/1`3oool0oooo01@0oooo00<000000?ooo`3oool08@3oool001l0oooo00<00000
0?ooo`3oool05P3oool2023/1`H0oooo00@08>`70?ooo`0Pk0L0oooo0P0Pk0L4000000L0oooo00D0
8>`7000000000000[/GZ023/1`040:k5jPL08>`70P2^aNX01P0Pk0L000000000000Pk0L0[<;Z023/
1`80[<;Z1@0Pk0L50:c2jP808>`700<000000:c2j@0Pk0L00P0Pk0L01@2/`^X08>`70:c2j@2/`^X0
8>`700<0[<;Z00<08>`70:c2jP2/`^X00P2/`^X02`0Pk0L0[<;Z0:c2jP2/`^X00000023/1`3oool0
0000023/1`000000oooo00H08>`70`2^aNX2023/1`80[/GZ0`0Pk0L20:k5jPH08>`70P2^aNX00`0P
k0L000000:k5jP020:k5jP<08>`700<000000?ooo`0Pk0L01P0Pk0L00`3oool08>`70?ooo`020?oo
o`03023/1`3oool08>`700808>`70`3oool00`000000[/GZ0:k5jP050:k5jP030000002kNXX00000
00@0[/GZ0`0000030?ooo`05023/1`3oool0oooo0?ooo`0Pk0L05P3oool00`000000oooo0?ooo`0Q
0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`808>`71P3oool0100Pk0L0oooo023/1`3oool2
023/1`80oooo00<08>`70?ooo`3oool01P3oool01P0Pk0L0oooo0?ooo`0000008>`7000000<0[/GZ
1`0Pk0L200000006023/1`2/`^X0[<;Z023/1`2/`^X08>`70P2/`^X5023/1`030:c2jP2/`^T0[<;Z
0080[<;Z0P0Pk0L00`000000[<;Z023/1`02023/1`050:c2jP0Pk0L0[<;Y0:c2jP0Pk0L00`2/`^X0
0`0Pk0L0[<;Z0:c2jP020:c2jP0;023/1`2/`^X0[<;Z0:c2jP0000008>`70?ooo`0000008>`70000
003oool01P0Pk0L30:k5jP808>`70P2^aNX3023/1`80[/GZ1P0Pk0L20:k5jP03023/1`000000[/GZ
0080[/GZ0`0Pk0L00`000000oooo023/1`06023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?oo
o`0Pk0L00P0Pk0L40?ooo`<0000000<08>`70000000000000P0000000`2kNXX00000000000030000
00H0oooo00D08>`70?ooo`3oool0oooo023/1`0F0?ooo`030000003oool0oooo0240oooo000O0?oo
o`030000003oool0oooo01H0oooo0P0Pk0L60?ooo`04023/1`3oool08>`70?ooo`808>`70P3oool0
0`0Pk0L0oooo0?ooo`060?ooo`03023/1`3oool0oooo0080oooo00@08>`700000000000000001`0P
k0L0103oool00000023/1`000002023/1`040:c2jP0Pk0L0[<;Z0:c2jPD08>`7102/`^X01@2/`^T0
8>`7023/1`000000j:6000<08>`700D0[<;Z023/1`2/`^T0[<;Z023/1`030:c2jP03023/1`2/`^X0
[<;Z0080[<;Z00X08>`70:c2jP2/`^X0[<;Z0000000Pk0L0oooo0000000Pk0L000001`0Pk0L30:k5
jP808>`70P2^aNX3023/1`030:k5jP0000008>`700D08>`70P2^aNX00`0Pk0L000000:k5jP020:k5
jP@08>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0
8>`700808>`71P3oool00`0000008>`70?ooo`020?ooo`0306LgPP2kNXX0000000X0oooo00D08>`7
0?ooo`3oool0oooo023/1`0F0?ooo`030000003oool0oooo0240oooo000O0?ooo`030000003oool0
oooo01H0oooo0P0Pk0L60?ooo`04023/1`3oool08>`70?ooo`808>`70P3oool2023/1`L0oooo00<0
8>`70?ooo`3oool00P3oool0100Pk0L0oooo0?ooo`3oool7023/1`040?ooo`0000008>`700000080
8>`700@0[<;Z023/1`2/`^X0[<;Z1@0Pk0L01@2/`^X0[<;Y0:c2j@2/`^T0[<;Z00808>`700<00000
0>RQP00Pk0L00P0Pk0L01@2/`^X08>`70:c2j@2/`^X08>`700<0[<;Z00<08>`70:c2jP2/`^X00P2/
`^X02P0Pk0L0[<;Z023/1`000000oooo023/1`3oool00000023/1`000007023/1`<0[/GZ0P0Pk0L2
0:k5jP<08>`700<0[/GZ0000000Pk0L01@0Pk0L20:k5jP03023/1`000000[/GZ0080[/GZ100Pk0L0
103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`0Pk0L00P0P
k0L60?ooo`808>`700<0oooo0000000000001@0000080?ooo`05023/1`3oool0oooo0?ooo`0Pk0L0
5P3oool00`000000oooo0?ooo`0Q0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`808>`71P3o
ool0100Pk0L0oooo023/1`3oool2023/1`80oooo0P0Pk0L70?ooo`03023/1`3oool0oooo0080oooo
00@08>`700000000000000001`0Pk0L200000006023/1`2/`^X08>`7023/1`2/`^X08>`70P2/`^X5
023/1`D0[<;Z0P0Pk0L00`000000j:60023/1`02023/1`050:c2j@0Pk0L0[<;Z0:c2jP0Pk0L00`2/
`^X00`0Pk0L0[<;Z0:c2jP020:c2jP05023/1`2/`^X08>`70000003oool00P0Pk0L00`0000008>`7
00000007023/1`<0[/GZ0P0Pk0L20:k5jP<08>`700<0[/GZ0:Q[RP0Pk0L01@0Pk0L20:k5jP03023/
1`000000[/GZ0080[/GZ100Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0oooo0080
oooo00<08>`70?ooo`0Pk0L00P0Pk0L60?ooo``000001P3oool01@0Pk0L0oooo0?ooo`3oool08>`7
01H0oooo00<000000?ooo`3oool08@3oool001l0oooo00<000000?ooo`3oool05P3oool2023/1`H0
oooo00@08>`70?ooo`0Pk0L0oooo0P0Pk0L20?ooo`808>`71`3oool01P0Pk0L0oooo0?ooo`3oool0
0000023/1`<000001`0Pk0L4000000808>`700@0[<;Z023/1`2/`^X0[<;Z1@0Pk0L50:c2jP808>`7
00<000000>RQP00Pk0L00P0Pk0L01@2/`^X08>`70:c2jP2/`^X08>`700<0[<;Z00<08>`70:c2jP2/
`^X00P2/`^X01@0Pk0L0[<;Z023/1`000000oooo00D000001`0Pk0L30:k5jP808>`70P2^aNX3023/
1`030:k5jP2XJhX08>`700D08>`70P2^aNX00`0Pk0L000000:k5jP020:k5jP@08>`700@0oooo023/
1`0Pk0L0oooo100Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool08>`700808>`7103oool5
0000000309QQSP2[LI40Zg6A00T000000`3oool01@0Pk0L0oooo0?ooo`3oool08>`701H0oooo00<0
00000?ooo`3oool08@3oool001l0oooo00<000000?ooo`3oool05P3oool2023/1`H0oooo00<08>`7
0?ooo`0Pk0L00`0Pk0L20?ooo`808>`71`3oool02@0Pk0L0oooo0?ooo`3oool00000023/1`1oC8T0
V66>00000004023/1`050000000Pk0L08>`70000003;SI800`0000000`0Pk0L0[<;Z023/1`020:c2
jPD08>`71@2/`^X2023/1`030000003XXH008>`700808>`700D0[<;Z023/1`2/`^X0[<;Z023/1`03
0:c2jP03023/1`2/`^X0[<;Z0080[<;Z00@08>`70:c2jP0Pk0L0oooo100000001@0Pk0L0/L;W023/
1`0Pk0L0000000@08>`70`2^aNX2023/1`80[/GZ0`0Pk0L00`2^aNX0Z6^:023/1`05023/1`80[/GZ
00<08>`70000002^aNX00P2^aNX4023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3oool0
0P3oool00`0Pk0L0oooo023/1`02023/1`<0oooo2@0000040:Fkj@@0000000D0fi^@0000003oool0
oooo023/1`030?ooo`03023/1`3oool0oooo01D0oooo00<000000?ooo`3oool0803oool001l0oooo
00<000000?ooo`3oool05P3oool2023/1`H0oooo00<08>`70?ooo`3oool00`0Pk0L20?ooo`808>`7
1`3oool00`0Pk0L0oooo0?ooo`0200000004023/1`00000000000:Bkj@@08>`700@0Y;_Y023/1`0P
k0L0Y;_Y100000000`0Pk0L0[<;Z023/1`020:c2jPD08>`71@2/`^X2023/1`030000003XXH008>`7
00808>`700D0[<;Z023/1`2/`^X0[<;Z023/1`030:c2jP03023/1`2/`^X0[<;Z0080[<;Z00@08>`7
0000000Pk0L0oooo0P0000020;72i`05023/1`2a`^L08>`7023/1`000000100Pk0L30:k5jP808>`7
0P2^aNX3023/1`030:k5jP2XJhX08>`700D08>`70P2^aNX0100Pk0L000000:k5jP2^aNX3023/1`03
0?ooo`0Pk0L0oooo00L08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo023/1`02023/1`<0
oooo0`00000<0:Fkj@D0000000<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`0E0?ooo`03
0000003oool0oooo0200oooo000O0?ooo`030000003oool0oooo01H0oooo0P0Pk0L60?ooo`03023/
1`3oool0oooo00<08>`70P3oool2023/1`L0oooo00<08>`70?ooo`0000000P000000100Pk0L0Y;_Y
0:Bkj@2T^nT4023/1`030:Bkj@0Pk0L08>`70080Y;_Y00H08>`70:Bkj@00000000000:c2jP0Pk0L2
0:c2jPD08>`71@2/`^X2023/1`030000003XXH008>`700808>`700D0[<;Z023/1`2/`^X0[<;Z023/
1`030:c2jP0:023/1`2/`^X0[<;Z0:c2jP0000008>`70?ooo`0Pk0L0oooo000000<0/L;W00D08>`7
0;72i`0Pk0L08>`700000004023/1`<0[/GZ0P0Pk0L20:k5jP<08>`700<0[/GZ0:Q[RP0Pk0L01@0P
k0L20:k5jP04023/1`0000000000000000<08>`700<0oooo023/1`3oool01`0Pk0L00`3oool08>`7
0?ooo`020?ooo`03023/1`3oool08>`700808>`70P3oool200000100YK_Y0`0000000`3oool08>`7
0?ooo`020?ooo`03023/1`3oool0oooo01D0oooo00<000000?ooo`3oool0803oool001l0oooo00<0
00000?ooo`3oool05P3oool2023/1`H0oooo00<08>`70?ooo`3oool00`0Pk0L20?ooo`808>`71`3o
ool01P0Pk0L00000000000000000Y;_Y023/1`<0Y;_Y100Pk0L00`2T^nT08>`7023/1`020:Bkj@03
023/1`2T^nT000000080000000<08>`70:c2jP0000001@0Pk0L30:c2jP8000000P0Pk0L2000000<0
8>`70`0000000`2/`^X08>`70:c2jP020:c2jP09023/1`2/`^X0[<;Z0000003oool08>`70?ooo`0P
k0L0oooo008000000P2a`^L00`0Pk0L0/L;W023/1`06023/1`80000000<0[/GZ023/1`0Pk0L00P2^
aNX3023/1`030:k5jP2XJhX08>`700D08>`70P2^aNX0100Pk0L000000?ooo`3oool3023/1`030?oo
o`0Pk0L0oooo00L08>`700D0oooo023/1`3oool0oooo023/1`020?ooo`<08>`70P3oool200000180
YK_Y0P0000001@0Pk0L0oooo0?ooo`3oool08>`701L0oooo00<000000?ooo`3oool0803oool001l0
oooo00<000000?ooo`3oool05P3oool2023/1`H0oooo00<08>`70?ooo`3oool00`0Pk0L20?ooo`80
8>`71`3oool00`0Pk0L000000:Bkj@020:Bkj@04023/1`2T^nT0Y;_Y0:Bkj@@08>`700<0Y;_Y023/
1`0Pk0L00P2T^nT00`0Pk0L0Y;_Y0:Bkj@0200000003023/1`000000[<;Z00D08>`700D0[<;Z0000
00000000VfNE0:adU002023/1`8000000`0Pk0L400000005023/1`00000000000:c2jP0Pk0L00P00
00020?ooo`03023/1`3oool08>`70080oooo0`0000000`0Pk0L00000023/1`06023/1`80oooo00<0
0000023/1`0Pk0L00P2^aNX3023/1`030:k5jP2XJhX08>`700D08>`70P000000100Pk0L000000?oo
o`3oool3023/1`030?ooo`0Pk0L0oooo00L08>`700D0oooo023/1`3oool0oooo023/1`020?ooo`<0
8>`70P3oool00`000000YK_Y0:Fkj@0A0:Fkj@80000000D08>`70?ooo`3oool0oooo023/1`0G0?oo
o`030000003oool0oooo0200oooo000O0?ooo`030000003oool0oooo01H0oooo0P0Pk0L60?ooo`03
023/1`3oool0oooo00<08>`70P3oool2023/1`L0oooo00<08>`70000002T^nT00`2T^nT00`0Pk0L0
Y;_Y0:Bkj@04023/1`030:Bkj@0Pk0L08>`70080Y;_Y00@08>`70:Bkj@2T^nT0Y;_Y0P0000000`3o
ool00000023/1`03023/1`80000000@0VfNE00000000000000000P0Pk0L00`2/M9@0^gnB023/1`02
023/1`050<^:SP0Pk0L0bhZ>0000000Pk0L00`0000000`0Pk0L0oooo0?ooo`020?ooo`03023/1`3o
ool08>`70080oooo100Pk0L00`3oool08>`7023/1`05023/1`<0oooo0P0Pk0L2000000<08>`700<0
[/GZ0:Q[RP0Pk0L01@0Pk0L20?ooo`04023/1`000000oooo0?ooo`<08>`700<0oooo023/1`3oool0
1`0Pk0L01P3oool08>`70?ooo`3oool08>`70?ooo`@08>`70P3oool00`000000YK_Y0:Fkj@0B0:Fk
j@030000000Pk0L0oooo0080oooo00<08>`70?ooo`3oool05@3oool00`000000oooo0?ooo`0P0?oo
o`007`3oool00`000000oooo0?ooo`0F0?ooo`808>`71P3oool00`0Pk0L0oooo0?ooo`03023/1`80
oooo0P0Pk0L70?ooo`03023/1`000000Y;_Y00<0Y;_Y00<08>`70:Bkj@2T^nT0100Pk0L00`000000
8>`7023/1`020:Bkj@04023/1`2T^nT0Y;_Y0:Bkj@8000000P3oool4023/1`H000000P0Pk0L20000
00<08>`7100000001P0Pk0L000000=^GR00000008>`7000000<0oooo00<08>`70?ooo`0Pk0L00P3o
ool5023/1`030?ooo`0Pk0L08>`700@08>`70`3oool2023/1`80oooo0`0Pk0L00`000000Z6^:023/
1`05023/1`80oooo00@08>`70000003oool0oooo0`0Pk0L00`3oool08>`70?ooo`07023/1`060?oo
o`0Pk0L0oooo0?ooo`0Pk0L0oooo100Pk0L20?ooo`030000002U^nT0YK_Y00<0YK_Y00H00000023/
1`2U^nT0o;QQ0:Fkj@0000090:Fkj@030000000Pk0L0oooo0080oooo00<08>`70?ooo`3oool05@3o
ool00`000000oooo0?ooo`0P0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`808>`71P3oool0
0`0Pk0L0oooo0?ooo`03023/1`80oooo0P0Pk0L70?ooo`03023/1`000000Y;_Y00<0Y;_Y00<08>`7
0:Bkj@2T^nT0100Pk0L00`0000008>`7023/1`020:Bkj@03023/1`2T^nT0Y;_Y0080Y;_Y00<00000
0?ooo`3oool0100Pk0L3000000<0[/GZ0P0Pk0L20:k5jP<08>`700T0[/GZ023/1`2^aNX0[/GZ023/
1`2^aNX000000>jUNP0Pk0L00P0000020?ooo`03023/1`3oool08>`70080oooo1@0Pk0L00`3oool0
8>`7023/1`04023/1`<0oooo0P0Pk0L20?ooo`<08>`700<0oooo0000000Pk0L01@0Pk0L20?ooo`04
023/1`000000oooo0?ooo`<08>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`02023/
1`060?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo100Pk0L20?ooo`030000002U^nT0YK_Y00<0YK_Y00@0
0000023/1`2U^nT0001R0P0000090:Fkj@050000000Pk0L0oooo0?ooo`0Pk0L0603oool00`000000
oooo0?ooo`0P0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`808>`71P3oool00`0Pk0L0oooo
0?ooo`03023/1`80oooo0P0Pk0L70?ooo`03023/1`000000Y;_Y00<0Y;_Y00<08>`70:Bkj@2T^nT0
100Pk0L00`0000008>`7023/1`020:Bkj@03023/1`2T^nT0Y;_Y0080Y;_Y00<000000?ooo`000000
1@0Pk0L50:k5jP808>`70P2^aNX3023/1`040:k5jP0Pk0L0[/GZ0:k5jP808>`700D0[/GZ0000000P
k0L0kZEj000000020?ooo`03023/1`3oool08>`70080oooo1@0Pk0L00`3oool08>`7023/1`04023/
1`<0oooo0P0Pk0L01`3oool00000023/1`0000008>`70000002[LI401P0Pk0L20?ooo`04023/1`00
0000oooo0?ooo`<08>`700@0oooo023/1`3oool08>`70P3oool4023/1`060?ooo`0Pk0L0oooo0?oo
o`0Pk0L0oooo0`0Pk0L30?ooo`030000002U^nT0YK_Y00@0YK_Y00<08>`70:Fkj@2U^nT00P000009
0:Fkj@050000000Pk0L0oooo0?ooo`0Pk0L0603oool00`000000oooo0?ooo`0P0?ooo`007`3oool0
0`000000oooo0?ooo`0F0?ooo`808>`71P3oool00`0Pk0L0oooo0?ooo`03023/1`80oooo0P0Pk0L7
0?ooo`03023/1`3oool0000000<0Y;_Y00<08>`70:Bkj@2T^nT0100Pk0L00`0000008>`7023/1`02
0:Bkj@08023/1`2T^nT0Y;_Y0:Bkj@0000008>`70?ooo`000005023/1`D0[/GZ0P0Pk0L20:k5jP<0
8>`700@0[/GZ023/1`2^aNX0[/GZ0P0Pk0L20:k5jP08023/1`00000000000000003oool08>`70?oo
o`0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`808>`70P0000000`0Pk0L00000
023/1`02000000H08>`700@00000023/1`3oool000000P3oool3023/1`040?ooo`0Pk0L0oooo023/
1`80oooo100Pk0L01P3oool08>`70?ooo`3oool08>`70?ooo`<08>`7103oool2000000@0YK_Y00<0
8>`70:Fkj@0006800P0000090:Fkj@050000000Pk0L0oooo0?ooo`0Pk0L0603oool00`000000oooo
0?ooo`0P0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`<08>`71@3oool00`0Pk0L0oooo0?oo
o`03023/1`80oooo0P0Pk0L70?ooo`04023/1`3oool0oooo00000080Y;_Y00<08>`70:Bkj@2T^nT0
100Pk0L00`0000008>`7023/1`020:Bkj@06023/1`2T^nT0Y;_Y0000003oool08>`70P000005023/
1`D0[/GZ0P0Pk0L20:k5jP<08>`700@0[/GZ023/1`2^aNX0[/GZ0P0Pk0L20:k5jP08023/1`2^aNX0
00000000003oool08>`70?ooo`0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`80
8>`700D00000023/1`0000000000023/1`02000000H08>`700@00000023/1`00000000000P3oool3
023/1`040?ooo`0Pk0L0oooo023/1`80oooo100Pk0L01P3oool08>`70?ooo`3oool08>`70?ooo`<0
8>`71P3oool200000080YK_Y00<08>`70:Fkj@0006800P0000060:Fkj@<000000P0Pk0L20?ooo`03
023/1`3oool0oooo01H0oooo00<000000?ooo`3oool0803oool001l0oooo00<000000?ooo`3oool0
5P3oool3023/1`D0oooo00<08>`70?ooo`3oool00`0Pk0L20?ooo`808>`71`3oool0100Pk0L0oooo
0?ooo`3oool200000003023/1`2T^nT0Y;_Y00@08>`700<00000023/1`0Pk0L00P2T^nT01P0Pk0L0
Y;_Y0000000Pk0L0oooo023/1`8000001@0Pk0L50:k5jP808>`70P2^aNX3023/1`040:k5jP0Pk0L0
[/GZ0:k5jP808>`70P2^aNX0200Pk0L0[/GZ000000000000oooo023/1`3oool08>`70P3oool5023/
1`030?ooo`0Pk0L08>`700@08>`70`3oool2023/1`030000000Pk0L0Y;_Y00808>`70P2T^nT6023/
1`040000000Pk0L0000000000080oooo0`0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`@08>`700H0
oooo023/1`3oool0oooo023/1`3oool3023/1`L0oooo00H08>`70000000Pk0L08>`7000000000682
000000@0YK_Y0`0000020?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`0F0?ooo`030000003oool0
oooo0200oooo000O0?ooo`030000003oool0oooo01H0oooo0`0Pk0L50?ooo`03023/1`3oool0oooo
00<08>`70P3oool2023/1`L0oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0000000000004023/
1`030000000Pk0L08>`70080Y;_Y00P08>`70000000Pk0L08>`70?ooo`0Pk0L000000:k5jPD08>`7
1@2^aNX2023/1`80[/GZ0`0Pk0L0102^aNX08>`70:k5jP2^aNX2023/1`80[/GZ00P08>`70:k5jP2^
aNX000000?ooo`0Pk0L0oooo023/1`80oooo1@0Pk0L00`3oool08>`7023/1`04023/1`80oooo00H0
0000023/1`0Pk0L0Y;_Y023/1`000002023/1`80Y;_Y1P0Pk0L0102T^nT08>`70000000000020?oo
o`<08>`700@0oooo023/1`3oool08>`70P3oool4023/1`060?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo
0`0Pk0L70?ooo`06023/1`3oool08>`7023/1`000000001R0P0000030:Fkj@800000103oool2023/
1`80oooo00<08>`70?ooo`3oool05P3oool00`000000oooo0?ooo`0P0?ooo`007`3oool00`000000
oooo0?ooo`0F0?ooo`<08>`71@3oool00`0Pk0L0oooo0?ooo`03023/1`80oooo0P0Pk0L70?ooo`03
023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool0100Pk0L00`0000008>`7023/1`0200000006
023/1`3oool08>`7023/1`0000008>`70P2^aNX5023/1`D0[/GZ0P0Pk0L20:k5jP<08>`700@0[/GZ
023/1`2^aNX0[/GZ0P0Pk0L20:k5jP03023/1`2^aNX0[/GZ0080000000<08>`70?ooo`0Pk0L00P3o
ool5023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo0000000000000P0Pk0L00`2T^nT08>`70000
0002023/1`80Y;_Y1@0Pk0L20:Bkj@05023/1`2T^nT000000000003oool00`0Pk0L0103oool08>`7
0?ooo`0Pk0L20?ooo`@08>`700H0oooo023/1`3oool0oooo023/1`3oool3023/1`L0oooo00L08>`7
0?ooo`0Pk0L08>`70?ooo`000000Z6^:00@000001P3oool2023/1`80oooo00<08>`70?ooo`3oool0
5P3oool00`000000oooo0?ooo`0P0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`<08>`71@3o
ool00`0Pk0L0oooo0?ooo`03023/1`80oooo0P0Pk0L70?ooo`03023/1`3oool0oooo00<0oooo00<0
8>`70?ooo`3oool0100Pk0L00`0000008>`7023/1`020?ooo`06023/1`3oool08>`7023/1`000000
8>`70P2^aNX5023/1`D0[/GZ0P0Pk0L20:k5jP<08>`700@0[/GZ023/1`2^aNX0[/GZ0P0Pk0L20:k5
jP08023/1`2^aNX0[/GZ0:k5jP0000008>`70?ooo`0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L0
100Pk0L00`3oool000000:Bkj@02023/1`030:Bkj@0Pk0L08>`700808>`70P2T^nT5023/1`80Y;_Y
00D08>`70:Bkj@00000000000?ooo`03023/1`040?ooo`0Pk0L0oooo023/1`80oooo1@0Pk0L30?oo
o`03023/1`3oool08>`700808>`71`3oool00`0Pk0L0oooo023/1`020?ooo`030000HP2XJhX00000
00T0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo01H0oooo00<000000?ooo`3oool0803oool001l0
oooo00<000000?ooo`3oool05P3oool3023/1`D0oooo00<08>`70?ooo`3oool00`0Pk0L20?ooo`80
8>`71`3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00@08>`700<00000023/1`0P
k0L00P3oool01P0Pk0L0oooo023/1`0Pk0L00000023/1`80[/GZ1@0Pk0L50:k5jP808>`700<00000
0:k5jP0Pk0L00P0Pk0L0102^aNX08>`70:k5jP2^aNX2023/1`80[/GZ00P08>`70:k5jP2^aNX0[/GZ
0000000Pk0L0oooo023/1`80oooo1@0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`000000Y;_Y
00808>`700<0Y;_Y023/1`0Pk0L00P0Pk0L20:Bkj@03023/1`2T^nT08>`700808>`70P2T^nT00`0P
k0L0Y;_Y00000002000000<08>`700@0oooo023/1`3oool08>`70P3oool5023/1`<0oooo00<08>`7
0?ooo`0Pk0L00P0Pk0L70?ooo`03023/1`3oool08>`70080oooo00<0001R0:Q[RP0000002@3oool2
023/1`80oooo00<08>`70?ooo`3oool05P3oool00`000000oooo0?ooo`0P0?ooo`007`3oool00`00
0000oooo0?ooo`0F0?ooo`<08>`71@3oool00`0Pk0L0oooo0?ooo`03023/1`80oooo0P0Pk0L70?oo
o`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool0100Pk0L00`0000008>`7023/1`020?oo
o`06023/1`3oool08>`7023/1`0000008>`70P2^aNX5023/1`030000002^aNX0[/GZ0080[/GZ0P0P
k0L00`000000Fbio023/1`02023/1`040:k5jP0Pk0L0[/GZ0:k5jP808>`70P2^aNX0200Pk0L0[/GZ
0:k5jP000000oooo023/1`3oool08>`70P3oool4023/1`80oooo1P0Pk0L00`3oool000000:Bkj@02
023/1`030:Bkj@0Pk0L08>`700808>`700@0Y;_Y023/1`0Pk0L000000`0Pk0L20:Bkj@03023/1`2T
^nT00000008000000`0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`<08>`700<0oooo023/1`3oool0
0P3oool00`0Pk0L0oooo023/1`02023/1`L0oooo00<08>`70?ooo`0Pk0L00P3oool00`000680Z6^:
000000090?ooo`05023/1`3oool0oooo0?ooo`0Pk0L0603oool00`000000oooo0?ooo`0P0?ooo`00
7`3oool00`000000oooo0?ooo`0F0?ooo`<08>`71@3oool00`0Pk0L0oooo0?ooo`03023/1`80oooo
0P0Pk0L70?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool0100Pk0L00`0000008>`7
023/1`020?ooo`06023/1`3oool08>`7023/1`0000008>`70P2^aNX5023/1`030000002^aNX0[/GZ
0080[/GZ0P0Pk0L2000000<08>`700@0[/GZ023/1`2^aNX0[/GZ0P0Pk0L20:k5jP0;023/1`2^aNX0
[/GZ0000003oool08>`70?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L20?ooo`H08>`700<0oooo0000
002T^nT00P0Pk0L00`2T^nT08>`7023/1`02023/1`040:Bkj@0Pk0L08>`7000000<08>`70P2T^nT0
1@0Pk0L0Y;_Y0000002T^nT0000000<08>`700D0oooo023/1`3oool08>`70?ooo`04023/1`030?oo
o`0Pk0L0oooo0080oooo00<08>`70?ooo`0Pk0L00P0Pk0L70?ooo`03023/1`3oool08>`70080oooo
00<0001R0:Q[RP0000002@3oool01@0Pk0L0oooo0?ooo`3oool08>`701P0oooo00<000000?ooo`3o
ool0803oool001l0oooo00<000000?ooo`3oool05P3oool3023/1`D0oooo00<08>`70?ooo`3oool0
0`0Pk0L20?ooo`808>`71`3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00@08>`7
00<00000023/1`0Pk0L00P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`80[/GZ1@0Pk0L50:k5
jP808>`700<0ZF^:0>RQP00Pk0L00P0Pk0L0102^aNX08>`70:k5jP2^aNX2023/1`80[/GZ00<08>`7
0:k5jP0000000P3oool01P0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`70P3oool6023/1`030?oo
o`000000Y;_Y00808>`700<0Y;_Y023/1`0Pk0L00P0Pk0L0102T^nT08>`7023/1`000003023/1`80
Y;_Y00D08>`70:Bkj@000000Y;_Y00000003023/1`050?ooo`0Pk0L0oooo023/1`3oool0100Pk0L0
0`3oool08>`70?ooo`020?ooo`03023/1`3oool08>`700808>`71`3oool00`0Pk0L0oooo023/1`02
0?ooo`030000HP2XJhX0000000T0oooo00D08>`70?ooo`3oool0oooo023/1`0H0?ooo`030000003o
ool0oooo0200oooo000O0?ooo`030000003oool0oooo01H0oooo0`0Pk0L50?ooo`03023/1`3oool0
oooo00808>`700<0oooo023/1`3oool00P0Pk0L70?ooo`03023/1`3oool0oooo00@0oooo00<08>`7
0?ooo`0Pk0L00`0Pk0L00`0000008>`7023/1`020?ooo`06023/1`3oool08>`7023/1`3oool08>`7
0P2^aNX5023/1`D0[/GZ0P0Pk0L00`2YJhX0j:60023/1`02023/1`040:k5jP0Pk0L0[/GZ0:k5jP80
8>`70P2^aNX00`0Pk0L000000?ooo`020?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L2
0?ooo`H08>`70P3oool0100000008>`7023/1`2T^nT4023/1`040:Bkj@0Pk0L08>`7000000<08>`7
0P2T^nT01@0Pk0L0Y;_Y000000000000oooo00<08>`700D0oooo023/1`3oool08>`70?ooo`04023/
1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`0Pk0L00P0Pk0L70?ooo`03023/1`3oool08>`7
0080oooo1@0000070?ooo`05023/1`3oool0oooo0?ooo`0Pk0L0603oool00`000000oooo0?ooo`0P
0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`<08>`71@3oool00`0Pk0L0oooo0?ooo`02023/
1`030?ooo`0Pk0L0oooo00808>`71`3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool08>`7
00<08>`700<00000023/1`0000000P3oool0200Pk0L0oooo023/1`0Pk0L0oooo023/1`000000[/GZ
1@0Pk0L50:k5jP808>`700<0ZF^:0>RQP00Pk0L00P0Pk0L0102^aNX08>`70:k5jP2^aNX2023/1`80
[/GZ00<08>`70?ooo`3oool00P3oool01P0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`70P3oool6
023/1`<0oooo0P0Pk0L00`2T^nT08>`7023/1`02023/1`040:Bkj@0Pk0L08>`7000000<08>`70P2T
^nT00`0Pk0L00000000000020?ooo`<08>`700D0oooo023/1`3oool08>`70?ooo`04023/1`030?oo
o`0Pk0L0oooo0080oooo00<08>`70?ooo`0Pk0L00P0Pk0L70?ooo`03023/1`3oool08>`700P00000
1P3oool01@0Pk0L0oooo0?ooo`3oool08>`701P0oooo00<000000?ooo`3oool0803oool001l0oooo
00<000000?ooo`3oool05P3oool3023/1`D0oooo00<08>`70?ooo`3oool00P0Pk0L00`3oool08>`7
0?ooo`02023/1`L0oooo00<08>`70?ooo`3oool0103oool00`0Pk0L000000000000200000004023/
1`2a`^L08>`700000080oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L2000000D08>`71@2^aNX2
023/1`030:U[RP3XXH008>`700808>`700@0[/GZ023/1`2^aNX0[/GZ0P0Pk0L200000003023/1`3o
ool0oooo0080oooo00H08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`80oooo1P0Pk0L30?ooo`80
8>`700<00000023/1`0Pk0L00P0Pk0L0102T^nT08>`7023/1`000003023/1`050:Bkj@0000008>`7
0?ooo`0000000P3oool3023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`70?oo
o`020?ooo`03023/1`3oool08>`700808>`71`3oool00`0Pk0L0oooo023/1`02000000D0/L;W00<0
00000?ooo`3oool0103oool01@0Pk0L0oooo0?ooo`3oool08>`701P0oooo00<000000?ooo`3oool0
803oool001l0oooo00<000000?ooo`3oool05P3oool3023/1`D0oooo00<08>`70?ooo`3oool00P0P
k0L00`3oool08>`70?ooo`02023/1`L0oooo00<08>`70?ooo`3oool0103oool00`0Pk0L00000023/
1`03023/1`030;72i`0Pk0L000000080oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`D0
8>`71@2^aNX2023/1`030:U[RP3XXH008>`700808>`700@0[/GZ023/1`2^aNX0[/GZ0P0Pk0L20?oo
o`03023/1`3oool0oooo0080oooo00H08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`80oooo1P0P
k0L30?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L0100000008>`7023/1`000003023/1`050000
003oool08>`70?ooo`0000000P3oool3023/1`030?ooo`0Pk0L08>`70080oooo100Pk0L00`3oool0
8>`70?ooo`020?ooo`03023/1`3oool08>`700808>`71`3oool3023/1`030000002a`^L0/L;W00@0
/L;W00<000000?ooo`3oool0103oool01@0Pk0L0oooo0?ooo`3oool08>`701P0oooo00<000000?oo
o`3oool0803oool001l0oooo00<000000?ooo`3oool05P3oool3023/1`D0oooo00<08>`70?ooo`3o
ool00P0Pk0L00`3oool08>`70?ooo`02023/1`L0oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0
0000023/1`03023/1`070;72i`0Pk0L08>`70000003oool08>`70?ooo`02023/1`040?ooo`0Pk0L0
oooo0?ooo`D08>`71@2^aNX2023/1`030:U[RP3XXH008>`700808>`700@0[/GZ023/1`0000000000
0P0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00H08>`70?ooo`0Pk0L0oooo023/1`3oool3023/
1`80oooo1P0Pk0L30?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`7023/1`000003
023/1`80oooo00<08>`70?ooo`0000000P3oool3023/1`030?ooo`0Pk0L08>`70080oooo100Pk0L0
0`3oool08>`70?ooo`020?ooo`03023/1`3oool08>`700808>`71`3oool3023/1`030000002a`^L0
/L;W00@0/L;W00<000000?ooo`3oool0103oool01@0Pk0L0oooo0?ooo`3oool08>`701P0oooo00<0
00000?ooo`3oool0803oool001l0oooo00<000000?ooo`3oool05P3oool00`0Pk0L0oooo023/1`05
0?ooo`03023/1`3oool0oooo00@08>`700<0oooo023/1`0Pk0L01`3oool2023/1`D0oooo00<08>`7
0000000Pk0L00`0Pk0L00`2a`^L08>`7023/1`020?ooo`06023/1`3oool08>`7023/1`3oool08>`7
0P3oool5023/1`8000000`2^aNX2023/1`030:U[RP3XXH008>`700808>`700@00000023/1`3oool0
oooo0P0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00H08>`70?ooo`0Pk0L0oooo023/1`3oool3
023/1`80oooo1@0Pk0L40?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`7023/1`00
0003023/1`80oooo00<08>`70?ooo`0000000P3oool3023/1`030?ooo`0Pk0L08>`70080oooo100P
k0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool08>`700808>`71`3oool3023/1`8000000`2a
`^L2000000L0oooo00D08>`70?ooo`3oool0oooo023/1`0H0?ooo`030000003oool0oooo0200oooo
000O0?ooo`030000003oool0oooo01H0oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?oo
o`04023/1`030?ooo`0Pk0L08>`700L0oooo0P0Pk0L50?ooo`03023/1`3oool08>`700<08>`700<0
0000023/1`0Pk0L00P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`80oooo1P0Pk0L0103oool0
0000000000000002023/1`030:U[RP3XXH008>`700808>`700@0oooo023/1`3oool0oooo0P0Pk0L2
0?ooo`03023/1`3oool0oooo0080oooo00H08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`80oooo
1@0Pk0L30?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`7023/1`000003023/1`80
oooo00<08>`70?ooo`0000000P3oool3023/1`030?ooo`0Pk0L08>`70080oooo100Pk0L00`3oool0
8>`70?ooo`020?ooo`03023/1`3oool08>`700808>`71`3oool3023/1`80oooo0`0000090?ooo`05
023/1`3oool0oooo0?ooo`0Pk0L0603oool00`000000oooo0?ooo`0P0?ooo`007`3oool00`000000
oooo0?ooo`0F0?ooo`03023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool0100Pk0L00`3oool0
8>`7023/1`070?ooo`808>`71@3oool00`0Pk0L0oooo023/1`06023/1`80oooo00H08>`70?ooo`0P
k0L08>`70?ooo`0Pk0L20?ooo`H08>`7103oool2023/1`030:U[RP3XXH008>`700808>`700@0oooo
023/1`3oool0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00H08>`70?ooo`0Pk0L0oooo
023/1`3oool3023/1`80oooo1@0Pk0L30?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool0
8>`7023/1`000003023/1`80oooo00<08>`70?ooo`0000000P3oool3023/1`030?ooo`0Pk0L08>`7
0080oooo100Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool08>`700808>`71`3oool3023/
1`d0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo01L0oooo00<000000?ooo`3oool0803oool001l0
oooo00<000000?ooo`3oool05P3oool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00@0
8>`700<0oooo023/1`0Pk0L01`3oool2023/1`D0oooo00<08>`70?ooo`0Pk0L00`0Pk0L00`000000
8>`7023/1`020?ooo`06023/1`3oool08>`7023/1`3oool08>`70P3oool6023/1`040?ooo`000000
0000000000808>`70P000003023/1`040000000Pk0L0oooo0?ooo`808>`70P3oool00`0Pk0L0oooo
0?ooo`020?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L20?ooo`D08>`70`3oool3023/
1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`03023/1`3oool00000
0080oooo0`0Pk0L00`3oool08>`7023/1`020?ooo`@08>`700D0oooo023/1`3oool0oooo023/1`02
0?ooo`<08>`71`3oool3023/1`d0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo01L0oooo00<00000
0?ooo`3oool0803oool001l0oooo00<000000?ooo`3oool05`3oool2023/1`D0oooo00<08>`70?oo
o`3oool0100Pk0L00`3oool08>`7023/1`070?ooo`808>`71@3oool00`0Pk0L0oooo023/1`03023/
1`030000000Pk0L08>`70080oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`D08>`71@00
0002023/1`8000000`0Pk0L0100000008>`7000000000002023/1`80oooo00<08>`70?ooo`3oool0
0P3oool01P0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`70P3oool5023/1`<0oooo0`0Pk0L00`3o
ool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700@08>`70P3oool00`0Pk0L0oooo000000020?oo
o`<08>`700<0oooo023/1`0Pk0L00P3oool4023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L00P3oool3
023/1`H0oooo100Pk0L=0?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`0G0?ooo`030000003oool0
oooo0200oooo000O0?ooo`030000003oool0oooo01L0oooo0P0Pk0L50?ooo`03023/1`3oool0oooo
00@08>`700<0oooo023/1`0Pk0L01`3oool2023/1`D0oooo00<08>`70?ooo`0Pk0L00`0Pk0L00`3o
ool08>`7023/1`020?ooo`06023/1`3oool08>`7023/1`3oool08>`70P3oool5023/1`D000000P0P
k0L2000000<08>`70`0000000`3JVi008>`7023/1`020?ooo`03023/1`3oool0oooo0080oooo00H0
8>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`80oooo1@0Pk0L30?ooo`<08>`700<0oooo023/1`0P
k0L00P0Pk0L00`0000008>`7023/1`04023/1`80oooo00<08>`70?ooo`0000000P3oool6023/1`80
oooo100Pk0L01@3oool08>`70?ooo`3oool08>`70080oooo0`0Pk0L60?ooo`@08>`73@3oool2023/
1`80oooo00<08>`70?ooo`3oool05`3oool00`000000oooo0?ooo`0P0?ooo`007`3oool00`000000
oooo0?ooo`0G0?ooo`808>`71@3oool00`0Pk0L0oooo0?ooo`04023/1`030?ooo`0Pk0L08>`700L0
oooo0P0Pk0L50?ooo`03023/1`3oool08>`700H08>`70P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo
023/1`80oooo1@0Pk0L00`000000Y;_Y0:Bkj@020:Bkj@808>`70P2T^nT3023/1`040:Bkj@000000
0000000000808>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`06023/1`3oool08>`70?ooo`0Pk0L0
oooo0`0Pk0L20?ooo`D08>`70`3oool3023/1`040?ooo`0Pk0L08>`7023/1`8000001P0Pk0L20?oo
o`03023/1`3oool000000080oooo1P0Pk0L20?ooo`@08>`700D0oooo023/1`3oool0oooo023/1`02
0?ooo`<08>`71P3oool4023/1`d0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo01L0oooo00<00000
0?ooo`3oool0803oool001l0oooo00<000000?ooo`3oool05`3oool2023/1`D0oooo00<08>`70?oo
o`3oool0100Pk0L00`3oool08>`7023/1`070?ooo`808>`71@3oool0100Pk0L0oooo023/1`3oool5
023/1`80oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`D08>`71@2T^nT2023/1`80Y;_Y
0`0Pk0L0102T^nT08>`70:Bkj@000002023/1`80oooo00<08>`70?ooo`3oool00P3oool01P0Pk0L0
oooo023/1`3oool08>`70?ooo`<08>`700<0oooo023/1`3oool0100Pk0L30?ooo`<08>`700<0oooo
023/1`0Pk0L00`000006023/1`80oooo00<08>`70?ooo`0000000P3oool6023/1`80oooo100Pk0L0
1@3oool08>`70?ooo`3oool08>`70080oooo0`0Pk0L60?ooo`@08>`73@3oool2023/1`80oooo00<0
8>`70?ooo`3oool05`3oool00`000000oooo0?ooo`0P0?ooo`007`3oool00`000000oooo0?ooo`0G
0?ooo`808>`71P3oool00`0Pk0L0oooo023/1`03023/1`040?ooo`0Pk0L0oooo023/1`H0oooo0P0P
k0L60?ooo`808>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`06023/1`3oool08>`7023/1`3oool0
8>`70P3oool5023/1`D0Y;_Y0P0Pk0L20:Bkj@<08>`700@0Y;_Y023/1`2T^nT0Y;_Y0P0Pk0L00`00
0000oooo023/1`040?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L00`3oool08>`70?oo
o`04023/1`<0oooo0`0Pk0L01P3oool08>`7023/1`0000008>`70;72i`H08>`70P3oool0100Pk0L0
oooo0000003oool7023/1`80oooo1@0Pk0L30?ooo`03023/1`3oool0oooo00<08>`71P3oool4023/
1`d0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo01L0oooo00<000000?ooo`3oool0803oool001l0
oooo00<000000?ooo`3oool05`3oool2023/1`H0oooo00<08>`70?ooo`0Pk0L00`0Pk0L0103oool0
8>`70?ooo`0Pk0L60?ooo`808>`71P3oool2023/1`030?ooo`0Pk0L08>`700<08>`70P3oool01P0P
k0L0oooo023/1`0Pk0L0oooo023/1`80oooo1@0Pk0L50:Bkj@808>`70P2T^nT3023/1`040:Bkj@0P
k0L0Y;_Y0:Bkj@808>`700<000000?ooo`0Pk0L0103oool01P0Pk0L0oooo023/1`3oool08>`70?oo
o`<08>`700<0oooo023/1`3oool0100Pk0L30?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L00`2a
`^L08>`7023/1`04023/1`80oooo00@08>`70?ooo`000000oooo1`0Pk0L20?ooo`03023/1`3oool0
8>`700808>`70`3oool00`0Pk0L0oooo023/1`03023/1`H0oooo100Pk0L=0?ooo`808>`70P3oool0
0`0Pk0L0oooo0?ooo`0G0?ooo`030000003oool0oooo0200oooo000O0?ooo`030000003oool0oooo
01L0oooo0P0Pk0L60?ooo`03023/1`3oool08>`700<08>`700@0oooo023/1`3oool08>`71P3oool2
023/1`H0oooo0P0Pk0L00`3oool08>`7023/1`03023/1`80oooo00H08>`70?ooo`0Pk0L08>`70?oo
o`0Pk0L20?ooo`D08>`71@2T^nT2023/1`80Y;_Y0`0Pk0L0102T^nT08>`70:Bkj@2T^nT2023/1`80
000000<08>`70?ooo`3oool00P3oool01P0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`700<0oooo
023/1`3oool0100Pk0L30?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L00`2a`^L08>`7023/1`04
023/1`80oooo00@08>`70?ooo`000000oooo1`0Pk0L20?ooo`03023/1`3oool08>`700808>`70`3o
ool00`0Pk0L0oooo023/1`03023/1`H0oooo100Pk0L=0?ooo`808>`70P3oool00`0Pk0L0oooo0?oo
o`0G0?ooo`030000003oool0oooo0200oooo000O0?ooo`030000003oool0oooo01L0oooo0P0Pk0L6
0?ooo`03023/1`3oool08>`700<08>`700@0oooo023/1`3oool08>`71P3oool2023/1`H0oooo0P0P
k0L00`3oool08>`7023/1`03023/1`80oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`H0
8>`7102T^nT2023/1`030000002T^nT08>`700808>`700@0Y;_Y023/1`2T^nT0Y;_Y0P0Pk0L00`00
0000oooo023/1`040?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L00`3oool08>`70?oo
o`04023/1`<0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`030000000Pk0L08>`700@08>`70P3o
ool0100Pk0L0oooo0000003oool7023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L30?ooo`03023/
1`3oool08>`700<08>`71P3oool2023/1`030?ooo`0Pk0L0oooo00`0oooo0P0Pk0L20?ooo`03023/
1`3oool0oooo01L0oooo00<000000?ooo`3oool0803oool001l0oooo00<000000?ooo`3oool05`3o
ool2023/1`H0oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`70?ooo`0Pk0L70?ooo`03023/
1`3oool0oooo00@0oooo0P0Pk0L00`3oool08>`7023/1`03023/1`80oooo00H08>`70?ooo`0Pk0L0
8>`70?ooo`0Pk0L20?ooo`H08>`7102T^nT2023/1`030000003XXH008>`700808>`700@0Y;_Y023/
1`2T^nT0Y;_Y0P0Pk0L00`000000oooo023/1`040?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo
0`0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`030?oo
o`0Pk0L08>`700@08>`70P3oool0100Pk0L0oooo0000003oool7023/1`80oooo1@0Pk0L30?ooo`03
023/1`3oool08>`700<08>`71P3oool2023/1`030?ooo`0Pk0L0oooo00`0oooo0P0Pk0L20?ooo`03
023/1`3oool0oooo01L0oooo00<000000?ooo`3oool0803oool001l0oooo00<000000?ooo`3oool0
5`3oool2023/1`H0oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`70?ooo`0Pk0L70?ooo`03
023/1`3oool0oooo00@0oooo0P0Pk0L00`3oool08>`7023/1`03023/1`80oooo00H08>`70?ooo`0P
k0L08>`70?ooo`0Pk0L20?ooo`H08>`7102T^nT2023/1`030000003XXH008>`700808>`700@0Y;_Y
023/1`2T^nT0Y;_Y0P0Pk0L00`000000oooo023/1`040?ooo`06023/1`3oool08>`70?ooo`0Pk0L0
oooo0`0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`03
0?ooo`0Pk0L08>`700@08>`70P3oool0100Pk0L0oooo0000003oool7023/1`80oooo1@0Pk0L30?oo
o`03023/1`3oool08>`700<08>`71P3oool2023/1`030?ooo`0Pk0L0oooo00`0oooo0P0Pk0L20?oo
o`03023/1`3oool0oooo01L0oooo00<000000?ooo`3oool0803oool001l0oooo00<000000?ooo`3o
ool05`3oool2023/1`H0oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`70?ooo`0Pk0L70?oo
o`03023/1`3oool0oooo00@0oooo0P0Pk0L00`3oool08>`7023/1`03023/1`80oooo00H08>`70?oo
o`0Pk0L08>`70?ooo`0Pk0L20?ooo`H08>`7102T^nT2023/1`030000003XXH008>`700808>`700@0
Y;_Y023/1`2T^nT0Y;_Y0P0Pk0L00`000000oooo023/1`040?ooo`06023/1`3oool08>`70?ooo`0P
k0L0oooo0`0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0`0Pk0L00`3oool08>`7023/1`02023/
1`030?ooo`0Pk0L08>`700@08>`70P3oool0100Pk0L0oooo0000003oool3023/1`040?ooo`0Pk0L0
8>`7023/1`80oooo1@0Pk0L30?ooo`03023/1`3oool08>`700<08>`71P3oool2023/1`030?ooo`0P
k0L0oooo00`0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo01L0oooo00<000000?ooo`3oool0803o
ool001l0oooo00<000000?ooo`3oool05`3oool2023/1`H0oooo00<08>`70?ooo`3oool00`0Pk0L0
103oool08>`70?ooo`0Pk0L70?ooo`03023/1`3oool0oooo00@0oooo0P0Pk0L00`3oool08>`7023/
1`03023/1`80oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`H08>`7102T^nT2023/1`03
0000003XXH008>`700808>`700@0Y;_Y023/1`2T^nT0Y;_Y0P0Pk0L20?ooo`03023/1`3oool0oooo
0080oooo00H08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`030?ooo`0Pk0L0oooo00@08>`70`3o
ool3023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`04023/1`3o
ool000000?ooo`<08>`700@0oooo023/1`0Pk0L08>`70P3oool5023/1`<0oooo00<08>`70?ooo`0P
k0L00`0Pk0L60?ooo`808>`700<0oooo023/1`3oool0303oool2023/1`80oooo00<08>`70?ooo`3o
ool05`3oool00`000000oooo0?ooo`0P0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`808>`7
1P3oool00`0Pk0L0oooo0?ooo`03023/1`040?ooo`0Pk0L0oooo023/1`L0oooo00<08>`70?ooo`3o
ool0103oool2023/1`030?ooo`0Pk0L08>`700<08>`70P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo
023/1`80oooo1P0Pk0L010000000Y;_Y0:Bkj@2T^nT2023/1`030000003XXH008>`700808>`700@0
Y;_Y023/1`2T^nT0Y;_Y0P0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00H08>`70?ooo`0Pk0L0
oooo023/1`3oool3023/1`030?ooo`0Pk0L08>`700@08>`70`3oool3023/1`030?ooo`0Pk0L08>`7
00808>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`04023/1`3oool000000?ooo`<08>`700@0oooo
023/1`0Pk0L08>`70P3oool5023/1`<0oooo00<08>`70?ooo`0Pk0L00`0Pk0L60?ooo`808>`700<0
oooo023/1`3oool02`3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo01L0oooo00<0
00000?ooo`3oool0803oool001l0oooo00<000000?ooo`3oool05`3oool2023/1`H0oooo00<08>`7
0?ooo`3oool00`0Pk0L0103oool08>`70?ooo`0Pk0L70?ooo`03023/1`3oool0oooo00@0oooo00<0
8>`70?ooo`0Pk0L01@0Pk0L20?ooo`06023/1`3oool08>`7023/1`3oool08>`70P3oool6023/1`04
0?ooo`0000000000000000808>`700<000000>RQP00Pk0L00P0Pk0L0100000008>`7000000000002
023/1`80oooo00<08>`70?ooo`3oool00P3oool01P0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`7
00<0oooo023/1`0Pk0L0100Pk0L30?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7
023/1`04023/1`80oooo00@08>`70?ooo`000000oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?oo
o`H08>`70P3oool00`0Pk0L0oooo023/1`03023/1`H0oooo0P0Pk0L00`3oool08>`70?ooo`0;0?oo
o`03023/1`3oool08>`70080oooo00<08>`70?ooo`3oool05`3oool00`000000oooo0?ooo`0P0?oo
o`007`3oool00`000000oooo0?ooo`0G0?ooo`808>`71P3oool00`0Pk0L0oooo0?ooo`03023/1`04
0?ooo`0Pk0L0oooo023/1`L0oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo023/1`05023/
1`80oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`H08>`7103oool2023/1`030000003X
XH008>`700808>`700@0oooo023/1`3oool0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo0080oooo
00H08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`030?ooo`0Pk0L08>`700@08>`70`3oool3023/
1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`04023/1`3oool00000
0?ooo`<08>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`80oooo00<08>`70?ooo`0Pk0L00`0P
k0L60?ooo`<08>`73@3oool2023/1`<0oooo00<08>`70?ooo`3oool05`3oool00`000000oooo0?oo
o`0P0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`808>`71P3oool00`0Pk0L0oooo0?ooo`03
023/1`040?ooo`0Pk0L0oooo023/1`L0oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo023/
1`05023/1`80oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`H08>`7103oool2023/1`80
00000`0Pk0L0103oool08>`70?ooo`3oool2023/1`80oooo00<08>`70?ooo`3oool00P3oool01P0P
k0L0oooo023/1`3oool08>`70?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`<08>`700<0
oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`04023/1`80oooo00@08>`70?ooo`000000oooo
0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`70P3oool00`0Pk0L0oooo023/1`03023/1`H0
oooo0`0Pk0L=0?ooo`808>`70`3oool00`0Pk0L0oooo0?ooo`0G0?ooo`030000003oool0oooo0200
oooo000O0?ooo`030000003oool0oooo01L0oooo0P0Pk0L60?ooo`03023/1`3oool0oooo00<08>`7
00@0oooo023/1`3oool08>`71`3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool08>`700D0
8>`70P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`80oooo1P0Pk0L40?ooo`808>`700<0ZF^:
0000000Pk0L00P0Pk0L0103oool08>`70?ooo`3oool2023/1`80oooo00<08>`70?ooo`3oool00P3o
ool01P0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`<0
8>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`04023/1`80oooo00@08>`70?ooo`00
0000oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`70P3oool00`0Pk0L0oooo023/1`03
023/1`H0oooo0`0Pk0L=0?ooo`808>`70`3oool00`0Pk0L0oooo0?ooo`0G0?ooo`030000003oool0
oooo0200oooo000O0?ooo`030000003oool0oooo01L0oooo0P0Pk0L60?ooo`03023/1`3oool0oooo
00<08>`700@0oooo023/1`3oool08>`71`3oool00`0Pk0L0oooo0?ooo`050?ooo`L08>`70P3oool0
1P0Pk0L0oooo023/1`0Pk0L0oooo023/1`80oooo1P0Pk0L40?ooo`808>`700<0ZF^:0000000Pk0L0
0P0Pk0L0103oool08>`70?ooo`3oool2023/1`80oooo00<08>`70?ooo`3oool00P3oool01P0Pk0L0
oooo023/1`3oool08>`70?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`<08>`700<0oooo
023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`04023/1`80oooo00@08>`70?ooo`000000oooo0`0P
k0L0103oool08>`70?ooo`0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0
oooo023/1`02023/1`L0oooo0`0Pk0L=0?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`0H0?ooo`03
0000003oool0oooo0200oooo000O0?ooo`030000003oool0oooo01L0oooo0P0Pk0L60?ooo`03023/
1`3oool0oooo00<08>`700@0oooo023/1`3oool08>`71`3oool00`0Pk0L0oooo0?ooo`050?ooo`P0
8>`700<0oooo023/1`3oool00P0Pk0L0103oool08>`70?ooo`3oool6023/1`@0oooo0P0Pk0L00`2Y
JhX00000023/1`02023/1`040?ooo`0Pk0L0oooo0?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`02
0?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo
0`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700@08>`70P3oool0100Pk0L0oooo
0000003oool3023/1`040?ooo`0Pk0L0oooo023/1`80oooo0P0Pk0L0103oool08>`7023/1`0Pk0L2
0?ooo`03023/1`3oool08>`700808>`71`3oool3023/1`d0oooo0P0Pk0L20?ooo`03023/1`3oool0
oooo01P0oooo00<000000?ooo`3oool0803oool001l0oooo00<000000?ooo`3oool05`3oool2023/
1`H0oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`70?ooo`0Pk0L70?ooo`03023/1`3oool0
oooo00D0oooo200Pk0L00`3oool08>`70?ooo`02023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`7103o
ool2023/1`030:U[RP0000008>`700808>`700@0oooo023/1`3oool0oooo0P0Pk0L20?ooo`03023/
1`3oool0oooo0080oooo00@08>`70?ooo`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`04023/1`<0
oooo0`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700@08>`70P3oool0100Pk0L0
oooo0000003oool3023/1`040?ooo`0Pk0L0oooo023/1`80oooo0P0Pk0L0103oool08>`7023/1`0P
k0L20?ooo`03023/1`3oool08>`700808>`71`3oool00`0Pk0L0oooo023/1`0=0?ooo`808>`70P3o
ool00`0Pk0L0oooo0?ooo`0H0?ooo`030000003oool0oooo0200oooo000O0?ooo`030000003oool0
oooo01L0oooo0P0Pk0L60?ooo`03023/1`3oool0oooo00<08>`700@0oooo023/1`3oool08>`71`3o
ool00`0Pk0L0oooo0?ooo`050?ooo`P08>`700<0oooo023/1`3oool00P0Pk0L0103oool08>`70?oo
o`3oool6023/1`@0oooo0P0Pk0L2000000<08>`700@0oooo023/1`3oool0oooo0P0Pk0L20?ooo`03
023/1`3oool0oooo0080oooo00@08>`70?ooo`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`04023/
1`<0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700@08>`70P3oool0100P
k0L0oooo0000003oool3023/1`040?ooo`0Pk0L0oooo023/1`80oooo0P0Pk0L0203oool08>`7023/
1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L70?ooo`03023/1`3oool08>`700d0oooo0P0Pk0L20?oo
o`03023/1`3oool0oooo01P0oooo00<000000?ooo`3oool0803oool001l0oooo00<000000?ooo`3o
ool05`3oool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00<08>`70P3oool2023/1`L0
oooo00<08>`70?ooo`3oool01@3oool8023/1`030?ooo`0Pk0L0oooo00808>`700@0oooo023/1`3o
ool0oooo1P0Pk0L30?ooo`030000000Pk0L08>`700<000000P0Pk0L0103oool08>`70?ooo`3oool2
023/1`80oooo0P0Pk0L30?ooo`04023/1`3oool08>`70?ooo`D08>`700<0oooo023/1`0Pk0L0100P
k0L30?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`04023/1`80oooo00@0
8>`70?ooo`000000oooo0`0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`700P0oooo023/1`0P
k0L0oooo023/1`3oool08>`70?ooo`<08>`71`3oool00`0Pk0L0oooo023/1`0=0?ooo`808>`70P3o
ool00`0Pk0L0oooo0?ooo`0H0?ooo`030000003oool0oooo0200oooo000O0?ooo`030000003oool0
oooo01L0oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`02023/1`030?ooo`0Pk0L0
oooo00808>`71`3oool00`0Pk0L0oooo0?ooo`050?ooo`D08>`700H0oooo023/1`0Pk0L0oooo023/
1`3oool2023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`70`3oool00`0000008>`7023/1`020;72i`<0
8>`700@0oooo023/1`3oool0oooo0P0Pk0L20?ooo`808>`70`3oool0100Pk0L0oooo023/1`3oool5
023/1`030?ooo`0Pk0L08>`700@08>`70`3oool3023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`0Pk0L0100Pk0L20?ooo`04023/1`3oool000000?ooo`<08>`700D0oooo023/1`3oool08>`7
0?ooo`03023/1`080?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`L0oooo00<08>`7
0?ooo`0Pk0L03@3oool2023/1`80oooo00<08>`70?ooo`3oool0603oool00`000000oooo0?ooo`0P
0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`03023/1`3oool08>`700D0oooo00<08>`70?oo
o`3oool00P0Pk0L00`3oool08>`70?ooo`02023/1`L0oooo00<08>`70?ooo`3oool01@3oool5023/
1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L0103oool08>`70?ooo`3oool6023/1`<0oooo
00<00000023/1`0Pk0L00P2a`^L3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`70P3oool2023/1`<0
oooo00@08>`70?ooo`0Pk0L0oooo0P0Pk0L0103oool08>`7023/1`3oool6023/1`<0oooo200Pk0L0
0`3oool08>`7023/1`04023/1`060?ooo`0Pk0L0oooo0?ooo`000000oooo0`0Pk0L01@3oool08>`7
0?ooo`0Pk0L0oooo00<08>`700P0oooo023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`71P3o
ool2023/1`030?ooo`0Pk0L0oooo00`0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo01P0oooo00<0
00000?ooo`3oool0803oool001l0oooo00<000000?ooo`3oool05`3oool00`0Pk0L0oooo023/1`05
0?ooo`03023/1`3oool0oooo00808>`700<0oooo023/1`3oool00P0Pk0L70?ooo`03023/1`3oool0
oooo00D0oooo1@0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`808>`700@0oooo023/1`3oool0
oooo1P0Pk0L30?ooo`030000000Pk0L08>`70080/L;W0`0Pk0L0103oool08>`70?ooo`3oool2023/
1`80oooo0P0Pk0L30?ooo`04023/1`3oool08>`70?ooo`808>`700@0oooo023/1`0Pk0L0oooo1P0P
k0L30?ooo`P08>`700<0oooo023/1`0Pk0L0100Pk0L01P3oool08>`70?ooo`3oool000000?ooo`<0
8>`700D0oooo023/1`3oool08>`70?ooo`03023/1`080?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/
1`3oool3023/1`H0oooo0P0Pk0L00`3oool08>`70?ooo`0<0?ooo`808>`70P3oool00`0Pk0L0oooo
0?ooo`0H0?ooo`030000003oool0oooo0200oooo000O0?ooo`030000003oool0oooo01L0oooo00<0
8>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`02023/1`030?ooo`0Pk0L0oooo00808>`71`3o
ool00`0Pk0L0oooo0?ooo`050?ooo`D08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool2023/1`04
0?ooo`0Pk0L0oooo0?ooo`H08>`70`3oool00`0000008>`7023/1`020;72i`<08>`700@0oooo023/
1`3oool0oooo0P0Pk0L20?ooo`808>`70`3oool0100Pk0L0oooo023/1`3oool2023/1`040?ooo`0P
k0L08>`70?ooo`H08>`70`3oool8023/1`030?ooo`0Pk0L08>`700@08>`700H0oooo023/1`3oool0
oooo0000003oool3023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L0203oool08>`7023/1`3o
ool08>`70?ooo`0Pk0L0oooo0`0Pk0L60?ooo`808>`700<0oooo023/1`3oool0303oool2023/1`80
oooo00<08>`70?ooo`3oool0603oool00`000000oooo0?ooo`0P0?ooo`007`3oool00`000000oooo
0?ooo`0G0?ooo`03023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool00P0Pk0L00`3oool08>`7
0?ooo`02023/1`L0oooo00<08>`70?ooo`3oool01@3oool3023/1`030?ooo`0Pk0L0oooo00808>`7
00<0oooo023/1`3oool00P0Pk0L0103oool08>`70?ooo`3oool6023/1`@0oooo0P0Pk0L2000000<0
8>`700@0oooo023/1`3oool0oooo0P0Pk0L20?ooo`808>`70`3oool0100Pk0L0oooo023/1`3oool2
023/1`040?ooo`0Pk0L08>`70?ooo`H08>`70`3oool8023/1`030?ooo`0Pk0L08>`700<08>`70P3o
ool01@0Pk0L0oooo0?ooo`000000oooo00<08>`700<0oooo023/1`0Pk0L00P3oool3023/1`080?oo
o`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`H0oooo0P0Pk0L00`3oool08>`70?ooo`0<
0?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`0H0?ooo`030000003oool0oooo0200oooo000O0?oo
o`030000003oool0oooo01L0oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`02023/
1`030?ooo`0Pk0L0oooo00808>`71`3oool00`0Pk0L0oooo0?ooo`050?ooo`D08>`700H0oooo023/
1`0Pk0L0oooo023/1`3oool2023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`7103oool2023/1`80oooo
0`0Pk0L0103oool08>`70?ooo`3oool2023/1`80oooo0P0Pk0L30?ooo`04023/1`3oool08>`70?oo
o`808>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L30?ooo`P08>`700<0oooo023/1`0Pk0L00`0Pk0L2
0?ooo`05023/1`3oool0oooo0000003oool00`0Pk0L00`3oool08>`7023/1`020?ooo`<08>`700P0
oooo023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`71P3oool2023/1`030?ooo`0Pk0L0oooo
00`0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo01P0oooo00<000000?ooo`3oool0803oool001l0
oooo00<000000?ooo`3oool05`3oool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo0080
8>`700<0oooo023/1`3oool00P0Pk0L70?ooo`03023/1`3oool0oooo00D0oooo1@0Pk0L01P3oool0
8>`7023/1`3oool08>`70?ooo`808>`700@0oooo023/1`3oool0oooo1P0Pk0L40?ooo`808>`70P3o
ool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`70P3oool2023/1`<0oooo00@08>`70?ooo`0Pk0L0
oooo0P0Pk0L0103oool08>`7023/1`3oool6023/1`<0oooo200Pk0L00`3oool08>`7023/1`03023/
1`80oooo00D08>`70?ooo`3oool000000?ooo`03023/1`030?ooo`0Pk0L08>`70080oooo0`0Pk0L0
0`3oool08>`7023/1`020?ooo`808>`700@0oooo023/1`0Pk0L08>`71P3oool2023/1`030?ooo`0P
k0L0oooo00`0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo01P0oooo00<000000?ooo`3oool0803o
ool001l0oooo00<000000?ooo`3oool05`3oool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0
oooo00808>`700<0oooo023/1`3oool00P0Pk0L70?ooo`03023/1`3oool0oooo00H0oooo100Pk0L0
103oool08>`7023/1`3oool4023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`7103oool2023/1`80oooo
0`0Pk0L0103oool08>`70?ooo`3oool2023/1`80oooo0P0Pk0L30?ooo`04023/1`3oool08>`70?oo
o`808>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L30?ooo`P08>`700<0oooo023/1`0Pk0L00`0Pk0L2
0?ooo`05023/1`3oool0oooo0000003oool00`0Pk0L00`3oool08>`7023/1`020?ooo`<08>`700<0
oooo023/1`0Pk0L00P3oool2023/1`040?ooo`0Pk0L08>`7023/1`H0oooo0P0Pk0L00`3oool08>`7
0?ooo`0<0?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`0H0?ooo`030000003oool0oooo0200oooo
000O0?ooo`030000003oool0oooo01L0oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?oo
o`02023/1`030?ooo`0Pk0L0oooo00808>`71`3oool00`0Pk0L0oooo0?ooo`060?ooo`@08>`700@0
oooo023/1`0Pk0L0oooo100Pk0L0103oool08>`70?ooo`3oool6023/1`@0oooo0P0Pk0L20?ooo`<0
8>`700@0oooo023/1`3oool0oooo0P0Pk0L20?ooo`808>`70`3oool3023/1`040?ooo`0Pk0L08>`7
0?ooo`808>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`P08>`700<0oooo023/1`0Pk0L00`0Pk0L2
0?ooo`05023/1`3oool0oooo0000003oool01P0Pk0L20?ooo`H08>`70P3oool2023/1`040?ooo`0P
k0L08>`7023/1`H0oooo0P0Pk0L00`3oool08>`70?ooo`0<0?ooo`808>`70P3oool00`0Pk0L0oooo
0?ooo`0H0?ooo`030000003oool0oooo0200oooo000O0?ooo`030000003oool0oooo01L0oooo00<0
8>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`02023/1`030?ooo`0Pk0L0oooo00808>`71`3o
ool00`0Pk0L0oooo0?ooo`060?ooo`@08>`700@0oooo023/1`0Pk0L0oooo100Pk0L0103oool08>`7
0?ooo`3oool6023/1`@0oooo0P0Pk0L20?ooo`<08>`700@0oooo023/1`3oool0oooo0P0Pk0L20?oo
o`808>`70`3oool3023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L0100Pk0L3
0?ooo`P08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`05023/1`3oool0oooo0000003oool01P0P
k0L20?ooo`H08>`70P3oool2023/1`040?ooo`0Pk0L08>`7023/1`H0oooo0P0Pk0L00`3oool08>`7
0?ooo`0<0?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`0H0?ooo`030000003oool0oooo0200oooo
000O0?ooo`030000003oool0oooo01L0oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?oo
o`02023/1`030?ooo`0Pk0L0oooo00808>`71`3oool00`0Pk0L0oooo0?ooo`060?ooo`@08>`700@0
oooo023/1`0Pk0L0oooo100Pk0L0103oool08>`70?ooo`3oool6023/1`@0oooo0P0Pk0L20?ooo`<0
8>`700@0oooo023/1`3oool0oooo0P0Pk0L20?ooo`808>`70`3oool3023/1`040?ooo`0Pk0L08>`7
0?ooo`808>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`P08>`700<0oooo023/1`0Pk0L00`0Pk0L2
0?ooo`05023/1`3oool0oooo0000003oool01P0Pk0L20?ooo`H08>`70P3oool2023/1`040?ooo`0P
k0L08>`7023/1`H0oooo0P0Pk0L00`3oool08>`70?ooo`0<0?ooo`808>`70P3oool00`0Pk0L0oooo
0?ooo`0H0?ooo`030000003oool0oooo0200oooo000O0?ooo`030000003oool0oooo01L0oooo00<0
8>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`02023/1`030?ooo`0Pk0L0oooo00808>`71`3o
ool00`0Pk0L0oooo0?ooo`060?ooo`@08>`700@0oooo023/1`0Pk0L0oooo100Pk0L0103oool08>`7
0?ooo`3oool6023/1`@0oooo0P0Pk0L20?ooo`<08>`700@0oooo023/1`3oool0oooo0P0Pk0L20?oo
o`808>`70`3oool3023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L0100Pk0L3
0?ooo`P08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`05023/1`3oool0oooo0000003oool01P0P
k0L20?ooo`H08>`70P3oool6023/1`H0oooo0P0Pk0L00`3oool08>`70?ooo`0;0?ooo`03023/1`3o
ool08>`70080oooo00<08>`70?ooo`3oool0603oool00`000000oooo0?ooo`0P0?ooo`007`3oool0
0`000000oooo0?ooo`0G0?ooo`03023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool00P0Pk0L0
0`3oool08>`70?ooo`02023/1`L0oooo00<08>`70?ooo`3oool01P3oool4023/1`040?ooo`0Pk0L0
8>`70?ooo`@08>`700@0oooo023/1`3oool0oooo1P0Pk0L40?ooo`808>`70P3oool3023/1`040?oo
o`0Pk0L0oooo0?ooo`808>`70P3oool2023/1`<0oooo0`0Pk0L0103oool08>`7023/1`3oool2023/
1`030?ooo`0Pk0L08>`700@08>`70`3oool8023/1`030?ooo`0Pk0L08>`700<08>`70P3oool01@0P
k0L0oooo0?ooo`000000oooo00H08>`70P3oool5023/1`<0oooo1P0Pk0L60?ooo`808>`700<0oooo
023/1`3oool02`3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo01P0oooo00<00000
0?ooo`3oool0803oool001l0oooo00<000000?ooo`3oool05`3oool00`0Pk0L0oooo023/1`050?oo
o`03023/1`3oool0oooo00808>`700<0oooo023/1`3oool00P0Pk0L70?ooo`03023/1`3oool0oooo
00H0oooo100Pk0L0103oool08>`7023/1`3oool4023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`7103o
ool2023/1`80oooo0`0Pk0L0103oool08>`70?ooo`3oool2023/1`80oooo0P0Pk0L30?ooo`<08>`7
00@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`04023/1`<0oooo200Pk0L00`3oool0
8>`7023/1`03023/1`80oooo00H08>`70?ooo`3oool00000023/1`3oool5023/1`80oooo1@0Pk0L4
0?ooo`D08>`71P3oool2023/1`030?ooo`0Pk0L0oooo00/0oooo00<08>`70?ooo`0Pk0L00P3oool0
0`0Pk0L0oooo0?ooo`0H0?ooo`030000003oool0oooo0200oooo000O0?ooo`030000003oool0oooo
01L0oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`02023/1`030?ooo`0Pk0L0oooo
00808>`71`3oool00`0Pk0L0oooo0?ooo`060?ooo`@08>`700@0oooo023/1`0Pk0L0oooo100Pk0L0
103oool08>`70?ooo`3oool6023/1`@0oooo0P0Pk0L20?ooo`<08>`700@0oooo023/1`3oool0oooo
0P0Pk0L20?ooo`808>`70`3oool3023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0P
k0L0100Pk0L30?ooo`P08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`06023/1`3oool0oooo0000
000Pk0L0oooo1@0Pk0L20?ooo`03023/1`3oool08>`700808>`7103oool5023/1`H0oooo0P0Pk0L0
0`3oool08>`70?ooo`0;0?ooo`05023/1`3oool08>`70?ooo`0Pk0L06`3oool00`000000oooo0?oo
o`0P0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`03023/1`3oool08>`700D0oooo00<08>`7
0?ooo`3oool00P0Pk0L00`3oool08>`70?ooo`02023/1`L0oooo00<08>`70?ooo`3oool01P3oool4
023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700@0oooo023/1`3oool0oooo1P0Pk0L40?ooo`808>`7
0P3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`70P3oool2023/1`<0oooo0`0Pk0L0103oool0
8>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700@08>`70`3oool8023/1`030?ooo`0Pk0L08>`7
00<08>`70P3oool01P0Pk0L0oooo0?ooo`0000008>`70?ooo`D08>`70P3oool00`0Pk0L0oooo023/
1`02023/1`@0oooo1@0Pk0L60?ooo`808>`700<0oooo023/1`3oool02`3oool01@0Pk0L0oooo023/
1`3oool08>`701/0oooo00<000000?ooo`3oool0803oool001l0oooo00<000000?ooo`3oool05`3o
ool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00808>`700<0oooo023/1`3oool00P0P
k0L70?ooo`03023/1`3oool0oooo00H0oooo100Pk0L0103oool08>`7023/1`3oool4023/1`040?oo
o`0Pk0L0oooo0?ooo`H08>`7103oool2023/1`80oooo0`0Pk0L0103oool08>`70?ooo`3oool2023/
1`80oooo0P0Pk0L30?ooo`<08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`04
023/1`<0oooo200Pk0L00`3oool08>`7023/1`03023/1`80oooo00H08>`70?ooo`3oool00000023/
1`3oool5023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L30?ooo`H08>`71P3oool3023/1`d0oooo
00D08>`70?ooo`0Pk0L0oooo023/1`0K0?ooo`030000003oool0oooo0200oooo000O0?ooo`030000
003oool0oooo01L0oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`02023/1`060?oo
o`0Pk0L0oooo023/1`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`060?ooo`@08>`700@0oooo023/
1`0Pk0L0oooo100Pk0L0103oool08>`70?ooo`3oool6023/1`@0oooo0P0Pk0L20?ooo`<08>`700@0
oooo023/1`3oool0oooo0P0Pk0L20?ooo`808>`70`3oool3023/1`040?ooo`0Pk0L08>`70?ooo`80
8>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`P08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`06
023/1`3oool0oooo0000000Pk0L0oooo1@0Pk0L20?ooo`03023/1`3oool08>`700808>`70`3oool6
023/1`H0oooo0`0Pk0L=0?ooo`05023/1`3oool08>`70?ooo`0Pk0L06`3oool00`000000oooo0?oo
o`0P0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`03023/1`3oool08>`700D0oooo00<08>`7
0?ooo`3oool00P0Pk0L01P3oool08>`70?ooo`0Pk0L0oooo023/1`H0oooo00<08>`70?ooo`3oool0
1P3oool4023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700@0oooo023/1`3oool0oooo1P0Pk0L40?oo
o`808>`70P3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`70P3oool2023/1`<0oooo1P0Pk0L0
103oool08>`7023/1`3oool6023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/
1`03023/1`80oooo00H08>`70?ooo`3oool00000023/1`3oool5023/1`80oooo00<08>`70?ooo`0P
k0L00P0Pk0L30?ooo`H08>`71P3oool3023/1`d0oooo00D08>`70?ooo`0Pk0L0oooo023/1`0K0?oo
o`030000003oool0oooo0200oooo000O0?ooo`030000003oool0oooo01P0oooo0P0Pk0L50?ooo`03
023/1`3oool0oooo00808>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L60?ooo`03023/1`3oool0
oooo00H0oooo100Pk0L0103oool08>`7023/1`3oool4023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`7
103oool2023/1`80oooo0`0Pk0L0103oool08>`70?ooo`3oool2023/1`80oooo0P0Pk0L30?ooo`H0
8>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/
1`0Pk0L00`0Pk0L20?ooo`06023/1`3oool0oooo0000000Pk0L0oooo1@0Pk0L20?ooo`03023/1`3o
ool08>`700808>`70`3oool6023/1`H0oooo0`0Pk0L=0?ooo`808>`70P3oool00`0Pk0L0oooo0?oo
o`0I0?ooo`030000003oool0oooo0200oooo000O0?ooo`030000003oool0oooo01P0oooo0P0Pk0L5
0?ooo`03023/1`3oool0oooo00808>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L60?ooo`03023/
1`3oool0oooo00H0oooo100Pk0L0103oool08>`7023/1`3oool4023/1`040?ooo`0Pk0L0oooo0?oo
o`H08>`7103oool2023/1`80oooo0`0Pk0L0103oool08>`70?ooo`3oool2023/1`80oooo0P0Pk0L3
0?ooo`H08>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0
oooo023/1`0Pk0L00`0Pk0L20?ooo`06023/1`3oool0oooo0000000Pk0L0oooo1@0Pk0L20?ooo`03
023/1`3oool08>`700808>`70`3oool6023/1`H0oooo0`0Pk0L=0?ooo`808>`70P3oool00`0Pk0L0
oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo000O0?ooo`030000003oool0oooo01P0oooo
0P0Pk0L50?ooo`03023/1`3oool0oooo00808>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L60?oo
o`03023/1`3oool0oooo00H0oooo100Pk0L0103oool08>`7023/1`3oool4023/1`040?ooo`0Pk0L0
oooo0?ooo`H08>`7103oool2023/1`80oooo0`0Pk0L0103oool08>`70?ooo`3oool2023/1`80oooo
0P0Pk0L30?ooo`H08>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L20?ooo`03023/1`3oool08>`700@0
8>`700<0oooo023/1`3oool01@0Pk0L20?ooo`06023/1`3oool0oooo0000000Pk0L0oooo1@0Pk0L2
0?ooo`03023/1`3oool08>`700808>`70`3oool00`0Pk0L0oooo023/1`03023/1`H0oooo00<08>`7
0?ooo`0Pk0L03@3oool2023/1`80oooo00<08>`70?ooo`3oool06@3oool00`000000oooo0?ooo`0P
0?ooo`007P3oool00`000000oooo0?ooo`0I0?ooo`808>`71@3oool00`0Pk0L0oooo0?ooo`02023/
1`060?ooo`0Pk0L0oooo023/1`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`060?ooo`@08>`700@0
oooo023/1`0Pk0L0oooo100Pk0L0103oool08>`70?ooo`3oool6023/1`@0oooo0P0Pk0L20?ooo`<0
8>`700@0oooo023/1`3oool0oooo0P0Pk0L20?ooo`808>`70`3oool6023/1`040?ooo`0Pk0L08>`7
0?ooo`H08>`70P3oool2023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool01@0Pk0L2
0?ooo`06023/1`3oool0oooo0000000Pk0L0oooo1@0Pk0L20?ooo`03023/1`3oool08>`700808>`7
0`3oool00`0Pk0L0oooo023/1`03023/1`D0oooo0P0Pk0L00`3oool08>`70?ooo`0<0?ooo`808>`7
0P3oool00`0Pk0L0oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo000N0?ooo`030000003o
ool0oooo01T0oooo0P0Pk0L50?ooo`03023/1`3oool0oooo00808>`700H0oooo023/1`3oool08>`7
0?ooo`0Pk0L60?ooo`03023/1`3oool0oooo00H0oooo100Pk0L0103oool08>`7023/1`3oool4023/
1`040?ooo`0Pk0L0oooo0?ooo`H08>`7103oool2023/1`80oooo0`0Pk0L0103oool08>`70?ooo`3o
ool2023/1`80oooo0P0Pk0L30?ooo`H08>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L20?ooo`808>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`05023/1`80oooo00H08>`70?ooo`3oool0
0000023/1`3oool5023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L30?ooo`03023/1`3oool08>`7
00<08>`71@3oool2023/1`030?ooo`0Pk0L0oooo00`0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo
01T0oooo00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3oool06@3oool2023/1`D0
oooo00<08>`70?ooo`3oool00P0Pk0L01P3oool08>`70?ooo`0Pk0L0oooo023/1`H0oooo00<08>`7
0?ooo`3oool01P3oool4023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700@0oooo023/1`3oool0oooo
1P0Pk0L40?ooo`808>`70P3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`70P3oool2023/1`<0
oooo1P0Pk0L0103oool08>`7023/1`3oool6023/1`80oooo0P0Pk0L00`3oool08>`7023/1`02023/
1`030?ooo`0Pk0L0oooo00D08>`70P3oool01P0Pk0L0oooo0?ooo`0000008>`70?ooo`D08>`70P3o
ool5023/1`<0oooo00<08>`70?ooo`0Pk0L00`0Pk0L50?ooo`808>`700<0oooo023/1`3oool0303o
ool2023/1`80oooo00<08>`70?ooo`3oool06@3oool00`000000oooo0?ooo`0P0?ooo`007P3oool0
0`000000oooo0?ooo`0I0?ooo`<08>`7103oool00`0Pk0L0oooo0?ooo`04023/1`040?ooo`0Pk0L0
oooo023/1`H0oooo00<08>`70?ooo`3oool01P3oool4023/1`040?ooo`0Pk0L08>`70?ooo`@08>`7
00@0oooo023/1`3oool0oooo1P0Pk0L40?ooo`808>`70P3oool3023/1`040?ooo`0Pk0L0oooo0?oo
o`808>`70P3oool2023/1`<0oooo1P0Pk0L0103oool08>`7023/1`3oool6023/1`80oooo0P0Pk0L0
0`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool01P0Pk0L0oooo0?ooo`00
00008>`70?ooo`D08>`70P3oool5023/1`<0oooo00<08>`70?ooo`0Pk0L00`0Pk0L50?ooo`808>`7
00<0oooo023/1`3oool0303oool2023/1`80oooo00<08>`70?ooo`3oool06@3oool00`000000oooo
0?ooo`0P0?ooo`007P3oool00`000000oooo0?ooo`0I0?ooo`<08>`7103oool00`0Pk0L0oooo0?oo
o`04023/1`040?ooo`0Pk0L0oooo023/1`H0oooo00<08>`70?ooo`3oool01P3oool4023/1`040?oo
o`0Pk0L08>`70?ooo`@08>`700@0oooo023/1`3oool0oooo1P0Pk0L40?ooo`808>`70P3oool3023/
1`040?ooo`0Pk0L0oooo0?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool6023/1`040?ooo`0P
k0L08>`70?ooo`H08>`70P3oool2023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool0
1@0Pk0L20?ooo`06023/1`3oool0oooo0000000Pk0L0oooo1@0Pk0L20?ooo`D08>`70`3oool00`0P
k0L0oooo023/1`03023/1`D0oooo0P0Pk0L00`3oool08>`70?ooo`0<0?ooo`808>`70P3oool00`0P
k0L0oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo000N0?ooo`030000003oool0oooo01T0
oooo0`0Pk0L40?ooo`03023/1`3oool0oooo00@08>`700@0oooo023/1`3oool08>`71P3oool00`0P
k0L0oooo0?ooo`060?ooo`@08>`700@0oooo023/1`0Pk0L0oooo100Pk0L0103oool08>`70?ooo`3o
ool6023/1`@0oooo0P0Pk0L20?ooo`<08>`700@0oooo023/1`3oool0oooo0P0Pk0L0103oool08>`7
023/1`0Pk0L30?ooo`H08>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L20?ooo`808>`700<0oooo023/
1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`05023/1`80oooo00H08>`70?ooo`3oool00000023/1`3o
ool5023/1`80oooo1@0Pk0L30?ooo`03023/1`3oool08>`700<08>`71@3oool2023/1`030?ooo`0P
k0L0oooo00`0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo01T0oooo00<000000?ooo`3oool0803o
ool001h0oooo00<000000?ooo`3oool06@3oool3023/1`@0oooo00@08>`70?ooo`3oool0oooo0`0P
k0L0103oool08>`70?ooo`0Pk0L60?ooo`03023/1`3oool0oooo00H0oooo1`0Pk0L00`3oool08>`7
023/1`02023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`7103oool2023/1`80oooo0`0Pk0L0103oool0
8>`70?ooo`3oool2023/1`040?ooo`0Pk0L08>`7023/1`<0oooo0`0Pk0L0103oool08>`7023/1`3o
ool2023/1`030?ooo`0Pk0L08>`700@08>`70P3oool2023/1`030?ooo`0Pk0L08>`700808>`700<0
oooo023/1`0Pk0L01@0Pk0L20?ooo`06023/1`3oool0oooo0000000Pk0L0oooo1@0Pk0L20?ooo`D0
8>`70`3oool00`0Pk0L0oooo023/1`03023/1`D0oooo0P0Pk0L00`3oool08>`70?ooo`0<0?ooo`80
8>`70P3oool00`0Pk0L0oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo000N0?ooo`030000
003oool0oooo01T0oooo0`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`<08>`700@0oooo023/1`3o
ool08>`71P3oool00`0Pk0L0oooo0?ooo`060?ooo`L08>`700<0oooo023/1`0Pk0L00P0Pk0L0103o
ool08>`70?ooo`3oool6023/1`@0oooo0P0Pk0L20?ooo`<08>`700@0oooo023/1`3oool0oooo0P0P
k0L0103oool08>`7023/1`0Pk0L30?ooo`<08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool0
8>`7023/1`04023/1`80oooo0P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700D0
8>`70P3oool01P0Pk0L0oooo0?ooo`0000008>`70?ooo`<08>`700@0oooo023/1`3oool0oooo1@0P
k0L30?ooo`03023/1`3oool08>`700<08>`71@3oool2023/1`030?ooo`0Pk0L0oooo00`0oooo0P0P
k0L20?ooo`03023/1`3oool0oooo01T0oooo00<000000?ooo`3oool0803oool001h0oooo00<00000
0?ooo`3oool06@3oool3023/1`@0oooo00@08>`70?ooo`3oool0oooo0`0Pk0L0103oool08>`70?oo
o`0Pk0L60?ooo`03023/1`3oool0oooo00H0oooo1`0Pk0L00`3oool08>`7023/1`02023/1`040?oo
o`0Pk0L0oooo0?ooo`H08>`7103oool2023/1`80oooo0`0Pk0L0103oool08>`70?ooo`3oool2023/
1`040?ooo`0Pk0L08>`7023/1`<0oooo0`0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0P
k0L08>`700@08>`70P3oool2023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01@0P
k0L20?ooo`06023/1`3oool0oooo0000000Pk0L0oooo0`0Pk0L0103oool08>`70?ooo`3oool5023/
1`<0oooo00<08>`70?ooo`0Pk0L00`0Pk0L50?ooo`808>`700<0oooo023/1`3oool0303oool2023/
1`80oooo00<08>`70?ooo`3oool06@3oool00`000000oooo0?ooo`0P0?ooo`007P3oool00`000000
oooo0?ooo`0I0?ooo`<08>`7103oool0100Pk0L0oooo0?ooo`3oool3023/1`040?ooo`0Pk0L0oooo
023/1`H0oooo00<08>`70?ooo`3oool01P3oool7023/1`030?ooo`0Pk0L08>`700808>`700@0oooo
023/1`3oool0oooo1P0Pk0L40?ooo`808>`70P3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`7
00@0oooo023/1`0Pk0L08>`70`3oool3023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/
1`0Pk0L0100Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`05023/
1`80oooo00H08>`70?ooo`3oool00000023/1`3oool3023/1`030?ooo`0Pk0L0oooo00H08>`70`3o
ool00`0Pk0L0oooo023/1`03023/1`D0oooo0P0Pk0L00`3oool08>`70?ooo`0<0?ooo`808>`70P3o
ool00`0Pk0L0oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo000N0?ooo`030000003oool0
oooo01T0oooo0`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo023/1`0Pk0L0oooo
023/1`060?ooo`03023/1`3oool0oooo00H0oooo1`0Pk0L00`3oool08>`7023/1`02023/1`040?oo
o`0Pk0L0oooo0?ooo`H08>`7103oool0100Pk0L0oooo023/1`3oool3023/1`040?ooo`0Pk0L0oooo
0?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool3023/1`040?ooo`0Pk0L08>`70?ooo`808>`7
00<0oooo023/1`0Pk0L0100Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7
023/1`05023/1`80oooo00H08>`70?ooo`3oool00000023/1`3oool3023/1`030?ooo`0Pk0L0oooo
00H08>`70`3oool00`0Pk0L0oooo023/1`02023/1`H0oooo0P0Pk0L00`3oool08>`70?ooo`0<0?oo
o`808>`70P3oool00`0Pk0L0oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo000N0?ooo`03
0000003oool0oooo01T0oooo0`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo023/
1`0Pk0L0oooo023/1`060?ooo`03023/1`3oool0oooo00H0oooo1`0Pk0L00`3oool08>`7023/1`02
023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`7103oool0100Pk0L0oooo023/1`3oool3023/1`040?oo
o`0Pk0L0oooo0?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool3023/1`040?ooo`0Pk0L08>`7
0?ooo`808>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L0
0`3oool08>`7023/1`05023/1`80oooo00H08>`70?ooo`3oool00000023/1`3oool3023/1`030?oo
o`0Pk0L0oooo00H08>`70`3oool00`0Pk0L0oooo023/1`02023/1`H0oooo0P0Pk0L00`3oool08>`7
0?ooo`0;0?ooo`05023/1`3oool08>`70?ooo`0Pk0L0703oool00`000000oooo0?ooo`0P0?ooo`00
7P3oool00`000000oooo0?ooo`0I0?ooo`<08>`71@3oool00`0Pk0L0oooo0?ooo`02023/1`050?oo
o`0Pk0L08>`70?ooo`0Pk0L01P3oool00`0Pk0L0oooo0?ooo`060?ooo`L08>`700<0oooo023/1`0P
k0L00P0Pk0L0103oool08>`70?ooo`3oool6023/1`@0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L0
103oool08>`70?ooo`3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo00D08>`70?ooo`0Pk0L0
8>`70?ooo`02023/1`040?ooo`0Pk0L08>`70?ooo`H08>`70P3oool2023/1`030?ooo`0Pk0L08>`7
00808>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`06023/1`3oool0oooo0?ooo`000000oooo0`0P
k0L00`3oool08>`70?ooo`06023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L50?ooo`<08>`700<0
oooo023/1`3oool02`3oool01@0Pk0L0oooo023/1`3oool08>`701`0oooo00<000000?ooo`3oool0
803oool001h0oooo00<000000?ooo`3oool06@3oool3023/1`D0oooo00<08>`70?ooo`3oool00P0P
k0L01@3oool08>`7023/1`3oool08>`700H0oooo00<08>`70?ooo`3oool01P3oool7023/1`030?oo
o`0Pk0L08>`700808>`700@0oooo023/1`3oool0oooo1P0Pk0L40?ooo`04023/1`3oool08>`70?oo
o`<08>`700@0oooo023/1`3oool0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`05023/1`3o
ool08>`7023/1`3oool00P0Pk0L0103oool08>`7023/1`3oool6023/1`80oooo0P0Pk0L00`3oool0
8>`7023/1`02023/1`030?ooo`0Pk0L08>`700D08>`70P3oool01P0Pk0L0oooo0?ooo`3oool00000
0?ooo`<08>`700<0oooo023/1`3oool01P0Pk0L30?ooo`03023/1`3oool08>`700808>`71@3oool3
023/1`030?ooo`0Pk0L0oooo00/0oooo00D08>`70?ooo`0Pk0L0oooo023/1`0L0?ooo`030000003o
ool0oooo0200oooo000N0?ooo`030000003oool0oooo01T0oooo0`0Pk0L50?ooo`03023/1`3oool0
oooo00808>`700D0oooo023/1`0Pk0L0oooo023/1`060?ooo`03023/1`3oool0oooo00H0oooo1`0P
k0L00`3oool08>`7023/1`02023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`7103oool0100Pk0L0oooo
023/1`3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool0
1@0Pk0L0oooo023/1`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L20?ooo`808>`7
00<0oooo023/1`0Pk0L02P0Pk0L20?ooo`06023/1`3oool0oooo0?ooo`000000oooo100Pk0L20?oo
o`H08>`70`3oool00`0Pk0L0oooo023/1`02023/1`D0oooo0`0Pk0L00`3oool08>`70?ooo`0;0?oo
o`05023/1`3oool08>`70?ooo`0Pk0L0703oool00`000000oooo0?ooo`0P0?ooo`007P3oool00`00
0000oooo0?ooo`0I0?ooo`<08>`71@3oool00`0Pk0L0oooo0?ooo`02023/1`050?ooo`0Pk0L08>`7
0?ooo`0Pk0L01P3oool00`0Pk0L0oooo0?ooo`060?ooo`L08>`700<0oooo023/1`0Pk0L00P0Pk0L0
103oool08>`70?ooo`3oool6023/1`@0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool08>`7
0?ooo`3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02
023/1`040?ooo`0Pk0L08>`70?ooo`H08>`70P3oool2023/1`030?ooo`0Pk0L08>`700X08>`70P3o
ool01P0Pk0L0oooo0?ooo`3oool000000?ooo`@08>`70P3oool6023/1`<0oooo00<08>`70?ooo`0P
k0L00P0Pk0L50?ooo`<08>`700<0oooo023/1`3oool02`3oool01@0Pk0L0oooo023/1`3oool08>`7
01`0oooo00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3oool06@3oool3023/1`D0
oooo00<08>`70?ooo`3oool00P0Pk0L01@3oool08>`7023/1`3oool08>`700H0oooo00<08>`70?oo
o`3oool01P3oool7023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`3oool0oooo1P0Pk0L4
0?ooo`04023/1`3oool08>`70?ooo`<08>`700@0oooo023/1`3oool0oooo0P0Pk0L0103oool08>`7
023/1`0Pk0L20?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L0103oool08>`7023/1`3oool6
023/1`80oooo0P0Pk0L00`3oool08>`7023/1`0:023/1`80oooo00H08>`70?ooo`3oool0oooo0000
003oool4023/1`80oooo1P0Pk0L30?ooo`03023/1`3oool08>`700808>`71@3oool3023/1`030?oo
o`0Pk0L0oooo00/0oooo00D08>`70?ooo`0Pk0L0oooo023/1`0L0?ooo`030000003oool0oooo0200
oooo000N0?ooo`030000003oool0oooo01T0oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo
0?ooo`02023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01P3oool00`0Pk0L0oooo0?ooo`060?ooo`L0
8>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`70?ooo`3oool6023/1`@0oooo00@08>`70?oo
o`0Pk0L0oooo0`0Pk0L0103oool08>`70?ooo`3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo
00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`040?ooo`0Pk0L08>`70?ooo`H08>`70P3oool2023/
1`030?ooo`0Pk0L08>`700X08>`70P3oool01@0Pk0L0oooo0?ooo`3oool0000000D08>`70P3oool6
023/1`<0oooo1@0Pk0L50?ooo`<08>`700<0oooo023/1`3oool02`3oool01@0Pk0L0oooo023/1`3o
ool08>`701`0oooo00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3oool06@3oool0
0`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00808>`700D0oooo023/1`0Pk0L0oooo023/
1`060?ooo`03023/1`3oool0oooo00H0oooo1P0Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0P
k0L0oooo0?ooo`H08>`7103oool0100Pk0L0oooo023/1`3oool3023/1`040?ooo`0Pk0L0oooo0?oo
o`808>`700@0oooo023/1`0Pk0L08>`70P3oool01@0Pk0L0oooo023/1`0Pk0L0oooo00808>`700@0
oooo023/1`0Pk0L0oooo1P0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L02P0Pk0L20?ooo`05023/
1`3oool0oooo0?ooo`0000001@0Pk0L20?ooo`H08>`70`3oool5023/1`D0oooo0`0Pk0L00`3oool0
8>`70?ooo`0;0?ooo`05023/1`3oool08>`70?ooo`0Pk0L0703oool00`000000oooo0?ooo`0P0?oo
o`007P3oool00`000000oooo0?ooo`0I0?ooo`03023/1`3oool08>`700D0oooo00<08>`70?ooo`3o
ool00P0Pk0L01@3oool08>`7023/1`3oool08>`700H0oooo0P0Pk0L70?ooo`H08>`700<0oooo023/
1`0Pk0L00`0Pk0L0103oool08>`70?ooo`3oool6023/1`@0oooo00@08>`70?ooo`0Pk0L0oooo0`0P
k0L0103oool08>`70?ooo`3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo00D08>`70?ooo`0P
k0L08>`70?ooo`02023/1`040?ooo`0Pk0L08>`70?ooo`H08>`70P3oool2023/1`030?ooo`0Pk0L0
8>`700X08>`70P3oool01@0Pk0L0oooo0?ooo`3oool0000000D08>`70P3oool6023/1`<0oooo1@0P
k0L50?ooo`@08>`73@3oool01@0Pk0L0oooo023/1`3oool08>`701`0oooo00<000000?ooo`3oool0
803oool001h0oooo00<000000?ooo`3oool06@3oool00`0Pk0L0oooo023/1`050?ooo`03023/1`3o
ool0oooo00808>`700D0oooo023/1`0Pk0L0oooo023/1`060?ooo`808>`71`3oool6023/1`030?oo
o`0Pk0L08>`700<08>`700@0oooo023/1`3oool0oooo1P0Pk0L40?ooo`04023/1`3oool08>`70?oo
o`<08>`700@0oooo023/1`3oool0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`05023/1`3o
ool08>`7023/1`3oool00P0Pk0L0103oool08>`7023/1`3oool6023/1`80oooo0P0Pk0L00`3oool0
8>`7023/1`0:023/1`80oooo00D08>`70?ooo`3oool0oooo00000005023/1`80oooo1@0Pk0L40?oo
o`D08>`71@3oool4023/1`d0oooo00D08>`70?ooo`0Pk0L0oooo023/1`0L0?ooo`030000003oool0
oooo0200oooo000N0?ooo`030000003oool0oooo01T0oooo00<08>`70?ooo`0Pk0L01@3oool00`0P
k0L0oooo0?ooo`02023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01P3oool2023/1`L0oooo1P0Pk0L0
0`3oool08>`7023/1`03023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`7103oool0100Pk0L0oooo023/
1`3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool01@0P
k0L0oooo023/1`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L20?ooo`808>`700<0
oooo023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`030?ooo`030000000Pk0L08>`700<08>`70P3o
ool5023/1`@0oooo1P0Pk0L40?ooo`@08>`73@3oool01@0Pk0L0oooo023/1`3oool08>`701`0oooo
00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3oool06@3oool00`0Pk0L0oooo023/
1`050?ooo`03023/1`3oool0oooo00808>`700D0oooo023/1`0Pk0L0oooo023/1`060?ooo`808>`7
1`3oool6023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`3oool0oooo1P0Pk0L40?ooo`04
023/1`3oool08>`70?ooo`<08>`700@0oooo023/1`3oool0oooo0P0Pk0L0103oool08>`7023/1`0P
k0L20?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L0103oool08>`7023/1`3oool6023/1`80
oooo0P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70000000P
k0L0100Pk0L20?ooo`<08>`700<0oooo023/1`3oool00`3oool6023/1`@0oooo100Pk0L=0?ooo`05
023/1`3oool08>`70?ooo`0Pk0L0703oool00`000000oooo0?ooo`0P0?ooo`007P3oool00`000000
oooo0?ooo`0I0?ooo`03023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool00P0Pk0L01@3oool0
8>`7023/1`3oool08>`700H0oooo0P0Pk0L70?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L0103o
ool08>`70?ooo`3oool7023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool08>`70?oo
o`3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/
1`040?ooo`0Pk0L08>`70?ooo`H08>`70P3oool2023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo
023/1`3oool00P3oool00`0Pk0L00000023/1`04023/1`80oooo0`0Pk0L00`3oool08>`70?ooo`03
0?ooo`H08>`7103oool4023/1`d0oooo00D08>`70?ooo`0Pk0L0oooo023/1`0L0?ooo`030000003o
ool0oooo0200oooo000N0?ooo`030000003oool0oooo01T0oooo00<08>`70?ooo`0Pk0L01@3oool0
0`0Pk0L0oooo0?ooo`02023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01P3oool2023/1`L0oooo1P0P
k0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L0oooo0?ooo`L08>`70`3oool0100Pk0L0oooo
023/1`3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool0
1@0Pk0L0oooo023/1`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L20?ooo`808>`7
00<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`0000008>`700@08>`7
0P3oool01@0Pk0L0oooo023/1`3oool08>`700@0oooo1P0Pk0L40?ooo`@08>`73@3oool01@0Pk0L0
oooo023/1`3oool08>`701`0oooo00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3o
ool06@3oool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00808>`700D0oooo023/1`0P
k0L0oooo023/1`060?ooo`808>`71`3oool6023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/
1`3oool0oooo1`0Pk0L30?ooo`04023/1`3oool08>`70?ooo`<08>`700@0oooo023/1`3oool0oooo
0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L0103o
ool08>`7023/1`3oool4023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700<0oooo023/1`0Pk0L02P0P
k0L00`3oool08>`70?ooo`020?ooo`03023/1`0000008>`700@08>`70P3oool01@0Pk0L0oooo023/
1`3oool08>`700@0oooo1P0Pk0L30?ooo`03023/1`3oool08>`700808>`73@3oool2023/1`80oooo
00<08>`70?ooo`3oool06P3oool00`000000oooo0?ooo`0P0?ooo`007P3oool00`000000oooo0?oo
o`0I0?ooo`03023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool00P0Pk0L01@3oool08>`7023/
1`3oool08>`700H0oooo0P0Pk0L70?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7
0?ooo`3oool7023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool08>`70?ooo`3oool2
023/1`040?ooo`0Pk0L08>`7023/1`80oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`040?oo
o`0Pk0L08>`70?ooo`@08>`700@0oooo023/1`3oool0oooo0P0Pk0L00`3oool08>`7023/1`0:023/
1`030?ooo`0Pk0L0oooo0080oooo00<08>`70000000Pk0L0100Pk0L20?ooo`05023/1`3oool08>`7
0?ooo`0Pk0L0103oool6023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L=0?ooo`808>`70P3oool0
0`0Pk0L0oooo0?ooo`0J0?ooo`030000003oool0oooo0200oooo000N0?ooo`030000003oool0oooo
01T0oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`02023/1`050?ooo`0Pk0L08>`7
0?ooo`0Pk0L01P3oool2023/1`L0oooo1P0Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L0
oooo0?ooo`L08>`70`3oool0100Pk0L0oooo023/1`3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`80
8>`700@0oooo023/1`0Pk0L08>`70P3oool4023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo
023/1`0Pk0L00P0Pk0L0103oool08>`70?ooo`3oool2023/1`030?ooo`0Pk0L08>`700X08>`700<0
oooo023/1`3oool00P3oool00`0Pk0L00000023/1`04023/1`80oooo00D08>`70?ooo`0Pk0L0oooo
023/1`040?ooo`H08>`70`3oool2023/1`030?ooo`0Pk0L08>`700d0oooo0P0Pk0L20?ooo`03023/
1`3oool0oooo01X0oooo00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3oool06@3o
ool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00808>`700D0oooo023/1`0Pk0L0oooo
023/1`060?ooo`808>`71`3oool<023/1`040?ooo`0Pk0L0oooo0?ooo`L08>`70`3oool0100Pk0L0
oooo023/1`3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3o
ool4023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`7
0?ooo`3oool2023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0
0000023/1`04023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`D08>`700@0oooo023/
1`3oool0oooo0P0Pk0L00`3oool08>`7023/1`0=0?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`0J
0?ooo`030000003oool0oooo0200oooo000N0?ooo`030000003oool0oooo01T0oooo00@08>`70?oo
o`0Pk0L08>`7103oool00`0Pk0L0oooo0?ooo`02023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01P3o
ool2023/1`L0oooo300Pk0L0103oool08>`70?ooo`3oool7023/1`<0oooo00@08>`70?ooo`0Pk0L0
oooo0`0Pk0L0103oool08>`70?ooo`3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo100Pk0L0
103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`3oool0oooo
0P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70000000Pk0L0
100Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool5023/1`040?ooo`0Pk0L0oooo0?oo
o`808>`700<0oooo023/1`0Pk0L03@3oool2023/1`80oooo00<08>`70?ooo`3oool06P3oool00`00
0000oooo0?ooo`0P0?ooo`007P3oool00`000000oooo0?ooo`0I0?ooo`04023/1`3oool08>`7023/
1`@0oooo00<08>`70?ooo`3oool00P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo
00<0oooo0P0Pk0L70?ooo``08>`700@0oooo023/1`3oool0oooo1`0Pk0L30?ooo`04023/1`3oool0
8>`70?ooo`<08>`700@0oooo023/1`3oool0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`@0
8>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L01`3oool08>`7023/1`3oool08>`70?ooo`0Pk0L00P3o
ool2023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`3oool00P3oool00`0Pk0L00000023/
1`04023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`D08>`700@0oooo023/1`3oool0
oooo0P0Pk0L00`3oool08>`7023/1`0=0?ooo`808>`700<0oooo023/1`3oool0703oool00`000000
oooo0?ooo`0P0?ooo`007P3oool00`000000oooo0?ooo`0I0?ooo`04023/1`3oool08>`7023/1`@0
oooo00<08>`70?ooo`3oool00P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00@0
oooo00<08>`70?ooo`3oool01@3oool<023/1`040?ooo`0Pk0L0oooo0?ooo`L08>`70`3oool0100P
k0L0oooo023/1`3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700@0oooo023/1`0Pk0L08>`7
0P3oool4023/1`040?ooo`0Pk0L08>`70?ooo`808>`700L0oooo023/1`0Pk0L0oooo023/1`3oool0
8>`70080oooo0P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`7
0000000Pk0L0100Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool5023/1`040?ooo`0P
k0L0oooo0?ooo`808>`700<0oooo023/1`0Pk0L03@3oool2023/1`030?ooo`0Pk0L0oooo01`0oooo
00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3oool06@3oool0100Pk0L0oooo023/
1`0Pk0L40?ooo`03023/1`3oool0oooo00808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo
0?ooo`040?ooo`03023/1`3oool0oooo00D0oooo300Pk0L0103oool08>`70?ooo`3oool7023/1`<0
oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool08>`70?ooo`3oool2023/1`040?ooo`0Pk0L0
8>`7023/1`80oooo100Pk0L0103oool08>`7023/1`3oool2023/1`070?ooo`0Pk0L08>`70?ooo`0P
k0L0oooo023/1`020?ooo`808>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`020?oo
o`03023/1`0000008>`700@08>`70P3oool3023/1`030?ooo`0Pk0L0oooo00<0oooo1@0Pk0L0103o
ool08>`70?ooo`3oool2023/1`030?ooo`0Pk0L08>`700d0oooo0P0Pk0L00`3oool08>`70?ooo`0L
0?ooo`030000003oool0oooo0200oooo000N0?ooo`030000003oool0oooo01T0oooo00@08>`70?oo
o`0Pk0L08>`7103oool00`0Pk0L0oooo0?ooo`02023/1`060?ooo`0Pk0L0oooo023/1`3oool08>`7
1P3oool00`0Pk0L0oooo0?ooo`050?ooo``08>`700@0oooo023/1`3oool0oooo1`0Pk0L30?ooo`04
023/1`3oool08>`70?ooo`<08>`700@0oooo023/1`3oool0oooo0P0Pk0L0103oool08>`7023/1`0P
k0L20?ooo`@08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L01`3oool08>`7023/1`3oool08>`70?oo
o`0Pk0L00P3oool2023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`3oool00P3oool00`0P
k0L00000023/1`04023/1`80oooo0`0Pk0L00`3oool08>`70?ooo`030?ooo`D08>`700@0oooo023/
1`3oool0oooo0`0Pk0L00`3oool08>`70?ooo`0;0?ooo`05023/1`3oool08>`70?ooo`0Pk0L07@3o
ool00`000000oooo0?ooo`0P0?ooo`007P3oool00`000000oooo0?ooo`0I0?ooo`04023/1`3oool0
8>`7023/1`@0oooo00<08>`70?ooo`3oool00P0Pk0L01P3oool08>`70?ooo`0Pk0L0oooo023/1`H0
oooo00<08>`70?ooo`3oool01@3oool<023/1`040?ooo`0Pk0L0oooo0?ooo`L08>`70`3oool0100P
k0L0oooo023/1`3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700@0oooo023/1`0Pk0L08>`7
0P3oool4023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700@0oooo023/1`3oool0oooo0P0Pk0L00`3o
ool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70000000Pk0L0100Pk0L20?oo
o`D08>`7103oool5023/1`040?ooo`0Pk0L0oooo0?ooo`<08>`700<0oooo023/1`3oool02`3oool0
1@0Pk0L0oooo023/1`3oool08>`701d0oooo00<000000?ooo`3oool0803oool001h0oooo00<00000
0?ooo`3oool06@3oool0100Pk0L0oooo023/1`0Pk0L40?ooo`03023/1`3oool0oooo00@08>`700@0
oooo023/1`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`050?ooo``08>`700@0oooo023/1`3oool0
oooo1`0Pk0L30?ooo`04023/1`3oool08>`70?ooo`<08>`700@0oooo023/1`3oool0oooo0P0Pk0L0
103oool08>`7023/1`0Pk0L20?ooo`@08>`700@0oooo023/1`0Pk0L0oooo1`0Pk0L0103oool08>`7
0?ooo`3oool2023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0
0000023/1`04023/1`80oooo1@0Pk0L40?ooo`D08>`700@0oooo023/1`3oool0oooo0`0Pk0L00`3o
ool08>`70?ooo`0;0?ooo`05023/1`3oool08>`70?ooo`0Pk0L07@3oool00`000000oooo0?ooo`0P
0?ooo`007P3oool00`000000oooo0?ooo`0I0?ooo`04023/1`3oool08>`7023/1`@0oooo00<08>`7
0?ooo`3oool0100Pk0L0103oool08>`70?ooo`0Pk0L60?ooo`03023/1`3oool0oooo00D0oooo200P
k0L01P3oool08>`7023/1`0Pk0L0oooo023/1`80oooo1`0Pk0L30?ooo`04023/1`3oool08>`70?oo
o`<08>`700@0oooo023/1`3oool0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`@08>`700@0
oooo023/1`0Pk0L0oooo1`0Pk0L0103oool08>`70?ooo`3oool2023/1`030?ooo`0Pk0L08>`700X0
8>`700<0oooo023/1`3oool00P3oool00`0Pk0L00000023/1`04023/1`80oooo1@0Pk0L30?ooo`03
023/1`3oool08>`700<08>`70P3oool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo00/0
oooo00D08>`70?ooo`0Pk0L0oooo023/1`0M0?ooo`030000003oool0oooo0200oooo000N0?ooo`03
0000003oool0oooo01T0oooo00@08>`70?ooo`0Pk0L08>`7103oool00`0Pk0L0oooo0?ooo`04023/
1`040?ooo`0Pk0L0oooo023/1`H0oooo00<08>`70?ooo`3oool01@3oool8023/1`060?ooo`0Pk0L0
8>`7023/1`3oool08>`70P3oool7023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool0
8>`70?ooo`3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo00D08>`70?ooo`0Pk0L08>`70?oo
o`02023/1`030?ooo`0Pk0L08>`700D08>`700@0oooo023/1`3oool0oooo0P0Pk0L00`3oool08>`7
023/1`0:023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70000000Pk0L0100Pk0L20?ooo`D08>`7
0`3oool00`0Pk0L0oooo023/1`03023/1`80oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700`0
oooo00D08>`70?ooo`0Pk0L0oooo023/1`0M0?ooo`030000003oool0oooo0200oooo000N0?ooo`03
0000003oool0oooo01T0oooo00@08>`70?ooo`0Pk0L08>`7103oool00`0Pk0L0oooo0?ooo`04023/
1`040?ooo`0Pk0L0oooo023/1`H0oooo00<08>`70?ooo`3oool01@3oool8023/1`060?ooo`0Pk0L0
8>`7023/1`3oool08>`70P3oool7023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool0
8>`70?ooo`3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo00D08>`70?ooo`0Pk0L08>`70?oo
o`02023/1`030?ooo`0Pk0L08>`700D08>`700@0oooo023/1`3oool0oooo0P0Pk0L00`3oool08>`7
023/1`0:023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70000000Pk0L0100Pk0L20?ooo`D08>`7
0`3oool00`0Pk0L0oooo023/1`03023/1`80oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700`0
oooo00D08>`70?ooo`0Pk0L0oooo023/1`0M0?ooo`030000003oool0oooo0200oooo000N0?ooo`03
0000003oool0oooo01T0oooo00@08>`70?ooo`0Pk0L08>`7103oool00`0Pk0L0oooo0?ooo`04023/
1`040?ooo`0Pk0L0oooo023/1`H0oooo00<08>`70?ooo`3oool01@3oool8023/1`060?ooo`0Pk0L0
8>`7023/1`3oool08>`70P3oool7023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool0
8>`70?ooo`3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo00D08>`70?ooo`0Pk0L08>`70?oo
o`02023/1`030?ooo`0Pk0L08>`700D08>`700@0oooo023/1`3oool0oooo0P0Pk0L00`3oool08>`7
023/1`0:023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70000000Pk0L0100Pk0L20?ooo`D08>`7
0`3oool00`0Pk0L0oooo023/1`03023/1`80oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700`0
oooo00D08>`70?ooo`0Pk0L0oooo023/1`0M0?ooo`030000003oool0oooo0200oooo000N0?ooo`03
0000003oool0oooo01X0oooo0`0Pk0L40?ooo`03023/1`3oool0oooo00@08>`700@0oooo023/1`3o
ool08>`71P3oool00`0Pk0L0oooo0?ooo`050?ooo`P08>`700H0oooo023/1`0Pk0L08>`70?ooo`0P
k0L20?ooo`L08>`70`3oool0100Pk0L0oooo023/1`3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`80
8>`700@0oooo023/1`0Pk0L08>`70P3oool01@0Pk0L0oooo023/1`0Pk0L0oooo00808>`700<0oooo
023/1`0Pk0L01@0Pk0L0103oool08>`70?ooo`3oool2023/1`030?ooo`0Pk0L08>`700X08>`700<0
oooo023/1`3oool00P3oool00`0Pk0L00000023/1`04023/1`80oooo1@0Pk0L30?ooo`03023/1`3o
ool08>`700<08>`70P3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L0303oool01@0Pk0L0oooo
023/1`3oool08>`701d0oooo00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3oool0
6P3oool3023/1`@0oooo00<08>`70?ooo`3oool00`0Pk0L01@3oool08>`7023/1`3oool08>`700H0
oooo00<08>`70?ooo`3oool01@3oool8023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70P3oool7
023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3o
ool00`0Pk0L20?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`05023/
1`040?ooo`0Pk0L0oooo0?ooo`808>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`02
0?ooo`03023/1`0000008>`700@08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`03023/1`3oool0
8>`700<08>`70P3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L0303oool01@0Pk0L0oooo023/
1`3oool08>`701d0oooo00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3oool06P3o
ool3023/1`@0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700H0
oooo00<08>`70?ooo`3oool01@3oool8023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70P3oool7
023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3o
ool00`0Pk0L20?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`05023/
1`040?ooo`0Pk0L0oooo0?ooo`808>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`02
0?ooo`03023/1`0000008>`700@08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`04023/1`3oool0
8>`70?ooo`808>`70P3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L0303oool01@0Pk0L0oooo
023/1`3oool08>`701d0oooo00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3oool0
6P3oool3023/1`@0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`7
00H0oooo00<08>`70?ooo`3oool01@3oool8023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70P3o
ool7023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/
1`3oool00`0Pk0L20?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`07
023/1`80oooo0P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`7
0000000Pk0L0100Pk0L00`3oool08>`7023/1`04023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0P0P
k0L30?ooo`03023/1`3oool08>`700808>`73@3oool01@0Pk0L0oooo023/1`3oool08>`701d0oooo
00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3oool06P3oool3023/1`@0oooo00@0
8>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700H0oooo00<08>`70?ooo`3o
ool01@3oool00`0Pk0L0oooo023/1`05023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70P3oool7
023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3o
ool00`0Pk0L20?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`07023/
1`80oooo0P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/
1`3oool00P3oool00`0Pk0L00000023/1`04023/1`030?ooo`0Pk0L08>`700@08>`70`3oool0100P
k0L0oooo023/1`3oool2023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L=0?ooo`05023/1`3oool0
8>`70?ooo`0Pk0L07@3oool00`000000oooo0?ooo`0P0?ooo`007P3oool00`000000oooo0?ooo`0J
0?ooo`<08>`7103oool0100Pk0L0oooo0?ooo`3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L0
1P3oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool08>`700D08>`700H0oooo023/1`0Pk0L0
8>`70?ooo`0Pk0L20?ooo`L08>`70`3oool0100Pk0L0oooo023/1`3oool3023/1`070?ooo`0Pk0L0
oooo023/1`3oool08>`70?ooo`03023/1`80oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`03
0?ooo`0Pk0L08>`700L08>`70P3oool2023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0P
k0L0100Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`0000008>`700@08>`700<0oooo023/1`0P
k0L0100Pk0L30?ooo`<08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo023/1`02023/1`d0
oooo00D08>`70?ooo`0Pk0L0oooo023/1`0M0?ooo`030000003oool0oooo0200oooo000N0?ooo`03
0000003oool0oooo01X0oooo0`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo023/
1`0Pk0L0oooo023/1`060?ooo`03023/1`3oool0oooo00D0oooo00<08>`70?ooo`0Pk0L01@0Pk0L0
1P3oool08>`7023/1`0Pk0L0oooo023/1`80oooo1`0Pk0L30?ooo`04023/1`3oool08>`70?ooo`<0
8>`700X0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo
023/1`02023/1`030?ooo`0Pk0L0oooo00T08>`70P3oool2023/1`030?ooo`0Pk0L08>`700<08>`7
00<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`0000008>`700@08>`7
00<0oooo023/1`0Pk0L0100Pk0L30?ooo`D08>`7103oool00`0Pk0L0oooo023/1`02023/1`d0oooo
00D08>`70?ooo`0Pk0L0oooo023/1`0M0?ooo`030000003oool0oooo0200oooo000N0?ooo`030000
003oool0oooo01X0oooo0`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo023/1`0P
k0L0oooo023/1`060?ooo`03023/1`3oool0oooo00D0oooo00<08>`70?ooo`0Pk0L01@0Pk0L01P3o
ool08>`7023/1`0Pk0L0oooo023/1`80oooo1`0Pk0L30?ooo`04023/1`3oool08>`70?ooo`<08>`7
00X0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo023/
1`02023/1`030?ooo`0Pk0L0oooo00T08>`70P3oool2023/1`030?ooo`0Pk0L08>`700<08>`700<0
oooo023/1`0Pk0L0100Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`0000008>`700@08>`700<0
oooo023/1`0Pk0L0100Pk0L30?ooo`D08>`7103oool00`0Pk0L0oooo023/1`02023/1`d0oooo00D0
8>`70?ooo`0Pk0L0oooo023/1`0M0?ooo`030000003oool0oooo0200oooo000N0?ooo`030000003o
ool0oooo01X0oooo0`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo023/1`0Pk0L0
oooo023/1`060?ooo`03023/1`3oool0oooo00D0oooo00<08>`70?ooo`0Pk0L01@0Pk0L01P3oool0
8>`7023/1`0Pk0L0oooo023/1`80oooo1`0Pk0L30?ooo`04023/1`3oool08>`70?ooo`<08>`700/0
oooo023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`02023/1`070?ooo`0Pk0L0
8>`7023/1`3oool08>`70?ooo`09023/1`050?ooo`0Pk0L0oooo023/1`3oool01@0Pk0L00`3oool0
8>`7023/1`04023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70000000Pk0L0100Pk0L00`3oool0
8>`7023/1`04023/1`<0oooo1@0Pk0L40?ooo`03023/1`3oool08>`700808>`73@3oool01@0Pk0L0
oooo023/1`3oool08>`701d0oooo00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3o
ool06P3oool3023/1`@0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7023/1`3oool0
8>`700H0oooo00<08>`70?ooo`3oool01@3oool00`0Pk0L0oooo023/1`05023/1`060?ooo`0Pk0L0
8>`7023/1`3oool08>`70P3oool7023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L02`3oool0
8>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00808>`700L0oooo023/1`0Pk0L0
8>`70?ooo`0Pk0L0oooo00T08>`700D0oooo023/1`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L0
8>`700<08>`70P3oool01P0Pk0L0oooo0?ooo`3oool08>`7000000@08>`70P3oool6023/1`<0oooo
1@0Pk0L30?ooo`808>`700@0oooo023/1`0Pk0L08>`73@3oool01@0Pk0L0oooo023/1`3oool08>`7
01d0oooo00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3oool06P3oool3023/1`@0
oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700H0oooo00<08>`7
0?ooo`3oool01@3oool00`0Pk0L0oooo023/1`05023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`7
0P3oool7023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L02`3oool08>`70?ooo`0Pk0L0oooo
023/1`3oool08>`70?ooo`0Pk0L0oooo00808>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo
00T08>`700D0oooo023/1`3oool08>`70?ooo`0;023/1`80oooo00H08>`70?ooo`3oool0oooo023/
1`000004023/1`80oooo1@0Pk0L40?ooo`D08>`70`3oool2023/1`040?ooo`0Pk0L08>`7023/1`d0
oooo00@08>`70?ooo`0Pk0L08>`77P3oool00`000000oooo0?ooo`0P0?ooo`007P3oool00`000000
oooo0?ooo`0J0?ooo`<08>`7103oool0100Pk0L0oooo0?ooo`3oool2023/1`050?ooo`0Pk0L08>`7
0?ooo`0Pk0L01P3oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool08>`700D08>`700H0oooo
023/1`0Pk0L08>`70?ooo`0Pk0L20?ooo`L08>`70`3oool0100Pk0L0oooo023/1`3oool3023/1`0;
0?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L01`3oool08>`7
023/1`0Pk0L0oooo023/1`3oool02@0Pk0L00`3oool08>`70?ooo`0=023/1`80oooo00H08>`70?oo
o`3oool0oooo023/1`000002023/1`040?ooo`0Pk0L0oooo0?ooo`D08>`7103oool5023/1`<0oooo
00<08>`70?ooo`0Pk0L00`0Pk0L=0?ooo`04023/1`3oool08>`7023/1ah0oooo00<000000?ooo`3o
ool0803oool001h0oooo00<000000?ooo`3oool06P3oool3023/1`@0oooo00@08>`70?ooo`3oool0
oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700H0oooo00<08>`70?ooo`3oool01@3oool00`0P
k0L0oooo023/1`05023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70P3oool7023/1`<0oooo00@0
8>`70?ooo`0Pk0L0oooo0`0Pk0L02`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0P
k0L0oooo00808>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00T08>`700@0oooo023/1`0P
k0L0oooo300Pk0L20?ooo`06023/1`3oool0oooo0?ooo`0Pk0L000000P0Pk0L0103oool08>`70?oo
o`3oool5023/1`@0oooo1@0Pk0L30?ooo`04023/1`3oool08>`70?ooo`808>`73@3oool0100Pk0L0
oooo023/1`0Pk0LN0?ooo`030000003oool0oooo0200oooo000N0?ooo`030000003oool0oooo01X0
oooo0`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`06
0?ooo`03023/1`3oool0oooo00D0oooo00<08>`70?ooo`0Pk0L01@0Pk0L01P3oool08>`7023/1`0P
k0L0oooo023/1`80oooo1`0Pk0L30?ooo`04023/1`3oool08>`70?ooo`<08>`700/0oooo023/1`3o
ool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`02023/1`070?ooo`0Pk0L08>`7023/1`3o
ool08>`70?ooo`09023/1`040?ooo`0Pk0L08>`70?ooo``08>`70P3oool00`0Pk0L0oooo0?ooo`02
023/1`050000000Pk0L08>`70?ooo`0Pk0L00P3oool5023/1`@0oooo1@0Pk0L30?ooo`04023/1`3o
ool08>`70?ooo`808>`73@3oool2023/1`030?ooo`0Pk0L0oooo01h0oooo00<000000?ooo`3oool0
7`3oool001h0oooo00<000000?ooo`3oool06P3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00@0
8>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700H0oooo00<08>`70?ooo`3o
ool01@3oool00`0Pk0L0oooo023/1`05023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70P3oool7
023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L02`3oool08>`70?ooo`0Pk0L0oooo023/1`3o
ool08>`70?ooo`0Pk0L0oooo00808>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00T08>`7
00@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`7023/1`05023/1`80oooo00<08>`70?ooo`3o
ool00P0Pk0L01@0000008>`7023/1`3oool08>`70080oooo1@0Pk0L40?ooo`D08>`70`3oool0100P
k0L0oooo023/1`3oool2023/1``0oooo00D08>`70?ooo`0Pk0L0oooo023/1`0O0?ooo`030000003o
ool0oooo01l0oooo000N0?ooo`030000003oool0oooo01X0oooo0P0Pk0L00`3oool08>`70?ooo`02
0?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`060?ooo`03023/
1`3oool0oooo00D0oooo00<08>`70?ooo`0Pk0L01@0Pk0L01P3oool08>`7023/1`0Pk0L0oooo023/
1`80oooo1`0Pk0L30?ooo`04023/1`3oool08>`70?ooo`<08>`700/0oooo023/1`3oool08>`70?oo
o`0Pk0L0oooo023/1`3oool08>`70?ooo`02023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?oo
o`09023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`03023/
1`3oool0oooo00808>`700D00000023/1`0Pk0L0oooo023/1`020?ooo`D08>`7103oool5023/1`<0
oooo00@08>`70?ooo`0Pk0L0oooo0P0Pk0L<0?ooo`05023/1`3oool08>`70?ooo`0Pk0L07`3oool0
0`000000oooo0?ooo`0O0?ooo`007P3oool00`000000oooo0?ooo`0J0?ooo`808>`700<0oooo023/
1`3oool00P3oool0100Pk0L0oooo0?ooo`3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01P3o
ool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool08>`700D08>`700H0oooo023/1`0Pk0L08>`7
0?ooo`0Pk0L20?ooo`L08>`70`3oool0100Pk0L0oooo023/1`3oool3023/1`0;0?ooo`0Pk0L0oooo
023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L01`3oool08>`7023/1`0Pk0L0oooo
023/1`3oool02@0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`700D08>`70P3o
ool00`0Pk0L0oooo0?ooo`02023/1`050000000Pk0L08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo
023/1`02023/1`@0oooo1@0Pk0L30?ooo`04023/1`3oool08>`70?ooo`808>`7303oool01@0Pk0L0
oooo023/1`3oool08>`701l0oooo00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3o
ool06P3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3o
ool08>`7023/1`3oool08>`700H0oooo00<08>`70?ooo`3oool01@3oool00`0Pk0L0oooo023/1`05
023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70P3oool7023/1`<0oooo00@08>`70?ooo`0Pk0L0
oooo0`0Pk0L02`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00808>`7
00L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00T08>`700@0oooo023/1`0Pk0L0oooo100Pk0L0
0`3oool08>`7023/1`05023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L01@0000008>`7023/1`3o
ool08>`70080oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`D08>`70`3oool0100Pk0L0oooo023/
1`3oool2023/1``0oooo00D08>`70?ooo`0Pk0L0oooo023/1`0O0?ooo`030000003oool0oooo01l0
oooo000N0?ooo`030000003oool0oooo01X0oooo00@08>`70?ooo`0Pk0L08>`70`3oool0100Pk0L0
oooo0?ooo`3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01P3oool00`0Pk0L0oooo0?ooo`05
0?ooo`03023/1`3oool08>`700D08>`700H0oooo023/1`0Pk0L08>`70?ooo`0Pk0L20?ooo`L08>`7
0`3oool0100Pk0L0oooo023/1`3oool3023/1`090?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0P
k0L0oooo00808>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`70?ooo`09023/1`040?ooo`0P
k0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`03023/1`3oool0oooo00808>`7
00D00000023/1`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700808>`7103oool5023/1`<0
oooo00<08>`70?ooo`0Pk0L00`0Pk0L<0?ooo`05023/1`3oool08>`70?ooo`0Pk0L07`3oool00`00
0000oooo0?ooo`0O0?ooo`007P3oool00`000000oooo0?ooo`0J0?ooo`04023/1`3oool08>`7023/
1`<0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700H0oooo00<0
8>`70?ooo`3oool01@3oool00`0Pk0L0oooo023/1`05023/1`060?ooo`0Pk0L08>`7023/1`3oool0
8>`70P3oool7023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L02@3oool08>`70?ooo`0Pk0L0
oooo023/1`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo00@08>`70P3oool9023/1`040?oo
o`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`03023/1`3oool0oooo0080
8>`700D00000023/1`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700808>`7103oool5023/
1`<0oooo00<08>`70?ooo`0Pk0L00`0Pk0L<0?ooo`05023/1`3oool08>`70?ooo`0Pk0L07`3oool0
0`000000oooo0?ooo`0O0?ooo`007P3oool00`000000oooo0?ooo`0J0?ooo`04023/1`3oool08>`7
023/1`<0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700H0oooo
00<08>`70?ooo`3oool01P3oool7023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70P3oool7023/
1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L02@3oool08>`70?ooo`0Pk0L0oooo023/1`3oool0
8>`70?ooo`02023/1`030?ooo`0Pk0L0oooo00@08>`70P3oool9023/1`040?ooo`0Pk0L08>`70?oo
o`@08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`06023/1`3oool0oooo023/1`3oool000000P0P
k0L01P3oool08>`70?ooo`3oool08>`70?ooo`<08>`7103oool5023/1`<0oooo00<08>`70?ooo`0P
k0L00`0Pk0L<0?ooo`05023/1`3oool08>`70?ooo`0Pk0L07`3oool00`000000oooo0?ooo`0O0?oo
o`007P3oool00`000000oooo0?ooo`0J0?ooo`04023/1`3oool08>`7023/1`<0oooo00@08>`70?oo
o`3oool0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700H0oooo00<08>`70?ooo`3oool01P3o
ool7023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70P3oool7023/1`<0oooo00@08>`70?ooo`0P
k0L0oooo0`0Pk0L02@3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`02023/1`040?oo
o`0Pk0L08>`70?ooo`<08>`70P3oool9023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/
1`0Pk0L01@0Pk0L20?ooo`06023/1`3oool0oooo023/1`3oool000000P0Pk0L01P3oool08>`70?oo
o`3oool08>`70?ooo`<08>`7103oool5023/1`<0oooo00<08>`70?ooo`0Pk0L00`0Pk0L<0?ooo`05
023/1`3oool08>`70?ooo`0Pk0L07`3oool00`000000oooo0?ooo`0O0?ooo`007P3oool00`000000
oooo0?ooo`0J0?ooo`04023/1`3oool08>`7023/1`<0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L0
1@3oool08>`7023/1`3oool08>`700H0oooo00<08>`70?ooo`3oool01P3oool6023/1`030?ooo`0P
k0L08>`700808>`700@0oooo023/1`3oool0oooo1`0Pk0L30?ooo`04023/1`3oool08>`70?ooo`D0
8>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo0`0P
k0L20?ooo`T08>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`7023/1`05023/1`80oooo
00H08>`70?ooo`3oool08>`70?ooo`000002023/1`040?ooo`0Pk0L0oooo0?ooo`D08>`7103oool5
023/1`80oooo00<08>`70?ooo`3oool0100Pk0L<0?ooo`05023/1`3oool08>`70?ooo`0Pk0L07`3o
ool00`000000oooo0?ooo`0O0?ooo`007P3oool00`000000oooo0?ooo`0J0?ooo`04023/1`3oool0
8>`7023/1`<0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700H0
oooo00<08>`70?ooo`3oool01P3oool6023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`3o
ool0oooo1`0Pk0L30?ooo`04023/1`3oool08>`70?ooo`D08>`700L0oooo023/1`3oool08>`70?oo
o`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L20?ooo`T08>`700@0oooo023/1`0P
k0L0oooo100Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?oo
o`0000000P0Pk0L0103oool08>`70?ooo`3oool5023/1`@0oooo1@0Pk0L20?ooo`03023/1`3oool0
oooo00@08>`7303oool01@0Pk0L0oooo023/1`3oool08>`701l0oooo00<000000?ooo`3oool07`3o
ool001h0oooo00<000000?ooo`3oool06P3oool0100Pk0L0oooo023/1`0Pk0L40?ooo`03023/1`3o
ool0oooo00808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3o
ool0oooo00H0oooo1P0Pk0L00`3oool08>`7023/1`02023/1`040?ooo`0Pk0L0oooo0?ooo`L08>`7
0`3oool0100Pk0L0oooo023/1`3oool5023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`02
023/1`040?ooo`0Pk0L08>`70?ooo`<08>`70P3oool9023/1`040?ooo`0Pk0L08>`70?ooo`@08>`7
00<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0000000808>`7
00@0oooo023/1`3oool0oooo1@0Pk0L30?ooo`03023/1`3oool08>`700<08>`70P3oool00`0Pk0L0
oooo0?ooo`04023/1``0oooo00D08>`70?ooo`0Pk0L0oooo023/1`0O0?ooo`030000003oool0oooo
01l0oooo000N0?ooo`030000003oool0oooo01X0oooo00@08>`70?ooo`0Pk0L08>`7103oool00`0P
k0L0oooo0?ooo`02023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool00`3oool00`0P
k0L0oooo0?ooo`060?ooo`H08>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`70?ooo`3oool7
023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo1@0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3o
ool00P0Pk0L0103oool08>`7023/1`3oool3023/1`80oooo2@0Pk0L0103oool08>`7023/1`3oool4
023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo00000002
023/1`040?ooo`0Pk0L0oooo0?ooo`D08>`70`3oool00`0Pk0L0oooo023/1`03023/1`80oooo00<0
8>`70?ooo`3oool0100Pk0L<0?ooo`05023/1`3oool08>`70?ooo`0Pk0L07`3oool00`000000oooo
0?ooo`0O0?ooo`007P3oool00`000000oooo0?ooo`0J0?ooo`04023/1`3oool08>`7023/1`@0oooo
00<08>`70?ooo`3oool00P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00<0oooo
00<08>`70?ooo`3oool01P3oool6023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`3oool0
oooo1`0Pk0L30?ooo`04023/1`3oool08>`70?ooo`D08>`700L0oooo023/1`3oool08>`70?ooo`0P
k0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L20?ooo`T08>`700@0oooo023/1`0Pk0L0
oooo100Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`00
0000100Pk0L20?ooo`D08>`70`3oool00`0Pk0L0oooo023/1`03023/1`80oooo00<08>`70?ooo`3o
ool0100Pk0L<0?ooo`05023/1`3oool08>`70?ooo`0Pk0L07`3oool00`000000oooo0?ooo`0O0?oo
o`007P3oool00`000000oooo0?ooo`0J0?ooo`04023/1`3oool08>`7023/1`@0oooo00<08>`70?oo
o`3oool00P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?oo
o`3oool01P3oool6023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`3oool0oooo1`0Pk0L3
0?ooo`04023/1`3oool08>`70?ooo`D08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo0080
8>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L20?ooo`T08>`700@0oooo023/1`0Pk0L0oooo100Pk0L0
0`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`000000100Pk0L2
0?ooo`D08>`70`3oool00`0Pk0L0oooo023/1`03023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L=
0?ooo`05023/1`3oool08>`70?ooo`0Pk0L07`3oool00`000000oooo0?ooo`0O0?ooo`007P3oool0
0`000000oooo0?ooo`0J0?ooo`04023/1`3oool08>`7023/1`@0oooo00<08>`70?ooo`3oool00P0P
k0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01P3o
ool;023/1`040?ooo`0Pk0L0oooo0?ooo`L08>`70`3oool0100Pk0L0oooo023/1`3oool5023/1`08
0?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L08>`7
0P3oool9023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool0
8>`70?ooo`020?ooo`03023/1`3oool0000000@08>`70P3oool5023/1`<0oooo00<08>`70?ooo`0P
k0L00`0Pk0L20?ooo`03023/1`3oool0oooo00<08>`73@3oool01@0Pk0L0oooo023/1`3oool08>`7
01l0oooo00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06P3oool0100Pk0L0
oooo023/1`0Pk0L40?ooo`03023/1`3oool0oooo00808>`700<0oooo023/1`0Pk0L00P3oool00`0P
k0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00H0oooo2`0Pk0L0103oool08>`70?ooo`3oool7
023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo1@0Pk0L0203oool08>`70?ooo`0Pk0L0oooo023/1`3o
ool08>`70P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo2@0Pk0L0103oool08>`7023/1`3o
ool4023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0000
0004023/1`80oooo1@0Pk0L30?ooo`04023/1`3oool08>`70?ooo`808>`70P3oool00`0Pk0L0oooo
0?ooo`03023/1`d0oooo00@08>`70?ooo`0Pk0L08>`7803oool00`000000oooo0?ooo`0O0?ooo`00
7P3oool00`000000oooo0?ooo`0J0?ooo`04023/1`3oool08>`7023/1`@0oooo00<08>`70?ooo`3o
ool00P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3o
ool01P3oool;023/1`040?ooo`0Pk0L0oooo0?ooo`L08>`70`3oool0100Pk0L0oooo023/1`3oool5
023/1`080?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L20?ooo`808>`700@0oooo023/1`0P
k0L08>`70P3oool9023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L01@0Pk0L0
0`3oool08>`70?ooo`020?ooo`03023/1`3oool0000000@08>`70P3oool3023/1`030?ooo`0Pk0L0
oooo0080oooo00@08>`70?ooo`0Pk0L0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00<08>`73@3o
ool0100Pk0L0oooo023/1`0Pk0LP0?ooo`030000003oool0oooo01l0oooo000N0?ooo`030000003o
ool0oooo01X0oooo00@08>`70?ooo`0Pk0L08>`7103oool00`0Pk0L0oooo0?ooo`05023/1`80oooo
00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`060?ooo`/08>`700@0oooo023/1`3oool0
oooo1`0Pk0L30?ooo`03023/1`3oool08>`700H08>`700P0oooo023/1`3oool08>`70?ooo`0Pk0L0
oooo023/1`80oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`T08>`700@0oooo023/1`0Pk0L0
oooo100Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`00
0000100Pk0L20?ooo`<08>`700<0oooo023/1`3oool00P3oool0100Pk0L0oooo023/1`3oool2023/
1`80oooo00<08>`70?ooo`3oool00`0Pk0L=0?ooo`04023/1`3oool08>`7023/1b00oooo00<00000
0?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06P3oool0100Pk0L0oooo023/1`0Pk0L4
0?ooo`04023/1`3oool0oooo0?ooo`@08>`70P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3o
ool0oooo00H0oooo2`0Pk0L0103oool08>`70?ooo`3oool7023/1`<0oooo00<08>`70?ooo`0Pk0L0
1P0Pk0L0203oool08>`7023/1`0Pk0L0oooo023/1`3oool08>`70P3oool2023/1`040?ooo`0Pk0L0
8>`7023/1`80oooo2@0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`700D08>`7
00@0oooo023/1`3oool0oooo0P0Pk0L00`3oool00000023/1`03023/1`80oooo0`0Pk0L00`3oool0
8>`70?ooo`020?ooo`04023/1`3oool08>`70?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`03023/
1`d0oooo00@08>`70?ooo`0Pk0L08>`7803oool00`000000oooo0?ooo`0O0?ooo`007P3oool00`00
0000oooo0?ooo`0J0?ooo`04023/1`3oool08>`7023/1`@0oooo00@08>`70?ooo`3oool0oooo0P0P
k0L01@3oool08>`70?ooo`3oool08>`700D0oooo00<08>`70?ooo`3oool01P3oool;023/1`040?oo
o`0Pk0L0oooo0?ooo`L08>`70`3oool00`0Pk0L0oooo023/1`06023/1`080?ooo`0Pk0L08>`7023/
1`3oool08>`70?ooo`0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool9023/1`040?oo
o`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`3oool08>`7
0080oooo0P0Pk0L00`3oool00000023/1`03023/1`80oooo0`0Pk0L00`3oool08>`70?ooo`020?oo
o`<08>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`04023/1``0oooo00@08>`70?oo
o`0Pk0L08>`7803oool00`000000oooo0?ooo`0O0?ooo`007P3oool00`000000oooo0?ooo`0J0?oo
o`04023/1`3oool08>`7023/1`@0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`70?oo
o`3oool08>`700D0oooo00<08>`70?ooo`3oool01P3oool;023/1`040?ooo`0Pk0L0oooo0?ooo`L0
8>`70`3oool00`0Pk0L0oooo023/1`05023/1`80oooo0`0Pk0L0103oool08>`70?ooo`0Pk0L20?oo
o`808>`700@0oooo023/1`0Pk0L08>`70P3oool9023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0
oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`3oool08>`70080oooo0P0Pk0L00`3oool00000
023/1`03023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool00P3oool3023/1`050?oo
o`0Pk0L08>`70?ooo`0Pk0L00`3oool4023/1``0oooo00@08>`70?ooo`0Pk0L08>`7803oool00`00
0000oooo0?ooo`0O0?ooo`007P3oool00`000000oooo0?ooo`0J0?ooo`04023/1`3oool08>`7023/
1`@0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`700D0oooo00<0
8>`70?ooo`3oool01P3oool;023/1`040?ooo`0Pk0L0oooo0?ooo`L08>`70`3oool00`0Pk0L0oooo
023/1`05023/1`80oooo0`0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`808>`700@0oooo023/1`0P
k0L08>`70P3oool9023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L0
1@3oool08>`7023/1`3oool08>`70080oooo0P0Pk0L00`3oool00000023/1`03023/1`030?ooo`0P
k0L08>`700808>`700<0oooo023/1`3oool00P3oool3023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L0
0`3oool4023/1``0oooo00@08>`70?ooo`0Pk0L08>`7803oool00`000000oooo0?ooo`0O0?ooo`00
7P3oool00`000000oooo0?ooo`0J0?ooo`04023/1`3oool08>`7023/1`@0oooo00@08>`70?ooo`3o
ool0oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`700D0oooo00<08>`70?ooo`3oool01P3oool;
023/1`040?ooo`0Pk0L0oooo0?ooo`L08>`70`3oool00`0Pk0L0oooo023/1`05023/1`80oooo0`0P
k0L0103oool08>`70?ooo`0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool9023/1`04
0?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`3oool0
8>`70080oooo0P0Pk0L00`3oool00000023/1`03023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`3oool00P3oool3023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo023/
1`02023/1`/0oooo00<08>`70?ooo`3oool00P0Pk0LP0?ooo`030000003oool0oooo01l0oooo000N
0?ooo`030000003oool0oooo01X0oooo00@08>`70?ooo`0Pk0L08>`7103oool0100Pk0L0oooo0?oo
o`3oool2023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`060?ooo`<0
8>`700<0oooo023/1`0Pk0L01@0Pk0L0103oool08>`70?ooo`3oool7023/1`<0oooo00<08>`70?oo
o`0Pk0L01@0Pk0L20?ooo`<08>`700@0oooo023/1`3oool08>`70P3oool2023/1`040?ooo`0Pk0L0
8>`7023/1`80oooo2@0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`700808>`7
00D0oooo023/1`0Pk0L0oooo023/1`020?ooo`808>`700<0oooo0000000Pk0L00`0Pk0L00`3oool0
8>`7023/1`02023/1`030?ooo`0Pk0L0oooo0080oooo0`0Pk0L01@3oool08>`7023/1`3oool08>`7
0080oooo00<08>`70?ooo`0Pk0L00P0Pk0L;0?ooo`03023/1`3oool0oooo00808>`7803oool00`00
0000oooo0?ooo`0O0?ooo`007P3oool00`000000oooo0?ooo`0J0?ooo`04023/1`3oool08>`7023/
1`@0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`700D0oooo00<0
8>`70?ooo`3oool01P3oool3023/1`030?ooo`0Pk0L08>`700D08>`700@0oooo023/1`3oool0oooo
1`0Pk0L30?ooo`03023/1`3oool08>`700D08>`70P3oool3023/1`040?ooo`0Pk0L0oooo023/1`80
oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`T08>`700@0oooo023/1`0Pk0L0oooo100Pk0L0
0`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00P3oool2023/1`030?ooo`00
00008>`700<08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`020?ooo`<08>`700D0
oooo023/1`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700808>`72`3oool00`0Pk0L0oooo
0?ooo`02023/1b00oooo00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06P3o
ool0100Pk0L0oooo023/1`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo023/1`3o
ool0oooo023/1`050?ooo`03023/1`3oool0oooo00H0oooo0`0Pk0L00`3oool08>`7023/1`05023/
1`040?ooo`0Pk0L0oooo0?ooo`L08>`70`3oool00`0Pk0L0oooo023/1`05023/1`80oooo0`0Pk0L0
103oool08>`7023/1`0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool9023/1`040?oo
o`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`3oool08>`7
0080oooo0P0Pk0L00`3oool00000023/1`03023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/
1`3oool00P3oool3023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo023/1`02
023/1`/0oooo00<08>`70?ooo`3oool00P0Pk0LP0?ooo`030000003oool0oooo01l0oooo000N0?oo
o`030000003oool0oooo01X0oooo00D08>`70?ooo`0Pk0L0oooo023/1`030?ooo`04023/1`3oool0
oooo0?ooo`808>`700D0oooo023/1`3oool0oooo023/1`050?ooo`03023/1`3oool0oooo00H0oooo
0`0Pk0L00`3oool08>`7023/1`05023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L30?ooo`03023/
1`3oool08>`700D08>`70P3oool3023/1`040?ooo`0Pk0L08>`7023/1`80oooo0P0Pk0L0103oool0
8>`7023/1`0Pk0L20?ooo`T08>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`7023/1`02
023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00P3oool2023/1`030?ooo`0000008>`700<08>`700<0
oooo023/1`0Pk0L0100Pk0L30?ooo`<08>`700D0oooo023/1`0Pk0L0oooo023/1`020?ooo`06023/
1`3oool08>`7023/1`3oool08>`72P3oool01@0Pk0L0oooo023/1`3oool08>`70200oooo00<00000
0?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06P3oool01@0Pk0L0oooo023/1`3oool0
8>`700<0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`700D0oooo
00<08>`70?ooo`3oool01P3oool3023/1`030?ooo`0Pk0L08>`700D08>`70P3oool00`0Pk0L0oooo
023/1`06023/1`<0oooo00<08>`70?ooo`0Pk0L01@0Pk0L20?ooo`<08>`700@0oooo023/1`0Pk0L0
8>`70P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo2@0Pk0L0103oool08>`7023/1`3oool4
023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L0oooo023/1`020?ooo`808>`700<0
oooo0000000Pk0L00`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo100Pk0L0103oool08>`70?oo
o`0Pk0L20?ooo`06023/1`3oool08>`7023/1`3oool08>`72P3oool01@0Pk0L0oooo023/1`3oool0
8>`70200oooo00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06`3oool2023/
1`030?ooo`0Pk0L0oooo0080oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`70?ooo`3o
ool08>`700D0oooo00<08>`70?ooo`3oool01P3oool3023/1`030?ooo`0Pk0L08>`700D08>`70P3o
ool00`0Pk0L0oooo023/1`06023/1`<0oooo00<08>`70?ooo`0Pk0L01@0Pk0L20?ooo`<08>`700@0
oooo023/1`0Pk0L08>`70P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo2@0Pk0L0103oool0
8>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L0oooo023/1`02
0?ooo`808>`700<0oooo0000000Pk0L00`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo100Pk0L0
103oool08>`70?ooo`0Pk0L20?ooo`06023/1`3oool08>`7023/1`3oool08>`72P3oool01@0Pk0L0
oooo023/1`3oool08>`70200oooo00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3o
ool06`3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3o
ool08>`70?ooo`3oool08>`700D0oooo00<08>`70?ooo`3oool01P3oool3023/1`030?ooo`0Pk0L0
8>`700D08>`70P3oool00`0Pk0L0oooo023/1`06023/1`<0oooo00<08>`70?ooo`0Pk0L01@0Pk0L2
0?ooo`<08>`700@0oooo023/1`0Pk0L08>`70P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo
2@0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0P
k0L0oooo023/1`020?ooo`808>`700<0oooo0000000Pk0L00`0Pk0L00`3oool08>`7023/1`04023/
1`<0oooo1@0Pk0L20?ooo`05023/1`3oool0oooo023/1`3oool00P0Pk0L00`3oool08>`70?ooo`09
0?ooo`05023/1`3oool08>`70?ooo`0Pk0L0803oool00`000000oooo0?ooo`0O0?ooo`007P3oool0
0`000000oooo0?ooo`0K0?ooo`808>`700<0oooo023/1`3oool00P3oool0100Pk0L0oooo0?ooo`3o
ool2023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`060?ooo`<08>`7
00<0oooo023/1`0Pk0L01@0Pk0L20?ooo`03023/1`3oool08>`700H08>`70`3oool00`0Pk0L0oooo
023/1`05023/1`80oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`808>`700@0oooo023/1`0P
k0L08>`70P3oool9023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L0
1@3oool08>`7023/1`3oool08>`70080oooo00@08>`70?ooo`3oool00000100Pk0L00`3oool08>`7
023/1`04023/1`<0oooo1@0Pk0L20?ooo`05023/1`3oool0oooo023/1`3oool00P0Pk0L00`3oool0
8>`70?ooo`090?ooo`05023/1`3oool08>`70?ooo`0Pk0L0803oool00`000000oooo0?ooo`0O0?oo
o`007P3oool00`000000oooo0?ooo`0K0?ooo`808>`700<0oooo023/1`3oool00P3oool0100Pk0L0
oooo0?ooo`3oool2023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`06
0?ooo`/08>`70P3oool00`0Pk0L0oooo023/1`06023/1`<0oooo00<08>`70?ooo`0Pk0L01@0Pk0L2
0?ooo`<08>`700@0oooo023/1`0Pk0L08>`70P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo
2@0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`700808>`700H0oooo023/1`0P
k0L0oooo023/1`3oool2023/1`030?ooo`0Pk0L0000000@08>`700<0oooo023/1`0Pk0L0100Pk0L3
0?ooo`D08>`70P3oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00808>`700<0oooo023/1`3oool02@3o
ool01@0Pk0L0oooo023/1`3oool08>`70200oooo00<000000?ooo`3oool07`3oool001h0oooo00<0
00000?ooo`3oool06`3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00@08>`70?ooo`3oool0oooo
0P0Pk0L01@3oool08>`70?ooo`3oool08>`700D0oooo0P0Pk0L70?ooo`/08>`70P3oool00`0Pk0L0
oooo023/1`06023/1`<0oooo00<08>`70?ooo`0Pk0L01@0Pk0L20?ooo`<08>`700@0oooo023/1`0P
k0L08>`70P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L0103oool08>`7023/1`3o
ool2023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L01P3oool08>`7023/
1`3oool08>`70?ooo`808>`700<0oooo023/1`0000000`0Pk0L20?ooo`H08>`70`3oool5023/1`80
oooo00D08>`70?ooo`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo00T0oooo00D08>`70?oo
o`0Pk0L0oooo023/1`0P0?ooo`030000003oool0oooo01l0oooo000N0?ooo`030000003oool0oooo
01/0oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo
023/1`3oool0oooo023/1`050?ooo`808>`71`3oool;023/1`80oooo00<08>`70?ooo`0Pk0L01P0P
k0L30?ooo`03023/1`3oool08>`700D08>`70P3oool3023/1`040?ooo`0Pk0L08>`7023/1`80oooo
0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3o
ool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700808>`700H0oooo023/1`0Pk0L0oooo023/1`3o
ool2023/1`030?ooo`0Pk0L0000000<08>`70P3oool6023/1`<0oooo1@0Pk0L00`3oool08>`70?oo
o`020?ooo`06023/1`3oool08>`7023/1`3oool08>`72P3oool01@0Pk0L0oooo023/1`3oool08>`7
0200oooo00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06`3oool2023/1`03
0?ooo`0Pk0L0oooo0080oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`70?ooo`3oool0
8>`700D0oooo0P0Pk0L70?ooo`T08>`700H0oooo023/1`3oool0oooo023/1`3oool7023/1`<0oooo
00<08>`70?ooo`0Pk0L01@0Pk0L20?ooo`<08>`700@0oooo023/1`0Pk0L08>`70P3oool2023/1`04
0?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L0
8>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`808>`7
00<0oooo023/1`0000000`0Pk0L20?ooo`03023/1`3oool08>`700<08>`70`3oool5023/1`030?oo
o`0Pk0L0oooo0080oooo00@08>`70?ooo`0Pk0L08>`70P3oool00`0Pk0L0oooo0?ooo`070?ooo`04
023/1`3oool08>`7023/1b40oooo00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3o
ool06`3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3o
ool08>`7023/1`3oool08>`700D0oooo0P0Pk0L70?ooo`T08>`700H0oooo023/1`3oool0oooo023/
1`3oool7023/1`<0oooo00<08>`70?ooo`0Pk0L01@0Pk0L20?ooo`<08>`700@0oooo023/1`3oool0
8>`70P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L0103oool08>`7023/1`3oool2
023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`02
023/1`030?ooo`0Pk0L0000000<08>`70P3oool00`0Pk0L0oooo023/1`03023/1`<0oooo1@0Pk0L0
0`3oool08>`70?ooo`020?ooo`04023/1`3oool08>`7023/1`80oooo00<08>`70?ooo`3oool01`3o
ool0100Pk0L0oooo023/1`0Pk0LQ0?ooo`030000003oool0oooo01l0oooo000N0?ooo`030000003o
ool0oooo01/0oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`04023/1`3oool0oooo0?ooo`808>`7
00D0oooo023/1`0Pk0L0oooo023/1`050?ooo`808>`71`3oool9023/1`060?ooo`0Pk0L0oooo0?oo
o`0Pk0L0oooo1`0Pk0L30?ooo`03023/1`3oool08>`700D08>`70P3oool2023/1`050?ooo`0Pk0L0
8>`70?ooo`0Pk0L00P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L0103oool08>`7
023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool0
8>`70?ooo`02023/1`030?ooo`0Pk0L0000000<08>`70P3oool00`0Pk0L0oooo023/1`03023/1`<0
oooo1@0Pk0L00`3oool08>`70?ooo`020?ooo`04023/1`3oool08>`7023/1`80oooo00<08>`70?oo
o`3oool01`3oool0100Pk0L0oooo023/1`0Pk0LQ0?ooo`030000003oool0oooo01l0oooo000N0?oo
o`030000003oool0oooo01/0oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`04023/1`3oool0oooo
0?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`050?ooo`808>`71`3oool9023/1`060?ooo`0P
k0L0oooo0?ooo`0Pk0L0oooo1`0Pk0L30?ooo`03023/1`3oool08>`700D08>`70P3oool2023/1`05
0?ooo`0Pk0L08>`70?ooo`0Pk0L00P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L0
103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`3oool00P0P
k0L00`3oool08>`700000003023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L30?ooo`D08>`700<0
oooo023/1`3oool00P3oool0100Pk0L0oooo023/1`0Pk0L20?ooo`03023/1`3oool0oooo00L0oooo
00@08>`70?ooo`0Pk0L08>`78@3oool00`000000oooo0?ooo`0O0?ooo`007P3oool00`000000oooo
0?ooo`0K0?ooo`808>`700<0oooo023/1`3oool00P3oool0100Pk0L0oooo0?ooo`3oool2023/1`05
0?ooo`0Pk0L08>`70?ooo`0Pk0L01@3oool2023/1`L0oooo2@0Pk0L01P3oool08>`70?ooo`3oool0
8>`70?ooo`L08>`70`3oool00`0Pk0L0oooo023/1`05023/1`80oooo0P0Pk0L01@3oool08>`7023/
1`3oool08>`70080oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`700@0oooo023/1`0P
k0L0oooo0P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/
1`0000000`0Pk0L20?ooo`H08>`70`3oool5023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?oo
o`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`070?ooo`04023/1`3oool08>`7023/1b40oooo00<00000
0?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06`3oool2023/1`030?ooo`0Pk0L0oooo
0080oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700D0oooo0P0P
k0L70?ooo`T08>`700H0oooo023/1`3oool0oooo023/1`3oool7023/1`<0oooo00<08>`70?ooo`0P
k0L01@0Pk0L20?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`020?ooo`808>`700@0oooo023/
1`0Pk0L08>`70P3oool6023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L02P0P
k0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0000000<08>`70P3oool6023/1`80oooo00<0
8>`70?ooo`0Pk0L00`0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool08>`700<0oooo00<0
8>`70?ooo`3oool01`3oool0100Pk0L0oooo023/1`0Pk0LQ0?ooo`030000003oool0oooo01l0oooo
000N0?ooo`030000003oool0oooo01/0oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`04023/1`3o
ool0oooo0?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`050?ooo`808>`71`3oool9023/1`06
0?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo1`0Pk0L30?ooo`03023/1`3oool08>`700D08>`70P3oool2
023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo
1P0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`3o
ool00P0Pk0L00`3oool08>`700000003023/1`80oooo1P0Pk0L20?ooo`03023/1`3oool08>`700<0
8>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo00L0
oooo00@08>`70?ooo`0Pk0L08>`78@3oool00`000000oooo0?ooo`0O0?ooo`007P3oool00`000000
oooo0?ooo`0K0?ooo`808>`700<0oooo023/1`3oool00P3oool0100Pk0L0oooo0?ooo`3oool2023/
1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01@3oool2023/1`L0oooo2@0Pk0L01P3oool08>`70?ooo`3o
ool08>`70?ooo`L08>`70`3oool00`0Pk0L0oooo023/1`05023/1`80oooo0P0Pk0L01@3oool08>`7
023/1`3oool08>`70080oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`700@0oooo023/
1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo
023/1`0000000`0Pk0L20?ooo`H08>`70P3oool00`0Pk0L0oooo023/1`03023/1`030?ooo`0Pk0L0
oooo0080oooo00<08>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`060?ooo`04023/1`3oool0
8>`7023/1b40oooo00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06`3oool2
023/1`030?ooo`0Pk0L0oooo0080oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7023/
1`3oool08>`700D0oooo0P0Pk0L70?ooo`T08>`700H0oooo023/1`3oool0oooo023/1`3oool7023/
1`<0oooo00<08>`70?ooo`0Pk0L01@0Pk0L20?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`02
0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool4023/1`030?ooo`0Pk0L0oooo00808>`700@0
oooo023/1`0Pk0L0oooo1P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo00808>`7
00<0oooo023/1`0000000`0Pk0L20?ooo`H08>`70P3oool0100Pk0L0oooo023/1`3oool2023/1`03
0?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`060?ooo`04
023/1`3oool08>`7023/1b40oooo00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3o
ool06`3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3o
ool08>`7023/1`3oool08>`700D0oooo0P0Pk0L70?ooo`T08>`700H0oooo023/1`3oool0oooo023/
1`3oool7023/1`<0oooo00<08>`70?ooo`0Pk0L01@0Pk0L20?ooo`808>`700D0oooo023/1`0Pk0L0
oooo023/1`020?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool4023/1`030?ooo`0Pk0L0oooo
00808>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L00`3oool08>`7023/1`03023/1`080?ooo`0Pk0L0
8>`70?ooo`0Pk0L0oooo023/1`000003023/1`80oooo1P0Pk0L20?ooo`04023/1`3oool08>`70?oo
o`808>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo
00H0oooo00@08>`70?ooo`0Pk0L08>`78@3oool00`000000oooo0?ooo`0O0?ooo`007P3oool00`00
0000oooo0?ooo`0K0?ooo`808>`700<0oooo023/1`3oool00P3oool0100Pk0L0oooo0?ooo`3oool2
023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01@3oool2023/1`L0oooo2@0Pk0L01P3oool08>`70?oo
o`3oool08>`70?ooo`L08>`70`3oool00`0Pk0L0oooo023/1`05023/1`80oooo0P0Pk0L01@3oool0
8>`7023/1`3oool08>`70080oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`@08>`700<0oooo
023/1`3oool00P0Pk0L0103oool08>`7023/1`3oool6023/1`030?ooo`0Pk0L08>`700<08>`700P0
oooo023/1`0Pk0L0oooo023/1`3oool08>`7000000<08>`70P3oool6023/1`80oooo00@08>`70?oo
o`0Pk0L0oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool08>`700@0oooo00<08>`7
0?ooo`3oool01@3oool00`0Pk0L0oooo0?ooo`02023/1b40oooo00<000000?ooo`3oool07`3oool0
01h0oooo00<000000?ooo`3oool06`3oool0100Pk0L0oooo023/1`0Pk0L30?ooo`04023/1`3oool0
oooo0?ooo`808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3o
ool0oooo00D0oooo2@0Pk0L01P3oool08>`70?ooo`3oool08>`70?ooo`L08>`70`3oool00`0Pk0L0
oooo023/1`05023/1`80oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`70080oooo0P0Pk0L0103o
ool08>`7023/1`0Pk0L20?ooo`H08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/
1`04023/1`030?ooo`0Pk0L08>`700<08>`700P0oooo023/1`0Pk0L0oooo023/1`3oool08>`70000
00<08>`70P3oool6023/1`80oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L40?ooo`03023/1`3oool0
8>`700@0oooo00<08>`70?ooo`3oool01@3oool00`0Pk0L0oooo0?ooo`02023/1b40oooo00<00000
0?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06`3oool0100Pk0L0oooo023/1`0Pk0L3
0?ooo`04023/1`3oool0oooo0?ooo`808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?oo
o`030?ooo`03023/1`3oool0oooo00D0oooo2@0Pk0L01P3oool08>`70?ooo`3oool08>`70?ooo`L0
8>`70`3oool00`0Pk0L0oooo023/1`03023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700D0oooo023/
1`0Pk0L0oooo023/1`020?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`040?ooo`0P
k0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`03023/1`080?oo
o`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`000003023/1`80oooo1P0Pk0L20?ooo`04023/1`3oool0
8>`70?ooo`<08>`70`3oool0100Pk0L0oooo023/1`0Pk0L40?ooo`03023/1`3oool0oooo00D0oooo
00<08>`70?ooo`3oool00P0Pk0LQ0?ooo`030000003oool0oooo01l0oooo000N0?ooo`030000003o
ool0oooo01/0oooo00@08>`70?ooo`0Pk0L08>`70`3oool0100Pk0L0oooo0?ooo`3oool2023/1`03
0?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`050?ooo`T0
8>`700H0oooo023/1`3oool0oooo023/1`3oool7023/1`<0oooo00<08>`70?ooo`0Pk0L00`0Pk0L0
103oool08>`70?ooo`3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00P3oool2023/1`040?oo
o`0Pk0L08>`7023/1`80oooo1P0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`7
00@08>`700<0oooo023/1`0Pk0L00`0Pk0L0203oool08>`7023/1`3oool08>`70?ooo`0Pk0L00000
0`0Pk0L20?ooo`H08>`70P3oool3023/1`040?ooo`0Pk0L08>`7023/1`<0oooo00@08>`70?ooo`0P
k0L08>`7103oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool0oooo00808>`78@3oool00`00
0000oooo0?ooo`0O0?ooo`007P3oool00`000000oooo0?ooo`0K0?ooo`04023/1`3oool08>`7023/
1`<0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0
oooo00<0oooo00<08>`70?ooo`3oool01@3oool9023/1`060?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo
1`0Pk0L30?ooo`03023/1`3oool0oooo00<08>`700@0oooo023/1`3oool0oooo0P0Pk0L01@3oool0
8>`7023/1`3oool08>`70080oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`700@0oooo
023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700<08>`700P0
oooo023/1`0Pk0L0oooo023/1`3oool08>`7000000<08>`70P3oool6023/1`80oooo0`0Pk0L0103o
ool08>`7023/1`0Pk0L30?ooo`04023/1`3oool08>`7023/1`@0oooo00<08>`70?ooo`3oool01@3o
ool00`0Pk0L0oooo0?ooo`02023/1b40oooo00<000000?ooo`3oool07`3oool001h0oooo00<00000
0?ooo`3oool06`3oool0100Pk0L0oooo023/1`0Pk0L30?ooo`04023/1`3oool0oooo0?ooo`808>`7
00<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00D0oooo
2`0Pk0L20?ooo`03023/1`3oool08>`700H08>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`040?oo
o`0Pk0L0oooo0?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`020?ooo`808>`700@0oooo023/
1`0Pk0L08>`70P3oool6023/1`040?ooo`0Pk0L08>`70?ooo`808>`700D0oooo023/1`0Pk0L08>`7
0?ooo`02023/1`030?ooo`0Pk0L08>`700@08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L00000
00<08>`70P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo0`0Pk0L0103oool08>`7023/1`0P
k0L30?ooo`04023/1`3oool08>`7023/1`D0oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo
0?ooo`02023/1b40oooo00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06`3o
ool0100Pk0L0oooo023/1`0Pk0L30?ooo`04023/1`3oool0oooo0?ooo`808>`70P3oool0100Pk0L0
oooo0?ooo`0Pk0L50?ooo`03023/1`3oool0oooo00D0oooo2`0Pk0L20?ooo`03023/1`3oool08>`7
00H08>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700X0oooo
023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L20?ooo`H08>`700@0oooo023/
1`0Pk0L0oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L0100P
k0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`0000000`0Pk0L20?ooo`808>`700<0oooo023/1`0P
k0L00`3oool3023/1`040?ooo`0Pk0L08>`7023/1`<0oooo00@08>`70?ooo`0Pk0L08>`71@3oool0
0`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo00808>`78@3oool00`000000oooo0?ooo`0O
0?ooo`007P3oool00`000000oooo0?ooo`0K0?ooo`04023/1`3oool08>`7023/1`<0oooo00@08>`7
0?ooo`3oool0oooo0P0Pk0L20?ooo`04023/1`3oool0oooo023/1`D0oooo00<08>`70?ooo`3oool0
1@3oool;023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L30?ooo`03023/1`3oool0oooo00<08>`7
00@0oooo023/1`3oool0oooo0P0Pk0L02P3oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo023/
1`3oool3023/1`80oooo1P0Pk0L01@3oool08>`7023/1`3oool08>`70080oooo0`0Pk0L0103oool0
8>`7023/1`3oool6023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`700000003023/1`80oooo0P0P
k0L00`3oool08>`7023/1`030?ooo`<08>`700@0oooo023/1`0Pk0L08>`70`3oool0100Pk0L0oooo
023/1`0Pk0L50?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3oool00P0Pk0LQ0?ooo`03
0000003oool0oooo01l0oooo000N0?ooo`030000003oool0oooo01/0oooo00D08>`70?ooo`0Pk0L0
oooo023/1`020?ooo`04023/1`3oool0oooo0?ooo`808>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L5
0?ooo`03023/1`3oool0oooo00D0oooo1`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`03023/1`3o
ool08>`700H08>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`040?ooo`0Pk0L0oooo0?ooo`808>`7
00X0oooo023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L20?ooo`H08>`700D0
oooo023/1`0Pk0L0oooo023/1`020?ooo`<08>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L01`3oool0
8>`70?ooo`0Pk0L0oooo023/1`0000000`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70`3o
ool3023/1`040?ooo`0Pk0L08>`7023/1`<0oooo00@08>`70?ooo`0Pk0L08>`71@3oool00`0Pk0L0
oooo0?ooo`040?ooo`03023/1`3oool0oooo00808>`78@3oool00`000000oooo0?ooo`0O0?ooo`00
7P3oool00`000000oooo0?ooo`0K0?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3oool0100Pk0L0
oooo0?ooo`3oool3023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`05
0?ooo`L08>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`07023/1`80oooo00<0
8>`70?ooo`3oool00`0Pk0L0103oool08>`70?ooo`3oool2023/1`0:0?ooo`0Pk0L08>`70?ooo`0P
k0L0oooo023/1`3oool08>`70?ooo`<08>`70P3oool6023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L0
0P3oool3023/1`040?ooo`0Pk0L08>`70?ooo`H08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0
000000<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`<0oooo0`0Pk0L0103oool08>`7023/
1`0Pk0L30?ooo`04023/1`3oool08>`7023/1`D0oooo00<08>`70?ooo`3oool0103oool0100Pk0L0
oooo0?ooo`0Pk0LR0?ooo`030000003oool0oooo01l0oooo000N0?ooo`030000003oool0oooo01/0
oooo00D08>`70?ooo`0Pk0L0oooo023/1`020?ooo`04023/1`3oool0oooo0?ooo`<08>`700D0oooo
023/1`3oool0oooo023/1`050?ooo`03023/1`3oool0oooo00D0oooo1`0Pk0L0103oool08>`7023/
1`0Pk0L20?ooo`03023/1`3oool08>`700L08>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`040?oo
o`0Pk0L0oooo0?ooo`808>`700X0oooo023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo
0`0Pk0L20?ooo`H08>`700D0oooo023/1`0Pk0L0oooo023/1`020?ooo`<08>`700@0oooo023/1`0P
k0L0oooo1P0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`0000000`0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00808>`70`3oool3023/1`040?ooo`0Pk0L08>`7023/1`<0oooo00@08>`70?ooo`0P
k0L08>`71@3oool00`0Pk0L0oooo0?ooo`040?ooo`04023/1`3oool08>`7023/1b80oooo00<00000
0?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06`3oool01@0Pk0L0oooo023/1`3oool0
8>`70080oooo00@08>`70?ooo`3oool0oooo0`0Pk0L01@3oool08>`70?ooo`3oool08>`700D0oooo
00<08>`70?ooo`3oool01@3oool7023/1`040?ooo`0Pk0L08>`7023/1`80oooo00<08>`70?ooo`0P
k0L01`0Pk0L20?ooo`03023/1`3oool0oooo00<08>`700@0oooo023/1`3oool0oooo0P0Pk0L02P3o
ool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`80oooo1P0Pk0L00`3oool0
8>`7023/1`02023/1`80oooo0`0Pk0L0103oool08>`7023/1`3oool6023/1`070?ooo`0Pk0L0oooo
023/1`3oool08>`700000003023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L30?ooo`<08>`7
00@0oooo023/1`0Pk0L08>`70`3oool0100Pk0L0oooo023/1`0Pk0L50?ooo`03023/1`3oool0oooo
00@0oooo00@08>`70?ooo`0Pk0L08>`78P3oool00`000000oooo0?ooo`0O0?ooo`007P3oool00`00
0000oooo0?ooo`0K0?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`3o
ool3023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`050?ooo`L08>`7
00@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`07023/1`80oooo00<08>`70?ooo`3o
ool00`0Pk0L0103oool08>`70?ooo`3oool5023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?oo
o`03023/1`80oooo1P0Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L0103oool08>`7023/
1`3oool7023/1`80oooo00@08>`70?ooo`0Pk0L000000`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00808>`70`3oool3023/1`040?ooo`0Pk0L08>`7023/1`<0oooo00@08>`70?ooo`0Pk0L08>`71P3o
ool00`0Pk0L0oooo0?ooo`030?ooo`04023/1`3oool08>`7023/1b80oooo00<000000?ooo`3oool0
7`3oool001h0oooo00<000000?ooo`3oool06`3oool01@0Pk0L0oooo023/1`3oool08>`70080oooo
00<08>`70?ooo`3oool00P3oool2023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L01@3oool00`0Pk0L0
oooo0?ooo`050?ooo`L08>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`07023/
1`80oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`70?ooo`3oool5023/1`070?ooo`0Pk0L0
oooo023/1`3oool08>`70?ooo`03023/1`80oooo1P0Pk0L00`3oool08>`7023/1`02023/1`80oooo
0`0Pk0L0103oool08>`7023/1`3oool7023/1`80oooo00@08>`70?ooo`0Pk0L000000`0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00808>`70`3oool3023/1`030?ooo`0Pk0L08>`700@0oooo00@08>`7
0?ooo`0Pk0L08>`71P3oool00`0Pk0L0oooo0?ooo`030?ooo`04023/1`3oool08>`7023/1b80oooo
00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06`3oool01@0Pk0L0oooo023/
1`3oool08>`70080oooo00<08>`70?ooo`3oool00P3oool2023/1`050?ooo`0Pk0L0oooo0?ooo`0P
k0L01@3oool00`0Pk0L0oooo0?ooo`050?ooo`L08>`700@0oooo023/1`0Pk0L08>`70P3oool00`0P
k0L0oooo023/1`07023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`70?ooo`3oool5
023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`03023/1`80oooo1P0Pk0L00`3oool08>`7
023/1`02023/1`80oooo0`0Pk0L0103oool08>`7023/1`3oool7023/1`80oooo00@08>`70?ooo`0P
k0L000000`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70`3oool3023/1`030?ooo`0Pk0L0
8>`700@0oooo00@08>`70?ooo`0Pk0L08>`71P3oool00`0Pk0L0oooo0?ooo`030?ooo`04023/1`3o
ool08>`7023/1b80oooo00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06`3o
ool01@0Pk0L0oooo023/1`3oool08>`70080oooo00<08>`70?ooo`3oool00P3oool2023/1`050?oo
o`0Pk0L0oooo0?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`050?ooo`L08>`700@0oooo023/1`0P
k0L08>`70P3oool00`0Pk0L0oooo023/1`07023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L0103o
ool08>`70?ooo`3oool5023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`03023/1`80oooo
1P0Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L0103oool08>`7023/1`3oool7023/1`80
oooo00@08>`70?ooo`0Pk0L000000`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70`3oool3
023/1`030?ooo`0Pk0L08>`700@0oooo00@08>`70?ooo`0Pk0L08>`71P3oool00`0Pk0L0oooo0?oo
o`030?ooo`04023/1`3oool08>`7023/1b80oooo00<000000?ooo`3oool07`3oool001h0oooo00<0
00000?ooo`3oool06`3oool01@0Pk0L0oooo023/1`3oool08>`70080oooo00<08>`70?ooo`3oool0
0P3oool2023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`050?ooo`L0
8>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`07023/1`80oooo00<08>`70?oo
o`3oool00`0Pk0L0103oool08>`70?ooo`3oool5023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`7
0?ooo`03023/1`80oooo1P0Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L0103oool08>`7
023/1`3oool7023/1`80oooo00@08>`70?ooo`0Pk0L000000`0Pk0L01@3oool08>`7023/1`0Pk0L0
oooo00808>`70`3oool3023/1`030?ooo`0Pk0L08>`700@0oooo00@08>`70?ooo`0Pk0L08>`71P3o
ool00`0Pk0L0oooo0?ooo`030?ooo`04023/1`3oool08>`7023/1b80oooo00<000000?ooo`3oool0
7`3oool001h0oooo00<000000?ooo`3oool06`3oool01@0Pk0L0oooo023/1`3oool08>`70080oooo
00<08>`70?ooo`3oool00P3oool2023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L01@3oool00`0Pk0L0
oooo0?ooo`050?ooo`L08>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo023/1`07023/
1`80oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`70?ooo`3oool5023/1`070?ooo`0Pk0L0
oooo023/1`3oool08>`70?ooo`03023/1`80oooo1P0Pk0L00`3oool08>`7023/1`02023/1`80oooo
0`0Pk0L0103oool08>`7023/1`3oool7023/1`80oooo00@08>`70?ooo`0Pk0L000000`0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00808>`70`3oool3023/1`030?ooo`0Pk0L08>`700@0oooo00@08>`7
0?ooo`0Pk0L08>`71P3oool00`0Pk0L0oooo0?ooo`030?ooo`04023/1`3oool08>`7023/1b80oooo
00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06`3oool01@0Pk0L0oooo023/
1`3oool08>`700<0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`7
00D0oooo00<08>`70?ooo`3oool01@3oool7023/1`040?ooo`0Pk0L0oooo023/1`80oooo00<08>`7
0?ooo`0Pk0L01`0Pk0L20?ooo`03023/1`3oool0oooo00<08>`700@0oooo023/1`3oool0oooo1@0P
k0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L20?ooo`H08>`700<0oooo023/1`0P
k0L00P0Pk0L20?ooo`<08>`700@0oooo023/1`0Pk0L0oooo1`0Pk0L20?ooo`05023/1`3oool08>`7
0000003oool00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70`3oool4023/1`030?ooo`0P
k0L0oooo00<0oooo00<08>`70?ooo`0Pk0L01`3oool00`0Pk0L0oooo0?ooo`030?ooo`04023/1`3o
ool08>`7023/1b80oooo00<000000?ooo`3oool07`3oool001h0oooo00<000000?ooo`3oool06`3o
ool01@0Pk0L0oooo023/1`3oool08>`700<0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool0
8>`70?ooo`3oool08>`700D0oooo00<08>`70?ooo`3oool01@3oool7023/1`040?ooo`0Pk0L0oooo
023/1`80oooo00<08>`70?ooo`0Pk0L01`0Pk0L20?ooo`03023/1`3oool0oooo00<08>`700@0oooo
023/1`3oool0oooo1@0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L20?ooo`H0
8>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`700@0oooo023/1`0Pk0L0oooo1`0Pk0L20?oo
o`05023/1`3oool08>`70000003oool00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70`3o
ool4023/1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`0Pk0L01`3oool00`0Pk0L0oooo0?oo
o`030?ooo`04023/1`3oool08>`7023/1b80oooo00<000000?ooo`3oool07`3oool001h0oooo00<0
00000?ooo`3oool06`3oool01@0Pk0L0oooo023/1`3oool08>`700<0oooo00@08>`70?ooo`3oool0
oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`700D0oooo00<08>`70?ooo`3oool01@3oool7023/
1`040?ooo`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`0Pk0L01`0Pk0L20?ooo`03023/1`3oool0
oooo00<08>`700@0oooo023/1`3oool0oooo1@0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3o
ool00`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`700@0oooo023/1`0P
k0L0oooo1`0Pk0L01`3oool08>`70?ooo`3oool08>`70000003oool00P0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00808>`70`3oool4023/1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`0Pk0L0
203oool00`0Pk0L0oooo0?ooo`020?ooo`04023/1`3oool08>`7023/1b80oooo00<000000?ooo`3o
ool07`3oool001d0oooo00<000000?ooo`3oool0703oool01@0Pk0L0oooo023/1`3oool08>`700<0
oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`700D0oooo00<08>`7
0?ooo`3oool01@3oool7023/1`040?ooo`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`0Pk0L00P0P
k0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`70?oo
o`3oool5023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`03023/1`80oooo1P0Pk0L00`3o
ool08>`7023/1`02023/1`80oooo0`0Pk0L0103oool08>`7023/1`3oool7023/1`070?ooo`0Pk0L0
oooo0?ooo`0Pk0L000000?ooo`02023/1`030?ooo`0Pk0L08>`700@08>`70`3oool4023/1`030?oo
o`0Pk0L0oooo00<0oooo00<08>`70?ooo`0Pk0L0203oool01@0Pk0L0oooo0?ooo`3oool08>`70080
oooo0P0Pk0LR0?ooo`030000003oool0oooo01l0oooo000M0?ooo`030000003oool0oooo01`0oooo
00D08>`70?ooo`0Pk0L0oooo023/1`030?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo023/
1`3oool0oooo023/1`050?ooo`03023/1`3oool0oooo00D0oooo1`0Pk0L0103oool08>`70?ooo`0P
k0L20?ooo`03023/1`3oool08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3o
ool0oooo00<08>`700@0oooo023/1`3oool0oooo0P0Pk0L02P3oool08>`7023/1`3oool08>`70?oo
o`0Pk0L0oooo023/1`3oool3023/1`80oooo1P0Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0P
k0L0103oool08>`7023/1`3oool7023/1`0<0?ooo`0Pk0L0oooo0?ooo`0Pk0L00000023/1`3oool0
8>`70?ooo`0Pk0L0oooo100Pk0L30?ooo`H08>`7103oool00`0Pk0L0oooo023/1`080?ooo`05023/
1`3oool0oooo0?ooo`0Pk0L00P3oool2023/1b80oooo00<000000?ooo`3oool07`3oool001d0oooo
00<000000?ooo`3oool0703oool01@0Pk0L0oooo023/1`3oool08>`700<0oooo00@08>`70?ooo`3o
ool0oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`700D0oooo00<08>`70?ooo`3oool01@3oool7
023/1`040?ooo`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`7023/
1`02023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`70?ooo`3oool2023/1`0:0?oo
o`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`70P3oool6023/1`030?ooo`0P
k0L08>`700808>`70P3oool3023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700`0oooo023/1`3oool0
8>`70?ooo`0000008>`70?ooo`0Pk0L0oooo023/1`3oool4023/1`80oooo00<08>`70?ooo`0Pk0L0
100Pk0L40?ooo`03023/1`3oool08>`700P0oooo00D08>`70?ooo`3oool0oooo023/1`020?ooo`80
8>`78P3oool00`000000oooo0?ooo`0O0?ooo`007@3oool00`000000oooo0?ooo`0L0?ooo`05023/
1`3oool08>`70?ooo`0Pk0L00`3oool0100Pk0L0oooo0?ooo`3oool2023/1`050?ooo`0Pk0L0oooo
0?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`050?ooo`L08>`700@0oooo023/1`3oool08>`70P3o
ool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?oo
o`03023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700X0oooo023/1`0Pk0L0oooo023/1`3oool08>`7
0?ooo`0Pk0L0oooo0`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`700@0
oooo023/1`0Pk0L0oooo1P0Pk0L20?ooo`09023/1`3oool08>`70?ooo`0000008>`70?ooo`0Pk0L0
oooo00H08>`70P3oool00`0Pk0L0oooo023/1`04023/1`@0oooo00<08>`70?ooo`0Pk0L0203oool0
1@0Pk0L0oooo0?ooo`3oool08>`70080oooo0P0Pk0LR0?ooo`030000003oool0oooo01l0oooo000M
0?ooo`030000003oool0oooo01`0oooo00D08>`70?ooo`0Pk0L0oooo023/1`030?ooo`04023/1`3o
ool0oooo0?ooo`808>`700D0oooo023/1`3oool0oooo023/1`050?ooo`03023/1`3oool0oooo00D0
oooo1`0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`03023/1`3oool08>`700808>`700<0oooo023/
1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00<08>`700@0oooo023/1`3oool0oooo0P0Pk0L0
2P3oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`80oooo1P0Pk0L00`3o
ool08>`7023/1`02023/1`80oooo0`0Pk0L0103oool08>`7023/1`3oool6023/1`80oooo00T08>`7
0?ooo`0Pk0L0oooo0000000Pk0L0oooo023/1`3oool01P0Pk0L20?ooo`03023/1`3oool08>`700@0
8>`7103oool00`0Pk0L0oooo023/1`080?ooo`05023/1`3oool0oooo0?ooo`0Pk0L00P3oool2023/
1b80oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3oool0703oool01@0Pk0L0
oooo023/1`3oool08>`700<0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`70?ooo`3o
ool08>`700D0oooo00<08>`70?ooo`3oool01@3oool7023/1`040?ooo`0Pk0L0oooo023/1`80oooo
00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool0
0`0Pk0L0103oool08>`70?ooo`3oool2023/1`0:0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3o
ool08>`70?ooo`<08>`70P3oool6023/1`030?ooo`0Pk0L08>`700808>`70P3oool3023/1`040?oo
o`0Pk0L08>`70?ooo`H08>`70P3oool01@0Pk0L0oooo023/1`3oool0000000<08>`700<0oooo023/
1`0Pk0L0100Pk0L20?ooo`04023/1`3oool08>`70?ooo`808>`71@3oool00`0Pk0L0oooo023/1`08
0?ooo`05023/1`3oool0oooo0?ooo`0Pk0L00P3oool2023/1b80oooo00<000000?ooo`3oool07`3o
ool001d0oooo00<000000?ooo`3oool07@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00@08>`7
0?ooo`3oool0oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`700D0oooo00<08>`70?ooo`3oool0
1@3oool7023/1`040?ooo`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool0
8>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`70?ooo`3oool2023/
1`0:0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`70P3oool6023/1`03
0?ooo`0Pk0L08>`700808>`70P3oool3023/1`040?ooo`0Pk0L08>`70?ooo`H08>`70P3oool01@0P
k0L0oooo023/1`3oool0000000<08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`04023/1`3oool0
8>`70?ooo`808>`7103oool0100Pk0L0oooo0?ooo`0Pk0L90?ooo`04023/1`3oool0oooo023/1`80
oooo0P0Pk0LR0?ooo`030000003oool0oooo01l0oooo000M0?ooo`030000003oool0oooo01d0oooo
0P0Pk0L00`3oool08>`70?ooo`020?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo023/1`3o
ool0oooo023/1`050?ooo`03023/1`3oool0oooo00D0oooo100Pk0L01`3oool08>`7023/1`3oool0
8>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L08>`700808>`70P3o
ool00`0Pk0L0oooo0?ooo`03023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700X0oooo023/1`0Pk0L0
oooo023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00P0P
k0L20?ooo`<08>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`00
00000P0Pk0L20?ooo`H08>`70P3oool0100Pk0L0oooo023/1`3oool2023/1`@0oooo00@08>`70?oo
o`3oool08>`72@3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo0240oooo00<0
00000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3oool07@3oool2023/1`030?ooo`0Pk0L0
oooo0080oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`700D0oooo
00<08>`70?ooo`3oool01@3oool4023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L00`3o
ool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`03023/
1`040?ooo`0Pk0L0oooo0?ooo`808>`700X0oooo023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`0P
k0L0oooo0`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`700@0oooo023/
1`0Pk0L0oooo1P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0000000P0Pk0L20?ooo`H08>`70P3o
ool0100Pk0L0oooo023/1`3oool2023/1`@0oooo00@08>`70?ooo`3oool08>`72@3oool0100Pk0L0
oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo0240oooo00<000000?ooo`3oool07`3oool001d0
oooo00<000000?ooo`3oool07@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00@08>`70?ooo`3o
ool0oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`700D0oooo00<08>`70?ooo`3oool01@3oool4
023/1`030?ooo`0Pk0L0oooo00808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool3023/1`030?oo
o`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`040?ooo`0Pk0L0oooo0?ooo`80
8>`700X0oooo023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L20?ooo`H08>`7
00<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L20?ooo`05
023/1`3oool08>`70?ooo`0000000P0Pk0L20?ooo`H08>`70P3oool3023/1`030?ooo`0Pk0L08>`7
00@0oooo00@08>`70?ooo`3oool08>`72@3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3o
ool0oooo0240oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3oool07@3oool2
023/1`030?ooo`0Pk0L0oooo0080oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`70?oo
o`3oool08>`700D0oooo00<08>`70?ooo`3oool01@3oool4023/1`030?ooo`0Pk0L0oooo00808>`7
00H0oooo023/1`0Pk0L0oooo023/1`3oool3023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0P
k0L0oooo0?ooo`03023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700d0oooo023/1`0Pk0L0oooo023/
1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70080oooo1P0Pk0L00`3oool08>`7023/1`02
023/1`80oooo0`0Pk0L0103oool08>`7023/1`3oool6023/1`80oooo00D08>`70?ooo`0Pk0L0oooo
00000002023/1`80oooo1P0Pk0L20?ooo`<08>`700@0oooo023/1`00000000000`3oool0100Pk0L0
oooo0?ooo`0Pk0L90?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool08@3oool0
0`000000oooo0?ooo`0O0?ooo`007@3oool00`000000oooo0?ooo`0M0?ooo`808>`700<0oooo023/
1`3oool00P3oool0100Pk0L0oooo0?ooo`3oool2023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L01@3o
ool00`0Pk0L0oooo0?ooo`050?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L01P3oool08>`7023/
1`3oool08>`70?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00<0
8>`700@0oooo023/1`3oool0oooo0P0Pk0L03@3oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo
023/1`3oool08>`70?ooo`0Pk0L00P3oool6023/1`030?ooo`0Pk0L08>`700808>`70P3oool3023/
1`040?ooo`0Pk0L08>`70?ooo`H08>`70P3oool01@0Pk0L0oooo023/1`3oool0000000808>`70P3o
ool6023/1`80oooo0`0Pk0L0103oool08>`70000000000030?ooo`04023/1`3oool0oooo023/1`T0
oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`0Q0?ooo`030000003oool0oooo
01l0oooo000M0?ooo`030000003oool0oooo01d0oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`04
023/1`3oool0oooo0?ooo`808>`700D0oooo023/1`3oool0oooo023/1`050?ooo`03023/1`3oool0
oooo00D0oooo100Pk0L00`3oool08>`70?ooo`02023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo
0`0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`7
0?ooo`3oool2023/1`0=0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L0
oooo023/1`020?ooo`H08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`700@0oooo023/1`0P
k0L0oooo100Pk0L02@3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo00000002023/1`80oooo
1P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0103oool0100Pk0L0oooo0?ooo`0Pk0L90?ooo`04
023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool08@3oool00`000000oooo0?ooo`0O0?oo
o`007@3oool00`000000oooo0?ooo`0M0?ooo`808>`700<0oooo023/1`3oool00P3oool0100Pk0L0
oooo0?ooo`3oool2023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`05
0?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`<08>`7
00<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00<08>`700@0oooo023/1`3oool0
oooo0P0Pk0L03@3oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0P
k0L00P3oool6023/1`030?ooo`0Pk0L08>`700808>`70P3oool3023/1`040?ooo`0Pk0L08>`70?oo
o`@08>`700T0oooo023/1`3oool0oooo023/1`3oool08>`70?ooo`0000000P0Pk0L20?ooo`H08>`7
0P3oool3023/1`030?ooo`0Pk0L08>`700@0oooo00@08>`70?ooo`3oool08>`72P3oool00`0Pk0L0
oooo023/1`020?ooo`03023/1`3oool0oooo0240oooo00<000000?ooo`3oool07`3oool001d0oooo
00<000000?ooo`3oool07@3oool2023/1`80oooo00@08>`70?ooo`3oool08>`70`3oool2023/1`05
0?ooo`0Pk0L0oooo0?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`050?ooo`@08>`700<0oooo023/
1`3oool00P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`<08>`700<0oooo023/1`0Pk0L00P0P
k0L20?ooo`03023/1`3oool0oooo00<08>`700@0oooo023/1`3oool0oooo0P0Pk0L03@3oool08>`7
023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L00P3oool6023/1`030?oo
o`0Pk0L08>`700808>`70P3oool3023/1`030?ooo`0Pk0L08>`700D08>`700T0oooo023/1`3oool0
oooo023/1`3oool08>`70?ooo`0000000P0Pk0L20?ooo`H08>`70P3oool3023/1`030?ooo`0Pk0L0
8>`700@0oooo00@08>`70?ooo`3oool08>`72P3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3o
ool0oooo0240oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3oool07@3oool2
023/1`80oooo00@08>`70?ooo`3oool08>`70`3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<0
8>`70?ooo`3oool00P3oool00`0Pk0L0oooo0?ooo`050?ooo`@08>`700<0oooo023/1`3oool00P0P
k0L01P3oool08>`7023/1`3oool08>`70?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03
023/1`3oool0oooo00<08>`700@0oooo023/1`3oool0oooo0P0Pk0L03@3oool08>`7023/1`3oool0
8>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L00P3oool6023/1`030?ooo`0Pk0L08>`7
00808>`70P3oool3023/1`030?ooo`0Pk0L08>`700D08>`700T0oooo023/1`3oool0oooo023/1`3o
ool08>`70?ooo`0000000P0Pk0L20?ooo`H08>`70P3oool3023/1`030?ooo`0Pk0L08>`700@0oooo
00@08>`70?ooo`0Pk0L08>`72P3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo0240
oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3oool07@3oool2023/1`80oooo
00@08>`70?ooo`3oool08>`70`3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3o
ool00P3oool00`0Pk0L0oooo0?ooo`050?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L01P3oool0
8>`7023/1`3oool08>`70?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0
oooo00<08>`700@0oooo023/1`3oool0oooo0P0Pk0L03@3oool08>`7023/1`3oool08>`70?ooo`0P
k0L0oooo023/1`3oool08>`70?ooo`0Pk0L00P3oool6023/1`030?ooo`0Pk0L08>`700808>`70P3o
ool3023/1`030?ooo`0Pk0L08>`700L08>`70P3oool01@0Pk0L0oooo023/1`3oool0000000808>`7
0P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo0`0Pk0L00`3oool08>`7023/1`040?ooo`04
023/1`3oool08>`7023/1`X0oooo00@08>`70?ooo`0Pk0L0oooo0P0Pk0LS0?ooo`030000003oool0
oooo01l0oooo000M0?ooo`030000003oool0oooo01d0oooo0P0Pk0L20?ooo`04023/1`3oool0oooo
023/1`<0oooo0P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo0080oooo00<08>`7
0?ooo`3oool01@3oool4023/1`030?ooo`0Pk0L0oooo00808>`700H0oooo023/1`0Pk0L0oooo023/
1`3oool3023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`040?oo
o`0Pk0L0oooo0?ooo`808>`700d0oooo023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo
023/1`3oool08>`70080oooo1P0Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L00`3oool0
8>`7023/1`07023/1`80oooo00D08>`70?ooo`0Pk0L0oooo00000002023/1`80oooo0P0Pk0L0103o
ool08>`7023/1`0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0103oool0100Pk0L0oooo023/1`0P
k0L:0?ooo`04023/1`3oool08>`70?ooo`808>`78`3oool00`000000oooo0?ooo`0O0?ooo`007@3o
ool00`000000oooo0?ooo`0M0?ooo`808>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`808>`7
00<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00D0oooo
100Pk0L00`3oool08>`70?ooo`02023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0`0Pk0L00`3o
ool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`70?ooo`3oool2
023/1`0=0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`02
0?ooo`H08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L01`0Pk0L2
0?ooo`05023/1`3oool08>`70?ooo`0000000P0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L08>`7
0P3oool3023/1`030?ooo`0Pk0L08>`700@0oooo00@08>`70?ooo`0Pk0L08>`72P3oool0100Pk0L0
oooo023/1`3oool2023/1b<0oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3o
ool07@3oool2023/1`80oooo00@08>`70?ooo`3oool08>`70`3oool2023/1`030?ooo`0Pk0L08>`7
0080oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo0?ooo`050?ooo`@08>`700<0oooo023/
1`3oool00P0Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L2
0?ooo`03023/1`3oool0oooo00<08>`700@0oooo023/1`3oool0oooo0P0Pk0L03@3oool08>`7023/
1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L00P3oool6023/1`030?ooo`0P
k0L08>`700808>`70P3oool3023/1`030?ooo`0Pk0L08>`700L08>`70P3oool01@0Pk0L0oooo023/
1`3oool0000000808>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo0`0Pk0L00`3oool0
8>`7023/1`040?ooo`04023/1`3oool08>`7023/1`X0oooo00@08>`70?ooo`0Pk0L0oooo0P0Pk0LS
0?ooo`030000003oool0oooo01l0oooo000M0?ooo`030000003oool0oooo01d0oooo0P0Pk0L20?oo
o`04023/1`3oool0oooo023/1`<0oooo0P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0
oooo0080oooo00<08>`70?ooo`3oool01@3oool4023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo
023/1`3oool00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool00`0Pk0L0oooo0?oo
o`03023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700d0oooo023/1`0Pk0L0oooo023/1`3oool08>`7
0?ooo`0Pk0L0oooo023/1`3oool08>`70080oooo1P0Pk0L00`3oool08>`7023/1`02023/1`80oooo
0`0Pk0L00`3oool08>`7023/1`07023/1`80oooo00D08>`70?ooo`0Pk0L0oooo00000002023/1`05
0?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0103oool0100P
k0L0oooo023/1`0Pk0L:0?ooo`04023/1`3oool08>`70?ooo`808>`78`3oool00`000000oooo0?oo
o`0O0?ooo`007@3oool00`000000oooo0?ooo`0M0?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3o
ool0100Pk0L0oooo0?ooo`3oool2023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool0
0P3oool00`0Pk0L0oooo0?ooo`050?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`7
023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L20?ooo`03023/1`3oool0oooo00<0
8>`700@0oooo023/1`3oool0oooo0P0Pk0L02P3oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo
023/1`3oool2023/1`<0oooo1P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`70080
8>`700<0oooo023/1`0Pk0L01`0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0000000P0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00<08>`70P3oool3023/1`030?ooo`0Pk0L08>`700@0oooo00<08>`7
0?ooo`0Pk0L0303oool2023/1`030?ooo`0Pk0L08>`702<0oooo00<000000?ooo`3oool07`3oool0
01d0oooo00<000000?ooo`3oool07@3oool01@0Pk0L0oooo023/1`3oool08>`70080oooo00@08>`7
0?ooo`3oool0oooo0P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo0080oooo00<0
8>`70?ooo`3oool01@3oool4023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00P0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`030?oo
o`0Pk0L0oooo00<08>`700X0oooo023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo0P0P
k0L30?ooo`H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0P
k0L08>`700L08>`70P3oool01@0Pk0L0oooo023/1`3oool0000000808>`700D0oooo023/1`0Pk0L0
8>`70?ooo`03023/1`80oooo0`0Pk0L00`3oool08>`7023/1`040?ooo`03023/1`3oool08>`700`0
oooo00<08>`70?ooo`3oool00P0Pk0LS0?ooo`030000003oool0oooo01l0oooo000M0?ooo`030000
003oool0oooo01d0oooo00D08>`70?ooo`0Pk0L0oooo023/1`020?ooo`04023/1`3oool0oooo0?oo
o`808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo
00D0oooo100Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/
1`0Pk0L08>`70?ooo`04023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`70?ooo`03
023/1`0:0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`808>`70`3oool6023/
1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`06023/
1`<0oooo00D08>`70?ooo`0Pk0L0oooo00000002023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0P
k0L20?ooo`<08>`700<0oooo023/1`0Pk0L0103oool00`0Pk0L0oooo023/1`0<0?ooo`03023/1`3o
ool0oooo00808>`78`3oool00`000000oooo0?ooo`0O0?ooo`007@3oool00`000000oooo0?ooo`0M
0?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`3oool2023/1`030?oo
o`0Pk0L08>`70080oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo0?ooo`050?ooo`@08>`7
00<0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3o
ool0100Pk0L20?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`3oool00`0Pk0L02P3oool0
8>`7023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool2023/1`<0oooo1P0Pk0L00`3oool08>`7
023/1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01P0Pk0L30?ooo`05023/
1`3oool08>`70?ooo`0000000P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70P3oool3023/
1`030?ooo`0Pk0L08>`700@0oooo00<08>`70?ooo`0Pk0L0303oool00`0Pk0L0oooo0?ooo`02023/
1b<0oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3oool07@3oool01@0Pk0L0
oooo023/1`3oool08>`70080oooo00@08>`70?ooo`3oool0oooo1@0Pk0L20?ooo`03023/1`3oool0
oooo0080oooo00<08>`70?ooo`3oool01@3oool01`0Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool0
0P0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L20?ooo`03
023/1`3oool0oooo00<08>`700<0oooo023/1`3oool00`0Pk0L02P3oool08>`7023/1`3oool08>`7
0?ooo`0Pk0L0oooo023/1`3oool2023/1`<0oooo1P0Pk0L00`3oool08>`7023/1`02023/1`030?oo
o`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01P0Pk0L30?ooo`05023/1`3oool08>`70?ooo`00
00000P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70P3oool3023/1`030?ooo`0Pk0L08>`7
00@0oooo00<08>`70?ooo`0Pk0L0303oool00`0Pk0L0oooo0?ooo`02023/1b<0oooo00<000000?oo
o`3oool07`3oool001d0oooo00<000000?ooo`3oool07@3oool01@0Pk0L0oooo023/1`3oool08>`7
0080oooo00@08>`70?ooo`3oool0oooo1@0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00<08>`7
0?ooo`3oool01@3oool01`0Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool00P0Pk0L00`3oool08>`7
023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L20?ooo`03023/1`3oool0oooo00<0
8>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`020?ooo`808>`700<0oooo023/1`3o
ool00P0Pk0L30?ooo`H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`03
0?ooo`0Pk0L08>`700H08>`70`3oool01@0Pk0L0oooo023/1`3oool0000000808>`700D0oooo023/
1`0Pk0L08>`70?ooo`03023/1`80oooo0`0Pk0L00`3oool08>`7023/1`040?ooo`03023/1`3oool0
8>`700`0oooo00@08>`70?ooo`3oool08>`7903oool00`000000oooo0?ooo`0O0?ooo`007@3oool0
0`000000oooo0?ooo`0M0?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?oo
o`3oool3023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`050?ooo`07
023/1`3oool08>`7023/1`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700808>`700D0oooo
023/1`0Pk0L08>`70?ooo`04023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`70?oo
o`03023/1`030?ooo`0Pk0L08>`70080oooo0P0Pk0L00`3oool08>`70?ooo`02023/1`<0oooo1P0P
k0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01P0P
k0L30?ooo`05023/1`3oool08>`70?ooo`0000000P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<0
8>`70P3oool3023/1`030?ooo`0Pk0L08>`700@0oooo00<08>`70?ooo`0Pk0L0303oool0100Pk0L0
oooo0?ooo`0Pk0LT0?ooo`030000003oool0oooo01l0oooo000M0?ooo`030000003oool0oooo01d0
oooo00D08>`70?ooo`0Pk0L0oooo023/1`020?ooo`04023/1`3oool0oooo0?ooo`<08>`700D0oooo
023/1`3oool0oooo023/1`040?ooo`03023/1`3oool0oooo00D0oooo00L08>`70?ooo`0Pk0L08>`7
0?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00@08>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/
1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L0oooo00808>`70`3oool6023/1`030?ooo`0Pk0L08>`7
00808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`06023/1`<0oooo00D08>`70?oo
o`0Pk0L0oooo00000002023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`<08>`700<0
oooo023/1`0Pk0L0103oool00`0Pk0L0oooo023/1`0<0?ooo`808>`700<0oooo023/1`3oool08`3o
ool00`000000oooo0?ooo`0O0?ooo`007@3oool00`000000oooo0?ooo`0M0?ooo`05023/1`3oool0
8>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`3oool3023/1`050?ooo`0Pk0L0oooo0?ooo`0P
k0L0103oool00`0Pk0L0oooo0?ooo`050?ooo`07023/1`3oool08>`7023/1`3oool08>`70?ooo`02
023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`80oooo00<0
8>`70?ooo`3oool00`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`70080oooo0P0P
k0L00`3oool08>`70?ooo`02023/1`<0oooo1P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0P
k0L08>`700808>`700<0oooo023/1`0Pk0L01P0Pk0L30?ooo`05023/1`3oool08>`7023/1`000000
0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70P3oool3023/1`030?ooo`0Pk0L08>`700@0
oooo00<08>`70?ooo`0Pk0L0303oool2023/1`030?ooo`0Pk0L0oooo02<0oooo00<000000?ooo`3o
ool07`3oool001d0oooo00<000000?ooo`3oool07@3oool01@0Pk0L0oooo023/1`3oool08>`70080
oooo00@08>`70?ooo`3oool0oooo0`0Pk0L01@3oool08>`70?ooo`3oool08>`700@0oooo00<08>`7
0?ooo`3oool01@3oool01`0Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool00P0Pk0L00`3oool08>`7
023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L20?ooo`03023/1`3oool0oooo00<0
8>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`020?ooo`808>`700<0oooo023/1`3o
ool00P0Pk0L30?ooo`H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`03
0?ooo`0Pk0L08>`700H08>`70`3oool01@0Pk0L0oooo023/1`0Pk0L0000000808>`700D0oooo023/
1`0Pk0L08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00`3oool0
100Pk0L0oooo0?ooo`0Pk0L<0?ooo`808>`700<0oooo023/1`3oool08`3oool00`000000oooo0?oo
o`0O0?ooo`007@3oool00`000000oooo0?ooo`0M0?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3o
ool0100Pk0L0oooo0?ooo`3oool3023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L0103oool00`0Pk0L0
oooo0?ooo`050?ooo`05023/1`3oool08>`7023/1`3oool0100Pk0L01P3oool08>`7023/1`3oool0
8>`70?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00<08>`700<0
oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`020?ooo`808>`700<0oooo023/1`3oool00P0P
k0L30?ooo`H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0P
k0L08>`700H08>`70`3oool01@0Pk0L0oooo023/1`0Pk0L0000000808>`700D0oooo023/1`0Pk0L0
8>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00`3oool0100Pk0L0
oooo0?ooo`0Pk0L<0?ooo`808>`700<0oooo023/1`3oool08`3oool00`000000oooo0?ooo`0O0?oo
o`007@3oool00`000000oooo0?ooo`0M0?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3oool0100P
k0L0oooo0?ooo`3oool3023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L0103oool00`0Pk0L0oooo0?oo
o`050?ooo`05023/1`3oool08>`7023/1`3oool01`0Pk0L00`3oool08>`70?ooo`03023/1`030?oo
o`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`80
8>`700<0oooo023/1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L0oooo00808>`70`3oool6023/1`03
0?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`06023/1`<0
oooo00D08>`70?ooo`0Pk0L08>`700000002023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L0
103oool08>`70?ooo`0Pk0L20?ooo`808>`70`3oool0100Pk0L0oooo0?ooo`0Pk0L<0?ooo`808>`7
00<0oooo023/1`3oool08`3oool00`000000oooo0?ooo`0O0?ooo`007@3oool00`000000oooo0?oo
o`0M0?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`3oool3023/1`05
0?ooo`0Pk0L0oooo0?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`050?ooo`05023/1`3oool08>`7
023/1`3oool01`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`70P3oool0
0`0Pk0L0oooo0?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L00P3o
ool2023/1`030?ooo`0Pk0L0oooo00808>`70`3oool6023/1`030?ooo`0Pk0L08>`700808>`700<0
oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`06023/1`<0oooo00D08>`70?ooo`0Pk0L08>`7
00000002023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L0103oool08>`70?ooo`0Pk0L20?oo
o`808>`70`3oool0100Pk0L0oooo0?ooo`0Pk0L<0?ooo`808>`700<0oooo023/1`3oool08`3oool0
0`000000oooo0?ooo`0O0?ooo`007@3oool00`000000oooo0?ooo`0M0?ooo`05023/1`3oool08>`7
0?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`3oool3023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L0
103oool00`0Pk0L0oooo0?ooo`050?ooo`05023/1`3oool08>`7023/1`3oool01`0Pk0L00`3oool0
8>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`04
0?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L0oooo
00808>`70`3oool2023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`7023/1`02
023/1`030?ooo`0Pk0L08>`700H08>`70`3oool01@0Pk0L0oooo023/1`0Pk0L0000000808>`700D0
oooo023/1`0Pk0L08>`70?ooo`03023/1`040?ooo`0Pk0L0oooo023/1`80oooo0P0Pk0L30?ooo`04
023/1`3oool0oooo023/1``0oooo0P0Pk0L00`3oool08>`70?ooo`0S0?ooo`030000003oool0oooo
01l0oooo000M0?ooo`030000003oool0oooo01d0oooo00D08>`70?ooo`0Pk0L0oooo023/1`020?oo
o`03023/1`3oool0oooo0080oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`700@0oooo0P0Pk0L6
0?ooo`05023/1`3oool08>`7023/1`3oool01`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0P
k0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`808>`7
00<0oooo023/1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L0oooo00808>`70`3oool6023/1`030?oo
o`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`06023/1`<0oooo
00D08>`70?ooo`0Pk0L08>`700000002023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L0203o
ool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70`3oool0100Pk0L0oooo0?ooo`0Pk0L<0?ooo`04
023/1`3oool08>`7023/1b@0oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3o
ool07@3oool01@0Pk0L0oooo023/1`3oool08>`700<0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L0
1@3oool08>`70?ooo`3oool08>`700@0oooo0P0Pk0L60?ooo`05023/1`3oool08>`7023/1`3oool0
1`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo
0?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L00P3oool3023/1`80
oooo0P0Pk0L30?ooo`H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`03
0?ooo`0Pk0L08>`700H08>`70`3oool01@0Pk0L0oooo023/1`0Pk0L0000000808>`700D0oooo023/
1`0Pk0L08>`70?ooo`03023/1`080?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L30?ooo`04
023/1`3oool0oooo023/1``0oooo00@08>`70?ooo`0Pk0L08>`7903oool00`000000oooo0?ooo`0O
0?ooo`007@3oool00`000000oooo0?ooo`0M0?ooo`05023/1`3oool08>`70?ooo`0Pk0L00`3oool0
100Pk0L0oooo0?ooo`3oool2023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L0103oool2023/1`H0oooo
00D08>`70?ooo`0Pk0L08>`70?ooo`07023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0P
k0L00P0Pk0L20?ooo`03023/1`3oool0oooo00<08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3o
ool08>`7023/1`020?ooo`<08>`70P3oool2023/1`<0oooo1P0Pk0L00`3oool08>`7023/1`02023/
1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`06023/1`3oool08>`7
0?ooo`0Pk0L000000P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`700P0oooo023/1`0Pk0L0
8>`70?ooo`0Pk0L0oooo023/1`<0oooo00@08>`70?ooo`3oool08>`7303oool0100Pk0L0oooo023/
1`0Pk0LT0?ooo`030000003oool0oooo01l0oooo000M0?ooo`030000003oool0oooo01d0oooo00D0
8>`70?ooo`0Pk0L0oooo023/1`030?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo023/1`3o
ool0oooo023/1`040?ooo`808>`71P3oool01@0Pk0L0oooo023/1`0Pk0L0oooo00L08>`700<0oooo
023/1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L0
103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`70080oooo0`0Pk0L20?ooo`808>`70`3o
ool6023/1`040?ooo`0Pk0L08>`7023/1`80oooo100Pk0L00`3oool08>`7023/1`06023/1`80oooo
00H08>`70?ooo`0Pk0L0oooo023/1`000002023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L0
203oool08>`7023/1`0Pk0L0oooo023/1`3oool08>`70`3oool0100Pk0L0oooo0?ooo`0Pk0L<0?oo
o`04023/1`3oool08>`7023/1b@0oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?oo
o`3oool07@3oool01@0Pk0L0oooo023/1`3oool08>`700<0oooo00@08>`70?ooo`3oool0oooo0P0P
k0L01@3oool08>`70?ooo`3oool08>`700@0oooo0P0Pk0L60?ooo`05023/1`3oool08>`7023/1`3o
ool01`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0
oooo0?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L00P3oool3023/
1`80oooo0P0Pk0L30?ooo`H08>`700@0oooo023/1`0Pk0L08>`70P3oool4023/1`030?ooo`0Pk0L0
8>`700H08>`70P3oool01P0Pk0L0oooo023/1`3oool08>`7000000808>`700D0oooo023/1`0Pk0L0
8>`70?ooo`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L40?ooo`04023/1`3oool0oooo
023/1``0oooo00@08>`70?ooo`0Pk0L08>`7903oool00`000000oooo0?ooo`0O0?ooo`007@3oool0
0`000000oooo0?ooo`0M0?ooo`03023/1`3oool08>`70080oooo00@08>`70?ooo`3oool08>`70`3o
ool2023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L0103oool2023/1`H0oooo00D08>`70?ooo`0Pk0L0
8>`70?ooo`07023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03
023/1`3oool0oooo00<08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`020?oo
o`<08>`70P3oool2023/1`<0oooo1P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`@08>`700<0oooo
023/1`0Pk0L01P0Pk0L20?ooo`06023/1`3oool08>`70?ooo`0Pk0L000000P0Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`@0oooo00@08>`70?oo
o`3oool08>`7303oool0100Pk0L0oooo023/1`0Pk0LT0?ooo`030000003oool0oooo01l0oooo000M
0?ooo`030000003oool0oooo01d0oooo00<08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`0P
k0L30?ooo`808>`700D0oooo023/1`3oool0oooo023/1`040?ooo`808>`71P3oool01@0Pk0L0oooo
023/1`0Pk0L0oooo00L08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`80
oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`7
0080oooo0`0Pk0L20?ooo`808>`70`3oool3023/1`040?ooo`0Pk0L08>`70?ooo`<08>`70P3oool4
023/1`030?ooo`0Pk0L08>`700H08>`70P3oool01P0Pk0L0oooo023/1`3oool08>`7000000808>`7
00D0oooo023/1`0Pk0L08>`70?ooo`02023/1`80oooo0`0Pk0L00`3oool08>`7023/1`040?ooo`04
023/1`3oool0oooo023/1``0oooo00@08>`70?ooo`0Pk0L08>`7903oool00`000000oooo0?ooo`0O
0?ooo`007@3oool00`000000oooo0?ooo`0M0?ooo`03023/1`3oool08>`70080oooo00@08>`70?oo
o`3oool08>`70`3oool2023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L0103oool2023/1`L0oooo0`0P
k0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00P0P
k0L20?ooo`03023/1`3oool0oooo00<08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7
023/1`020?ooo`<08>`70P3oool2023/1`<0oooo0`0Pk0L0103oool08>`7023/1`3oool3023/1`80
oooo100Pk0L00`3oool08>`70?ooo`06023/1`80oooo00H08>`70?ooo`0Pk0L0oooo023/1`000002
023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0103o
ool0100Pk0L0oooo0?ooo`0Pk0L<0?ooo`04023/1`3oool08>`7023/1b@0oooo00<000000?ooo`3o
ool07`3oool001d0oooo00<000000?ooo`3oool07@3oool00`0Pk0L0oooo023/1`020?ooo`04023/
1`3oool0oooo023/1`<0oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`700@0oooo0P0Pk0L70?oo
o`<08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`7
00808>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700<0oooo
023/1`0Pk0L00P3oool3023/1`80oooo0P0Pk0L30?ooo`<08>`700@0oooo023/1`0Pk0L0oooo0`0P
k0L20?ooo`@08>`700<0oooo023/1`3oool01P0Pk0L20?ooo`06023/1`3oool08>`70?ooo`0Pk0L0
00000P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70P3oool3023/1`030?ooo`0Pk0L08>`7
00@0oooo00@08>`70?ooo`3oool08>`72`3oool01@0Pk0L0oooo0?ooo`3oool08>`702@0oooo00<0
00000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3oool07@3oool00`0Pk0L0oooo023/1`02
0?ooo`04023/1`3oool0oooo023/1`<0oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`700@0oooo
0P0Pk0L70?ooo`<08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`03023/1`030?oo
o`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`040?ooo`0Pk0L0oooo0?ooo`80
8>`700<0oooo023/1`0Pk0L00P3oool3023/1`80oooo0P0Pk0L30?ooo`<08>`700@0oooo023/1`0P
k0L0oooo0`0Pk0L20?ooo`@08>`700<0oooo023/1`3oool01P0Pk0L20?ooo`06023/1`3oool08>`7
0?ooo`0Pk0L000000P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70P3oool3023/1`030?oo
o`0Pk0L08>`700@0oooo00@08>`70?ooo`3oool08>`72`3oool00`0Pk0L0oooo0?ooo`02023/1b@0
oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3oool07@3oool00`0Pk0L0oooo
023/1`020?ooo`04023/1`3oool0oooo023/1`<0oooo0P0Pk0L01@3oool08>`70?ooo`3oool08>`7
00@0oooo0P0Pk0L70?ooo`<08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`03023/
1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`040?ooo`0Pk0L0oooo
0?ooo`808>`700<0oooo023/1`0Pk0L00P3oool3023/1`80oooo0P0Pk0L30?ooo`H08>`700@0oooo
023/1`0Pk0L08>`70P3oool4023/1`030?ooo`0Pk0L0oooo00H08>`70P3oool01P0Pk0L0oooo023/
1`3oool08>`7000000808>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`80oooo0`0Pk0L00`3o
ool08>`7023/1`040?ooo`04023/1`3oool0oooo023/1`/0oooo00<08>`70?ooo`3oool00P0Pk0LT
0?ooo`030000003oool0oooo01l0oooo000M0?ooo`030000003oool0oooo01d0oooo00<08>`70?oo
o`0Pk0L00P3oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`808>`700D0oooo023/1`3oool0oooo023/
1`040?ooo`808>`71`3oool3023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L00`0P
k0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L0103oool08>`70?oo
o`3oool2023/1`030?ooo`0Pk0L08>`70080oooo0`0Pk0L20?ooo`808>`70`3oool6023/1`040?oo
o`0Pk0L08>`7023/1`80oooo100Pk0L00`3oool08>`70?ooo`06023/1`80oooo00H08>`70?ooo`0P
k0L0oooo023/1`000002023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L20?ooo`<08>`700<0
oooo023/1`0Pk0L0103oool0100Pk0L0oooo023/1`0Pk0L;0?ooo`03023/1`3oool0oooo00808>`7
903oool00`000000oooo0?ooo`0O0?ooo`007@3oool00`000000oooo0?ooo`0M0?ooo`03023/1`3o
ool08>`70080oooo00@08>`70?ooo`3oool08>`70`3oool2023/1`050?ooo`0Pk0L0oooo0?ooo`0P
k0L0103oool2023/1`L0oooo0`0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700<0
8>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00D08>`70P3oool2023/1`03
0?ooo`0Pk0L08>`70080oooo0`0Pk0L20?ooo`808>`70`3oool6023/1`040?ooo`0Pk0L08>`7023/
1`80oooo1P0Pk0L00`3oool08>`7023/1`04023/1`80oooo00H08>`70?ooo`0Pk0L0oooo023/1`00
0002023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0
103oool0100Pk0L0oooo023/1`0Pk0L;0?ooo`03023/1`3oool0oooo00808>`7903oool00`000000
oooo0?ooo`0O0?ooo`007@3oool00`000000oooo0?ooo`0N0?ooo`808>`70P3oool0100Pk0L0oooo
0?ooo`0Pk0L30?ooo`808>`700D0oooo023/1`3oool0oooo023/1`040?ooo`808>`71`3oool3023/
1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`02023/
1`80oooo00<08>`70?ooo`3oool01@0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00P3oool3023/
1`80oooo0P0Pk0L30?ooo`H08>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L0
8>`700@08>`70P3oool01P0Pk0L0oooo023/1`3oool08>`7000000808>`700<0oooo023/1`0Pk0L0
100Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0103oool0100Pk0L0oooo023/1`0Pk0L;0?ooo`03
023/1`3oool0oooo00808>`7903oool00`000000oooo0?ooo`0O0?ooo`007@3oool00`000000oooo
0?ooo`0N0?ooo`808>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`808>`700D0oooo023/1`0P
k0L0oooo023/1`040?ooo`808>`71`3oool3023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/
1`0Pk0L00`0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool01@0Pk0L20?oo
o`808>`700<0oooo023/1`0Pk0L00P3oool3023/1`80oooo0P0Pk0L30?ooo`H08>`700@0oooo023/
1`3oool08>`70P3oool6023/1`030?ooo`0Pk0L08>`700@08>`70P3oool01P0Pk0L0oooo023/1`3o
ool08>`7000000808>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L20?ooo`<08>`700<0oooo023/1`0P
k0L0103oool0100Pk0L0oooo023/1`0Pk0L;0?ooo`03023/1`3oool0oooo00808>`7903oool00`00
0000oooo0?ooo`0O0?ooo`007@3oool00`000000oooo0?ooo`0N0?ooo`808>`70P3oool0100Pk0L0
oooo0?ooo`0Pk0L30?ooo`808>`700<0oooo023/1`0Pk0L00P3oool0100Pk0L0oooo0?ooo`3oool2
023/1`L0oooo0`0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo
023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00D08>`70P3oool2023/1`030?ooo`0Pk0L0
8>`70080oooo0`0Pk0L20?ooo`808>`70`3oool6023/1`040?ooo`0Pk0L0oooo023/1`80oooo1P0P
k0L00`3oool08>`7023/1`04023/1`80oooo00H08>`70?ooo`0Pk0L0oooo023/1`000002023/1`04
0?ooo`0Pk0L08>`70?ooo`<08>`70P3oool3023/1`030?ooo`0Pk0L08>`700@0oooo00@08>`70?oo
o`0Pk0L08>`72`3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1b<0oooo00<000000?ooo`3oool0
7`3oool001d0oooo00<000000?ooo`3oool07P3oool2023/1`80oooo00@08>`70?ooo`3oool08>`7
0`3oool2023/1`030?ooo`0Pk0L08>`70080oooo00@08>`70?ooo`3oool0oooo0P0Pk0L70?ooo`<0
8>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`70080
8>`70P3oool00`0Pk0L0oooo0?ooo`05023/1`80oooo0P0Pk0L00`3oool08>`7023/1`020?ooo`<0
8>`70P3oool2023/1`<0oooo1P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`700@0oooo023/
1`0Pk0L0oooo0`0Pk0L20?ooo`06023/1`3oool08>`70?ooo`0Pk0L000001@0Pk0L0103oool08>`7
0?ooo`0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0103oool00`0Pk0L0oooo023/1`0<0?ooo`06
023/1`3oool0oooo023/1`3oool08>`78`3oool00`000000oooo0?ooo`0O0?ooo`007@3oool00`00
0000oooo0?ooo`0N0?ooo`808>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`808>`700<0oooo
023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00D0oooo0`0Pk0L0
0`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P0Pk0L2
0?ooo`03023/1`3oool0oooo00D08>`70P3oool2023/1`030?ooo`0Pk0L0oooo0080oooo0`0Pk0L2
0?ooo`808>`70`3oool6023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L0103oool08>`7023/
1`3oool3023/1`80oooo00H08>`70?ooo`0Pk0L0oooo023/1`000005023/1`040?ooo`0Pk0L0oooo
023/1`80oooo0`0Pk0L00`3oool08>`7023/1`040?ooo`03023/1`3oool08>`700`0oooo00H08>`7
0?ooo`3oool08>`70?ooo`0Pk0LS0?ooo`030000003oool0oooo01l0oooo000M0?ooo`030000003o
ool0oooo01h0oooo0P0Pk0L20?ooo`04023/1`3oool0oooo023/1`<0oooo0P0Pk0L00`3oool08>`7
023/1`020?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`3oool01@3oool3023/1`030?oo
o`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`02023/1`80oooo
00<08>`70?ooo`3oool01@0Pk0L20?ooo`808>`700<0oooo023/1`3oool00P3oool3023/1`80oooo
0P0Pk0L30?ooo`H08>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L08>`700@0
8>`70P3oool01P0Pk0L0oooo023/1`3oool08>`7000000D08>`700@0oooo023/1`3oool08>`70P3o
ool3023/1`030?ooo`0Pk0L08>`700@0oooo00<08>`70?ooo`0Pk0L0303oool01P0Pk0L0oooo0?oo
o`0Pk0L0oooo023/1b<0oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3oool0
7P3oool2023/1`80oooo00@08>`70?ooo`3oool08>`70`3oool2023/1`030?ooo`0Pk0L08>`70080
oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo0?ooo`050?ooo`<08>`700<0oooo023/1`0P
k0L01@0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0
oooo0?ooo`05023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`<08>`70P3oool2023/1`<0
oooo1P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L20?oo
o`06023/1`3oool08>`70?ooo`0Pk0L000001@0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`<08>`7
00<0oooo023/1`0Pk0L0103oool00`0Pk0L0oooo023/1`0<0?ooo`06023/1`3oool0oooo023/1`3o
ool08>`78`3oool00`000000oooo0?ooo`0O0?ooo`007@3oool00`000000oooo0?ooo`0N0?ooo`80
8>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`808>`700<0oooo023/1`0Pk0L00P3oool00`0P
k0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00D0oooo0`0Pk0L00`3oool08>`7023/1`05023/
1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo
00D08>`70P3oool2023/1`030?ooo`0Pk0L0oooo0080oooo0`0Pk0L20?ooo`808>`70`3oool6023/
1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L00`3oool08>`7023/1`04023/1`80oooo00H08>`7
0?ooo`0Pk0L0oooo023/1`000005023/1`040?ooo`0Pk0L0oooo023/1`80oooo0`0Pk0L00`3oool0
8>`7023/1`030?ooo`04023/1`3oool0oooo023/1``0oooo00H08>`70?ooo`3oool08>`70?ooo`0P
k0LS0?ooo`030000003oool0oooo01l0oooo000M0?ooo`030000003oool0oooo01h0oooo0P0Pk0L2
0?ooo`04023/1`3oool0oooo023/1`<0oooo0P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3o
ool0oooo0080oooo00<08>`70?ooo`3oool01@3oool3023/1`030?ooo`0Pk0L08>`700D08>`700<0
oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool01@0P
k0L20?ooo`808>`700<0oooo023/1`3oool00P3oool3023/1`80oooo0P0Pk0L30?ooo`H08>`700@0
oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L08>`700@08>`70P3oool01P0Pk0L0oooo
023/1`3oool08>`7000000D08>`700@0oooo023/1`3oool08>`70P3oool3023/1`030?ooo`0Pk0L0
8>`700<0oooo00@08>`70?ooo`3oool08>`7303oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1b<0
oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3oool07P3oool2023/1`80oooo
00@08>`70?ooo`3oool08>`70`3oool2023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3o
ool00P3oool00`0Pk0L0oooo0?ooo`050?ooo`<08>`70P3oool6023/1`030?ooo`0Pk0L0oooo00<0
8>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00D08>`70P3oool2023/1`03
0?ooo`0Pk0L0oooo0080oooo0`0Pk0L20?ooo`808>`70`3oool6023/1`040?ooo`0Pk0L08>`7023/
1`80oooo1P0Pk0L00`3oool08>`7023/1`04023/1`80oooo00H08>`70?ooo`0Pk0L0oooo023/1`00
0005023/1`040?ooo`0Pk0L0oooo023/1`80oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`04023/
1`3oool0oooo023/1``0oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`0P0?oo
o`030000003oool0oooo01l0oooo000M0?ooo`030000003oool0oooo01h0oooo0P0Pk0L20?ooo`04
023/1`3oool0oooo023/1`<0oooo0P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo
0080oooo00<08>`70?ooo`3oool01@3oool3023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L00`3o
ool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`05023/
1`80oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`<08>`70P3oool2023/1`<0oooo1P0Pk0L0103o
ool08>`7023/1`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`06023/1`3oool0
8>`70?ooo`0Pk0L000001@0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`<08>`700<0oooo023/1`0P
k0L00`3oool0100Pk0L0oooo0?ooo`0Pk0L<0?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`7
0?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`007@3oool00`000000oooo0?ooo`0N0?oo
o`808>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`808>`700<0oooo023/1`0Pk0L00P3oool0
0`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00D0oooo0`0Pk0L20?ooo`03023/1`3oool0
8>`700<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`7
0?ooo`3oool01@0Pk0L20?ooo`808>`700<0oooo023/1`3oool00P3oool3023/1`80oooo0P0Pk0L3
0?ooo`H08>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L08>`700@08>`70P3o
ool01P0Pk0L0oooo023/1`3oool08>`7000000D08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0
oooo00808>`700<0oooo023/1`0Pk0L00`3oool0100Pk0L0oooo0?ooo`0Pk0L<0?ooo`04023/1`3o
ool0oooo023/1`80oooo00<08>`70?ooo`3oool08@3oool00`000000oooo0?ooo`0N0?ooo`007@3o
ool00`000000oooo0?ooo`0N0?ooo`808>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`808>`7
00<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00D0oooo
0`0Pk0L20?ooo`03023/1`3oool08>`700<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7
023/1`02023/1`80oooo00<08>`70?ooo`3oool01P0Pk0L01@3oool08>`7023/1`3oool08>`700<0
oooo0`0Pk0L20?ooo`808>`70`3oool6023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L00`3o
ool08>`7023/1`04023/1`80oooo00H08>`70?ooo`0Pk0L0oooo023/1`000005023/1`080?ooo`0P
k0L08>`7023/1`3oool08>`70?ooo`0Pk0L20?ooo`808>`70`3oool0100Pk0L0oooo0?ooo`0Pk0L<
0?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool08@3oool00`000000oooo0?oo
o`0N0?ooo`007@3oool00`000000oooo0?ooo`0N0?ooo`808>`70P3oool0100Pk0L0oooo0?ooo`0P
k0L30?ooo`D08>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00D0oooo0`0P
k0L20?ooo`03023/1`3oool08>`700<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/
1`02023/1`80oooo00<08>`70?ooo`3oool01P0Pk0L01@3oool08>`7023/1`3oool08>`700<0oooo
0`0Pk0L20?ooo`808>`70`3oool6023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L00`3oool0
8>`7023/1`04023/1`80oooo00H08>`70?ooo`0Pk0L0oooo023/1`000005023/1`080?ooo`0Pk0L0
8>`7023/1`3oool08>`70?ooo`0Pk0L20?ooo`808>`70`3oool0100Pk0L0oooo0?ooo`0Pk0L<0?oo
o`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool08@3oool00`000000oooo0?ooo`0N
0?ooo`007@3oool00`000000oooo0?ooo`0N0?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3oool0
100Pk0L0oooo0?ooo`3oool5023/1`80oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo0?oo
o`050?ooo`<08>`70P3oool00`0Pk0L0oooo023/1`03023/1`030?ooo`0Pk0L0oooo00<08>`700<0
oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00H08>`700D0oooo023/1`0Pk0L0oooo
023/1`030?ooo`<08>`70P3oool2023/1`<0oooo1P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H0
8>`700<0oooo023/1`0Pk0L00`0Pk0L30?ooo`03023/1`3oool08>`700808>`700<00000023/1`0P
k0L00`0Pk0L0203oool08>`7023/1`0Pk0L0oooo023/1`3oool08>`70P3oool2023/1`<0oooo00@0
8>`70?ooo`3oool08>`7303oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo0240
oooo00<000000?ooo`3oool07P3oool001d0oooo00<000000?ooo`3oool07P3oool01@0Pk0L0oooo
023/1`3oool08>`70080oooo00@08>`70?ooo`3oool0oooo1@0Pk0L20?ooo`03023/1`3oool0oooo
0080oooo00<08>`70?ooo`3oool01@3oool3023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L00`3o
ool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`06023/
1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00`3oool3023/1`80oooo0P0Pk0L30?ooo`H08>`700@0oooo
023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L08>`700<08>`70`3oool00`0Pk0L0oooo023/
1`02023/1`030000000Pk0L08>`700<08>`700P0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo023/
1`80oooo0P0Pk0L30?ooo`04023/1`3oool0oooo023/1``0oooo00@08>`70?ooo`3oool08>`70P3o
ool00`0Pk0L0oooo0?ooo`0Q0?ooo`030000003oool0oooo01h0oooo000M0?ooo`030000003oool0
oooo01h0oooo00D08>`70?ooo`0Pk0L0oooo023/1`020?ooo`04023/1`3oool0oooo0?ooo`D08>`7
0P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00D0oooo0`0Pk0L20?ooo`03023/
1`3oool08>`700<08>`700<0oooo023/1`3oool02@0Pk0L0103oool08>`70?ooo`3oool6023/1`05
0?ooo`0Pk0L08>`70?ooo`0Pk0L00`3oool3023/1`80oooo0P0Pk0L30?ooo`H08>`700@0oooo023/
1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L08>`700<08>`70`3oool00`0Pk0L0oooo023/1`02
023/1`030000000Pk0L08>`700<08>`700P0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`80
oooo0P0Pk0L30?ooo`04023/1`3oool0oooo023/1``0oooo00@08>`70?ooo`3oool08>`70`3oool0
0`0Pk0L0oooo0?ooo`0P0?ooo`030000003oool0oooo01h0oooo000M0?ooo`030000003oool0oooo
01h0oooo00D08>`70?ooo`0Pk0L0oooo023/1`020?ooo`04023/1`3oool0oooo0?ooo`D08>`70P3o
ool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00D0oooo0`0Pk0L20?ooo`03023/1`3o
ool08>`700<08>`700<0oooo023/1`3oool02@0Pk0L0103oool08>`70?ooo`3oool6023/1`050?oo
o`0Pk0L08>`70?ooo`0Pk0L00`3oool3023/1`80oooo0P0Pk0L30?ooo`H08>`700@0oooo023/1`0P
k0L08>`70P3oool6023/1`040?ooo`0Pk0L08>`70?ooo`808>`70`3oool00`0Pk0L0oooo023/1`02
023/1`030000000Pk0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo0P0P
k0L30?ooo`04023/1`3oool0oooo023/1`/0oooo00D08>`70?ooo`3oool0oooo023/1`030?ooo`03
023/1`3oool0oooo0200oooo00<000000?ooo`3oool07P3oool001d0oooo00<000000?ooo`3oool0
7P3oool01@0Pk0L0oooo023/1`3oool08>`70080oooo00@08>`70?ooo`3oool0oooo1@0Pk0L20?oo
o`03023/1`3oool0oooo0080oooo00<08>`70?ooo`3oool01@3oool3023/1`80oooo00<08>`70?oo
o`0Pk0L00`0Pk0L00`3oool08>`70?ooo`09023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`700D0oooo
023/1`0Pk0L0oooo023/1`030?ooo`<08>`70P3oool2023/1`<0oooo1P0Pk0L0103oool08>`7023/
1`0Pk0L20?ooo`T08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo023/1`02023/1`030000
000Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo0P0Pk0L30?ooo`04
023/1`3oool0oooo023/1`/0oooo00<08>`70?ooo`3oool00P0Pk0L30?ooo`03023/1`3oool0oooo
0200oooo00<000000?ooo`3oool07P3oool001d0oooo00<000000?ooo`3oool07P3oool00`0Pk0L0
oooo023/1`020?ooo`03023/1`3oool08>`700<0oooo1@0Pk0L20?ooo`03023/1`3oool0oooo0080
oooo00<08>`70?ooo`3oool01@3oool3023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L00`3oool0
8>`70?ooo`09023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`700D0oooo023/1`0Pk0L0oooo023/1`03
0?ooo`<08>`70P3oool2023/1`<0oooo1P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`T08>`700<0
oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo023/1`02023/1`030000000Pk0L0oooo00<08>`700D0
oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo0P0Pk0L30?ooo`04023/1`3oool0oooo023/1`/0
oooo00<08>`70?ooo`3oool00P0Pk0L30?ooo`03023/1`3oool0oooo0200oooo00<000000?ooo`3o
ool07P3oool001d0oooo00<000000?ooo`3oool07P3oool00`0Pk0L0oooo023/1`020?ooo`03023/
1`3oool08>`700<0oooo1@0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`3oool0
1@3oool3023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L00`3oool08>`70?ooo`09023/1`040?oo
o`0Pk0L0oooo0?ooo`H08>`700D0oooo023/1`0Pk0L0oooo023/1`030?ooo`<08>`70P3oool2023/
1`<0oooo1P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`T08>`700<0oooo023/1`0Pk0L00`3oool0
0`0Pk0L0oooo023/1`02023/1`030000000Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?oo
o`03023/1`80oooo0P0Pk0L30?ooo`04023/1`3oool0oooo023/1`/0oooo00<08>`70?ooo`3oool0
0P0Pk0L30?ooo`03023/1`3oool0oooo0200oooo00<000000?ooo`3oool07P3oool001d0oooo00<0
00000?ooo`3oool07P3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700<0oooo00<0
8>`70?ooo`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`3oool01@3o
ool3023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L00`3oool08>`70?ooo`09023/1`040?ooo`0P
k0L0oooo0?ooo`H08>`700D0oooo023/1`0Pk0L0oooo023/1`030?ooo`<08>`70P3oool2023/1`<0
oooo1P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`T08>`700<0oooo023/1`0Pk0L00`3oool00`0P
k0L0oooo023/1`02023/1`030000000Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03
023/1`80oooo0P0Pk0L30?ooo`04023/1`3oool0oooo023/1`/0oooo00<08>`70?ooo`3oool00P0P
k0L30?ooo`03023/1`3oool0oooo0200oooo00<000000?ooo`3oool07P3oool001d0oooo00<00000
0?ooo`3oool07P3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700<0oooo00<08>`7
0?ooo`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`3oool01@3oool3
023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L00`3oool08>`70?ooo`09023/1`040?ooo`0Pk0L0
oooo0?ooo`H08>`700D0oooo023/1`0Pk0L0oooo023/1`030?ooo`<08>`70P3oool2023/1`<0oooo
1P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00X08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0
oooo023/1`02023/1`030000000Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/
1`80oooo0P0Pk0L30?ooo`04023/1`3oool08>`7023/1`/0oooo00<08>`70?ooo`3oool00P0Pk0L3
0?ooo`03023/1`3oool0oooo0200oooo00<000000?ooo`3oool07P3oool001d0oooo00<000000?oo
o`3oool07P3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700<0oooo00<08>`70?oo
o`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`3oool01@3oool3023/
1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L00`3oool08>`70?ooo`09023/1`040?ooo`0Pk0L0oooo
0?ooo`H08>`700D0oooo023/1`0Pk0L0oooo023/1`030?ooo`<08>`70P3oool2023/1`<0oooo1P0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00X08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo
023/1`02023/1`030000000Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80
oooo0P0Pk0L30?ooo`04023/1`3oool08>`7023/1`/0oooo00<08>`70?ooo`3oool00P0Pk0L30?oo
o`03023/1`3oool0oooo0200oooo00<000000?ooo`3oool07P3oool001d0oooo00<000000?ooo`3o
ool07P3oool00`0Pk0L0oooo023/1`020?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?oo
o`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`3oool01@3oool3023/
1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L00`3oool08>`70?ooo`09023/1`040?ooo`0Pk0L0oooo
0?ooo`H08>`700D0oooo023/1`0Pk0L0oooo023/1`030?ooo`<08>`70P3oool2023/1`<0oooo1P0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00X08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo
023/1`02023/1`030000000Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80
oooo0P0Pk0L30?ooo`04023/1`3oool08>`7023/1`/0oooo00@08>`70?ooo`3oool08>`71@3oool0
0`0Pk0L0oooo0?ooo`0O0?ooo`030000003oool0oooo01h0oooo000M0?ooo`030000003oool0oooo
01h0oooo00<08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0
8>`700808>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00D0oooo0`0Pk0L2
0?ooo`03023/1`3oool08>`700D08>`700<0oooo023/1`0Pk0L01`0Pk0L0103oool08>`70?ooo`3o
ool6023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00`3oool3023/1`80oooo0P0Pk0L30?ooo`H08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`0:023/1`030?ooo`0Pk0L08>`700<0oooo0P0Pk0L01P3oool0
8>`7023/1`0000008>`70?ooo`<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo0P0P
k0L30?ooo`04023/1`3oool08>`7023/1`/0oooo00@08>`70?ooo`3oool08>`71@3oool00`0Pk0L0
oooo0?ooo`0O0?ooo`030000003oool0oooo01h0oooo000M0?ooo`030000003oool0oooo01h0oooo
00<08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool08>`70080
8>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00D0oooo0`0Pk0L20?ooo`03
023/1`3oool08>`700D08>`700<0oooo023/1`0Pk0L01`0Pk0L0103oool08>`70?ooo`3oool6023/
1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00`3oool3023/1`80oooo0P0Pk0L30?ooo`H08>`700D0oooo
023/1`0Pk0L08>`70?ooo`0:023/1`030?ooo`0Pk0L08>`70080oooo00@08>`70?ooo`0Pk0L0oooo
0P0Pk0L00`0000008>`70?ooo`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`80
8>`70`3oool0100Pk0L0oooo023/1`0Pk0L;0?ooo`04023/1`3oool0oooo023/1`D0oooo00<08>`7
0?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?ooo`007@3oool00`000000oooo0?ooo`0N0?oo
o`03023/1`3oool08>`70080oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0oooo023/1`02
023/1`80oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo0?ooo`050?ooo`<08>`70P3oool0
0`0Pk0L0oooo023/1`05023/1`030?ooo`0Pk0L08>`700L08>`700@0oooo023/1`3oool0oooo1P0P
k0L01@3oool08>`7023/1`3oool08>`700<0oooo0`0Pk0L20?ooo`808>`70`3oool6023/1`050?oo
o`0Pk0L08>`7023/1`3oool02P0Pk0L00`3oool08>`7023/1`020?ooo`04023/1`3oool08>`70?oo
o`808>`700<00000023/1`3oool00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70P3oool2
023/1`<0oooo00@08>`70?ooo`0Pk0L08>`72`3oool0100Pk0L0oooo0?ooo`0Pk0L50?ooo`03023/
1`3oool0oooo01l0oooo00<000000?ooo`3oool07P3oool001d0oooo00<000000?ooo`3oool07P3o
ool00`0Pk0L0oooo023/1`020?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`0Pk0L0
0P0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`3oool01@3oool3023/1`80oooo
00<08>`70?ooo`0Pk0L01@0Pk0L00`3oool08>`7023/1`07023/1`040?ooo`0Pk0L0oooo0?ooo`H0
8>`700D0oooo023/1`0Pk0L0oooo023/1`030?ooo`<08>`70P3oool2023/1`<0oooo1P0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00X08>`700<0oooo023/1`0Pk0L00P3oool0100Pk0L0oooo023/1`3o
ool2023/1`030000000Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`040?oo
o`0Pk0L0oooo023/1`<0oooo00@08>`70?ooo`0Pk0L08>`72`3oool0100Pk0L0oooo0?ooo`0Pk0L5
0?ooo`03023/1`3oool0oooo01l0oooo00<000000?ooo`3oool07P3oool001d0oooo00<000000?oo
o`3oool07P3oool00`0Pk0L0oooo023/1`020?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`7
0?ooo`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`3oool01@3oool3
023/1`80oooo200Pk0L00`3oool08>`7023/1`07023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`700D0
oooo023/1`0Pk0L0oooo023/1`030?ooo`03023/1`3oool08>`70080oooo0P0Pk0L30?ooo`H08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`0:023/1`030?ooo`0Pk0L08>`70080oooo00@08>`70?ooo`0P
k0L0oooo0P0Pk0L00`0000008>`70?ooo`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L0
103oool08>`70?ooo`0Pk0L30?ooo`04023/1`3oool08>`7023/1`/0oooo00@08>`70?ooo`3oool0
8>`71@3oool00`0Pk0L0oooo0?ooo`0O0?ooo`030000003oool0oooo01h0oooo000M0?ooo`030000
003oool0oooo01h0oooo00<08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03
023/1`3oool08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00D0
oooo0`0Pk0L20?ooo`P08>`700<0oooo023/1`0Pk0L01`0Pk0L0103oool08>`70?ooo`3oool6023/
1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo023/1`020?ooo`808>`70`3oool6
023/1`050?ooo`0Pk0L08>`7023/1`3oool02P0Pk0L00`3oool08>`7023/1`020?ooo`04023/1`3o
ool08>`70?ooo`808>`700<00000023/1`3oool00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<0
8>`700@0oooo023/1`3oool08>`70`3oool0100Pk0L0oooo023/1`0Pk0L;0?ooo`04023/1`3oool0
oooo023/1`D0oooo00<08>`70?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?ooo`007@3oool0
0`000000oooo0?ooo`0N0?ooo`03023/1`3oool08>`70080oooo00@08>`70?ooo`3oool08>`70P3o
ool00`0Pk0L0oooo023/1`02023/1`80oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo0?oo
o`050?ooo`<08>`70P3oool8023/1`030?ooo`0Pk0L08>`700L08>`700@0oooo023/1`3oool0oooo
1P0Pk0L01@3oool08>`7023/1`3oool08>`700<0oooo00<08>`70?ooo`0Pk0L00P3oool2023/1`<0
oooo1P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00X08>`700<0oooo023/1`0Pk0L00P3oool0100P
k0L0oooo023/1`3oool2023/1`030000000Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?oo
o`03023/1`030?ooo`0Pk0L08>`700@0oooo00@08>`70?ooo`0Pk0L08>`72`3oool0100Pk0L0oooo
0?ooo`0Pk0L60?ooo`03023/1`3oool0oooo01h0oooo00<000000?ooo`3oool07P3oool001d0oooo
00<000000?ooo`3oool07P3oool00`0Pk0L0oooo023/1`020?ooo`04023/1`3oool0oooo023/1`80
oooo00P08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`@0oooo00<08>`70?ooo`3oool01@3o
ool3023/1`80oooo200Pk0L00`3oool08>`7023/1`07023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`7
00D0oooo023/1`0Pk0L0oooo023/1`030?ooo`03023/1`3oool08>`70080oooo0P0Pk0L30?ooo`H0
8>`700D0oooo023/1`0Pk0L08>`70?ooo`0:023/1`030?ooo`0Pk0L08>`70080oooo00@08>`70?oo
o`0Pk0L0oooo0P0Pk0L00`0000008>`70?ooo`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0P
k0L00`3oool08>`7023/1`030?ooo`03023/1`3oool0oooo00808>`72`3oool0100Pk0L0oooo0?oo
o`0Pk0L60?ooo`03023/1`3oool0oooo01h0oooo00<000000?ooo`3oool07P3oool001d0oooo00<0
00000?ooo`3oool07P3oool00`0Pk0L0oooo023/1`020?ooo`04023/1`3oool0oooo023/1`80oooo
00P08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`@0oooo00<08>`70?ooo`3oool01@3oool3
023/1`80oooo200Pk0L00`3oool08>`7023/1`08023/1`<0oooo1P0Pk0L01@3oool08>`7023/1`3o
ool08>`700<0oooo00<08>`70?ooo`0Pk0L00P3oool2023/1`<0oooo1P0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00X08>`700<0oooo023/1`0Pk0L00P3oool0100Pk0L0oooo023/1`3oool2023/1`03
0000000Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00808>`70`3oool00`0Pk0L0oooo0?ooo`02023/1`/0oooo00@08>`70?ooo`3oool08>`71P3oool0
0`0Pk0L0oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo000M0?ooo`030000003oool0oooo
01h0oooo00<08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`08023/1`3oool0
8>`7023/1`3oool08>`70?ooo`0Pk0L40?ooo`03023/1`3oool0oooo00D0oooo0`0Pk0L20?ooo`P0
8>`700<0oooo023/1`0Pk0L0200Pk0L30?ooo`H08>`700D0oooo023/1`0Pk0L0oooo023/1`030?oo
o`03023/1`3oool08>`70080oooo0P0Pk0L30?ooo`H08>`700D0oooo023/1`0Pk0L08>`70?ooo`0:
023/1`030?ooo`0Pk0L08>`70080oooo00@08>`70?ooo`0Pk0L0oooo0P0Pk0L00`0000008>`70?oo
o`02023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`<0oooo
00<08>`70?ooo`3oool00P0Pk0L;0?ooo`04023/1`3oool0oooo023/1`H0oooo00<08>`70?ooo`3o
ool07P3oool00`000000oooo0?ooo`0N0?ooo`007@3oool00`000000oooo0?ooo`0N0?ooo`03023/
1`3oool08>`70080oooo00@08>`70?ooo`3oool08>`70P3oool0100Pk0L0oooo023/1`3oool2023/
1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool01@3oool3023/1`80oooo200Pk0L00`3o
ool08>`7023/1`08023/1`<0oooo1P0Pk0L01@3oool08>`7023/1`3oool08>`700<0oooo00<08>`7
0?ooo`0Pk0L00P3oool2023/1`<0oooo1P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00d08>`70P3o
ool0100Pk0L0oooo023/1`3oool2023/1`030000000Pk0L08>`700808>`700<0oooo023/1`0Pk0L0
0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70`3oool00`0Pk0L0oooo0?ooo`02023/1`/0
oooo00@08>`70?ooo`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`0N0?ooo`030000003oool0oooo
01h0oooo000M0?ooo`030000003oool0oooo01h0oooo00<08>`70?ooo`0Pk0L00P3oool0100Pk0L0
oooo0?ooo`0Pk0L20?ooo`04023/1`3oool08>`70?ooo`808>`700<0oooo023/1`3oool00`3oool0
0`0Pk0L0oooo0?ooo`050?ooo`<08>`70P3oool8023/1`030?ooo`0Pk0L08>`700P08>`70`3oool7
023/1`040?ooo`0Pk0L0oooo023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool2023/1`<0oooo1P0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00d08>`70P3oool0100Pk0L0oooo023/1`3oool2023/1`03
0000000Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00808>`70`3oool00`0Pk0L0oooo0?ooo`02023/1`/0oooo00@08>`70?ooo`3oool08>`71P3oool0
0`0Pk0L0oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo000M0?ooo`030000003oool0oooo
01h0oooo00<08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`04023/1`3oool0
8>`70?ooo`808>`70P3oool01@0Pk0L0oooo0?ooo`3oool08>`700L0oooo0`0Pk0L20?ooo`P08>`7
00<0oooo023/1`0Pk0L0200Pk0L30?ooo`L08>`700@0oooo023/1`3oool08>`70`3oool00`0Pk0L0
oooo023/1`020?ooo`808>`70`3oool6023/1`050?ooo`0Pk0L08>`7023/1`3oool03@0Pk0L20?oo
o`04023/1`3oool08>`70?ooo`808>`700<00000023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02
023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L30?ooo`03023/1`3oool0oooo00808>`72`3o
ool0100Pk0L0oooo0?ooo`0Pk0L60?ooo`03023/1`3oool0oooo01h0oooo00<000000?ooo`3oool0
7P3oool001d0oooo00<000000?ooo`3oool07P3oool00`0Pk0L0oooo023/1`020?ooo`04023/1`3o
ool0oooo023/1`80oooo0`0Pk0L00`3oool08>`7023/1`020?ooo`05023/1`3oool0oooo0?ooo`0P
k0L01`3oool4023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L0200Pk0L30?ooo`L0
8>`700@0oooo023/1`3oool08>`70`3oool00`0Pk0L0oooo023/1`020?ooo`808>`70`3oool6023/
1`050?ooo`0Pk0L08>`7023/1`3oool03@0Pk0L20?ooo`04023/1`3oool08>`70?ooo`808>`700<0
0000023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0
0P0Pk0L30?ooo`04023/1`3oool0oooo023/1``0oooo00@08>`70?ooo`0Pk0L08>`71`3oool00`0P
k0L0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo000M0?ooo`030000003oool0oooo01h0
oooo00<08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`<08>`700<0oooo023/
1`0Pk0L00P3oool01@0Pk0L0oooo0?ooo`3oool08>`700L0oooo100Pk0L00`3oool08>`7023/1`06
023/1`030?ooo`0Pk0L08>`700P08>`70`3oool7023/1`040?ooo`0Pk0L0oooo023/1`<0oooo00<0
8>`70?ooo`0Pk0L00P3oool2023/1`<0oooo1P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00d08>`7
0P3oool0100Pk0L0oooo023/1`3oool2023/1`030000000Pk0L08>`700808>`700<0oooo023/1`0P
k0L00`0Pk0L0103oool08>`70?ooo`3oool2023/1`<0oooo00@08>`70?ooo`3oool08>`72`3oool0
0`0Pk0L0oooo0?ooo`02023/1`L0oooo00<08>`70?ooo`3oool07@3oool00`000000oooo0?ooo`0N
0?ooo`007@3oool00`000000oooo0?ooo`0N0?ooo`03023/1`3oool08>`70080oooo00@08>`70?oo
o`3oool08>`70P3oool3023/1`030?ooo`0Pk0L08>`70080oooo00D08>`70?ooo`3oool0oooo023/
1`070?ooo`@08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`08023/1`<0oooo1`0P
k0L0103oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`70080oooo0P0Pk0L30?ooo`@08>`7
00<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700H08>`7
0P3oool0100Pk0L0oooo023/1`3oool2023/1`030000000Pk0L08>`700808>`700<0oooo023/1`0P
k0L00`0Pk0L0103oool08>`70?ooo`3oool2023/1`<0oooo00@08>`70?ooo`3oool08>`72`3oool0
0`0Pk0L0oooo0?ooo`02023/1`L0oooo00<08>`70?ooo`3oool07@3oool00`000000oooo0?ooo`0N
0?ooo`007@3oool00`000000oooo0?ooo`0N0?ooo`03023/1`3oool08>`70080oooo00@08>`70?oo
o`3oool08>`70P3oool3023/1`030?ooo`0Pk0L08>`70080oooo00D08>`70?ooo`3oool0oooo023/
1`070?ooo`@08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`08023/1`<0oooo1`0P
k0L0103oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`70080oooo0P0Pk0L30?ooo`@08>`7
00<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700H08>`7
0P3oool0100Pk0L0oooo023/1`3oool2023/1`030000000Pk0L08>`700808>`700<0oooo023/1`0P
k0L00`0Pk0L0103oool08>`70?ooo`3oool2023/1`<0oooo00@08>`70?ooo`3oool08>`72`3oool0
0`0Pk0L0oooo0?ooo`02023/1`L0oooo00<08>`70?ooo`3oool07@3oool00`000000oooo0?ooo`0N
0?ooo`007@3oool00`000000oooo0?ooo`0O0?ooo`808>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L2
0?ooo`<08>`700<0oooo023/1`0Pk0L00P3oool01@0Pk0L0oooo0?ooo`3oool08>`700L0oooo100P
k0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700P08>`70`3oool7023/1`040?ooo`0P
k0L0oooo023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool2023/1`<0oooo100Pk0L00`3oool08>`7
0?ooo`03023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`04023/
1`3oool08>`70?ooo`808>`700<00000023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`04
0?ooo`0Pk0L0oooo0?ooo`808>`70`3oool0100Pk0L0oooo0?ooo`0Pk0L;0?ooo`03023/1`3oool0
oooo00808>`71`3oool00`0Pk0L0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo000M0?oo
o`030000003oool0oooo01l0oooo0P0Pk0L20?ooo`04023/1`3oool0oooo023/1`80oooo1P0Pk0L2
0?ooo`05023/1`3oool0oooo0?ooo`0Pk0L01`3oool4023/1`030?ooo`0Pk0L08>`700H08>`700<0
oooo023/1`0Pk0L0200Pk0L30?ooo`L08>`700@0oooo023/1`3oool08>`70`3oool00`0Pk0L0oooo
023/1`020?ooo`808>`70`3oool4023/1`030?ooo`0Pk0L0oooo00808>`70P3oool4023/1`030?oo
o`0Pk0L08>`700H08>`70P3oool0100Pk0L0oooo023/1`3oool2023/1`030000000Pk0L08>`70080
8>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`70?ooo`3oool2023/1`<0oooo00@08>`70?oo
o`3oool08>`72`3oool00`0Pk0L0oooo0?ooo`02023/1`L0oooo00<08>`70?ooo`3oool07@3oool0
0`000000oooo0?ooo`0N0?ooo`007@3oool00`000000oooo0?ooo`0O0?ooo`808>`70P3oool0100P
k0L0oooo0?ooo`0Pk0L20?ooo`H08>`70P3oool01@0Pk0L0oooo0?ooo`3oool08>`700L0oooo100P
k0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700P08>`70`3oool7023/1`040?ooo`0P
k0L0oooo023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L30?ooo`@08>`700<0oooo023/1`3o
ool00P0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`04023/1`3oool08>`70?oo
o`808>`700<00000023/1`0Pk0L00P0Pk0L0203oool08>`7023/1`0Pk0L0oooo023/1`3oool08>`7
0P3oool2023/1`<0oooo00@08>`70?ooo`3oool08>`72`3oool00`0Pk0L0oooo0?ooo`02023/1`L0
oooo00<08>`70?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`007@3oool00`000000oooo
0?ooo`0O0?ooo`808>`70`3oool00`0Pk0L0oooo023/1`020?ooo`H08>`70P3oool01@0Pk0L0oooo
0?ooo`3oool08>`700L0oooo100Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700P0
8>`70`3oool7023/1`040?ooo`0Pk0L0oooo023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L3
0?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L01P0Pk0L2
0?ooo`04023/1`3oool08>`70?ooo`808>`700<00000023/1`0Pk0L00P0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00<08>`70P3oool2023/1`<0oooo00@08>`70?ooo`3oool08>`72`3oool00`0Pk0L0
oooo0?ooo`02023/1`L0oooo00<08>`70?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`00
7@3oool00`000000oooo0?ooo`0O0?ooo`808>`70`3oool00`0Pk0L0oooo023/1`020?ooo`H08>`7
0P3oool01@0Pk0L0oooo0?ooo`3oool08>`700L0oooo100Pk0L00`3oool08>`7023/1`06023/1`03
0?ooo`0Pk0L08>`700P08>`70`3oool7023/1`040?ooo`0Pk0L0oooo023/1`<0oooo00@08>`70?oo
o`0Pk0L0oooo0`0Pk0L30?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L20?ooo`@08>`700<0oooo
023/1`0Pk0L01P0Pk0L20?ooo`07023/1`3oool08>`7023/1`3oool08>`700000004023/1`050?oo
o`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`808>`70`3oool0100Pk0L0oooo0?ooo`0Pk0L;0?oo
o`03023/1`3oool0oooo00808>`7203oool00`0Pk0L0oooo0?ooo`0L0?ooo`030000003oool0oooo
01h0oooo000M0?ooo`030000003oool0oooo01l0oooo0P0Pk0L30?ooo`03023/1`3oool08>`70080
oooo1P0Pk0L20?ooo`05023/1`3oool0oooo0?ooo`0Pk0L01`3oool4023/1`030?ooo`0Pk0L08>`7
00H08>`700<0oooo023/1`0Pk0L0200Pk0L20?ooo`P08>`700@0oooo023/1`3oool08>`70`3oool0
100Pk0L0oooo023/1`3oool3023/1`<0oooo100Pk0L00`3oool08>`70?ooo`02023/1`80oooo100P
k0L00`3oool08>`7023/1`06023/1`80oooo00L08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0000000@0
8>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo0P0Pk0L30?ooo`04023/1`3oool08>`7
023/1`/0oooo00<08>`70?ooo`3oool00P0Pk0L80?ooo`03023/1`3oool0oooo01`0oooo00<00000
0?ooo`3oool07P3oool001d0oooo00<000000?ooo`3oool07`3oool2023/1`<0oooo00<08>`70?oo
o`0Pk0L00P3oool6023/1`80oooo00D08>`70?ooo`3oool0oooo023/1`070?ooo`@08>`700<0oooo
023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`08023/1`80oooo200Pk0L0103oool08>`70?ooo`0P
k0L30?ooo`04023/1`3oool08>`70?ooo`<08>`70`3oool4023/1`030?ooo`0Pk0L0oooo00808>`7
0P3oool4023/1`030?ooo`0Pk0L08>`700H08>`70P3oool01`0Pk0L0oooo023/1`0Pk0L0oooo023/
1`000000100Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`70P3oool2023/1`<0oooo00@08>`7
0?ooo`0Pk0L08>`72`3oool00`0Pk0L0oooo0?ooo`02023/1`P0oooo00<08>`70?ooo`3oool0703o
ool00`000000oooo0?ooo`0N0?ooo`007@3oool00`000000oooo0?ooo`0O0?ooo`808>`70`3oool0
0`0Pk0L0oooo023/1`020?ooo`H08>`70P3oool01@0Pk0L0oooo0?ooo`3oool08>`700L0oooo100P
k0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700P08>`70P3oool8023/1`040?ooo`0P
k0L0oooo023/1`<0oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L30?ooo`@08>`700<0oooo023/1`3o
ool00P0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`07023/1`3oool08>`7023/
1`3oool08>`700000004023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L20?ooo`808>`70`3o
ool0100Pk0L0oooo023/1`0Pk0L;0?ooo`03023/1`3oool0oooo00808>`7203oool00`0Pk0L0oooo
0?ooo`0L0?ooo`030000003oool0oooo01h0oooo000M0?ooo`030000003oool0oooo01l0oooo0P0P
k0L30?ooo`03023/1`3oool08>`70080oooo1P0Pk0L20?ooo`05023/1`3oool0oooo0?ooo`0Pk0L0
1`3oool4023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L0200Pk0L20?ooo`P08>`7
00@0oooo023/1`3oool08>`70`3oool0100Pk0L0oooo023/1`3oool3023/1`<0oooo100Pk0L00`3o
ool08>`70?ooo`02023/1`80oooo100Pk0L00`3oool08>`7023/1`06023/1`80oooo00L08>`70?oo
o`0Pk0L08>`70?ooo`0Pk0L0000000@08>`700D0oooo023/1`3oool08>`70?ooo`03023/1`80oooo
0P0Pk0L30?ooo`04023/1`3oool08>`7023/1`/0oooo00<08>`70?ooo`3oool00P0Pk0L80?ooo`03
023/1`3oool0oooo01`0oooo00<000000?ooo`3oool07P3oool001d0oooo00<000000?ooo`3oool0
7`3oool2023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool6023/1`80oooo00D08>`70?ooo`3oool0
oooo023/1`070?ooo`@08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`08023/1`80
oooo200Pk0L0103oool08>`70?ooo`0Pk0L30?ooo`04023/1`3oool08>`70?ooo`808>`7103oool4
023/1`030?ooo`0Pk0L0oooo00808>`70P3oool4023/1`030?ooo`0Pk0L08>`700H08>`70P3oool0
1`0Pk0L0oooo023/1`0Pk0L0oooo023/1`000000100Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<0
8>`70P3oool2023/1`<0oooo00@08>`70?ooo`0Pk0L08>`72`3oool0100Pk0L0oooo0?ooo`0Pk0L9
0?ooo`03023/1`3oool0oooo01`0oooo00<000000?ooo`3oool07P3oool001d0oooo00<000000?oo
o`3oool07`3oool2023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool2023/1`040?ooo`0Pk0L08>`7
023/1`80oooo00D08>`70?ooo`3oool0oooo023/1`070?ooo`@08>`700<0oooo023/1`0Pk0L01P0P
k0L00`3oool08>`7023/1`08023/1`80oooo200Pk0L0103oool08>`70?ooo`0Pk0L30?ooo`04023/
1`3oool08>`70?ooo`808>`7103oool4023/1`030?ooo`0Pk0L0oooo00808>`70P3oool4023/1`03
0?ooo`0Pk0L08>`700H08>`70P3oool01`0Pk0L0oooo023/1`0Pk0L0oooo023/1`000000100Pk0L0
1@3oool08>`70?ooo`0Pk0L0oooo00<08>`70P3oool2023/1`<0oooo00@08>`70?ooo`0Pk0L08>`7
2`3oool0100Pk0L0oooo0?ooo`0Pk0L90?ooo`03023/1`3oool0oooo01`0oooo00<000000?ooo`3o
ool07P3oool001d0oooo00<000000?ooo`3oool07`3oool2023/1`<0oooo00<08>`70?ooo`0Pk0L0
0P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo00D08>`70?ooo`3oool0oooo023/1`070?oo
o`@08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`08023/1`80oooo200Pk0L0103o
ool08>`70?ooo`0Pk0L30?ooo`04023/1`3oool08>`70?ooo`808>`7103oool4023/1`030?ooo`0P
k0L0oooo00808>`70P3oool4023/1`030?ooo`0Pk0L08>`700D08>`70`3oool01`0Pk0L0oooo023/
1`0Pk0L0oooo023/1`000000100Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`70P3oool2023/
1`<0oooo00@08>`70?ooo`0Pk0L08>`72`3oool0100Pk0L0oooo0?ooo`0Pk0L:0?ooo`03023/1`3o
ool0oooo01/0oooo00<000000?ooo`3oool07P3oool001d0oooo00<000000?ooo`3oool07`3oool2
023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo00D0
8>`70?ooo`3oool0oooo023/1`070?ooo`@08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7
023/1`08023/1`80oooo200Pk0L0103oool08>`70?ooo`0Pk0L30?ooo`04023/1`3oool08>`70?oo
o`808>`7103oool4023/1`030?ooo`0Pk0L0oooo00808>`70P3oool4023/1`030?ooo`0Pk0L08>`7
00D08>`70`3oool01`0Pk0L0oooo023/1`0Pk0L0oooo023/1`000000100Pk0L01@3oool08>`70?oo
o`0Pk0L0oooo00<08>`70P3oool2023/1`<0oooo00@08>`70?ooo`0Pk0L08>`72`3oool0100Pk0L0
oooo0?ooo`0Pk0L:0?ooo`03023/1`3oool0oooo01/0oooo00<000000?ooo`3oool07P3oool001d0
oooo00<000000?ooo`3oool07`3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700<0
oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?ooo`04023/1`3oool0oooo0?ooo`808>`71P3oool4023/
1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L0200Pk0L20?ooo`T08>`70P3oool0200P
k0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L40?ooo`@08>`700<0oooo023/1`3oool0
0P0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L01@0Pk0L30?ooo`07023/1`3oool08>`7023/1`3o
ool08>`700000004023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L20?ooo`808>`70`3oool0
100Pk0L0oooo023/1`0Pk0L;0?ooo`04023/1`3oool0oooo023/1`X0oooo00<08>`70?ooo`3oool0
6`3oool00`000000oooo0?ooo`0N0?ooo`007@3oool00`000000oooo0?ooo`0O0?ooo`03023/1`3o
ool08>`70080oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo023/1`02023/1`80oooo00@0
8>`70?ooo`3oool0oooo0P0Pk0L60?ooo`@08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7
023/1`08023/1`80oooo2@0Pk0L20?ooo`08023/1`3oool0oooo0?ooo`0Pk0L0oooo023/1`3oool2
023/1`@0oooo100Pk0L00`3oool08>`70?ooo`02023/1`80oooo100Pk0L00`3oool08>`7023/1`02
023/1`030?ooo`0Pk0L08>`700<0oooo00L08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0000000@08>`7
00D0oooo023/1`3oool08>`70?ooo`03023/1`80oooo0P0Pk0L30?ooo`04023/1`3oool08>`7023/
1`/0oooo00@08>`70?ooo`3oool08>`72P3oool00`0Pk0L0oooo0?ooo`0K0?ooo`030000003oool0
oooo01h0oooo000M0?ooo`030000003oool0oooo01l0oooo00<08>`70?ooo`0Pk0L00P3oool00`0P
k0L0oooo023/1`030?ooo`03023/1`3oool08>`700808>`70P3oool0100Pk0L0oooo0?ooo`3oool2
023/1`H0oooo100Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo
023/1`3oool0200Pk0L20?ooo`08023/1`3oool0oooo0?ooo`0Pk0L0oooo023/1`3oool2023/1`@0
oooo0P0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00808>`70P3oool4023/1`030?ooo`0Pk0L08>`7
00808>`700<0oooo023/1`0Pk0L00`3oool01`0Pk0L0oooo023/1`0Pk0L0oooo023/1`000000100P
k0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`70P3oool2023/1`80oooo00<08>`70?ooo`3oool0
0P0Pk0L;0?ooo`04023/1`3oool0oooo023/1`X0oooo00<08>`70?ooo`3oool06`3oool00`000000
oooo0?ooo`0N0?ooo`007@3oool00`000000oooo0?ooo`0O0?ooo`03023/1`3oool08>`70080oooo
00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo023/1`02023/1`80oooo00@08>`70?ooo`3oool0
oooo0P0Pk0L60?ooo`@08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`08023/1`03
0?ooo`0Pk0L0oooo00P08>`70P3oool0200Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L0oooo0P0P
k0L40?ooo`808>`700D0oooo023/1`3oool08>`70?ooo`02023/1`80oooo100Pk0L00`3oool08>`7
023/1`02023/1`030?ooo`0Pk0L08>`700<0oooo00L08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L00000
00@08>`700D0oooo023/1`3oool08>`70?ooo`03023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0
oooo00808>`72`3oool0100Pk0L0oooo0?ooo`0Pk0L:0?ooo`03023/1`3oool0oooo01/0oooo00<0
00000?ooo`3oool07P3oool001d0oooo00<000000?ooo`3oool07`3oool00`0Pk0L0oooo023/1`02
0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?ooo`04023/1`3oool0
oooo0?ooo`808>`71P3oool4023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L0200P
k0L00`3oool08>`70?ooo`08023/1`80oooo00P08>`70?ooo`3oool0oooo023/1`3oool08>`70?oo
o`808>`7103oool2023/1`050?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L20?ooo`T08>`700<0oooo
023/1`0Pk0L00`3oool01`0Pk0L0oooo023/1`0Pk0L0oooo023/1`000000100Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00<08>`70P3oool2023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L;0?ooo`04
023/1`3oool08>`7023/1`X0oooo00<08>`70?ooo`3oool06`3oool00`000000oooo0?ooo`0N0?oo
o`007@3oool00`000000oooo0?ooo`0O0?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`0P
k0L00`3oool00`0Pk0L0oooo023/1`02023/1`80oooo00@08>`70?ooo`3oool0oooo0P0Pk0L60?oo
o`@08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L0
oooo00P08>`70P3oool0200Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L40?ooo`80
8>`700D0oooo023/1`3oool08>`70?ooo`02023/1`80oooo2@0Pk0L00`3oool08>`7023/1`030?oo
o`808>`700D0oooo023/1`3oool08>`700000004023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0P
k0L20?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`X0oooo00<08>`70?ooo`3oool00P0P
k0L;0?ooo`03023/1`3oool0oooo01X0oooo00<000000?ooo`3oool07P3oool001d0oooo00<00000
0?ooo`3oool07`3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700<0oooo00<08>`7
0?ooo`0Pk0L00P0Pk0L20?ooo`04023/1`3oool0oooo0?ooo`808>`71P3oool4023/1`040?ooo`0P
k0L08>`70?ooo`D08>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`70?ooo`08023/1`80oooo
00P08>`70?ooo`3oool0oooo023/1`3oool08>`70?ooo`808>`7103oool2023/1`050?ooo`0Pk0L0
oooo023/1`3oool00P0Pk0L20?ooo`T08>`700<0oooo023/1`0Pk0L00`3oool2023/1`050?ooo`0P
k0L0oooo023/1`000000100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70P3oool2023/1`80
oooo00<08>`70?ooo`3oool00P0Pk0L:0?ooo`03023/1`3oool0oooo00808>`72`3oool00`0Pk0L0
oooo0?ooo`0J0?ooo`030000003oool0oooo01h0oooo000M0?ooo`030000003oool0oooo01l0oooo
00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool08>`700808>`7
0P3oool0100Pk0L0oooo0?ooo`3oool2023/1`H0oooo100Pk0L0103oool08>`7023/1`3oool5023/
1`80oooo2@0Pk0L00`3oool08>`70?ooo`08023/1`80oooo00P08>`70?ooo`3oool0oooo023/1`3o
ool08>`70?ooo`808>`7103oool4023/1`030?ooo`0Pk0L0oooo00808>`70P3oool9023/1`030?oo
o`0Pk0L08>`700<0oooo0P0Pk0L01@3oool08>`70?ooo`0Pk0L0000000@08>`700D0oooo023/1`0P
k0L08>`70?ooo`03023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00808>`72P3oool00`0P
k0L0oooo0?ooo`02023/1`/0oooo00<08>`70?ooo`3oool06P3oool00`000000oooo0?ooo`0N0?oo
o`007@3oool00`000000oooo0?ooo`0O0?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`0P
k0L00`3oool00`0Pk0L0oooo023/1`02023/1`80oooo00@08>`70?ooo`3oool0oooo0P0Pk0L60?oo
o`@08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L20?ooo`T08>`700<0oooo023/1`3oool0200Pk0L2
0?ooo`08023/1`3oool0oooo0?ooo`0Pk0L0oooo023/1`3oool2023/1`@0oooo100Pk0L00`3oool0
8>`70?ooo`02023/1`80oooo2@0Pk0L00`3oool08>`7023/1`020?ooo`04023/1`3oool08>`70?oo
o`<08>`700<00000023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70P3oool2
023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L:0?ooo`03023/1`3oool0oooo00808>`72P3oool2
000001`0oooo00<000000?ooo`3oool07P3oool001d0oooo00<000000?ooo`3oool07`3oool00`0P
k0L0oooo023/1`020?ooo`03023/1`3oool08>`700<0oooo00P08>`70?ooo`0Pk0L08>`70?ooo`0P
k0L0oooo023/1`<0oooo0P0Pk0L60?ooo`@08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L20?ooo`T0
8>`700<0oooo023/1`3oool0200Pk0L20?ooo`08023/1`3oool0oooo0?ooo`0Pk0L0oooo023/1`3o
ool2023/1`@0oooo100Pk0L00`3oool08>`70?ooo`02023/1`80oooo2@0Pk0L00`3oool08>`7023/
1`020?ooo`04023/1`3oool08>`70?ooo`<08>`700<00000023/1`0Pk0L01P0Pk0L0103oool08>`7
023/1`0Pk0L20?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`X0oooo00<08>`70?ooo`3o
ool00P0Pk0L:0?ooo`800000703oool00`000000oooo0?ooo`0N0?ooo`007@3oool00`000000oooo
0?ooo`0O0?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`0Pk0L00`3oool0200Pk0L0oooo
023/1`0Pk0L0oooo023/1`3oool08>`70`3oool2023/1`H0oooo100Pk0L0103oool08>`7023/1`3o
ool5023/1`80oooo2@0Pk0L00`3oool08>`70?ooo`08023/1`80oooo00P08>`70?ooo`3oool0oooo
023/1`3oool08>`70?ooo`808>`7103oool4023/1`030?ooo`0Pk0L0oooo00808>`70P3oool9023/
1`030?ooo`0Pk0L08>`70080oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L00`0000008>`7023/1`06
023/1`040?ooo`0Pk0L08>`7023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00808>`72P3o
ool00`0Pk0L0oooo0?ooo`02023/1bP0oooo00<000000?ooo`3oool07P3oool001d0oooo00<00000
0?ooo`3oool07`3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700<0oooo00P08>`7
0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`<0oooo0P0Pk0L60?ooo`@08>`700@0oooo023/1`0P
k0L0oooo1@0Pk0L20?ooo`T08>`700<0oooo023/1`3oool0200Pk0L20?ooo`08023/1`3oool0oooo
0?ooo`0Pk0L0oooo023/1`3oool2023/1`@0oooo100Pk0L00`3oool08>`70?ooo`02023/1`80oooo
2@0Pk0L00`3oool08>`7023/1`020?ooo`04023/1`3oool08>`70?ooo`<08>`700D00000023/1`0P
k0L08>`70?ooo`04023/1`040?ooo`0Pk0L08>`7023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0
oooo00808>`72P3oool00`0Pk0L0oooo0?ooo`02023/1bP0oooo00<000000?ooo`3oool07P3oool0
01d0oooo00<000000?ooo`3oool07`3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`7
00<0oooo00P08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`<0oooo0P0Pk0L60?ooo`@08>`7
00@0oooo023/1`0Pk0L0oooo1@0Pk0L20?ooo`X08>`70P3oool8023/1`80oooo00P08>`70?ooo`3o
ool0oooo023/1`3oool08>`70?ooo`808>`7103oool4023/1`030?ooo`0Pk0L0oooo00808>`70P3o
ool9023/1`030?ooo`0Pk0L08>`70080oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L01@0000008>`7
023/1`0Pk0L0oooo00D08>`700<0oooo023/1`3oool00P3oool2023/1`80oooo00<08>`70?ooo`3o
ool00P0Pk0L:0?ooo`03023/1`3oool0oooo00808>`7:03oool00`000000oooo0?ooo`0N0?ooo`00
7@3oool00`000000oooo0?ooo`0O0?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`0Pk0L0
0`3oool0200Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool08>`70`3oool2023/1`H0oooo100Pk0L0
103oool08>`7023/1`3oool5023/1`80oooo2P0Pk0L20?ooo`P08>`70P3oool0200Pk0L0oooo0?oo
o`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L40?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L20?oo
o`808>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`020?ooo`04023/1`3oool08>`7
0?ooo`<08>`700D00000023/1`0Pk0L08>`70?ooo`05023/1`030?ooo`0Pk0L0oooo0080oooo0P0P
k0L20?ooo`03023/1`3oool0oooo00808>`72P3oool00`0Pk0L0oooo0?ooo`02023/1bP0oooo00<0
00000?ooo`3oool07P3oool001d0oooo00<000000?ooo`3oool07`3oool00`0Pk0L0oooo023/1`02
0?ooo`03023/1`3oool08>`700<0oooo00P08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`<0
oooo0P0Pk0L60?ooo`@08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L20?ooo`X08>`70P3oool8023/
1`80oooo00P08>`70?ooo`3oool0oooo023/1`3oool08>`70?ooo`808>`7103oool4023/1`030?oo
o`0Pk0L0oooo00808>`70P3oool2023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L0
0P3oool0100Pk0L0oooo023/1`3oool3023/1`050000000Pk0L08>`7023/1`3oool01@0Pk0L01`3o
ool08>`70?ooo`3oool08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`02023/1`X0oooo00<0
8>`70?ooo`3oool00P0Pk0LX0?ooo`030000003oool0oooo01h0oooo000M0?ooo`030000003oool0
oooo01l0oooo00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo023/1`030?ooo`08023/1`3oool0
8>`7023/1`3oool08>`70?ooo`0Pk0L30?ooo`808>`71P3oool4023/1`040?ooo`0Pk0L08>`70?oo
o`D08>`70P3oool:023/1`80oooo200Pk0L20?ooo`08023/1`3oool0oooo0?ooo`0Pk0L0oooo023/
1`3oool2023/1`@0oooo100Pk0L00`3oool08>`70?ooo`02023/1`80oooo0P0Pk0L00`3oool08>`7
023/1`04023/1`030?ooo`0Pk0L08>`70080oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L01@000000
8>`7023/1`0Pk0L0oooo00D08>`700L0oooo023/1`3oool0oooo023/1`3oool08>`70080oooo00<0
8>`70?ooo`3oool00P0Pk0L:0?ooo`03023/1`3oool0oooo00808>`7:03oool00`000000oooo0?oo
o`0N0?ooo`00703oool00`000000oooo0?ooo`0P0?ooo`03023/1`3oool08>`70080oooo00<08>`7
0?ooo`0Pk0L00`3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`3oool0
0P0Pk0L60?ooo`@08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L20?ooo`X08>`70P3oool8023/1`80
oooo00P08>`70?ooo`3oool0oooo023/1`3oool08>`70?ooo`808>`7103oool4023/1`030?ooo`0P
k0L0oooo00808>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`70080oooo
00@08>`70?ooo`0Pk0L0oooo0`0Pk0L01@0000008>`7023/1`0Pk0L0oooo00D08>`700L0oooo023/
1`3oool0oooo023/1`3oool08>`70080oooo00D08>`70?ooo`0Pk0L0oooo023/1`0:0?ooo`03023/
1`3oool0oooo00808>`7:03oool00`000000oooo0?ooo`0N0?ooo`00703oool00`000000oooo0?oo
o`0P0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo023/
1`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L60?ooo`@08>`700@0oooo023/1`0P
k0L0oooo1@0Pk0L20?ooo`X08>`70P3oool8023/1`80oooo00P08>`70?ooo`3oool0oooo023/1`3o
ool08>`70?ooo`808>`7103oool4023/1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/1`0Pk0L0
8>`70?ooo`06023/1`030?ooo`0Pk0L08>`70080oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L01@00
00008>`7023/1`0Pk0L0oooo00D08>`700@0oooo023/1`3oool0oooo0P0Pk0L30?ooo`05023/1`3o
ool08>`70?ooo`0Pk0L02P3oool00`0Pk0L0oooo0?ooo`02023/1bP0oooo00<000000?ooo`3oool0
7P3oool001`0oooo00<000000?ooo`3oool0803oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3o
ool08>`70080oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`03023/1`3oool0oooo0080
8>`71P3oool4023/1`040?ooo`0Pk0L08>`70?ooo`D08>`70P3oool:023/1`80oooo200Pk0L20?oo
o`08023/1`3oool0oooo0?ooo`0Pk0L0oooo023/1`3oool2023/1`@0oooo100Pk0L00`3oool08>`7
0?ooo`02023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3oool08>`7023/1`020?ooo`04
023/1`3oool08>`70?ooo`<08>`700D00000023/1`0Pk0L08>`70?ooo`07023/1`80oooo0P0Pk0L3
0?ooo`04023/1`3oool08>`7023/1`/0oooo00<08>`70?ooo`3oool00P0Pk0LX0?ooo`030000003o
ool0oooo01h0oooo000L0?ooo`030000003oool0oooo0200oooo00<08>`70?ooo`0Pk0L00`3oool0
0`0Pk0L0oooo023/1`020?ooo`06023/1`3oool08>`7023/1`3oool08>`70P3oool00`0Pk0L0oooo
0?ooo`02023/1`H0oooo100Pk0L0103oool08>`7023/1`3oool5023/1`80oooo2P0Pk0L20?ooo`P0
8>`70P3oool0200Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L40?ooo`@08>`700<0
oooo023/1`3oool00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L0
0P3oool0100Pk0L0oooo023/1`3oool3023/1`050000000Pk0L08>`7023/1`3oool01`0Pk0L20?oo
o`808>`70`3oool0100Pk0L0oooo023/1`0Pk0L;0?ooo`03023/1`3oool0oooo00808>`7:03oool0
0`000000oooo0?ooo`0N0?ooo`00703oool00`000000oooo0?ooo`0P0?ooo`03023/1`3oool08>`7
00<0oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`80oooo00<0
8>`70?ooo`3oool00P0Pk0L60?ooo`@08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L20?ooo`X08>`7
0P3oool8023/1`80oooo00P08>`70?ooo`3oool0oooo023/1`3oool08>`70?ooo`808>`7103oool4
023/1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0P
k0L08>`70080oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L01@0000008>`7023/1`0Pk0L0oooo00L0
8>`70P3oool2023/1`<0oooo00@08>`70?ooo`0Pk0L08>`72`3oool00`0Pk0L0oooo0?ooo`02023/
1bP0oooo00<000000?ooo`3oool07P3oool001`0oooo00<000000?ooo`3oool0803oool00`0Pk0L0
oooo023/1`030?ooo`03023/1`3oool08>`70080oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L2
0?ooo`05023/1`3oool0oooo0?ooo`0Pk0L01P3oool4023/1`030?ooo`0Pk0L08>`700H08>`70P3o
ool:023/1`80oooo200Pk0L20?ooo`08023/1`3oool0oooo0?ooo`0Pk0L0oooo023/1`3oool2023/
1`@0oooo100Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L0
0`3oool08>`7023/1`020?ooo`04023/1`3oool08>`70?ooo`<08>`700D00000023/1`0Pk0L08>`7
0?ooo`07023/1`80oooo0P0Pk0L30?ooo`04023/1`3oool08>`7023/1`/0oooo00<08>`70?ooo`3o
ool00P0Pk0LX0?ooo`030000003oool0oooo01h0oooo000L0?ooo`030000003oool0oooo0200oooo
00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3oool08>`7023/1`3o
ool08>`70P3oool01@0Pk0L0oooo0?ooo`3oool08>`700H0oooo100Pk0L00`3oool08>`7023/1`04
023/1`040?ooo`0Pk0L0oooo0?ooo`X08>`70P3oool8023/1`80oooo0P0Pk0L20?ooo`04023/1`3o
ool08>`70?ooo`808>`7103oool4023/1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/1`0Pk0L0
8>`70?ooo`06023/1`030?ooo`0Pk0L08>`70080oooo00@08>`70?ooo`0Pk0L0oooo0`0Pk0L01@00
00008>`7023/1`0Pk0L0oooo00L08>`70P3oool2023/1`<0oooo00@08>`70?ooo`0Pk0L08>`72`3o
ool00`0Pk0L0oooo0?ooo`02023/1bP0oooo00<000000?ooo`3oool07P3oool001`0oooo00<00000
0?ooo`3oool0803oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool08>`70080oooo00H08>`7
0?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`05023/1`3oool0oooo0?ooo`0Pk0L01P3oool4023/1`03
0?ooo`0Pk0L08>`700@08>`700@0oooo023/1`3oool0oooo2@0Pk0L30?ooo`P08>`70P3oool2023/
1`80oooo00@08>`70?ooo`0Pk0L0oooo0P0Pk0L40?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L0
1@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L00P3oool0100Pk0L0oooo023/
1`3oool3023/1`050000000Pk0L08>`7023/1`3oool01`0Pk0L20?ooo`808>`70`3oool0100Pk0L0
oooo023/1`0Pk0L;0?ooo`03023/1`3oool0oooo00808>`7:03oool00`000000oooo0?ooo`0N0?oo
o`00703oool00`000000oooo0?ooo`0P0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`0P
k0L00P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`80oooo00D08>`70?ooo`3oool0oooo023/
1`060?ooo`@08>`700<0oooo023/1`0Pk0L0100Pk0L0103oool08>`70?ooo`3oool9023/1`<0oooo
200Pk0L20?ooo`808>`70P3oool0100Pk0L0oooo023/1`3oool2023/1`@0oooo100Pk0L00`3oool0
8>`70?ooo`02023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3oool08>`7023/1`020?oo
o`05023/1`3oool08>`7023/1`3oool00P0Pk0L01@0000008>`7023/1`0Pk0L0oooo00L08>`70P3o
ool2023/1`<0oooo00@08>`70?ooo`0Pk0L08>`72`3oool01@0Pk0L0oooo023/1`3oool08>`702P0
oooo00<000000?ooo`3oool07P3oool001`0oooo00<000000?ooo`3oool0803oool00`0Pk0L0oooo
023/1`030?ooo`03023/1`3oool08>`70080oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?oo
o`05023/1`3oool0oooo0?ooo`0Pk0L01P3oool4023/1`030?ooo`0Pk0L08>`700@08>`700@0oooo
023/1`3oool0oooo2@0Pk0L30?ooo`P08>`70P3oool2023/1`80oooo00@08>`70?ooo`0Pk0L0oooo
0P0Pk0L40?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H0
8>`700<0oooo023/1`0Pk0L00P3oool01@0Pk0L0oooo023/1`0Pk0L0oooo00808>`700D00000023/
1`0Pk0L08>`70?ooo`07023/1`80oooo0P0Pk0L30?ooo`04023/1`3oool08>`7023/1`/0oooo00D0
8>`70?ooo`0Pk0L0oooo023/1`0X0?ooo`030000003oool0oooo01h0oooo000L0?ooo`030000003o
ool0oooo0200oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3o
ool08>`7023/1`3oool08>`70P3oool01@0Pk0L0oooo0?ooo`3oool08>`700H0oooo100Pk0L00`3o
ool08>`7023/1`04023/1`040?ooo`0Pk0L0oooo0?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L3
0?ooo`P08>`70P3oool2023/1`80oooo0P0Pk0L20?ooo`808>`7103oool4023/1`030?ooo`0Pk0L0
oooo00808>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`70080oooo00D0
8>`70?ooo`0Pk0L08>`70?ooo`02023/1`050000000Pk0L08>`7023/1`3oool01`0Pk0L20?ooo`80
8>`70`3oool0100Pk0L0oooo023/1`0Pk0L;0?ooo`04023/1`3oool08>`7023/1bT0oooo00<00000
0?ooo`3oool07P3oool001`0oooo00<000000?ooo`3oool0803oool00`0Pk0L0oooo023/1`030?oo
o`03023/1`3oool08>`70080oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`05023/1`3o
ool0oooo0?ooo`0Pk0L01P3oool4023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`3oool0
8>`70P3oool4023/1`030?ooo`0Pk0L08>`700808>`70`3oool8023/1`80oooo0P0Pk0L20?ooo`80
8>`70P3oool2023/1`@0oooo100Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L08>`7023/
1`3oool01P0Pk0L00`3oool08>`7023/1`020?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L0
1@0000008>`7023/1`0Pk0L0oooo00L08>`70P3oool2023/1`80oooo00<08>`70?ooo`3oool00P0P
k0L:0?ooo`03023/1`3oool0oooo00808>`7:@3oool00`000000oooo0?ooo`0N0?ooo`00703oool0
0`000000oooo0?ooo`0P0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`0Pk0L00P3oool0
1P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`80oooo00D08>`70?ooo`3oool0oooo023/1`060?ooo`@0
8>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`@08>`700<0oooo023/
1`0Pk0L00P0Pk0L30?ooo`P08>`70P3oool2023/1`80oooo0P0Pk0L20?ooo`808>`7103oool4023/
1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L0
8>`70080oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`050000000Pk0L08>`7023/1`3oool0
1`0Pk0L20?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`X0oooo00<08>`70?ooo`3oool0
0P0Pk0LY0?ooo`030000003oool0oooo01h0oooo000L0?ooo`030000003oool0oooo0200oooo00<0
8>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3oool0oooo023/1`3oool0
8>`70P3oool01@0Pk0L0oooo0?ooo`3oool08>`700H0oooo100Pk0L00`3oool08>`7023/1`02023/
1`040?ooo`0Pk0L0oooo023/1`80oooo100Pk0L00`3oool08>`7023/1`02023/1`<0oooo200Pk0L2
0?ooo`808>`70P3oool2023/1`80oooo0P0Pk0L40?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L0
1@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L00P3oool01@0Pk0L0oooo023/
1`0Pk0L0oooo00808>`700D00000023/1`0Pk0L08>`70?ooo`07023/1`80oooo0P0Pk0L20?ooo`03
023/1`3oool0oooo00808>`72P3oool00`0Pk0L0oooo0?ooo`02023/1bT0oooo00<000000?ooo`3o
ool07P3oool001`0oooo00<000000?ooo`3oool08@3oool2023/1`<0oooo00<08>`70?ooo`0Pk0L0
0P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`80oooo00D08>`70?ooo`3oool0oooo023/1`06
0?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`@08>`700<0
oooo023/1`0Pk0L00P0Pk0L30?ooo`P08>`70P3oool2023/1`80oooo0P0Pk0L20?ooo`808>`7103o
ool4023/1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?oo
o`0Pk0L08>`70080oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`050000000Pk0L08>`7023/
1`3oool01`0Pk0L20?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`X0oooo00<08>`70?oo
o`3oool00P0Pk0LY0?ooo`030000003oool0oooo01h0oooo000L0?ooo`030000003oool0oooo0240
oooo0P0Pk0L30?ooo`03023/1`3oool08>`70080oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L2
0?ooo`05023/1`3oool0oooo0?ooo`0Pk0L01P3oool4023/1`030?ooo`0Pk0L08>`700808>`700@0
oooo023/1`3oool08>`70P3oool4023/1`030?ooo`0Pk0L08>`700808>`70`3oool8023/1`80oooo
0P0Pk0L20?ooo`808>`70P3oool2023/1`@0oooo100Pk0L00`3oool08>`70?ooo`02023/1`050?oo
o`0Pk0L08>`7023/1`3oool01P0Pk0L00`3oool08>`7023/1`020?ooo`05023/1`3oool08>`7023/
1`3oool00P0Pk0L01@0000008>`7023/1`0Pk0L0oooo00L08>`70P3oool2023/1`80oooo00<08>`7
0?ooo`3oool00P0Pk0L:0?ooo`03023/1`3oool0oooo00808>`7:@3oool00`000000oooo0?ooo`0N
0?ooo`00703oool00`000000oooo0?ooo`0Q0?ooo`808>`70`3oool00`0Pk0L0oooo023/1`020?oo
o`06023/1`3oool0oooo023/1`3oool08>`70P3oool01@0Pk0L0oooo0?ooo`3oool08>`700H0oooo
100Pk0L00`3oool08>`7023/1`02023/1`040?ooo`0Pk0L0oooo023/1`80oooo100Pk0L00`3oool0
8>`7023/1`02023/1`<0oooo200Pk0L20?ooo`808>`70P3oool2023/1`80oooo0P0Pk0L30?ooo`D0
8>`700<0oooo023/1`3oool00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo023/
1`0Pk0L00P3oool01@0Pk0L0oooo023/1`0Pk0L0oooo00808>`700D00000023/1`0Pk0L08>`70?oo
o`07023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00808>`72P3oool00`0Pk0L0oooo0?oo
o`02023/1bT0oooo00<000000?ooo`3oool07P3oool001`0oooo00<000000?ooo`3oool08@3oool2
023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool2023/1`040?ooo`0Pk0L0oooo023/1`80oooo00D0
8>`70?ooo`3oool0oooo023/1`060?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`7
0?ooo`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`P08>`70P3oool2023/1`80
oooo0P0Pk0L20?ooo`808>`70`3oool5023/1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/1`0P
k0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`70080oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02
023/1`050000000Pk0L08>`7023/1`3oool01`0Pk0L20?ooo`808>`70P3oool00`0Pk0L0oooo0?oo
o`02023/1`X0oooo00<08>`70?ooo`3oool00P0Pk0LY0?ooo`030000003oool0oooo01h0oooo000L
0?ooo`030000003oool0oooo0240oooo0P0Pk0L30?ooo`03023/1`3oool08>`70080oooo0P0Pk0L0
103oool08>`70?ooo`0Pk0L20?ooo`05023/1`3oool0oooo0?ooo`0Pk0L01P3oool4023/1`030?oo
o`0Pk0L08>`700808>`700@0oooo023/1`3oool08>`70P3oool4023/1`030?ooo`0Pk0L08>`70080
8>`70`3oool8023/1`80oooo0P0Pk0L20?ooo`808>`70P3oool2023/1`<0oooo1@0Pk0L00`3oool0
8>`70?ooo`02023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3oool08>`7023/1`020?oo
o`05023/1`3oool08>`7023/1`3oool00P0Pk0L01@0000008>`7023/1`0Pk0L0oooo00L08>`70P3o
ool2023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L:0?ooo`03023/1`3oool0oooo00808>`7:@3o
ool00`000000oooo0?ooo`0N0?ooo`00703oool00`000000oooo0?ooo`0Q0?ooo`808>`70`3oool0
0`0Pk0L0oooo023/1`020?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool01@0Pk0L0oooo0?oo
o`3oool08>`700H0oooo100Pk0L00`3oool08>`7023/1`02023/1`040?ooo`0Pk0L0oooo023/1`80
oooo100Pk0L00`3oool08>`7023/1`02023/1`<0oooo200Pk0L20?ooo`808>`70P3oool2023/1`80
oooo0P0Pk0L30?ooo`D08>`700<0oooo023/1`3oool00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00H08>`700<0oooo023/1`0Pk0L00P3oool01@0Pk0L0oooo023/1`0Pk0L0oooo00808>`700D00000
023/1`0Pk0L08>`70?ooo`07023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00808>`72P3o
ool00`0Pk0L0oooo0?ooo`02023/1bT0oooo00<000000?ooo`3oool07P3oool001`0oooo00<00000
0?ooo`3oool08@3oool2023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool2023/1`040?ooo`0Pk0L0
8>`7023/1`80oooo00D08>`70?ooo`3oool0oooo023/1`060?ooo`@08>`700<0oooo023/1`0Pk0L0
0P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`P0
8>`70P3oool2023/1`80oooo0P0Pk0L20?ooo`808>`70`3oool5023/1`030?ooo`0Pk0L08>`70080
8>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`70080oooo00D08>`70?oo
o`0Pk0L08>`70?ooo`02023/1`050000000Pk0L08>`7023/1`3oool01`0Pk0L20?ooo`808>`70P3o
ool00`0Pk0L0oooo0?ooo`02023/1`X0oooo00<08>`70?ooo`3oool00P0Pk0LY0?ooo`030000003o
ool0oooo01h0oooo000L0?ooo`030000003oool0oooo0240oooo0P0Pk0L30?ooo`03023/1`3oool0
8>`70080oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`05023/1`3oool0oooo0?ooo`0Pk0L0
1P3oool4023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`3oool08>`70P3oool4023/1`03
0?ooo`0Pk0L08>`700808>`70`3oool8023/1`80oooo0P0Pk0L20?ooo`808>`70P3oool2023/1`<0
oooo1@0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3o
ool08>`7023/1`020?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L01@0000008>`7023/1`0P
k0L0oooo00<08>`700@0oooo023/1`0Pk0L08>`70P3oool2023/1`80oooo00<08>`70?ooo`3oool0
0P0Pk0L:0?ooo`03023/1`3oool0oooo00808>`7:@3oool00`000000oooo0?ooo`0N0?ooo`00703o
ool00`000000oooo0?ooo`0Q0?ooo`808>`70`3oool00`0Pk0L0oooo023/1`020?ooo`808>`700@0
oooo023/1`0Pk0L08>`70P3oool01@0Pk0L0oooo0?ooo`3oool08>`700H0oooo00D08>`70?ooo`0P
k0L08>`70?ooo`04023/1`040?ooo`0Pk0L0oooo023/1`80oooo100Pk0L00`3oool08>`7023/1`02
023/1`<0oooo200Pk0L20?ooo`808>`70P3oool2023/1`80oooo0P0Pk0L30?ooo`D08>`700<0oooo
023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L00P3o
ool01@0Pk0L0oooo023/1`0Pk0L0oooo00808>`700D00000023/1`0Pk0L08>`70?ooo`03023/1`04
0?ooo`0Pk0L08>`7023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00808>`72P3oool00`0P
k0L0oooo0?ooo`02023/1bT0oooo00<000000?ooo`3oool07P3oool001`0oooo00<000000?ooo`3o
ool08@3oool2023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool2023/1`040?ooo`0Pk0L08>`7023/
1`80oooo00D08>`70?ooo`3oool0oooo023/1`060?ooo`05023/1`3oool08>`7023/1`3oool0100P
k0L0103oool08>`70?ooo`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`P08>`7
0P3oool2023/1`80oooo0P0Pk0L20?ooo`808>`70`3oool5023/1`030?ooo`0Pk0L08>`700808>`7
00D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`70080oooo00D08>`70?ooo`0P
k0L08>`70?ooo`02023/1`030000000Pk0L08>`700808>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L3
0?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`X0oooo00<08>`70?ooo`3oool00P0Pk0LY
0?ooo`030000003oool0oooo01h0oooo000L0?ooo`030000003oool0oooo0240oooo0P0Pk0L30?oo
o`03023/1`3oool08>`70080oooo0P0Pk0L01`3oool08>`7023/1`3oool08>`70?ooo`0Pk0L00`3o
ool00`0Pk0L0oooo0?ooo`050?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`70?oo
o`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`P08>`70P3oool2023/1`80oooo
0P0Pk0L20?ooo`808>`70`3oool5023/1`040?ooo`0Pk0L08>`7023/1`80oooo2P0Pk0L00`3oool0
8>`7023/1`020?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L00`0000008>`7023/1`02023/
1`040?ooo`0Pk0L08>`70?ooo`808>`70`3oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/
1`0:0?ooo`03023/1`3oool0oooo00808>`7:@3oool00`000000oooo0?ooo`0N0?ooo`00703oool0
0`000000oooo0?ooo`0Q0?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`0Pk0L00P3oool2
023/1`070?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo00D0oooo
0`0Pk0L00`3oool08>`7023/1`02023/1`040?ooo`0Pk0L0oooo023/1`80oooo100Pk0L00`3oool0
8>`7023/1`02023/1`<0oooo200Pk0L20?ooo`808>`70P3oool2023/1`80oooo0P0Pk0L30?ooo`D0
8>`700@0oooo023/1`0Pk0L08>`70P3oool:023/1`030?ooo`0Pk0L08>`70080oooo0P0Pk0L00`3o
ool08>`70?ooo`02023/1`030000000Pk0L08>`700<08>`700D0oooo023/1`0Pk0L0oooo023/1`03
0?ooo`808>`70P3oool01@0Pk0L0oooo023/1`3oool08>`700X0oooo00<08>`70?ooo`3oool00P0P
k0LY0?ooo`030000003oool0oooo01h0oooo000L0?ooo`030000003oool0oooo0240oooo00<08>`7
0?ooo`0Pk0L00P3oool00`0Pk0L0oooo023/1`020?ooo`808>`700L0oooo023/1`0Pk0L0oooo023/
1`3oool08>`700<0oooo00<08>`70?ooo`3oool01@3oool3023/1`030?ooo`0Pk0L08>`700808>`7
00@0oooo023/1`3oool08>`70P3oool4023/1`030?ooo`0Pk0L08>`700808>`70`3oool8023/1`80
oooo0P0Pk0L20?ooo`808>`70P3oool2023/1`<0oooo1@0Pk0L0103oool08>`7023/1`0Pk0L20?oo
o`X08>`700<0oooo023/1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L0oooo00808>`700<00000023/
1`0Pk0L00`0Pk0L01@3oool08>`7023/1`3oool08>`700<0oooo0P0Pk0L20?ooo`05023/1`3oool0
8>`70?ooo`0Pk0L02P3oool00`0Pk0L0oooo0?ooo`02023/1bT0oooo00<000000?ooo`3oool07P3o
ool001`0oooo00<000000?ooo`3oool08@3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0
8>`70080oooo0P0Pk0L01`3oool08>`7023/1`3oool08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo
0?ooo`050?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`@0
8>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`P08>`70P3oool2023/1`80oooo0P0Pk0L20?ooo`80
8>`70`3oool5023/1`040?ooo`0Pk0L08>`7023/1`80oooo2P0Pk0L00`3oool08>`7023/1`020?oo
o`808>`700<0oooo023/1`3oool00P0Pk0L00`0000008>`7023/1`03023/1`050?ooo`0Pk0L08>`7
0?ooo`0Pk0L00`3oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/1`0:0?ooo`03023/1`3o
ool0oooo00808>`7:@3oool00`000000oooo0?ooo`0N0?ooo`00703oool00`000000oooo0?ooo`0Q
0?ooo`03023/1`3oool08>`700<0oooo0P0Pk0L20?ooo`808>`700L0oooo023/1`0Pk0L0oooo023/
1`3oool08>`700<0oooo00<08>`70?ooo`3oool01@3oool3023/1`030?ooo`0Pk0L08>`700808>`7
00@0oooo023/1`3oool08>`70P3oool4023/1`030?ooo`0Pk0L08>`700808>`70`3oool8023/1`80
oooo0P0Pk0L20?ooo`808>`70P3oool2023/1`<0oooo1@0Pk0L0103oool08>`7023/1`0Pk0L20?oo
o`X08>`700<0oooo023/1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L0oooo00808>`700@00000023/
1`0Pk0L0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700<0oooo0P0Pk0L20?ooo`05023/1`3o
ool08>`70?ooo`0Pk0L02P3oool01@0Pk0L0oooo023/1`3oool08>`702T0oooo00<000000?ooo`3o
ool07P3oool001`0oooo00<000000?ooo`3oool08@3oool00`0Pk0L0oooo023/1`030?ooo`808>`7
0P3oool2023/1`070?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo
00D0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`040?ooo`0Pk0L0oooo023/1`80oooo100Pk0L0
0`3oool08>`7023/1`02023/1`<0oooo200Pk0L20?ooo`808>`70P3oool2023/1`80oooo0P0Pk0L3
0?ooo`@08>`70P3oool3023/1`80oooo2P0Pk0L02P3oool08>`7023/1`3oool08>`70?ooo`0Pk0L0
oooo023/1`3oool2023/1`040000000Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L3
0?ooo`808>`70P3oool01@0Pk0L0oooo023/1`3oool08>`700X0oooo00D08>`70?ooo`0Pk0L0oooo
023/1`0Y0?ooo`030000003oool0oooo01h0oooo000L0?ooo`030000003oool0oooo0240oooo00<0
8>`70?ooo`0Pk0L00`3oool2023/1`80oooo0P0Pk0L01`3oool08>`7023/1`3oool08>`70?ooo`0P
k0L00`3oool00`0Pk0L0oooo0?ooo`050?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool0
8>`70?ooo`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`P08>`70P3oool2023/
1`80oooo0P0Pk0L20?ooo`808>`70`3oool4023/1`80oooo0`0Pk0L20?ooo`X08>`700X0oooo023/
1`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L0100000008>`7023/1`3oool2023/
1`030?ooo`0Pk0L08>`700808>`70`3oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/1`0:
0?ooo`05023/1`3oool08>`70?ooo`0Pk0L0:@3oool00`000000oooo0?ooo`0N0?ooo`00703oool0
0`000000oooo0?ooo`0Q0?ooo`03023/1`3oool08>`700<0oooo0P0Pk0L20?ooo`808>`700L0oooo
023/1`0Pk0L0oooo023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool01@3oool3023/1`030?oo
o`0Pk0L08>`700808>`700@0oooo023/1`3oool08>`70P3oool4023/1`030?ooo`0Pk0L08>`70080
8>`70`3oool8023/1`80oooo0P0Pk0L20?ooo`808>`70P3oool2023/1`<0oooo100Pk0L20?ooo`<0
8>`70P3oool:023/1`0:0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`808>`7
00@00000023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`<0oooo0P0Pk0L20?ooo`05
023/1`3oool08>`70?ooo`0Pk0L02P3oool01@0Pk0L0oooo023/1`3oool08>`702T0oooo00<00000
0?ooo`3oool07P3oool001`0oooo00<000000?ooo`3oool08@3oool00`0Pk0L0oooo023/1`030?oo
o`808>`70P3oool2023/1`070?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`030?ooo`03023/1`3o
ool0oooo00D0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`040?ooo`0Pk0L0oooo023/1`80oooo
100Pk0L00`3oool08>`7023/1`02023/1`<0oooo200Pk0L0103oool08>`7023/1`0Pk0L20?ooo`80
8>`70P3oool2023/1`<0oooo100Pk0L20?ooo`<08>`70P3oool:023/1`0:0?ooo`0Pk0L08>`70?oo
o`0Pk0L0oooo023/1`3oool08>`70?ooo`808>`700@00000023/1`0Pk0L0oooo0P0Pk0L00`3oool0
8>`7023/1`02023/1`<0oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L02P3oool01@0P
k0L0oooo023/1`3oool08>`702T0oooo00<000000?ooo`3oool07P3oool001`0oooo00<000000?oo
o`3oool08@3oool00`0Pk0L0oooo023/1`030?ooo`808>`70P3oool2023/1`070?ooo`0Pk0L08>`7
0?ooo`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo00D0oooo0`0Pk0L00`3oool08>`70?oo
o`02023/1`040?ooo`0Pk0L0oooo023/1`80oooo100Pk0L00`3oool08>`7023/1`02023/1`<0oooo
200Pk0L0103oool08>`7023/1`0Pk0L20?ooo`808>`70P3oool2023/1`<0oooo100Pk0L20?ooo`<0
8>`70P3oool:023/1`0:0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`808>`7
00@00000023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`<0oooo0P0Pk0L20?ooo`05
023/1`3oool08>`70?ooo`0Pk0L02@3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1bT0oooo00<0
00000?ooo`3oool07P3oool001`0oooo00<000000?ooo`3oool08@3oool00`0Pk0L0oooo023/1`03
0?ooo`808>`70P3oool2023/1`070?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`030?ooo`03023/
1`3oool0oooo00D0oooo0`0Pk0L00`3oool08>`70?ooo`02023/1`040?ooo`0Pk0L0oooo023/1`80
oooo100Pk0L00`3oool08>`7023/1`02023/1`<0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`04
0?ooo`0Pk0L08>`7023/1`80oooo0P0Pk0L20?ooo`808>`70`3oool4023/1`80oooo0`0Pk0L20?oo
o`D08>`700<0oooo023/1`0Pk0L00P0Pk0L02P3oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo
023/1`3oool2023/1`040000000Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?oo
o`808>`70P3oool01@0Pk0L0oooo023/1`3oool08>`700T0oooo00H08>`70?ooo`3oool08>`70?oo
o`0Pk0LY0?ooo`030000003oool0oooo01h0oooo000L0?ooo`030000003oool0oooo0240oooo00<0
8>`70?ooo`0Pk0L00`3oool2023/1`<0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`04
023/1`3oool0oooo023/1`L0oooo0`0Pk0L00`3oool08>`70?ooo`02023/1`040?ooo`0Pk0L0oooo
023/1`80oooo100Pk0L00`3oool08>`7023/1`02023/1`<0oooo0`0Pk0L00`3oool08>`7023/1`02
023/1`040?ooo`0Pk0L08>`7023/1`80oooo0P0Pk0L20?ooo`808>`70`3oool4023/1`80oooo0`0P
k0L20?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L02P3oool08>`7023/1`3oool08>`70?ooo`0P
k0L0oooo023/1`3oool2023/1`040000000Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L00P0P
k0L30?ooo`808>`70P3oool01@0Pk0L0oooo023/1`3oool08>`700T0oooo00H08>`70?ooo`3oool0
8>`70?ooo`0Pk0LY0?ooo`030000003oool0oooo01h0oooo000L0?ooo`030000003oool0oooo0240
oooo00<08>`70?ooo`0Pk0L00`3oool2023/1`<0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L2
0?ooo`04023/1`3oool0oooo023/1`L0oooo0`0Pk0L00`3oool08>`70?ooo`02023/1`040?ooo`0P
k0L0oooo023/1`80oooo100Pk0L00`3oool08>`7023/1`02023/1`<0oooo0`0Pk0L00`3oool08>`7
023/1`02023/1`040?ooo`0Pk0L08>`7023/1`80oooo0P0Pk0L20?ooo`808>`70`3oool4023/1`80
oooo0`0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L02P3oool08>`7023/1`3oool08>`7
0?ooo`0Pk0L0oooo023/1`3oool2023/1`040000000Pk0L08>`70?ooo`L08>`70`3oool2023/1`07
0?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`090?ooo`06023/1`3oool0oooo023/1`3oool08>`7
:@3oool00`000000oooo0?ooo`0N0?ooo`00703oool00`000000oooo0?ooo`0Q0?ooo`03023/1`3o
ool08>`700<0oooo0P0Pk0L30?ooo`06023/1`3oool08>`7023/1`3oool08>`70P3oool0100Pk0L0
oooo0?ooo`0Pk0L70?ooo`<08>`700<0oooo023/1`3oool00P0Pk0L0103oool08>`70?ooo`0Pk0L2
0?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L0
103oool08>`7023/1`0Pk0L20?ooo`808>`70P3oool2023/1`<0oooo100Pk0L20?ooo`<08>`70P3o
ool5023/1`030?ooo`0Pk0L08>`700808>`700X0oooo023/1`0Pk0L0oooo023/1`3oool08>`70?oo
o`0Pk0L0oooo0P0Pk0L0100000008>`7023/1`3oool7023/1`<0oooo0P0Pk0L01`3oool08>`70?oo
o`3oool08>`70?ooo`0Pk0L02@3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1bT0oooo00<00000
0?ooo`3oool07P3oool001`0oooo00<000000?ooo`3oool08@3oool00`0Pk0L0oooo023/1`030?oo
o`808>`70`3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`80oooo00@08>`70?ooo`3oool08>`7
1`3oool3023/1`030?ooo`0Pk0L0oooo00808>`700@0oooo023/1`3oool08>`70P3oool4023/1`03
0?ooo`0Pk0L08>`700808>`70`3oool3023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`0P
k0L08>`70P3oool2023/1`80oooo0P0Pk0L30?ooo`@08>`70P3oool3023/1`80oooo1@0Pk0L00`3o
ool08>`7023/1`02023/1`0:0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`80
8>`700@00000023/1`0Pk0L0oooo1`0Pk0L30?ooo`808>`700@0oooo023/1`3oool0oooo0P0Pk0L:
0?ooo`06023/1`3oool0oooo023/1`3oool08>`7:@3oool00`000000oooo0?ooo`0N0?ooo`00703o
ool00`000000oooo0?ooo`0Q0?ooo`03023/1`3oool08>`700<0oooo0P0Pk0L30?ooo`06023/1`3o
ool08>`7023/1`3oool08>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L70?ooo`<08>`700<0oooo023/
1`3oool0100Pk0L0103oool08>`70?ooo`3oool4023/1`030?ooo`0Pk0L08>`700808>`70`3oool3
023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`0Pk0L08>`70P3oool2023/1`80oooo0P0P
k0L30?ooo`@08>`70P3oool3023/1`80oooo1@0Pk0L00`3oool08>`7023/1`02023/1`0:0?ooo`0P
k0L08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`808>`700@00000023/1`0Pk0L0oooo1`0P
k0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3oool2023/1`X0oooo00H08>`70?ooo`3oool0
8>`70?ooo`0Pk0LY0?ooo`030000003oool0oooo01h0oooo000L0?ooo`030000003oool0oooo0240
oooo00<08>`70?ooo`0Pk0L00`3oool2023/1`<0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L2
0?ooo`04023/1`3oool0oooo023/1`L0oooo0`0Pk0L00`3oool08>`70?ooo`04023/1`040?ooo`0P
k0L0oooo0?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`<08>`700<0oooo023/1`0Pk0L0
0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`808>`70P3oool2023/1`<0oooo100Pk0L20?ooo`<0
8>`70P3oool5023/1`030?ooo`0Pk0L08>`700808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool2
023/1`80oooo0P0Pk0L0100000008>`7023/1`3oool7023/1`80oooo00D08>`70?ooo`0Pk0L0oooo
023/1`020?ooo`808>`72P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1bT0oooo00<000000?oo
o`3oool07P3oool001`0oooo00<000000?ooo`3oool08@3oool00`0Pk0L0oooo023/1`030?ooo`80
8>`70`3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`80oooo00@08>`70?ooo`3oool08>`71`3o
ool3023/1`030?ooo`0Pk0L0oooo00@08>`700@0oooo023/1`3oool0oooo100Pk0L00`3oool08>`7
023/1`02023/1`<0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`040?ooo`0Pk0L08>`7023/1`80
oooo0P0Pk0L20?ooo`808>`70`3oool4023/1`80oooo0`0Pk0L20?ooo`D08>`700<0oooo023/1`0P
k0L00P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`808>`70P3oool2023/1`040000000Pk0L0
8>`70?ooo`L08>`70P3oool2023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L:0?ooo`06023/1`3o
ool0oooo023/1`3oool08>`7:@3oool00`000000oooo0?ooo`0N0?ooo`00703oool00`000000oooo
0?ooo`0Q0?ooo`03023/1`3oool08>`700<0oooo0P0Pk0L30?ooo`06023/1`3oool0oooo023/1`3o
ool08>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L70?ooo`<08>`700<0oooo023/1`3oool0100Pk0L0
103oool08>`70?ooo`3oool4023/1`030?ooo`0Pk0L08>`700808>`70`3oool3023/1`030?ooo`0P
k0L08>`700808>`700@0oooo023/1`0Pk0L08>`70P3oool2023/1`80oooo0P0Pk0L30?ooo`@08>`7
0P3oool3023/1`80oooo1@0Pk0L00`3oool08>`7023/1`02023/1`060?ooo`0Pk0L08>`70?ooo`0P
k0L0oooo0P0Pk0L20?ooo`808>`700@00000023/1`0Pk0L0oooo1`0Pk0L20?ooo`808>`70P3oool0
0`0Pk0L0oooo0?ooo`02023/1`X0oooo00<08>`70?ooo`3oool00P0Pk0LZ0?ooo`030000003oool0
oooo01h0oooo000L0?ooo`030000003oool0oooo0240oooo00<08>`70?ooo`0Pk0L00`3oool2023/
1`<0oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L20?ooo`04023/1`3oool0oooo023/1`L0oooo
0`0Pk0L00`3oool08>`70?ooo`04023/1`040?ooo`0Pk0L0oooo0?ooo`@08>`700<0oooo023/1`0P
k0L00P0Pk0L30?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`7023/1`0Pk0L20?oo
o`808>`70P3oool2023/1`<0oooo100Pk0L20?ooo`<08>`70P3oool5023/1`030?ooo`0Pk0L08>`7
00808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool2023/1`80oooo0P0Pk0L0100000008>`7023/
1`3oool7023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00808>`72P3oool00`0Pk0L0oooo
0?ooo`02023/1bX0oooo00<000000?ooo`3oool07P3oool001`0oooo00<000000?ooo`3oool08@3o
ool00`0Pk0L0oooo023/1`030?ooo`808>`70`3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`80
oooo00@08>`70?ooo`3oool08>`71`3oool3023/1`030?ooo`0Pk0L0oooo00@08>`700@0oooo023/
1`3oool0oooo100Pk0L00`3oool08>`7023/1`02023/1`<0oooo0`0Pk0L00`3oool08>`7023/1`02
023/1`040?ooo`0Pk0L08>`7023/1`80oooo0P0Pk0L20?ooo`808>`70`3oool4023/1`80oooo0`0P
k0L20?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`80
8>`70P3oool2023/1`040000000Pk0L08>`70?ooo`L08>`70P3oool2023/1`80oooo00<08>`70?oo
o`3oool00P0Pk0L:0?ooo`03023/1`3oool0oooo00808>`7:P3oool00`000000oooo0?ooo`0N0?oo
o`00703oool00`000000oooo0?ooo`0Q0?ooo`03023/1`3oool08>`700<0oooo0P0Pk0L30?ooo`06
023/1`3oool0oooo023/1`3oool08>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L70?ooo`<08>`700<0
oooo023/1`3oool0100Pk0L0103oool08>`70?ooo`3oool4023/1`030?ooo`0Pk0L08>`700808>`7
0`3oool3023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`0Pk0L08>`70P3oool2023/1`80
oooo0P0Pk0L30?ooo`@08>`70P3oool3023/1`80oooo1@0Pk0L00`3oool08>`70?ooo`02023/1`06
0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L20?ooo`808>`700@00000023/1`0Pk0L0oooo1`0P
k0L20?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`X0oooo00<08>`70?ooo`3oool00P0P
k0LZ0?ooo`030000003oool0oooo01h0oooo000L0?ooo`030000003oool0oooo0240oooo00<08>`7
0?ooo`0Pk0L00`3oool2023/1`<0oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L20?ooo`04023/
1`3oool0oooo023/1`L0oooo0`0Pk0L00`3oool08>`70?ooo`04023/1`040?ooo`0Pk0L0oooo0?oo
o`@08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L0103o
ool08>`7023/1`0Pk0L20?ooo`808>`70P3oool2023/1`<0oooo100Pk0L20?ooo`<08>`70P3oool5
023/1`030?ooo`0Pk0L0oooo00808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool2023/1`80oooo
0P0Pk0L0100000008>`7023/1`3oool7023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0oooo0080
8>`72P3oool00`0Pk0L0oooo0?ooo`02023/1bX0oooo00<000000?ooo`3oool07P3oool001`0oooo
00<000000?ooo`3oool08@3oool00`0Pk0L0oooo023/1`030?ooo`808>`70`3oool01P0Pk0L0oooo
0?ooo`0Pk0L0oooo023/1`80oooo00@08>`70?ooo`3oool08>`71`3oool3023/1`030?ooo`0Pk0L0
oooo00H08>`70P3oool4023/1`030?ooo`0Pk0L08>`700808>`70`3oool3023/1`030?ooo`0Pk0L0
8>`700808>`700@0oooo023/1`0Pk0L08>`70P3oool2023/1`80oooo0P0Pk0L30?ooo`@08>`70P3o
ool3023/1`80oooo1@0Pk0L00`3oool08>`70?ooo`02023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0
oooo0P0Pk0L20?ooo`808>`700@00000023/1`0Pk0L0oooo1`0Pk0L20?ooo`808>`70P3oool00`0P
k0L0oooo0?ooo`02023/1`X0oooo00<08>`70?ooo`3oool00P0Pk0LZ0?ooo`030000003oool0oooo
01h0oooo000L0?ooo`030000003oool0oooo0240oooo00<08>`70?ooo`0Pk0L00`3oool2023/1`<0
oooo00<08>`70?ooo`3oool00`0Pk0L20?ooo`04023/1`3oool0oooo023/1`L0oooo0`0Pk0L00`3o
ool08>`70?ooo`06023/1`80oooo100Pk0L00`3oool08>`7023/1`02023/1`<0oooo0`0Pk0L00`3o
ool08>`7023/1`02023/1`040?ooo`0Pk0L08>`7023/1`80oooo0P0Pk0L20?ooo`808>`70`3oool4
023/1`80oooo0`0Pk0L20?ooo`D08>`700<0oooo023/1`3oool00P0Pk0L01P3oool08>`7023/1`3o
ool08>`70?ooo`808>`70P3oool2023/1`040000000Pk0L08>`70?ooo`L08>`70P3oool2023/1`80
oooo00<08>`70?ooo`3oool00P0Pk0L:0?ooo`03023/1`3oool0oooo00808>`7:P3oool00`000000
oooo0?ooo`0N0?ooo`00703oool00`000000oooo0?ooo`0Q0?ooo`03023/1`3oool08>`700<0oooo
00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`03023/1`80oooo00@08>`70?ooo`3oool0
8>`71`3oool3023/1`030?ooo`0Pk0L0oooo00H08>`70P3oool9023/1`<0oooo0`0Pk0L00`3oool0
8>`7023/1`02023/1`040?ooo`0Pk0L08>`7023/1`80oooo0P0Pk0L20?ooo`808>`70`3oool4023/
1`80oooo0`0Pk0L20?ooo`D08>`700<0oooo023/1`3oool00P0Pk0L01P3oool08>`7023/1`3oool0
8>`70?ooo`808>`70P3oool2023/1`040000000Pk0L08>`70?ooo`L08>`70P3oool2023/1`80oooo
00D08>`70?ooo`0Pk0L0oooo023/1`0:0?ooo`05023/1`3oool08>`70?ooo`0Pk0L0:P3oool00`00
0000oooo0?ooo`0N0?ooo`00703oool00`000000oooo0?ooo`0Q0?ooo`03023/1`3oool08>`700<0
oooo00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`03023/1`80oooo00@08>`70?ooo`3o
ool08>`71`3oool3023/1`030?ooo`0Pk0L0oooo00H08>`70P3oool9023/1`<0oooo0`0Pk0L00`3o
ool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`808>`70`3oool4
023/1`80oooo0`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L0oooo00D08>`700<0oooo
023/1`3oool00P0Pk0L20?ooo`808>`700@00000023/1`0Pk0L0oooo1`0Pk0L20?ooo`808>`70P3o
ool01@0Pk0L0oooo023/1`3oool08>`700X0oooo00D08>`70?ooo`0Pk0L0oooo023/1`0Z0?ooo`03
0000003oool0oooo01h0oooo000L0?ooo`030000003oool0oooo0240oooo00<08>`70?ooo`0Pk0L0
0`3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo00<08>`70P3oool0100Pk0L0oooo
0?ooo`0Pk0L70?ooo`<08>`700<0oooo023/1`3oool01P0Pk0L20?ooo`T08>`70`3oool3023/1`03
0?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo0P0Pk0L30?oo
o`@08>`70P3oool3023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`3oool01@0Pk0L00`3o
ool08>`70?ooo`02023/1`80oooo0P0Pk0L0100000008>`7023/1`3oool6023/1`<0oooo0P0Pk0L2
0?ooo`05023/1`3oool08>`70?ooo`0Pk0L02P3oool01@0Pk0L0oooo023/1`3oool08>`702X0oooo
00<000000?ooo`3oool07P3oool001`0oooo00<000000?ooo`3oool08@3oool00`0Pk0L0oooo023/
1`030?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`3oool00`0Pk0L20?ooo`03023/1`3o
ool0oooo00808>`71P3oool3023/1`030?ooo`0Pk0L0oooo00H08>`70P3oool:023/1`80oooo0`0P
k0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`808>`7
0`3oool4023/1`80oooo0`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L0oooo00D08>`7
00<0oooo023/1`3oool00P0Pk0L01@3oool08>`7023/1`0Pk0L0000000808>`700<0oooo023/1`0P
k0L0100Pk0L30?ooo`808>`70P3oool01@0Pk0L0oooo023/1`3oool08>`700X0oooo00D08>`70?oo
o`0Pk0L0oooo023/1`0Z0?ooo`030000003oool0oooo01h0oooo000L0?ooo`030000003oool0oooo
0240oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo
00<08>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`H0oooo0`0Pk0L00`3oool08>`70?ooo`06023/
1`80oooo2P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0
oooo00<08>`70P3oool2023/1`<0oooo100Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L0
0`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/1`0Pk0L08>`70000
0003023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70`3oool2023/1`80oooo00D08>`70?ooo`0P
k0L0oooo023/1`0:0?ooo`05023/1`3oool08>`70?ooo`0Pk0L0:P3oool00`000000oooo0?ooo`0N
0?ooo`00703oool00`000000oooo0?ooo`0Q0?ooo`03023/1`3oool08>`700@0oooo0P0Pk0L20?oo
o`03023/1`3oool0oooo00<08>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`H0oooo0`0Pk0L00`3o
ool08>`70?ooo`06023/1`80oooo2P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00<08>`70P3oool2023/1`<0oooo100Pk0L20?ooo`<08>`700<0oooo
023/1`0Pk0L0100Pk0L00`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L0oooo00808>`700D0oooo
023/1`0Pk0L08>`700000003023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70`3oool2023/1`80
oooo00D08>`70?ooo`0Pk0L0oooo023/1`090?ooo`06023/1`3oool0oooo023/1`3oool08>`7:P3o
ool00`000000oooo0?ooo`0N0?ooo`00703oool00`000000oooo0?ooo`0Q0?ooo`03023/1`3oool0
8>`700@0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00<08>`70P3oool00`0Pk0L0oooo0?ooo`02
023/1`H0oooo0`0Pk0L00`3oool08>`70?ooo`06023/1`80oooo2P0Pk0L20?ooo`<08>`700<0oooo
023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70P3oool2023/1`<0oooo100P
k0L20?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0P
k0L0oooo00808>`700D0oooo023/1`0Pk0L08>`700000003023/1`060?ooo`0Pk0L08>`7023/1`3o
ool08>`70`3oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/1`090?ooo`06023/1`3oool0
oooo023/1`3oool08>`7:P3oool00`000000oooo0?ooo`0N0?ooo`00703oool00`000000oooo0?oo
o`0R0?ooo`808>`7103oool2023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L0103oool08>`70?oo
o`0Pk0L20?ooo`808>`71P3oool3023/1`030?ooo`0Pk0L0oooo00H08>`70P3oool:023/1`80oooo
0`0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L0103oool0
8>`70?ooo`0Pk0L30?ooo`@08>`70P3oool3023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/
1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L0oooo023/1`0000000`0Pk0L0
1P3oool08>`7023/1`0Pk0L0oooo023/1`<0oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0P
k0L02@3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1bX0oooo00<000000?ooo`3oool07P3oool0
01`0oooo00<000000?ooo`3oool08P3oool2023/1`@0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo
00808>`700@0oooo023/1`3oool08>`70P3oool2023/1`H0oooo0`0Pk0L00`3oool08>`70?ooo`07
023/1`030?ooo`0Pk0L08>`700P08>`70P3oool3023/1`030?ooo`0Pk0L08>`700808>`700D0oooo
023/1`0Pk0L08>`70?ooo`03023/1`040?ooo`0Pk0L0oooo023/1`<0oooo100Pk0L20?ooo`<08>`7
00<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`04023/1`80oooo00T08>`70?ooo`0Pk0L0
8>`70?ooo`0Pk0L0oooo023/1`0000000`0Pk0L00`3oool08>`7023/1`03023/1`<0oooo0P0Pk0L2
0?ooo`05023/1`3oool08>`70?ooo`0Pk0L02@3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1bX0
oooo00<000000?ooo`3oool07P3oool001`0oooo00<000000?ooo`3oool08P3oool2023/1`@0oooo
0P0Pk0L20?ooo`03023/1`3oool0oooo00808>`700@0oooo023/1`3oool08>`70P3oool2023/1`H0
oooo0`0Pk0L00`3oool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`700P08>`70P3oool3023/1`03
0?ooo`0Pk0L08>`700808>`700D0oooo023/1`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L0oooo
023/1`<0oooo100Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`04
023/1`80oooo00T08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`0000000`0Pk0L00`3oool0
8>`7023/1`03023/1`<0oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L02@3oool01P0P
k0L0oooo0?ooo`0Pk0L0oooo023/1bX0oooo00<000000?ooo`3oool07P3oool001`0oooo00<00000
0?ooo`3oool08P3oool2023/1`@0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00808>`700@0oooo
023/1`3oool08>`70P3oool2023/1`H0oooo0`0Pk0L00`3oool08>`70?ooo`07023/1`030?ooo`0P
k0L08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00P0P
k0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L08>`70`3oool4023/1`80
oooo0`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700@08>`70P3oool02@0Pk0L0
oooo023/1`0Pk0L0oooo023/1`3oool08>`700000003023/1`030?ooo`0Pk0L08>`700<08>`70`3o
ool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/1`090?ooo`06023/1`3oool0oooo023/1`3o
ool08>`7:P3oool00`000000oooo0?ooo`0N0?ooo`00703oool00`000000oooo0?ooo`0R0?ooo`80
8>`7103oool2023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L0103oool08>`70?ooo`0Pk0L20?oo
o`808>`71P3oool3023/1`030?ooo`0Pk0L0oooo00L08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3o
ool08>`7023/1`03023/1`80oooo0`0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L0oooo
023/1`3oool00`0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`@08>`70P3oool3023/1`030?ooo`0P
k0L08>`700@08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`808>`700<0oooo023/1`3oool00`0P
k0L01@0000008>`70?ooo`0Pk0L0oooo00D08>`70`3oool2023/1`80oooo00D08>`70?ooo`0Pk0L0
oooo023/1`090?ooo`06023/1`3oool0oooo023/1`3oool08>`7:P3oool00`000000oooo0?ooo`0N
0?ooo`00703oool00`000000oooo0?ooo`0R0?ooo`808>`7103oool2023/1`80oooo00<08>`70?oo
o`3oool00P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`808>`71P3oool3023/1`030?ooo`0Pk0L0
oooo00L08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo0`0Pk0L0
0`3oool08>`7023/1`02023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L0103oool08>`7023/
1`0Pk0L30?ooo`@08>`70P3oool3023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L0
100Pk0L20?ooo`808>`700<0oooo023/1`3oool00`0Pk0L01@0000008>`70?ooo`0Pk0L0oooo00D0
8>`70`3oool2023/1`070?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`090?ooo`06023/1`3oool0
oooo023/1`3oool08>`7:P3oool00`000000oooo0?ooo`0N0?ooo`00703oool00`000000oooo0?oo
o`0R0?ooo`808>`7103oool2023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L0103oool08>`70?oo
o`0Pk0L20?ooo`808>`71P3oool3023/1`030?ooo`0Pk0L0oooo00L08>`700<0oooo023/1`0Pk0L0
0P0Pk0L00`3oool08>`7023/1`03023/1`80oooo0`0Pk0L00`3oool08>`7023/1`02023/1`050?oo
o`0Pk0L0oooo023/1`3oool00`0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`@08>`70P3oool3023/
1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`808>`700<0oooo023/
1`3oool00`0Pk0L01@0000008>`70?ooo`0Pk0L0oooo00D08>`70`3oool2023/1`070?ooo`0Pk0L0
oooo0?ooo`0Pk0L0oooo023/1`090?ooo`06023/1`3oool0oooo023/1`3oool08>`7:P3oool00`00
0000oooo0?ooo`0N0?ooo`00703oool00`000000oooo0?ooo`0R0?ooo`808>`7103oool2023/1`80
oooo00<08>`70?ooo`3oool00P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`808>`71P3oool3023/
1`030?ooo`0Pk0L0oooo00L08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/
1`80oooo0`0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L0
103oool08>`7023/1`0Pk0L30?ooo`@08>`70P3oool3023/1`030?ooo`0Pk0L08>`700@08>`700<0
oooo023/1`0Pk0L0100Pk0L20?ooo`808>`700<0oooo023/1`3oool00`0Pk0L01@0000008>`70?oo
o`0Pk0L0oooo00D08>`70`3oool2023/1`070?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`090?oo
o`06023/1`3oool0oooo023/1`3oool08>`7:P3oool00`000000oooo0?ooo`0N0?ooo`00703oool0
0`000000oooo0?ooo`0R0?ooo`808>`7103oool2023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L0
103oool08>`70?ooo`0Pk0L20?ooo`808>`71P3oool3023/1`030?ooo`0Pk0L0oooo00L08>`700<0
oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0oooo00<08>`700<0
oooo023/1`0Pk0L00P0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L0
8>`70`3oool4023/1`80oooo0`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700@0
8>`70P3oool2023/1`030?ooo`0Pk0L0oooo00<08>`700D00000023/1`3oool08>`70?ooo`05023/
1`<0oooo0P0Pk0L01`3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L02@3oool01P0Pk0L0oooo0?oo
o`0Pk0L0oooo023/1bX0oooo00<000000?ooo`3oool07P3oool001`0oooo00<000000?ooo`3oool0
8P3oool2023/1`@0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00808>`700@0oooo023/1`3oool0
8>`70P3oool2023/1`H0oooo0`0Pk0L00`3oool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`70080
8>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`08023/1`050?ooo`0Pk0L0oooo023/
1`3oool00`0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`@08>`70P3oool3023/1`030?ooo`0Pk0L0
8>`700@08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`808>`700<0oooo023/1`3oool00`0Pk0L0
1@0000008>`70?ooo`0Pk0L0oooo00D08>`70`3oool2023/1`070?ooo`0Pk0L0oooo0?ooo`0Pk0L0
oooo023/1`090?ooo`06023/1`3oool0oooo023/1`3oool08>`7:`3oool00`000000oooo0?ooo`0M
0?ooo`00703oool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool08>`700<0oooo0P0Pk0L20?oo
o`03023/1`3oool0oooo00808>`700@0oooo023/1`3oool08>`70P3oool2023/1`H0oooo0`0Pk0L2
0?ooo`P08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0
oooo00P08>`700D0oooo023/1`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L08>`7023/1`<0oooo
100Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`04023/1`070?oo
o`0Pk0L0oooo023/1`3oool08>`70?ooo`03023/1`050000000Pk0L0oooo023/1`3oool01@0Pk0L3
0?ooo`808>`700L0oooo023/1`3oool0oooo023/1`3oool08>`700T0oooo00H08>`70?ooo`3oool0
8>`70?ooo`0Pk0L[0?ooo`030000003oool0oooo01d0oooo000L0?ooo`030000003oool0oooo0280
oooo00<08>`70?ooo`0Pk0L00`3oool2023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L0103oool0
8>`70?ooo`0Pk0L20?ooo`808>`71P3oool3023/1`80oooo200Pk0L00`3oool08>`7023/1`02023/
1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool0200Pk0L01@3oool08>`70?ooo`0Pk0L0
oooo00<08>`700@0oooo023/1`0Pk0L08>`70`3oool4023/1`80oooo0`0Pk0L00`3oool08>`7023/
1`04023/1`030?ooo`0Pk0L08>`700@08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00<0
8>`700D00000023/1`3oool08>`70?ooo`05023/1`<0oooo0P0Pk0L01`3oool08>`70?ooo`3oool0
8>`70?ooo`0Pk0L02@3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1b/0oooo00<000000?ooo`3o
ool07@3oool001`0oooo00<000000?ooo`3oool08P3oool00`0Pk0L0oooo023/1`030?ooo`808>`7
0P3oool2023/1`070?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`020?ooo`808>`71P3oool3023/
1`80oooo200Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/
1`3oool0200Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L08>`70`3o
ool4023/1`80oooo0`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700@08>`700L0
oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00<08>`700D00000023/1`3oool08>`70?ooo`05023/
1`<0oooo0P0Pk0L01`3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L02@3oool01P0Pk0L0oooo0?oo
o`0Pk0L0oooo023/1b/0oooo00<000000?ooo`3oool07@3oool001`0oooo00<000000?ooo`3oool0
8P3oool00`0Pk0L0oooo023/1`030?ooo`808>`70P3oool2023/1`070?ooo`0Pk0L08>`70?ooo`0P
k0L0oooo023/1`020?ooo`808>`71P3oool3023/1`80oooo200Pk0L00`3oool08>`7023/1`02023/
1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool0200Pk0L01@3oool08>`70?ooo`0Pk0L0
oooo00<08>`700@0oooo023/1`0Pk0L08>`70`3oool4023/1`80oooo0`0Pk0L00`3oool08>`7023/
1`04023/1`030?ooo`0Pk0L08>`700@08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00<0
8>`700D00000023/1`3oool08>`70?ooo`05023/1`<0oooo0P0Pk0L01`3oool08>`70?ooo`3oool0
8>`70?ooo`0Pk0L02@3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo02T0oooo00<0
00000?ooo`3oool07@3oool001`0oooo00<000000?ooo`3oool08P3oool00`0Pk0L0oooo023/1`03
0?ooo`808>`70P3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo023/
1`0Pk0L60?ooo`<08>`70P3oool8023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L0
0P0Pk0L00`3oool08>`70?ooo`08023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L0103oool0
8>`7023/1`0Pk0L30?ooo`@08>`70P3oool3023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/
1`0Pk0L0100Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L01@0000008>`70?oo
o`0Pk0L0oooo00D08>`70`3oool2023/1`070?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`090?oo
o`03023/1`3oool08>`70080oooo00<08>`70?ooo`3oool0:@3oool00`000000oooo0?ooo`0M0?oo
o`00703oool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool08>`700<0oooo0P0Pk0L20?ooo`80
8>`700D0oooo023/1`0Pk0L0oooo023/1`020?ooo`04023/1`3oool08>`7023/1`H0oooo0`0Pk0L2
0?ooo`P08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0
oooo00P08>`700D0oooo023/1`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L08>`7023/1`<0oooo
100Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`04023/1`070?oo
o`0Pk0L0oooo023/1`3oool08>`70?ooo`03023/1`050000000Pk0L0oooo023/1`3oool01@0Pk0L3
0?ooo`808>`700L0oooo023/1`3oool0oooo023/1`3oool08>`700T0oooo00<08>`70?ooo`0Pk0L0
0P3oool00`0Pk0L0oooo0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo000L0?ooo`030000003o
ool0oooo0280oooo00<08>`70?ooo`0Pk0L00`3oool2023/1`80oooo0P0Pk0L01@3oool08>`7023/
1`3oool08>`70080oooo00@08>`70?ooo`0Pk0L08>`71P3oool3023/1`80oooo200Pk0L00`3oool0
8>`7023/1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool0200Pk0L01@3oool0
8>`70?ooo`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L08>`70`3oool4023/1`80oooo0`0Pk0L0
0`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700@08>`700L0oooo023/1`3oool08>`70?oo
o`0Pk0L0oooo00<08>`700D00000023/1`3oool08>`70?ooo`05023/1`<0oooo0P0Pk0L01`3oool0
8>`70?ooo`3oool08>`70?ooo`0Pk0L02@3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0
oooo02T0oooo00<000000?ooo`3oool07@3oool001`0oooo00<000000?ooo`3oool08P3oool00`0P
k0L0oooo023/1`030?ooo`808>`70P3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00P3oool0
100Pk0L0oooo023/1`0Pk0L60?ooo`<08>`70P3oool8023/1`030?ooo`0Pk0L08>`700808>`700<0
oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`08023/1`050?ooo`0Pk0L0oooo023/1`3oool0
0`0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`@08>`70P3oool3023/1`030?ooo`0Pk0L08>`700/0
8>`700<0oooo023/1`3oool00P0Pk0L20?ooo`<08>`700<00000023/1`3oool00P0Pk0L00`3oool0
8>`7023/1`02023/1`<0oooo0P0Pk0L01P3oool08>`70?ooo`0Pk0L0oooo023/1`X0oooo00D08>`7
0?ooo`0Pk0L0oooo023/1`0/0?ooo`030000003oool0oooo01d0oooo000L0?ooo`030000003oool0
oooo0280oooo00<08>`70?ooo`0Pk0L00`3oool2023/1`80oooo0P0Pk0L01@3oool08>`7023/1`3o
ool08>`70080oooo00@08>`70?ooo`0Pk0L08>`71P3oool3023/1`80oooo200Pk0L00`3oool08>`7
023/1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool0200Pk0L01@3oool08>`7
0?ooo`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L08>`70`3oool4023/1`80oooo0`0Pk0L00`3o
ool08>`7023/1`0;023/1`030?ooo`0Pk0L0oooo00808>`70P3oool3023/1`030000000Pk0L0oooo
00808>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`0P
k0L:0?ooo`05023/1`3oool08>`70?ooo`0Pk0L0;03oool00`000000oooo0?ooo`0M0?ooo`00703o
ool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool08>`700<0oooo0P0Pk0L20?ooo`808>`700D0
oooo023/1`0Pk0L0oooo023/1`020?ooo`04023/1`3oool08>`7023/1`H0oooo0`0Pk0L20?ooo`P0
8>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`80oooo2@0Pk0L01@3oool0
8>`70?ooo`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L08>`70`3oool4023/1`80oooo0`0Pk0L0
0`3oool08>`7023/1`0;023/1`030?ooo`0Pk0L0oooo00808>`70P3oool3023/1`030000000Pk0L0
oooo00808>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`808>`700H0oooo023/1`3oool08>`70?oo
o`0Pk0L90?ooo`06023/1`3oool0oooo023/1`3oool08>`7;03oool00`000000oooo0?ooo`0M0?oo
o`00703oool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool08>`700<0oooo0P0Pk0L20?ooo`80
8>`700D0oooo023/1`0Pk0L0oooo023/1`020?ooo`04023/1`3oool0oooo023/1`H0oooo0`0Pk0L2
0?ooo`P08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`80oooo2@0Pk0L0
1@3oool08>`70?ooo`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L08>`70`3oool4023/1`80oooo
0`0Pk0L00`3oool08>`7023/1`0;023/1`030?ooo`0Pk0L0oooo00808>`70P3oool3023/1`030000
000Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`808>`700H0oooo023/1`3oool0
8>`70?ooo`0Pk0L90?ooo`06023/1`3oool0oooo023/1`3oool08>`7;03oool00`000000oooo0?oo
o`0M0?ooo`00703oool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool08>`700<0oooo0P0Pk0L2
0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`020?ooo`04023/1`3oool0oooo023/1`H0oooo0`0P
k0L20?ooo`P08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`70P3oool9023/1`050?ooo`0P
k0L0oooo023/1`3oool00`0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`@08>`70P3oool3023/1`03
0?ooo`0Pk0L08>`700/08>`700<0oooo023/1`3oool00P0Pk0L20?ooo`<08>`700<00000023/1`3o
ool00P0Pk0L00`3oool08>`7023/1`02023/1`<0oooo0P0Pk0L01P3oool08>`70?ooo`0Pk0L0oooo
023/1`T0oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L/0?ooo`030000003oool0oooo01d0oooo
000L0?ooo`030000003oool0oooo0280oooo00<08>`70?ooo`0Pk0L00`3oool2023/1`80oooo0P0P
k0L20?ooo`03023/1`3oool08>`70080oooo00@08>`70?ooo`3oool08>`71P3oool3023/1`80oooo
200Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L20?ooo`T08>`700D0oooo023/1`3oool0
8>`70?ooo`03023/1`040?ooo`0Pk0L08>`7023/1`<0oooo100Pk0L20?ooo`<08>`700<0oooo023/
1`0Pk0L0200Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`808>`70P3oool3023/1`030000000P
k0L0oooo00808>`700@0oooo023/1`0Pk0L08>`7103oool2023/1`060?ooo`0Pk0L0oooo023/1`3o
ool08>`72@3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1b`0oooo00<000000?ooo`3oool07@3o
ool001`0oooo00<000000?ooo`3oool08P3oool00`0Pk0L0oooo023/1`030?ooo`808>`70P3oool2
023/1`80oooo00<08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`0Pk0L60?ooo`<08>`70P3o
ool8023/1`030?ooo`0Pk0L08>`700808>`70P3oool3023/1`80oooo2@0Pk0L01@3oool08>`70?oo
o`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L08>`70`3oool4023/1`80oooo0`0Pk0L00`3oool0
8>`7023/1`08023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L20?ooo`<08>`700<00000
023/1`3oool00P0Pk0L0103oool08>`7023/1`0Pk0L40?ooo`808>`700H0oooo023/1`3oool08>`7
0?ooo`0Pk0L90?ooo`06023/1`3oool0oooo023/1`3oool08>`7;03oool00`000000oooo0?ooo`0M
0?ooo`00703oool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool08>`700<0oooo0P0Pk0L20?oo
o`808>`70P3oool00`0Pk0L0oooo023/1`020?ooo`04023/1`3oool0oooo023/1`H0oooo0`0Pk0L2
0?ooo`P08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`70P3oool9023/1`050?ooo`0Pk0L0
oooo023/1`3oool00`0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`@08>`70P3oool3023/1`030?oo
o`0Pk0L08>`700P08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool2023/1`80oooo0`0Pk0L00`00
00008>`70?ooo`02023/1`040?ooo`0Pk0L08>`7023/1`@0oooo0P0Pk0L01P3oool08>`70?ooo`0P
k0L0oooo023/1`T0oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L/0?ooo`030000003oool0oooo
01d0oooo000L0?ooo`030000003oool0oooo0280oooo00<08>`70?ooo`0Pk0L0103oool00`0Pk0L0
oooo0?ooo`02023/1`80oooo00<08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo0?ooo`0Pk0L60?oo
o`<08>`70P3oool00`0Pk0L0oooo023/1`05023/1`030?ooo`0Pk0L08>`700808>`70P3oool3023/
1`80oooo2@0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L08>`70`3o
ool4023/1`80oooo0`0Pk0L00`3oool08>`7023/1`08023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0
oooo0P0Pk0L20?ooo`<08>`700<00000023/1`3oool00P0Pk0L0103oool08>`70?ooo`0Pk0L30?oo
o`808>`70P3oool01@0Pk0L0oooo023/1`3oool08>`700T0oooo00H08>`70?ooo`3oool08>`70?oo
o`0Pk0L/0?ooo`030000003oool0oooo01d0oooo000L0?ooo`030000003oool0oooo0280oooo00<0
8>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`02023/1`80oooo0`0Pk0L20?ooo`04023/1`3o
ool0oooo023/1`H0oooo0`0Pk0L20?ooo`03023/1`3oool08>`700D08>`700<0oooo023/1`0Pk0L0
0P0Pk0L20?ooo`<08>`70P3oool9023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L0103oool0
8>`7023/1`0Pk0L30?ooo`@08>`70P3oool3023/1`030?ooo`0Pk0L08>`700P08>`700H0oooo023/
1`0Pk0L0oooo023/1`3oool2023/1`80oooo0`0Pk0L00`0000008>`70?ooo`02023/1`040?ooo`0P
k0L0oooo023/1`<0oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L02@3oool01P0Pk0L0
oooo0?ooo`0Pk0L0oooo023/1b`0oooo00<000000?ooo`3oool07@3oool001`0oooo00<000000?oo
o`3oool08P3oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00808>`70P3oool3023/
1`80oooo00@08>`70?ooo`3oool08>`71P3oool3023/1`80oooo00<08>`70?ooo`0Pk0L01@0Pk0L0
0`3oool08>`7023/1`02023/1`80oooo0`0Pk0L20?ooo`T08>`700D0oooo023/1`3oool08>`70?oo
o`03023/1`040?ooo`0Pk0L08>`7023/1`80oooo1@0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0
200Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`808>`70P3oool3023/1`090000000Pk0L08>`7
0?ooo`0Pk0L0oooo023/1`3oool08>`700<0oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0P
k0L02@3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1b`0oooo00<000000?ooo`3oool07@3oool0
01`0oooo00<000000?ooo`3oool08P3oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo
00808>`70P3oool3023/1`80oooo00@08>`70?ooo`3oool08>`71P3oool3023/1`80oooo00<08>`7
0?ooo`0Pk0L01@0Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L20?ooo`T08>`700D0oooo
023/1`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L08>`7023/1`80oooo1@0Pk0L20?ooo`<08>`7
00<0oooo023/1`0Pk0L0200Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`808>`70P3oool3023/
1`040000000Pk0L08>`70?ooo`<08>`700<0oooo023/1`3oool00P3oool2023/1`80oooo00D08>`7
0?ooo`0Pk0L0oooo023/1`090?ooo`06023/1`3oool0oooo023/1`3oool08>`7;03oool00`000000
oooo0?ooo`0M0?ooo`00703oool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool08>`700@0oooo
00<08>`70?ooo`3oool00P0Pk0L20?ooo`<08>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L60?ooo`<0
8>`70P3oool00`0Pk0L0oooo023/1`05023/1`030?ooo`0Pk0L08>`700808>`70P3oool3023/1`80
oooo2@0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L08>`70P3oool5
023/1`80oooo0`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700808>`700H0oooo
023/1`0Pk0L0oooo023/1`3oool2023/1`80oooo0`0Pk0L0100000008>`7023/1`3oool5023/1`<0
oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L02@3oool01P0Pk0L0oooo0?ooo`0Pk0L0
oooo023/1b`0oooo00<000000?ooo`3oool07@3oool001`0oooo00<000000?ooo`3oool08P3oool0
0`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00808>`70P3oool3023/1`80oooo00@08>`7
0?ooo`3oool08>`71P3oool4023/1`030?ooo`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L00P0P
k0L20?ooo`<08>`70P3oool9023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L0103oool08>`7
023/1`0Pk0L20?ooo`D08>`70P3oool3023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0P
k0L00P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`808>`70P3oool3023/1`040000000Pk0L0
8>`70?ooo`D08>`70`3oool2023/1`070?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`090?ooo`06
023/1`3oool0oooo023/1`3oool08>`7;03oool00`000000oooo0?ooo`0M0?ooo`00703oool00`00
0000oooo0?ooo`0R0?ooo`03023/1`3oool08>`700@0oooo00D08>`70?ooo`3oool0oooo023/1`02
0?ooo`808>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`@08>`700<0
oooo023/1`3oool01P0Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L20?ooo`T08>`700D0
oooo023/1`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L08>`7023/1`80oooo1@0Pk0L20?ooo`<0
8>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`02023/1`060?ooo`0Pk0L08>`70?oo
o`0Pk0L0oooo0P0Pk0L20?ooo`<08>`700@00000023/1`0Pk0L0oooo1@0Pk0L30?ooo`808>`700L0
oooo023/1`3oool0oooo023/1`3oool08>`700T0oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L/
0?ooo`030000003oool0oooo01d0oooo000L0?ooo`030000003oool0oooo0280oooo00<08>`70?oo
o`0Pk0L0103oool01@0Pk0L0oooo0?ooo`3oool08>`70080oooo0P0Pk0L0103oool08>`70?ooo`0P
k0L20?ooo`03023/1`3oool0oooo00@0oooo100Pk0L00`3oool08>`70?ooo`06023/1`030?ooo`0P
k0L08>`700808>`70P3oool3023/1`80oooo2@0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`7
00@0oooo023/1`0Pk0L08>`70P3oool5023/1`80oooo0`0Pk0L00`3oool08>`7023/1`03023/1`03
0?ooo`0Pk0L08>`700808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool2023/1`80oooo0`0Pk0L0
100000008>`7023/1`3oool5023/1`<0oooo0P0Pk0L01`3oool08>`70?ooo`3oool08>`70?ooo`0P
k0L02@3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1b`0oooo00<000000?ooo`3oool07@3oool0
01`0oooo00<000000?ooo`3oool08P3oool00`0Pk0L0oooo023/1`040?ooo`05023/1`3oool0oooo
0?ooo`0Pk0L00P3oool2023/1`040?ooo`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`3oool0103o
ool4023/1`050?ooo`0Pk0L0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`80oooo
0`0Pk0L20?ooo`T08>`700D0oooo023/1`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L08>`7023/
1`80oooo100Pk0L30?ooo`<08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`02023/
1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`040000000P
k0L08>`70?ooo`D08>`70`3oool2023/1`070?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`090?oo
o`03023/1`3oool08>`70080oooo00<08>`70?ooo`3oool0:P3oool00`000000oooo0?ooo`0M0?oo
o`00703oool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool08>`700@0oooo00D08>`70?ooo`3o
ool0oooo023/1`020?ooo`808>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`04
0?ooo`@08>`700D0oooo023/1`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`70P3o
ool3023/1`80oooo2@0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L0
8>`70P3oool4023/1`<0oooo0`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`70080
8>`700H0oooo023/1`0Pk0L0oooo023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`700@00000
023/1`0Pk0L0oooo1@0Pk0L30?ooo`808>`700L0oooo023/1`3oool0oooo023/1`3oool08>`700T0
oooo00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`0Z0?ooo`030000003oool0oooo01d0
oooo000L0?ooo`030000003oool0oooo0280oooo00<08>`70?ooo`0Pk0L0103oool01@0Pk0L0oooo
0?ooo`3oool08>`70080oooo0P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`03023/1`3oool0oooo
00@0oooo100Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L2
0?ooo`<08>`70P3oool6023/1`080?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`04
0?ooo`0Pk0L08>`7023/1`80oooo100Pk0L30?ooo`<08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L0
0`3oool08>`7023/1`02023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L00`3oool08>`7
023/1`02023/1`040000000Pk0L08>`70?ooo`D08>`70`3oool2023/1`070?ooo`0Pk0L0oooo0?oo
o`0Pk0L0oooo023/1`090?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0M0?ooo`00703oool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool08>`7
00@0oooo00D08>`70?ooo`3oool0oooo023/1`020?ooo`808>`700@0oooo023/1`3oool08>`70P3o
ool00`0Pk0L0oooo0?ooo`040?ooo`@08>`700D0oooo023/1`3oool08>`70?ooo`04023/1`030?oo
o`0Pk0L08>`700808>`70P3oool3023/1`80oooo1P0Pk0L0203oool08>`7023/1`3oool08>`70?oo
o`0Pk0L0oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`@08>`70`3oool3023/1`040?ooo`0P
k0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L01P3oool08>`7023/1`3oool08>`70?oo
o`808>`700<0oooo023/1`0Pk0L00P0Pk0L0100000008>`7023/1`3oool5023/1`<0oooo0P0Pk0L0
1`3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L02@3oool00`0Pk0L0oooo023/1`020?ooo`03023/
1`3oool0oooo02X0oooo00<000000?ooo`3oool07@3oool001`0oooo00<000000?ooo`3oool08P3o
ool00`0Pk0L0oooo023/1`040?ooo`05023/1`3oool0oooo0?ooo`0Pk0L00P3oool2023/1`040?oo
o`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`3oool0103oool4023/1`050?ooo`0Pk0L0oooo023/
1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L20?ooo`H08>`700P0oooo023/
1`0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`700@0oooo023/1`0Pk0L08>`70P3oool4023/1`<0
oooo0`0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`700H0oooo023/
1`0Pk0L0oooo023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`700@000000?ooo`0Pk0L0oooo
1@0Pk0L30?ooo`808>`700L0oooo023/1`3oool0oooo023/1`3oool08>`700T0oooo00<08>`70?oo
o`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`0Z0?ooo`030000003oool0oooo01d0oooo000L0?ooo`03
0000003oool0oooo0280oooo00<08>`70?ooo`0Pk0L0103oool01@0Pk0L0oooo0?ooo`3oool08>`7
0080oooo0P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo100Pk0L0
1@3oool08>`70?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`70P3o
ool6023/1`080?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`040?ooo`0Pk0L08>`7
023/1`80oooo100Pk0L30?ooo`<08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/
1`02023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`04
0000003oool08>`70?ooo`D08>`70`3oool2023/1`070?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/
1`090?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`3oool0:P3oool00`000000oooo0?oo
o`0M0?ooo`00703oool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool08>`700@0oooo00D08>`7
0?ooo`3oool0oooo023/1`020?ooo`808>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo
0?ooo`040?ooo`@08>`700D0oooo023/1`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo00@0
8>`70P3oool3023/1`80oooo1P0Pk0L0203oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo0`0P
k0L0103oool08>`7023/1`0Pk0L20?ooo`@08>`70`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3o
ool08>`70?ooo`04023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/
1`02023/1`040000003oool08>`70?ooo`D08>`70`3oool2023/1`070?ooo`0Pk0L0oooo0?ooo`0P
k0L0oooo023/1`090?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0M0?ooo`00703oool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool08>`700@0
oooo00D08>`70?ooo`3oool0oooo023/1`020?ooo`808>`700@0oooo023/1`3oool08>`70P3oool0
0`0Pk0L0oooo0?ooo`040?ooo`@08>`700D0oooo023/1`3oool08>`70?ooo`02023/1`030?ooo`0P
k0L0oooo00@08>`70P3oool3023/1`80oooo1P0Pk0L0203oool08>`7023/1`3oool08>`70?ooo`0P
k0L0oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`@08>`70`3oool3023/1`070?ooo`0Pk0L0
8>`7023/1`3oool08>`70?ooo`04023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`3o
ool0100Pk0L010000000oooo023/1`3oool5023/1`<0oooo0P0Pk0L01`3oool08>`70?ooo`3oool0
8>`70?ooo`0Pk0L0203oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo02X0oooo
00<000000?ooo`3oool07@3oool001`0oooo00<000000?ooo`3oool08P3oool00`0Pk0L0oooo023/
1`040?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`040?ooo`0Pk0L0oooo023/1`80oooo
00<08>`70?ooo`3oool0103oool4023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`02023/
1`030?ooo`0Pk0L08>`700808>`70P3oool3023/1`80oooo1P0Pk0L0203oool08>`7023/1`3oool0
8>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`@08>`70`3oool3023/1`07
0?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`04023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0
oooo023/1`3oool0100Pk0L010000000oooo023/1`3oool5023/1`<0oooo0P0Pk0L0103oool08>`7
0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00H0oooo00@08>`70?ooo`3oool08>`70P3oool00`0P
k0L0oooo0?ooo`0Z0?ooo`030000003oool0oooo01d0oooo000L0?ooo`030000003oool0oooo0280
oooo00<08>`70?ooo`0Pk0L0103oool2023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L0103oool0
8>`70?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo100Pk0L00`3oool08>`70?ooo`03023/
1`040?ooo`0Pk0L08>`70?ooo`@08>`70P3oool3023/1`80oooo1P0Pk0L0203oool08>`7023/1`3o
ool08>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`@08>`70`3oool3023/
1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`07023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0
oooo100Pk0L010000000oooo023/1`3oool5023/1`<0oooo0P0Pk0L0103oool08>`70?ooo`0Pk0L2
0?ooo`03023/1`3oool0oooo00H0oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0oooo0?oo
o`0Z0?ooo`030000003oool0oooo01d0oooo000L0?ooo`030000003oool0oooo02<0oooo0P0Pk0L4
0?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`040?ooo`0Pk0L0oooo023/1`80oooo00<0
8>`70?ooo`3oool0103oool4023/1`030?ooo`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L0oooo
100Pk0L20?ooo`<08>`70P3oool6023/1`080?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool3
023/1`040?ooo`0Pk0L08>`7023/1`80oooo100Pk0L30?ooo`L08>`700<0oooo023/1`3oool01`0P
k0L01P3oool08>`7023/1`3oool08>`70?ooo`@08>`700@000000?ooo`0Pk0L0oooo1@0Pk0L30?oo
o`808>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`060?ooo`04023/1`3oool0
oooo023/1`80oooo00<08>`70?ooo`3oool0:P3oool00`000000oooo0?ooo`0M0?ooo`00703oool0
0`000000oooo0?ooo`0S0?ooo`808>`7103oool2023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L0
103oool08>`70?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo100Pk0L00`3oool08>`70?oo
o`03023/1`040?ooo`0Pk0L08>`70?ooo`@08>`70P3oool3023/1`80oooo1P0Pk0L0203oool08>`7
023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`@08>`70`3o
ool7023/1`030?ooo`0Pk0L0oooo00L08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool4023/1`04
0000003oool08>`70?ooo`D08>`70`3oool2023/1`040?ooo`0Pk0L0oooo023/1`80oooo00<08>`7
0?ooo`3oool01P3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo02X0oooo00<0
00000?ooo`3oool07@3oool001`0oooo00<000000?ooo`3oool08`3oool2023/1`@0oooo0P0Pk0L2
0?ooo`03023/1`3oool0oooo00808>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo0?oo
o`040?ooo`@08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`05023/1`80oooo0`0P
k0L20?ooo`H08>`700P0oooo023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`700@0oooo023/
1`0Pk0L08>`70P3oool4023/1`<0oooo1`0Pk0L00`3oool08>`70?ooo`07023/1`060?ooo`0Pk0L0
8>`70?ooo`0Pk0L0oooo100Pk0L010000000oooo023/1`3oool5023/1`<0oooo0P0Pk0L0103oool0
8>`70?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00H0oooo00@08>`70?ooo`3oool08>`70P3oool0
0`0Pk0L0oooo0?ooo`0Z0?ooo`030000003oool0oooo01d0oooo000L0?ooo`030000003oool0oooo
02<0oooo0P0Pk0L40?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`040?ooo`0Pk0L0oooo
023/1`80oooo00<08>`70?ooo`3oool0103oool4023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo
023/1`0Pk0L01@0Pk0L20?ooo`<08>`70P3oool6023/1`080?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo
023/1`3oool3023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo100Pk0L30?ooo`L08>`700<0oooo
023/1`3oool01`0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`@08>`700@000000?ooo`0Pk0L0
oooo1@0Pk0L30?ooo`808>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`060?oo
o`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool0:P3oool00`000000oooo0?ooo`0M
0?ooo`00703oool00`000000oooo0?ooo`0S0?ooo`808>`7103oool2023/1`80oooo00<08>`70?oo
o`3oool00P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo100Pk0L0
0`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700D08>`70P3oool3023/1`80oooo1P0Pk0L0
203oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L01P3oool08>`7023/1`3oool08>`7
0?ooo`@08>`70`3oool7023/1`030?ooo`0Pk0L0oooo00L08>`700H0oooo023/1`0Pk0L0oooo023/
1`3oool4023/1`040000003oool08>`70?ooo`D08>`70`3oool2023/1`040?ooo`0Pk0L0oooo023/
1`80oooo00<08>`70?ooo`3oool01P3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0
oooo02X0oooo00<000000?ooo`3oool07@3oool001`0oooo00<000000?ooo`3oool08`3oool2023/
1`@0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00808>`700@0oooo023/1`3oool08>`70P3oool0
0`0Pk0L0oooo0?ooo`040?ooo`@08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`05
023/1`80oooo0`0Pk0L20?ooo`H08>`700P0oooo023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`80
8>`70P3oool2023/1`030?ooo`0Pk0L0oooo00@08>`70`3oool7023/1`030?ooo`0Pk0L0oooo00P0
8>`700D0oooo023/1`3oool08>`70?ooo`04023/1`040000003oool08>`70?ooo`D08>`70`3oool2
023/1`040?ooo`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`3oool01P3oool0100Pk0L0oooo0?oo
o`0Pk0L20?ooo`03023/1`3oool0oooo02X0oooo00<000000?ooo`3oool07@3oool001`0oooo00<0
00000?ooo`3oool08`3oool2023/1`@0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00808>`700L0
oooo023/1`3oool0oooo023/1`3oool08>`700H0oooo100Pk0L00`3oool08>`70?ooo`03023/1`03
0?ooo`0Pk0L08>`700D08>`70P3oool3023/1`80oooo1P0Pk0L0203oool08>`7023/1`3oool08>`7
0?ooo`0Pk0L0oooo0P0Pk0L20?ooo`808>`700<0oooo023/1`3oool0100Pk0L30?ooo`L08>`700<0
oooo023/1`3oool0200Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00@08>`700@000000?ooo`0Pk0L0
oooo1@0Pk0L30?ooo`808>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`060?oo
o`06023/1`3oool0oooo023/1`3oool08>`7;@3oool00`000000oooo0?ooo`0M0?ooo`00703oool0
0`000000oooo0?ooo`0S0?ooo`808>`7103oool2023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L0
1`3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L01P3oool4023/1`030?ooo`0Pk0L0oooo00<08>`7
00<0oooo023/1`0Pk0L01@0Pk0L20?ooo`<08>`70P3oool6023/1`080?ooo`0Pk0L08>`70?ooo`0P
k0L0oooo023/1`3oool2023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo1`0Pk0L0
0`3oool08>`70?ooo`08023/1`030?ooo`0Pk0L08>`70080oooo100Pk0L010000000oooo023/1`3o
ool4023/1`@0oooo0P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00H0oooo
00H08>`70?ooo`3oool08>`70?ooo`0Pk0L]0?ooo`030000003oool0oooo01d0oooo000L0?ooo`03
0000003oool0oooo02<0oooo00<08>`70?ooo`0Pk0L00`3oool2023/1`80oooo00<08>`70?ooo`3o
ool00P0Pk0L01`3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L01P3oool4023/1`030?ooo`0Pk0L0
oooo00<08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`<08>`70P3oool6023/1`080?ooo`0Pk0L0
8>`70?ooo`0Pk0L0oooo023/1`3oool2023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`04023/1`<0
oooo1`0Pk0L00`3oool08>`70?ooo`08023/1`030?ooo`0Pk0L08>`70080oooo100Pk0L010000000
oooo023/1`3oool4023/1`@0oooo0P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`03023/1`3oool0
oooo00H0oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L]0?ooo`030000003oool0oooo01d0oooo
000L0?ooo`030000003oool0oooo02<0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo0?oo
o`0Pk0L20?ooo`808>`700L0oooo023/1`3oool0oooo023/1`3oool08>`700H0oooo100Pk0L00`3o
ool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700D08>`70P3oool3023/1`80oooo1P0Pk0L0203o
ool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L20?ooo`808>`700<0oooo023/1`3oool0
100Pk0L30?ooo`L08>`700<0oooo023/1`3oool0200Pk0L00`3oool08>`7023/1`020?ooo`@08>`7
00@000000?ooo`0Pk0L0oooo100Pk0L40?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L9
0?ooo`06023/1`3oool0oooo023/1`3oool08>`7;@3oool00`000000oooo0?ooo`0M0?ooo`00703o
ool00`000000oooo0?ooo`0S0?ooo`03023/1`3oool08>`700@0oooo00@08>`70?ooo`3oool08>`7
0P3oool2023/1`070?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`060?ooo`@08>`700<0oooo023/
1`3oool00`0Pk0L00`3oool08>`7023/1`05023/1`80oooo0`0Pk0L20?ooo`H08>`700P0oooo023/
1`0Pk0L0oooo023/1`3oool08>`70?ooo`808>`70P3oool2023/1`030?ooo`0Pk0L0oooo00@08>`7
0`3oool7023/1`030?ooo`0Pk0L0oooo00P08>`700<0oooo023/1`0Pk0L00P3oool4023/1`040000
003oool08>`70?ooo`@08>`7103oool2023/1`060?ooo`0Pk0L0oooo023/1`3oool08>`72@3oool0
1P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1bd0oooo00<000000?ooo`3oool07@3oool001`0oooo00<0
00000?ooo`3oool08`3oool00`0Pk0L0oooo023/1`040?ooo`04023/1`3oool0oooo023/1`80oooo
0P0Pk0L01`3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L01P3oool4023/1`030?ooo`0Pk0L0oooo
00<08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`<08>`70P3oool6023/1`080?ooo`0Pk0L08>`7
0?ooo`0Pk0L0oooo023/1`3oool2023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo
1`0Pk0L00`3oool08>`70?ooo`08023/1`030?ooo`0Pk0L08>`70080oooo100Pk0L010000000oooo
023/1`3oool4023/1`@0oooo0P0Pk0L01P3oool08>`70?ooo`0Pk0L0oooo023/1`T0oooo00<08>`7
0?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`0[0?ooo`030000003oool0oooo01d0oooo000L0?oo
o`030000003oool0oooo02<0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo0?ooo`0Pk0L2
0?ooo`808>`700L0oooo023/1`3oool0oooo023/1`3oool08>`700H0oooo100Pk0L00`3oool08>`7
0?ooo`03023/1`030?ooo`0Pk0L08>`700D08>`70P3oool3023/1`80oooo1P0Pk0L0203oool08>`7
023/1`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L20?ooo`808>`700<0oooo023/1`3oool0100Pk0L3
0?ooo`L08>`700<0oooo023/1`3oool0200Pk0L00`3oool08>`7023/1`020?ooo`@08>`700@00000
0?ooo`0Pk0L0oooo100Pk0L40?ooo`<08>`70P3oool00`0Pk0L0oooo023/1`090?ooo`03023/1`3o
ool08>`70080oooo00<08>`70?ooo`3oool0:`3oool00`000000oooo0?ooo`0M0?ooo`00703oool0
0`000000oooo0?ooo`0S0?ooo`03023/1`3oool08>`700@0oooo00@08>`70?ooo`3oool08>`70P3o
ool2023/1`070?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`060?ooo`@08>`700<0oooo023/1`3o
ool00`0Pk0L00`3oool08>`7023/1`05023/1`80oooo0`0Pk0L20?ooo`H08>`700P0oooo023/1`0P
k0L0oooo023/1`3oool08>`70?ooo`808>`70P3oool2023/1`030?ooo`0Pk0L0oooo00@08>`70`3o
ool7023/1`030?ooo`0Pk0L0oooo00P08>`700<0oooo023/1`0Pk0L00P3oool5023/1`030000000P
k0L0oooo00@08>`7103oool3023/1`80oooo00<08>`70?ooo`0Pk0L02@3oool00`0Pk0L0oooo023/
1`020?ooo`03023/1`3oool0oooo02/0oooo00<000000?ooo`3oool07@3oool001`0oooo00<00000
0?ooo`3oool08`3oool00`0Pk0L0oooo023/1`040?ooo`04023/1`3oool0oooo023/1`80oooo0P0P
k0L01`3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L01P3oool4023/1`030?ooo`0Pk0L0oooo00<0
8>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`<08>`70P3oool6023/1`080?ooo`0Pk0L08>`70?oo
o`0Pk0L0oooo023/1`3oool2023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo1`0P
k0L00`3oool08>`70?ooo`08023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`0Pk0L00P0P
k0L00`000000oooo0?ooo`04023/1`@0oooo0`0Pk0L20?ooo`03023/1`3oool08>`700T0oooo00<0
8>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`0[0?ooo`030000003oool0oooo01d0oooo000L
0?ooo`030000003oool0oooo02<0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo0?ooo`0P
k0L20?ooo`808>`700L0oooo023/1`3oool0oooo023/1`3oool08>`700H0oooo100Pk0L00`3oool0
8>`70?ooo`03023/1`030?ooo`0Pk0L08>`700D08>`70P3oool3023/1`80oooo1P0Pk0L0203oool0
8>`7023/1`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L20?ooo`808>`700<0oooo023/1`3oool0100P
k0L30?ooo`L08>`700<0oooo023/1`3oool0200Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3o
ool08>`700808>`700<000000?ooo`3oool0100Pk0L40?ooo`<08>`70P3oool00`0Pk0L0oooo023/
1`090?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`3oool0:`3oool00`000000oooo0?oo
o`0M0?ooo`00703oool00`000000oooo0?ooo`0S0?ooo`03023/1`3oool08>`700@0oooo00@08>`7
0?ooo`3oool08>`70P3oool4023/1`80oooo00<08>`70?ooo`0Pk0L01P3oool4023/1`030?ooo`0P
k0L0oooo00<08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L0100P
k0L0203oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L20?ooo`808>`700<0oooo023/
1`3oool0100Pk0L30?ooo`L08>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`7023/1`020?oo
o`03023/1`3oool08>`700808>`700<000000?ooo`3oool0100Pk0L40?ooo`<08>`70P3oool00`0P
k0L0oooo023/1`090?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0M0?ooo`00703oool00`000000oooo0?ooo`0S0?ooo`03023/1`3oool08>`700@0
oooo00@08>`70?ooo`3oool08>`70P3oool4023/1`80oooo00<08>`70?ooo`0Pk0L01P3oool4023/
1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`@08>`700<0oooo023/
1`0Pk0L0100Pk0L0203oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L20?ooo`808>`7
00<0oooo023/1`3oool0100Pk0L30?ooo`L08>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`7
023/1`020?ooo`03023/1`3oool08>`700808>`700<000000?ooo`3oool0100Pk0L40?ooo`<08>`7
0P3oool00`0Pk0L0oooo023/1`090?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`3oool0
:`3oool00`000000oooo0?ooo`0M0?ooo`00703oool00`000000oooo0?ooo`0S0?ooo`03023/1`3o
ool08>`700@0oooo00@08>`70?ooo`3oool08>`70P3oool4023/1`80oooo00<08>`70?ooo`0Pk0L0
1P3oool4023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`@08>`7
00<0oooo023/1`0Pk0L0100Pk0L0203oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L2
0?ooo`808>`700<0oooo023/1`3oool0100Pk0L30?ooo`L08>`700<0oooo023/1`0Pk0L0200Pk0L0
0`3oool08>`7023/1`020?ooo`03023/1`3oool08>`700808>`700<000000?ooo`3oool0100Pk0L4
0?ooo`<08>`70P3oool00`0Pk0L0oooo023/1`080?ooo`04023/1`3oool0oooo023/1`80oooo00<0
8>`70?ooo`3oool0:`3oool00`000000oooo0?ooo`0M0?ooo`00703oool00`000000oooo0?ooo`0S
0?ooo`03023/1`3oool08>`700@0oooo00<08>`70?ooo`3oool00P0Pk0L00`3oool08>`7023/1`02
023/1`80oooo00<08>`70?ooo`0Pk0L01P3oool4023/1`030?ooo`0Pk0L0oooo00/08>`70P3oool4
023/1`030?ooo`0Pk0L08>`700@08>`700P0oooo023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`80
8>`70P3oool2023/1`030?ooo`0Pk0L0oooo00@08>`70`3oool7023/1`030?ooo`0Pk0L08>`700P0
8>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo023/1`02023/1`030000003oool0oooo00@0
8>`7103oool3023/1`80oooo00<08>`70?ooo`0Pk0L0203oool0100Pk0L0oooo0?ooo`0Pk0L20?oo
o`03023/1`3oool0oooo02/0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3o
ool0903oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00808>`700X0oooo023/1`0P
k0L08>`70?ooo`0Pk0L0oooo023/1`3oool08>`71P3oool4023/1`030?ooo`0Pk0L0oooo00/08>`7
0P3oool4023/1`030?ooo`0Pk0L08>`700@08>`700P0oooo023/1`0Pk0L0oooo023/1`3oool08>`7
0?ooo`808>`70P3oool2023/1`030?ooo`0Pk0L0oooo00@08>`70`3oool7023/1`030?ooo`0Pk0L0
8>`700P08>`700<0oooo023/1`0Pk0L00P3oool5023/1`030000003oool0oooo00@08>`7103oool3
023/1`80oooo00<08>`70?ooo`0Pk0L0203oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3o
ool0oooo02/0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool0903oool0
0`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00808>`700T0oooo023/1`0Pk0L08>`70?oo
o`0Pk0L0oooo023/1`3oool00P0Pk0L50?ooo`@08>`700<0oooo023/1`3oool02`0Pk0L20?ooo`@0
8>`700<0oooo023/1`0Pk0L0100Pk0L0203oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo0P0P
k0L20?ooo`808>`700<0oooo023/1`3oool0100Pk0L30?oooa808>`700<0oooo023/1`0Pk0L00P3o
ool5023/1`030000003oool0oooo00@08>`7103oool3023/1`80oooo00<08>`70?ooo`0Pk0L0203o
ool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo02/0oooo00<000000?ooo`3oool0
7@3oool001/0oooo00<000000?ooo`3oool0903oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3o
ool0oooo00808>`700T0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L50?oo
o`@08>`700<0oooo023/1`3oool02`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L0100Pk0L0203o
ool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L20?ooo`808>`700<0oooo023/1`3oool0
100Pk0L30?oooa808>`700<0oooo023/1`0Pk0L00P3oool5023/1`040000003oool08>`70?ooo`<0
8>`7103oool3023/1`80oooo00<08>`70?ooo`0Pk0L0203oool0100Pk0L0oooo0?ooo`0Pk0L20?oo
o`03023/1`3oool0oooo02/0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3o
ool0903oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00808>`700T0oooo023/1`0P
k0L08>`70?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L50?ooo`@08>`700<0oooo023/1`3oool02`0P
k0L20?ooo`@08>`700<0oooo023/1`0Pk0L0100Pk0L0203oool08>`7023/1`3oool08>`70?ooo`0P
k0L0oooo0P0Pk0L20?ooo`808>`700<0oooo023/1`3oool0100Pk0L30?oooa808>`700@0oooo023/
1`0Pk0L0oooo1P0Pk0L010000000oooo023/1`3oool3023/1`<0oooo0P0Pk0L0103oool08>`70?oo
o`0Pk0L20?ooo`03023/1`3oool0oooo00H0oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0
oooo0?ooo`0[0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo02@0oooo
00<08>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`02023/1`090?ooo`0Pk0L08>`7023/1`3o
ool08>`70?ooo`0Pk0L0oooo00808>`71@3oool4023/1`030?ooo`0Pk0L0oooo00/08>`70P3oool4
023/1`030?ooo`0Pk0L08>`700@08>`700P0oooo023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`80
8>`70P3oool2023/1`030?ooo`0Pk0L0oooo00@08>`70`3ooolB023/1`040?ooo`0Pk0L08>`70?oo
o`H08>`700@000000?ooo`0Pk0L0oooo0`0Pk0L30?ooo`808>`700@0oooo023/1`3oool08>`70P3o
ool00`0Pk0L0oooo0?ooo`060?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool0
:`3oool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0T0?ooo`03023/1`3o
ool08>`700@0oooo00<08>`70?ooo`3oool00P0Pk0L02@3oool08>`7023/1`0Pk0L0oooo023/1`3o
ool08>`70?ooo`02023/1`D0oooo100Pk0L00`3oool08>`70?ooo`0;023/1`80oooo100Pk0L00`3o
ool08>`7023/1`04023/1`080?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool2023/1`80oooo
0P0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo4P0Pk0L0103oool08>`7023/1`3oool6023/1`04
0000003oool08>`70?ooo`<08>`70`3oool2023/1`040?ooo`0Pk0L0oooo023/1`80oooo00<08>`7
0?ooo`3oool01P3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo02/0oooo00<0
00000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool0903oool00`0Pk0L0oooo023/1`04
0?ooo`03023/1`3oool0oooo00808>`700T0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3o
ool00P0Pk0L60?ooo`<08>`700<0oooo023/1`3oool02`0Pk0L20?ooo`@08>`700<0oooo023/1`0P
k0L0100Pk0L0203oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L20?ooo`808>`700<0
oooo023/1`3oool0100Pk0L20?oooa<08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L01@3oool00000
0?ooo`0Pk0L0oooo00<08>`70`3oool2023/1`040?ooo`0Pk0L0oooo023/1`80oooo00<08>`70?oo
o`3oool01P3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo02/0oooo00<00000
0?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool0903oool00`0Pk0L0oooo023/1`040?oo
o`03023/1`3oool0oooo00808>`700T0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool0
0P0Pk0L60?ooo`<08>`700<0oooo023/1`3oool02`0Pk0L20?ooo`@08>`700D0oooo023/1`0Pk0L0
8>`70?ooo`02023/1`080?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool2023/1`80oooo0P0P
k0L00`3oool08>`70?ooo`04023/1`80oooo4`0Pk0L0103oool08>`7023/1`3oool5023/1`050?oo
o`000000oooo023/1`3oool00`0Pk0L30?ooo`808>`700@0oooo023/1`3oool08>`70P3oool00`0P
k0L0oooo0?ooo`060?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0T0?ooo`03023/1`3oool08>`7
00@0oooo00<08>`70?ooo`3oool00P0Pk0L02@3oool08>`7023/1`0Pk0L0oooo023/1`3oool08>`7
0?ooo`02023/1`H0oooo0`0Pk0L00`3oool08>`70?ooo`0;023/1`80oooo100Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00D08>`700D0oooo023/1`3oool08>`70?ooo`02023/1`80oooo0P0Pk0L00`3o
ool08>`70?ooo`04023/1`80oooo4`0Pk0L0103oool08>`7023/1`3oool5023/1`050?ooo`000000
oooo023/1`3oool00`0Pk0L30?ooo`808>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo
0?ooo`060?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool0:`3oool00`000000
oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0T0?ooo`03023/1`3oool08>`700@0oooo
00<08>`70?ooo`3oool00P0Pk0L02@3oool08>`7023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`02
023/1`H0oooo0`0Pk0L00`3oool08>`70?ooo`0;023/1`80oooo100Pk0L01@3oool08>`7023/1`0P
k0L0oooo00D08>`700D0oooo023/1`3oool08>`70?ooo`02023/1`80oooo0P0Pk0L00`3oool08>`7
0?ooo`04023/1`80oooo4`0Pk0L0103oool08>`7023/1`3oool5023/1`050?ooo`000000oooo023/
1`3oool00`0Pk0L30?ooo`808>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`06
0?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool0:`3oool00`000000oooo0?oo
o`0M0?ooo`006`3oool00`000000oooo0?ooo`0T0?ooo`03023/1`3oool08>`700@0oooo00<08>`7
0?ooo`3oool00P0Pk0L02@3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`02023/1`H0
oooo0`0Pk0L0103oool08>`70?ooo`3oool:023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0
oooo00D08>`700D0oooo023/1`3oool08>`70?ooo`02023/1`80oooo0P0Pk0L00`3oool08>`70?oo
o`04023/1`80oooo4`0Pk0L0103oool08>`7023/1`3oool5023/1`050?ooo`000000oooo023/1`3o
ool00`0Pk0L30?ooo`808>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`060?oo
o`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool0:`3oool00`000000oooo0?ooo`0M
0?ooo`006`3oool00`000000oooo0?ooo`0T0?ooo`03023/1`3oool08>`700@0oooo00<08>`70?oo
o`3oool00P0Pk0L02@3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`02023/1`H0oooo
0`0Pk0L0103oool08>`70?ooo`3oool:023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00D08>`700D0oooo023/1`3oool08>`70?ooo`02023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`04
023/1`80oooo4`0Pk0L0103oool08>`7023/1`3oool5023/1`050?ooo`000000oooo023/1`3oool0
0`0Pk0L30?ooo`808>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`060?ooo`03
023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool0:`3oool00`000000oooo0?ooo`0M0?ooo`00
6`3oool00`000000oooo0?ooo`0T0?ooo`03023/1`3oool08>`700@0oooo00<08>`70?ooo`3oool0
0P0Pk0L02@3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`02023/1`H0oooo0`0Pk0L0
103oool08>`70?ooo`3oool:023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`7
00D0oooo023/1`3oool08>`70?ooo`02023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`04023/1`80
oooo500Pk0L00`3oool08>`70?ooo`05023/1`050?ooo`000000oooo023/1`3oool00`0Pk0L30?oo
o`808>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`060?ooo`03023/1`3oool0
8>`700<0oooo00<08>`70?ooo`3oool0:`3oool00`000000oooo0?ooo`0M0?ooo`006`3oool00`00
0000oooo0?ooo`0T0?ooo`03023/1`3oool08>`700@0oooo00<08>`70?ooo`3oool00P0Pk0L02@3o
ool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`02023/1`H0oooo0`0Pk0L0103oool08>`7
0?ooo`3oool:023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700D0oooo023/
1`3oool08>`70?ooo`02023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`04023/1`80oooo500Pk0L0
0`3oool08>`70?ooo`05023/1`030?ooo`000000oooo00D08>`70`3oool2023/1`040?ooo`0Pk0L0
oooo023/1`80oooo00<08>`70?ooo`3oool01P3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3o
ool0oooo02/0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool0903oool0
0`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00808>`70P3oool2023/1`050?ooo`0Pk0L0
oooo023/1`3oool00P0Pk0L60?ooo`<08>`700@0oooo023/1`3oool0oooo2P0Pk0L20?ooo`@08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`05023/1`050?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L20?oo
o`808>`700<0oooo023/1`3oool0100Pk0L20?oooa@08>`700<0oooo023/1`3oool01@0Pk0L00`3o
ool000000?ooo`04023/1`@0oooo0P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`03023/1`3oool0
oooo00H0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`0[0?ooo`030000003oool0
oooo01d0oooo000K0?ooo`030000003oool0oooo02@0oooo00<08>`70?ooo`0Pk0L0103oool2023/
1`030?ooo`0Pk0L08>`70080oooo0P0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00808>`71P3oool3
023/1`040?ooo`0Pk0L0oooo0?ooo`X08>`70P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool0
100Pk0L20?ooo`04023/1`3oool08>`70?ooo`808>`70P3oool2023/1`030?ooo`0Pk0L0oooo00@0
8>`70P3ooolD023/1`030?ooo`0Pk0L0oooo00D08>`700<0oooo0000003oool0100Pk0L40?ooo`80
8>`700@0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`060?ooo`03023/1`3oool08>`7
00<0oooo00<08>`70?ooo`3oool0:`3oool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000
oooo0?ooo`0T0?ooo`03023/1`3oool08>`700@0oooo0P0Pk0L00`3oool08>`7023/1`020?ooo`80
8>`700D0oooo023/1`3oool08>`70?ooo`02023/1`H0oooo0`0Pk0L0103oool08>`70?ooo`3oool:
023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool0100Pk0L0oooo023/
1`3oool2023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`04023/1`80oooo500Pk0L00`3oool08>`7
0?ooo`05023/1`030?ooo`000000oooo00@08>`7103oool2023/1`040?ooo`0Pk0L0oooo023/1`80
oooo00<08>`70?ooo`3oool01P3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo02`0
oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool0903oool00`0Pk0L0oooo
023/1`040?ooo`808>`700<0oooo023/1`0Pk0L00P3oool2023/1`050?ooo`0Pk0L0oooo023/1`3o
ool00P0Pk0L60?ooo`<08>`700@0oooo023/1`3oool0oooo2P0Pk0L20?ooo`@08>`700D0oooo023/
1`0Pk0L08>`70?ooo`04023/1`80oooo00@08>`70?ooo`0Pk0L0oooo0P0Pk0L20?ooo`808>`700<0
oooo023/1`3oool0100Pk0L20?ooo``08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?oo
o`05023/1`030?ooo`000000oooo00@08>`7103oool3023/1`80oooo00@08>`70?ooo`3oool08>`7
203oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo02`0oooo00<000000?ooo`3oool0
7@3oool001/0oooo00<000000?ooo`3oool0903oool00`0Pk0L0oooo023/1`040?ooo`808>`700<0
oooo023/1`0Pk0L00P3oool2023/1`040?ooo`0Pk0L0oooo0?ooo`<08>`71P3oool3023/1`040?oo
o`0Pk0L0oooo0?ooo`X08>`70P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L20?oo
o`04023/1`3oool08>`70?ooo`808>`70P3oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00@08>`70P3o
ool<023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3oool01@0Pk0L00`3oool000000?oo
o`04023/1`@0oooo0`0Pk0L20?ooo`04023/1`3oool0oooo023/1`P0oooo00<08>`70?ooo`0Pk0L0
0P3oool00`0Pk0L0oooo0?ooo`0/0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003o
ool0oooo02@0oooo00<08>`70?ooo`0Pk0L0103oool2023/1`030?ooo`0Pk0L08>`70080oooo0P0P
k0L0103oool08>`70?ooo`3oool3023/1`H0oooo0`0Pk0L0103oool08>`70?ooo`3oool:023/1`80
oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool0100Pk0L0oooo023/1`3oool2
023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?ooo``08>`700<0oooo
023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`05023/1`030?ooo`000000oooo00@08>`7103oool3
023/1`80oooo00@08>`70?ooo`3oool08>`71`3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/
1`3oool0oooo02`0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool0903o
ool00`0Pk0L0oooo023/1`040?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`040?ooo`0P
k0L0oooo0?ooo`<08>`71P3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`X08>`70P3oool4023/1`05
0?ooo`0Pk0L08>`7023/1`3oool0100Pk0L20?ooo`04023/1`3oool08>`70?ooo`808>`700<0oooo
023/1`0Pk0L00P3oool00`0Pk0L0oooo023/1`03023/1`80oooo1P0Pk0L00`3oool08>`7023/1`03
023/1`030?ooo`0Pk0L08>`700808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool5023/1`030?oo
o`000000oooo00@08>`7103oool3023/1`80oooo00@08>`70?ooo`3oool08>`71`3oool0100Pk0L0
oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo02`0oooo00<000000?ooo`3oool07@3oool001/0
oooo00<000000?ooo`3oool09@3oool2023/1`@0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo0080
8>`700@0oooo023/1`3oool0oooo0`0Pk0L60?ooo`<08>`700@0oooo023/1`3oool0oooo2P0Pk0L2
0?ooo`@08>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`80oooo00@08>`70?ooo`0Pk0L0oooo
0P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool08>`700<08>`70P3oool6023/1`030?oo
o`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P0Pk0L01P3oool08>`7023/1`3oool08>`70?oo
o`D08>`700<0oooo0000003oool0100Pk0L40?ooo`<08>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L7
0?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool0;03oool00`000000oooo0?oo
o`0M0?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`808>`7103oool2023/1`80oooo00<08>`7
0?ooo`3oool00P0Pk0L0103oool08>`70?ooo`3oool3023/1`H0oooo0`0Pk0L0103oool08>`70?oo
o`3oool:023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool0100Pk0L0
oooo023/1`3oool2023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?oo
o`H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`7
0080oooo1@0Pk0L00`3oool000000?ooo`04023/1`@0oooo0`0Pk0L20?ooo`04023/1`3oool0oooo
023/1`L0oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`0/0?ooo`030000003o
ool0oooo01d0oooo000K0?ooo`030000003oool0oooo02D0oooo0P0Pk0L40?ooo`808>`70P3oool0
0`0Pk0L0oooo0?ooo`02023/1`040?ooo`0Pk0L0oooo0?ooo`<08>`71P3oool3023/1`040?ooo`0P
k0L0oooo0?ooo`X08>`70P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L20?ooo`07
023/1`3oool08>`7023/1`3oool08>`70?ooo`02023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L2
0?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0
8>`70080oooo1@0Pk0L00`3oool000000?ooo`04023/1`@0oooo0`0Pk0L20?ooo`04023/1`3oool0
oooo023/1`L0oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`0/0?ooo`030000
003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo02D0oooo0P0Pk0L40?ooo`808>`70P3o
ool00`0Pk0L0oooo0?ooo`02023/1`040?ooo`0Pk0L0oooo0?ooo`<08>`71P3oool3023/1`040?oo
o`0Pk0L0oooo0?ooo`X08>`70P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L20?oo
o`07023/1`3oool08>`7023/1`3oool08>`70?ooo`02023/1`80oooo00<08>`70?ooo`0Pk0L00`0P
k0L20?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0P
k0L08>`70080oooo1P0Pk0L00`000000oooo023/1`03023/1`@0oooo0`0Pk0L20?ooo`04023/1`3o
ool0oooo023/1`L0oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`0/0?ooo`03
0000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo02D0oooo0P0Pk0L40?ooo`808>`7
0P3oool00`0Pk0L0oooo0?ooo`02023/1`040?ooo`0Pk0L0oooo0?ooo`<08>`71P3oool3023/1`04
0?ooo`0Pk0L0oooo0?ooo`X08>`70`3oool3023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L2
0?ooo`07023/1`3oool08>`7023/1`3oool08>`70?ooo`02023/1`80oooo00<08>`70?ooo`0Pk0L0
0`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03023/1`030?oo
o`0Pk0L08>`70080oooo1P0Pk0L00`000000oooo023/1`03023/1`@0oooo0`0Pk0L20?ooo`03023/
1`3oool08>`700P0oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`0/0?ooo`03
0000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo02D0oooo0P0Pk0L50?ooo`04023/
1`3oool0oooo023/1`80oooo0P0Pk0L0103oool08>`70?ooo`3oool3023/1`H0oooo0`0Pk0L0103o
ool08>`70?ooo`3oool:023/1`<0oooo0`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool0
0P0Pk0L20?ooo`07023/1`3oool08>`7023/1`3oool08>`70?ooo`02023/1`80oooo00<08>`70?oo
o`0Pk0L00`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03023/
1`030?ooo`0Pk0L08>`70080oooo1P0Pk0L00`000000oooo023/1`03023/1`@0oooo0`0Pk0L20?oo
o`03023/1`3oool08>`700P0oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`0/
0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo02D0oooo0P0Pk0L50?oo
o`04023/1`3oool0oooo023/1`80oooo0P0Pk0L0103oool08>`70?ooo`3oool3023/1`H0oooo0`0P
k0L0103oool08>`70?ooo`3oool:023/1`<0oooo0`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/
1`3oool00P0Pk0L20?ooo`07023/1`3oool08>`7023/1`3oool08>`70?ooo`02023/1`80oooo00<0
8>`70?ooo`0Pk0L00`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/
1`03023/1`030?ooo`0Pk0L08>`70080oooo1P0Pk0L00`000000oooo023/1`03023/1`@0oooo0`0P
k0L01@3oool08>`70?ooo`3oool08>`700P0oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0
oooo0?ooo`0/0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo02D0oooo
0P0Pk0L50?ooo`04023/1`3oool0oooo023/1`80oooo0P0Pk0L0103oool08>`70?ooo`3oool3023/
1`H0oooo0`0Pk0L0103oool08>`70?ooo`3oool:023/1`<0oooo0`0Pk0L01`3oool08>`7023/1`0P
k0L0oooo023/1`3oool00P0Pk0L20?ooo`07023/1`3oool08>`7023/1`3oool08>`70?ooo`02023/
1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?ooo`<08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L0
0`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`70080oooo1P0Pk0L00`000000oooo023/1`03
023/1`@0oooo0`0Pk0L01@3oool08>`70?ooo`3oool08>`700P0oooo00@08>`70?ooo`3oool08>`7
0P3oool00`0Pk0L0oooo0?ooo`0/0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003o
ool0oooo02D0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`808>`7
00L0oooo023/1`3oool0oooo023/1`3oool08>`700H0oooo0`0Pk0L0103oool08>`70?ooo`3oool3
023/1`030?ooo`0Pk0L08>`700@08>`70`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`7
0?ooo`02023/1`80oooo00L08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo00808>`70P3oool00`0P
k0L0oooo023/1`03023/1`80oooo1P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`7
00<08>`700<0oooo023/1`0Pk0L00P3oool6023/1`030000003oool08>`700<08>`7103oool3023/
1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L0203oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3o
ool0oooo02`0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool09@3oool0
0`0Pk0L0oooo023/1`040?ooo`04023/1`3oool0oooo023/1`80oooo100Pk0L20?ooo`03023/1`3o
ool08>`700H0oooo0`0Pk0L0103oool08>`70?ooo`3oool3023/1`030?ooo`0Pk0L08>`700@08>`7
0`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`02023/1`80oooo00L08>`70?oo
o`0Pk0L08>`70?ooo`0Pk0L0oooo00808>`70P3oool00`0Pk0L0oooo023/1`03023/1`80oooo1P0P
k0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P3o
ool6023/1`030000003oool08>`700<08>`7103oool3023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L0
203oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo02`0oooo00<000000?ooo`3o
ool07@3oool001/0oooo00<000000?ooo`3oool09@3oool00`0Pk0L0oooo023/1`040?ooo`04023/
1`3oool0oooo023/1`80oooo100Pk0L20?ooo`03023/1`3oool08>`700H0oooo0`0Pk0L0103oool0
8>`70?ooo`3oool3023/1`030?ooo`0Pk0L08>`700@08>`70`3oool3023/1`070?ooo`0Pk0L08>`7
023/1`3oool08>`70?ooo`02023/1`80oooo00L08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0080
8>`70P3oool5023/1`<0oooo1P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<0
8>`700<0oooo023/1`0Pk0L00P3oool6023/1`030000003oool08>`700<08>`7103oool3023/1`05
0?ooo`0Pk0L0oooo0?ooo`0Pk0L0203oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo
02`0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool09@3oool00`0Pk0L0
oooo023/1`040?ooo`04023/1`3oool0oooo023/1`80oooo0`0Pk0L01P3oool08>`70?ooo`0Pk0L0
oooo023/1`H0oooo0`0Pk0L0103oool08>`70?ooo`3oool3023/1`030?ooo`0Pk0L08>`700@08>`7
0`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`02023/1`80oooo00L08>`70?oo
o`0Pk0L08>`70?ooo`0Pk0L0oooo00808>`70P3oool5023/1`<0oooo1P0Pk0L00`3oool08>`7023/
1`03023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P3oool6023/1`030000003o
ool08>`700<08>`7103oool3023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L0203oool00`0Pk0L0oooo
023/1`030?ooo`03023/1`3oool0oooo02`0oooo00<000000?ooo`3oool07@3oool001/0oooo00<0
00000?ooo`3oool09@3oool00`0Pk0L0oooo023/1`040?ooo`04023/1`3oool0oooo023/1`80oooo
0`0Pk0L01P3oool08>`70?ooo`0Pk0L0oooo023/1`H0oooo0`0Pk0L0103oool08>`70?ooo`3oool3
023/1`030?ooo`0Pk0L08>`700@08>`70`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`7
0?ooo`02023/1`80oooo00D08>`70?ooo`0Pk0L08>`70?ooo`04023/1`80oooo1@0Pk0L30?ooo`H0
8>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`70080
oooo1P0Pk0L00`000000oooo023/1`03023/1`@0oooo0`0Pk0L01@3oool08>`70?ooo`3oool08>`7
00P0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`0/0?ooo`030000003oool0oooo
01d0oooo000K0?ooo`030000003oool0oooo02D0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0
oooo0?ooo`0Pk0L20?ooo`<08>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L60?ooo`<08>`700@0
oooo023/1`3oool0oooo0`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo0`0Pk0L01`3oool08>`7
023/1`0Pk0L0oooo023/1`3oool00P0Pk0L20?ooo`05023/1`3oool08>`7023/1`3oool0100Pk0L2
0?ooo`D08>`70`3oool6023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00`0Pk0L0
0`3oool08>`7023/1`020?ooo`H08>`700<000000?ooo`0Pk0L00`0Pk0L40?ooo`<08>`700D0oooo
023/1`3oool0oooo023/1`080?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool0;03o
ool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`03023/1`3oool0
8>`700@0oooo00@08>`70?ooo`3oool08>`70P3oool3023/1`060?ooo`0Pk0L0oooo023/1`3oool0
8>`71P3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L30?oo
o`<08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00808>`70P3oool01@0Pk0L0oooo023/
1`0Pk0L0oooo00@08>`70P3oool5023/1`<0oooo1P0Pk0L00`3oool08>`7023/1`03023/1`030?oo
o`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P3oool6023/1`030000003oool08>`700<08>`7
103oool3023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L0203oool00`0Pk0L0oooo023/1`030?ooo`03
023/1`3oool0oooo02`0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool0
9@3oool00`0Pk0L0oooo023/1`040?ooo`04023/1`3oool0oooo023/1`80oooo0`0Pk0L01P3oool0
8>`70?ooo`0Pk0L0oooo023/1`H0oooo0`0Pk0L0103oool08>`70?ooo`3oool3023/1`030?ooo`0P
k0L08>`700@08>`70`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`02023/1`80
oooo00D08>`70?ooo`0Pk0L08>`70?ooo`04023/1`80oooo1@0Pk0L30?ooo`H08>`700<0oooo023/
1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo1@0P
k0L00`000000oooo023/1`03023/1`@0oooo0`0Pk0L01@3oool08>`70?ooo`3oool08>`700P0oooo
00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`0/0?ooo`030000003oool0oooo01d0oooo
000K0?ooo`030000003oool0oooo02D0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo0?oo
o`0Pk0L20?ooo`<08>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L60?ooo`<08>`700@0oooo023/
1`3oool0oooo0`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo0`0Pk0L01`3oool08>`7023/1`0P
k0L0oooo023/1`3oool00P0Pk0L20?ooo`05023/1`3oool08>`7023/1`3oool0100Pk0L20?ooo`D0
8>`70`3oool6023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00`0Pk0L01P3oool0
8>`7023/1`3oool08>`70?ooo`D08>`700<000000?ooo`0Pk0L00`0Pk0L40?ooo`<08>`700D0oooo
023/1`3oool0oooo023/1`080?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool0;03o
ool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`03023/1`3oool0
8>`700@0oooo00@08>`70?ooo`3oool08>`70P3oool3023/1`060?ooo`0Pk0L0oooo023/1`3oool0
8>`71P3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L30?oo
o`<08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00808>`70P3oool01@0Pk0L0oooo023/
1`0Pk0L0oooo00@08>`70P3oool5023/1`<0oooo1P0Pk0L00`3oool08>`7023/1`03023/1`030?oo
o`0Pk0L08>`700<08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool5023/1`030000003oool08>`7
00<08>`7103oool3023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L0203oool00`0Pk0L0oooo023/1`03
0?ooo`03023/1`3oool0oooo02`0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?oo
o`3oool09@3oool00`0Pk0L0oooo023/1`040?ooo`04023/1`3oool0oooo023/1`80oooo0`0Pk0L0
1P3oool08>`70?ooo`0Pk0L0oooo023/1`H0oooo0`0Pk0L0103oool08>`70?ooo`3oool3023/1`03
0?ooo`0Pk0L08>`700@08>`70`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`02
023/1`80oooo00D08>`70?ooo`0Pk0L08>`70?ooo`04023/1`80oooo1@0Pk0L30?ooo`H08>`700<0
oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0
oooo0`0Pk0L0103oool08>`70000003oool4023/1`@0oooo0`0Pk0L01@3oool08>`70?ooo`3oool0
8>`700L0oooo00@08>`70?ooo`3oool08>`70`3oool00`0Pk0L0oooo0?ooo`0/0?ooo`030000003o
ool0oooo01d0oooo000K0?ooo`030000003oool0oooo02D0oooo00<08>`70?ooo`0Pk0L0103oool0
100Pk0L0oooo0?ooo`0Pk0L20?ooo`09023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`7
00H0oooo0`0Pk0L0103oool08>`70?ooo`3oool3023/1`030?ooo`0Pk0L08>`700@08>`70`3oool3
023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`02023/1`80oooo00D08>`70?ooo`0Pk0L0
8>`70?ooo`04023/1`80oooo1@0Pk0L30?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool0
8>`7023/1`03023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool08>`70000003o
ool4023/1`@0oooo0`0Pk0L01@3oool08>`70?ooo`3oool08>`700L0oooo00@08>`70?ooo`3oool0
8>`70`3oool00`0Pk0L0oooo0?ooo`0/0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000
003oool0oooo02D0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`09
023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`700H0oooo0`0Pk0L0103oool08>`70?oo
o`3oool3023/1`030?ooo`0Pk0L0oooo00@08>`70`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3o
ool08>`70?ooo`02023/1`80oooo00D08>`70?ooo`0Pk0L08>`70?ooo`04023/1`80oooo1@0Pk0L3
0?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03023/1`060?ooo`0Pk0L0
8>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool08>`70000003oool4023/1`@0oooo0`0Pk0L01@3oool0
8>`70?ooo`3oool08>`700L0oooo00@08>`70?ooo`3oool08>`70`3oool00`0Pk0L0oooo0?ooo`0/
0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo02D0oooo00<08>`70?oo
o`0Pk0L0103oool2023/1`0=0?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0P
k0L0oooo023/1`060?ooo`<08>`700@0oooo023/1`3oool0oooo0`0Pk0L00`3oool08>`70?ooo`04
023/1`<0oooo0`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool00P0Pk0L20?ooo`05023/
1`3oool08>`7023/1`3oool0100Pk0L20?ooo`D08>`70`3oool6023/1`030?ooo`0Pk0L08>`700<0
8>`700<0oooo023/1`0Pk0L00`0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`<08>`700@0oooo
023/1`000000oooo0`0Pk0L50?ooo`808>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L70?ooo`04023/
1`3oool0oooo023/1`<0oooo00<08>`70?ooo`3oool0;03oool00`000000oooo0?ooo`0M0?ooo`00
6`3oool00`000000oooo0?ooo`0U0?ooo`03023/1`3oool08>`700@0oooo0P0Pk0L03@3oool08>`7
0?ooo`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L01P3oool3023/1`040?oo
o`0Pk0L0oooo0?ooo`<08>`700<0oooo023/1`3oool0100Pk0L30?ooo`<08>`700L0oooo023/1`0P
k0L08>`70?ooo`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/
1`02023/1`80oooo1@0Pk0L30?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/
1`03023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool08>`70000003oool3023/
1`D0oooo0P0Pk0L20?ooo`04023/1`3oool0oooo023/1`L0oooo00@08>`70?ooo`3oool08>`70P3o
ool00`0Pk0L0oooo0?ooo`0]0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0
oooo02D0oooo00<08>`70?ooo`0Pk0L0103oool2023/1`0=0?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo
023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`060?ooo`<08>`700<0oooo023/1`3oool0100Pk0L0
0`3oool08>`70?ooo`04023/1`<0oooo0`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool0
0P0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool5023/1`<0
oooo1P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`700H0oooo023/1`0P
k0L0oooo023/1`3oool3023/1`040?ooo`0Pk0L000000?ooo`<08>`7103oool3023/1`80oooo00@0
8>`70?ooo`3oool08>`71`3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo02d0
oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool09@3oool00`0Pk0L0oooo
023/1`040?ooo`808>`700d0oooo023/1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo023/
1`3oool08>`700H0oooo0`0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L0oooo00@08>`7
0`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`02023/1`040?ooo`0Pk0L08>`7
0?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`D08>`70P3oool7023/1`030?ooo`0Pk0L0
8>`700<08>`700<0oooo023/1`0Pk0L00`0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`<08>`7
00@0oooo023/1`000000oooo0`0Pk0L40?ooo`<08>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L70?oo
o`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool0;@3oool00`000000oooo0?ooo`0M
0?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`03023/1`3oool08>`700@0oooo0P0Pk0L03@3o
ool08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L01P3oool3023/
1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`3oool0100Pk0L30?ooo`<08>`700L0oooo023/
1`0Pk0L08>`70?ooo`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7
023/1`02023/1`80oooo1@0Pk0L20?ooo`L08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7
023/1`03023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0`0Pk0L0103oool08>`70000003oool3
023/1`@0oooo0`0Pk0L20?ooo`04023/1`3oool0oooo023/1`L0oooo00@08>`70?ooo`3oool08>`7
0P3oool00`0Pk0L0oooo0?ooo`0]0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003o
ool0oooo02D0oooo00<08>`70?ooo`0Pk0L0103oool2023/1`0=0?ooo`0Pk0L0oooo0?ooo`0Pk0L0
oooo023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`060?ooo`<08>`700<0oooo023/1`3oool0100P
k0L00`3oool08>`70?ooo`04023/1`<0oooo0`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3o
ool00P0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool5023/
1`80oooo1`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`700H0oooo023/
1`0Pk0L0oooo023/1`3oool3023/1`040?ooo`0Pk0L000000?ooo`<08>`7103oool3023/1`80oooo
00@08>`70?ooo`3oool08>`71`3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo
02d0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool09@3oool00`0Pk0L0
oooo023/1`040?ooo`808>`700d0oooo023/1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo
023/1`3oool08>`700H0oooo0`0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L0oooo00@0
8>`70`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`02023/1`040?ooo`0Pk0L0
8>`70?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`D08>`70P3oool7023/1`030?ooo`0P
k0L08>`700<08>`700<0oooo023/1`0Pk0L0100Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`7
00@0oooo023/1`000000oooo0`0Pk0L40?ooo`<08>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L70?oo
o`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool0;@3oool00`000000oooo0?ooo`0M
0?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`03023/1`3oool08>`700@0oooo0P0Pk0L02@3o
ool08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo023/1`020?ooo`808>`71P3oool3023/1`030?oo
o`0Pk0L0oooo00@08>`700<0oooo023/1`3oool0100Pk0L30?ooo`<08>`700L0oooo023/1`0Pk0L0
8>`70?ooo`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`02
023/1`80oooo1@0Pk0L20?ooo`L08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`04
023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L0103oool08>`70000003oool3023/1`@0oooo
0`0Pk0L20?ooo`04023/1`3oool0oooo023/1`L0oooo00@08>`70?ooo`3oool08>`70P3oool00`0P
k0L0oooo0?ooo`0]0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo02D0
oooo00<08>`70?ooo`0Pk0L0103oool2023/1`090?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3o
ool08>`70080oooo0P0Pk0L60?ooo`<08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`70?oo
o`04023/1`<0oooo0`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool01@0Pk0L20?ooo`03
023/1`3oool08>`700<08>`70P3oool5023/1`80oooo1`0Pk0L00`3oool08>`7023/1`03023/1`03
0?ooo`0Pk0L08>`700@08>`700D0oooo023/1`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L00000
00@08>`7103oool3023/1`80oooo00@08>`70?ooo`3oool08>`71`3oool0100Pk0L0oooo0?ooo`0P
k0L20?ooo`03023/1`3oool0oooo02d0oooo00<000000?ooo`3oool07@3oool001/0oooo00<00000
0?ooo`3oool09@3oool00`0Pk0L0oooo023/1`040?ooo`808>`700T0oooo023/1`0Pk0L0oooo023/
1`3oool08>`70?ooo`0Pk0L00P3oool2023/1`H0oooo0`0Pk0L00`3oool08>`70?ooo`04023/1`03
0?ooo`0Pk0L0oooo00@08>`70`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`05
023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?ooo`D08>`70P3oool7023/1`070?ooo`0Pk0L0
8>`7023/1`3oool08>`70?ooo`06023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L00`3oool0
8>`700000004023/1`@0oooo0`0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo00D0
oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`0]0?ooo`030000003oool0oooo
01d0oooo000K0?ooo`030000003oool0oooo02D0oooo00<08>`70?ooo`0Pk0L0103oool2023/1`09
0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70080oooo0P0Pk0L60?ooo`<08>`700<0
oooo023/1`3oool0100Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0`0Pk0L01`3oool08>`7023/
1`0Pk0L0oooo023/1`3oool01@0Pk0L20?ooo`03023/1`3oool08>`700<08>`70P3oool5023/1`80
oooo1`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool01P0Pk0L01@3oool08>`70?ooo`0P
k0L0oooo00<08>`700<0oooo023/1`000000100Pk0L40?ooo`<08>`700<0oooo023/1`3oool00P3o
ool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`03023/1`3oool0
8>`700@0oooo0P0Pk0L02@3oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`020?ooo`80
8>`71P3oool3023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`3oool0100Pk0L30?ooo`<0
8>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00D08>`70P3oool00`0Pk0L0oooo023/1`03
023/1`80oooo1@0Pk0L20?ooo`L08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00H08>`7
00D0oooo023/1`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0000000@08>`7103oool3023/1`03
0?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool01@3oool00`0Pk0L0oooo023/1`030?ooo`03
023/1`3oool0oooo02d0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool0
9@3oool00`0Pk0L0oooo023/1`040?ooo`808>`700T0oooo023/1`0Pk0L0oooo023/1`3oool08>`7
0?ooo`0Pk0L00P3oool2023/1`H0oooo0`0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L0
oooo00@08>`70`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`05023/1`80oooo
00<08>`70?ooo`0Pk0L00`0Pk0L20?ooo`D08>`70P3oool7023/1`070?ooo`0Pk0L08>`7023/1`3o
ool08>`70?ooo`06023/1`030?ooo`0Pk0L0oooo00H08>`700<0oooo0000000Pk0L00`0Pk0L40?oo
o`<08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool08>`7
00<0oooo00<08>`70?ooo`3oool0;@3oool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000
oooo0?ooo`0U0?ooo`03023/1`3oool08>`700@0oooo0P0Pk0L02@3oool08>`7023/1`3oool08>`7
0?ooo`0Pk0L0oooo023/1`020?ooo`808>`71P3oool3023/1`040?ooo`0Pk0L08>`70?ooo`<08>`7
00<0oooo023/1`3oool0100Pk0L30?ooo`<08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo
00D08>`70P3oool00`0Pk0L0oooo023/1`03023/1`80oooo1@0Pk0L20?ooo`L08>`700L0oooo023/
1`0Pk0L08>`70?ooo`0Pk0L0oooo00H08>`700<0oooo023/1`3oool01P0Pk0L00`3oool00000023/
1`03023/1`@0oooo0`0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo00D0oooo00<0
8>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`0]0?ooo`030000003oool0oooo01d0oooo000K
0?ooo`030000003oool0oooo02D0oooo00<08>`70?ooo`0Pk0L0103oool2023/1`090?ooo`0Pk0L0
8>`70?ooo`0Pk0L0oooo023/1`3oool08>`70080oooo0P0Pk0L60?ooo`<08>`700@0oooo023/1`0P
k0L0oooo0`0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0`0Pk0L01`3oool08>`7023/1`0Pk0L0
oooo023/1`3oool01@0Pk0L20?ooo`03023/1`3oool08>`700<08>`70P3oool5023/1`80oooo1`0P
k0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool01`0Pk0L20?ooo`H08>`700<0oooo0000000P
k0L00`0Pk0L40?ooo`<08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`050?ooo`03
023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool0;@3oool00`000000oooo0?ooo`0M0?ooo`00
6`3oool00`000000oooo0?ooo`0U0?ooo`03023/1`3oool08>`700@0oooo0P0Pk0L02@3oool08>`7
023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`020?ooo`808>`71P3oool3023/1`040?ooo`0Pk0L0
8>`70?ooo`<08>`700<0oooo023/1`3oool0100Pk0L30?ooo`<08>`700L0oooo023/1`0Pk0L08>`7
0?ooo`0Pk0L0oooo00D08>`70P3oool00`0Pk0L0oooo023/1`03023/1`80oooo1@0Pk0L20?ooo`L0
8>`700T0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool01@0Pk0L20?ooo`H08>`700<0
oooo0000000Pk0L00`0Pk0L40?ooo`<08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?oo
o`050?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool0;@3oool00`000000oooo0?oo
o`0M0?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`03023/1`3oool08>`700@0oooo0P0Pk0L0
2@3oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`020?ooo`808>`71P3oool3023/1`04
0?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo023/1`3oool0100Pk0L30?ooo`<08>`700L0oooo023/
1`0Pk0L08>`70?ooo`0Pk0L0oooo00D08>`70P3oool00`0Pk0L0oooo023/1`03023/1`80oooo0`0P
k0L01@3oool08>`70?ooo`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7
023/1`03023/1`80oooo1P0Pk0L00`3oool00000023/1`03023/1`@0oooo0`0Pk0L00`3oool08>`7
0?ooo`020?ooo`03023/1`3oool0oooo00D0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo
0?ooo`0]0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo02D0oooo00<0
8>`70?ooo`0Pk0L0103oool2023/1`090?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`3oool08>`7
0080oooo0P0Pk0L60?ooo`<08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3oool08>`70?ooo`04
023/1`<0oooo0`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool01@0Pk0L20?ooo`03023/
1`3oool08>`700<08>`70P3oool3023/1`050?ooo`0Pk0L0oooo023/1`3oool01P0Pk0L00`3oool0
8>`7023/1`05023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool6023/1`030?ooo`0000008>`7
00<08>`7103oool3023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool01@3oool00`0P
k0L0oooo023/1`030?ooo`03023/1`3oool0oooo02d0oooo00<000000?ooo`3oool07@3oool001/0
oooo00<000000?ooo`3oool09@3oool00`0Pk0L0oooo023/1`040?ooo`808>`700T0oooo023/1`0P
k0L0oooo023/1`3oool08>`70?ooo`0Pk0L00P3oool2023/1`H0oooo0`0Pk0L0103oool08>`7023/
1`3oool3023/1`030?ooo`0Pk0L0oooo00@08>`70`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3o
ool08>`70?ooo`05023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?ooo`<08>`700D0oooo023/
1`3oool08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700D08>`700@0oooo023/1`0Pk0L0oooo0P0P
k0L20?ooo`H08>`700<0oooo0000000Pk0L00`0Pk0L40?ooo`<08>`700D0oooo023/1`3oool0oooo
023/1`070?ooo`04023/1`3oool0oooo023/1`<0oooo00<08>`70?ooo`3oool0;@3oool00`000000
oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`03023/1`3oool08>`700@0oooo
0P0Pk0L02@3oool08>`7023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`020?ooo`808>`71P3oool3
023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo023/1`3oool0100Pk0L30?ooo`<08>`700L0
oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00D08>`70P3oool00`0Pk0L0oooo023/1`03023/1`80
oooo0`0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L01@0Pk0L0103o
ool08>`7023/1`3oool2023/1`80oooo1P0Pk0L00`3oool00000023/1`03023/1`@0oooo0`0Pk0L0
1@3oool08>`70?ooo`3oool08>`700L0oooo00@08>`70?ooo`3oool08>`70`3oool00`0Pk0L0oooo
0?ooo`0]0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo02H0oooo0P0P
k0L40?ooo`808>`700T0oooo023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L00P3oool2023/
1`H0oooo0`0Pk0L0103oool08>`7023/1`3oool3023/1`030?ooo`0Pk0L0oooo00@08>`70`3oool3
023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`05023/1`80oooo00<08>`70?ooo`0Pk0L0
0`0Pk0L20?ooo`<08>`700D0oooo023/1`3oool08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700D0
8>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`H08>`700<0oooo0000000Pk0L00`0Pk0L40?oo
o`<08>`700D0oooo023/1`3oool0oooo023/1`070?ooo`04023/1`3oool0oooo023/1`<0oooo00<0
8>`70?ooo`3oool0;@3oool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0V
0?ooo`808>`7103oool2023/1`070?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`020?ooo`04023/
1`3oool08>`7023/1`H0oooo0`0Pk0L0103oool08>`7023/1`3oool3023/1`030?ooo`0Pk0L0oooo
00@08>`70`3oool3023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`05023/1`80oooo00<0
8>`70?ooo`0Pk0L00`0Pk0L20?ooo`<08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00@0
8>`700<0oooo023/1`0Pk0L01@0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo1P0Pk0L00`3o
ool00000023/1`03023/1`@0oooo0`0Pk0L01@3oool08>`70?ooo`3oool08>`700L0oooo00@08>`7
0?ooo`3oool08>`70`3oool00`0Pk0L0oooo0?ooo`0]0?ooo`030000003oool0oooo01d0oooo000K
0?ooo`030000003oool0oooo02H0oooo0P0Pk0L40?ooo`808>`700H0oooo023/1`0Pk0L0oooo023/
1`3oool2023/1`030?ooo`0Pk0L0oooo00808>`71P3oool3023/1`040?ooo`0Pk0L08>`70?ooo`<0
8>`700<0oooo023/1`3oool0100Pk0L30?ooo`<08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0
oooo00@08>`70`3oool00`0Pk0L0oooo023/1`03023/1`80oooo0`0Pk0L01`3oool08>`70?ooo`0P
k0L0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`05023/1`040?ooo`0Pk0L08>`70?ooo`80
8>`70P3oool6023/1`030?ooo`0000008>`700<08>`7103oool3023/1`050?ooo`0Pk0L0oooo0?oo
o`0Pk0L01`3oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`03023/1`3oool0oooo02d0oooo00<00000
0?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool09P3oool2023/1`@0oooo0P0Pk0L01P3o
ool08>`7023/1`3oool08>`70?ooo`808>`700<0oooo023/1`3oool00P0Pk0L60?ooo`<08>`700@0
oooo023/1`3oool0oooo0`0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0`0Pk0L01`3oool08>`7
023/1`0Pk0L0oooo023/1`3oool0100Pk0L30?ooo`03023/1`3oool08>`700<08>`70P3oool3023/
1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700D08>`700@0
oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`H08>`700<0oooo0000000Pk0L00`0Pk0L40?ooo`<08>`7
00D0oooo023/1`3oool0oooo023/1`070?ooo`04023/1`3oool0oooo023/1`<0oooo00<08>`70?oo
o`3oool0;@3oool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0V0?ooo`80
8>`7103oool2023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L00`3oool08>`70?ooo`02
023/1`H0oooo0`0Pk0L0103oool08>`70?ooo`3oool3023/1`030?ooo`0Pk0L0oooo00@08>`70`3o
ool3023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`03023/1`8000000P3oool00`0Pk0L0
oooo023/1`03023/1`80oooo0`0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool0100Pk0L0
0`3oool08>`7023/1`05023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool6023/1`030?ooo`00
00008>`700<08>`7103oool3023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L01`3oool0100Pk0L0oooo
0?ooo`0Pk0L30?ooo`03023/1`3oool0oooo02d0oooo00<000000?ooo`3oool07@3oool001/0oooo
00<000000?ooo`3oool09P3oool2023/1`@0oooo0P0Pk0L01P3oool08>`7023/1`3oool08>`70?oo
o`808>`700<0oooo023/1`3oool00P0Pk0L60?ooo`<08>`700@0oooo023/1`3oool0oooo0`0Pk0L0
0`3oool08>`70?ooo`04023/1`<0oooo0`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool0
0`0Pk0L200000080oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?ooo`<08>`700L0oooo023/1`3oool0
8>`70?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L01@0Pk0L0103oool08>`7023/1`3oool2
023/1`80oooo1P0Pk0L00`3oool00000023/1`03023/1`@0oooo0P0Pk0L20?ooo`04023/1`3oool0
oooo023/1`L0oooo00@08>`70?ooo`3oool08>`70`3oool00`0Pk0L0oooo0?ooo`0]0?ooo`030000
003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo02H0oooo0P0Pk0L40?ooo`03023/1`3o
ool08>`700808>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`70?ooo`02023/1`H0oooo0`0P
k0L0103oool08>`70?ooo`3oool3023/1`030?ooo`0Pk0L0oooo00@08>`70`3oool3023/1`070?oo
o`0Pk0L08>`7023/1`3oool08>`70?ooo`04023/1`<0oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?oo
o`<08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00<08>`70P3oool7023/1`040?ooo`0P
k0L08>`70?ooo`808>`700<0oooo023/1`3oool01@0Pk0L00`3oool00000023/1`03023/1`@0oooo
0P0Pk0L20?ooo`04023/1`3oool0oooo023/1`L0oooo00@08>`70?ooo`3oool08>`70`3oool00`0P
k0L0oooo0?ooo`0]0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo02H0
oooo0P0Pk0L40?ooo`03023/1`3oool08>`700808>`700P0oooo023/1`3oool0oooo023/1`3oool0
8>`70?ooo`<08>`71@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`D08>`700<0oooo023/1`0Pk0L0
0P0Pk0L30?ooo`L08>`700<0oooo023/1`3oool0100Pk0L30?ooo`03023/1`3oool08>`700<08>`7
0P3oool5023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L20?ooo`L08>`700@0oooo023/1`0P
k0L0oooo0P0Pk0L00`3oool08>`70?ooo`05023/1`030?ooo`0000008>`700808>`71@3oool2023/
1`80oooo00@08>`70?ooo`3oool08>`71`3oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`03023/1`3o
ool0oooo02d0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool09P3oool0
0`0Pk0L0oooo023/1`030?ooo`03023/1`3oool08>`700808>`70P3oool01P0Pk0L0oooo023/1`3o
ool08>`70?ooo`<08>`71@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`D08>`700<0oooo023/1`0P
k0L00P0Pk0L30?ooo`L08>`700<0oooo023/1`3oool0100Pk0L30?ooo`03023/1`3oool08>`700<0
8>`70P3oool6023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?ooo`L08>`700@0oooo023/1`0P
k0L0oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L0oooo000000<08>`71@3oool2
023/1`80oooo00@08>`70?ooo`3oool08>`71`3oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`03023/
1`3oool0oooo02d0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool09P3o
ool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool08>`700808>`70P3oool01P0Pk0L0oooo023/
1`3oool08>`70?ooo`<08>`71@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`D08>`700<0oooo023/
1`0Pk0L00P0Pk0L30?ooo`L08>`700<0oooo023/1`3oool0100Pk0L30?ooo`03023/1`3oool08>`7
00<08>`70P3oool6023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?ooo`L08>`700@0oooo023/
1`0Pk0L0oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L0oooo000000<08>`71@3o
ool2023/1`80oooo00@08>`70?ooo`3oool08>`71`3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03
023/1`3oool0oooo02h0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool0
9P3oool00`0Pk0L0oooo023/1`030?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3oool01P0Pk0L0
oooo023/1`3oool08>`70?ooo`<08>`71@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`D08>`700<0
oooo023/1`0Pk0L00P0Pk0L30?ooo`L08>`700<0oooo023/1`3oool0100Pk0L30?ooo`03023/1`3o
ool08>`700<08>`70P3oool6023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?ooo`L08>`700@0
oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L0oooo000000<0
8>`71@3oool2023/1`80oooo00@08>`70?ooo`3oool08>`71`3oool00`0Pk0L0oooo023/1`030?oo
o`03023/1`3oool0oooo02l0oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3o
ool09P3oool00`0Pk0L0oooo023/1`030?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3oool01P0P
k0L0oooo023/1`3oool08>`70?ooo`<08>`71@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`D08>`7
00<0oooo023/1`0Pk0L00P0Pk0L30?ooo`L08>`700<0oooo023/1`3oool0100Pk0L30?ooo`03023/
1`3oool08>`700<08>`70P3oool6023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?ooo`L08>`7
00@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L0oooo0000
00<08>`71@3oool2023/1`80oooo00@08>`70?ooo`3oool08>`71`3oool00`0Pk0L0oooo023/1`03
0?ooo`03023/1`3oool0oooo02l0oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?oo
o`3oool09P3oool00`0Pk0L0oooo023/1`040?ooo`808>`700X0oooo023/1`3oool0oooo023/1`3o
ool08>`70?ooo`0Pk0L0oooo0`0Pk0L50?ooo`<08>`700@0oooo023/1`3oool0oooo1@0Pk0L00`3o
ool08>`7023/1`02023/1`<0oooo1`0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo00<08>`70?oo
o`0Pk0L00`0Pk0L20?ooo`H08>`70P3oool00`0Pk0L0oooo023/1`02023/1`80oooo1`0Pk0L0103o
ool08>`7023/1`3oool2023/1`030?ooo`0Pk0L0oooo00<08>`700@0oooo023/1`3oool000000`0P
k0L50?ooo`808>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L70?ooo`03023/1`3oool08>`700<0oooo
00<08>`70?ooo`3oool0;`3oool00`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo0?oo
o`0V0?ooo`03023/1`3oool08>`700@0oooo0P0Pk0L02P3oool08>`70?ooo`3oool08>`70?ooo`0P
k0L0oooo023/1`3oool3023/1`D0oooo1@0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L3
0?ooo`L08>`700<0oooo023/1`3oool0100Pk0L30?ooo`03023/1`3oool08>`700<08>`70P3oool6
023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?ooo`L08>`700@0oooo023/1`0Pk0L0oooo0P0P
k0L00`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L0oooo000000<08>`71@3oool2023/1`80oooo
00@08>`70?ooo`3oool08>`71`3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo02l0
oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool09P3oool00`0Pk0L0oooo
023/1`040?ooo`808>`700X0oooo023/1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo0`0P
k0L50?ooo`@08>`700<0oooo023/1`3oool01@0Pk0L00`3oool08>`7023/1`02023/1`<0oooo1`0P
k0L00`3oool08>`70?ooo`04023/1`<0oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?ooo`H08>`70P3o
ool00`0Pk0L0oooo023/1`02023/1`80oooo1`0Pk0L0103oool08>`7023/1`3oool2023/1`030?oo
o`0Pk0L0oooo00<08>`700@0oooo023/1`3oool000000`0Pk0L50?ooo`808>`700<0oooo023/1`3o
ool00P3oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo0?ooo`0V0?ooo`03023/
1`3oool08>`700@0oooo0P0Pk0L02P3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo023/1`3o
ool3023/1`D0oooo100Pk0L00`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L08>`700808>`70`3o
ool7023/1`030?ooo`0Pk0L0oooo00@08>`70`3oool00`0Pk0L0oooo023/1`03023/1`80oooo1P0P
k0L20?ooo`03023/1`3oool08>`700808>`70P3oool7023/1`040?ooo`0Pk0L08>`70?ooo`808>`7
00<0oooo023/1`3oool00`0Pk0L0103oool08>`70?ooo`000003023/1`D0oooo0P0Pk0L00`3oool0
8>`70?ooo`020?ooo`03023/1`3oool0oooo00D0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0
oooo0?ooo`0_0?ooo`030000003oool0oooo01`0oooo000K0?ooo`030000003oool0oooo02H0oooo
00<08>`70?ooo`0Pk0L0103oool2023/1`0:0?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool0
8>`70?ooo`<08>`71@3oool4023/1`030?ooo`0Pk0L0oooo00D08>`700<0oooo023/1`0Pk0L00P0P
k0L30?ooo`L08>`700<0oooo023/1`3oool0100Pk0L30?ooo`808>`700@0oooo023/1`0Pk0L08>`7
0P3oool6023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?ooo`L08>`700@0oooo023/1`0Pk0L0
oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L0oooo000000<08>`71@3oool2023/
1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool01@3oool00`0Pk0L0oooo023/1`030?oo
o`03023/1`3oool0oooo02l0oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3o
ool09P3oool00`0Pk0L0oooo023/1`040?ooo`808>`700X0oooo023/1`3oool0oooo023/1`3oool0
8>`70?ooo`0Pk0L0oooo0`0Pk0L50?ooo`@08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`L08>`7
00<0oooo023/1`3oool0100Pk0L30?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`80
oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?ooo`L08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3o
ool08>`70?ooo`03023/1`040?ooo`0Pk0L0oooo000000<08>`71@3oool2023/1`030?ooo`0Pk0L0
oooo0080oooo00<08>`70?ooo`3oool01@3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0
oooo02l0oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool09P3oool00`0P
k0L0oooo023/1`040?ooo`808>`700T0oooo023/1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L0
0P3oool2023/1`D0oooo100Pk0L00`3oool08>`70?ooo`0:023/1`<0oooo1`0Pk0L00`3oool08>`7
0?ooo`04023/1`<0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`70P3oool00`0Pk0L0
oooo023/1`02023/1`80oooo1`0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L0oooo
00<08>`700@0oooo023/1`3oool000000`0Pk0L50?ooo`808>`700<0oooo023/1`3oool00P3oool0
0`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo0?ooo`0V0?ooo`03023/1`3oool08>`7
00@0oooo0P0Pk0L02@3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo023/1`020?ooo`808>`7
1@3oool4023/1`030?ooo`0Pk0L0oooo00X08>`70`3oool7023/1`030?ooo`0Pk0L0oooo00@08>`7
0`3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L20?ooo`03023/1`3oool08>`70080
8>`70P3oool7023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`3oool00`0Pk0L0103o
ool08>`70?ooo`000003023/1`D0oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0
oooo00@0oooo00@08>`70?ooo`3oool08>`70`3oool00`0Pk0L0oooo0?ooo`0_0?ooo`030000003o
ool0oooo01`0oooo000K0?ooo`030000003oool0oooo02H0oooo00<08>`70?ooo`0Pk0L0103oool2
023/1`090?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`70080oooo0P0Pk0L50?ooo`@0
8>`700<0oooo023/1`3oool02P0Pk0L30?ooo`L08>`700<0oooo023/1`3oool0100Pk0L30?ooo`80
8>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?oo
o`L08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L0
oooo000000<08>`71@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0103o
ool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`03023/1`3oool0oooo02l0oooo00<000000?ooo`3oool0
703oool001/0oooo00<000000?ooo`3oool09P3oool00`0Pk0L0oooo023/1`040?ooo`808>`700T0
oooo023/1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L00P3oool2023/1`D0oooo100Pk0L00`3o
ool08>`70?ooo`0:023/1`<0oooo1`0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0P0Pk0L0103o
ool08>`7023/1`0Pk0L20?ooo`D08>`70`3oool00`0Pk0L0oooo023/1`02023/1`80oooo1`0Pk0L0
2@3oool08>`7023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L0oooo0000
00<08>`71@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0103oool0100P
k0L0oooo0?ooo`0Pk0L30?ooo`03023/1`3oool0oooo02l0oooo00<000000?ooo`3oool0703oool0
01/0oooo00<000000?ooo`3oool09P3oool00`0Pk0L0oooo023/1`040?ooo`808>`700T0oooo023/
1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L00P3oool2023/1`D0oooo100Pk0L00`3oool08>`7
0?ooo`0:023/1`<0oooo1`0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0P0Pk0L0103oool08>`7
023/1`0Pk0L20?ooo`D08>`70`3oool00`0Pk0L0oooo023/1`02023/1`80oooo1`0Pk0L02@3oool0
8>`7023/1`0Pk0L0oooo023/1`3oool08>`70?ooo`04023/1`80oooo00@00000023/1`0Pk0L08>`7
1@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo
0?ooo`0Pk0L30?ooo`03023/1`3oool0oooo02l0oooo00<000000?ooo`3oool0703oool001/0oooo
00<000000?ooo`3oool09P3oool00`0Pk0L0oooo023/1`040?ooo`808>`700T0oooo023/1`3oool0
oooo023/1`3oool08>`70?ooo`0Pk0L00P3oool2023/1`D0oooo100Pk0L00`3oool08>`70?ooo`0:
023/1`<0oooo1`0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0P0Pk0L0103oool08>`7023/1`0P
k0L20?ooo`D08>`70`3oool00`0Pk0L0oooo023/1`02023/1`80oooo1`0Pk0L02@3oool08>`7023/
1`0Pk0L0oooo023/1`3oool08>`70?ooo`04023/1`80oooo00@00000023/1`0Pk0L08>`7103oool3
023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`0P
k0L30?ooo`03023/1`3oool0oooo02l0oooo00<000000?ooo`3oool0703oool001/0oooo00<00000
0?ooo`3oool09P3oool00`0Pk0L0oooo023/1`040?ooo`808>`700T0oooo023/1`3oool0oooo023/
1`3oool08>`70?ooo`0Pk0L00P3oool2023/1`D0oooo100Pk0L00`3oool08>`70?ooo`0:023/1`<0
oooo1`0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?oo
o`D08>`70`3oool00`0Pk0L0oooo023/1`02023/1`80oooo1`0Pk0L02@3oool08>`7023/1`0Pk0L0
oooo023/1`3oool08>`70?ooo`04023/1`80oooo00@00000023/1`0Pk0L08>`7103oool3023/1`03
0?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`0Pk0L30?oo
o`03023/1`3oool0oooo02l0oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3o
ool09P3oool00`0Pk0L0oooo023/1`040?ooo`808>`700T0oooo023/1`3oool0oooo023/1`3oool0
8>`70?ooo`0Pk0L00P3oool2023/1`D0oooo100Pk0L00`3oool08>`70?ooo`0:023/1`<0oooo1`0P
k0L00`3oool08>`70?ooo`04023/1`<0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`D08>`7
0`3oool00`0Pk0L0oooo023/1`02023/1`80oooo1`0Pk0L02@3oool08>`7023/1`0Pk0L0oooo023/
1`3oool08>`70?ooo`04023/1`80oooo00@00000023/1`0Pk0L08>`7103oool3023/1`030?ooo`0P
k0L0oooo0080oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`03023/
1`3oool0oooo02l0oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool09P3o
ool00`0Pk0L0oooo023/1`040?ooo`808>`700T0oooo023/1`3oool0oooo023/1`3oool08>`70?oo
o`0Pk0L00P3oool2023/1`D0oooo100Pk0L00`3oool08>`70?ooo`0:023/1`<0oooo1`0Pk0L00`3o
ool08>`70?ooo`04023/1`<0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`D08>`70`3oool0
0`0Pk0L0oooo023/1`02023/1`80oooo1`0Pk0L02@3oool08>`7023/1`0Pk0L0oooo023/1`3oool0
8>`70?ooo`04023/1`80oooo00@00000023/1`0Pk0L08>`7103oool3023/1`030?ooo`0Pk0L0oooo
0080oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`03023/1`3oool0
oooo02l0oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool09P3oool00`0P
k0L0oooo023/1`040?ooo`808>`700T0oooo023/1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L0
0P3oool2023/1`D0oooo100Pk0L00`3oool08>`70?ooo`0:023/1`<0oooo1`0Pk0L00`3oool08>`7
0?ooo`04023/1`<0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`D08>`70`3oool00`0Pk0L0
oooo023/1`02023/1`030?ooo`0Pk0L08>`700H08>`700T0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0
oooo023/1`3oool0100Pk0L20?ooo`040000000Pk0L08>`7023/1`@0oooo0`0Pk0L00`3oool08>`7
0?ooo`020?ooo`03023/1`3oool0oooo00@0oooo00@08>`70?ooo`3oool08>`70`3oool00`0Pk0L0
oooo0?ooo`0_0?ooo`030000003oool0oooo01`0oooo000K0?ooo`030000003oool0oooo02H0oooo
00<08>`70?ooo`0Pk0L0103oool2023/1`090?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool0
8>`70080oooo0P0Pk0L50?ooo`@08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`L08>`700<0oooo
023/1`3oool0100Pk0L30?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool5023/1`80oooo0P0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00P08>`700T0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo
023/1`3oool0100Pk0L20?ooo`040000000Pk0L08>`7023/1`@0oooo0`0Pk0L00`3oool08>`70?oo
o`020?ooo`03023/1`3oool0oooo00@0oooo00@08>`70?ooo`3oool08>`70`3oool00`0Pk0L0oooo
0?ooo`0_0?ooo`030000003oool0oooo01`0oooo000K0?ooo`030000003oool0oooo02H0oooo00<0
8>`70?ooo`0Pk0L0103oool2023/1`090?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`7
0080oooo0P0Pk0L50?ooo`@08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`L08>`700<0oooo023/
1`3oool0100Pk0L30?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool5023/1`80oooo0P0Pk0L0
1@3oool08>`7023/1`0Pk0L0oooo00P08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3o
ool08>`700<08>`70P3oool0100000008>`7023/1`0Pk0L40?ooo`<08>`700<0oooo023/1`3oool0
0P3oool00`0Pk0L0oooo0?ooo`040?ooo`04023/1`3oool0oooo023/1`<0oooo00<08>`70?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo0?ooo`0V0?ooo`03023/
1`3oool08>`700@0oooo0P0Pk0L02@3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo023/1`02
0?ooo`808>`71@3oool4023/1`030?ooo`0Pk0L0oooo00X08>`7103oool6023/1`030?ooo`0Pk0L0
oooo00@08>`70`3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo1@0Pk0L20?ooo`808>`700D0
oooo023/1`0Pk0L08>`70?ooo`08023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo
023/1`03023/1`80oooo00@00000023/1`0Pk0L08>`7103oool2023/1`80oooo00D08>`70?ooo`3o
ool0oooo023/1`060?ooo`04023/1`3oool0oooo023/1`<0oooo00<08>`70?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo0?ooo`0V0?ooo`03023/1`3oool08>`7
00@0oooo0P0Pk0L02@3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo023/1`020?ooo`808>`7
1@3oool4023/1`030?ooo`0Pk0L0oooo00X08>`7103oool6023/1`030?ooo`0Pk0L0oooo00@08>`7
0`3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo1@0Pk0L20?ooo`808>`700D0oooo023/1`0P
k0L08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L20?oo
o`03023/1`3oool08>`700<08>`70P3oool0100000008>`7023/1`0Pk0L40?ooo`808>`70P3oool0
1@0Pk0L0oooo0?ooo`3oool08>`700H0oooo00<08>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?oo
o`0_0?ooo`030000003oool0oooo01`0oooo000K0?ooo`030000003oool0oooo02H0oooo00<08>`7
0?ooo`0Pk0L0103oool2023/1`090?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`70080
oooo0P0Pk0L50?ooo`@08>`700<0oooo023/1`3oool02P0Pk0L40?ooo`H08>`700<0oooo023/1`0P
k0L0100Pk0L30?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool5023/1`80oooo0P0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02
023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?ooo`040000000Pk0L08>`7023/1`@0oooo0P0P
k0L20?ooo`05023/1`3oool0oooo0?ooo`0Pk0L01P3oool00`0Pk0L0oooo023/1`040?ooo`03023/
1`3oool0oooo02l0oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool09P3o
ool00`0Pk0L0oooo023/1`040?ooo`04023/1`3oool08>`7023/1`80oooo00<08>`70?ooo`0Pk0L0
0P3oool0100Pk0L0oooo023/1`0Pk0L50?ooo`@08>`700<0oooo023/1`3oool02P0Pk0L40?ooo`H0
8>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool5023/
1`80oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00P0Pk0L0
0`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?ooo`040000000Pk0L0
8>`7023/1`@0oooo0P0Pk0L20?ooo`04023/1`3oool0oooo023/1`L0oooo00<08>`70?ooo`0Pk0L0
103oool00`0Pk0L0oooo0?ooo`0_0?ooo`030000003oool0oooo01`0oooo000K0?ooo`030000003o
ool0oooo02H0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo023/1`0Pk0L20?ooo`07023/
1`3oool08>`7023/1`3oool08>`70?ooo`02023/1`D0oooo100Pk0L00`3oool08>`70?ooo`0:023/
1`@0oooo1P0Pk0L00`3oool08>`7023/1`04023/1`<0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L2
0?ooo`D08>`70P3oool2023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`7023/
1`02023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo023/1`03023/1`80oooo00@0
0000023/1`0Pk0L08>`7103oool2023/1`80oooo00@08>`70?ooo`3oool08>`71`3oool00`0Pk0L0
oooo023/1`040?ooo`03023/1`3oool0oooo02l0oooo00<000000?ooo`3oool0703oool001/0oooo
00<000000?ooo`3oool09P3oool00`0Pk0L0oooo023/1`040?ooo`04023/1`3oool08>`7023/1`80
oooo00L08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo00808>`71@3oool4023/1`030?ooo`0Pk0L0
oooo00X08>`7103oool6023/1`030?ooo`0Pk0L08>`700@08>`70`3oool2023/1`030?ooo`0Pk0L0
8>`700<0oooo1@0Pk0L20?ooo`808>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`030?ooo`0P
k0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool08>`700<08>`70P3o
ool00`0000008>`7023/1`050?ooo`808>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L70?ooo`03023/
1`3oool08>`700@0oooo00<08>`70?ooo`3oool0;`3oool00`000000oooo0?ooo`0L0?ooo`006`3o
ool00`000000oooo0?ooo`0V0?ooo`03023/1`3oool08>`700@0oooo00@08>`70?ooo`0Pk0L08>`7
0P3oool01`0Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool00P0Pk0L50?ooo`@08>`700<0oooo023/
1`3oool02P0Pk0L40?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`808>`700<0oooo023/
1`0Pk0L00`3oool5023/1`80oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`700<0oooo
023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L2
0?ooo`030000000Pk0L08>`700D0oooo0P0Pk0L20?ooo`04023/1`3oool0oooo023/1`L0oooo00<0
8>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`0`0?ooo`030000003oool0oooo01`0oooo000K
0?ooo`030000003oool0oooo02H0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo023/1`0P
k0L20?ooo`07023/1`3oool0oooo023/1`3oool08>`70?ooo`02023/1`D0oooo100Pk0L00`3oool0
8>`70?ooo`0:023/1`@0oooo1P0Pk0L00`3oool08>`7023/1`04023/1`<0oooo0P0Pk0L00`3oool0
8>`7023/1`030?ooo`D08>`70P3oool2023/1`050?ooo`0Pk0L08>`7023/1`3oool0200Pk0L00`3o
ool08>`7023/1`02023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?ooo`030000000Pk0L08>`7
00D0oooo0P0Pk0L20?ooo`04023/1`3oool0oooo023/1`L0oooo00<08>`70?ooo`0Pk0L00`3oool0
0`0Pk0L0oooo0?ooo`0`0?ooo`030000003oool0oooo01`0oooo000K0?ooo`030000003oool0oooo
02H0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo023/1`0Pk0L20?ooo`07023/1`3oool0
oooo023/1`3oool08>`70?ooo`02023/1`D0oooo100Pk0L00`3oool08>`70?ooo`0:023/1`@0oooo
1P0Pk0L00`3oool08>`7023/1`04023/1`<0oooo0P0Pk0L00`3oool08>`7023/1`030?ooo`D08>`7
0P3oool2023/1`050?ooo`0Pk0L08>`7023/1`3oool0200Pk0L00`3oool08>`7023/1`02023/1`80
oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?ooo`030000000Pk0L08>`700D0oooo0P0Pk0L00`3oool0
8>`70?ooo`020?ooo`03023/1`3oool0oooo00D0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0
oooo0?ooo`0`0?ooo`030000003oool0oooo01`0oooo000K0?ooo`030000003oool0oooo02H0oooo
00<08>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo023/1`02023/1`080?ooo`0Pk0L0oooo0?ooo`0P
k0L0oooo023/1`3oool2023/1`D0oooo100Pk0L00`3oool08>`70?ooo`0:023/1`@0oooo1P0Pk0L0
0`3oool08>`7023/1`04023/1`<0oooo0P0Pk0L00`3oool08>`7023/1`030?ooo`D08>`70P3oool2
023/1`050?ooo`0Pk0L08>`7023/1`3oool0200Pk0L00`3oool08>`7023/1`02023/1`040?ooo`0P
k0L0oooo0?ooo`@08>`70P3oool00`0000008>`7023/1`050?ooo`808>`700<0oooo023/1`3oool0
0P3oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool0
<03oool00`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo0?ooo`0V0?ooo`03023/1`3o
ool08>`700@0oooo00<08>`70?ooo`0Pk0L00P0Pk0L0203oool08>`70?ooo`3oool08>`70?ooo`0P
k0L0oooo0P0Pk0L50?ooo`@08>`700<0oooo023/1`3oool02P0Pk0L40?ooo`H08>`700<0oooo023/
1`0Pk0L0100Pk0L30?ooo`808>`700<0oooo023/1`0Pk0L00`3oool5023/1`80oooo0P0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00P08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`05
023/1`80oooo00<00000023/1`0Pk0L01@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`7
0?ooo`3oool0103oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`03023/1`3oool0oooo0300oooo00<0
00000?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool09`3oool2023/1`@0oooo00<08>`7
0?ooo`0Pk0L00P0Pk0L0203oool08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L50?ooo`@0
8>`700<0oooo023/1`3oool02P0Pk0L40?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`80
8>`700<0oooo023/1`0Pk0L00`3oool5023/1`80oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00X08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool5023/1`80oooo00<00000023/1`0Pk0L01@3o
ool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?oo
o`0Pk0L30?ooo`03023/1`3oool0oooo0300oooo00<000000?ooo`3oool0703oool001/0oooo00<0
00000?ooo`3oool09`3oool2023/1`@0oooo00<08>`70?ooo`0Pk0L00P0Pk0L0203oool08>`70?oo
o`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L50?ooo`@08>`700<0oooo023/1`3oool02P0Pk0L40?oo
o`H08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`808>`700<0oooo023/1`0Pk0L00`3oool5023/
1`80oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00X08>`700H0oooo023/1`0Pk0L0oooo023/
1`3oool5023/1`80oooo00<000000?ooo`0Pk0L01@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo
00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`03023/1`3oool0oooo0300
oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool09`3oool2023/1`@0oooo
00<08>`70?ooo`0Pk0L00P0Pk0L0203oool08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L5
0?ooo`@08>`700<0oooo023/1`3oool02P0Pk0L40?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L3
0?ooo`808>`700<0oooo023/1`0Pk0L00`3oool5023/1`80oooo0P0Pk0L01@3oool08>`7023/1`0P
k0L0oooo00X08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool5023/1`80oooo00<00000023/1`0P
k0L01@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0103oool0100Pk0L0
oooo0?ooo`0Pk0L30?ooo`03023/1`3oool0oooo0300oooo00<000000?ooo`3oool0703oool001/0
oooo00<000000?ooo`3oool09`3oool2023/1`@0oooo00<08>`70?ooo`0Pk0L00P0Pk0L0203oool0
8>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo0P0Pk0L50?ooo`@08>`700<0oooo023/1`3oool02P0P
k0L40?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`808>`700<0oooo023/1`0Pk0L00`3o
ool5023/1`80oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00X08>`700H0oooo023/1`0Pk0L0
oooo023/1`3oool5023/1`80oooo00<00000023/1`0Pk0L01@3oool2023/1`030?ooo`0Pk0L0oooo
0080oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`03023/1`3oool0
oooo0300oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool09`3oool2023/
1`@0oooo00<08>`70?ooo`0Pk0L00P0Pk0L0203oool08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo
0P0Pk0L50?ooo`@08>`700D0oooo023/1`3oool08>`70?ooo`08023/1`@0oooo1P0Pk0L00`3oool0
8>`7023/1`04023/1`<0oooo0P0Pk0L00`3oool08>`7023/1`030?ooo`D08>`70P3oool2023/1`05
0?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L00`3oool08>`7023/1`02023/1`060?ooo`0Pk0L08>`7
0?ooo`0Pk0L0oooo1@0Pk0L20?ooo`030000000Pk0L08>`700D0oooo0P0Pk0L00`3oool08>`70?oo
o`020?ooo`03023/1`3oool0oooo00@0oooo00@08>`70?ooo`3oool08>`70`3oool00`0Pk0L0oooo
0?ooo`0`0?ooo`030000003oool0oooo01`0oooo000K0?ooo`030000003oool0oooo02L0oooo0P0P
k0L40?ooo`03023/1`3oool08>`700808>`700P0oooo023/1`3oool0oooo023/1`3oool08>`70?oo
o`808>`71@3oool4023/1`050?ooo`0Pk0L0oooo023/1`3oool0200Pk0L40?ooo`H08>`700<0oooo
023/1`0Pk0L0100Pk0L30?ooo`808>`700<0oooo023/1`0Pk0L00`3oool5023/1`80oooo0P0Pk0L0
1@3oool08>`7023/1`0Pk0L0oooo00D08>`700<0oooo023/1`0Pk0L00P0Pk0L01P3oool08>`7023/
1`3oool08>`70?ooo`D08>`70P3oool00`0000008>`7023/1`050?ooo`808>`700<0oooo023/1`3o
ool00P3oool00`0Pk0L0oooo0?ooo`040?ooo`04023/1`3oool0oooo023/1`<0oooo00<08>`70?oo
o`3oool0<03oool00`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo0?ooo`0W0?ooo`80
8>`7103oool00`0Pk0L0oooo023/1`02023/1`080?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3o
ool2023/1`D0oooo100Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00P08>`7103oool6023/1`030?oo
o`0Pk0L08>`700@08>`70`3oool2023/1`030?ooo`0Pk0L08>`700<0oooo1@0Pk0L20?ooo`808>`7
00D0oooo023/1`0Pk0L08>`70?ooo`05023/1`030?ooo`0Pk0L08>`700808>`700H0oooo023/1`0P
k0L0oooo023/1`3oool5023/1`80oooo00<00000023/1`0Pk0L01@3oool2023/1`030?ooo`0Pk0L0
oooo0080oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`0Pk0L30?ooo`03023/1`3o
ool0oooo0300oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool09`3oool2
023/1`@0oooo00<08>`70?ooo`0Pk0L00P0Pk0L0203oool08>`70?ooo`3oool08>`70?ooo`0Pk0L0
oooo0P0Pk0L50?ooo`@08>`700D0oooo023/1`3oool08>`70?ooo`08023/1`@0oooo1P0Pk0L00`3o
ool08>`7023/1`04023/1`<0oooo0P0Pk0L00`3oool08>`7023/1`030?ooo`D08>`70P3oool2023/
1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L00`3oool08>`7023/1`02023/1`060?ooo`0Pk0L0
8>`70?ooo`0Pk0L0oooo1@0Pk0L20?ooo`030000000Pk0L08>`700D0oooo0P0Pk0L00`3oool08>`7
0?ooo`020?ooo`03023/1`3oool0oooo00@0oooo00@08>`70?ooo`3oool08>`70`3oool00`0Pk0L0
oooo0?ooo`0`0?ooo`030000003oool0oooo01`0oooo000K0?ooo`030000003oool0oooo02L0oooo
00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo023/1`02023/1`070?ooo`0Pk0L0oooo0?ooo`0P
k0L0oooo023/1`020?ooo`03023/1`3oool0oooo00<0oooo100Pk0L01@3oool08>`70?ooo`0Pk0L0
oooo00P08>`7103oool6023/1`030?ooo`0Pk0L08>`700@08>`70`3oool2023/1`030?ooo`0Pk0L0
8>`700<0oooo1@0Pk0L20?ooo`808>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`030?ooo`0P
k0L08>`700808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool5023/1`80oooo00<00000023/1`0P
k0L01@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0103oool0100Pk0L0
oooo0?ooo`0Pk0L30?ooo`03023/1`3oool0oooo0300oooo00<000000?ooo`3oool0703oool001/0
oooo00<000000?ooo`3oool09`3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool08>`70080
8>`700L0oooo023/1`3oool0oooo023/1`3oool08>`70080oooo00<08>`70?ooo`3oool00`3oool4
023/1`050?ooo`0Pk0L0oooo023/1`3oool0200Pk0L40?ooo`H08>`700<0oooo023/1`0Pk0L0100P
k0L30?ooo`808>`700<0oooo023/1`0Pk0L00`3oool5023/1`80oooo0P0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00D08>`700<0oooo023/1`0Pk0L00P0Pk0L01P3oool08>`7023/1`3oool08>`70?oo
o`D08>`70P3oool00`0000008>`7023/1`050?ooo`808>`700<0oooo023/1`3oool00P3oool00`0P
k0L0oooo0?ooo`040?ooo`04023/1`3oool0oooo023/1`<0oooo00<08>`70?ooo`3oool0<03oool0
0`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo0?ooo`0W0?ooo`03023/1`3oool08>`7
00<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L01`3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L00P3o
ool00`0Pk0L0oooo0?ooo`030?ooo`@08>`700D0oooo023/1`3oool08>`70?ooo`08023/1`@0oooo
1P0Pk0L00`3oool08>`7023/1`04023/1`<0oooo0P0Pk0L00`3oool08>`7023/1`030?ooo`D08>`7
0P3oool2023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`7
00808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool5023/1`80oooo00<00000023/1`0Pk0L01@3o
ool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo023/
1`040?ooo`03023/1`3oool0oooo0300oooo00<000000?ooo`3oool0703oool001/0oooo00<00000
0?ooo`3oool09`3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool08>`700808>`700L0oooo
023/1`3oool0oooo023/1`3oool08>`70080oooo00<08>`70?ooo`3oool00`3oool4023/1`050?oo
o`0Pk0L0oooo023/1`3oool0200Pk0L40?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`80
8>`700<0oooo023/1`0Pk0L00`3oool5023/1`80oooo0P0Pk0L01`3oool08>`7023/1`0Pk0L0oooo
023/1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo
100Pk0L30?ooo`030000000Pk0L08>`700D0oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`03023/
1`3oool0oooo00@0oooo00<08>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`0`0?ooo`030000
003oool0oooo01`0oooo000K0?ooo`030000003oool0oooo02L0oooo00<08>`70?ooo`0Pk0L00`3o
ool00`0Pk0L0oooo023/1`02023/1`070?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`020?ooo`03
023/1`3oool0oooo00<0oooo100Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00P08>`7103oool6023/
1`030?ooo`0Pk0L08>`700@08>`70`3oool2023/1`030?ooo`0Pk0L08>`700<0oooo1@0Pk0L20?oo
o`808>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00P0P
k0L01P3oool08>`7023/1`3oool08>`70?ooo`@08>`70`3oool00`0000008>`7023/1`050?ooo`80
8>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool08>`700@0
oooo00<08>`70?ooo`3oool0<03oool00`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo
0?ooo`0W0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L01`3oool08>`7
0?ooo`3oool08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`030?ooo`@08>`700D0oooo023/
1`3oool08>`70?ooo`08023/1`@0oooo1P0Pk0L00`3oool08>`7023/1`04023/1`<0oooo0P0Pk0L0
0`3oool08>`7023/1`030?ooo`D08>`70P3oool5023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L0
0`3oool08>`7023/1`02023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo100Pk0L30?ooo`030000
000Pk0L08>`700D0oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo00@0oooo
00<08>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`0`0?ooo`030000003oool0oooo01`0oooo
000K0?ooo`030000003oool0oooo02L0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo023/
1`02023/1`070?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo0080
oooo00<08>`70?ooo`0Pk0L00P0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00P08>`7103oool6023/
1`030?ooo`0Pk0L08>`700@08>`70`3oool2023/1`030?ooo`0Pk0L08>`700<0oooo1@0Pk0L20?oo
o`D08>`70P3oool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L08>`700808>`700H0oooo023/
1`0Pk0L0oooo023/1`3oool4023/1`<0oooo00<00000023/1`0Pk0L01@3oool2023/1`030?ooo`0P
k0L0oooo0080oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3o
ool0oooo0300oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool09`3oool0
0`0Pk0L0oooo023/1`030?ooo`03023/1`3oool08>`700808>`700L0oooo023/1`3oool0oooo023/
1`3oool08>`70080oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo023/1`02023/1`050?oo
o`0Pk0L0oooo023/1`3oool0200Pk0L40?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`<0
8>`700<0oooo023/1`0Pk0L00`3oool5023/1`80oooo1@0Pk0L20?ooo`03023/1`3oool08>`70080
8>`700<0oooo023/1`0Pk0L00P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`@08>`70`3oool0
0`0000008>`7023/1`050?ooo`808>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`04
0?ooo`03023/1`3oool08>`700@0oooo00<08>`70?ooo`3oool0<03oool00`000000oooo0?ooo`0L
0?ooo`006P3oool00`000000oooo0?ooo`0X0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?oo
o`0Pk0L00P0Pk0L01`3oool08>`70?ooo`3oool08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?oo
o`020?ooo`03023/1`3oool08>`700808>`700D0oooo023/1`3oool08>`70?ooo`08023/1`@0oooo
1P0Pk0L00`3oool08>`7023/1`04023/1`80oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`D08>`7
0P3oool5023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`050?oo
o`0Pk0L0oooo023/1`3oool0100Pk0L30?ooo`030000000Pk0L08>`700D0oooo0P0Pk0L00`3oool0
8>`70?ooo`020?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`0Pk0L0103oool00`0Pk0L0
oooo0?ooo`0`0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003oool0oooo02P0oooo
00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo023/1`02023/1`070?ooo`0Pk0L0oooo0?ooo`0P
k0L0oooo023/1`020?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`0Pk0L00P0Pk0L01@3o
ool08>`70?ooo`0Pk0L0oooo00P08>`7103oool6023/1`030?ooo`0Pk0L08>`700@08>`70P3oool3
023/1`030?ooo`0Pk0L08>`700<0oooo1@0Pk0L20?ooo`D08>`70P3oool00`0Pk0L0oooo023/1`02
023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`3oool08>`70?ooo`04023/1`<0oooo00<0
0000023/1`0Pk0L01@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0103o
ool00`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo0300oooo00<000000?ooo`3oool0703o
ool001X0oooo00<000000?ooo`3oool0:03oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0
8>`700808>`700L0oooo023/1`3oool0oooo023/1`3oool08>`70080oooo00<08>`70?ooo`3oool0
0P3oool00`0Pk0L0oooo023/1`02023/1`050?ooo`0Pk0L0oooo023/1`3oool0200Pk0L40?ooo`H0
8>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00`3oool5023/1`80
oooo1@0Pk0L20?ooo`03023/1`3oool08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool0
8>`70?ooo`0Pk0L0oooo00@08>`70`3oool00`0000008>`7023/1`050?ooo`808>`700<0oooo023/
1`3oool00P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool08>`700@0oooo00<08>`70?oo
o`3oool0<03oool00`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0X0?ooo`03
023/1`3oool08>`700@0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`03023/1`3oool0
8>`70080oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo023/1`02023/1`050?ooo`0Pk0L0
oooo023/1`3oool0200Pk0L40?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`<08>`700<0
oooo023/1`0Pk0L00`3oool2023/1`030?ooo`0Pk0L08>`70080oooo1@0Pk0L20?ooo`03023/1`3o
ool08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00@08>`7
0`3oool00`0000008>`7023/1`050?ooo`808>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo
0?ooo`030?ooo`04023/1`3oool0oooo023/1`@0oooo00<08>`70?ooo`3oool0<03oool00`000000
oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0X0?ooo`03023/1`3oool08>`700@0oooo
00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`03023/1`3oool08>`70080oooo00<08>`70?oo
o`3oool00P3oool00`0Pk0L0oooo023/1`02023/1`050?ooo`0Pk0L0oooo023/1`3oool0200Pk0L4
0?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00`3oool2
023/1`030?ooo`0Pk0L08>`70080oooo1@0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L00`0Pk0L0
1@3oool08>`70?ooo`0Pk0L0oooo00@08>`70`3oool00`0000008>`7023/1`050?ooo`04023/1`3o
ool0oooo023/1`<0oooo00<08>`70?ooo`3oool00`3oool0100Pk0L0oooo0?ooo`0Pk0L40?ooo`03
023/1`3oool0oooo0300oooo00<000000?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0
:03oool00`0Pk0L0oooo023/1`040?ooo`06023/1`3oool08>`7023/1`3oool08>`70P3oool00`0P
k0L0oooo023/1`020?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`0Pk0L00P0Pk0L01@3o
ool08>`70?ooo`0Pk0L0oooo00P08>`7103oool6023/1`030?ooo`0Pk0L08>`700@08>`70P3oool3
023/1`030?ooo`0Pk0L08>`700<0oooo0P0Pk0L00`3oool08>`7023/1`020?ooo`D08>`70P3oool5
023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`3oool08>`70?ooo`04023/1`<0oooo00<0
0000023/1`0Pk0L01@3oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00<0oooo00@0
8>`70?ooo`3oool08>`7103oool00`0Pk0L0oooo0?ooo`0`0?ooo`030000003oool0oooo01`0oooo
000J0?ooo`030000003oool0oooo02P0oooo00<08>`70?ooo`0Pk0L0103oool01P0Pk0L0oooo023/
1`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`020?ooo`03
023/1`3oool08>`700808>`700D0oooo023/1`3oool08>`70?ooo`08023/1`@0oooo1P0Pk0L00`3o
ool08>`7023/1`04023/1`80oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`808>`700<0oooo023/
1`0Pk0L00P3oool5023/1`80oooo1@0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L0oooo
023/1`3oool0100Pk0L30?ooo`030000000Pk0L08>`700D0oooo00<08>`70?ooo`0Pk0L0103oool0
0`0Pk0L0oooo0?ooo`030?ooo`04023/1`3oool0oooo023/1`@0oooo00<08>`70?ooo`3oool0<03o
ool00`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0X0?ooo`03023/1`3oool0
8>`700@0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`808>`700@0oooo023/1`3oool0
8>`7103oool00`0Pk0L0oooo023/1`02023/1`050?ooo`0Pk0L0oooo023/1`3oool0200Pk0L40?oo
o`H08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00`3oool2023/
1`030?ooo`0Pk0L08>`70080oooo1@0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L0100Pk0L20?oo
o`03023/1`3oool08>`700<08>`70`3oool00`0000008>`7023/1`040?ooo`808>`700<0oooo023/
1`3oool00`3oool00`0Pk0L0oooo0?ooo`030?ooo`04023/1`3oool0oooo023/1`<0oooo00<08>`7
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0X0?oo
o`03023/1`3oool08>`700@0oooo00@08>`70?ooo`0Pk0L08>`70P3oool0200Pk0L0oooo023/1`0P
k0L0oooo023/1`3oool08>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`050?ooo`0Pk0L0oooo023/
1`3oool0200Pk0L40?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`<08>`700<0oooo023/
1`0Pk0L00`3oool2023/1`030?ooo`0Pk0L08>`70080oooo1@0Pk0L20?ooo`D08>`700<0oooo023/
1`0Pk0L0100Pk0L20?ooo`03023/1`3oool08>`700<08>`70`3oool00`0000008>`7023/1`040?oo
o`808>`700<0oooo023/1`3oool00`3oool00`0Pk0L0oooo0?ooo`030?ooo`04023/1`3oool0oooo
023/1`<0oooo00<08>`70?ooo`3oool0<@3oool00`000000oooo0?ooo`0L0?ooo`006P3oool00`00
0000oooo0?ooo`0X0?ooo`03023/1`3oool08>`700@0oooo00@08>`70?ooo`0Pk0L08>`70P3oool0
200Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`05
0?ooo`0Pk0L0oooo023/1`3oool0200Pk0L40?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L20?oo
o`<08>`700<0oooo023/1`0Pk0L00`3oool2023/1`030?ooo`0Pk0L08>`70080oooo1@0Pk0L20?oo
o`D08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`03023/1`3oool08>`700<08>`70`3oool00`00
00008>`7023/1`040?ooo`808>`700<0oooo023/1`3oool00`3oool00`0Pk0L0oooo0?ooo`030?oo
o`04023/1`3oool0oooo023/1`<0oooo00<08>`70?ooo`3oool0<@3oool00`000000oooo0?ooo`0L
0?ooo`006P3oool00`000000oooo0?ooo`0X0?ooo`03023/1`3oool08>`700@0oooo00@08>`70?oo
o`0Pk0L08>`70P3oool0200Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`70`3oool00`0Pk0L0
oooo0?ooo`03023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`02023/
1`@0oooo1P0Pk0L00`3oool08>`7023/1`04023/1`80oooo0`0Pk0L00`3oool08>`7023/1`030?oo
o`808>`700<0oooo023/1`0Pk0L00P3oool5023/1`80oooo1@0Pk0L00`3oool08>`7023/1`04023/
1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L30?ooo`030000000Pk0L08>`700@0oooo0P0Pk0L00`3o
ool08>`70?ooo`030?ooo`03023/1`3oool0oooo00<0oooo00@08>`70?ooo`3oool08>`70`3oool0
0`0Pk0L0oooo0?ooo`0a0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003oool0oooo
02P0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo023/1`0Pk0L20?ooo`08023/1`3oool0
oooo023/1`3oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool0oooo00<08>`700D0oooo023/1`3o
ool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`7103oool6023/1`030?ooo`0Pk0L08>`7
00@08>`70P3oool3023/1`030?ooo`0Pk0L08>`700<0oooo1@0Pk0L20?ooo`D08>`70P3oool5023/
1`030?ooo`0Pk0L08>`700@08>`70P3oool00`0Pk0L0oooo023/1`03023/1`<0oooo00<00000023/
1`0Pk0L0103oool2023/1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool00`3oool0100P
k0L0oooo0?ooo`0Pk0L30?ooo`03023/1`3oool0oooo0340oooo00<000000?ooo`3oool0703oool0
01X0oooo00<000000?ooo`3oool0:03oool00`0Pk0L0oooo023/1`040?ooo`04023/1`3oool08>`7
023/1`80oooo00P08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo023/1`<0oooo00<08>`70?ooo`3o
ool00`0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00P0Pk0L40?oo
o`H08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00`3oool5023/
1`80oooo1@0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`03023/1`3oool08>`7
00<08>`70`3oool00`0000008>`7023/1`040?ooo`808>`700<0oooo023/1`3oool00P3oool00`0P
k0L0oooo0?ooo`040?ooo`04023/1`3oool0oooo023/1`<0oooo00<08>`70?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0X0?ooo`03023/1`3oool08>`7
00@0oooo00@08>`70?ooo`0Pk0L08>`70P3oool0200Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool0
8>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L00`3o
ool08>`7023/1`02023/1`@0oooo1P0Pk0L00`3oool08>`7023/1`04023/1`80oooo0`0Pk0L00`3o
ool08>`7023/1`030?ooo`D08>`70P3oool5023/1`80oooo1@0Pk0L00`3oool08>`7023/1`04023/
1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?ooo`04023/1`0000008>`7023/1`@0oooo0P0Pk0L0
0`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo00@0oooo00@08>`70?ooo`3oool08>`70`3o
ool00`0Pk0L0oooo0?ooo`0a0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003oool0
oooo02P0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo023/1`0Pk0L20?ooo`08023/1`3o
ool0oooo023/1`3oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool0oooo00<08>`700D0oooo023/
1`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`7103oool6023/1`030?ooo`0Pk0L0
8>`700@08>`70P3oool3023/1`030?ooo`0Pk0L08>`700<0oooo1@0Pk0L20?ooo`D08>`700<0oooo
023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`04023/1`80oooo1P0Pk0L20?ooo`04023/1`000000
8>`7023/1`@0oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo00@0oooo00<0
8>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`0a0?ooo`030000003oool0oooo01`0oooo000J
0?ooo`030000003oool0oooo02P0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo023/1`0P
k0L20?ooo`08023/1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool0oooo
00<08>`700D0oooo023/1`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`7103oool6
023/1`030?ooo`0Pk0L08>`700@08>`70P3oool3023/1`030?ooo`0Pk0L08>`700<0oooo1@0Pk0L2
0?ooo`D08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L0
oooo00D08>`70P3oool0100Pk0L00000023/1`0Pk0L40?ooo`808>`700<0oooo023/1`3oool00P3o
ool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool08>`700@0oooo00<08>`70?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0X0?ooo`03023/1`3oool0
8>`700@0oooo00@08>`70?ooo`0Pk0L08>`70P3oool0200Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3o
ool08>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L0
0`3oool08>`7023/1`02023/1`@0oooo1P0Pk0L00`3oool08>`7023/1`04023/1`80oooo0`0Pk0L0
0`3oool08>`7023/1`030?ooo`D08>`70P3oool5023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo
023/1`3oool01@0Pk0L20?ooo`04023/1`0000008>`7023/1`@0oooo0P0Pk0L00`3oool08>`70?oo
o`020?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?oo
o`0a0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003oool0oooo02P0oooo00<08>`7
0?ooo`0Pk0L0103oool0100Pk0L0oooo023/1`0Pk0L20?ooo`08023/1`3oool0oooo023/1`3oool0
8>`70?ooo`0Pk0L30?ooo`03023/1`3oool0oooo00<08>`700D0oooo023/1`3oool08>`70?ooo`03
023/1`030?ooo`0Pk0L08>`700808>`7103oool6023/1`030?ooo`0Pk0L08>`700@08>`70P3oool3
023/1`030?ooo`0Pk0L08>`700<0oooo1@0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L02`0Pk0L0
0`3oool08>`70?ooo`05023/1`80oooo00@08>`70000000Pk0L08>`7103oool2023/1`030?ooo`0P
k0L0oooo0080oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3o
ool0oooo0340oooo00<000000?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0:03oool0
0`0Pk0L0oooo023/1`040?ooo`04023/1`3oool08>`7023/1`80oooo00P08>`70?ooo`3oool08>`7
0?ooo`0Pk0L0oooo023/1`<0oooo00<08>`70?ooo`3oool00`0Pk0L01@3oool08>`70?ooo`0Pk0L0
oooo00<08>`700<0oooo023/1`0Pk0L00P0Pk0L40?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L2
0?ooo`<08>`700<0oooo023/1`0Pk0L00`3oool5023/1`80oooo1@0Pk0L00`3oool08>`7023/1`0;
023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool0100Pk0L00000023/1`0Pk0L40?ooo`808>`700<0
oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool08>`700@0oooo00<0
8>`70?ooo`3oool0<@3oool00`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0X
0?ooo`03023/1`3oool08>`700@0oooo00@08>`70?ooo`0Pk0L08>`70P3oool0200Pk0L0oooo0?oo
o`0Pk0L0oooo023/1`3oool08>`70P3oool0100Pk0L0oooo0?ooo`3oool3023/1`050?ooo`0Pk0L0
oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`@0oooo1P0Pk0L00`3oool08>`7023/
1`04023/1`80oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`D08>`70P3oool5023/1`030?ooo`0P
k0L08>`700/08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`04023/1`0000008>`7023/1`@0oooo
0P0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`0Pk0L0
103oool00`0Pk0L0oooo0?ooo`0a0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003o
ool0oooo02P0oooo00<08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo023/1`0Pk0L20?ooo`08023/
1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L20?ooo`04023/1`3oool0oooo0?ooo`<08>`700D0
oooo023/1`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`7103oool6023/1`030?oo
o`0Pk0L08>`700@08>`70P3oool3023/1`030?ooo`0Pk0L08>`700<0oooo1@0Pk0L20?ooo`D08>`7
00<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`70?ooo`05023/1`80oooo00@08>`70000000Pk0L0
8>`7103oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0
oooo023/1`040?ooo`03023/1`3oool0oooo0340oooo00<000000?ooo`3oool0703oool001X0oooo
00<000000?ooo`3oool0:03oool00`0Pk0L0oooo023/1`040?ooo`04023/1`3oool08>`7023/1`80
oooo00L08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo00808>`700<0oooo023/1`3oool00P3oool3
023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`@0oooo1P0P
k0L00`3oool08>`7023/1`04023/1`80oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`D08>`70P3o
ool5023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`70?oo
o`05023/1`80oooo00<08>`70000000Pk0L01@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<0
8>`70?ooo`3oool0103oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo0340oooo00<0
00000?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0:03oool00`0Pk0L0oooo023/1`04
0?ooo`04023/1`3oool08>`7023/1`80oooo00L08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo0080
8>`700<0oooo023/1`3oool00P3oool3023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L00`3o
ool08>`7023/1`02023/1`@0oooo1P0Pk0L00`3oool08>`7023/1`04023/1`80oooo0`0Pk0L00`3o
ool08>`7023/1`030?ooo`D08>`70P3oool5023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/
1`0Pk0L01P0Pk0L00`3oool08>`70?ooo`05023/1`80oooo00<08>`70000000Pk0L01@3oool2023/
1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo023/1`040?oo
o`03023/1`3oool0oooo0340oooo00<000000?ooo`3oool0703oool001X0oooo00<000000?ooo`3o
ool0:03oool00`0Pk0L0oooo023/1`040?ooo`04023/1`3oool08>`7023/1`80oooo00L08>`70?oo
o`3oool08>`70?ooo`0Pk0L0oooo00808>`700<0oooo023/1`3oool00P3oool3023/1`050?ooo`0P
k0L0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`@0oooo1P0Pk0L00`3oool08>`7
023/1`04023/1`80oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`D08>`70P3oool5023/1`030?oo
o`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`70?ooo`05023/1`80oooo
00<08>`70000000Pk0L01@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0
103oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo0340oooo00<000000?ooo`3oool0
703oool001X0oooo00<000000?ooo`3oool0:03oool00`0Pk0L0oooo023/1`040?ooo`04023/1`3o
ool08>`7023/1`80oooo00L08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo00808>`700<0oooo023/
1`3oool00P3oool3023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`02
023/1`@0oooo1P0Pk0L00`3oool08>`7023/1`04023/1`80oooo0`0Pk0L00`3oool08>`7023/1`03
0?ooo`D08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0
8>`700H08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`03023/1`0000008>`700D0oooo0P0Pk0L0
0`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo00<0oooo00@08>`70?ooo`3oool08>`7103o
ool00`0Pk0L0oooo0?ooo`0a0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003oool0
oooo02T0oooo0P0Pk0L40?ooo`04023/1`3oool08>`7023/1`80oooo00L08>`70?ooo`3oool08>`7
0?ooo`0Pk0L0oooo00808>`700<0oooo023/1`3oool00P3oool3023/1`050?ooo`0Pk0L0oooo023/
1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`@0oooo1P0Pk0L00`3oool08>`7023/1`04023/
1`80oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`D08>`700<0oooo023/1`0Pk0L0100Pk0L00`3o
ool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`3oool0100Pk0L30?oo
o`03023/1`0000008>`700D0oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo
00<0oooo00@08>`70?ooo`3oool08>`7103oool00`0Pk0L0oooo0?ooo`0a0?ooo`030000003oool0
oooo01`0oooo000J0?ooo`030000003oool0oooo02T0oooo0P0Pk0L40?ooo`04023/1`3oool08>`7
023/1`80oooo00L08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo00808>`700<0oooo023/1`3oool0
0P3oool3023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`@0
oooo1P0Pk0L00`3oool08>`7023/1`04023/1`80oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`D0
8>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/
1`3oool0100Pk0L00`3oool08>`70?ooo`04023/1`<0oooo00<08>`70000000Pk0L01@3oool2023/
1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool00`3oool0100Pk0L0oooo0?ooo`0Pk0L4
0?ooo`03023/1`3oool0oooo0340oooo00<000000?ooo`3oool0703oool001X0oooo00<000000?oo
o`3oool0:@3oool2023/1`@0oooo00@08>`70?ooo`0Pk0L08>`70P3oool01`0Pk0L0oooo0?ooo`0P
k0L0oooo023/1`3oool00P0Pk0L00`3oool08>`70?ooo`020?ooo`<08>`700D0oooo023/1`3oool0
8>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`7103oool6023/1`030?ooo`0Pk0L08>`700@0
8>`70P3oool3023/1`030?ooo`0Pk0L08>`700<0oooo1@0Pk0L00`3oool08>`7023/1`04023/1`03
0?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`030?ooo`0Pk0L0oooo
00@08>`70`3oool00`0Pk0L00000023/1`050?ooo`808>`700<0oooo023/1`3oool00P3oool00`0P
k0L0oooo0?ooo`030?ooo`04023/1`3oool0oooo023/1`@0oooo00<08>`70?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0Y0?ooo`808>`7103oool0100P
k0L0oooo023/1`0Pk0L20?ooo`07023/1`3oool0oooo023/1`3oool08>`70?ooo`02023/1`030?oo
o`0Pk0L0oooo0080oooo0`0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0P
k0L00P0Pk0L40?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`<08>`700<0oooo023/1`0P
k0L00P3oool6023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool0
8>`7023/1`0Pk0L0oooo00@08>`700<0oooo023/1`3oool0100Pk0L30?ooo`03023/1`0000008>`7
00D0oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo00<0oooo00@08>`70?oo
o`3oool08>`7103oool00`0Pk0L0oooo0?ooo`0a0?ooo`030000003oool0oooo01`0oooo000J0?oo
o`030000003oool0oooo02T0oooo0P0Pk0L40?ooo`04023/1`3oool0oooo023/1`80oooo00L08>`7
0?ooo`3oool08>`70?ooo`0Pk0L0oooo00<08>`7103oool3023/1`050?ooo`0Pk0L0oooo023/1`3o
ool00`0Pk0L00`3oool08>`7023/1`02023/1`@0oooo1P0Pk0L00`3oool08>`7023/1`04023/1`80
oooo0`0Pk0L00`3oool08>`7023/1`020?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool0
8>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`70?ooo`04023/
1`<0oooo00<08>`70000000Pk0L01@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?oo
o`3oool00`3oool0100Pk0L0oooo0?ooo`0Pk0L40?ooo`03023/1`3oool0oooo0340oooo00<00000
0?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0:@3oool2023/1`@0oooo00@08>`70?oo
o`3oool08>`70P3oool01`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L40?ooo`<08>`7
00D0oooo023/1`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`7103oool7023/1`03
0?ooo`0Pk0L08>`700<08>`70P3oool3023/1`030?ooo`0Pk0L08>`70080oooo1P0Pk0L00`3oool0
8>`7023/1`04023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/
1`030?ooo`0Pk0L0oooo00@08>`70`3oool00`0Pk0L00000023/1`050?ooo`<08>`7103oool00`0P
k0L0oooo0?ooo`030?ooo`04023/1`3oool0oooo023/1`@0oooo00<08>`70?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0Y0?ooo`808>`7103oool0100P
k0L0oooo0?ooo`0Pk0L20?ooo`07023/1`3oool0oooo023/1`3oool08>`70?ooo`03023/1`@0oooo
0`0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00`0Pk0L30?ooo`L0
8>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00P3oool6023/1`03
0?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00@08>`700<0oooo023/1`3oool0100Pk0L30?ooo`03023/1`0000008>`700D0oooo0`0Pk0L40?oo
o`03023/1`3oool0oooo00<0oooo00@08>`70?ooo`3oool08>`7103oool00`0Pk0L0oooo0?ooo`0a
0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003oool0oooo02T0oooo0P0Pk0L40?oo
o`04023/1`3oool0oooo023/1`80oooo00L08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo00<08>`7
103oool3023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`03023/1`<0
oooo1`0Pk0L00`3oool08>`7023/1`03023/1`80oooo0`0Pk0L00`3oool08>`7023/1`020?ooo`H0
8>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/
1`3oool0100Pk0L00`3oool08>`70?ooo`04023/1`<0oooo00<08>`70000000Pk0L01@3oool3023/
1`@0oooo00<08>`70?ooo`3oool00`3oool0100Pk0L0oooo0?ooo`0Pk0L40?ooo`03023/1`3oool0
oooo0340oooo00<000000?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0:@3oool00`0P
k0L0oooo023/1`030?ooo`03023/1`3oool0oooo00808>`700P0oooo023/1`3oool0oooo023/1`3o
ool08>`70?ooo`<08>`7103oool3023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L00`3oool0
8>`7023/1`03023/1`<0oooo1`0Pk0L00`3oool08>`7023/1`03023/1`80oooo0`0Pk0L00`3oool0
8>`7023/1`020?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`02023/1`05
0?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`70?ooo`04023/1`<0oooo00<08>`70000
000Pk0L01@3oool3023/1`@0oooo00<08>`70?ooo`3oool00`3oool0100Pk0L0oooo0?ooo`0Pk0L4
0?ooo`03023/1`3oool0oooo0340oooo00<000000?ooo`3oool0703oool001X0oooo00<000000?oo
o`3oool0:@3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo00808>`700P0oooo023/
1`3oool0oooo023/1`3oool08>`70?ooo`<08>`7103oool3023/1`050?ooo`0Pk0L0oooo023/1`3o
ool00`0Pk0L00`3oool08>`7023/1`03023/1`<0oooo1`0Pk0L00`3oool08>`7023/1`03023/1`80
oooo0`0Pk0L00`3oool08>`7023/1`020?ooo`H08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool0
8>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`70?ooo`04023/
1`<0oooo00<08>`70000000Pk0L01@3oool3023/1`@0oooo00<08>`70?ooo`3oool00`3oool0100P
k0L0oooo0?ooo`0Pk0L30?ooo`03023/1`3oool0oooo0380oooo00<000000?ooo`3oool0703oool0
01X0oooo00<000000?ooo`3oool0:@3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo
00808>`700P0oooo023/1`3oool0oooo023/1`3oool08>`70?ooo`<08>`7103oool3023/1`030?oo
o`0Pk0L0oooo00D08>`700<0oooo023/1`0Pk0L00`0Pk0L30?ooo`L08>`700<0oooo023/1`0Pk0L0
0`0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00P3oool6023/1`030?ooo`0Pk0L08>`700@08>`7
00<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700D0oooo023/1`3o
ool08>`70?ooo`04023/1`<0oooo00<08>`70000000Pk0L01@3oool3023/1`@0oooo00<08>`70?oo
o`3oool00`3oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo0380oooo00<000000?oo
o`3oool0703oool001X0oooo00<000000?ooo`3oool0:@3oool00`0Pk0L0oooo023/1`030?ooo`03
023/1`3oool0oooo00808>`700P0oooo023/1`3oool0oooo023/1`3oool08>`70?ooo`<08>`7103o
ool3023/1`030?ooo`0Pk0L0oooo00D08>`700<0oooo023/1`0Pk0L00`0Pk0L30?ooo`L08>`700<0
oooo023/1`0Pk0L00`0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00P3oool6023/1`030?ooo`0P
k0L08>`700@08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`7
00D0oooo023/1`3oool08>`70?ooo`04023/1`<0oooo00<08>`70000000Pk0L01@3oool3023/1`@0
oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo0380
oooo00<000000?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0:@3oool00`0Pk0L0oooo
023/1`030?ooo`03023/1`3oool0oooo00808>`700@0oooo023/1`3oool0oooo0`0Pk0L0103oool0
8>`7023/1`0Pk0L40?ooo`<08>`700<0oooo023/1`3oool01@0Pk0L00`3oool08>`7023/1`03023/
1`<0oooo1`0Pk0L00`3oool08>`7023/1`03023/1`80oooo0`0Pk0L00`3oool08>`7023/1`020?oo
o`H08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7
023/1`3oool00P0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00@08>`70`3oool00`0Pk0L00000023/
1`050?ooo`<08>`7103oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool08>`700@0oooo00<0
8>`70?ooo`3oool0<P3oool00`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0Y
0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool00P0Pk0L00`3oool08>`70?ooo`02
0?ooo`808>`700@0oooo023/1`0Pk0L08>`7103oool3023/1`030?ooo`0Pk0L0oooo00D08>`700<0
oooo023/1`0Pk0L00`0Pk0L30?ooo`L08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`<08>`700<0
oooo023/1`0Pk0L00P3oool6023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L00P0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700D0oooo023/1`3oool08>`70?ooo`04023/1`<0
oooo00<08>`70000000Pk0L01@3oool3023/1`@0oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0
oooo023/1`040?ooo`03023/1`3oool0oooo0380oooo00<000000?ooo`3oool0703oool001X0oooo
00<000000?ooo`3oool0:@3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo00808>`7
00<0oooo023/1`3oool00P3oool00`0Pk0L0oooo023/1`03023/1`@0oooo0`0Pk0L00`3oool08>`7
0?ooo`05023/1`030?ooo`0Pk0L08>`700<08>`70`3oool7023/1`030?ooo`0Pk0L08>`700<08>`7
0P3oool3023/1`030?ooo`0Pk0L08>`70080oooo1P0Pk0L00`3oool08>`7023/1`04023/1`030?oo
o`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`050?ooo`0Pk0L0oooo023/
1`3oool0100Pk0L30?ooo`03023/1`0000008>`700D0oooo0`0Pk0L40?ooo`03023/1`3oool0oooo
00<0oooo00<08>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`0b0?ooo`030000003oool0oooo
01`0oooo000J0?ooo`030000003oool0oooo02T0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0
oooo0?ooo`02023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`0Pk0L00P0Pk0L50?ooo`<0
8>`700<0oooo023/1`3oool01@0Pk0L00`3oool08>`7023/1`03023/1`<0oooo1`0Pk0L00`3oool0
8>`7023/1`03023/1`80oooo0`0Pk0L00`3oool08>`7023/1`020?ooo`H08>`700<0oooo023/1`0P
k0L0100Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L01@3o
ool08>`70?ooo`0Pk0L0oooo00@08>`70`3oool00`0Pk0L00000023/1`050?ooo`<08>`7103oool0
0`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool08>`700@0oooo00<08>`70?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0Y0?ooo`03023/1`3oool08>`7
00<0oooo00<08>`70?ooo`3oool00P0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool08>`7
00808>`71@3oool3023/1`030?ooo`0Pk0L0oooo00D08>`700<0oooo023/1`0Pk0L00`0Pk0L30?oo
o`L08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`<08>`700H0oooo023/1`0Pk0L0oooo023/1`3o
ool5023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00<08>`70P3oool00`0Pk0L0oooo023/1`03023/1`<0oooo00<08>`70000000Pk0L0
1@3oool3023/1`@0oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo023/1`040?ooo`03023/
1`3oool0oooo0380oooo00<000000?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0:@3o
ool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo00808>`700<0oooo023/1`3oool00P3o
ool00`0Pk0L0oooo023/1`02023/1`D0oooo0`0Pk0L00`3oool08>`70?ooo`05023/1`030?ooo`0P
k0L08>`700<08>`70`3oool7023/1`030?ooo`0Pk0L08>`700<08>`70P3oool3023/1`060?ooo`0P
k0L08>`70?ooo`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`70080
8>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?oo
o`808>`700<00000023/1`3oool0103oool3023/1`@0oooo00<08>`70?ooo`3oool00`3oool00`0P
k0L0oooo023/1`040?ooo`03023/1`3oool0oooo0380oooo00<000000?ooo`3oool0703oool001X0
oooo00<000000?ooo`3oool0:@3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo0080
8>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo023/1`02023/1`D0oooo0`0Pk0L00`3oool0
8>`70?ooo`05023/1`030?ooo`0Pk0L08>`700<08>`70`3oool7023/1`030?ooo`0Pk0L08>`700<0
8>`70P3oool3023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`04
023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo00<0
8>`70?ooo`0Pk0L00`0Pk0L20?ooo`808>`700<00000023/1`3oool0103oool3023/1`@0oooo00<0
8>`70?ooo`3oool00`3oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo0380oooo00<0
00000?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0:@3oool00`0Pk0L0oooo023/1`03
0?ooo`03023/1`3oool0oooo00808>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo023/1`02
023/1`D0oooo0`0Pk0L00`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L08>`700<08>`70`3oool7
023/1`030?ooo`0Pk0L08>`700<08>`70P3oool3023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo
1@0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L0
8>`70?ooo`03023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L20?ooo`808>`700<00000023/1`3o
ool0103oool3023/1`@0oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo023/1`040?ooo`03
023/1`3oool0oooo0380oooo00<000000?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0
:@3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo00808>`700<0oooo023/1`3oool0
0P3oool00`0Pk0L0oooo023/1`02023/1`D0oooo0`0Pk0L00`3oool08>`70?ooo`05023/1`030?oo
o`0Pk0L08>`700<08>`70`3oool7023/1`030?ooo`0Pk0L08>`700<08>`70P3oool3023/1`060?oo
o`0Pk0L08>`70?ooo`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`03023/1`80oooo100Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00<08>`70P3oool6023/1`80oooo0P0Pk0L00`0000008>`70?ooo`04
0?ooo`03023/1`3oool08>`700@0oooo00<08>`70?ooo`3oool00P3oool0100Pk0L0oooo0?ooo`0P
k0L40?ooo`03023/1`3oool0oooo0380oooo00<000000?ooo`3oool0703oool001X0oooo00<00000
0?ooo`3oool0:@3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo00808>`700<0oooo
023/1`3oool00P3oool00`0Pk0L0oooo023/1`02023/1`D0oooo0`0Pk0L00`3oool08>`70?ooo`05
023/1`030?ooo`0Pk0L08>`700<08>`70`3oool7023/1`030?ooo`0Pk0L08>`700<08>`70P3oool3
023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`@08>`700D0
oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo1P0Pk0L20?ooo`808>`700<00000023/1`3oool0
103oool00`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo0080oooo00@08>`70?ooo`3oool0
8>`7103oool00`0Pk0L0oooo0?ooo`0b0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000
003oool0oooo02T0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`02023/1`030?oo
o`0Pk0L0oooo0080oooo00<08>`70?ooo`0Pk0L00P0Pk0L50?ooo`<08>`700@0oooo023/1`3oool0
oooo100Pk0L00`3oool08>`7023/1`03023/1`<0oooo1`0Pk0L00`3oool08>`7023/1`03023/1`80
oooo0`0Pk0L0103oool08>`7023/1`3oool7023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4023/
1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`H08>`70P3oool2023/1`030000000Pk0L0
oooo00@0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`030?ooo`04023/1`3oool0
oooo023/1`@0oooo00<08>`70?ooo`3oool0<P3oool00`000000oooo0?ooo`0L0?ooo`006P3oool0
0`000000oooo0?ooo`0Y0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool00P0Pk0L0
0`3oool08>`70?ooo`020?ooo`03023/1`3oool08>`700808>`71@3oool3023/1`040?ooo`0Pk0L0
oooo0?ooo`@08>`700<0oooo023/1`0Pk0L00`0Pk0L30?ooo`L08>`700<0oooo023/1`0Pk0L00`0P
k0L20?ooo`<08>`700@0oooo023/1`0Pk0L0oooo1`0Pk0L00`3oool08>`7023/1`03023/1`80oooo
100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`80
8>`700<00000023/1`3oool00`3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3o
ool00`3oool0100Pk0L0oooo0?ooo`0Pk0L40?ooo`03023/1`3oool0oooo0380oooo00<000000?oo
o`3oool0703oool001X0oooo00<000000?ooo`3oool0:@3oool00`0Pk0L0oooo023/1`030?ooo`03
023/1`3oool0oooo00808>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo023/1`02023/1`D0
oooo0`0Pk0L0103oool08>`70?ooo`3oool4023/1`030?ooo`0Pk0L08>`700<08>`70`3oool7023/
1`030?ooo`0Pk0L08>`700<08>`70P3oool3023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700<0oooo
023/1`3oool00`0Pk0L20?ooo`@08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`030?ooo`0P
k0L0oooo00D08>`70P3oool2023/1`030000000Pk0L0oooo00<0oooo0P0Pk0L00`3oool08>`70?oo
o`020?ooo`03023/1`3oool0oooo00<0oooo00@08>`70?ooo`3oool08>`7103oool00`0Pk0L0oooo
0?ooo`0b0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003oool0oooo02T0oooo00<0
8>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`02023/1`030?ooo`0Pk0L0oooo0080oooo00<0
8>`70?ooo`0Pk0L00P0Pk0L50?ooo`<08>`700@0oooo023/1`3oool0oooo2P0Pk0L30?ooo`L08>`7
00<0oooo023/1`0Pk0L00`0Pk0L20?ooo`<08>`700@0oooo023/1`0Pk0L0oooo1`0Pk0L00`3oool0
8>`70?ooo`03023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`700<0oooo023/
1`3oool01@0Pk0L20?ooo`808>`700<00000023/1`3oool00`3oool2023/1`030?ooo`0Pk0L0oooo
0080oooo00<08>`70?ooo`3oool00`3oool0100Pk0L0oooo0?ooo`0Pk0L40?ooo`03023/1`3oool0
oooo0380oooo00<000000?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0:@3oool00`0P
k0L0oooo023/1`040?ooo`06023/1`3oool08>`7023/1`3oool08>`70`3oool00`0Pk0L0oooo023/
1`02023/1`D0oooo0`0Pk0L0103oool08>`70?ooo`3oool:023/1`<0oooo1`0Pk0L00`3oool08>`7
023/1`03023/1`80oooo0`0Pk0L0103oool08>`7023/1`3oool7023/1`030?ooo`0Pk0L0oooo00<0
8>`70P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`70?ooo`05023/
1`80oooo0P0Pk0L00`0000008>`70?ooo`030?ooo`808>`700<0oooo023/1`3oool00P3oool00`0P
k0L0oooo0?ooo`030?ooo`04023/1`3oool0oooo023/1`@0oooo00<08>`70?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0Y0?ooo`03023/1`3oool08>`7
00@0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`700808>`71@3o
ool3023/1`040?ooo`0Pk0L0oooo0?ooo`X08>`70`3oool7023/1`030?ooo`0Pk0L08>`700<08>`7
0P3oool3023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700<0oooo023/1`3oool00`0Pk0L20?ooo`@0
8>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`05023/1`80oooo0P0Pk0L00`000000
8>`70?ooo`030?ooo`808>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`030?ooo`04
023/1`3oool0oooo023/1`@0oooo00<08>`70?ooo`3oool0<P3oool00`000000oooo0?ooo`0L0?oo
o`006P3oool00`000000oooo0?ooo`0Y0?ooo`03023/1`3oool08>`700@0oooo00H08>`70?ooo`0P
k0L08>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`700<08>`7103oool3023/1`040?ooo`0Pk0L0
oooo0?ooo`X08>`70`3oool7023/1`030?ooo`0Pk0L08>`700<08>`70P3oool2023/1`80oooo0P0P
k0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00<08>`70P3oool4023/1`030?ooo`0P
k0L08>`700D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`808>`700<00000023/1`3oool00`3o
ool2023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool00`3oool0100Pk0L0oooo0?oo
o`0Pk0L40?ooo`03023/1`3oool0oooo0380oooo00<000000?ooo`3oool0703oool001X0oooo00<0
00000?ooo`3oool0:@3oool00`0Pk0L0oooo023/1`040?ooo`06023/1`3oool08>`7023/1`3oool0
8>`70`3oool00`0Pk0L0oooo023/1`03023/1`@0oooo0`0Pk0L0103oool08>`70?ooo`3oool:023/
1`<0oooo1`0Pk0L00`3oool08>`7023/1`03023/1`80oooo0P0Pk0L20?ooo`<08>`700<0oooo023/
1`0Pk0L0100Pk0L00`3oool08>`70?ooo`03023/1`80oooo100Pk0L00`3oool08>`7023/1`05023/
1`030?ooo`0Pk0L0oooo00D08>`70P3oool2023/1`030000000Pk0L0oooo00<0oooo0`0Pk0L40?oo
o`03023/1`3oool0oooo00<0oooo00@08>`70?ooo`3oool08>`7103oool00`0Pk0L0oooo0?ooo`0b
0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003oool0oooo02T0oooo00<08>`70?oo
o`0Pk0L0103oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`<0oooo00<08>`70?ooo`0Pk0L00`0P
k0L40?ooo`<08>`700@0oooo023/1`3oool0oooo2P0Pk0L30?ooo`L08>`700<0oooo023/1`0Pk0L0
0`0Pk0L20?ooo`808>`70P3oool3023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`3oool0
0`0Pk0L20?ooo``08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`808>`700<00000023/1`3oool0
0`3oool3023/1`@0oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo023/1`050?ooo`03023/
1`3oool0oooo0380oooo00<000000?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0:@3o
ool00`0Pk0L0oooo023/1`040?ooo`06023/1`3oool08>`7023/1`3oool08>`70`3oool00`0Pk0L0
oooo023/1`03023/1`@0oooo0`0Pk0L0103oool08>`70?ooo`3oool:023/1`<0oooo1`0Pk0L00`3o
ool08>`7023/1`03023/1`80oooo0P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L00`3o
ool08>`70?ooo`03023/1`80oooo300Pk0L00`3oool08>`70?ooo`05023/1`80oooo0P0Pk0L00`00
00008>`70?ooo`030?ooo`<08>`7103oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool08>`7
00D0oooo00<08>`70?ooo`3oool0<P3oool00`000000oooo0?ooo`0L0?ooo`006P3oool00`000000
oooo0?ooo`0Y0?ooo`03023/1`3oool08>`700@0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L3
0?ooo`03023/1`3oool08>`700<08>`7103oool3023/1`040?ooo`0Pk0L0oooo0?ooo`X08>`70`3o
ool7023/1`030?ooo`0Pk0L08>`700<08>`70P3oool2023/1`80oooo00@08>`70?ooo`0Pk0L0oooo
1P0Pk0L00`3oool08>`70?ooo`03023/1`80oooo300Pk0L00`3oool08>`70?ooo`05023/1`80oooo
0P0Pk0L00`0000008>`70?ooo`030?ooo`<08>`7103oool00`0Pk0L0oooo0?ooo`030?ooo`03023/
1`3oool08>`700D0oooo00<08>`70?ooo`3oool0<P3oool00`000000oooo0?ooo`0L0?ooo`006P3o
ool00`000000oooo0?ooo`0Y0?ooo`03023/1`3oool08>`700@0oooo00H08>`70?ooo`3oool08>`7
0?ooo`0Pk0L30?ooo`03023/1`3oool08>`700<08>`7103oool3023/1`040?ooo`0Pk0L0oooo0?oo
o`X08>`70`3oool7023/1`030?ooo`0Pk0L08>`700<08>`70P3oool2023/1`80oooo00@08>`70?oo
o`0Pk0L0oooo1P0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo
023/1`3oool01@0Pk0L20?ooo`808>`700<00000023/1`3oool00`3oool3023/1`@0oooo00<08>`7
0?ooo`3oool00`3oool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo0380oooo00<00000
0?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0:@3oool00`0Pk0L0oooo023/1`040?oo
o`06023/1`3oool0oooo023/1`3oool08>`70`3oool00`0Pk0L0oooo023/1`03023/1`@0oooo0`0P
k0L0103oool08>`70?ooo`3oool:023/1`<0oooo1`0Pk0L00`3oool08>`7023/1`03023/1`80oooo
0P0Pk0L20?ooo`04023/1`3oool08>`70?ooo`H08>`700<0oooo023/1`3oool00`0Pk0L00`3oool0
8>`7023/1`0;023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool2023/1`030000000Pk0L0oooo00<0
oooo0`0Pk0L40?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0
oooo0?ooo`0b0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003oool0oooo02T0oooo
00<08>`70?ooo`0Pk0L0103oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`<0oooo00<08>`70?oo
o`0Pk0L00`0Pk0L40?ooo`<08>`700@0oooo023/1`3oool0oooo2P0Pk0L30?ooo`D08>`700<0oooo
023/1`3oool01@0Pk0L20?ooo`808>`70P3oool0100Pk0L0oooo023/1`3oool6023/1`030?ooo`0P
k0L0oooo00<08>`700<0oooo023/1`3oool02`0Pk0L00`3oool08>`70?ooo`05023/1`80oooo0P0P
k0L00`0000008>`70?ooo`030?ooo`<08>`7103oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3o
ool08>`700D0oooo00<08>`70?ooo`3oool0<P3oool00`000000oooo0?ooo`0L0?ooo`006P3oool0
0`000000oooo0?ooo`0Y0?ooo`03023/1`3oool08>`700@0oooo00H08>`70?ooo`3oool08>`70?oo
o`0Pk0L30?ooo`04023/1`3oool08>`70?ooo`808>`7103oool3023/1`040?ooo`0Pk0L0oooo0?oo
o`X08>`70`3oool5023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool2023/1`80oooo00@08>`70?oo
o`0Pk0L0oooo1P0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00/08>`700<0oooo
023/1`3oool0100Pk0L30?ooo`808>`700<00000023/1`3oool00`3oool3023/1`@0oooo00<08>`7
0?ooo`3oool00`3oool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo0380oooo00<00000
0?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0:@3oool00`0Pk0L0oooo023/1`040?oo
o`06023/1`3oool0oooo023/1`3oool08>`70`3oool0100Pk0L0oooo023/1`3oool2023/1`@0oooo
0`0Pk0L0103oool08>`70?ooo`3oool:023/1`<0oooo1@0Pk0L00`3oool08>`70?ooo`05023/1`80
oooo0P0Pk0L20?ooo`04023/1`3oool08>`70?ooo`H08>`700<0oooo023/1`3oool00`0Pk0L00`3o
ool08>`70?ooo`0;023/1`030?ooo`0Pk0L0oooo00@08>`70`3oool2023/1`030000000Pk0L0oooo
00<0oooo0`0Pk0L40?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`0Pk0L0103oool00`0P
k0L0oooo0?ooo`0c0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003oool0oooo02T0
oooo00<08>`70?ooo`0Pk0L0103oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`<0oooo00@08>`7
0?ooo`0Pk0L0oooo0P0Pk0L40?ooo`<08>`700@0oooo023/1`3oool0oooo2P0Pk0L30?ooo`D08>`7
00<0oooo023/1`3oool01@0Pk0L20?ooo`808>`70P3oool0100Pk0L0oooo023/1`3oool6023/1`03
0?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`3oool02`0Pk0L00`3oool08>`70?ooo`04023/1`<0
oooo0P0Pk0L00`0000008>`70?ooo`030?ooo`<08>`7103oool00`0Pk0L0oooo0?ooo`030?ooo`03
023/1`3oool08>`700@0oooo00<08>`70?ooo`3oool0<`3oool00`000000oooo0?ooo`0L0?ooo`00
6P3oool00`000000oooo0?ooo`0Y0?ooo`03023/1`3oool08>`700@0oooo00@08>`70?ooo`3oool0
8>`70P3oool01`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L40?ooo`<08>`700@0oooo
023/1`3oool0oooo2P0Pk0L30?ooo`D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`808>`70P3o
ool0100Pk0L0oooo023/1`3oool6023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`3oool0
2`0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0P0Pk0L00`0000008>`70?ooo`030?ooo`<08>`7
103oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool08>`700@0oooo00<08>`70?ooo`3oool0
<`3oool00`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0Y0?ooo`03023/1`3o
ool08>`700@0oooo00@08>`70?ooo`3oool08>`70P3oool01`0Pk0L0oooo0?ooo`0Pk0L0oooo023/
1`3oool00P0Pk0L40?ooo`<08>`700@0oooo023/1`3oool0oooo2P0Pk0L30?ooo`D08>`700<0oooo
023/1`3oool01@0Pk0L20?ooo`808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool6023/1`030?oo
o`0Pk0L0oooo00<08>`700<0oooo023/1`3oool02`0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo
0P0Pk0L00`0000008>`70?ooo`030?ooo`<08>`7103oool00`0Pk0L0oooo0?ooo`030?ooo`03023/
1`3oool08>`700@0oooo00<08>`70?ooo`3oool0<`3oool00`000000oooo0?ooo`0L0?ooo`006P3o
ool00`000000oooo0?ooo`0Z0?ooo`808>`7103oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`07023/
1`3oool0oooo023/1`3oool08>`70?ooo`02023/1`@0oooo0`0Pk0L0103oool08>`70?ooo`3oool:
023/1`<0oooo1@0Pk0L00`3oool08>`70?ooo`05023/1`80oooo0P0Pk0L01P3oool08>`7023/1`3o
ool08>`70?ooo`808>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00<08>`700<0oooo023/
1`3oool02`0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0P0Pk0L00`0000008>`70?ooo`030?oo
o`<08>`7103oool00`0Pk0L0oooo0?ooo`020?ooo`04023/1`3oool0oooo023/1`@0oooo00<08>`7
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0Z0?oo
o`808>`7103oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`07023/1`3oool0oooo023/1`3oool08>`7
0?ooo`02023/1`@0oooo0`0Pk0L0103oool08>`70?ooo`3oool:023/1`<0oooo1@0Pk0L00`3oool0
8>`70?ooo`05023/1`80oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`808>`700L0oooo023/
1`0Pk0L08>`70?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`3oool02`0Pk0L00`3oool08>`70?oo
o`04023/1`<0oooo0P0Pk0L00`0000008>`70?ooo`030?ooo`<08>`7103oool00`0Pk0L0oooo0?oo
o`020?ooo`04023/1`3oool0oooo023/1`@0oooo00<08>`70?ooo`3oool0<`3oool00`000000oooo
0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`808>`7103oool0100Pk0L0oooo0?oo
o`0Pk0L20?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0Pk0L0103oool3023/1`040?oo
o`0Pk0L0oooo0?ooo`X08>`70`3oool5023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool2023/1`04
0?ooo`0Pk0L08>`7023/1`80oooo0P0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool00`0P
k0L00`3oool08>`70?ooo`0;023/1`030?ooo`0Pk0L0oooo00@08>`70`3oool2023/1`030000000P
k0L0oooo00<0oooo0`0Pk0L40?ooo`03023/1`3oool0oooo0080oooo00@08>`70?ooo`3oool08>`7
103oool00`0Pk0L0oooo0?ooo`0c0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003o
ool0oooo02X0oooo0P0Pk0L40?ooo`04023/1`3oool0oooo023/1`80oooo00@08>`70?ooo`3oool0
oooo0P0Pk0L00`3oool08>`7023/1`040?ooo`<08>`700@0oooo023/1`3oool0oooo2P0Pk0L30?oo
o`D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool2
023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00/08>`7
00<0oooo023/1`3oool0100Pk0L30?ooo`808>`700<000000?ooo`3oool00`3oool3023/1`@0oooo
00<08>`70?ooo`3oool00P3oool0100Pk0L0oooo0?ooo`0Pk0L40?ooo`03023/1`3oool0oooo03<0
oooo00<000000?ooo`3oool0703oool001X0oooo00<000000?ooo`3oool0:P3oool2023/1`@0oooo
00@08>`70?ooo`3oool08>`70P3oool0100Pk0L0oooo0?ooo`3oool5023/1`@0oooo0`0Pk0L0103o
ool08>`70?ooo`3oool:023/1`<0oooo1@0Pk0L00`3oool08>`70?ooo`05023/1`80oooo0P0Pk0L0
103oool08>`7023/1`0Pk0L20?ooo`808>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00<0
8>`700<0oooo023/1`3oool02@0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00@08>`70P3oool3023/
1`030000003oool0oooo00<0oooo0`0Pk0L40?ooo`03023/1`3oool0oooo0080oooo00@08>`70?oo
o`3oool08>`7103oool00`0Pk0L0oooo0?ooo`0c0?ooo`030000003oool0oooo01`0oooo000J0?oo
o`030000003oool0oooo02X0oooo0P0Pk0L40?ooo`04023/1`3oool0oooo023/1`80oooo00H08>`7
0?ooo`3oool0oooo023/1`3oool3023/1`@0oooo0`0Pk0L0103oool08>`70?ooo`3oool:023/1`<0
oooo1@0Pk0L00`3oool08>`70?ooo`05023/1`80oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?oo
o`808>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`3oool02@0P
k0L01@3oool08>`70?ooo`0Pk0L0oooo00@08>`70P3oool3023/1`030000003oool0oooo00<0oooo
0`0Pk0L40?ooo`03023/1`3oool0oooo0080oooo00@08>`70?ooo`3oool08>`7103oool00`0Pk0L0
oooo0?ooo`0c0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003oool0oooo02X0oooo
0P0Pk0L40?ooo`04023/1`3oool0oooo023/1`80oooo00H08>`70?ooo`3oool0oooo023/1`3oool3
023/1`@0oooo0`0Pk0L0103oool08>`70?ooo`3oool:023/1`<0oooo1@0Pk0L00`3oool08>`70?oo
o`05023/1`80oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`700<0oooo023/1`3oool0
0`0Pk0L00`3oool08>`70?ooo`09023/1`050?ooo`0Pk0L0oooo023/1`3oool0100Pk0L20?ooo`<0
8>`700<000000?ooo`3oool00`3oool3023/1`@0oooo00<08>`70?ooo`3oool00P3oool0100Pk0L0
oooo0?ooo`0Pk0L40?ooo`03023/1`3oool0oooo03<0oooo00<000000?ooo`3oool0703oool001X0
oooo00<000000?ooo`3oool0:P3oool2023/1`@0oooo00@08>`70?ooo`3oool08>`70P3oool01P0P
k0L0oooo0?ooo`3oool08>`70?ooo`<08>`7103oool3023/1`040?ooo`0Pk0L0oooo0?ooo`X08>`7
0`3oool5023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool2023/1`040?ooo`0Pk0L08>`7023/1`80
oooo1P0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00T08>`700D0oooo023/1`3o
ool08>`70?ooo`04023/1`80oooo0`0Pk0L00`000000oooo0?ooo`020?ooo`@08>`7103oool00`0P
k0L0oooo0?ooo`020?ooo`04023/1`3oool0oooo023/1`@0oooo00<08>`70?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`808>`7103oool0100P
k0L0oooo0?ooo`0Pk0L20?ooo`06023/1`3oool0oooo0?ooo`0Pk0L0oooo0`0Pk0L40?ooo`<08>`7
00@0oooo023/1`3oool0oooo2P0Pk0L30?ooo`D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`80
8>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/
1`3oool02@0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00@08>`70P3oool3023/1`030000003oool0
oooo0080oooo100Pk0L40?ooo`03023/1`3oool0oooo0080oooo00@08>`70?ooo`3oool08>`7103o
ool00`0Pk0L0oooo0?ooo`0c0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003oool0
oooo02X0oooo00<08>`70?ooo`0Pk0L00`3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`06023/1`3o
ool0oooo0?ooo`0Pk0L0oooo0`0Pk0L40?ooo`<08>`700@0oooo023/1`3oool0oooo2P0Pk0L30?oo
o`D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool6
023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`3oool02@0Pk0L01@3oool08>`70?ooo`0P
k0L0oooo00@08>`70P3oool3023/1`030000003oool0oooo0080oooo100Pk0L40?ooo`03023/1`3o
ool0oooo0080oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`0c0?ooo`030000003o
ool0oooo01`0oooo000J0?ooo`030000003oool0oooo02X0oooo00<08>`70?ooo`0Pk0L00`3oool0
100Pk0L0oooo0?ooo`0Pk0L20?ooo`06023/1`3oool0oooo0?ooo`0Pk0L0oooo0`0Pk0L40?ooo`<0
8>`700@0oooo023/1`3oool0oooo2P0Pk0L30?ooo`D08>`700<0oooo023/1`3oool01@0Pk0L20?oo
o`808>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo
023/1`3oool02P0Pk0L20?ooo`03023/1`3oool08>`700<08>`70P3oool3023/1`030000003oool0
oooo0080oooo100Pk0L40?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`0Pk0L01@3oool0
0`0Pk0L0oooo0?ooo`0c0?ooo`030000003oool0oooo01`0oooo000J0?ooo`030000003oool0oooo
02X0oooo00<08>`70?ooo`0Pk0L00`3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`06023/1`3oool0
oooo0?ooo`0Pk0L0oooo0`0Pk0L40?ooo`<08>`700@0oooo023/1`3oool0oooo2P0Pk0L30?ooo`D0
8>`700<0oooo023/1`3oool01@0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool8023/
1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700D08>`70P3o
ool6023/1`80oooo0`0Pk0L00`000000oooo0?ooo`020?ooo`@08>`7103oool00`0Pk0L0oooo0?oo
o`020?ooo`03023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool0<`3oool00`000000oooo0?oo
o`0L0?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`03023/1`3oool08>`700<0oooo00@08>`7
0?ooo`3oool08>`70P3oool01P0Pk0L0oooo0?ooo`3oool08>`70?ooo`<08>`7103oool3023/1`04
0?ooo`0Pk0L0oooo0?ooo`X08>`70`3oool5023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool2023/
1`040?ooo`0Pk0L08>`7023/1`80oooo200Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool0
0P0Pk0L00`3oool08>`7023/1`05023/1`80oooo1P0Pk0L20?ooo`<08>`700<000000?ooo`3oool0
0P3oool3023/1`D0oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo023/1`050?ooo`03023/
1`3oool0oooo03@0oooo00<000000?ooo`3oool06`3oool001X0oooo00<000000?ooo`3oool0:P3o
ool00`0Pk0L0oooo023/1`030?ooo`04023/1`3oool0oooo023/1`80oooo00H08>`70?ooo`3oool0
oooo023/1`3oool3023/1`@0oooo0`0Pk0L0103oool08>`70?ooo`3oool:023/1`<0oooo1@0Pk0L0
0`3oool08>`70?ooo`05023/1`80oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`P08>`700L0
oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`H0
8>`70P3oool3023/1`030000003oool0oooo0080oooo0`0Pk0L50?ooo`03023/1`3oool0oooo0080
oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`0d0?ooo`030000003oool0oooo01/0
oooo000J0?ooo`030000003oool0oooo02X0oooo00<08>`70?ooo`0Pk0L00`3oool0100Pk0L0oooo
0?ooo`0Pk0L20?ooo`06023/1`3oool0oooo0?ooo`0Pk0L0oooo0`0Pk0L40?ooo`<08>`700@0oooo
023/1`3oool0oooo2P0Pk0L30?ooo`D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`808>`700<0
oooo023/1`0Pk0L00`3oool8023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`02023/1`03
0?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`<08>`700<000000?ooo`3o
ool00P3oool3023/1`D0oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo023/1`050?ooo`03
023/1`3oool0oooo03@0oooo00<000000?ooo`3oool06`3oool001X0oooo00<000000?ooo`3oool0
:P3oool00`0Pk0L0oooo023/1`030?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3o
ool00P0Pk0L0103oool08>`7023/1`0Pk0L40?ooo`<08>`700@0oooo023/1`3oool0oooo2P0Pk0L3
0?ooo`D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00`3oool8
023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700D08>`7
00<0oooo023/1`3oool01@0Pk0L20?ooo`<08>`700<000000?ooo`3oool00P3oool3023/1`D0oooo
00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo03@0oooo
00<000000?ooo`3oool06`3oool001X0oooo00<000000?ooo`3oool0:P3oool00`0Pk0L0oooo023/
1`030?ooo`03023/1`3oool0oooo00808>`700@0oooo023/1`3oool0oooo0P0Pk0L0103oool08>`7
023/1`0Pk0L40?ooo`<08>`700@0oooo023/1`3oool0oooo2P0Pk0L30?ooo`D08>`700<0oooo023/
1`3oool01@0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00`3oool8023/1`070?ooo`0Pk0L08>`7
023/1`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3oool01@0P
k0L20?ooo`<08>`700<000000?ooo`3oool00P3oool3023/1`@0oooo00<08>`70?ooo`3oool00`3o
ool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo03@0oooo00<000000?ooo`3oool06`3o
ool001X0oooo00<000000?ooo`3oool0:P3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0
oooo00808>`700@0oooo023/1`3oool0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L40?ooo`<08>`7
00@0oooo023/1`3oool0oooo2P0Pk0L30?ooo`D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`80
8>`700<0oooo023/1`0Pk0L00`3oool8023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`02
023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`<08>`700<00000
0?ooo`3oool00P3oool3023/1`@0oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo023/1`05
0?ooo`03023/1`3oool0oooo03@0oooo00<000000?ooo`3oool06`3oool001X0oooo00<000000?oo
o`3oool0:P3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo00808>`700@0oooo023/
1`3oool0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700<0oooo0`0Pk0L0103oool08>`70?oo
o`3oool:023/1`<0oooo1@0Pk0L00`3oool08>`70?ooo`05023/1`80oooo0P0Pk0L00`3oool08>`7
023/1`030?ooo`P08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00808>`700<0oooo023/
1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`05023/1`80oooo0`0Pk0L00`000000oooo0?ooo`020?oo
o`<08>`7103oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool08>`700D0oooo00<08>`70?oo
o`3oool0=03oool00`000000oooo0?ooo`0K0?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`03
023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool00P0Pk0L0103oool08>`70?ooo`3oool2023/
1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00`3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`X08>`70`3o
ool5023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool2023/1`030?ooo`0Pk0L08>`700<0oooo200P
k0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`05023/1`03
0?ooo`0Pk0L0oooo00D08>`70P3oool3023/1`030000003oool0oooo0080oooo0`0Pk0L40?ooo`03
023/1`3oool0oooo00<0oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`0d0?ooo`03
0000003oool0oooo01/0oooo000J0?ooo`030000003oool0oooo02X0oooo00<08>`70?ooo`0Pk0L0
0`3oool00`0Pk0L0oooo0?ooo`02023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700D0oooo023/1`0P
k0L0oooo023/1`030?ooo`D08>`70P3oool:023/1`<0oooo1@0Pk0L00`3oool08>`70?ooo`05023/
1`80oooo0P0Pk0L00`3oool08>`7023/1`030?ooo`P08>`700L0oooo023/1`0Pk0L08>`70?ooo`0P
k0L0oooo00808>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`05023/1`80oooo0`0P
k0L00`000000oooo0?ooo`020?ooo`<08>`7103oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3o
ool08>`700D0oooo00<08>`70?ooo`3oool0=03oool00`000000oooo0?ooo`0K0?ooo`006P3oool0
0`000000oooo0?ooo`0Z0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool00P0Pk0L0
103oool08>`70?ooo`3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L00`3oool5023/1`80oooo
2P0Pk0L30?ooo`D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L0
0`3oool8023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L08>`7
00D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`<08>`700<000000?ooo`3oool00P3oool3023/
1`@0oooo00<08>`70?ooo`3oool00P3oool0100Pk0L0oooo0?ooo`0Pk0L50?ooo`03023/1`3oool0
oooo03@0oooo00<000000?ooo`3oool06`3oool001X0oooo00<000000?ooo`3oool0:P3oool00`0P
k0L0oooo023/1`030?ooo`03023/1`3oool0oooo00808>`700@0oooo023/1`3oool0oooo0P0Pk0L0
1@3oool08>`7023/1`3oool08>`700<0oooo1@0Pk0L20?ooo`X08>`70`3oool5023/1`030?ooo`0P
k0L0oooo00D08>`70P3oool2023/1`030?ooo`0Pk0L08>`700<0oooo200Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`05023/1`80oooo
0`0Pk0L00`000000oooo0?ooo`020?ooo`<08>`7103oool00`0Pk0L0oooo0?ooo`020?ooo`04023/
1`3oool0oooo023/1`D0oooo00<08>`70?ooo`3oool0=03oool00`000000oooo0?ooo`0K0?ooo`00
6P3oool00`000000oooo0?ooo`0Z0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool0
0P0Pk0L0103oool08>`70?ooo`3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L0103oool4023/
1`80oooo2P0Pk0L30?ooo`D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`808>`700<0oooo023/
1`0Pk0L00`3oool8023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`7023/1`05
023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool3023/1`030000003oool0oooo0080oooo0`0Pk0L4
0?ooo`03023/1`3oool0oooo0080oooo00@08>`70?ooo`3oool08>`7103oool00`0Pk0L0oooo0?oo
o`0e0?ooo`030000003oool0oooo01/0oooo000J0?ooo`030000003oool0oooo02X0oooo00<08>`7
0?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`02023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700D0
oooo023/1`0Pk0L0oooo023/1`040?ooo`<08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`D08>`7
00<0oooo023/1`3oool01@0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00`3oool8023/1`050?oo
o`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00D0
8>`70P3oool3023/1`030000003oool0oooo0080oooo0`0Pk0L40?ooo`03023/1`3oool0oooo0080
oooo00@08>`70?ooo`3oool08>`7103oool00`0Pk0L0oooo0?ooo`0e0?ooo`030000003oool0oooo
01/0oooo000J0?ooo`030000003oool0oooo02X0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0
oooo0?ooo`02023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`04
0?ooo`<08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`D08>`700<0oooo023/1`3oool01@0Pk0L2
0?ooo`808>`700<0oooo023/1`0Pk0L00`3oool8023/1`050?ooo`0Pk0L08>`7023/1`3oool0100P
k0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool3023/1`030000003o
ool0oooo0080oooo0`0Pk0L40?ooo`03023/1`3oool0oooo0080oooo00@08>`70?ooo`3oool08>`7
103oool00`0Pk0L0oooo0?ooo`0e0?ooo`030000003oool0oooo01/0oooo000J0?ooo`030000003o
ool0oooo02X0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`02023/1`070?ooo`0P
k0L0oooo023/1`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo00<0oooo0`0Pk0L00`3oool0
8>`70?ooo`0:023/1`<0oooo1@0Pk0L00`3oool08>`70?ooo`05023/1`80oooo0P0Pk0L00`3oool0
8>`7023/1`030?ooo`P08>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`030?ooo`0Pk0L08>`7
00D08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`<08>`700<000000?ooo`3oool00P3oool3023/
1`@0oooo00<08>`70?ooo`3oool00P3oool0100Pk0L0oooo0?ooo`0Pk0L40?ooo`03023/1`3oool0
oooo03D0oooo00<000000?ooo`3oool06`3oool001X0oooo00<000000?ooo`3oool0:P3oool00`0P
k0L0oooo023/1`030?ooo`03023/1`3oool0oooo00808>`700L0oooo023/1`3oool08>`70?ooo`0P
k0L0oooo00808>`700<0oooo023/1`3oool00`3oool3023/1`030?ooo`0Pk0L0oooo00X08>`70`3o
ool5023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool2023/1`030?ooo`0Pk0L08>`700<0oooo0`0P
k0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`7
0?ooo`05023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool3023/1`030000003oool0oooo0080oooo
0`0Pk0L40?ooo`03023/1`3oool0oooo0080oooo00@08>`70?ooo`3oool08>`7103oool00`0Pk0L0
oooo0?ooo`0e0?ooo`030000003oool0oooo01/0oooo000J0?ooo`030000003oool0oooo02X0oooo
00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`02023/1`070?ooo`0Pk0L0oooo023/1`3o
ool08>`70?ooo`04023/1`@0oooo0`0Pk0L00`3oool08>`70?ooo`0:023/1`<0oooo1@0Pk0L00`3o
ool08>`70?ooo`05023/1`80oooo0P0Pk0L00`3oool08>`7023/1`030?ooo`<08>`700<0oooo023/
1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`700<0oooo023/1`3oool01@0Pk0L0
0`3oool08>`70?ooo`05023/1`80oooo0`0Pk0L00`000000oooo0?ooo`020?ooo`<08>`7103oool0
0`0Pk0L0oooo0?ooo`020?ooo`04023/1`3oool0oooo023/1`@0oooo00<08>`70?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0K0?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`03023/1`3oool0
8>`700<0oooo00<08>`70?ooo`3oool00P0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool0
100Pk0L40?ooo`<08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`D08>`700<0oooo023/1`3oool0
1@0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00`3oool3023/1`030?ooo`0Pk0L08>`700808>`7
00D0oooo023/1`0Pk0L08>`70?ooo`04023/1`030?ooo`0Pk0L0oooo00D08>`700<0oooo023/1`3o
ool01@0Pk0L20?ooo`<08>`700<000000?ooo`3oool00P3oool3023/1`@0oooo00<08>`70?ooo`3o
ool00P3oool0100Pk0L0oooo0?ooo`0Pk0L40?ooo`03023/1`3oool0oooo03D0oooo00<000000?oo
o`3oool06`3oool001X0oooo00<000000?ooo`3oool0:P3oool00`0Pk0L0oooo023/1`030?ooo`03
023/1`3oool0oooo00808>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00@08>`7103oool3
023/1`030?ooo`0Pk0L0oooo00X08>`70`3oool5023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool2
023/1`030?ooo`0Pk0L08>`700<0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L0
8>`7023/1`3oool0100Pk0L00`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L0oooo00D08>`70P3o
ool3023/1`030000003oool0oooo0080oooo0`0Pk0L40?ooo`03023/1`3oool0oooo0080oooo00<0
8>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`0e0?ooo`030000003oool0oooo01/0oooo000J
0?ooo`030000003oool0oooo02X0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`02
023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`04023/1`@0oooo0`0Pk0L00`3oool08>`7
0?ooo`0:023/1`<0oooo1@0Pk0L00`3oool08>`70?ooo`05023/1`80oooo0P0Pk0L00`3oool08>`7
023/1`030?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@0
8>`700<0oooo023/1`3oool01@0Pk0L00`3oool08>`70?ooo`05023/1`80oooo0`0Pk0L00`000000
oooo0?ooo`020?ooo`<08>`7103oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool08>`700D0
oooo00<08>`70?ooo`3oool0=@3oool00`000000oooo0?ooo`0K0?ooo`006P3oool00`000000oooo
0?ooo`0Z0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool00P0Pk0L01@3oool08>`7
0?ooo`0Pk0L0oooo00H08>`7103oool3023/1`030?ooo`0Pk0L0oooo00X08>`70`3oool5023/1`03
0?ooo`0Pk0L0oooo00D08>`70P3oool2023/1`030?ooo`0Pk0L08>`700<0oooo0`0Pk0L00`3oool0
8>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`70?ooo`05023/
1`030?ooo`0Pk0L0oooo00D08>`700<0oooo023/1`0Pk0L00P0Pk0L010000000oooo0?ooo`3oool4
023/1`@0oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0
oooo03D0oooo00<000000?ooo`3oool06`3oool001X0oooo00<000000?ooo`3oool0:P3oool00`0P
k0L0oooo023/1`040?ooo`08023/1`3oool08>`7023/1`3oool08>`70?ooo`0Pk0L20?ooo`D08>`7
103oool3023/1`030?ooo`0Pk0L0oooo00X08>`70`3oool5023/1`030?ooo`0Pk0L0oooo00D08>`7
00D0oooo023/1`3oool08>`70?ooo`02023/1`<0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`05
0?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L0oooo
00D08>`700<0oooo023/1`0Pk0L00P0Pk0L010000000oooo0?ooo`3oool4023/1`@0oooo00<08>`7
0?ooo`3oool00P3oool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo03D0oooo00<00000
0?ooo`3oool06`3oool001X0oooo00<000000?ooo`3oool0:P3oool00`0Pk0L0oooo023/1`040?oo
o`08023/1`3oool08>`7023/1`3oool08>`70?ooo`0Pk0L20?ooo`D08>`7103oool3023/1`030?oo
o`0Pk0L0oooo00X08>`70`3oool5023/1`030?ooo`0Pk0L0oooo00D08>`700D0oooo023/1`3oool0
8>`70?ooo`02023/1`<0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/
1`3oool0100Pk0L00`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L0oooo00D08>`700<0oooo023/
1`0Pk0L00P0Pk0L010000000oooo0?ooo`3oool4023/1`@0oooo00<08>`70?ooo`3oool00P3oool0
0`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo03D0oooo00<000000?ooo`3oool06`3oool0
01X0oooo00<000000?ooo`3oool0:P3oool00`0Pk0L0oooo023/1`040?ooo`08023/1`3oool08>`7
023/1`3oool08>`70?ooo`0Pk0L20?ooo`D08>`7103oool3023/1`030?ooo`0Pk0L0oooo00X08>`7
0`3oool5023/1`030?ooo`0Pk0L0oooo00D08>`700D0oooo023/1`3oool08>`70?ooo`02023/1`<0
oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3o
ool08>`70?ooo`05023/1`030?ooo`0Pk0L0oooo00D08>`700<0oooo023/1`0Pk0L00P0Pk0L01000
0000oooo0?ooo`3oool4023/1`@0oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo023/1`05
0?ooo`03023/1`3oool0oooo03D0oooo00<000000?ooo`3oool06`3oool001X0oooo00<000000?oo
o`3oool0:P3oool00`0Pk0L0oooo023/1`040?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L3
0?ooo`03023/1`3oool08>`700808>`7103oool3023/1`030?ooo`0Pk0L0oooo00X08>`70`3oool5
023/1`030?ooo`0Pk0L0oooo00D08>`700D0oooo023/1`3oool08>`70?ooo`02023/1`<0oooo0`0P
k0L0103oool08>`7023/1`0Pk0L20?ooo`P08>`700<0oooo023/1`3oool01@0Pk0L00`3oool08>`7
0?ooo`05023/1`030?ooo`0Pk0L08>`700808>`700@000000?ooo`3oool0oooo100Pk0L40?ooo`03
023/1`3oool0oooo0080oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`0e0?ooo`03
0000003oool0oooo01/0oooo000J0?ooo`030000003oool0oooo02X0oooo00<08>`70?ooo`0Pk0L0
103oool01@0Pk0L0oooo023/1`0Pk0L0oooo00808>`70`3oool00`0Pk0L0oooo023/1`02023/1`@0
oooo0`0Pk0L00`3oool08>`70?ooo`0:023/1`<0oooo1@0Pk0L00`3oool08>`70?ooo`05023/1`05
0?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L30?ooo`<08>`700@0oooo023/1`0Pk0L08>`70P3oool8
023/1`030?ooo`0Pk0L0oooo00D08>`700<0oooo023/1`3oool01@0Pk0L00`3oool08>`7023/1`02
023/1`040000003oool0oooo0?ooo`<08>`71@3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3o
ool08>`700D0oooo00<08>`70?ooo`3oool0=@3oool00`000000oooo0?ooo`0K0?ooo`006P3oool0
0`000000oooo0?ooo`0Z0?ooo`03023/1`3oool08>`700@0oooo00D08>`70?ooo`0Pk0L08>`70?oo
o`02023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`<08>`700<0oooo023/1`3oool02P0P
k0L30?ooo`D08>`700<0oooo023/1`3oool01@0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0`0P
k0L0103oool08>`7023/1`0Pk0L20?ooo`@08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo
00D08>`700<0oooo023/1`3oool01@0Pk0L00`3oool08>`7023/1`02023/1`040000003oool0oooo
0?ooo`<08>`71@3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool08>`700D0oooo00<08>`7
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0K0?ooo`006P3oool00`000000oooo0?ooo`0Z0?oo
o`03023/1`3oool08>`700@0oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`<0oooo00<08>`7
0?ooo`0Pk0L00P0Pk0L40?ooo`<08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`D08>`700<0oooo
023/1`3oool01@0Pk0L00`3oool08>`70?ooo`04023/1`<0oooo0`0Pk0L0103oool08>`7023/1`0P
k0L20?ooo`@08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00D08>`700<0oooo023/1`3o
ool01@0Pk0L00`3oool08>`7023/1`02023/1`040000003oool0oooo0?ooo`<08>`71@3oool00`0P
k0L0oooo0?ooo`020?ooo`03023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0K0?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`03023/1`3oool08>`700@0
oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?oo
o`<08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`D08>`700<0oooo023/1`3oool01@0Pk0L00`3o
ool08>`70?ooo`04023/1`<0oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`@08>`700L0oooo
023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00D08>`700<0oooo023/1`3oool01@0Pk0L00`3oool08>`7
023/1`02023/1`040000003oool0oooo0?ooo`<08>`71@3oool00`0Pk0L0oooo0?ooo`020?ooo`03
023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool0=@3oool00`000000oooo0?ooo`0K0?ooo`00
6P3oool00`000000oooo0?ooo`0[0?ooo`808>`7103oool01@0Pk0L0oooo023/1`0Pk0L0oooo0080
8>`70`3oool00`0Pk0L0oooo023/1`02023/1`@0oooo0`0Pk0L00`3oool08>`70?ooo`0:023/1`<0
oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L0oooo00@0
8>`70`3oool3023/1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L01`3oool08>`7023/1`0Pk0L0
oooo023/1`3oool01@0Pk0L00`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L08>`700808>`700@0
00000?ooo`3oool0oooo0`0Pk0L50?ooo`05023/1`3oool0oooo0?ooo`0Pk0L00P3oool00`0Pk0L0
oooo0?ooo`030?ooo`03023/1`3oool0oooo03D0oooo00<000000?ooo`3oool06`3oool001X0oooo
00<000000?ooo`3oool0:`3oool2023/1`@0oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`<0
oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`<08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`03
023/1`3oool08>`700808>`700<0oooo023/1`3oool01@0Pk0L00`3oool08>`70?ooo`04023/1`<0
oooo0`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700L0oooo023/1`0Pk0L08>`70?ooo`0P
k0L0oooo00D08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`02023/1`040000003o
ool0oooo0?ooo`<08>`71@3oool01@0Pk0L0oooo0?ooo`3oool08>`70080oooo00<08>`70?ooo`3o
ool00`3oool00`0Pk0L0oooo0?ooo`0e0?ooo`030000003oool0oooo01/0oooo000J0?ooo`030000
003oool0oooo02/0oooo0P0Pk0L40?ooo`03023/1`3oool08>`700@08>`70`3oool00`0Pk0L0oooo
023/1`02023/1`@0oooo0`0Pk0L00`3oool08>`70?ooo`0:023/1`<0oooo00<08>`70?ooo`0Pk0L0
0P0Pk0L00`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L0oooo00@08>`70`3oool3023/1`050?oo
o`0Pk0L08>`7023/1`3oool01@0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool01@0Pk0L0
0`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700808>`700@000000?ooo`3oool0oooo0`0P
k0L50?ooo`05023/1`3oool0oooo0?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/
1`3oool0oooo03D0oooo00<000000?ooo`3oool06`3oool001X0oooo00<000000?ooo`3oool0:`3o
ool2023/1`@0oooo00<08>`70?ooo`3oool0100Pk0L30?ooo`03023/1`3oool08>`700808>`7103o
ool3023/1`030?ooo`0Pk0L0oooo00X08>`70`3oool00`0Pk0L0oooo023/1`02023/1`030?ooo`0P
k0L0oooo00D08>`700<0oooo023/1`3oool0100Pk0L30?ooo`<08>`700D0oooo023/1`0Pk0L08>`7
0?ooo`05023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L08>`7
00D08>`700<0oooo023/1`0Pk0L00P0Pk0L010000000oooo0?ooo`3oool3023/1`D0oooo00D08>`7
0?ooo`3oool0oooo023/1`020?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0K0?ooo`006P3oool00`000000oooo0?ooo`0[0?ooo`808>`7103oool0
0`0Pk0L0oooo0?ooo`04023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`<08>`700<0oooo
023/1`3oool02P0Pk0L30?ooo`03023/1`3oool08>`700808>`700<0oooo023/1`3oool01@0Pk0L0
0`3oool08>`70?ooo`04023/1`<0oooo0`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700L0
oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00@08>`70P3oool7023/1`030?ooo`0Pk0L08>`70080
8>`700@000000?ooo`3oool0oooo0`0Pk0L50?ooo`05023/1`3oool0oooo0?ooo`0Pk0L00P3oool0
0`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo03D0oooo00<000000?ooo`3oool06`3oool0
01X0oooo00<000000?ooo`3oool0:`3oool2023/1`@0oooo00<08>`70?ooo`3oool0100Pk0L30?oo
o`03023/1`3oool08>`700808>`7103oool3023/1`030?ooo`0Pk0L0oooo00X08>`70`3oool00`0P
k0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700H0oooo023/1`0Pk0L0oooo023/1`3o
ool4023/1`<0oooo0`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700L0oooo023/1`0Pk0L0
8>`70?ooo`0Pk0L0oooo00@08>`70P3oool7023/1`030?ooo`0Pk0L08>`700808>`700@000000?oo
o`3oool0oooo0`0Pk0L50?ooo`05023/1`3oool0oooo0?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?oo
o`030?ooo`03023/1`3oool0oooo03D0oooo00<000000?ooo`3oool06`3oool001X0oooo00<00000
0?ooo`3oool0:`3oool2023/1`@0oooo00<08>`70?ooo`3oool00`0Pk0L40?ooo`03023/1`3oool0
8>`700808>`7103oool3023/1`030?ooo`0Pk0L0oooo00X08>`70`3oool00`0Pk0L0oooo023/1`02
023/1`030?ooo`0Pk0L0oooo00808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool4023/1`80oooo
100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0
oooo00@08>`700<0oooo023/1`3oool01P0Pk0L00`3oool08>`7023/1`02023/1`040000003oool0
oooo0?ooo`<08>`71@3oool01@0Pk0L0oooo0?ooo`3oool08>`70080oooo00<08>`70?ooo`3oool0
0`3oool00`0Pk0L0oooo0?ooo`0e0?ooo`030000003oool0oooo01/0oooo000J0?ooo`030000003o
ool0oooo02/0oooo0P0Pk0L40?ooo`03023/1`3oool0oooo00<08>`7103oool00`0Pk0L0oooo023/
1`02023/1`@0oooo0`0Pk0L00`3oool08>`70?ooo`0:023/1`<0oooo00<08>`70?ooo`0Pk0L00P0P
k0L00`3oool08>`70?ooo`02023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo100Pk0L20?ooo`@0
8>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?oo
o`04023/1`030?ooo`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L00P0Pk0L010000000oooo0?oo
o`3oool3023/1`D0oooo00D08>`70?ooo`3oool0oooo023/1`020?ooo`03023/1`3oool0oooo00<0
oooo00<08>`70?ooo`3oool0=@3oool00`000000oooo0?ooo`0K0?ooo`006P3oool00`000000oooo
0?ooo`0[0?ooo`808>`7103oool00`0Pk0L0oooo0?ooo`03023/1`@0oooo00H08>`70?ooo`0Pk0L0
8>`70?ooo`0Pk0L30?ooo`<08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`03023/1`3oool08>`7
00808>`700<0oooo023/1`3oool00P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`@08>`70P3o
ool4023/1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/
1`3oool0100Pk0L00`3oool08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700808>`700@000000?oo
o`3oool0oooo0`0Pk0L50?ooo`05023/1`3oool0oooo0?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?oo
o`030?ooo`03023/1`3oool0oooo03D0oooo00<000000?ooo`3oool06`3oool001X0oooo00<00000
0?ooo`3oool0:`3oool2023/1`@0oooo00<08>`70?ooo`3oool00`0Pk0L40?ooo`06023/1`3oool0
8>`7023/1`3oool08>`70`3oool3023/1`030?ooo`0Pk0L0oooo00X08>`70`3oool00`0Pk0L0oooo
023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool4023/
1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700L0oooo023/1`0Pk0L08>`70?oo
o`0Pk0L0oooo00@08>`700<0oooo023/1`3oool01P0Pk0L00`3oool08>`7023/1`02023/1`040000
003oool0oooo0?ooo`<08>`71@3oool01`0Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L01P3oool0
0`0Pk0L0oooo0?ooo`0e0?ooo`030000003oool0oooo01/0oooo000J0?ooo`030000003oool0oooo
02/0oooo0P0Pk0L40?ooo`03023/1`3oool0oooo00<08>`7103oool01P0Pk0L0oooo023/1`0Pk0L0
oooo023/1`<0oooo0`0Pk0L00`3oool08>`70?ooo`0:023/1`<0oooo00<08>`70?ooo`0Pk0L00P0P
k0L00`3oool08>`70?ooo`02023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo100Pk0L20?ooo`@0
8>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?oo
o`04023/1`030?ooo`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L00P0Pk0L010000000oooo0?oo
o`3oool3023/1`D0oooo00L08>`70?ooo`3oool0oooo023/1`3oool08>`700D0oooo00<08>`70?oo
o`3oool0=P3oool00`000000oooo0?ooo`0K0?ooo`006P3oool00`000000oooo0?ooo`0[0?ooo`03
023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool00`0Pk0L40?ooo`06023/1`3oool08>`7023/
1`3oool08>`70`3oool3023/1`030?ooo`0Pk0L0oooo00X08>`70`3oool00`0Pk0L0oooo023/1`02
023/1`030?ooo`0Pk0L0oooo00808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool4023/1`80oooo
100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0
oooo00@08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`70?ooo`04023/1`040000003oool0
oooo0?ooo`<08>`7103oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool08>`700D0oooo00<0
8>`70?ooo`3oool0=P3oool00`000000oooo0?ooo`0K0?ooo`006@3oool00`000000oooo0?ooo`0/
0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool00`0Pk0L40?ooo`06023/1`3oool0
8>`7023/1`3oool08>`70`3oool3023/1`030?ooo`0Pk0L0oooo00X08>`70`3oool00`0Pk0L0oooo
023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool4023/
1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700L0oooo023/1`0Pk0L08>`70?oo
o`0Pk0L0oooo00@08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`@08>`700@000000?ooo`3oool0
oooo0`0Pk0L40?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0
oooo0?ooo`0f0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02`0oooo
00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`04023/1`<0oooo00H08>`70?ooo`0Pk0L0
8>`70?ooo`0Pk0L30?ooo`<08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`03023/1`3oool08>`7
00808>`700<0oooo023/1`3oool00P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`@08>`70P3o
ool4023/1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/
1`3oool0100Pk0L00`3oool08>`70?ooo`05023/1`80oooo100Pk0L010000000oooo0?ooo`3oool3
023/1`@0oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0
oooo03H0oooo00<000000?ooo`3oool06`3oool001T0oooo00<000000?ooo`3oool0;03oool00`0P
k0L0oooo023/1`030?ooo`03023/1`3oool0oooo00@08>`70`3oool01P0Pk0L0oooo023/1`0Pk0L0
oooo023/1`<0oooo0`0Pk0L00`3oool08>`70?ooo`0:023/1`<0oooo00<08>`70?ooo`0Pk0L00P0P
k0L00`3oool08>`70?ooo`02023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo100Pk0L20?ooo`@0
8>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`70?oo
o`04023/1`030?ooo`0Pk0L0oooo00D08>`70P3oool4023/1`040000003oool0oooo0?ooo`<08>`7
103oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool0
=P3oool00`000000oooo0?ooo`0K0?ooo`006@3oool00`000000oooo0?ooo`0/0?ooo`03023/1`3o
ool08>`700<0oooo00<08>`70?ooo`3oool0100Pk0L30?ooo`06023/1`3oool08>`7023/1`3oool0
8>`70`3oool3023/1`030?ooo`0Pk0L0oooo00X08>`70`3oool00`0Pk0L0oooo023/1`02023/1`03
0?ooo`0Pk0L0oooo00808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool4023/1`80oooo100Pk0L0
1@3oool08>`7023/1`0Pk0L0oooo00D08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00@0
8>`700<0oooo023/1`3oool01@0Pk0L20?ooo`@08>`700@000000?ooo`3oool0oooo0`0Pk0L40?oo
o`03023/1`3oool0oooo0080oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`0f0?oo
o`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02`0oooo00<08>`70?ooo`0P
k0L00`3oool00`0Pk0L0oooo0?ooo`02023/1`030?ooo`0Pk0L0oooo0080oooo00H08>`70?ooo`0P
k0L08>`70?ooo`0Pk0L30?ooo`<08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`03023/1`3oool0
8>`700808>`700<0oooo023/1`3oool00P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`@08>`7
0P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L01`3oool08>`7023/1`0Pk0L0oooo
023/1`3oool0100Pk0L00`3oool08>`70?ooo`05023/1`80oooo100Pk0L01@000000oooo0?ooo`0P
k0L0oooo00808>`7103oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool08>`700D0oooo00<0
8>`70?ooo`3oool0=P3oool00`000000oooo0?ooo`0K0?ooo`006@3oool00`000000oooo0?ooo`0/
0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool00P0Pk0L00`3oool08>`70?ooo`02
0?ooo`06023/1`3oool08>`7023/1`3oool08>`70`3oool3023/1`030?ooo`0Pk0L0oooo00X08>`7
0`3oool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700H0oooo023/1`0Pk0L0
oooo023/1`3oool4023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700L0oooo
023/1`0Pk0L08>`70?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`3oool01@0Pk0L20?ooo`808>`7
00<0oooo023/1`0000000P3oool0100Pk0L0oooo023/1`0Pk0L40?ooo`03023/1`3oool0oooo0080
oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`0f0?ooo`030000003oool0oooo01/0
oooo000I0?ooo`030000003oool0oooo02`0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo
0?ooo`02023/1`030?ooo`0Pk0L0oooo0080oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L30?oo
o`<08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`03023/1`3oool08>`700808>`700<0oooo023/
1`3oool00P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`@08>`70P3oool4023/1`050?ooo`0P
k0L08>`7023/1`3oool00`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00@08>`7
00<0oooo023/1`3oool01@0Pk0L20?ooo`808>`700<0oooo023/1`0000000P3oool0100Pk0L0oooo
023/1`0Pk0L40?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0
oooo0?ooo`0f0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02`0oooo
00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`02023/1`030?ooo`0Pk0L0oooo0080oooo
00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L30?ooo`<08>`700<0oooo023/1`3oool02P0Pk0L30?oo
o`03023/1`3oool08>`700808>`700<0oooo023/1`3oool00P0Pk0L01P3oool08>`7023/1`3oool0
8>`70?ooo`@08>`70P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`7
0?ooo`03023/1`050?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L00`3oool08>`70?ooo`05023/1`80
oooo0P0Pk0L00`3oool08>`7000000020?ooo`04023/1`3oool08>`7023/1`@0oooo00<08>`70?oo
o`3oool00P3oool00`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo03H0oooo00<000000?oo
o`3oool06`3oool001T0oooo00<000000?ooo`3oool0;03oool00`0Pk0L0oooo023/1`030?ooo`03
023/1`3oool0oooo00808>`700<0oooo023/1`3oool00P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo
023/1`<0oooo0`0Pk0L00`3oool08>`70?ooo`0:023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L0
0`3oool08>`70?ooo`02023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo100Pk0L20?ooo`@08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00<08>`700D0oooo023/1`3o
ool08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo00D08>`700L0oooo023/1`0Pk0L08>`70?ooo`0P
k0L000000080oooo00<08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3o
ool08>`700D0oooo00<08>`70?ooo`3oool0=P3oool00`000000oooo0?ooo`0K0?ooo`006@3oool0
0`000000oooo0?ooo`0/0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool00P0Pk0L0
0`3oool08>`70?ooo`020?ooo`@08>`700<0oooo023/1`3oool00P3oool3023/1`030?ooo`0Pk0L0
oooo00X08>`70`3oool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700H0oooo
023/1`0Pk0L0oooo023/1`3oool4023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<0
8>`700<0oooo023/1`3oool00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700<0oooo023/
1`3oool01@0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`0000000P3oool00`0Pk0L0oooo023/
1`050?ooo`05023/1`3oool0oooo0?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/
1`3oool0oooo03H0oooo00<000000?ooo`3oool06`3oool001T0oooo00<000000?ooo`3oool0;03o
ool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo00808>`700<0oooo023/1`3oool00`3o
ool3023/1`030?ooo`0Pk0L0oooo0080oooo0`0Pk0L00`3oool08>`70?ooo`0:023/1`<0oooo00<0
8>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0
oooo100Pk0L20?ooo`@08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo
00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo00D08>`700L0oooo
023/1`0Pk0L08>`70?ooo`0Pk0L000000080oooo00<08>`70?ooo`0Pk0L01@3oool01@0Pk0L0oooo
0?ooo`3oool08>`70080oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`0f0?ooo`03
0000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02`0oooo00<08>`70?ooo`0Pk0L0
0`3oool00`0Pk0L0oooo0?ooo`02023/1`030?ooo`0Pk0L0oooo00<0oooo0`0Pk0L00`3oool08>`7
0?ooo`020?ooo`<08>`700<0oooo023/1`3oool02P0Pk0L30?ooo`03023/1`3oool08>`700808>`7
00<0oooo023/1`3oool00P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`@08>`70P3oool4023/
1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L0
8>`7023/1`3oool00P0Pk0L00`3oool08>`70?ooo`05023/1`070?ooo`0Pk0L08>`7023/1`3oool0
8>`7000000020?ooo`<08>`71@3oool01@0Pk0L0oooo0?ooo`3oool08>`70080oooo00<08>`70?oo
o`3oool00`3oool00`0Pk0L0oooo0?ooo`0f0?ooo`030000003oool0oooo01/0oooo000I0?ooo`03
0000003oool0oooo02`0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`02023/1`03
0?ooo`0Pk0L0oooo00<0oooo0`0Pk0L00`3oool08>`70?ooo`020?ooo`<08>`700<0oooo023/1`3o
ool00`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool0
8>`70?ooo`02023/1`040?ooo`0Pk0L08>`70?ooo`H08>`70P3oool4023/1`050?ooo`0Pk0L08>`7
023/1`3oool00`0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0P
k0L00`3oool08>`70?ooo`05023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`7000000020?ooo`<0
8>`71@3oool01@0Pk0L0oooo0?ooo`3oool08>`70080oooo00<08>`70?ooo`3oool00`3oool00`0P
k0L0oooo0?ooo`0f0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02`0
oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`02023/1`030?ooo`0Pk0L0oooo00<0
oooo0`0Pk0L00`3oool08>`70?ooo`020?ooo`<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool0
8>`7023/1`04023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`04
0?ooo`0Pk0L08>`70?ooo`H08>`70P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L0
0`3oool08>`7023/1`07023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo1@0Pk0L01`3oool08>`7
023/1`0Pk0L0oooo023/1`0000000P3oool3023/1`D0oooo00D08>`70?ooo`3oool0oooo023/1`02
0?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool0=P3oool00`000000oooo0?ooo`0K
0?ooo`006@3oool00`000000oooo0?ooo`0/0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?oo
o`3oool00P0Pk0L00`3oool08>`70?ooo`030?ooo`<08>`700<0oooo023/1`3oool00P3oool3023/
1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`03023/1`3oool08>`7
00808>`700<0oooo023/1`3oool00P0Pk0L0103oool08>`7023/1`3oool6023/1`80oooo100Pk0L0
1@3oool08>`7023/1`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L01`0Pk0L01P3oool08>`7023/
1`3oool08>`70?ooo`D08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L000000080oooo0`0Pk0L5
0?ooo`05023/1`3oool0oooo0?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3o
ool0oooo03H0oooo00<000000?ooo`3oool06`3oool001T0oooo00<000000?ooo`3oool0;03oool0
0`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo00808>`700<0oooo023/1`3oool00`3oool0
1@0Pk0L0oooo023/1`3oool08>`700<0oooo0`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0P
k0L08>`700@08>`70`3oool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700@0
oooo023/1`0Pk0L0oooo1P0Pk0L20?ooo`@08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`03
0?ooo`0Pk0L08>`700L08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool5023/1`070?ooo`0Pk0L0
8>`7023/1`3oool08>`7000000020?ooo`<08>`71@3oool01@0Pk0L0oooo0?ooo`3oool08>`70080
oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`0f0?ooo`030000003oool0oooo01/0
oooo000I0?ooo`030000003oool0oooo02`0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo
0?ooo`02023/1`030?ooo`0Pk0L0oooo00<0oooo00D08>`70?ooo`0Pk0L0oooo023/1`030?ooo`<0
8>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo00<08>`70?ooo`0P
k0L00P0Pk0L00`3oool08>`70?ooo`02023/1`040?ooo`0Pk0L08>`70?ooo`H08>`70P3oool4023/
1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`7023/1`07023/1`060?ooo`0Pk0L0
8>`70?ooo`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`03023/1`030000003oool0oooo00<08>`7
1@3oool01@0Pk0L0oooo0?ooo`3oool08>`70080oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0
oooo0?ooo`0f0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02`0oooo
00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`04023/1`@0oooo00D08>`70?ooo`0Pk0L0
oooo023/1`030?ooo`<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`04023/1`<0
oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`040?ooo`0Pk0L08>`70?oo
o`H08>`70P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`7023/1`07
023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`03023/1`030000
003oool0oooo00<08>`71@3oool01`0Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L01P3oool00`0P
k0L0oooo0?ooo`0f0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02`0
oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`04023/1`@0oooo00D08>`70?ooo`0P
k0L0oooo023/1`030?ooo`<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`04023/
1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`040?ooo`0Pk0L08>`7
0?ooo`H08>`70P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`7023/
1`07023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`03023/1`03
0000003oool0oooo00<08>`71@3oool01`0Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L01P3oool0
0`0Pk0L0oooo0?ooo`0f0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo
02`0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`04023/1`@0oooo00D08>`70?oo
o`0Pk0L0oooo023/1`030?ooo`<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`04
023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`040?ooo`0Pk0L0
8>`70?ooo`H08>`70P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`7
023/1`07023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`03023/
1`030000003oool0oooo00<08>`71@3oool01`0Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L01P3o
ool00`0Pk0L0oooo0?ooo`0f0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0
oooo02`0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`04023/1`@0oooo00D08>`7
0?ooo`0Pk0L0oooo023/1`030?ooo`<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/
1`04023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`040?ooo`0P
k0L08>`70?ooo`H08>`70P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool0
8>`7023/1`07023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`03
023/1`030000003oool0oooo00<08>`71@3oool01`0Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L0
1P3oool00`0Pk0L0oooo0?ooo`0f0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003o
ool0oooo02`0oooo00<08>`70?ooo`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`04023/1`@0oooo00D0
8>`70?ooo`0Pk0L0oooo023/1`030?ooo`<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7
023/1`04023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`040?oo
o`0Pk0L08>`70?ooo`H08>`70P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3o
ool08>`7023/1`07023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700<0oooo023/1`0Pk0L00`0Pk0L0
0`000000oooo0?ooo`03023/1`D0oooo00L08>`70?ooo`3oool0oooo023/1`3oool08>`700H0oooo
00<08>`70?ooo`3oool0=P3oool00`000000oooo0?ooo`0K0?ooo`006@3oool00`000000oooo0?oo
o`0/0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`3oool0100Pk0L40?ooo`05023/1`3o
ool08>`70?ooo`0Pk0L00`3oool3023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L0
100Pk0L30?ooo`03023/1`3oool08>`700808>`700<0oooo023/1`3oool00P0Pk0L0103oool08>`7
023/1`3oool6023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`700<0oooo023/
1`0Pk0L02P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700<08>`700<000000?oo
o`3oool00`0Pk0L50?ooo`07023/1`3oool0oooo0?ooo`0Pk0L0oooo023/1`060?ooo`03023/1`3o
ool0oooo03H0oooo00<000000?ooo`3oool06`3oool001T0oooo00<000000?ooo`3oool0;03oool0
0`0Pk0L0oooo023/1`030?ooo`03023/1`3oool0oooo00@08>`7103oool01@0Pk0L0oooo023/1`3o
ool08>`700<0oooo0`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700@08>`70`3o
ool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo
1P0Pk0L20?ooo`@08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700X0
8>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`03023/1`030000003oool0oooo00<0
8>`71@3oool01`0Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L01P3oool00`0Pk0L0oooo0?ooo`0f
0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02`0oooo00<08>`70?oo
o`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`04023/1`@0oooo00D08>`70?ooo`0Pk0L0oooo023/1`03
0?ooo`<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo00<08>`7
0?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`040?ooo`0Pk0L08>`70?ooo`H08>`70P3o
ool4023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00P0
8>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`03023/1`030000003oool0oooo00<0
8>`71@3oool01`0Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L01P3oool00`0Pk0L0oooo0?ooo`0f
0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02`0oooo00<08>`70?oo
o`0Pk0L00`3oool00`0Pk0L0oooo023/1`04023/1`@0oooo00D08>`70?ooo`0Pk0L0oooo023/1`03
0?ooo`<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo00<08>`7
0?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo
100Pk0L20?ooo`@08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`050?ooo`0Pk0L08>`7023/
1`3oool0200Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700<08>`700<000000?oo
o`3oool00`0Pk0L50?ooo`07023/1`3oool0oooo0?ooo`0Pk0L0oooo023/1`050?ooo`03023/1`3o
ool0oooo03L0oooo00<000000?ooo`3oool06`3oool001T0oooo00<000000?ooo`3oool0;03oool0
0`0Pk0L0oooo023/1`030?ooo`03023/1`3oool08>`700@08>`7103oool01@0Pk0L0oooo023/1`3o
ool08>`700<0oooo0`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700@08>`70`3o
ool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700H0oooo023/1`0Pk0L0oooo
023/1`3oool4023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`700D0oooo023/
1`0Pk0L08>`70?ooo`08023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L00`0Pk0L0
0`000000oooo0?ooo`03023/1`D0oooo00L08>`70?ooo`3oool0oooo023/1`3oool08>`700D0oooo
00<08>`70?ooo`3oool0=`3oool00`000000oooo0?ooo`0K0?ooo`006@3oool00`000000oooo0?oo
o`0/0?ooo`03023/1`3oool08>`700<0oooo00<08>`70?ooo`0Pk0L0100Pk0L40?ooo`05023/1`3o
ool08>`70?ooo`0Pk0L00`3oool3023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L0
100Pk0L30?ooo`03023/1`3oool08>`700808>`700<0oooo023/1`3oool00P0Pk0L0103oool08>`7
023/1`3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0
oooo00L08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L0
8>`700<08>`700<000000?ooo`3oool00`0Pk0L50?ooo`07023/1`3oool0oooo0?ooo`0Pk0L0oooo
023/1`050?ooo`03023/1`3oool0oooo03L0oooo00<000000?ooo`3oool06`3oool001T0oooo00<0
00000?ooo`3oool0;03oool00`0Pk0L0oooo023/1`040?ooo`H08>`7103oool01@0Pk0L0oooo023/
1`3oool08>`700<0oooo0`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700@08>`7
0`3oool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0
oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`@08>`700D0oooo023/1`0Pk0L08>`70?ooo`07
023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`03
023/1`030000003oool0oooo00<08>`71@3oool01`0Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L0
1@3oool00`0Pk0L0oooo0?ooo`0g0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003o
ool0oooo02d0oooo0P0Pk0L40?ooo`H08>`7103oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3o
ool0oooo00<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo00<0
8>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`05023/1`040?ooo`0Pk0L08>`70?ooo`<08>`7
0P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L0103oool08>`7023/1`3oool7023/
1`030?ooo`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L00`0Pk0L010000000oooo023/1`3oool2
023/1`D0oooo00L08>`70?ooo`3oool0oooo023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool0
=`3oool00`000000oooo0?ooo`0K0?ooo`006@3oool00`000000oooo0?ooo`0]0?ooo`808>`7103o
ool6023/1`@0oooo00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`03023/1`030?ooo`0P
k0L0oooo00<08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`03023/1`3oool08>`700808>`700<0
oooo023/1`3oool01@0Pk0L0103oool08>`7023/1`3oool3023/1`80oooo100Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00@08>`700@0oooo023/1`0Pk0L0oooo1`0Pk0L00`3oool08>`70?ooo`06023/
1`030?ooo`0Pk0L08>`700<08>`700@000000?ooo`0Pk0L0oooo0P0Pk0L50?ooo`04023/1`3oool0
oooo023/1`80oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`0g0?ooo`030000003o
ool0oooo01/0oooo000I0?ooo`030000003oool0oooo02d0oooo0P0Pk0L40?ooo`H08>`7103oool0
0`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`3oool00`0Pk0L0
0`3oool08>`7023/1`04023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`05
023/1`040?ooo`0Pk0L08>`70?ooo`<08>`70P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool0
100Pk0L0103oool08>`7023/1`3oool7023/1`030?ooo`0Pk0L0oooo00H08>`700<0oooo023/1`0P
k0L00`0Pk0L010000000oooo023/1`3oool2023/1`D0oooo00@08>`70?ooo`3oool08>`70P3oool0
0`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo03L0oooo00<000000?ooo`3oool06`3oool0
01T0oooo00<000000?ooo`3oool0;@3oool2023/1`@0oooo1P0Pk0L40?ooo`03023/1`3oool08>`7
0080oooo00<08>`70?ooo`3oool00`0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool01P0P
k0L30?ooo`03023/1`3oool08>`700808>`700<0oooo023/1`3oool01@0Pk0L0103oool08>`7023/
1`3oool3023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`700@0oooo023/1`0P
k0L0oooo1`0Pk0L00`3oool08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700<08>`700@000000?oo
o`0Pk0L0oooo0P0Pk0L50?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool00`3o
ool00`0Pk0L0oooo0?ooo`0g0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0
oooo02d0oooo0P0Pk0L40?ooo`H08>`7103oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0
oooo00<08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00H08>`70`3oool00`0Pk0L0oooo
023/1`02023/1`030?ooo`0Pk0L0oooo00D08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L20?ooo`@0
8>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700<0oooo
023/1`3oool01P0Pk0L00`3oool08>`7023/1`03023/1`040000003oool08>`70?ooo`808>`71@3o
ool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool0
=`3oool00`000000oooo0?ooo`0K0?ooo`006@3oool00`000000oooo0?ooo`0]0?ooo`808>`7103o
ool6023/1`@0oooo00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`03023/1`070?ooo`0P
k0L0oooo023/1`3oool08>`70?ooo`06023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool0
8>`70?ooo`05023/1`040?ooo`0Pk0L08>`70?ooo`<08>`70P3oool3023/1`80oooo0`0Pk0L00`3o
ool08>`7023/1`02023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700<0oooo023/1`3oool01P0Pk0L0
0`3oool08>`7023/1`03023/1`040000003oool08>`70?ooo`808>`7103oool01@0Pk0L0oooo0?oo
o`3oool08>`70080oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`0g0?ooo`030000
003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02d0oooo0P0Pk0L40?ooo`03023/1`3o
ool08>`700<08>`7103oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo00<08>`700L0
oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00H08>`70`3oool00`0Pk0L0oooo023/1`02023/1`03
0?ooo`0Pk0L0oooo00D08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L20?ooo`<08>`70P3oool2023/
1`80oooo100Pk0L0103oool08>`7023/1`3oool7023/1`030?ooo`0Pk0L0oooo00H08>`700<0oooo
023/1`0Pk0L00`0Pk0L010000000oooo023/1`3oool2023/1`@0oooo00D08>`70?ooo`3oool0oooo
023/1`020?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool0=`3oool00`000000oooo
0?ooo`0K0?ooo`006@3oool00`000000oooo0?ooo`0]0?ooo`808>`7103oool00`0Pk0L0oooo023/
1`03023/1`@0oooo00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`03023/1`070?ooo`0P
k0L0oooo023/1`3oool08>`70?ooo`06023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool0
8>`70?ooo`05023/1`040?ooo`0Pk0L08>`70?ooo`<08>`70P3oool3023/1`80oooo0P0Pk0L20?oo
o`@08>`700@0oooo023/1`0Pk0L0oooo1`0Pk0L00`3oool08>`70?ooo`0<023/1`040000003oool0
8>`70?ooo`808>`7103oool01@0Pk0L0oooo0?ooo`3oool08>`70080oooo00<08>`70?ooo`3oool0
0`3oool00`0Pk0L0oooo0?ooo`0g0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003o
ool0oooo02d0oooo0P0Pk0L40?ooo`03023/1`3oool08>`700<08>`7103oool00`0Pk0L0oooo023/
1`020?ooo`03023/1`3oool0oooo00<08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00H0
8>`70`3oool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo00D08>`700@0oooo023/1`0P
k0L0oooo0`0Pk0L20?ooo`<08>`70P3oool2023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/
1`0Pk0L0oooo1`0Pk0L00`3oool08>`70?ooo`0<023/1`040000003oool08>`70?ooo`808>`7103o
ool01@0Pk0L0oooo0?ooo`3oool08>`70080oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo
0?ooo`0g0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02d0oooo0P0P
k0L40?ooo`03023/1`3oool08>`700<08>`7103oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3o
ool0oooo00<08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00H08>`70`3oool00`0Pk0L0
oooo023/1`02023/1`030?ooo`0Pk0L0oooo00P08>`700@0oooo023/1`0Pk0L08>`70P3oool3023/
1`80oooo0P0Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700<0oooo
023/1`3oool0300Pk0L010000000oooo023/1`3oool2023/1`@0oooo00L08>`70?ooo`3oool0oooo
023/1`3oool08>`700H0oooo00<08>`70?ooo`3oool0=`3oool00`000000oooo0?ooo`0K0?ooo`00
6@3oool00`000000oooo0?ooo`0]0?ooo`808>`7103oool00`0Pk0L0oooo023/1`03023/1`@0oooo
00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`03023/1`070?ooo`0Pk0L0oooo023/1`3o
ool08>`70?ooo`06023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`08023/
1`040?ooo`0Pk0L08>`7023/1`80oooo0`0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00`0Pk0L0
103oool08>`7023/1`3oool7023/1`030?ooo`0Pk0L0oooo00`08>`700@000000?ooo`0Pk0L0oooo
0P0Pk0L40?ooo`07023/1`3oool0oooo0?ooo`0Pk0L0oooo023/1`060?ooo`03023/1`3oool0oooo
03L0oooo00<000000?ooo`3oool06`3oool001T0oooo00<000000?ooo`3oool0;@3oool2023/1`@0
oooo00<08>`70?ooo`0Pk0L00`0Pk0L40?ooo`<08>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`07
0?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`06023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L0
0`3oool08>`70?ooo`08023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0`0Pk0L20?ooo`808>`7
00<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool7023/1`030?ooo`0Pk0L0oooo00`0
8>`700@000000?ooo`0Pk0L0oooo0P0Pk0L40?ooo`07023/1`3oool0oooo0?ooo`0Pk0L0oooo023/
1`060?ooo`03023/1`3oool0oooo03L0oooo00<000000?ooo`3oool06`3oool001T0oooo00<00000
0?ooo`3oool0;@3oool00`0Pk0L0oooo023/1`030?ooo`03023/1`3oool08>`700<08>`71@3oool2
023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool0
1P0Pk0L30?ooo`03023/1`3oool08>`700808>`700<0oooo023/1`3oool0200Pk0L01P3oool08>`7
023/1`3oool08>`70?ooo`<08>`70P3oool2023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/
1`0Pk0L0oooo1`0Pk0L00`3oool08>`70?ooo`0<023/1`040000003oool08>`70?ooo`808>`7103o
ool01`0Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L01P3oool00`0Pk0L0oooo0?ooo`0g0?ooo`03
0000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02d0oooo00<08>`70?ooo`0Pk0L0
0`3oool00`0Pk0L0oooo023/1`03023/1`D0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00<08>`7
00L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00H08>`70`3oool00`0Pk0L0oooo023/1`02023/
1`030?ooo`0Pk0L0oooo00P08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool3023/1`80oooo0P0P
k0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700<0oooo023/1`3oool0
300Pk0L010000000oooo023/1`3oool2023/1`@0oooo00L08>`70?ooo`3oool0oooo023/1`3oool0
8>`700H0oooo00<08>`70?ooo`3oool0=`3oool00`000000oooo0?ooo`0K0?ooo`006@3oool00`00
0000oooo0?ooo`0]0?ooo`03023/1`3oool08>`700<0oooo00H08>`70?ooo`3oool08>`70?ooo`0P
k0L50?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`070?ooo`0Pk0L0oooo023/1`3oool0
8>`70?ooo`06023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`08023/1`06
0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0`0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00`0Pk0L0
103oool08>`7023/1`3oool7023/1`030?ooo`0Pk0L0oooo00`08>`700@000000?ooo`0Pk0L0oooo
0P0Pk0L40?ooo`07023/1`3oool0oooo0?ooo`0Pk0L0oooo023/1`060?ooo`03023/1`3oool0oooo
03L0oooo00<000000?ooo`3oool06`3oool001T0oooo00<000000?ooo`3oool0;@3oool00`0Pk0L0
oooo023/1`030?ooo`06023/1`3oool0oooo023/1`3oool08>`71@3oool2023/1`80oooo00<08>`7
0?ooo`3oool00`0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool01P0Pk0L30?ooo`03023/
1`3oool08>`700808>`700<0oooo023/1`3oool0200Pk0L01P3oool08>`7023/1`3oool08>`70?oo
o`<08>`70P3oool2023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo1`0Pk0L0
0`3oool08>`70?ooo`0<023/1`040000003oool08>`70?ooo`808>`7103oool01`0Pk0L0oooo0?oo
o`3oool08>`70?ooo`0Pk0L01P3oool00`0Pk0L0oooo0?ooo`0g0?ooo`030000003oool0oooo01/0
oooo000I0?ooo`030000003oool0oooo02d0oooo00<08>`70?ooo`0Pk0L00`3oool01P0Pk0L0oooo
0?ooo`0Pk0L0oooo023/1`D0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00<08>`700L0oooo023/
1`3oool08>`70?ooo`0Pk0L0oooo00H08>`70`3oool00`0Pk0L0oooo023/1`02023/1`030?ooo`0P
k0L0oooo00P08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool3023/1`80oooo0P0Pk0L00`3oool0
8>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700<0oooo023/1`3oool02`0Pk0L01@3o
ool000000?ooo`0Pk0L0oooo00808>`7103oool01`0Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L0
1P3oool00`0Pk0L0oooo0?ooo`0g0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003o
ool0oooo02d0oooo00<08>`70?ooo`0Pk0L00P3oool2023/1`80oooo00<08>`70?ooo`0Pk0L01@3o
ool3023/1`040?ooo`0Pk0L0oooo0?ooo`<08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo
00H08>`70`3oool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo00P08>`700H0oooo023/
1`0Pk0L0oooo023/1`3oool3023/1`80oooo0P0Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0P
k0L08>`70?ooo`L08>`700<0oooo023/1`3oool02`0Pk0L01@3oool000000?ooo`0Pk0L0oooo0080
8>`7103oool01`0Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L01P3oool00`0Pk0L0oooo0?ooo`0g
0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02d0oooo00<08>`70?oo
o`0Pk0L00P3oool2023/1`80oooo00<08>`70?ooo`0Pk0L01@3oool3023/1`040?ooo`0Pk0L0oooo
0?ooo`<08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00H08>`70`3oool00`0Pk0L0oooo
023/1`02023/1`030?ooo`0Pk0L0oooo00P08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool3023/
1`80oooo0P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/
1`3oool02`0Pk0L01P3oool000000?ooo`0Pk0L0oooo023/1`D0oooo00L08>`70?ooo`3oool0oooo
023/1`3oool08>`700H0oooo00<08>`70?ooo`3oool0=`3oool00`000000oooo0?ooo`0K0?ooo`00
6@3oool00`000000oooo0?ooo`0]0?ooo`03023/1`3oool08>`70080oooo0P0Pk0L20?ooo`03023/
1`3oool08>`700D0oooo0`0Pk0L0103oool08>`70?ooo`3oool3023/1`070?ooo`0Pk0L0oooo023/
1`3oool08>`70?ooo`06023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`08
023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0`0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L0
0`0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L0
1P0Pk0L01P3oool000000?ooo`0Pk0L0oooo023/1`D0oooo00L08>`70?ooo`3oool0oooo023/1`3o
ool08>`700H0oooo00<08>`70?ooo`3oool0=`3oool00`000000oooo0?ooo`0K0?ooo`006@3oool0
0`000000oooo0?ooo`0]0?ooo`03023/1`3oool08>`70080oooo0P0Pk0L20?ooo`03023/1`3oool0
8>`700D0oooo0`0Pk0L0103oool08>`70?ooo`3oool3023/1`070?ooo`0Pk0L0oooo023/1`3oool0
8>`70?ooo`06023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`08023/1`06
0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0`0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00`0Pk0L0
0`3oool08>`7023/1`08023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L01P0Pk0L0
1P3oool000000?ooo`0Pk0L0oooo023/1`D0oooo00L08>`70?ooo`3oool0oooo023/1`3oool08>`7
00H0oooo00<08>`70?ooo`3oool0=`3oool00`000000oooo0?ooo`0K0?ooo`006@3oool00`000000
oooo0?ooo`0]0?ooo`03023/1`3oool08>`70080oooo0P0Pk0L20?ooo`03023/1`3oool08>`700D0
oooo0`0Pk0L0103oool08>`70?ooo`3oool3023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?oo
o`06023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`05023/1`040?ooo`0P
k0L08>`70?ooo`808>`700<0oooo023/1`3oool00`0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L0
0`0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L0
1P0Pk0L01P3oool000000?ooo`0Pk0L0oooo023/1`D0oooo00L08>`70?ooo`3oool0oooo023/1`3o
ool08>`700H0oooo00<08>`70?ooo`3oool0=`3oool00`000000oooo0?ooo`0K0?ooo`006@3oool0
0`000000oooo0?ooo`0]0?ooo`03023/1`3oool08>`70080oooo0P0Pk0L20?ooo`03023/1`3oool0
8>`700D0oooo0`0Pk0L0103oool08>`70?ooo`3oool3023/1`070?ooo`0Pk0L0oooo023/1`3oool0
8>`70?ooo`06023/1`<0oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`7023/1`06023/1`06
0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0`0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00`0Pk0L0
0`3oool08>`7023/1`08023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00`0Pk0L0
2@3oool08>`7023/1`3oool000000?ooo`0Pk0L0oooo023/1`050?ooo`04023/1`3oool0oooo023/
1`80oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`0g0?ooo`030000003oool0oooo
01/0oooo000I0?ooo`030000003oool0oooo02d0oooo00<08>`70?ooo`0Pk0L00P3oool2023/1`80
oooo00<08>`70?ooo`0Pk0L01@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`<08>`700L0oooo023/
1`3oool08>`70?ooo`0Pk0L0oooo00H08>`70`3oool00`0Pk0L0oooo023/1`04023/1`030?ooo`0P
k0L08>`700H08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool3023/1`80oooo0P0Pk0L00`3oool0
8>`7023/1`03023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool0
8>`7023/1`03023/1`060?ooo`0Pk0L08>`70?ooo`000000oooo0`0Pk0L50?ooo`04023/1`3oool0
oooo023/1`80oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`0g0?ooo`030000003o
ool0oooo01/0oooo000I0?ooo`030000003oool0oooo02d0oooo00<08>`70?ooo`0Pk0L00P3oool2
023/1`80oooo00<08>`70?ooo`0Pk0L01@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`<08>`700L0
oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00H08>`70`3oool00`0Pk0L0oooo023/1`04023/1`03
0?ooo`0Pk0L08>`700H08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool3023/1`80oooo0P0Pk0L0
0`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L00P0Pk0L0
0`3oool08>`7023/1`04023/1`050?ooo`0Pk0L0oooo0000003oool00`0Pk0L50?ooo`04023/1`3o
ool0oooo023/1`80oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`0h0?ooo`030000
003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02d0oooo00<08>`70?ooo`0Pk0L00P3o
ool2023/1`80oooo00<08>`70?ooo`0Pk0L01@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`<08>`7
00L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00H08>`70`3oool00`0Pk0L0oooo023/1`04023/
1`030?ooo`0Pk0L08>`700H08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool3023/1`80oooo0P0P
k0L00`3oool08>`7023/1`0>023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L0100P
k0L01P3oool08>`70?ooo`0000008>`70?ooo`808>`71@3oool0100Pk0L0oooo0?ooo`0Pk0L20?oo
o`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool0>03oool00`000000oooo0?ooo`0K0?oo
o`006@3oool00`000000oooo0?ooo`0]0?ooo`03023/1`3oool08>`70080oooo0P0Pk0L20?ooo`03
023/1`3oool08>`700D0oooo0`0Pk0L0103oool08>`70?ooo`3oool3023/1`070?ooo`0Pk0L0oooo
023/1`3oool08>`70?ooo`06023/1`<0oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`7023/
1`06023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0`0Pk0L20?ooo`808>`700<0oooo023/1`0P
k0L03P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700@08>`700H0oooo023/1`3o
ool00000023/1`3oool2023/1`D0oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0oooo0?oo
o`030?ooo`03023/1`3oool0oooo03P0oooo00<000000?ooo`3oool06`3oool001T0oooo00<00000
0?ooo`3oool0;@3oool01`0Pk0L0oooo023/1`3oool08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo
023/1`050?ooo`<08>`700@0oooo023/1`3oool0oooo0`0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo
023/1`3oool01P0Pk0L30?ooo`03023/1`3oool08>`700@08>`700<0oooo023/1`0Pk0L01P0Pk0L0
1P3oool08>`7023/1`3oool08>`70?ooo`<08>`70P3oool2023/1`030?ooo`0Pk0L08>`700h08>`7
00<0oooo023/1`0Pk0L02@0Pk0L01P3oool08>`70?ooo`0000008>`70?ooo`808>`71@3oool0100P
k0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool0>03oool0
0`000000oooo0?ooo`0K0?ooo`006@3oool00`000000oooo0?ooo`0]0?ooo`07023/1`3oool08>`7
0?ooo`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700D0oooo0`0Pk0L0103oool08>`70?oo
o`3oool3023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`06023/1`<0oooo00<08>`70?oo
o`0Pk0L0100Pk0L00`3oool08>`7023/1`06023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0`0P
k0L20?ooo`808>`700@0oooo023/1`0Pk0L0oooo3@0Pk0L00`3oool08>`7023/1`03023/1`030?oo
o`0Pk0L0oooo00<08>`700H0oooo023/1`3oool00000023/1`3oool2023/1`D0oooo00@08>`70?oo
o`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo03P0oooo00<00000
0?ooo`3oool06`3oool001T0oooo00<000000?ooo`3oool0;@3oool01`0Pk0L0oooo023/1`3oool0
8>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo023/1`0Pk0L40?ooo`<08>`700@0oooo023/1`3oool0
oooo0`0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool01P0Pk0L30?ooo`03023/1`3oool0
8>`700@08>`700<0oooo023/1`0Pk0L01P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`<08>`7
0P3oool2023/1`040?ooo`0Pk0L08>`70?ooo`P08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool0
8>`7023/1`03023/1`030?ooo`0Pk0L0oooo00<08>`700H0oooo023/1`3oool00000023/1`3oool2
023/1`D0oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L60?ooo`03023/1`3oool0oooo03P0oooo
00<000000?ooo`3oool06`3oool001T0oooo00<000000?ooo`3oool0;@3oool01`0Pk0L0oooo023/
1`3oool08>`70?ooo`0Pk0L00P3oool0100Pk0L0oooo023/1`0Pk0L40?ooo`<08>`700@0oooo023/
1`3oool0oooo0`0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool01P0Pk0L30?ooo`03023/
1`3oool08>`700@08>`700<0oooo023/1`0Pk0L01P0Pk0L01P3oool08>`7023/1`3oool08>`70?oo
o`<08>`70P3oool2023/1`040?ooo`0Pk0L08>`70?ooo`P08>`700<0oooo023/1`0Pk0L00P0Pk0L0
0`3oool08>`7023/1`05023/1`0:0?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`0000008>`70?oo
o`808>`71@3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`H0oooo00<08>`70?ooo`3oool0>03o
ool00`000000oooo0?ooo`0K0?ooo`006@3oool00`000000oooo0?ooo`0]0?ooo`07023/1`3oool0
8>`70?ooo`0Pk0L0oooo023/1`020?ooo`04023/1`3oool08>`7023/1`@0oooo0`0Pk0L0103oool0
8>`70?ooo`3oool3023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`06023/1`<0oooo00<0
8>`70?ooo`0Pk0L0100Pk0L00`3oool08>`7023/1`06023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0
oooo0`0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L0oooo200Pk0L00`3oool08>`7023/1`03023/
1`030?ooo`0Pk0L08>`700@08>`700X0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo0000000Pk0L0
oooo0P0Pk0L50?ooo`06023/1`3oool0oooo023/1`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`0h
0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02d0oooo00L08>`70?oo
o`0Pk0L0oooo023/1`3oool08>`70080oooo00@08>`70?ooo`0Pk0L08>`7103oool3023/1`040?oo
o`0Pk0L0oooo0?ooo`<08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00H08>`70`3oool0
0`0Pk0L0oooo023/1`04023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo1@0P
k0L20?ooo`808>`700@0oooo023/1`0Pk0L0oooo200Pk0L00`3oool08>`7023/1`03023/1`030?oo
o`0Pk0L08>`700@08>`700X0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo0000000Pk0L0oooo0P0P
k0L50?ooo`06023/1`3oool0oooo023/1`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`0h0?ooo`03
0000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02d0oooo00L08>`70?ooo`0Pk0L0
oooo023/1`3oool08>`70080oooo00@08>`70?ooo`0Pk0L08>`7103oool3023/1`040?ooo`0Pk0L0
oooo0?ooo`<08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00H08>`70`3oool00`0Pk0L0
oooo023/1`04023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L20?oo
o`808>`700@0oooo023/1`0Pk0L0oooo200Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0
8>`700@08>`700X0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo0000000Pk0L0oooo0P0Pk0L50?oo
o`06023/1`3oool0oooo023/1`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`0h0?ooo`030000003o
ool0oooo01/0oooo000I0?ooo`030000003oool0oooo02d0oooo00L08>`70?ooo`0Pk0L0oooo023/
1`3oool08>`70080oooo00@08>`70?ooo`0Pk0L08>`7103oool3023/1`040?ooo`0Pk0L0oooo0?oo
o`<08>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00H08>`70`3oool00`0Pk0L0oooo023/
1`04023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L20?ooo`808>`7
00@0oooo023/1`0Pk0L0oooo200Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700@0
8>`700X0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo0000000Pk0L0oooo0P0Pk0L50?ooo`06023/
1`3oool0oooo023/1`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`0h0?ooo`030000003oool0oooo
01/0oooo000I0?ooo`030000003oool0oooo02d0oooo00L08>`70?ooo`0Pk0L0oooo023/1`3oool0
8>`70080oooo00@08>`70?ooo`0Pk0L08>`7103oool3023/1`040?ooo`0Pk0L0oooo0?ooo`<08>`7
00L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00H08>`70`3oool00`0Pk0L0oooo023/1`04023/
1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L20?ooo`808>`700@0oooo
023/1`0Pk0L0oooo200Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700X08>`700@0
oooo0000000Pk0L0oooo0P0Pk0L50?ooo`06023/1`3oool0oooo023/1`3oool08>`71P3oool00`0P
k0L0oooo0?ooo`0h0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02d0
oooo00L08>`70?ooo`0Pk0L0oooo023/1`3oool08>`70080oooo00@08>`70?ooo`0Pk0L08>`7103o
ool3023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3o
ool01P0Pk0L30?ooo`03023/1`3oool08>`700@08>`700<0oooo023/1`0Pk0L01P0Pk0L0103oool0
8>`7023/1`3oool5023/1`80oooo0P0Pk0L0103oool08>`7023/1`3oool8023/1`030?ooo`0Pk0L0
8>`700<08>`700<0oooo023/1`0Pk0L02P0Pk0L0103oool00000023/1`3oool2023/1`D0oooo00H0
8>`70?ooo`3oool08>`70?ooo`0Pk0L60?ooo`03023/1`3oool0oooo03P0oooo00<000000?ooo`3o
ool06`3oool001T0oooo00<000000?ooo`3oool0;@3oool0100Pk0L0oooo023/1`0Pk0L20?ooo`05
023/1`3oool0oooo023/1`3oool00P0Pk0L40?ooo`<08>`70P3oool00`0Pk0L0oooo023/1`02023/
1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`06023/1`<0oooo00<08>`70?ooo`0Pk0L0100P
k0L00`3oool08>`7023/1`06023/1`040?ooo`0Pk0L08>`70?ooo`D08>`70P3oool2023/1`040?oo
o`0Pk0L08>`70?ooo`P08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`0:023/1`04
0?ooo`0000008>`70?ooo`808>`71@3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`H0oooo00<0
8>`70?ooo`3oool0>03oool00`000000oooo0?ooo`0K0?ooo`006@3oool00`000000oooo0?ooo`0]
0?ooo`04023/1`3oool08>`7023/1`80oooo00D08>`70?ooo`3oool08>`70?ooo`02023/1`@0oooo
0`0Pk0L20?ooo`03023/1`3oool08>`700808>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo
00H08>`70`3oool00`0Pk0L0oooo023/1`04023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/
1`0Pk0L0oooo1@0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L0oooo200Pk0L00`3oool08>`7023/
1`03023/1`030?ooo`0Pk0L08>`700X08>`700@0oooo0000000Pk0L0oooo0P0Pk0L50?ooo`06023/
1`3oool0oooo023/1`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`0h0?ooo`030000003oool0oooo
01/0oooo000I0?ooo`030000003oool0oooo02d0oooo00@08>`70?ooo`0Pk0L08>`70P3oool00`0P
k0L0oooo0?ooo`04023/1`@0oooo0`0Pk0L20?ooo`03023/1`3oool08>`700808>`700L0oooo023/
1`3oool08>`70?ooo`0Pk0L0oooo00L08>`70P3oool00`0Pk0L0oooo023/1`04023/1`030?ooo`0P
k0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L0
oooo200Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700X08>`700@0oooo0000000P
k0L0oooo0P0Pk0L50?ooo`06023/1`3oool0oooo023/1`3oool08>`71P3oool00`0Pk0L0oooo0?oo
o`0h0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02d0oooo00@08>`7
0?ooo`0Pk0L08>`70P3oool00`0Pk0L0oooo0?ooo`04023/1`@0oooo0`0Pk0L20?ooo`03023/1`3o
ool08>`700808>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00L08>`70P3oool00`0Pk0L0
oooo023/1`04023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L20?oo
o`808>`700@0oooo023/1`0Pk0L0oooo200Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0
8>`700X08>`700@0oooo0000000Pk0L0oooo0P0Pk0L40?ooo`07023/1`3oool0oooo0?ooo`0Pk0L0
oooo023/1`060?ooo`03023/1`3oool0oooo03P0oooo00<000000?ooo`3oool06`3oool001T0oooo
00<000000?ooo`3oool0;P3oool3023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L00`3oool08>`7
0?ooo`030?ooo`<08>`70P3oool00`0Pk0L0oooo023/1`02023/1`070?ooo`0Pk0L0oooo023/1`3o
ool08>`70?ooo`07023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`7023/1`06023/
1`040?ooo`0Pk0L08>`70?ooo`D08>`70P3oool2023/1`040?ooo`0Pk0L08>`70?ooo`P08>`700<0
oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`0:023/1`040?ooo`0000008>`70?ooo`808>`7
103oool01`0Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L01P3oool00`0Pk0L0oooo0?ooo`0h0?oo
o`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02h0oooo0`0Pk0L20?ooo`03
023/1`3oool0oooo00808>`700<0oooo023/1`3oool0103oool2023/1`80oooo00<08>`70?ooo`3o
ool00P0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool01`0Pk0L20?ooo`03023/1`3oool0
8>`700@08>`700<0oooo023/1`0Pk0L01P0Pk0L0103oool08>`7023/1`3oool5023/1`80oooo0P0P
k0L0103oool08>`7023/1`3oool8023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L0
2P0Pk0L0103oool00000023/1`3oool2023/1`@0oooo00@08>`70?ooo`3oool08>`70P3oool00`0P
k0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo03P0oooo00<000000?ooo`3oool06`3oool001T0
oooo00<000000?ooo`3oool0;P3oool3023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L00`3oool0
8>`70?ooo`040?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`070?ooo`0Pk0L0oooo023/
1`3oool08>`70?ooo`07023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`7023/1`06
023/1`040?ooo`0Pk0L08>`70?ooo`D08>`70P3oool2023/1`040?ooo`0Pk0L08>`70?ooo`P08>`7
00<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`0:023/1`040?ooo`0000008>`70?ooo`80
8>`7103oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?oo
o`3oool0>03oool00`000000oooo0?ooo`0K0?ooo`006@3oool00`000000oooo0?ooo`0^0?ooo`<0
8>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`030?ooo`0Pk0L0oooo00@0oooo0P0Pk0L20?ooo`03
023/1`3oool0oooo00808>`700L0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo00L08>`70P3oool0
0`0Pk0L0oooo023/1`04023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo1@0P
k0L20?ooo`808>`700H0oooo023/1`0Pk0L0oooo023/1`3oool6023/1`030?ooo`0Pk0L08>`700<0
8>`700<0oooo023/1`0Pk0L02P0Pk0L0103oool00000023/1`3oool2023/1`@0oooo00@08>`70?oo
o`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo03P0oooo00<00000
0?ooo`3oool06`3oool001T0oooo00<000000?ooo`3oool0;P3oool3023/1`80oooo00<08>`70?oo
o`3oool00P0Pk0L00`3oool08>`70?ooo`040?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`02023/
1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`07023/1`80oooo00<08>`70?ooo`0Pk0L0100P
k0L00`3oool08>`7023/1`06023/1`040?ooo`0Pk0L08>`70?ooo`D08>`70P3oool2023/1`060?oo
o`0Pk0L08>`70?ooo`0Pk0L0oooo1P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`7
00X08>`700@0oooo0000000Pk0L0oooo0P0Pk0L40?ooo`04023/1`3oool0oooo023/1`80oooo00<0
8>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`0h0?ooo`030000003oool0oooo01/0oooo000I
0?ooo`030000003oool0oooo02h0oooo0`0Pk0L20?ooo`03023/1`3oool0oooo00808>`700<0oooo
023/1`3oool0103oool2023/1`80oooo00<08>`70?ooo`3oool00P0Pk0L01`3oool08>`70?ooo`0P
k0L0oooo023/1`3oool01`0Pk0L20?ooo`03023/1`3oool08>`700@08>`700<0oooo023/1`0Pk0L0
1P0Pk0L0103oool08>`7023/1`3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700H0oooo023/
1`0Pk0L0oooo023/1`3oool6023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L02P0P
k0L0103oool00000023/1`3oool2023/1`@0oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0
oooo0?ooo`040?ooo`03023/1`3oool0oooo03P0oooo00<000000?ooo`3oool06`3oool001T0oooo
00<000000?ooo`3oool0;P3oool3023/1`<0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L50?oo
o`808>`70P3oool00`0Pk0L0oooo0?ooo`02023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?oo
o`07023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`7023/1`06023/1`040?ooo`0P
k0L08>`70?ooo`D08>`70P3oool2023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo1P0Pk0L00`3o
ool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700X08>`700@0oooo0000000Pk0L0oooo0P0Pk0L4
0?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?oo
o`0h0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02h0oooo0P0Pk0L4
0?ooo`06023/1`3oool08>`7023/1`3oool08>`71@3oool2023/1`80oooo00<08>`70?ooo`3oool0
0P0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool01`0Pk0L20?ooo`03023/1`3oool08>`7
00@08>`700<0oooo023/1`3oool01P0Pk0L0103oool08>`7023/1`3oool5023/1`80oooo0P0Pk0L0
1P3oool08>`7023/1`3oool08>`70?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7
023/1`0:023/1`040?ooo`0000008>`70?ooo`808>`7103oool0100Pk0L0oooo0?ooo`0Pk0L20?oo
o`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3oool0>03oool00`000000oooo0?ooo`0K0?oo
o`006@3oool00`000000oooo0?ooo`0^0?ooo`808>`7103oool01P0Pk0L0oooo023/1`0Pk0L0oooo
023/1`D0oooo0`0Pk0L0103oool08>`70?ooo`3oool2023/1`070?ooo`0Pk0L0oooo023/1`3oool0
8>`70?ooo`07023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`70?ooo`06023/1`04
0?ooo`0Pk0L08>`70?ooo`D08>`70P3oool2023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo1P0P
k0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700H08>`700P0oooo023/1`0Pk0L08>`7
0?ooo`0000008>`70?ooo`808>`7103oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0
oooo00@0oooo00<08>`70?ooo`3oool0>03oool00`000000oooo0?ooo`0K0?ooo`006@3oool00`00
0000oooo0?ooo`0^0?ooo`808>`7103oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`D0oooo0`0P
k0L0103oool08>`70?ooo`3oool2023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`07023/
1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L08>`7
023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo0P0Pk0L01P3oool08>`7023/1`3o
ool08>`70?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool5023/1`06
0?ooo`0Pk0L08>`7023/1`3oool000000P3oool2023/1`@0oooo00H08>`70?ooo`3oool08>`70?oo
o`0Pk0L70?ooo`03023/1`3oool0oooo03P0oooo00<000000?ooo`3oool06`3oool001T0oooo00<0
00000?ooo`3oool0;P3oool2023/1`@0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L50?ooo`<0
8>`700@0oooo023/1`3oool0oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`7
00D08>`70P3oool00`0Pk0L0oooo023/1`04023/1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/
1`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700<08>`70P3oool2023/1`060?ooo`0Pk0L0
8>`70?ooo`0Pk0L0oooo1P0Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`D0
8>`700H0oooo023/1`0Pk0L08>`70?ooo`0000020?ooo`808>`7103oool01P0Pk0L0oooo0?ooo`0P
k0L0oooo023/1`H0oooo00<08>`70?ooo`3oool0>@3oool00`000000oooo0?ooo`0K0?ooo`006@3o
ool00`000000oooo0?ooo`0^0?ooo`808>`7103oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`D0
oooo0`0Pk0L0103oool08>`70?ooo`3oool2023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/
1`0Pk0L01@0Pk0L20?ooo`03023/1`3oool08>`700@08>`700<0oooo023/1`3oool00P0Pk0L01@3o
ool08>`70?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`808>`700H0oooo
023/1`0Pk0L0oooo023/1`3oool6023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0
oooo1@0Pk0L01`3oool08>`7023/1`0Pk0L0oooo0000003oool00`0Pk0L40?ooo`06023/1`3oool0
oooo023/1`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`0i0?ooo`030000003oool0oooo01/0oooo
000I0?ooo`030000003oool0oooo02h0oooo0P0Pk0L40?ooo`06023/1`3oool08>`7023/1`3oool0
8>`71@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700<0oooo023/1`3oool00`0Pk0L00`3o
ool08>`7023/1`05023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`70?ooo`02023/
1`050?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo0P0Pk0L0
1P3oool08>`7023/1`3oool08>`70?ooo``08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L01`3oool0
8>`7023/1`0Pk0L0oooo0000003oool00`0Pk0L40?ooo`06023/1`3oool0oooo023/1`3oool08>`7
1P3oool00`0Pk0L0oooo0?ooo`0i0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003o
ool0oooo02h0oooo0P0Pk0L40?ooo`06023/1`3oool08>`7023/1`3oool08>`71@3oool3023/1`04
0?ooo`0Pk0L0oooo0?ooo`808>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`05023/
1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L0oooo
023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo0P0Pk0L01P3oool08>`7023/1`3o
ool08>`70?ooo`l08>`700<0oooo023/1`0Pk0L00`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo0000
003oool00`0Pk0L40?ooo`06023/1`3oool0oooo023/1`3oool08>`71P3oool00`0Pk0L0oooo0?oo
o`0i0?ooo`030000003oool0oooo01/0oooo000I0?ooo`030000003oool0oooo02h0oooo0`0Pk0L3
0?ooo`06023/1`3oool08>`7023/1`3oool08>`71@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`80
8>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`05023/1`80oooo00<08>`70?ooo`0P
k0L0100Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L00`3o
ool08>`7023/1`03023/1`80oooo0P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`l08>`700<0
oooo023/1`0Pk0L00`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo0000003oool00`0Pk0L40?ooo`06
023/1`3oool0oooo023/1`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`0j0?ooo`030000003oool0
oooo01X0oooo000I0?ooo`030000003oool0oooo02h0oooo0`0Pk0L30?ooo`06023/1`3oool08>`7
023/1`3oool08>`71@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700<0oooo023/1`3oool0
0`0Pk0L00`3oool08>`7023/1`05023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`7
0?ooo`02023/1`050?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`80
oooo0P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`l08>`700<0oooo023/1`0Pk0L00`0Pk0L0
1`3oool08>`7023/1`0Pk0L0oooo0000003oool00`0Pk0L40?ooo`06023/1`3oool0oooo023/1`3o
ool08>`71P3oool00`0Pk0L0oooo0?ooo`0j0?ooo`030000003oool0oooo01X0oooo000I0?ooo`03
0000003oool0oooo02h0oooo0`0Pk0L30?ooo`06023/1`3oool08>`7023/1`3oool08>`71@3oool3
023/1`040?ooo`0Pk0L0oooo0?ooo`@08>`700D0oooo023/1`0Pk0L08>`70?ooo`07023/1`80oooo
00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L0oooo023/1`3o
ool00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo1@0Pk0L00`3oool08>`70?ooo`0E023/1`07
0?ooo`0Pk0L08>`7023/1`3oool000000?ooo`03023/1`@0oooo00H08>`70?ooo`3oool08>`70?oo
o`0Pk0L60?ooo`03023/1`3oool0oooo03X0oooo00<000000?ooo`3oool06P3oool001T0oooo00<0
00000?ooo`3oool0;P3oool00`0Pk0L0oooo023/1`030?ooo`06023/1`3oool08>`7023/1`3oool0
8>`71@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`@08>`700D0oooo023/1`0Pk0L08>`70?ooo`07
023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L0
oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo1@0Pk0L00`3oool08>`70?oo
o`0E023/1`070?ooo`0Pk0L08>`7023/1`3oool000000?ooo`02023/1`D0oooo00H08>`70?ooo`3o
ool08>`70?ooo`0Pk0L60?ooo`03023/1`3oool0oooo03X0oooo00<000000?ooo`3oool06P3oool0
01T0oooo00<000000?ooo`3oool0;P3oool00`0Pk0L0oooo023/1`030?ooo`06023/1`3oool08>`7
023/1`3oool08>`71@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`@08>`700D0oooo023/1`0Pk0L0
8>`70?ooo`07023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`70?ooo`02023/1`05
0?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo1@0Pk0L00`3o
ool08>`70?ooo`0E023/1`070?ooo`0Pk0L08>`7023/1`3oool000000?ooo`02023/1`D0oooo00H0
8>`70?ooo`3oool08>`70?ooo`0Pk0L60?ooo`03023/1`3oool0oooo03X0oooo00<000000?ooo`3o
ool06P3oool001T0oooo00<000000?ooo`3oool0;P3oool00`0Pk0L0oooo023/1`030?ooo`06023/
1`3oool08>`7023/1`3oool08>`71@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`@08>`700D0oooo
023/1`0Pk0L08>`70?ooo`07023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`7023/
1`02023/1`050?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo
1@0Pk0L00`3oool08>`70?ooo`0E023/1`070?ooo`0Pk0L08>`7023/1`3oool000000?ooo`02023/
1`D0oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L60?ooo`03023/1`3oool0oooo03X0oooo00<0
00000?ooo`3oool06P3oool001T0oooo00<000000?ooo`3oool0;P3oool00`0Pk0L0oooo023/1`03
0?ooo`06023/1`3oool08>`7023/1`3oool08>`71@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`@0
8>`700D0oooo023/1`0Pk0L08>`70?ooo`07023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3o
ool08>`7023/1`02023/1`050?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`03
023/1`80oooo1@0Pk0L00`3oool08>`70?ooo`0E023/1`070?ooo`0Pk0L08>`7023/1`3oool00000
0?ooo`02023/1`D0oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L60?ooo`03023/1`3oool0oooo
03X0oooo00<000000?ooo`3oool06P3oool001T0oooo00<000000?ooo`3oool0;P3oool00`0Pk0L0
oooo023/1`030?ooo`06023/1`3oool08>`7023/1`3oool08>`71@3oool3023/1`040?ooo`0Pk0L0
oooo0?ooo`@08>`70P3oool2023/1`030?ooo`0Pk0L08>`700D08>`70P3oool00`0Pk0L0oooo023/
1`04023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`3oool08>`70?ooo`02023/1`030?oo
o`0Pk0L08>`700<08>`70P3oool5023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L0
3P0Pk0L01`3oool08>`7023/1`0Pk0L0oooo0000003oool00P0Pk0L50?ooo`06023/1`3oool0oooo
023/1`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`0j0?ooo`030000003oool0oooo01X0oooo000I
0?ooo`030000003oool0oooo02h0oooo00<08>`70?ooo`0Pk0L00`3oool01P0Pk0L0oooo023/1`0P
k0L0oooo023/1`D0oooo0`0Pk0L0103oool08>`70?ooo`3oool4023/1`80oooo0P0Pk0L00`3oool0
8>`7023/1`05023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`7023/1`02023/1`05
0?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo1@0Pk0L00`3o
ool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L01`0Pk0L01`3o
ool08>`7023/1`0Pk0L0oooo0000003oool00P0Pk0L50?ooo`03023/1`3oool08>`70080oooo00<0
8>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`0j0?ooo`030000003oool0oooo01X0oooo000I
0?ooo`030000003oool0oooo02h0oooo00<08>`70?ooo`0Pk0L00`3oool01P0Pk0L0oooo023/1`0P
k0L0oooo023/1`D0oooo0`0Pk0L0103oool08>`70?ooo`3oool4023/1`80oooo0P0Pk0L00`3oool0
8>`7023/1`05023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`7023/1`02023/1`05
0?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo1`0Pk0L00`3o
ool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`07
023/1`030?ooo`0Pk0L08>`70080oooo00@000000?ooo`0Pk0L08>`71@3oool00`0Pk0L0oooo023/
1`020?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3oool0>P3oool00`000000oooo0?oo
o`0J0?ooo`006@3oool00`000000oooo0?ooo`0^0?ooo`03023/1`3oool08>`700<0oooo00H08>`7
0?ooo`0Pk0L08>`70?ooo`0Pk0L50?ooo`<08>`700@0oooo023/1`3oool0oooo100Pk0L20?ooo`80
8>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`03023/1`3oool08>`700@08>`700<0oooo023/1`0P
k0L00P0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00`0Pk0L20?oo
o`L08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700<0oooo
023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`020?ooo`040000003oool08>`7023/1`D0oooo00<0
8>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo03X0oooo00<0
00000?ooo`3oool06P3oool001T0oooo00<000000?ooo`3oool0;P3oool00`0Pk0L0oooo023/1`03
0?ooo`06023/1`3oool08>`7023/1`3oool08>`71@3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`@0
8>`70P3oool2023/1`030?ooo`0Pk0L08>`700D08>`70P3oool00`0Pk0L0oooo023/1`09023/1`05
0?ooo`0Pk0L0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo1`0Pk0L00`3o
ool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3o
ool08>`7023/1`020?ooo`040000003oool08>`7023/1`D0oooo00<08>`70?ooo`0Pk0L00P3oool0
0`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo03X0oooo00<000000?ooo`3oool06P3oool0
01T0oooo00<000000?ooo`3oool0;P3oool00`0Pk0L0oooo023/1`030?ooo`05023/1`3oool0oooo
023/1`3oool00P0Pk0L40?ooo`<08>`700@0oooo023/1`3oool0oooo100Pk0L20?ooo`808>`700<0
oooo023/1`0Pk0L01@0Pk0L20?ooo`03023/1`3oool08>`700T08>`700H0oooo023/1`3oool08>`7
0?ooo`0Pk0L20?ooo`D08>`70P3oool<023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0P
k0L01`0Pk0L00`3oool08>`7023/1`020?ooo`040000003oool08>`7023/1`D0oooo00<08>`70?oo
o`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo03X0oooo00<000000?oo
o`3oool06P3oool001T0oooo00<000000?ooo`3oool0;P3oool00`0Pk0L0oooo023/1`030?ooo`05
023/1`3oool0oooo023/1`3oool00P0Pk0L40?ooo`<08>`700@0oooo023/1`3oool0oooo100Pk0L2
0?ooo`808>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`03023/1`3oool08>`700T08>`700H0oooo
023/1`3oool08>`70?ooo`0Pk0L20?ooo`D08>`70P3oool<023/1`030?ooo`0Pk0L08>`700@08>`7
00<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`020?ooo`040000003oool08>`7023/1`D0
oooo00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo03X0
oooo00<000000?ooo`3oool06P3oool001T0oooo00<000000?ooo`3oool0;@3oool2023/1`030?oo
o`0Pk0L0oooo0080oooo00D08>`70?ooo`3oool08>`70?ooo`02023/1`@0oooo0`0Pk0L0103oool0
8>`70?ooo`3oool4023/1`80oooo0P0Pk0L00`3oool08>`7023/1`05023/1`80oooo00<08>`70?oo
o`0Pk0L02@0Pk0L01P3oool08>`70?ooo`0Pk0L0oooo023/1`80oooo1@0Pk0L20?ooo``08>`700<0
oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`70080oooo00@0
00000?ooo`0Pk0L08>`71@3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo00@0oooo
00<08>`70?ooo`3oool0>P3oool00`000000oooo0?ooo`0J0?ooo`006@3oool00`000000oooo0?oo
o`0]0?ooo`808>`700<0oooo023/1`3oool00P3oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00808>`7
103oool3023/1`040?ooo`0Pk0L0oooo0?ooo`@08>`70P3oool2023/1`030?ooo`0Pk0L08>`700D0
8>`70P3oool00`0Pk0L0oooo023/1`08023/1`070?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`02
0?ooo`D08>`70P3oool<023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L01`0Pk0L0
0`3oool08>`7023/1`020?ooo`040000003oool08>`7023/1`D0oooo00D08>`70?ooo`0Pk0L0oooo
023/1`070?ooo`03023/1`3oool0oooo03X0oooo00<000000?ooo`3oool06P3oool001T0oooo00<0
00000?ooo`3oool0;@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00D08>`70?ooo`3oool08>`7
0?ooo`02023/1`@0oooo0`0Pk0L20?ooo`03023/1`3oool08>`700<08>`70P3oool2023/1`030?oo
o`0Pk0L08>`700D08>`70P3oool00`0Pk0L0oooo023/1`08023/1`070?ooo`0Pk0L08>`70?ooo`0P
k0L0oooo023/1`020?ooo`D08>`70P3oool<023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/
1`0Pk0L01`0Pk0L00`3oool08>`7023/1`020?ooo`040000003oool08>`7023/1`D0oooo00D08>`7
0?ooo`0Pk0L0oooo023/1`070?ooo`03023/1`3oool0oooo03X0oooo00<000000?ooo`3oool06P3o
ool001T0oooo00<000000?ooo`3oool0;@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00D08>`7
0?ooo`3oool08>`70?ooo`02023/1`D0oooo0P0Pk0L20?ooo`03023/1`3oool08>`700<08>`70P3o
ool2023/1`030?ooo`0Pk0L08>`700D08>`70P3oool00`0Pk0L0oooo023/1`08023/1`070?ooo`0P
k0L08>`70?ooo`0Pk0L0oooo023/1`020?ooo`D08>`70P3oool<023/1`030?ooo`0Pk0L08>`700@0
8>`700<0oooo023/1`0Pk0L0200Pk0L01P3oool08>`70?ooo`3oool000000?ooo`808>`71@3oool0
1@0Pk0L0oooo023/1`3oool08>`700L0oooo00<08>`70?ooo`3oool0>P3oool00`000000oooo0?oo
o`0J0?ooo`006@3oool00`000000oooo0?ooo`0]0?ooo`808>`700<0oooo023/1`3oool00P3oool0
1@0Pk0L0oooo0?ooo`0Pk0L0oooo00808>`71@3oool2023/1`80oooo00<08>`70?ooo`0Pk0L00`0P
k0L20?ooo`808>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0
oooo023/1`3oool00P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`D08>`70P3oool<023/1`030?oo
o`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L0200Pk0L01P3oool08>`70?ooo`3oool000000?oo
o`808>`71@3oool01@0Pk0L0oooo023/1`3oool08>`700L0oooo00<08>`70?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0J0?ooo`006@3oool00`000000oooo0?ooo`0]0?ooo`808>`700<0oooo023/
1`3oool00P3oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00808>`71@3oool2023/1`80oooo00<08>`7
0?ooo`0Pk0L00`0Pk0L20?ooo`808>`700<0oooo023/1`0000001@0Pk0L20?ooo`03023/1`3oool0
8>`700H08>`700<0oooo023/1`3oool00P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`D08>`70P3o
ool<023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L0200Pk0L01P3oool08>`70?oo
o`3oool000000?ooo`808>`71@3oool01@0Pk0L0oooo023/1`3oool08>`700L0oooo00<08>`70?oo
o`3oool0>P3oool00`000000oooo0?ooo`0J0?ooo`006@3oool00`000000oooo0?ooo`0]0?ooo`80
8>`700<0oooo023/1`3oool00P3oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00808>`71@3oool2023/
1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L00000
00D08>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L0oooo00808>`700@0oooo023/
1`3oool08>`70P3oool5023/1`80oooo300Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L0
8>`700P08>`700H0oooo023/1`3oool08>`70000003oool2023/1`D0oooo00D08>`70?ooo`0Pk0L0
oooo023/1`070?ooo`03023/1`3oool0oooo03X0oooo00<000000?ooo`3oool06P3oool001T0oooo
00<000000?ooo`3oool0;@3oool2023/1`030?ooo`0Pk0L0oooo0080oooo00D08>`70?ooo`3oool0
8>`70?ooo`02023/1`D0oooo0P0Pk0L20?ooo`03023/1`3oool08>`700808>`700<0oooo023/1`3o
ool00P0Pk0L00`3oool08>`700000005023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool0
8>`70?ooo`02023/1`040?ooo`0Pk0L0oooo023/1`80oooo1@0Pk0L20?ooo``08>`700<0oooo023/
1`0Pk0L0100Pk0L00`3oool08>`7023/1`08023/1`050?ooo`0Pk0L0oooo023/1`0000000`0Pk0L4
0?ooo`06023/1`3oool0oooo023/1`3oool08>`71`3oool00`0Pk0L0oooo0?ooo`0j0?ooo`030000
003oool0oooo01X0oooo000I0?ooo`030000003oool0oooo02d0oooo0P0Pk0L00`3oool08>`70?oo
o`020?ooo`05023/1`3oool0oooo023/1`3oool00P0Pk0L50?ooo`808>`70P3oool00`0Pk0L0oooo
023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0000001@0Pk0L20?ooo`03023/
1`3oool08>`700H08>`700<0oooo023/1`3oool00P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`D0
8>`70P3oool9023/1`040?ooo`0Pk0L08>`70?ooo`H08>`700<0oooo023/1`0Pk0L01P0Pk0L01`3o
ool08>`70?ooo`0Pk0L0oooo023/1`0000000`0Pk0L40?ooo`06023/1`3oool0oooo023/1`3oool0
8>`71`3oool00`0Pk0L0oooo0?ooo`0j0?ooo`030000003oool0oooo01X0oooo000I0?ooo`030000
003oool0oooo02d0oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`05023/1`3oool0oooo023/1`3o
ool00P0Pk0L50?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo0080
8>`700<0oooo023/1`0000001@0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`3o
ool00P0Pk0L0103oool08>`70?ooo`0Pk0L20?ooo`D08>`70P3oool9023/1`040?ooo`0Pk0L08>`7
0?ooo`H08>`700<0oooo023/1`0Pk0L01P0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`000000
0`0Pk0L40?ooo`06023/1`3oool0oooo023/1`3oool08>`71`3oool00`0Pk0L0oooo0?ooo`0j0?oo
o`030000003oool0oooo01X0oooo000I0?ooo`030000003oool0oooo02`0oooo00D08>`70?ooo`0P
k0L0oooo023/1`030?ooo`05023/1`3oool0oooo023/1`3oool00P0Pk0L50?ooo`808>`70P3oool0
0`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0000001@0Pk0L2
0?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`3oool00P0Pk0L0103oool08>`70?ooo`0P
k0L20?ooo`D08>`70P3oool9023/1`040?ooo`0Pk0L08>`70?ooo`H08>`700<0oooo023/1`0Pk0L0
1P0Pk0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`0000000`0Pk0L40?ooo`06023/1`3oool0oooo
023/1`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`0k0?ooo`030000003oool0oooo01X0oooo000I
0?ooo`030000003oool0oooo02`0oooo00D08>`70?ooo`0Pk0L0oooo023/1`030?ooo`05023/1`3o
ool0oooo023/1`3oool00P0Pk0L50?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L00`3o
ool08>`70?ooo`02023/1`030?ooo`0Pk0L0000000D08>`70P3oool00`0Pk0L0oooo023/1`06023/
1`030?ooo`0Pk0L0oooo00808>`700@0oooo023/1`3oool08>`70P3oool5023/1`80oooo2@0Pk0L0
103oool08>`7023/1`3oool6023/1`040?ooo`0Pk0L08>`70?ooo`D08>`700L0oooo023/1`3oool0
8>`70?ooo`0Pk0L0000000<08>`7103oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`H0oooo00<0
8>`70?ooo`3oool0>`3oool00`000000oooo0?ooo`0J0?ooo`006@3oool00`000000oooo0?ooo`0/
0?ooo`05023/1`3oool08>`70?ooo`0Pk0L00`3oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00808>`7
1@3oool01P0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`700<0oooo023/1`3oool00P0Pk0L00`3o
ool08>`700000005023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`70?ooo`02023/
1`040?ooo`0Pk0L0oooo023/1`80oooo1@0Pk0L20?ooo`T08>`700@0oooo023/1`0Pk0L0oooo1P0P
k0L0103oool08>`7023/1`3oool5023/1`070?ooo`0Pk0L0oooo023/1`3oool08>`700000003023/
1`@0oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L60?ooo`03023/1`3oool0oooo03/0oooo00<0
00000?ooo`3oool06P3oool001T0oooo00<000000?ooo`3oool0;03oool00`0Pk0L0oooo0?ooo`02
023/1`<0oooo00D08>`70?ooo`3oool08>`70?ooo`02023/1`D0oooo00H08>`70?ooo`0Pk0L0oooo
023/1`3oool3023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0000001@0Pk0L20?ooo`03
023/1`3oool08>`700H08>`700<0oooo023/1`3oool00P0Pk0L0103oool08>`7023/1`0Pk0L20?oo
o`D08>`70P3oool9023/1`040?ooo`0Pk0L08>`70?ooo`H08>`700@0oooo023/1`0Pk0L0oooo1@0P
k0L01`3oool08>`70?ooo`0Pk0L0oooo023/1`0000000`0Pk0L40?ooo`06023/1`3oool0oooo023/
1`3oool08>`71P3oool00`0Pk0L0oooo0?ooo`0k0?ooo`030000003oool0oooo01X0oooo000I0?oo
o`030000003oool0oooo02`0oooo00<08>`70?ooo`3oool00P0Pk0L30?ooo`05023/1`3oool0oooo
023/1`3oool00P0Pk0L50?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L00`3oool08>`7
0?ooo`02023/1`030?ooo`0Pk0L0000000D08>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?oo
o`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L08>`70P3oool5023/1`80oooo2@0Pk0L0103oool0
8>`7023/1`3oool6023/1`040?ooo`0Pk0L08>`70?ooo`D08>`700L0oooo023/1`0Pk0L08>`70?oo
o`0Pk0L0000000<08>`7103oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`H0oooo00<08>`70?oo
o`3oool0>`3oool00`000000oooo0?ooo`0J0?ooo`006@3oool00`000000oooo0?ooo`0/0?ooo`03
023/1`3oool0oooo00808>`70`3oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00808>`71@3oool01P0P
k0L0oooo023/1`3oool08>`70?ooo`<08>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`70000
0005023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`70?ooo`02023/1`040?ooo`0P
k0L08>`7023/1`80oooo1@0Pk0L20?ooo`T08>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L0103oool0
8>`7023/1`3oool5023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`700000003023/1`@0oooo00<0
8>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo03/0oooo00<0
00000?ooo`3oool06P3oool001T0oooo00<000000?ooo`3oool0;03oool00`0Pk0L0oooo0?ooo`02
023/1`<0oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`030?ooo`06023/1`3o
ool08>`70?ooo`0Pk0L0oooo0`0Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0000000D0
8>`70P3oool00`0Pk0L0oooo023/1`03023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L0
103oool08>`7023/1`0Pk0L20?ooo`D08>`70P3oool9023/1`040?ooo`0Pk0L08>`70?ooo`H08>`7
00@0oooo023/1`0Pk0L0oooo1@0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`0000000`0Pk0L4
0?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`0k
0?ooo`030000003oool0oooo01X0oooo000I0?ooo`030000003oool0oooo02`0oooo00<08>`70?oo
o`3oool00P0Pk0L30?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool00`3oool0
1P0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`7
00000005023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L01P3oool08>`7023/1`3oool08>`70?oo
o`808>`700@0oooo023/1`0Pk0L08>`70P3oool5023/1`80oooo2@0Pk0L0103oool08>`7023/1`3o
ool9023/1`030?ooo`0Pk0L08>`700<08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0000000<0
8>`7103oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0J0?ooo`006@3oool00`000000oooo0?ooo`0/0?ooo`03023/
1`3oool0oooo00808>`70`3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00<0
oooo00H08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo
023/1`0000001@0Pk0L20?ooo`03023/1`3oool08>`700<08>`700@0oooo023/1`0Pk0L0oooo100P
k0L0103oool08>`7023/1`0Pk0L20?ooo`D08>`70P3oool9023/1`040?ooo`0Pk0L08>`70?ooo`X0
8>`700<0oooo023/1`0Pk0L00P0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`0000000`0Pk0L4
0?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`0k
0?ooo`030000003oool0oooo01X0oooo000I0?ooo`030000003oool0oooo02`0oooo00<08>`70?oo
o`3oool00P0Pk0L30?ooo`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool00`3oool0
1P0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`7
00000005023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool4023/1`04
0?ooo`0Pk0L08>`7023/1`80oooo1@0Pk0L20?ooo`T08>`700@0oooo023/1`0Pk0L0oooo2P0Pk0L0
0`3oool08>`7023/1`02023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`700000003023/1`@0oooo
00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo03/0oooo
00<000000?ooo`3oool06P3oool001T0oooo00<000000?ooo`3oool0;03oool00`0Pk0L0oooo0?oo
o`02023/1`<0oooo00@08>`70?ooo`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`030?ooo`06023/
1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L00000
00D08>`70P3oool00`0Pk0L0oooo023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700@0oooo
023/1`0Pk0L08>`70P3oool5023/1`030?ooo`0Pk0L08>`700P08>`700@0oooo023/1`0Pk0L0oooo
3`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`0000000`0Pk0L40?ooo`03023/1`3oool08>`7
0080oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`0k0?ooo`030000003oool0oooo
01X0oooo000I0?ooo`030000003oool0oooo02/0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L30?oo
o`04023/1`3oool0oooo023/1`80oooo00<08>`70?ooo`3oool00`3oool01P0Pk0L0oooo023/1`3o
ool08>`70?ooo`<08>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`700000005023/1`80oooo
00<08>`70?ooo`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool4023/1`040?ooo`0Pk0L08>`7023/
1`80oooo1@0Pk0L00`3oool08>`7023/1`08023/1`040?ooo`0Pk0L08>`70?ooo`l08>`700L0oooo
023/1`0Pk0L08>`70?ooo`0Pk0L0000000<08>`7103oool01@0Pk0L0oooo023/1`3oool08>`700L0
oooo00<08>`70?ooo`3oool0>`3oool00`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo
0?ooo`0/0?ooo`04023/1`3oool0oooo0?ooo`808>`70`3oool00`0Pk0L0oooo0?ooo`02023/1`03
0?ooo`0Pk0L0oooo00@0oooo00H08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`030?ooo`0Pk0L0
oooo00808>`700<0oooo023/1`0000001@0Pk0L20?ooo`03023/1`3oool08>`700<08>`700@0oooo
023/1`0Pk0L0oooo100Pk0L0103oool08>`7023/1`0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L0
200Pk0L0103oool08>`7023/1`3oool?023/1`070?ooo`0Pk0L08>`7023/1`3oool08>`700000003
023/1`@0oooo00D08>`70?ooo`0Pk0L0oooo023/1`070?ooo`03023/1`3oool0oooo03/0oooo00<0
00000?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool0;03oool0100Pk0L0oooo0?ooo`3o
ool2023/1`<0oooo00<08>`70?ooo`3oool00P0Pk0L00`3oool08>`70?ooo`040?ooo`06023/1`3o
ool08>`70?ooo`0Pk0L0oooo0`0Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0000000@0
8>`700D0oooo023/1`3oool08>`70?ooo`04023/1`040?ooo`0Pk0L08>`70?ooo`D08>`700<0oooo
023/1`0Pk0L00P3oool5023/1`030?ooo`0Pk0L08>`700P08>`700@0oooo023/1`0Pk0L0oooo3`0P
k0L0203oool08>`7023/1`0Pk0L0oooo023/1`3oool000000P0Pk0L40?ooo`05023/1`3oool08>`7
0?ooo`0Pk0L01`3oool00`0Pk0L0oooo0?ooo`0k0?ooo`030000003oool0oooo01X0oooo000H0?oo
o`030000003oool0oooo02`0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L30?ooo`03023/1`3oool0
oooo00808>`700<0oooo023/1`3oool0103oool01P0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`7
00<0oooo023/1`3oool00P0Pk0L00`3oool08>`700000004023/1`050?ooo`0Pk0L0oooo023/1`3o
ool0100Pk0L0103oool08>`7023/1`3oool5023/1`030?ooo`0Pk0L08>`70080oooo1@0Pk0L00`3o
ool08>`7023/1`08023/1`040?ooo`0Pk0L08>`70?ooo`l08>`700P0oooo023/1`0Pk0L08>`70?oo
o`0Pk0L0oooo000000808>`7103oool01@0Pk0L0oooo023/1`3oool08>`700L0oooo00<08>`70?oo
o`3oool0>`3oool00`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0/0?ooo`04
023/1`3oool0oooo0?ooo`808>`70`3oool00`0Pk0L0oooo0?ooo`02023/1`030?ooo`0Pk0L08>`7
00@0oooo0`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/
1`000000100Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00@08>`700@0oooo023/1`0Pk0L0oooo1@0P
k0L00`3oool08>`7023/1`020?ooo`D08>`700<0oooo023/1`0Pk0L0200Pk0L0103oool08>`7023/
1`3oool?023/1`080?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`000002023/1`@0oooo00D08>`7
0?ooo`0Pk0L0oooo023/1`070?ooo`03023/1`3oool0oooo03/0oooo00<000000?ooo`3oool06P3o
ool001P0oooo00<000000?ooo`3oool0;03oool0100Pk0L0oooo0?ooo`3oool2023/1`@0oooo00D0
8>`70?ooo`0Pk0L08>`70?ooo`02023/1`@0oooo0`0Pk0L00`3oool08>`70?ooo`03023/1`030?oo
o`0Pk0L0oooo00808>`700<0oooo023/1`000000100Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00@0
8>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`020?ooo`D08>`700<0oooo023/
1`0Pk0L0200Pk0L0103oool08>`7023/1`3oool?023/1`080?ooo`0Pk0L08>`7023/1`3oool08>`7
0?ooo`000002023/1`@0oooo00D08>`70?ooo`0Pk0L0oooo023/1`070?ooo`03023/1`3oool0oooo
03/0oooo00<000000?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool0;03oool0100Pk0L0
oooo0?ooo`3oool2023/1`@0oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`@0oooo0`0Pk0L0
0`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`000000100Pk0L0
1@3oool08>`70?ooo`0Pk0L0oooo00L08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/
1`020?ooo`D08>`700<0oooo023/1`0Pk0L0200Pk0L0103oool08>`7023/1`3oool5023/1`030?oo
o`0Pk0L08>`700L08>`700P0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo000000808>`7103oool0
1@0Pk0L0oooo023/1`3oool08>`700L0oooo00<08>`70?ooo`3oool0>`3oool00`000000oooo0?oo
o`0J0?ooo`00603oool00`000000oooo0?ooo`0/0?ooo`07023/1`3oool0oooo0?ooo`0Pk0L0oooo
023/1`030?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L40?ooo`<08>`700<0oooo023/1`3o
ool00`0Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0000000@08>`700D0oooo023/1`3o
ool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P3oool5023/
1`030?ooo`0Pk0L08>`700P08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`07
023/1`080?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`000002023/1`@0oooo00D08>`70?ooo`0P
k0L0oooo023/1`070?ooo`03023/1`3oool0oooo03/0oooo00<000000?ooo`3oool06P3oool001P0
oooo00<000000?ooo`3oool0;03oool01`0Pk0L0oooo0?ooo`3oool08>`70?ooo`0Pk0L00`3oool0
1@0Pk0L0oooo023/1`0Pk0L0oooo00808>`7103oool3023/1`030?ooo`0Pk0L0oooo00<08>`700<0
oooo023/1`3oool00P0Pk0L00`3oool08>`700000004023/1`050?ooo`0Pk0L0oooo023/1`3oool0
1`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`70080oooo1@0Pk0L00`3oool08>`7
023/1`08023/1`040?ooo`0Pk0L08>`70?ooo`D08>`700<0oooo023/1`0Pk0L01`0Pk0L02@3oool0
8>`7023/1`0Pk0L0oooo023/1`3oool00000023/1`050?ooo`05023/1`3oool08>`70?ooo`0Pk0L0
1`3oool00`0Pk0L0oooo0?ooo`0k0?ooo`030000003oool0oooo01X0oooo000H0?ooo`030000003o
ool0oooo02`0oooo00L08>`70?ooo`3oool0oooo023/1`3oool08>`700<0oooo00D08>`70?ooo`0P
k0L08>`70?ooo`02023/1`@0oooo0`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo
00808>`700<0oooo023/1`000000100Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00L08>`700<0oooo
023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`020?ooo`D08>`700<0oooo023/1`0Pk0L0200Pk0L0
103oool08>`7023/1`3oool5023/1`030?ooo`0Pk0L08>`700L08>`700T0oooo023/1`0Pk0L08>`7
0?ooo`0Pk0L0oooo0000000Pk0L01@3oool01@0Pk0L0oooo023/1`3oool08>`700L0oooo00<08>`7
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0[0?oo
o`03023/1`3oool0oooo0080oooo00<08>`70?ooo`0Pk0L00`3oool01@0Pk0L0oooo023/1`0Pk0L0
oooo00808>`7103oool3023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`3oool00P0Pk0L0
0`3oool08>`700000004023/1`050?ooo`0Pk0L0oooo023/1`3oool01`0Pk0L00`3oool08>`7023/
1`03023/1`030?ooo`0Pk0L08>`70080oooo1@0Pk0L00`3oool08>`7023/1`08023/1`040?ooo`0P
k0L08>`70?ooo`D08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`02023/1`80oooo
00<00000023/1`3oool0103oool01@0Pk0L0oooo023/1`3oool08>`700L0oooo00<08>`70?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0[0?ooo`03023/
1`3oool0oooo0080oooo00<08>`70?ooo`0Pk0L00`3oool01@0Pk0L0oooo023/1`0Pk0L0oooo0080
8>`7103oool3023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`3oool00P0Pk0L00`3oool0
8>`700000004023/1`050?ooo`0Pk0L0oooo023/1`3oool01`0Pk0L00`3oool08>`7023/1`03023/
1`030?ooo`0Pk0L08>`70080oooo1@0Pk0L00`3oool08>`7023/1`08023/1`040?ooo`0Pk0L08>`7
0?ooo`D08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`02023/1`040?ooo`0Pk0L0
0000023/1`D0oooo00D08>`70?ooo`0Pk0L0oooo023/1`070?ooo`03023/1`3oool0oooo03/0oooo
00<000000?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool0:`3oool00`0Pk0L0oooo0?oo
o`020?ooo`03023/1`3oool08>`700<0oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`@0oooo
0`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`000000
100Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00L08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool0
8>`7023/1`020?ooo`D08>`700<0oooo023/1`0Pk0L0200Pk0L0103oool08>`7023/1`3oool5023/
1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`70000000Pk0L5
0?ooo`05023/1`3oool08>`70?ooo`0Pk0L01`3oool00`0Pk0L0oooo0?ooo`0k0?ooo`030000003o
ool0oooo01X0oooo000H0?ooo`030000003oool0oooo02/0oooo00<08>`70?ooo`3oool00P3oool0
0`0Pk0L0oooo023/1`030?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L40?ooo`<08>`700<0
oooo023/1`3oool00`0Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0000000@08>`700D0
oooo023/1`3oool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L0
0P3oool5023/1`030?ooo`0Pk0L08>`700P08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L00`3oool0
8>`7023/1`07023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`0000008>`71@3oool01@0P
k0L0oooo023/1`3oool08>`700L0oooo00<08>`70?ooo`3oool0>`3oool00`000000oooo0?ooo`0J
0?ooo`00603oool00`000000oooo0?ooo`0[0?ooo`03023/1`3oool0oooo0080oooo00<08>`70?oo
o`0Pk0L00`3oool01@0Pk0L0oooo023/1`0Pk0L0oooo00808>`7103oool3023/1`030?ooo`0Pk0L0
oooo00<08>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`700000004023/1`050?ooo`0Pk0L0
oooo023/1`3oool01`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`70080oooo1@0P
k0L00`3oool08>`7023/1`08023/1`040?ooo`0Pk0L08>`70?ooo`D08>`700<0oooo023/1`0Pk0L0
1P0Pk0L20?ooo`@08>`700@0oooo023/1`0000008>`71@3oool01@0Pk0L0oooo023/1`3oool08>`7
00L0oooo00<08>`70?ooo`3oool0>`3oool00`000000oooo0?ooo`0J0?ooo`00603oool00`000000
oooo0?ooo`0[0?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`0Pk0L00`3oool01@0Pk0L0
oooo023/1`0Pk0L0oooo00808>`7103oool3023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/
1`3oool00P0Pk0L00`3oool08>`700000004023/1`050?ooo`0Pk0L0oooo023/1`3oool01`0Pk0L0
0`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`70080oooo1@0Pk0L00`3oool08>`7023/1`08
023/1`040?ooo`0Pk0L08>`70?ooo`D08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`@08>`700@0
oooo023/1`0000008>`71@3oool2023/1`80oooo00<08>`70?ooo`3oool01@3oool00`0Pk0L0oooo
0?ooo`0k0?ooo`030000003oool0oooo01X0oooo000H0?ooo`030000003oool0oooo02/0oooo00<0
8>`70?ooo`3oool00P3oool00`0Pk0L0oooo023/1`030?ooo`05023/1`3oool08>`7023/1`3oool0
0P0Pk0L40?ooo`<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`70?ooo`02023/1`030?oo
o`0Pk0L0000000@08>`700D0oooo023/1`3oool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`700<0
8>`700<0oooo023/1`0Pk0L00P3oool5023/1`030?ooo`0Pk0L08>`700P08>`700@0oooo023/1`0P
k0L0oooo1@0Pk0L00`3oool08>`7023/1`06023/1`80oooo100Pk0L0103oool08>`70000000Pk0L5
0?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo03`0oooo00<00000
0?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool0:`3oool00`0Pk0L0oooo0?ooo`020?oo
o`03023/1`3oool08>`700<0oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`@0oooo0`0Pk0L2
0?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`700000004023/1`050?ooo`0Pk0L0
oooo023/1`3oool01`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`70080oooo1@0P
k0L00`3oool08>`7023/1`08023/1`040?ooo`0Pk0L08>`70?ooo`D08>`700<0oooo023/1`0Pk0L0
1P0Pk0L20?ooo`@08>`700@0oooo023/1`0000008>`71@3oool2023/1`80oooo00<08>`70?ooo`3o
ool0103oool00`0Pk0L0oooo0?ooo`0l0?ooo`030000003oool0oooo01X0oooo000H0?ooo`030000
003oool0oooo02/0oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo023/1`030?ooo`05023/
1`3oool08>`7023/1`3oool00P0Pk0L40?ooo`<08>`70P3oool4023/1`030?ooo`0Pk0L0oooo0080
8>`700<0oooo023/1`000000100Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00L08>`700<0oooo023/
1`0Pk0L00`0Pk0L00`3oool08>`7023/1`020?ooo`D08>`700<0oooo023/1`0Pk0L0200Pk0L0103o
ool08>`7023/1`3oool5023/1`030?ooo`0Pk0L08>`700H08>`70P3oool4023/1`040?ooo`0Pk0L0
0000023/1`D0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3oool0?03o
ool00`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0[0?ooo`03023/1`3oool0
oooo0080oooo00<08>`70?ooo`0Pk0L00`3oool01@0Pk0L0oooo023/1`0Pk0L0oooo00808>`7103o
ool3023/1`80oooo100Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0000000@08>`700D0
oooo023/1`3oool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L0
0P3oool5023/1`030?ooo`0Pk0L08>`700P08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L00`3oool0
8>`7023/1`06023/1`80oooo100Pk0L0103oool08>`70000000Pk0L50?ooo`808>`70P3oool00`0P
k0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo03`0oooo00<000000?ooo`3oool06P3oool001P0
oooo00<000000?ooo`3oool0:P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool08>`700<0
oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`@0oooo0`0Pk0L20?ooo`@08>`700<0oooo023/
1`3oool00P0Pk0L00`3oool08>`700000004023/1`050?ooo`0Pk0L0oooo023/1`3oool01`0Pk0L0
0`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`70080oooo1@0Pk0L00`3oool08>`7023/1`08
023/1`040?ooo`0Pk0L08>`70?ooo`D08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`@08>`700@0
oooo023/1`0000008>`71@3oool2023/1`80oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo
0?ooo`0l0?ooo`030000003oool0oooo01X0oooo000H0?ooo`030000003oool0oooo02X0oooo00<0
8>`70?ooo`3oool00`3oool00`0Pk0L0oooo023/1`030?ooo`05023/1`3oool08>`7023/1`3oool0
0P0Pk0L40?ooo`808>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`70?ooo`02023/1`030?oo
o`0Pk0L0000000@08>`700D0oooo023/1`3oool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`700<0
8>`700<0oooo023/1`0Pk0L00P3oool5023/1`030?ooo`0Pk0L08>`700P08>`700@0oooo023/1`0P
k0L0oooo1@0Pk0L0103oool08>`7023/1`3oool5023/1`80oooo0P0Pk0L01P3oool08>`70?ooo`0P
k0L00000023/1`@0oooo00D08>`70?ooo`0Pk0L0oooo023/1`070?ooo`03023/1`3oool0oooo03`0
oooo00<000000?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool0:P3oool00`0Pk0L0oooo
0?ooo`030?ooo`03023/1`3oool08>`700<0oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`@0
oooo0P0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`00
0000100Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00L08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3o
ool08>`7023/1`020?ooo`D08>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`7023/1`06023/
1`040?ooo`0Pk0L08>`70?ooo`D08>`70P3oool2023/1`060?ooo`0Pk0L0oooo023/1`0000008>`7
103oool01@0Pk0L0oooo023/1`3oool08>`700L0oooo00<08>`70?ooo`3oool0?03oool00`000000
oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0Z0?ooo`03023/1`3oool0oooo00<0oooo
00<08>`70?ooo`0Pk0L00`3oool01@0Pk0L0oooo023/1`0Pk0L0oooo00808>`7103oool2023/1`03
0?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`700000004023/1`05
0?ooo`0Pk0L0oooo023/1`3oool01`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`7
0080oooo1@0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/
1`0Pk0L0oooo1@0Pk0L20?ooo`808>`700H0oooo023/1`3oool08>`70000000Pk0L40?ooo`05023/
1`3oool08>`70?ooo`0Pk0L01`3oool00`0Pk0L0oooo0?ooo`0l0?ooo`030000003oool0oooo01X0
oooo000H0?ooo`030000003oool0oooo02X0oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo
023/1`030?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L40?ooo`808>`700<0oooo023/1`3o
ool0100Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0000000H08>`700<0oooo023/1`3o
ool01`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`70080oooo1@0Pk0L00`3oool0
8>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L01P0Pk0L0103oool0
8>`7023/1`3oool5023/1`80oooo0P0Pk0L01P3oool08>`70?ooo`0Pk0L00000023/1`@0oooo00D0
8>`70?ooo`0Pk0L0oooo023/1`070?ooo`03023/1`3oool0oooo03`0oooo00<000000?ooo`3oool0
6P3oool001P0oooo00<000000?ooo`3oool0:P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3o
ool08>`700<0oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`@0oooo0P0Pk0L00`3oool08>`7
0?ooo`04023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0000001P0Pk0L00`3oool08>`7
0?ooo`07023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P3oool5023/1`030?oo
o`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`06023/1`040?oo
o`0Pk0L08>`70?ooo`D08>`70P3oool2023/1`060?ooo`0Pk0L0oooo023/1`0000008>`7103oool0
1@0Pk0L0oooo023/1`3oool08>`700L0oooo00<08>`70?ooo`3oool0?03oool00`000000oooo0?oo
o`0J0?ooo`00603oool00`000000oooo0?ooo`0Z0?ooo`03023/1`3oool0oooo00<0oooo00<08>`7
0?ooo`0Pk0L00`3oool01@0Pk0L0oooo023/1`0Pk0L0oooo00808>`7103oool2023/1`030?ooo`0P
k0L0oooo00@08>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`700000006023/1`030?ooo`0P
k0L0oooo00L08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`020?ooo`D08>`700<0
oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700H08>`700@0
oooo023/1`0Pk0L0oooo1@0Pk0L20?ooo`808>`700H0oooo023/1`3oool08>`70000000Pk0L40?oo
o`05023/1`3oool08>`70?ooo`0Pk0L01`3oool00`0Pk0L0oooo0?ooo`0l0?ooo`030000003oool0
oooo01X0oooo000H0?ooo`030000003oool0oooo02X0oooo00<08>`70?ooo`3oool00`3oool00`0P
k0L0oooo023/1`030?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L40?ooo`808>`700<0oooo
023/1`3oool0100Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0000000H08>`700<0oooo
023/1`3oool01`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`70080oooo1@0Pk0L0
0`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L02@0Pk0L0
0`3oool08>`7023/1`03023/1`80oooo0P0Pk0L01P3oool08>`70?ooo`0Pk0L00000023/1`@0oooo
00D08>`70?ooo`0Pk0L0oooo023/1`070?ooo`03023/1`3oool0oooo03`0oooo00<000000?ooo`3o
ool06P3oool001P0oooo00<000000?ooo`3oool0:P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/
1`3oool08>`700<0oooo00D08>`70?ooo`0Pk0L08>`70?ooo`02023/1`@0oooo0P0Pk0L00`3oool0
8>`70?ooo`04023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0000001P0Pk0L00`3oool0
8>`70?ooo`07023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P3oool5023/1`03
0?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`0;023/1`03
0?ooo`0Pk0L08>`700808>`70P3oool2023/1`060?ooo`0Pk0L0oooo023/1`0000008>`7103oool0
1@0Pk0L0oooo023/1`3oool08>`700L0oooo00<08>`70?ooo`3oool0?03oool00`000000oooo0?oo
o`0J0?ooo`00603oool00`000000oooo0?ooo`0Z0?ooo`03023/1`3oool0oooo00<0oooo00<08>`7
0?ooo`0Pk0L00`3oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00808>`71@3oool0100Pk0L0oooo023/
1`3oool4023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0000001P0Pk0L00`3oool08>`7
0?ooo`07023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P3oool5023/1`030?oo
o`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`0;023/1`030?oo
o`0Pk0L08>`700808>`70P3oool2023/1`060?ooo`0Pk0L0oooo023/1`0000008>`7103oool01@0P
k0L0oooo023/1`3oool08>`700L0oooo00<08>`70?ooo`3oool0?03oool00`000000oooo0?ooo`0J
0?ooo`00603oool00`000000oooo0?ooo`0Z0?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?oo
o`0Pk0L00`3oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00808>`71@3oool0100Pk0L0oooo023/1`3o
ool4023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0000001P0Pk0L00`3oool08>`70?oo
o`07023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P3oool5023/1`030?ooo`0P
k0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`0;023/1`030?ooo`0P
k0L08>`700808>`700X0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`0000008>`7103oool0
1@0Pk0L0oooo023/1`3oool08>`700L0oooo00<08>`70?ooo`3oool0?03oool00`000000oooo0?oo
o`0J0?ooo`00603oool00`000000oooo0?ooo`0Y0?ooo`03023/1`3oool0oooo00@0oooo00<08>`7
0?ooo`0Pk0L00`3oool0200Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`7103oool0100Pk0L0
oooo023/1`3oool4023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0000001P0Pk0L00`3o
ool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P3oool5023/
1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`0;023/
1`030?ooo`0Pk0L08>`700808>`700X0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`000000
8>`7103oool01@0Pk0L0oooo023/1`3oool08>`700L0oooo00<08>`70?ooo`3oool0?03oool00`00
0000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0Y0?ooo`03023/1`3oool0oooo00@0
oooo00<08>`70?ooo`0Pk0L00`3oool0200Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`7103o
ool0100Pk0L0oooo023/1`3oool4023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`000000
1P0Pk0L00`3oool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L0
0P3oool5023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7
023/1`0;023/1`030?ooo`0Pk0L08>`700808>`700X0oooo023/1`3oool08>`70?ooo`0Pk0L0oooo
023/1`0000008>`7103oool01@0Pk0L0oooo023/1`3oool08>`700L0oooo00<08>`70?ooo`3oool0
?03oool00`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0Y0?ooo`03023/1`3o
ool0oooo00D0oooo0P0Pk0L30?ooo`08023/1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L40?oo
o`04023/1`3oool08>`70?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`70?ooo`06
023/1`030?ooo`0Pk0L0oooo00L08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`02
0?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0
8>`700/08>`700<0oooo023/1`0Pk0L00P0Pk0L02P3oool08>`70?ooo`0Pk0L0oooo023/1`3oool0
8>`70000000Pk0L40?ooo`05023/1`3oool08>`70?ooo`0Pk0L01`3oool00`0Pk0L0oooo0?ooo`0l
0?ooo`030000003oool0oooo01X0oooo000H0?ooo`030000003oool0oooo02T0oooo00<08>`70?oo
o`3oool01@3oool2023/1`<0oooo00P08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo023/1`@0oooo
00@08>`70?ooo`0Pk0L0oooo100Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo00H0
8>`700<0oooo023/1`3oool01`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`70080
oooo1@0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0P
k0L02`0Pk0L00`3oool08>`7023/1`02023/1`0:0?ooo`0Pk0L0oooo023/1`3oool08>`70?ooo`0P
k0L00000023/1`@0oooo00D08>`70?ooo`0Pk0L0oooo023/1`070?ooo`03023/1`3oool0oooo03`0
oooo00<000000?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool0:@3oool00`0Pk0L0oooo
0?ooo`050?ooo`808>`70`3oool0200Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`7103oool0
100Pk0L0oooo023/1`3oool4023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`3oool01P0P
k0L00`3oool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P3o
ool5023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/
1`0;023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool00P0Pk0L01@3oool08>`70?oo
o`0000008>`700@0oooo00D08>`70?ooo`0Pk0L0oooo023/1`070?ooo`03023/1`3oool0oooo03`0
oooo00<000000?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool0:@3oool00`0Pk0L0oooo
0?ooo`050?ooo`808>`70`3oool0200Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`7103oool0
100Pk0L0oooo023/1`3oool4023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`3oool01P0P
k0L00`3oool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P3o
ool3023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/
1`0;023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool00P0Pk0L01@3oool08>`70?oo
o`0000008>`700@0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00D0oooo00<08>`70?ooo`3oool0
?03oool00`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0Y0?ooo`03023/1`3o
ool0oooo00D0oooo0P0Pk0L30?ooo`08023/1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L40?oo
o`04023/1`3oool08>`70?ooo`@08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`04
023/1`030?ooo`0Pk0L0oooo00L08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`02
0?ooo`<08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0
8>`700808>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0
oooo00808>`700D0oooo023/1`3oool00000023/1`040?ooo`808>`70P3oool00`0Pk0L0oooo0?oo
o`050?ooo`03023/1`3oool0oooo03`0oooo00<000000?ooo`3oool06P3oool001P0oooo00<00000
0?ooo`3oool0:@3oool00`0Pk0L0oooo0?ooo`050?ooo`808>`70`3oool0200Pk0L0oooo0?ooo`0P
k0L0oooo023/1`3oool08>`7103oool0100Pk0L0oooo023/1`3oool4023/1`030?ooo`0Pk0L0oooo
00@08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`7
00<08>`700<0oooo023/1`0Pk0L00P3oool3023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/
1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/
1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L0oooo0000000Pk0L0103oool2
023/1`80oooo00<08>`70?ooo`3oool01@3oool00`0Pk0L0oooo0?ooo`0l0?ooo`030000003oool0
oooo01X0oooo000H0?ooo`030000003oool0oooo02T0oooo00<08>`70?ooo`3oool01@3oool2023/
1`<0oooo00P08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo023/1`@0oooo00@08>`70?ooo`0Pk0L0
oooo100Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`3o
ool01`0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3o
ool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3o
ool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool00P0Pk0L01@3o
ool08>`70?ooo`0000008>`700@0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00D0oooo00<08>`7
0?ooo`3oool0?03oool00`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0Y0?oo
o`03023/1`3oool0oooo00D0oooo0P0Pk0L30?ooo`08023/1`3oool0oooo023/1`3oool08>`70?oo
o`0Pk0L40?ooo`04023/1`3oool08>`70?ooo`@08>`700<0oooo023/1`3oool0100Pk0L00`3oool0
8>`7023/1`04023/1`030?ooo`0Pk0L0oooo00L08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool0
8>`7023/1`0Pk0L0oooo00<08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/
1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`02023/
1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/1`3oool00000023/1`040?ooo`808>`70P3oool0
0`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool0oooo03`0oooo00<000000?ooo`3oool06P3oool0
01P0oooo00<000000?ooo`3oool0:03oool00`0Pk0L0oooo0?ooo`060?ooo`808>`70`3oool0200P
k0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`7103oool0100Pk0L0oooo023/1`3oool4023/1`03
0?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`70?ooo`07023/1`03
0?ooo`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo
00@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`7
00H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L0oooo
0000000Pk0L0103oool2023/1`030?ooo`0Pk0L0oooo00L0oooo00<08>`70?ooo`3oool0?03oool0
0`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0X0?ooo`03023/1`3oool0oooo
00H0oooo0P0Pk0L30?ooo`08023/1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L40?ooo`<08>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700@08>`7
00<0oooo023/1`3oool01`0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3o
ool00`0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0P
k0L00P0Pk0L00`3oool08>`7023/1`06023/1`040?ooo`0Pk0L08>`7023/1`80oooo100Pk0L01@3o
ool08>`70?ooo`0000008>`700@0oooo0P0Pk0L00`3oool08>`70?ooo`070?ooo`03023/1`3oool0
oooo03`0oooo00<000000?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool0:03oool00`0P
k0L0oooo0?ooo`060?ooo`808>`70`3oool0200Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`7
103oool3023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7
023/1`04023/1`030?ooo`0Pk0L0oooo00L08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00<08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`03
0?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01P0Pk0L0103oool08>`7023/1`0Pk0L20?oo
o`@08>`700D0oooo023/1`3oool00000023/1`040?ooo`808>`700<0oooo023/1`3oool01`3oool0
0`0Pk0L0oooo0?ooo`0l0?ooo`030000003oool0oooo01X0oooo000H0?ooo`030000003oool0oooo
02P0oooo00<08>`70?ooo`3oool01P3oool2023/1`<0oooo00P08>`70?ooo`3oool08>`70?ooo`0P
k0L0oooo023/1`@0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0oooo00@08>`7
00<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`700<08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0P
k0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0P
k0L08>`70P3oool4023/1`050?ooo`0Pk0L0oooo0000000Pk0L0103oool2023/1`030?ooo`0Pk0L0
oooo00H0oooo00<08>`70?ooo`3oool0?@3oool00`000000oooo0?ooo`0J0?ooo`00603oool00`00
0000oooo0?ooo`0X0?ooo`03023/1`3oool0oooo00H0oooo0P0Pk0L30?ooo`08023/1`3oool0oooo
023/1`3oool08>`70?ooo`0Pk0L40?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7
0?ooo`04023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`3oool01`0Pk0L00`3oool08>`7
023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`70?ooo`04023/1`03
0?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L02`0Pk0L0103oool08>`7023/1`0Pk0L20?oo
o`@08>`700D0oooo023/1`3oool00000023/1`040?ooo`808>`700<0oooo023/1`3oool01P3oool0
0`0Pk0L0oooo0?ooo`0m0?ooo`030000003oool0oooo01X0oooo000H0?ooo`030000003oool0oooo
02P0oooo00<08>`70?ooo`3oool01P3oool2023/1`<0oooo00P08>`70?ooo`3oool08>`70?ooo`0P
k0L0oooo023/1`@0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0oooo00@08>`7
00<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`70?ooo`07023/1`030?ooo`0Pk0L08>`700<08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0P
k0L00P0Pk0L00`3oool08>`7023/1`0;023/1`040?ooo`0Pk0L08>`7023/1`80oooo100Pk0L01@3o
ool08>`70?ooo`0000008>`700@0oooo0P0Pk0L00`3oool08>`70?ooo`060?ooo`03023/1`3oool0
oooo03d0oooo00<000000?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool0:03oool00`0P
k0L0oooo0?ooo`060?ooo`808>`70`3oool0200Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`7
103oool3023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7
023/1`04023/1`030?ooo`0Pk0L0oooo00L08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00<08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`03
0?ooo`0Pk0L08>`700/08>`700@0oooo023/1`0Pk0L08>`70P3oool4023/1`050?ooo`0Pk0L0oooo
0000000Pk0L0103oool2023/1`030?ooo`0Pk0L0oooo00H0oooo00<08>`70?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0X0?ooo`03023/1`3oool0oooo
00H0oooo0P0Pk0L30?ooo`08023/1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L40?ooo`<08>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700@08>`7
00<0oooo023/1`3oool01`0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3o
ool00`0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0P
k0L02`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`@08>`700D0oooo023/1`3oool00000023/1`04
0?ooo`808>`700<0oooo023/1`3oool01P3oool00`0Pk0L0oooo0?ooo`0m0?ooo`030000003oool0
oooo01X0oooo000H0?ooo`030000003oool0oooo02P0oooo00<08>`70?ooo`3oool01P3oool2023/
1`<0oooo00P08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo023/1`@0oooo0`0Pk0L00`3oool08>`7
023/1`02023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7
0?ooo`07023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`03
0?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`0;023/1`04
0?ooo`0Pk0L08>`7023/1`80oooo100Pk0L0103oool08>`70?ooo`0000050?ooo`808>`700<0oooo
023/1`3oool01P3oool00`0Pk0L0oooo0?ooo`0m0?ooo`030000003oool0oooo01X0oooo000H0?oo
o`030000003oool0oooo02P0oooo00<08>`70?ooo`3oool01P3oool00`0Pk0L0oooo023/1`020?oo
o`08023/1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L40?ooo`<08>`700<0oooo023/1`0Pk0L0
0P0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`3oool0
1`0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool0
8>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool02`0Pk0L0103oool0
8>`7023/1`0Pk0L20?ooo`@08>`700@0oooo023/1`3oool000001@3oool2023/1`030?ooo`0Pk0L0
oooo00H0oooo00<08>`70?ooo`3oool0?@3oool00`000000oooo0?ooo`0J0?ooo`00603oool00`00
0000oooo0?ooo`0X0?ooo`03023/1`3oool0oooo00H0oooo00<08>`70?ooo`0Pk0L00P3oool0100P
k0L0oooo0?ooo`0Pk0L20?ooo`808>`7103oool3023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`3oool0100Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L0oooo00L08>`700<0oooo
023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`700<0oooo023/1`3oool0100P
k0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0oooo00/08>`700@0oooo023/1`0Pk0L08>`7
0P3oool4023/1`040?ooo`0Pk0L0oooo000000D0oooo0P0Pk0L00`3oool08>`70?ooo`060?ooo`03
023/1`3oool0oooo03d0oooo00<000000?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool0
9`3oool00`0Pk0L0oooo0?ooo`070?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`3oool0
0P0Pk0L00`3oool08>`7023/1`040?ooo`808>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7
0?ooo`04023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`3oool01`0Pk0L00`3oool08>`7
023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`7023/1`04023/1`03
0?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool02@0Pk0L00`3oool08>`70?ooo`03023/1`80
oooo100Pk0L0103oool08>`70?ooo`0000050?ooo`808>`700<0oooo023/1`3oool01P3oool00`0P
k0L0oooo0?ooo`0m0?ooo`030000003oool0oooo01X0oooo000H0?ooo`030000003oool0oooo02L0
oooo00<08>`70?ooo`3oool01`3oool00`0Pk0L0oooo023/1`030?ooo`05023/1`3oool08>`7023/
1`3oool00P0Pk0L40?ooo`808>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`70?ooo`04023/
1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`3oool01`0Pk0L00`3oool08>`7023/1`03023/
1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L0
8>`700808>`700<0oooo023/1`3oool02@0Pk0L00`3oool08>`70?ooo`03023/1`80oooo100Pk0L0
103oool08>`70?ooo`0000050?ooo`808>`700<0oooo023/1`3oool01P3oool00`0Pk0L0oooo0?oo
o`0m0?ooo`030000003oool0oooo01X0oooo000H0?ooo`030000003oool0oooo02L0oooo00<08>`7
0?ooo`3oool01`3oool00`0Pk0L0oooo023/1`030?ooo`05023/1`3oool08>`7023/1`3oool00P0P
k0L40?ooo`808>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0P
k0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo1`0Pk0L00`3oool08>`7023/1`03023/1`050?oo
o`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`70080
8>`700<0oooo023/1`0Pk0L02@0Pk0L00`3oool08>`70?ooo`03023/1`80oooo100Pk0L0103oool0
8>`70?ooo`0000050?ooo`808>`700<0oooo023/1`3oool01P3oool00`0Pk0L0oooo0?ooo`0m0?oo
o`030000003oool0oooo01X0oooo000H0?ooo`030000003oool0oooo02L0oooo00<08>`70?ooo`3o
ool01`3oool00`0Pk0L0oooo023/1`030?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L40?oo
o`808>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`7
00<08>`700@0oooo023/1`0Pk0L0oooo1`0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L0
8>`7023/1`3oool00`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700808>`700<0
oooo023/1`0Pk0L02@0Pk0L00`3oool08>`70?ooo`03023/1`80oooo100Pk0L0103oool08>`70?oo
o`0000050?ooo`808>`700<0oooo023/1`3oool01P3oool00`0Pk0L0oooo0?ooo`0m0?ooo`030000
003oool0oooo01X0oooo000H0?ooo`030000003oool0oooo02L0oooo00<08>`70?ooo`3oool01`3o
ool00`0Pk0L0oooo023/1`030?ooo`05023/1`3oool08>`7023/1`3oool00P0Pk0L40?ooo`808>`7
00<0oooo023/1`3oool00`0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700<08>`7
00@0oooo023/1`0Pk0L0oooo1`0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L0oooo023/
1`3oool00`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/
1`0Pk0L02@0Pk0L00`3oool08>`70?ooo`03023/1`80oooo100Pk0L0103oool08>`7023/1`000004
0?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool0oooo03d0oooo00<00000
0?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool09`3oool00`0Pk0L0oooo0?ooo`070?oo
o`03023/1`3oool08>`700<0oooo00P08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`<0oooo
0P0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L0
0`0Pk0L0103oool08>`7023/1`3oool7023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`3o
ool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3o
ool08>`7023/1`09023/1`030?ooo`0Pk0L0oooo00<08>`70P3oool4023/1`040?ooo`0Pk0L08>`7
000000@0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00D0oooo00<08>`70?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0W0?ooo`03023/1`3oool0oooo
00L0oooo00<08>`70?ooo`0Pk0L00`3oool0200Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool08>`7
0`3oool2023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7
023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool0
8>`70?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`02023/
1`030?ooo`0Pk0L08>`700X08>`70P3oool3023/1`80oooo100Pk0L0103oool08>`7023/1`000004
0?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool0oooo03d0oooo00<00000
0?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool09`3oool00`0Pk0L0oooo0?ooo`070?oo
o`03023/1`3oool08>`700<0oooo00P08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`<0oooo
0P0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L0
0`0Pk0L0103oool08>`7023/1`3oool7023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`3o
ool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3o
ool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700808>`70P3oool5023/1`030?ooo`0Pk0L00000
00@0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00D0oooo00<08>`70?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0W0?ooo`03023/1`3oool0oooo00L0
oooo00<08>`70?ooo`0Pk0L00`3oool0200Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool08>`70`3o
ool2023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/
1`03023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7
0?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`02023/1`03
0?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`700D0oooo023/1`3o
ool08>`7000000040?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool0oooo
03d0oooo00<000000?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool09`3oool00`0Pk0L0
oooo0?ooo`070?ooo`03023/1`3oool08>`700<0oooo00P08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0
oooo023/1`<0oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00@08>`700<0
oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool7023/1`030?ooo`0Pk0L08>`700<08>`7
00D0oooo023/1`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0P
k0L00P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700808>`70P3oool3023/1`05
0?ooo`0Pk0L0oooo023/1`000000103oool2023/1`030?ooo`0Pk0L0oooo00L0oooo00<08>`70?oo
o`3oool0?@3oool00`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0V0?ooo`03
023/1`3oool0oooo00P0oooo00<08>`70?ooo`0Pk0L00`3oool0200Pk0L0oooo023/1`0Pk0L0oooo
023/1`3oool08>`70`3oool2023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`3oool0100P
k0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`L08>`700<0oooo023/1`0Pk0L0
0`0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool0
8>`7023/1`02023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<0
8>`700D0oooo023/1`3oool08>`7000000040?ooo`808>`700<0oooo023/1`3oool01`3oool00`0P
k0L0oooo0?ooo`0m0?ooo`030000003oool0oooo01X0oooo000H0?ooo`030000003oool0oooo02H0
oooo00<08>`70?ooo`3oool0203oool00`0Pk0L0oooo023/1`030?ooo`08023/1`3oool08>`7023/
1`3oool08>`70?ooo`0Pk0L30?ooo`808>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`70?oo
o`04023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo1`0Pk0L00`3oool08>`7
023/1`03023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`04023/1`03
0?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`02023/1`80
oooo0`0Pk0L01@3oool08>`70?ooo`0Pk0L0000000@0oooo0P0Pk0L00`3oool08>`70?ooo`070?oo
o`03023/1`3oool0oooo03d0oooo00<000000?ooo`3oool06P3oool001P0oooo00<000000?ooo`3o
ool09P3oool00`0Pk0L0oooo0?ooo`080?ooo`03023/1`3oool08>`700<0oooo00P08>`70?ooo`0P
k0L08>`70?ooo`0Pk0L0oooo023/1`<0oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0P
k0L0oooo00@08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool7023/1`030?oo
o`0Pk0L08>`700<08>`700D0oooo023/1`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700@0
8>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`70080
8>`70P3oool3023/1`050?ooo`0Pk0L0oooo023/1`000000103oool2023/1`030?ooo`0Pk0L0oooo
00L0oooo00<08>`70?ooo`3oool0?@3oool00`000000oooo0?ooo`0J0?ooo`00603oool00`000000
oooo0?ooo`0V0?ooo`03023/1`3oool0oooo00P0oooo00<08>`70?ooo`0Pk0L00`3oool0200Pk0L0
oooo023/1`0Pk0L0oooo023/1`3oool08>`70`3oool2023/1`030?ooo`0Pk0L0oooo00<08>`700<0
oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`L08>`7
00<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0P
k0L0100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0P
k0L00P0Pk0L20?ooo`<08>`700D0oooo023/1`3oool08>`7000000040?ooo`808>`700<0oooo023/
1`3oool01`3oool00`0Pk0L0oooo0?ooo`0m0?ooo`030000003oool0oooo01X0oooo000H0?ooo`03
0000003oool0oooo02H0oooo00<08>`70?ooo`3oool0203oool00`0Pk0L0oooo023/1`030?ooo`08
023/1`3oool08>`7023/1`3oool08>`70?ooo`0Pk0L30?ooo`808>`700<0oooo023/1`3oool00`0P
k0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`3oool0oooo
1`0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L00`3oool0
8>`7023/1`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool0
8>`7023/1`02023/1`80oooo0`0Pk0L01@3oool08>`70?ooo`0Pk0L0000000@0oooo0P0Pk0L00`3o
ool08>`70?ooo`070?ooo`03023/1`3oool0oooo03d0oooo00<000000?ooo`3oool06P3oool001P0
oooo00<000000?ooo`3oool09P3oool00`0Pk0L0oooo0?ooo`080?ooo`03023/1`3oool08>`700<0
oooo00P08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`<0oooo0P0Pk0L00`3oool08>`70?oo
o`03023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`70?oo
o`3oool7023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`3oool08>`70?ooo`03023/1`03
0?ooo`0Pk0L08>`700<08>`70P3oool4023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0P
k0L00`0Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L01@3oool08>`70?ooo`0Pk0L00000
00@0oooo0P0Pk0L00`3oool08>`70?ooo`070?ooo`03023/1`3oool0oooo03d0oooo00<000000?oo
o`3oool06P3oool001P0oooo00<000000?ooo`3oool09P3oool00`0Pk0L0oooo0?ooo`080?ooo`03
023/1`3oool08>`700<0oooo00P08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`<0oooo0P0P
k0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00`0P
k0L0103oool08>`70?ooo`3oool7023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`3oool0
8>`70?ooo`03023/1`030?ooo`0Pk0L08>`700<08>`70P3oool3023/1`80oooo1P0Pk0L00`3oool0
8>`7023/1`03023/1`030?ooo`0Pk0L08>`700808>`70P3oool3023/1`050?ooo`0Pk0L0oooo023/
1`000000103oool2023/1`030?ooo`0Pk0L0oooo00L0oooo00<08>`70?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0V0?ooo`03023/1`3oool0oooo00P0
oooo00<08>`70?ooo`0Pk0L00`3oool0200Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool08>`70`3o
ool2023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/
1`03023/1`040?ooo`0Pk0L0oooo0?ooo`L08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7
0?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`<08>`70P3oool2023/1`05
0?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`<08>`700D0oooo
023/1`3oool08>`7000000040?ooo`808>`700<0oooo023/1`3oool01`3oool00`0Pk0L0oooo0?oo
o`0m0?ooo`030000003oool0oooo01X0oooo000H0?ooo`030000003oool0oooo02H0oooo00<08>`7
0?ooo`3oool0203oool00`0Pk0L0oooo023/1`030?ooo`08023/1`3oool08>`7023/1`3oool08>`7
0?ooo`0Pk0L30?ooo`808>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`70?ooo`04023/1`03
0?ooo`0Pk0L08>`700<08>`700@0oooo023/1`3oool0oooo0P0Pk0L00`3oool08>`7023/1`02023/
1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0
8>`700<08>`70P3oool3023/1`80oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700@0
oooo023/1`0Pk0L08>`70`3oool3023/1`050?ooo`0Pk0L0oooo023/1`000000103oool2023/1`03
0?ooo`0Pk0L0oooo00L0oooo00<08>`70?ooo`3oool0?@3oool00`000000oooo0?ooo`0J0?ooo`00
603oool00`000000oooo0?ooo`0V0?ooo`03023/1`3oool0oooo00P0oooo00<08>`70?ooo`0Pk0L0
0`3oool0200Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool08>`70`3oool2023/1`030?ooo`0Pk0L0
oooo00<08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L0
oooo0?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0P
k0L0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`03023/1`80oooo0`0Pk0L20?ooo`808>`7
00D0oooo023/1`0Pk0L08>`70?ooo`05023/1`040?ooo`0Pk0L08>`7023/1`<0oooo0`0Pk0L01@3o
ool08>`70?ooo`0Pk0L0000000@0oooo0P0Pk0L00`3oool08>`70?ooo`060?ooo`03023/1`3oool0
oooo03h0oooo00<000000?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool09@3oool00`0P
k0L0oooo0?ooo`090?ooo`03023/1`3oool08>`700<0oooo00P08>`70?ooo`0Pk0L08>`70?ooo`0P
k0L0oooo023/1`<0oooo100Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool0100Pk0L00`3o
ool08>`7023/1`03023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L0
0`3oool08>`7023/1`03023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/
1`03023/1`80oooo0`0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L01`0Pk0L0103oool08>`7023/
1`0Pk0L30?ooo`<08>`700D0oooo023/1`3oool08>`7000000040?ooo`808>`700<0oooo023/1`3o
ool01P3oool00`0Pk0L0oooo0?ooo`0n0?ooo`030000003oool0oooo01X0oooo000H0?ooo`030000
003oool0oooo02D0oooo00<08>`70?ooo`3oool02@3oool00`0Pk0L0oooo023/1`030?ooo`08023/
1`3oool08>`7023/1`3oool08>`70?ooo`0Pk0L30?ooo`05023/1`3oool08>`7023/1`3oool00`0P
k0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`3oool00`0P
k0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`3oool08>`7
0?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool3023/1`80oooo0P0Pk0L00`3oool0
8>`7023/1`07023/1`040?ooo`0Pk0L08>`7023/1`<0oooo0`0Pk0L01@3oool08>`70?ooo`0Pk0L0
000000@0oooo0P0Pk0L00`3oool08>`70?ooo`060?ooo`03023/1`3oool0oooo03h0oooo00<00000
0?ooo`3oool06P3oool001P0oooo00<000000?ooo`3oool09@3oool00`0Pk0L0oooo0?ooo`0:0?oo
o`808>`70`3oool0200Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool08>`70`3oool01@0Pk0L0oooo
023/1`0Pk0L0oooo00<08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`04
0?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0
oooo00<08>`700<0oooo023/1`3oool00`0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo0`0P
k0L20?ooo``08>`700@0oooo023/1`0Pk0L08>`70`3oool3023/1`050?ooo`0Pk0L0oooo023/1`00
0000103oool2023/1`030?ooo`0Pk0L0oooo00H0oooo00<08>`70?ooo`3oool0?P3oool00`000000
oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0U0?ooo`03023/1`3oool0oooo00X0oooo
0P0Pk0L30?ooo`08023/1`3oool08>`7023/1`3oool08>`70?ooo`0Pk0L30?ooo`05023/1`3oool0
8>`7023/1`3oool00`0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700@0
oooo023/1`0Pk0L0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3o
ool00`0Pk0L00`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool3023/
1`80oooo300Pk0L0103oool08>`7023/1`0Pk0L30?ooo`<08>`700D0oooo023/1`3oool08>`70000
00040?ooo`808>`700<0oooo023/1`3oool01P3oool00`0Pk0L0oooo0?ooo`0n0?ooo`030000003o
ool0oooo01X0oooo000H0?ooo`030000003oool0oooo02D0oooo00<08>`70?ooo`3oool02P3oool2
023/1`<0oooo00P08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`<0oooo00D08>`70?ooo`0P
k0L08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L0103o
ool08>`7023/1`3oool3023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?oo
o`03023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`<08>`7
0P3oool<023/1`040?ooo`0Pk0L08>`7023/1`<0oooo0`0Pk0L01@3oool08>`70?ooo`0Pk0L00000
00@0oooo0P0Pk0L00`3oool08>`70?ooo`060?ooo`03023/1`3oool0oooo03h0oooo00<000000?oo
o`3oool06P3oool001P0oooo00<000000?ooo`3oool09@3oool00`0Pk0L0oooo0?ooo`0:0?ooo`80
8>`70`3oool0200Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool08>`70`3oool01@0Pk0L0oooo023/
1`0Pk0L0oooo00<08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`040?oo
o`0Pk0L08>`70?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00<08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo0`0Pk0L2
0?ooo``08>`700@0oooo023/1`0Pk0L08>`70`3oool3023/1`050?ooo`0Pk0L0oooo023/1`000000
103oool0100Pk0L0oooo0?ooo`0Pk0L70?ooo`03023/1`3oool0oooo03h0oooo00<000000?ooo`3o
ool06P3oool001P0oooo00<000000?ooo`3oool09@3oool00`0Pk0L0oooo0?ooo`0:0?ooo`808>`7
0`3oool0200Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool08>`70`3oool4023/1`070?ooo`0Pk0L0
8>`7023/1`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`0Pk0L0
oooo0`0Pk0L00`3oool08>`7023/1`06023/1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L0103o
ool08>`7023/1`3oool2023/1`80oooo0`0Pk0L20?ooo``08>`700@0oooo023/1`0Pk0L08>`70P3o
ool02@0Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool08>`7000000040?ooo`04023/1`3oool0oooo
023/1`L0oooo00<08>`70?ooo`3oool0?P3oool00`000000oooo0?ooo`0J0?ooo`00603oool00`00
0000oooo0?ooo`0U0?ooo`03023/1`3oool0oooo00X0oooo0P0Pk0L30?ooo`08023/1`3oool08>`7
023/1`3oool08>`70?ooo`0Pk0L30?ooo`@08>`700L0oooo023/1`0Pk0L08>`70?ooo`0Pk0L0oooo
00@08>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`7023/1`3oool3023/1`030?ooo`0Pk0L0
8>`700H08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`040?ooo`0Pk0L08>`70?ooo`808>`7
0P3oool3023/1`80oooo300Pk0L0103oool08>`7023/1`0Pk0L20?ooo`09023/1`3oool08>`7023/
1`3oool08>`70?ooo`0Pk0L0000000@0oooo00@08>`70?ooo`3oool08>`71`3oool00`0Pk0L0oooo
0?ooo`0n0?ooo`030000003oool0oooo01X0oooo000H0?ooo`030000003oool0oooo02D0oooo00<0
8>`70?ooo`3oool02P3oool2023/1`<0oooo00P08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/
1`<0oooo100Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool0100Pk0L00`3oool08>`7023/
1`02023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo023/1`0Pk0L01P0Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00D08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`<08>`70P3oool<023/
1`040?ooo`0Pk0L08>`7023/1`80oooo00T08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo023/1`00
0000103oool0100Pk0L0oooo0?ooo`0Pk0L70?ooo`03023/1`3oool0oooo03h0oooo00<000000?oo
o`3oool06P3oool001P0oooo00<000000?ooo`3oool09@3oool00`0Pk0L0oooo0?ooo`0:0?ooo`80
8>`70`3oool0200Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool08>`70`3oool4023/1`070?ooo`0P
k0L08>`7023/1`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`0P
k0L0oooo0`0Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo
023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo0`0Pk0L20?ooo``08>`700@0
oooo023/1`0Pk0L08>`70P3oool02@0Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool08>`700000004
0?ooo`04023/1`3oool0oooo023/1`L0oooo00<08>`70?ooo`3oool0?P3oool00`000000oooo0?oo
o`0J0?ooo`00603oool00`000000oooo0?ooo`0U0?ooo`03023/1`3oool0oooo00X0oooo0P0Pk0L3
0?ooo`08023/1`3oool0oooo023/1`3oool08>`70?ooo`0Pk0L30?ooo`@08>`700L0oooo023/1`0P
k0L08>`70?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L0103oool08>`7023/1`3o
ool3023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3oool08>`7
023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool3023/1`80oooo300Pk0L0103oool0
8>`7023/1`0Pk0L20?ooo`09023/1`3oool08>`7023/1`3oool08>`70?ooo`0Pk0L0000000@0oooo
00<08>`70?ooo`0Pk0L0203oool00`0Pk0L0oooo0?ooo`0n0?ooo`030000003oool0oooo01X0oooo
000H0?ooo`030000003oool0oooo02@0oooo00<08>`70?ooo`3oool02`3oool2023/1`<0oooo00P0
8>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo023/1`<0oooo100Pk0L01`3oool08>`7023/1`0Pk0L0
oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`040?ooo`0Pk0L08>`70?ooo`<08>`7
00<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool3023/1`030?ooo`0Pk0L08>`700<0
8>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`<08>`70P3oool:023/1`030?ooo`0Pk0L0oooo
00<08>`70P3oool02@0Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool08>`7000000040?ooo`03023/
1`3oool08>`700P0oooo00<08>`70?ooo`3oool0?P3oool00`000000oooo0?ooo`0J0?ooo`00603o
ool00`000000oooo0?ooo`0T0?ooo`03023/1`3oool0oooo00/0oooo0P0Pk0L30?ooo`06023/1`3o
ool0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`030?ooo`0Pk0L08>`70080
8>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`040?ooo`0Pk0L08>`70?oo
o`<08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool3023/1`030?ooo`0Pk0L0
8>`700<08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`80oooo2P0P
k0L00`3oool08>`70?ooo`03023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?ooo`03023/1`00
0000oooo00<0oooo00<08>`70?ooo`0Pk0L0203oool00`0Pk0L0oooo0?ooo`0n0?ooo`030000003o
ool0oooo01X0oooo000H0?ooo`030000003oool0oooo02@0oooo00<08>`70?ooo`3oool02`3oool2
023/1`<0oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00<08>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`7
00D0oooo023/1`0Pk0L08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0P
k0L0100Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/
1`0Pk0L00P0Pk0L20?ooo`X08>`700<0oooo023/1`3oool00`0Pk0L20?ooo`05023/1`3oool08>`7
0?ooo`0Pk0L00P3oool00`0Pk0L000000?ooo`030?ooo`03023/1`3oool08>`700P0oooo00<08>`7
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0T0?oo
o`03023/1`3oool0oooo00/0oooo0P0Pk0L30?ooo`06023/1`3oool0oooo023/1`3oool08>`70P3o
ool00`0Pk0L0oooo0?ooo`03023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L00P0P
k0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L00`3oool08>`7
023/1`03023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7
023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool:023/1`030?ooo`0Pk0L0oooo00<0
8>`70P3oool01@0Pk0L0oooo023/1`3oool08>`70080oooo00<08>`70000003oool00`3oool00`0P
k0L0oooo023/1`080?ooo`03023/1`3oool0oooo03h0oooo00<000000?ooo`3oool06P3oool001P0
oooo00<000000?ooo`3oool0903oool00`0Pk0L0oooo0?ooo`0;0?ooo`808>`70`3oool01P0Pk0L0
oooo0?ooo`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`70?ooo`04
023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0P
k0L0oooo00808>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L00`0P
k0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool:023/1`030?oo
o`0Pk0L0oooo00<08>`70P3oool01@0Pk0L0oooo023/1`3oool08>`70080oooo00<08>`70000003o
ool00`3oool00`0Pk0L0oooo023/1`080?ooo`03023/1`3oool0oooo03h0oooo00<000000?ooo`3o
ool06P3oool001P0oooo00<000000?ooo`3oool0903oool00`0Pk0L0oooo0?ooo`0;0?ooo`808>`7
0`3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L00`3o
ool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`D08>`700<0oooo
023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3o
ool;023/1`80oooo0`0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3oool00`0Pk0L00000
0?ooo`030?ooo`03023/1`3oool08>`700P0oooo00<08>`70?ooo`3oool0?P3oool00`000000oooo
0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0T0?ooo`03023/1`3oool0oooo00/0oooo0P0P
k0L30?ooo`06023/1`3oool0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo0?ooo`03023/1`03
0?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`05
0?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo1@0Pk0L00`3o
ool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L0
0`3oool08>`7023/1`0:023/1`80oooo0`0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L00P3o
ool00`0Pk0L000000?ooo`030?ooo`03023/1`3oool08>`700P0oooo00<08>`70?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0T0?ooo`03023/1`3oool0
oooo00/0oooo0P0Pk0L30?ooo`06023/1`3oool0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo
0?ooo`03023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7
023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`80
oooo1@0Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/
1`0Pk0L00P0Pk0L00`3oool08>`7023/1`0:023/1`80oooo0`0Pk0L20?ooo`<08>`700H0oooo023/
1`3oool0oooo023/1`0000040?ooo`03023/1`3oool08>`700P0oooo00<08>`70?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0I0?ooo`00603oool00`000000oooo0?ooo`0T0?ooo`03023/1`3oool0
oooo00/0oooo0P0Pk0L30?ooo`06023/1`3oool0oooo023/1`3oool08>`70P3oool00`0Pk0L0oooo
0?ooo`03023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7
023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`80
oooo1@0Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/
1`0Pk0L00P0Pk0L00`3oool08>`7023/1`0:023/1`80oooo0`0Pk0L20?ooo`<08>`700H0oooo023/
1`3oool0oooo023/1`0000040?ooo`03023/1`3oool08>`700P0oooo00<08>`70?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0I0?ooo`00603oool00`000000oooo0?ooo`0T0?ooo`03023/1`3oool0
oooo00/0oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`80oooo
00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`7
00<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700<0oooo023/1`0P
k0L00`0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool2023/
1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L02P0Pk0L20?ooo`<08>`70P3oool3023/
1`060?ooo`0Pk0L0oooo0?ooo`0Pk0L000000`3oool2023/1`030?ooo`0Pk0L0oooo00L0oooo00<0
8>`70?ooo`3oool0?`3oool00`000000oooo0?ooo`0I0?ooo`00603oool00`000000oooo0?ooo`0S
0?ooo`03023/1`3oool0oooo00`0oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo0?ooo`0P
k0L0oooo023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`70?ooo`04023/1`030?oo
o`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo0080
8>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool0
8>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L02P0Pk0L20?oo
o`<08>`70P3oool3023/1`060?ooo`0Pk0L0oooo0?ooo`0Pk0L000000`3oool2023/1`030?ooo`0P
k0L0oooo00L0oooo00<08>`70?ooo`3oool0?`3oool00`000000oooo0?ooo`0I0?ooo`00603oool0
0`000000oooo0?ooo`0S0?ooo`03023/1`3oool0oooo00`0oooo00<08>`70?ooo`0Pk0L00P3oool0
1P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`7
0?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`D08>`700<0oooo023/1`0P
k0L00`0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/
1`0Pk0L02P0Pk0L20?ooo`<08>`70P3oool3023/1`060?ooo`0Pk0L0oooo0?ooo`0Pk0L000000`3o
ool2023/1`030?ooo`0Pk0L0oooo00L0oooo00<08>`70?ooo`3oool0?`3oool00`000000oooo0?oo
o`0I0?ooo`00603oool00`000000oooo0?ooo`0S0?ooo`03023/1`3oool0oooo00`0oooo00<08>`7
0?ooo`0Pk0L00P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`3oool0
0`0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L0
0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`D0
8>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`7
00808>`700<0oooo023/1`0Pk0L02P0Pk0L20?ooo`<08>`70P3oool3023/1`060?ooo`0Pk0L0oooo
0?ooo`0Pk0L000000`3oool2023/1`030?ooo`0Pk0L0oooo00L0oooo00<08>`70?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0I0?ooo`00603oool00`000000oooo0?ooo`0S0?ooo`03023/1`3oool0
oooo00`0oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`80oooo
00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`7
00<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700<0oooo023/1`0P
k0L00`0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool2023/
1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L02P0Pk0L20?ooo`<08>`70P3oool3023/
1`030?ooo`0Pk0L0oooo00808>`700@000000?ooo`3oool0oooo0P0Pk0L00`3oool08>`70?ooo`07
0?ooo`03023/1`3oool0oooo03l0oooo00<000000?ooo`3oool06@3oool001P0oooo00<000000?oo
o`3oool08`3oool00`0Pk0L0oooo0?ooo`0<0?ooo`03023/1`3oool08>`70080oooo00H08>`70?oo
o`3oool08>`70?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`3oool0100P
k0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`7
0?ooo`02023/1`030?ooo`0Pk0L08>`700<08>`70P3oool5023/1`030?ooo`0Pk0L08>`700808>`7
0P3oool2023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L02P0Pk0L20?ooo`<0
8>`70P3oool3023/1`030?ooo`0Pk0L0oooo00808>`700@000000?ooo`3oool0oooo0P0Pk0L00`3o
ool08>`70?ooo`070?ooo`03023/1`3oool0oooo03l0oooo00<000000?ooo`3oool06@3oool001P0
oooo00<000000?ooo`3oool08`3oool00`0Pk0L0oooo0?ooo`0<0?ooo`03023/1`3oool08>`70080
oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L20?ooo`03023/1`3oool0oooo00<08>`700<0oooo
023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L08>`700<08>`70P3oool5023/1`030?ooo`0Pk0L0
8>`700808>`70P3oool2023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L02P0P
k0L20?ooo`<08>`70P3oool3023/1`030?ooo`0Pk0L0oooo00808>`700D000000?ooo`3oool0oooo
023/1`020?ooo`03023/1`3oool0oooo00H0oooo00<08>`70?ooo`3oool0?`3oool00`000000oooo
0?ooo`0I0?ooo`00603oool00`000000oooo0?ooo`0S0?ooo`03023/1`3oool0oooo00`0oooo00<0
8>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`80oooo00<08>`70?ooo`3o
ool00`0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0P
k0L00P0Pk0L00`3oool08>`7023/1`020?ooo`808>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`D0
8>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3o
ool08>`7023/1`0:023/1`80oooo0`0Pk0L20?ooo`<08>`700<0oooo023/1`3oool00P0Pk0L01@00
0000oooo0?ooo`3oool08>`70080oooo00<08>`70?ooo`3oool01@3oool00`0Pk0L0oooo0?ooo`10
0?ooo`030000003oool0oooo01T0oooo000H0?ooo`030000003oool0oooo02<0oooo00<08>`70?oo
o`3oool0303oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3oool0oooo023/1`3oool08>`70P3o
ool00`0Pk0L0oooo0?ooo`03023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0P
k0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`70080oooo0P0Pk0L00`3oool08>`7023/
1`03023/1`80oooo1@0Pk0L00`3oool08>`7023/1`02023/1`80oooo0P0Pk0L0103oool08>`7023/
1`3oool4023/1`030?ooo`0Pk0L08>`700X08>`70P3oool3023/1`80oooo0`0Pk0L00`3oool08>`7
0?ooo`02023/1`050000003oool0oooo0?ooo`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`050?ooo`03
023/1`3oool0oooo0400oooo00<000000?ooo`3oool06@3oool001P0oooo00<000000?ooo`3oool0
8`3oool00`0Pk0L0oooo0?ooo`0<0?ooo`03023/1`3oool08>`700<0oooo00D08>`70?ooo`0Pk0L0
oooo023/1`020?ooo`04023/1`3oool0oooo0?ooo`808>`700<0oooo023/1`3oool0100Pk0L00`3o
ool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P3oool2023/
1`030?ooo`0Pk0L08>`700<08>`70P3oool5023/1`030?ooo`0Pk0L08>`700808>`70P3oool2023/
1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L02P0Pk0L20?ooo`<08>`70P3oool3
023/1`030?ooo`0Pk0L0oooo00808>`700D000000?ooo`3oool0oooo023/1`020?ooo`03023/1`3o
ool0oooo00D0oooo00<08>`70?ooo`3oool0@03oool00`000000oooo0?ooo`0I0?ooo`00603oool0
0`000000oooo0?ooo`0S0?ooo`03023/1`3oool0oooo00`0oooo00<08>`70?ooo`0Pk0L00`3oool0
1@0Pk0L0oooo023/1`3oool08>`70080oooo00@08>`70?ooo`3oool0oooo100Pk0L00`3oool08>`7
023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7
023/1`020?ooo`808>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L0
0P0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`7023/1`0:023/1`80
oooo0`0Pk0L20?ooo`<08>`700<0oooo023/1`3oool00P0Pk0L01`000000oooo0?ooo`3oool08>`7
0?ooo`0Pk0L0203oool00`0Pk0L0oooo0?ooo`100?ooo`030000003oool0oooo01T0oooo000H0?oo
o`030000003oool0oooo02<0oooo00<08>`70?ooo`3oool0303oool00`0Pk0L0oooo023/1`030?oo
o`05023/1`3oool08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo0?ooo`3oool08>`70?ooo`808>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700808>`7
00<0oooo023/1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L08>`700<08>`70P3oool5023/1`030?oo
o`0Pk0L08>`700808>`70P3oool2023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0P
k0L02P0Pk0L20?ooo`<08>`70P3oool3023/1`030?ooo`0Pk0L0oooo00808>`700L000000?ooo`3o
ool0oooo023/1`3oool08>`700P0oooo00<08>`70?ooo`3oool0@03oool00`000000oooo0?ooo`0I
0?ooo`00603oool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool0oooo00d0oooo00<08>`70?oo
o`0Pk0L00`3oool00`0Pk0L0oooo023/1`02023/1`80oooo00H08>`70?ooo`3oool0oooo023/1`3o
ool2023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/
1`02023/1`030?ooo`0Pk0L08>`70080oooo0P0Pk0L00`3oool08>`7023/1`03023/1`80oooo1@0P
k0L00`3oool08>`7023/1`02023/1`80oooo0P0Pk0L0103oool08>`7023/1`3oool4023/1`030?oo
o`0Pk0L08>`700X08>`70P3oool3023/1`80oooo0`0Pk0L00`3oool08>`70?ooo`02023/1`070000
003oool0oooo0?ooo`0Pk0L0oooo023/1`080?ooo`03023/1`3oool0oooo0400oooo00<000000?oo
o`3oool06@3oool001P0oooo00<000000?ooo`3oool08P3oool00`0Pk0L0oooo0?ooo`0=0?ooo`03
023/1`3oool08>`700<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?ooo`06023/1`3oool0oooo0?oo
o`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo
023/1`0Pk0L01@0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`D08>`700<0oooo
023/1`0Pk0L00P0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`7023/
1`0:023/1`80oooo0`0Pk0L20?ooo`<08>`700<0oooo023/1`3oool00P0Pk0L01`000000oooo0?oo
o`3oool08>`70?ooo`0Pk0L0203oool00`0Pk0L0oooo0?ooo`100?ooo`030000003oool0oooo01T0
oooo000H0?ooo`030000003oool0oooo0280oooo00<08>`70?ooo`3oool03@3oool00`0Pk0L0oooo
023/1`030?ooo`03023/1`3oool08>`700808>`70P3oool01P0Pk0L0oooo0?ooo`3oool08>`70?oo
o`808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L08>`7
00D08>`70P3oool2023/1`030?ooo`0Pk0L08>`700<08>`70P3oool5023/1`030?ooo`0Pk0L08>`7
00808>`70P3oool2023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L02P0Pk0L2
0?ooo`<08>`70P3oool3023/1`030?ooo`0Pk0L0oooo00808>`700L000000?ooo`3oool0oooo023/
1`3oool08>`700P0oooo00<08>`70?ooo`3oool0@03oool00`000000oooo0?ooo`0I0?ooo`00603o
ool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool0oooo00d0oooo00<08>`70?ooo`0Pk0L00`3o
ool00`0Pk0L0oooo023/1`02023/1`80oooo00H08>`70?ooo`3oool0oooo023/1`3oool2023/1`03
0?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`06023/1`04
0?ooo`0Pk0L08>`70?ooo`D08>`70P3oool5023/1`030?ooo`0Pk0L08>`700808>`70P3oool2023/
1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L02P0Pk0L20?ooo`<08>`70P3oool3
023/1`030?ooo`0Pk0L0oooo00808>`700L000000?ooo`3oool0oooo023/1`3oool08>`700P0oooo
00<08>`70?ooo`3oool0@03oool00`000000oooo0?ooo`0I0?ooo`00603oool00`000000oooo0?oo
o`0R0?ooo`03023/1`3oool0oooo00d0oooo00<08>`70?ooo`0Pk0L00`3oool0200Pk0L0oooo023/
1`0Pk0L0oooo023/1`3oool08>`70`3oool01@0Pk0L0oooo023/1`0Pk0L0oooo00@08>`700<0oooo
023/1`3oool00P0Pk0L00`3oool08>`7023/1`06023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700@0
oooo023/1`3oool0oooo1@0Pk0L00`3oool08>`7023/1`02023/1`80oooo0P0Pk0L0103oool08>`7
023/1`3oool4023/1`030?ooo`0Pk0L08>`700X08>`70P3oool3023/1`80oooo100Pk0L20?ooo`80
8>`700L000000?ooo`3oool0oooo023/1`3oool08>`700P0oooo00<08>`70?ooo`3oool0@03oool0
0`000000oooo0?ooo`0I0?ooo`00603oool00`000000oooo0?ooo`0R0?ooo`03023/1`3oool0oooo
00d0oooo00<08>`70?ooo`0Pk0L00`3oool0200Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool08>`7
0`3oool01@0Pk0L0oooo023/1`0Pk0L0oooo00@08>`700<0oooo023/1`3oool00P0Pk0L00`3oool0
8>`7023/1`06023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700@0oooo023/1`3oool0oooo1@0Pk0L0
0`3oool08>`7023/1`02023/1`80oooo0P0Pk0L0103oool08>`7023/1`3oool3023/1`80oooo300P
k0L20?ooo`808>`70`3oool4023/1`80oooo0P0Pk0L01`000000oooo0?ooo`3oool08>`70?ooo`0P
k0L0203oool00`0Pk0L0oooo0?ooo`100?ooo`030000003oool0oooo01T0oooo000H0?ooo`030000
003oool0oooo0280oooo00<08>`70?ooo`3oool03@3oool00`0Pk0L0oooo023/1`030?ooo`06023/
1`3oool08>`7023/1`3oool08>`70P3oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00808>`700<0oooo
023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo
023/1`0Pk0L0oooo0`0Pk0L0103oool08>`70?ooo`3oool5023/1`030?ooo`0Pk0L08>`700808>`7
0P3oool2023/1`040?ooo`0Pk0L08>`70?ooo`<08>`70P3oool<023/1`80oooo0P0Pk0L30?ooo`@0
8>`70P3oool2023/1`070000003oool0oooo0?ooo`0Pk0L0oooo023/1`080?ooo`03023/1`3oool0
oooo0400oooo00<000000?ooo`3oool06@3oool001P0oooo00<000000?ooo`3oool08P3oool00`0P
k0L0oooo0?ooo`0=0?ooo`03023/1`3oool08>`700<0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0P
k0L20?ooo`05023/1`3oool0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`02023/1`030?oo
o`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L01P0Pk0L0103oool08>`7023/1`3oool3023/1`04
0?ooo`0Pk0L0oooo0?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`808>`700@0oooo023/
1`0Pk0L0oooo0`0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`808>`70`3oool4
023/1`80oooo0P0Pk0L01`000000oooo0?ooo`3oool08>`70?ooo`0Pk0L0203oool00`0Pk0L0oooo
0?ooo`100?ooo`030000003oool0oooo01T0oooo000H0?ooo`030000003oool0oooo0280oooo00<0
8>`70?ooo`3oool03@3oool00`0Pk0L0oooo023/1`030?ooo`06023/1`3oool08>`7023/1`3oool0
8>`70P3oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3o
ool08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L0
103oool08>`70?ooo`3oool5023/1`030?ooo`0Pk0L08>`700808>`70P3oool2023/1`040?ooo`0P
k0L08>`70?ooo`<08>`70P3oool3023/1`030?ooo`0Pk0L08>`700H08>`70P3oool2023/1`<0oooo
100Pk0L20?ooo`808>`700L000000?ooo`3oool0oooo023/1`3oool08>`700P0oooo00<08>`70?oo
o`3oool0@03oool00`000000oooo0?ooo`0I0?ooo`00603oool00`000000oooo0?ooo`0R0?ooo`03
023/1`3oool0oooo00d0oooo00<08>`70?ooo`0Pk0L00`3oool01P0Pk0L0oooo023/1`0Pk0L0oooo
023/1`80oooo00D08>`70?ooo`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700808>`700<0
oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`06023/1`040?ooo`0Pk0L08>`70?ooo`<08>`7
00@0oooo023/1`3oool0oooo1@0Pk0L00`3oool08>`7023/1`02023/1`80oooo0P0Pk0L0103oool0
8>`7023/1`3oool3023/1`80oooo0`0Pk0L00`3oool08>`7023/1`06023/1`80oooo0P0Pk0L30?oo
o`@08>`70P3oool2023/1`070000003oool0oooo0?ooo`0Pk0L0oooo023/1`080?ooo`03023/1`3o
ool0oooo0400oooo00<000000?ooo`3oool06@3oool001P0oooo00<000000?ooo`3oool08@3oool0
0`0Pk0L0oooo0?ooo`0>0?ooo`03023/1`3oool08>`700<0oooo00H08>`70?ooo`0Pk0L08>`70?oo
o`0Pk0L20?ooo`05023/1`3oool0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`02023/1`03
0?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L01P0Pk0L0103oool08>`7023/1`3oool3023/
1`040?ooo`0Pk0L0oooo0?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`808>`700@0oooo
023/1`0Pk0L0oooo0`0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L0103oool08>`70?oo
o`3oool2023/1`<0oooo100Pk0L20?ooo`808>`700L000000?ooo`3oool0oooo023/1`3oool08>`7
00P0oooo00<08>`70?ooo`3oool0@03oool00`000000oooo0?ooo`0I0?ooo`00603oool00`000000
oooo0?ooo`0Q0?ooo`03023/1`3oool0oooo00l0oooo0P0Pk0L30?ooo`06023/1`3oool08>`7023/
1`3oool08>`70P3oool01`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool01@0Pk0L00`3oool08>`7
0?ooo`02023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L0103oool0
8>`70?ooo`3oool5023/1`030?ooo`0Pk0L08>`700808>`70P3oool5023/1`040?ooo`0Pk0L08>`7
023/1`80oooo0`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L0oooo00<08>`70`3oool4
023/1`80oooo0P0Pk0L01`000000oooo0?ooo`3oool08>`70?ooo`0Pk0L0203oool00`0Pk0L0oooo
0?ooo`100?ooo`030000003oool0oooo01T0oooo000H0?ooo`030000003oool0oooo0240oooo00<0
8>`70?ooo`3oool03`3oool2023/1`<0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`07
023/1`3oool0oooo023/1`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo
023/1`0Pk0L01P0Pk0L0103oool08>`7023/1`3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`D08>`7
00<0oooo023/1`0Pk0L00P0Pk0L20?ooo`D08>`700@0oooo023/1`0Pk0L08>`70P3oool:023/1`03
0?ooo`0Pk0L0oooo00<08>`70`3oool4023/1`80oooo0P0Pk0L01`000000oooo0?ooo`3oool08>`7
0?ooo`0Pk0L0203oool00`0Pk0L0oooo0?ooo`100?ooo`030000003oool0oooo01T0oooo000H0?oo
o`030000003oool0oooo0240oooo00<08>`70?ooo`3oool03`3oool2023/1`<0oooo00H08>`70?oo
o`0Pk0L08>`70?ooo`0Pk0L20?ooo`07023/1`3oool0oooo023/1`3oool08>`70?ooo`05023/1`03
0?ooo`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L01P0Pk0L0103oool08>`7023/1`3oool3023/
1`040?ooo`0Pk0L0oooo0?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`D08>`700@0oooo
023/1`0Pk0L08>`70P3oool:023/1`030?ooo`0Pk0L0oooo00<08>`70`3oool2023/1`040?ooo`0P
k0L0oooo0?ooo`808>`700L000000?ooo`3oool0oooo023/1`3oool08>`700P0oooo00<08>`70?oo
o`3oool0@03oool00`000000oooo0?ooo`0I0?ooo`00603oool00`000000oooo0?ooo`0Q0?ooo`03
023/1`3oool0oooo00l0oooo0P0Pk0L30?ooo`06023/1`3oool08>`7023/1`3oool08>`70P3oool0
1`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool0100Pk0L0103oool08>`7023/1`3oool2023/1`03
0?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L0103oool08>`70?ooo`3oool5
023/1`030?ooo`0Pk0L08>`700808>`70P3oool5023/1`040?ooo`0Pk0L08>`7023/1`80oooo2`0P
k0L20?ooo`<08>`70`3oool2023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700L000000?ooo`3oool0
oooo023/1`3oool08>`700P0oooo00<08>`70?ooo`3oool0@03oool00`000000oooo0?ooo`0I0?oo
o`00603oool00`000000oooo0?ooo`0Q0?ooo`03023/1`3oool0oooo00l0oooo0P0Pk0L30?ooo`06
023/1`3oool08>`7023/1`3oool08>`70P3oool01`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool0
100Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0P
k0L0oooo0`0Pk0L0103oool08>`70?ooo`3oool5023/1`030?ooo`0Pk0L08>`700808>`70P3oool5
023/1`040?ooo`0Pk0L08>`7023/1`80oooo2`0Pk0L20?ooo`<08>`70`3oool2023/1`040?ooo`0P
k0L0oooo0?ooo`808>`700<000000?ooo`3oool00P0Pk0L00`3oool08>`70?ooo`070?ooo`03023/
1`3oool0oooo0400oooo00<000000?ooo`3oool06@3oool001L0oooo00<000000?ooo`3oool08P3o
ool00`0Pk0L0oooo0?ooo`0?0?ooo`808>`70`3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`80
oooo00L08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo00@08>`700@0oooo023/1`0Pk0L0oooo0P0P
k0L00`3oool08>`7023/1`06023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700@0oooo023/1`3oool0
oooo1@0Pk0L00`3oool08>`7023/1`02023/1`80oooo1@0Pk0L0103oool08>`7023/1`0Pk0L20?oo
o`/08>`70P3oool3023/1`<0oooo0P0Pk0L0103oool08>`70?ooo`3oool2023/1`030000003oool0
oooo00808>`700<0oooo023/1`3oool01`3oool00`0Pk0L0oooo0?ooo`100?ooo`030000003oool0
oooo01T0oooo000G0?ooo`030000003oool0oooo0280oooo00<08>`70?ooo`3oool03`3oool2023/
1`<0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`07023/1`3oool0oooo023/1`3oool0
8>`70?ooo`04023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L01P0Pk0L0103o
ool08>`7023/1`3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`D08>`700<0oooo023/1`0Pk0L00P0P
k0L20?ooo`D08>`700@0oooo023/1`0Pk0L08>`70P3oool;023/1`80oooo0`0Pk0L30?ooo`808>`7
00@0oooo023/1`3oool0oooo0P0Pk0L00`000000oooo0?ooo`02023/1`030?ooo`0Pk0L0oooo00L0
oooo00<08>`70?ooo`3oool0@03oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo
0?ooo`0R0?ooo`03023/1`3oool0oooo00l0oooo0P0Pk0L30?ooo`06023/1`3oool08>`7023/1`3o
ool08>`70P3oool01`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool0100Pk0L0103oool08>`7023/
1`3oool2023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L0103oool0
8>`70?ooo`3oool5023/1`030?ooo`0Pk0L08>`700808>`70P3oool5023/1`040?ooo`0Pk0L08>`7
023/1`80oooo2`0Pk0L20?ooo`<08>`70`3oool2023/1`040?ooo`0Pk0L0oooo0?ooo`808>`700<0
00000?ooo`3oool00`0Pk0L90?ooo`03023/1`3oool0oooo0400oooo00<000000?ooo`3oool06@3o
ool001L0oooo00<000000?ooo`3oool08P3oool00`0Pk0L0oooo0?ooo`0?0?ooo`808>`70`3oool0
1P0Pk0L0oooo023/1`0Pk0L0oooo023/1`80oooo00L08>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo
00@08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`06023/1`040?ooo`0Pk0L0
8>`70?ooo`<08>`700@0oooo023/1`3oool0oooo1@0Pk0L00`3oool08>`7023/1`02023/1`80oooo
1@0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`/08>`70P3oool3023/1`<0oooo0P0Pk0L0103oool0
8>`70?ooo`3oool2023/1`030000003oool0oooo00<08>`72@3oool00`0Pk0L0oooo0?ooo`100?oo
o`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo0280oooo00<08>`70?ooo`3o
ool03`3oool2023/1`<0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`07023/1`3oool0
oooo023/1`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L0
1P0Pk0L0103oool08>`7023/1`3oool3023/1`040?ooo`0Pk0L0oooo0?ooo`D08>`700<0oooo023/
1`0Pk0L00P0Pk0L20?ooo`D08>`700@0oooo023/1`0Pk0L08>`70P3oool;023/1`80oooo0`0Pk0L3
0?ooo`808>`700@0oooo023/1`3oool0oooo0P0Pk0L00`000000oooo0?ooo`03023/1`T0oooo00<0
8>`70?ooo`3oool0@03oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0Q
0?ooo`03023/1`3oool0oooo0100oooo0P0Pk0L30?ooo`06023/1`3oool08>`7023/1`3oool08>`7
0P3oool01`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/
1`030000000Pk0L08>`700@08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L01P3oool08>`7023/1`0P
k0L0oooo023/1`80oooo1@0Pk0L00`3oool08>`7023/1`02023/1`80oooo1@0Pk0L0103oool08>`7
023/1`0Pk0L20?ooo`/08>`70P3oool3023/1`<0oooo0P0Pk0L0103oool08>`70?ooo`3oool2023/
1`030000003oool0oooo00<08>`72@3oool00`0Pk0L0oooo0?ooo`100?ooo`030000003oool0oooo
01T0oooo000G0?ooo`030000003oool0oooo0240oooo00<08>`70?ooo`3oool0403oool2023/1`<0
oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?ooo`07023/1`3oool0oooo023/1`3oool08>`7
0?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<00000023/1`0Pk0L0100Pk0L0103oool08>`7
023/1`3oool2023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70P3oool5023/1`030?ooo`0Pk0L0
8>`700808>`70P3oool00`0Pk0L0oooo023/1`02023/1`040?ooo`0Pk0L08>`7023/1`80oooo2`0P
k0L20?ooo`<08>`70P3oool01@0Pk0L0oooo023/1`3oool08>`70080oooo0P0Pk0L00`000000oooo
0?ooo`03023/1`P0oooo00<08>`70?ooo`3oool0@@3oool00`000000oooo0?ooo`0I0?ooo`005`3o
ool00`000000oooo0?ooo`0Q0?ooo`03023/1`3oool0oooo0100oooo0P0Pk0L30?ooo`06023/1`3o
ool08>`7023/1`3oool08>`70P3oool01`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool0100Pk0L0
0`3oool08>`7023/1`02023/1`030000000Pk0L08>`700@08>`700@0oooo023/1`0Pk0L0oooo0P0P
k0L01P3oool08>`7023/1`0Pk0L0oooo023/1`80oooo1@0Pk0L00`3oool08>`7023/1`02023/1`80
oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`70?ooo`0:023/1`80oooo0`0Pk0L20?ooo`05
023/1`3oool08>`70?ooo`0Pk0L00P3oool2023/1`060000003oool0oooo023/1`3oool08>`7203o
ool00`0Pk0L0oooo0?ooo`110?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0
oooo0240oooo00<08>`70?ooo`3oool0403oool2023/1`<0oooo00H08>`70?ooo`0Pk0L08>`70?oo
o`0Pk0L20?ooo`07023/1`3oool0oooo023/1`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`7
00808>`700<00000023/1`0Pk0L0100Pk0L0103oool08>`7023/1`3oool2023/1`060?ooo`0Pk0L0
8>`7023/1`3oool08>`70P3oool5023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo
023/1`06023/1`030?ooo`0Pk0L0oooo00X08>`70P3oool3023/1`80oooo00D08>`70?ooo`0Pk0L0
oooo023/1`020?ooo`808>`700H000000?ooo`3oool08>`70?ooo`0Pk0L80?ooo`03023/1`3oool0
oooo0440oooo00<000000?ooo`3oool06@3oool001L0oooo00<000000?ooo`3oool08@3oool00`0P
k0L0oooo0?ooo`0@0?ooo`808>`70`3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`80oooo00L0
8>`70?ooo`3oool08>`70?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`000000
8>`7023/1`04023/1`040?ooo`0Pk0L08>`70?ooo`808>`700H0oooo023/1`0Pk0L08>`70?ooo`0P
k0L20?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool08>`700<08>`700H0
oooo023/1`0Pk0L0oooo023/1`3oool:023/1`80oooo0`0Pk0L20?ooo`05023/1`3oool08>`70?oo
o`0Pk0L00P3oool00`0Pk0L0oooo000000020?ooo`03023/1`3oool08>`700P0oooo00<08>`70?oo
o`3oool0@@3oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0Q0?ooo`03
023/1`3oool0oooo0100oooo0P0Pk0L30?ooo`06023/1`3oool08>`7023/1`3oool08>`70P3oool0
1`0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`030000
000Pk0L08>`700@08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L01P3oool08>`7023/1`0Pk0L0oooo
023/1`80oooo1@0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L0
1P3oool08>`7023/1`3oool08>`70?ooo`X08>`70P3oool3023/1`80oooo00D08>`70?ooo`0Pk0L0
oooo023/1`020?ooo`03023/1`3oool000000080oooo00<08>`70?ooo`0Pk0L0203oool00`0Pk0L0
oooo0?ooo`110?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo0240oooo
00<08>`70?ooo`3oool0403oool2023/1`<0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L20?oo
o`07023/1`3oool0oooo023/1`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<0
0000023/1`0Pk0L0100Pk0L0103oool08>`7023/1`3oool2023/1`060?ooo`0Pk0L08>`7023/1`3o
ool08>`70P3oool5023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo023/1`03023/
1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo2P0Pk0L20?ooo`<08>`70P3oool01@0Pk0L0oooo023/
1`3oool08>`70080oooo00<08>`70?ooo`0000000P3oool00`0Pk0L0oooo023/1`080?ooo`03023/
1`3oool0oooo0440oooo00<000000?ooo`3oool06@3oool001L0oooo00<000000?ooo`3oool08@3o
ool00`0Pk0L0oooo0?ooo`0@0?ooo`808>`70`3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`80
oooo00D08>`70?ooo`3oool08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700808>`700<00000023/
1`0Pk0L0100Pk0L0103oool08>`7023/1`3oool2023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`7
0P3oool5023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo023/1`03023/1`060?oo
o`0Pk0L08>`70?ooo`0Pk0L0oooo2P0Pk0L20?ooo`<08>`70P3oool0100Pk0L0oooo023/1`0Pk0L3
0?ooo`03023/1`3oool000000080oooo00<08>`70?ooo`0Pk0L0203oool00`0Pk0L0oooo0?ooo`11
0?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo0240oooo00<08>`70?oo
o`3oool0403oool2023/1`<0oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L20?ooo`04023/1`3o
ool0oooo023/1`80oooo1@0Pk0L00`3oool08>`7023/1`02023/1`030000000Pk0L08>`700@08>`7
00@0oooo023/1`0Pk0L0oooo0P0Pk0L01P3oool08>`7023/1`0Pk0L0oooo023/1`80oooo1@0Pk0L0
0`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L01P3oool08>`7023/1`3o
ool08>`70?ooo`X08>`70P3oool3023/1`80oooo00@08>`70?ooo`0Pk0L08>`70`3oool00`0Pk0L0
oooo000000020?ooo`03023/1`3oool08>`700P0oooo00<08>`70?ooo`3oool0@@3oool00`000000
oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0Q0?ooo`03023/1`3oool0oooo0100oooo
0P0Pk0L30?ooo`06023/1`3oool0oooo023/1`3oool08>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L2
0?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L00`0000008>`7023/1`04023/1`040?ooo`0Pk0L0
8>`70?ooo`808>`700H0oooo023/1`0Pk0L08>`70?ooo`0Pk0L20?ooo`D08>`700<0oooo023/1`0P
k0L00P0Pk0L20?ooo`03023/1`3oool08>`700<08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool:
023/1`80oooo0`0Pk0L20?ooo`04023/1`3oool08>`7023/1`<0oooo00<08>`70?ooo`0000000P3o
ool00`0Pk0L0oooo023/1`080?ooo`03023/1`3oool0oooo0440oooo00<000000?ooo`3oool06@3o
ool001L0oooo00<000000?ooo`3oool0803oool00`0Pk0L0oooo0?ooo`0A0?ooo`03023/1`3oool0
8>`70080oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L20?ooo`04023/1`3oool0oooo023/1`80
oooo1@0Pk0L00`3oool08>`70?ooo`02023/1`030000000Pk0L08>`700@08>`700@0oooo023/1`0P
k0L0oooo0P0Pk0L01P3oool08>`7023/1`0Pk0L0oooo023/1`80oooo100Pk0L20?ooo`@08>`70P3o
ool00`0Pk0L0oooo023/1`03023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo2P0Pk0L20?ooo`<0
8>`70P3oool4023/1`80oooo0P0Pk0L01`3oool000000?ooo`3oool08>`70?ooo`0Pk0L0203oool0
0`0Pk0L0oooo0?ooo`110?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo
0200oooo00<08>`70?ooo`3oool04@3oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3oool0oooo
023/1`3oool08>`70P3oool0100Pk0L0oooo0?ooo`0Pk0L20?ooo`D08>`700<0oooo023/1`3oool0
0P0Pk0L00`0000008>`7023/1`04023/1`040?ooo`0Pk0L08>`70?ooo`808>`700H0oooo023/1`0P
k0L08>`70?ooo`0Pk0L20?ooo`@08>`70P3oool4023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L0
1P3oool08>`7023/1`3oool08>`70?ooo`X08>`70P3oool3023/1`80oooo100Pk0L20?ooo`808>`7
00L0oooo0000003oool0oooo023/1`3oool08>`700P0oooo00<08>`70?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0P0?ooo`03023/1`3oool0oooo0140
oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`<0oooo00<08>`7
0?ooo`0Pk0L00P3oool5023/1`030?ooo`0Pk0L0oooo00808>`700<00000023/1`0Pk0L0100Pk0L0
103oool08>`7023/1`3oool2023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70P3oool4023/1`80
oooo100Pk0L20?ooo`03023/1`3oool08>`700<08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool:
023/1`80oooo0`0Pk0L20?ooo`@08>`70P3oool2023/1`070?ooo`000000oooo0?ooo`0Pk0L0oooo
023/1`080?ooo`03023/1`3oool0oooo0440oooo00<000000?ooo`3oool06@3oool001L0oooo00<0
00000?ooo`3oool0803oool00`0Pk0L0oooo0?ooo`0A0?ooo`03023/1`3oool08>`70080oooo00H0
8>`70?ooo`3oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`70080oooo1@0Pk0L00`3oool0
8>`70?ooo`02023/1`030000000Pk0L08>`700@08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L01P3o
ool08>`7023/1`0Pk0L0oooo023/1`80oooo100Pk0L20?ooo`@08>`70P3oool00`0Pk0L0oooo023/
1`03023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo2P0Pk0L20?ooo`<08>`70P3oool4023/1`80
oooo0P0Pk0L01`3oool000000?ooo`3oool08>`70?ooo`0Pk0L0203oool00`0Pk0L0oooo0?ooo`11
0?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo0200oooo00<08>`70?oo
o`3oool04@3oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3oool0oooo023/1`3oool08>`70`3o
ool00`0Pk0L0oooo023/1`020?ooo`D08>`700<0oooo023/1`3oool00P0Pk0L00`0000008>`7023/
1`04023/1`040?ooo`0Pk0L08>`70?ooo`808>`700H0oooo023/1`0Pk0L08>`70?ooo`0Pk0L20?oo
o`@08>`70P3oool4023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L01P3oool08>`7023/1`3oool0
8>`70?ooo`X08>`70P3oool3023/1`80oooo100Pk0L20?ooo`808>`700<0oooo0000003oool00P0P
k0L00`3oool08>`70?ooo`070?ooo`03023/1`3oool0oooo0440oooo00<000000?ooo`3oool06@3o
ool001L0oooo00<000000?ooo`3oool0803oool00`0Pk0L0oooo0?ooo`0A0?ooo`03023/1`3oool0
8>`70080oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`70080oooo
1@0Pk0L00`3oool08>`70?ooo`02023/1`030000000Pk0L08>`700@08>`700@0oooo023/1`0Pk0L0
oooo0P0Pk0L01P3oool08>`7023/1`0Pk0L0oooo023/1`80oooo100Pk0L20?ooo`@08>`70P3oool0
0`0Pk0L0oooo023/1`03023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo2P0Pk0L20?ooo`<08>`7
0P3oool4023/1`80oooo0P0Pk0L00`3oool000000?ooo`02023/1`030?ooo`0Pk0L0oooo00L0oooo
00<08>`70?ooo`3oool0@@3oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?oo
o`0P0?ooo`03023/1`3oool0oooo0140oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo0?oo
o`0Pk0L0oooo023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool5023/1`030?ooo`0Pk0L0oooo0080
8>`700<00000023/1`0Pk0L0100Pk0L0103oool08>`7023/1`3oool2023/1`060?ooo`0Pk0L08>`7
023/1`3oool08>`70P3oool4023/1`80oooo100Pk0L20?ooo`03023/1`3oool08>`700<08>`700H0
oooo023/1`0Pk0L0oooo023/1`3oool:023/1`80oooo0`0Pk0L20?ooo`@08>`70P3oool2023/1`03
0?ooo`000000oooo00808>`700<0oooo023/1`3oool01`3oool00`0Pk0L0oooo0?ooo`110?ooo`03
0000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo0200oooo00<08>`70?ooo`3oool0
4@3oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3oool0oooo023/1`3oool08>`70`3oool00`0P
k0L0oooo023/1`020?ooo`D08>`700<0oooo023/1`3oool00P0Pk0L00`0000008>`7023/1`04023/
1`040?ooo`0Pk0L08>`70?ooo`808>`700H0oooo023/1`0Pk0L08>`70?ooo`0Pk0L20?ooo`@08>`7
0P3oool4023/1`80oooo00<08>`70?ooo`0Pk0L00`0Pk0L01P3oool08>`7023/1`3oool08>`70?oo
o`X08>`70P3oool3023/1`80oooo100Pk0L20?ooo`808>`700<0oooo0000003oool00P0Pk0L00`3o
ool08>`70?ooo`070?ooo`03023/1`3oool0oooo0440oooo00<000000?ooo`3oool06@3oool001L0
oooo00<000000?ooo`3oool0803oool00`0Pk0L0oooo0?ooo`0A0?ooo`03023/1`3oool08>`70080
oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`70080oooo1@0Pk0L0
0`3oool08>`70?ooo`02023/1`030000000Pk0L08>`700@08>`700@0oooo023/1`0Pk0L0oooo0P0P
k0L01P3oool08>`7023/1`0Pk0L0oooo023/1`80oooo100Pk0L20?ooo`@08>`70P3oool00`0Pk0L0
oooo023/1`03023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo2P0Pk0L00`3oool08>`7023/1`02
023/1`80oooo100Pk0L20?ooo`808>`700<0oooo0000003oool00`0Pk0L90?ooo`03023/1`3oool0
oooo0440oooo00<000000?ooo`3oool06@3oool001L0oooo00<000000?ooo`3oool0803oool00`0P
k0L0oooo0?ooo`0A0?ooo`03023/1`3oool08>`70080oooo00H08>`70?ooo`3oool08>`70?ooo`0P
k0L30?ooo`03023/1`3oool08>`70080oooo1@0Pk0L00`3oool08>`70?ooo`02023/1`030000000P
k0L08>`700@08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L01P3oool08>`7023/1`0Pk0L0oooo023/
1`80oooo100Pk0L20?ooo`@08>`70P3oool00`0Pk0L0oooo023/1`03023/1`060?ooo`0Pk0L08>`7
0?ooo`0Pk0L0oooo2P0Pk0L00`3oool08>`7023/1`02023/1`80oooo100Pk0L20?ooo`808>`700<0
oooo0000003oool00`0Pk0L90?ooo`03023/1`3oool0oooo0440oooo00<000000?ooo`3oool06@3o
ool001L0oooo00<000000?ooo`3oool07`3oool00`0Pk0L0oooo0?ooo`0B0?ooo`03023/1`3oool0
8>`70080oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`70080oooo
1@0Pk0L00`3oool08>`70?ooo`02023/1`030000000Pk0L08>`700@08>`700@0oooo023/1`0Pk0L0
oooo0P0Pk0L01P3oool08>`7023/1`0Pk0L0oooo023/1`80oooo100Pk0L20?ooo`@08>`70P3oool0
0`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L0oooo00P08>`700<0oooo023/1`3oool0100Pk0L2
0?ooo`@08>`70P3oool2023/1`030?ooo`000000oooo00<08>`72@3oool00`0Pk0L0oooo0?ooo`11
0?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo01l0oooo00<08>`70?oo
o`3oool04P3oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3oool0oooo023/1`3oool08>`70`3o
ool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700808>`700<0oooo023/1`3oool00P0P
k0L00`0000008>`7023/1`04023/1`040?ooo`0Pk0L08>`70?ooo`808>`700H0oooo023/1`0Pk0L0
8>`70?ooo`0Pk0L20?ooo`@08>`70P3oool4023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3o
ool08>`70?ooo`08023/1`030?ooo`0Pk0L0oooo00@08>`70P3oool4023/1`80oooo0P0Pk0L00`3o
ool000000?ooo`03023/1`T0oooo00<08>`70?ooo`3oool0@@3oool00`000000oooo0?ooo`0I0?oo
o`005`3oool00`000000oooo0?ooo`0O0?ooo`03023/1`3oool0oooo0180oooo00<08>`70?ooo`0P
k0L00P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool0
0`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700<00000023/1`0Pk0L0100Pk0L0
103oool08>`7023/1`3oool2023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70P3oool4023/1`80
oooo100Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`3oool0200Pk0L00`3oool0
8>`70?ooo`04023/1`80oooo100Pk0L20?ooo`808>`700<0oooo0000003oool00`0Pk0L90?ooo`03
023/1`3oool0oooo0440oooo00<000000?ooo`3oool06@3oool001L0oooo00<000000?ooo`3oool0
7`3oool00`0Pk0L0oooo0?ooo`0B0?ooo`03023/1`3oool08>`70080oooo00H08>`70?ooo`3oool0
8>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3o
ool08>`70?ooo`02023/1`030000000Pk0L08>`700@08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L0
1P3oool08>`7023/1`0Pk0L0oooo023/1`80oooo100Pk0L20?ooo`@08>`70P3oool00`0Pk0L0oooo
023/1`06023/1`030?ooo`0Pk0L0oooo00T08>`70P3oool4023/1`80oooo100Pk0L20?ooo`808>`7
00<0oooo0000003oool00`0Pk0L90?ooo`03023/1`3oool0oooo0440oooo00<000000?ooo`3oool0
6@3oool001L0oooo00<000000?ooo`3oool07`3oool00`0Pk0L0oooo0?ooo`0B0?ooo`03023/1`3o
ool08>`700<0oooo00D08>`70?ooo`0Pk0L0oooo023/1`030?ooo`03023/1`3oool08>`70080oooo
00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02023/1`030000000Pk0L08>`700@08>`7
00@0oooo023/1`0Pk0L0oooo0P0Pk0L01P3oool08>`7023/1`0Pk0L0oooo023/1`80oooo100Pk0L2
0?ooo`@08>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L0oooo00T08>`70P3oool4
023/1`80oooo100Pk0L20?ooo`808>`700<0oooo0000003oool00`0Pk0L90?ooo`03023/1`3oool0
oooo0440oooo00<000000?ooo`3oool06@3oool001L0oooo00<000000?ooo`3oool07`3oool00`0P
k0L0oooo0?ooo`0B0?ooo`03023/1`3oool08>`700<0oooo00D08>`70?ooo`0Pk0L0oooo023/1`03
0?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`3oool08>`70?ooo`02
023/1`030000000Pk0L08>`700@08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L01P3oool08>`7023/
1`0Pk0L0oooo023/1`80oooo100Pk0L20?ooo`@08>`70P3oool00`0Pk0L0oooo023/1`06023/1`03
0?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`@08>`70P3oool4023/1`80
oooo0P0Pk0L00`3oool000000?ooo`03023/1`T0oooo00<08>`70?ooo`3oool0@@3oool00`000000
oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0O0?ooo`03023/1`3oool0oooo0180oooo
00<08>`70?ooo`0Pk0L00`3oool01@0Pk0L0oooo023/1`3oool08>`700<0oooo00<08>`70?ooo`0P
k0L00P3oool00`0Pk0L0oooo023/1`02023/1`030?ooo`0Pk0L0oooo00808>`700<00000023/1`0P
k0L0100Pk0L0103oool08>`7023/1`3oool2023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70P3o
ool4023/1`80oooo100Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`3oool00`0P
k0L00`3oool08>`7023/1`03023/1`80oooo100Pk0L20?ooo`@08>`70P3oool2023/1`030?ooo`00
0000oooo00<08>`72@3oool00`0Pk0L0oooo0?ooo`110?ooo`030000003oool0oooo01T0oooo000G
0?ooo`030000003oool0oooo01l0oooo00<08>`70?ooo`3oool04P3oool00`0Pk0L0oooo023/1`03
0?ooo`05023/1`3oool08>`70?ooo`0Pk0L00`3oool01`0Pk0L0oooo023/1`0Pk0L0oooo023/1`3o
ool00`0Pk0L00`3oool08>`70?ooo`02023/1`030000000Pk0L08>`700@08>`700@0oooo023/1`0P
k0L0oooo0P0Pk0L00`3oool08>`7023/1`03023/1`80oooo100Pk0L20?ooo`@08>`70P3oool00`0P
k0L0oooo023/1`06023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00`0Pk0L20?oo
o`@08>`70P3oool4023/1`80oooo0P0Pk0L00`3oool000000?ooo`03023/1`T0oooo00<08>`70?oo
o`3oool0@@3oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0O0?ooo`03
023/1`3oool0oooo0180oooo00<08>`70?ooo`0Pk0L00`3oool01@0Pk0L0oooo023/1`3oool08>`7
00<0oooo00L08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`3oool00P0P
k0L00`0000008>`7023/1`07023/1`040?ooo`0Pk0L08>`70?ooo`D08>`70P3oool4023/1`80oooo
100Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7
023/1`03023/1`80oooo100Pk0L20?ooo`@08>`70P3oool2023/1`030?ooo`000000oooo00<08>`7
2@3oool00`0Pk0L0oooo0?ooo`110?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003o
ool0oooo01l0oooo00<08>`70?ooo`3oool04P3oool00`0Pk0L0oooo023/1`030?ooo`05023/1`3o
ool08>`70?ooo`0Pk0L00`3oool01`0Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool00`0Pk0L00`3o
ool08>`70?ooo`02023/1`030000000Pk0L08>`700L08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L2
0?ooo`@08>`70P3oool4023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`70?ooo`03
023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4023/1`80oooo100Pk0L20?ooo`808>`700<0oooo
0000003oool00`0Pk0L80?ooo`03023/1`3oool0oooo0480oooo00<000000?ooo`3oool06@3oool0
01L0oooo00<000000?ooo`3oool07`3oool00`0Pk0L0oooo0?ooo`0B0?ooo`03023/1`3oool08>`7
00<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L30?ooo`07023/1`3oool08>`7023/1`3oool08>`70?oo
o`03023/1`030?ooo`0Pk0L0oooo00808>`700<00000023/1`0Pk0L01`0Pk0L0103oool08>`7023/
1`3oool5023/1`80oooo100Pk0L20?ooo`@08>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?oo
o`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`@08>`70P3oool4023/1`80oooo
0P0Pk0L00`3oool000000?ooo`03023/1`P0oooo00<08>`70?ooo`3oool0@P3oool00`000000oooo
0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0N0?ooo`03023/1`3oool0oooo01@0oooo0P0P
k0L30?ooo`03023/1`3oool08>`700808>`70`3oool01`0Pk0L0oooo023/1`0Pk0L0oooo023/1`3o
ool00`0Pk0L00`3oool08>`70?ooo`02023/1`030000000Pk0L08>`700L08>`700@0oooo023/1`0P
k0L0oooo1@0Pk0L20?ooo`@08>`70P3oool4023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3o
ool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4023/1`80oooo100Pk0L20?oo
o`808>`700<0oooo0000003oool00`0Pk0L80?ooo`03023/1`3oool0oooo0480oooo00<000000?oo
o`3oool06@3oool001L0oooo00<000000?ooo`3oool07P3oool00`0Pk0L0oooo0?ooo`0D0?ooo`80
8>`70`3oool00`0Pk0L0oooo023/1`02023/1`<0oooo00L08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0
oooo00<08>`700<0oooo023/1`3oool00P0Pk0L00`0000008>`7023/1`07023/1`040?ooo`0Pk0L0
8>`70?ooo`D08>`70P3oool4023/1`80oooo0`0Pk0L30?ooo`03023/1`3oool08>`700H08>`700<0
oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`03023/1`80oooo100Pk0L20?ooo`<08>`70`3o
ool2023/1`030?ooo`000000oooo00<08>`7203oool00`0Pk0L0oooo0?ooo`120?ooo`030000003o
ool0oooo01T0oooo000G0?ooo`030000003oool0oooo01h0oooo00<08>`70?ooo`3oool0503oool2
023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L30?ooo`07023/1`3oool08>`7023/1`3oool08>`7
0?ooo`03023/1`030?ooo`0Pk0L0oooo00808>`700<00000023/1`0Pk0L01`0Pk0L0103oool08>`7
023/1`3oool5023/1`80oooo100Pk0L20?ooo`<08>`70P3oool2023/1`030?ooo`0Pk0L08>`700D0
8>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`03023/1`80oooo100Pk0L20?ooo`<0
8>`70`3oool2023/1`030?ooo`000000oooo00<08>`7203oool00`0Pk0L0oooo0?ooo`120?ooo`03
0000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo01h0oooo00<08>`70?ooo`3oool0
503oool2023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L30?ooo`07023/1`3oool08>`7023/1`3o
ool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00808>`700<00000023/1`0Pk0L01`0Pk0L0103o
ool08>`7023/1`3oool5023/1`80oooo100Pk0L20?ooo`<08>`70P3oool2023/1`030?ooo`0Pk0L0
8>`700D08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`03023/1`80oooo100Pk0L2
0?ooo`<08>`70`3oool2023/1`030?ooo`000000oooo00<08>`7203oool00`0Pk0L0oooo0?ooo`12
0?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo01h0oooo00<08>`70?oo
o`3oool0503oool2023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L30?ooo`07023/1`3oool08>`7
023/1`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0oooo00808>`700<00000023/1`0Pk0L01P0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`70P3oool4023/1`80oooo0`0Pk0L20?ooo`808>`7
00<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700<08>`7
0P3oool4023/1`80oooo0`0Pk0L30?ooo`808>`700@0oooo0000000Pk0L0oooo0P0Pk0L80?ooo`03
023/1`3oool0oooo0480oooo00<000000?ooo`3oool06@3oool001L0oooo00<000000?ooo`3oool0
7P3oool00`0Pk0L0oooo0?ooo`0D0?ooo`808>`70`3oool00`0Pk0L0oooo023/1`02023/1`<0oooo
00L08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`3oool00P0Pk0L00`00
00008>`7023/1`06023/1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L20?ooo`@08>`70P3oool3
023/1`80oooo0P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo
023/1`0Pk0L00`0Pk0L20?ooo`@08>`70P3oool3023/1`<0oooo0P0Pk0L0103oool00000023/1`3o
ool2023/1`P0oooo00<08>`70?ooo`3oool0@P3oool00`000000oooo0?ooo`0I0?ooo`005`3oool0
0`000000oooo0?ooo`0N0?ooo`03023/1`3oool0oooo01@0oooo0P0Pk0L30?ooo`03023/1`3oool0
8>`700808>`70`3oool01`0Pk0L0oooo023/1`0Pk0L0oooo023/1`3oool00`0Pk0L00`3oool08>`7
0?ooo`02023/1`030000000Pk0L08>`700H08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`03
0?ooo`0Pk0L08>`700<08>`70P3oool3023/1`80oooo0P0Pk0L00`3oool08>`7023/1`05023/1`03
0?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`@08>`70P3oool3023/1`<0
oooo0P0Pk0L0103oool00000023/1`3oool2023/1`P0oooo00<08>`70?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0N0?ooo`03023/1`3oool0oooo01@0
oooo0P0Pk0L30?ooo`03023/1`3oool08>`700808>`70`3oool01@0Pk0L0oooo023/1`0Pk0L0oooo
00D08>`700<0oooo023/1`3oool00P0Pk0L00`0000008>`7023/1`06023/1`050?ooo`0Pk0L08>`7
023/1`3oool01@0Pk0L00`3oool08>`7023/1`03023/1`80oooo0`0Pk0L20?ooo`808>`700<0oooo
023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4
023/1`80oooo0`0Pk0L30?ooo`808>`700<0oooo0000000Pk0L00P0Pk0L90?ooo`03023/1`3oool0
oooo0480oooo00<000000?ooo`3oool06@3oool001L0oooo00<000000?ooo`3oool07P3oool00`0P
k0L0oooo0?ooo`0D0?ooo`808>`70`3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`<0oooo0`0P
k0L20?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L00`0000008>`7023/1`06023/1`050?ooo`0P
k0L08>`7023/1`3oool01@0Pk0L00`3oool08>`7023/1`03023/1`80oooo0`0Pk0L20?ooo`X08>`7
00<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03023/1`80oooo100Pk0L20?ooo`<08>`7
0`3oool2023/1`030?ooo`0000008>`700808>`72@3oool00`0Pk0L0oooo0?ooo`120?ooo`030000
003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo01h0oooo00<08>`70?ooo`3oool0503o
ool2023/1`<0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L30?ooo`<08>`70P3oool4023/1`03
0?ooo`0Pk0L0oooo00808>`700<00000023/1`0Pk0L01P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00D08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L0200Pk0L00`3o
ool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4023/1`80oooo0`0Pk0L30?oo
o`808>`700<0oooo0000000Pk0L00P0Pk0L90?ooo`03023/1`3oool0oooo0480oooo00<000000?oo
o`3oool06@3oool001L0oooo00<000000?ooo`3oool07@3oool00`0Pk0L0oooo0?ooo`0E0?ooo`80
8>`70`3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`<0oooo0`0Pk0L20?ooo`@08>`700<0oooo
023/1`3oool00P0Pk0L00`0000008>`7023/1`06023/1`050?ooo`0Pk0L08>`7023/1`3oool01@0P
k0L00`3oool08>`7023/1`03023/1`80oooo100Pk0L00`3oool08>`7023/1`09023/1`030?ooo`0P
k0L08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`<08>`70`3oool3023/1`<0oooo0P0P
k0L00`3oool00000023/1`02023/1`T0oooo00<08>`70?ooo`3oool0@P3oool00`000000oooo0?oo
o`0I0?ooo`005`3oool00`000000oooo0?ooo`0M0?ooo`03023/1`3oool0oooo01D0oooo0P0Pk0L3
0?ooo`06023/1`3oool08>`7023/1`3oool08>`70`3oool3023/1`80oooo100Pk0L00`3oool08>`7
0?ooo`02023/1`030000000Pk0L08>`700H08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`03
0?ooo`0Pk0L08>`700<08>`70P3oool4023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`0P
k0L00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo0`0Pk0L30?ooo`<08>`70`3oool2023/1`03
0?ooo`0000008>`700808>`72@3oool00`0Pk0L0oooo0?ooo`120?ooo`030000003oool0oooo01T0
oooo000G0?ooo`030000003oool0oooo01d0oooo00<08>`70?ooo`3oool05@3oool2023/1`<0oooo
00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L30?ooo`<08>`70P3oool4023/1`030?ooo`0Pk0L0oooo
00808>`700<00000023/1`0Pk0L01P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700<0oooo
023/1`0Pk0L00`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L02@0Pk0L00`3oool08>`7023/1`02
023/1`030?ooo`0Pk0L08>`700<08>`70P3oool3023/1`<0oooo0`0Pk0L30?ooo`808>`700<0oooo
0000000Pk0L00P0Pk0L90?ooo`03023/1`3oool0oooo0480oooo00<000000?ooo`3oool06@3oool0
01L0oooo00<000000?ooo`3oool07@3oool00`0Pk0L0oooo0?ooo`0E0?ooo`808>`70`3oool01P0P
k0L0oooo023/1`0Pk0L0oooo023/1`<0oooo0`0Pk0L20?ooo`@08>`700<0oooo023/1`3oool00P0P
k0L00`0000008>`7023/1`06023/1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L00`3oool08>`7
023/1`03023/1`80oooo100Pk0L00`3oool08>`7023/1`09023/1`030?ooo`0Pk0L08>`700808>`7
00<0oooo023/1`0Pk0L00`0Pk0L20?ooo`<08>`70`3oool3023/1`<0oooo0P0Pk0L00`3oool00000
023/1`02023/1`T0oooo00<08>`70?ooo`3oool0@P3oool00`000000oooo0?ooo`0I0?ooo`005`3o
ool00`000000oooo0?ooo`0M0?ooo`03023/1`3oool0oooo01D0oooo0P0Pk0L30?ooo`06023/1`3o
ool08>`7023/1`3oool08>`70`3oool3023/1`80oooo100Pk0L00`3oool08>`70?ooo`02023/1`03
0000000Pk0L08>`700H08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`030?ooo`0Pk0L08>`7
00<08>`70P3oool4023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`0Pk0L0200Pk0L20?oo
o`<08>`70`3oool3023/1`<0oooo00@08>`70?ooo`3oool000000`0Pk0L90?ooo`03023/1`3oool0
oooo0480oooo00<000000?ooo`3oool06@3oool001L0oooo00<000000?ooo`3oool07@3oool00`0P
k0L0oooo0?ooo`0E0?ooo`808>`70`3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`<0oooo0`0P
k0L20?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L00`0000008>`7023/1`06023/1`050?ooo`0P
k0L08>`7023/1`3oool01@0Pk0L00`3oool08>`7023/1`03023/1`80oooo100Pk0L00`3oool08>`7
023/1`09023/1`030?ooo`0Pk0L08>`700P08>`70P3oool3023/1`<0oooo0`0Pk0L30?ooo`04023/
1`3oool0oooo000000<08>`72@3oool00`0Pk0L0oooo0?ooo`120?ooo`030000003oool0oooo01T0
oooo000G0?ooo`030000003oool0oooo01d0oooo00<08>`70?ooo`3oool05@3oool2023/1`<0oooo
00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`70080oooo100Pk0L00`3o
ool08>`70?ooo`02023/1`030000000Pk0L08>`700H08>`700D0oooo023/1`0Pk0L08>`70?ooo`05
023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo
023/1`0Pk0L0200Pk0L00`3oool08>`7023/1`02023/1`<0oooo0`0Pk0L30?ooo`04023/1`3oool0
oooo000000<08>`72@3oool00`0Pk0L0oooo0?ooo`120?ooo`030000003oool0oooo01T0oooo000G
0?ooo`030000003oool0oooo01d0oooo00<08>`70?ooo`3oool05@3oool2023/1`<0oooo00H08>`7
0?ooo`0Pk0L08>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`70080oooo100Pk0L00`3oool08>`7
0?ooo`02023/1`030000000Pk0L08>`700H08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`03
0?ooo`0Pk0L08>`700<08>`70P3oool4023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0P
k0L00P0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L08>`700808>`70`3oool3023/1`<0
oooo00@08>`70?ooo`3oool000000`0Pk0L90?ooo`03023/1`3oool0oooo0480oooo00<000000?oo
o`3oool06@3oool001L0oooo00<000000?ooo`3oool07@3oool00`0Pk0L0oooo0?ooo`0E0?ooo`80
8>`70`3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool4
023/1`030?ooo`0Pk0L0oooo00808>`700<00000023/1`0Pk0L01P0Pk0L01@3oool08>`7023/1`0P
k0L0oooo00D08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L0100P
k0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L00P0P
k0L20?ooo`@08>`70`3oool0100Pk0L0oooo0?ooo`000003023/1`T0oooo00<08>`70?ooo`3oool0
@P3oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0M0?ooo`03023/1`3o
ool0oooo01D0oooo0P0Pk0L30?ooo`06023/1`3oool08>`7023/1`3oool08>`70`3oool00`0Pk0L0
oooo023/1`020?ooo`@08>`700<0oooo023/1`3oool00P0Pk0L00`0000008>`7023/1`0:023/1`03
0?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`@08>`700<0oooo023/1`0P
k0L0100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`3o
ool0100Pk0L20?ooo`@08>`70P3oool2023/1`80oooo00@00000023/1`0Pk0L08>`72@3oool00`0P
k0L0oooo0?ooo`120?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo01d0
oooo00<08>`70?ooo`3oool05@3oool2023/1`<0oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L3
0?ooo`03023/1`3oool08>`70080oooo100Pk0L00`3oool08>`70?ooo`02023/1`030000000Pk0L0
8>`700X08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03023/1`80oooo100Pk0L0
0`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01P0Pk0L0
0`3oool08>`70?ooo`04023/1`80oooo100Pk0L20?ooo`808>`70P3oool0100000008>`7023/1`0P
k0L90?ooo`03023/1`3oool0oooo0480oooo00<000000?ooo`3oool06@3oool001L0oooo00<00000
0?ooo`3oool0703oool00`0Pk0L0oooo0?ooo`0F0?ooo`03023/1`3oool08>`70080oooo00H08>`7
0?ooo`0Pk0L08>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`70080oooo100Pk0L00`3oool08>`7
0?ooo`02023/1`030000000Pk0L08>`700X08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7
023/1`03023/1`80oooo100Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700808>`7
00<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`70?ooo`04023/1`80oooo100Pk0L20?ooo`808>`7
0P3oool0100000008>`7023/1`0Pk0L90?ooo`03023/1`3oool0oooo0480oooo00<000000?ooo`3o
ool06@3oool001L0oooo00<000000?ooo`3oool0703oool00`0Pk0L0oooo0?ooo`0F0?ooo`03023/
1`3oool08>`70080oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`7
0080oooo00L08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo00808>`700<00000023/1`0Pk0L02P0P
k0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4023/1`030?ooo`0P
k0L08>`700@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`07023/1`80oooo100P
k0L20?ooo`@08>`70P3oool2023/1`80oooo00@00000023/1`0Pk0L08>`72@3oool00`0Pk0L0oooo
0?ooo`120?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo01`0oooo00<0
8>`70?ooo`3oool05P3oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3oool08>`7023/1`3oool0
8>`70`3oool00`0Pk0L0oooo023/1`020?ooo`07023/1`3oool08>`7023/1`3oool08>`70?ooo`02
023/1`030000000Pk0L08>`700X08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03
023/1`80oooo100Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`0Pk0L01`0Pk0L20?ooo`@08>`70P3oool4023/1`80oooo0P0Pk0L20?ooo`040000000Pk0L0
8>`7023/1`T0oooo00<08>`70?ooo`3oool0@P3oool00`000000oooo0?ooo`0I0?ooo`005`3oool0
0`000000oooo0?ooo`0L0?ooo`03023/1`3oool0oooo01H0oooo00<08>`70?ooo`0Pk0L00P3oool0
1P0Pk0L0oooo023/1`0Pk0L0oooo023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool01`0Pk0L0oooo
023/1`0Pk0L0oooo023/1`3oool00P0Pk0L00`0000008>`7023/1`0:023/1`030?ooo`0Pk0L08>`7
00<08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L0100Pk0L00`3o
ool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700L08>`70P3oool4023/1`80oooo100Pk0L20?oo
o`808>`70P3oool0100000008>`7023/1`0Pk0L90?ooo`03023/1`3oool0oooo0480oooo00<00000
0?ooo`3oool06@3oool001L0oooo00<000000?ooo`3oool0703oool00`0Pk0L0oooo0?ooo`0F0?oo
o`03023/1`3oool08>`70080oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L30?ooo`03023/1`3o
ool08>`70080oooo00L08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo00808>`700<00000023/1`0P
k0L02P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4023/1`03
0?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`07023/1`80
oooo100Pk0L20?ooo`<08>`70`3oool2023/1`80oooo00@000000?ooo`0Pk0L08>`7203oool00`0P
k0L0oooo0?ooo`130?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo01`0
oooo00<08>`70?ooo`3oool05P3oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3oool08>`7023/
1`3oool08>`70`3oool00`0Pk0L0oooo023/1`020?ooo`07023/1`3oool08>`7023/1`3oool08>`7
0?ooo`02023/1`030000000Pk0L08>`700X08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7
023/1`03023/1`80oooo100Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700808>`7
00<0oooo023/1`0Pk0L01`0Pk0L20?ooo`@08>`70P3oool3023/1`<0oooo0P0Pk0L20?ooo`040000
003oool08>`7023/1`P0oooo00<08>`70?ooo`3oool0@`3oool00`000000oooo0?ooo`0I0?ooo`00
5`3oool00`000000oooo0?ooo`0L0?ooo`03023/1`3oool0oooo01H0oooo00<08>`70?ooo`0Pk0L0
0P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool01`0P
k0L0oooo023/1`0Pk0L0oooo023/1`3oool00P0Pk0L00`0000008>`7023/1`0:023/1`030?ooo`0P
k0L08>`700<08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L0100P
k0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700L08>`70P3oool4023/1`80oooo0`0P
k0L30?ooo`808>`70P3oool00`000000oooo023/1`090?ooo`03023/1`3oool0oooo04<0oooo00<0
00000?ooo`3oool06@3oool001L0oooo00<000000?ooo`3oool0703oool00`0Pk0L0oooo0?ooo`0F
0?ooo`03023/1`3oool08>`70080oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L30?ooo`03023/
1`3oool08>`70080oooo00L08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo00808>`700<00000023/
1`0Pk0L02P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4023/
1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`07023/
1`80oooo100Pk0L20?ooo`<08>`70`3oool2023/1`80oooo00<000000?ooo`0Pk0L02@3oool00`0P
k0L0oooo0?ooo`130?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo01`0
oooo00<08>`70?ooo`3oool05P3oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3oool0oooo023/
1`3oool08>`70`3oool00`0Pk0L0oooo023/1`020?ooo`07023/1`3oool08>`7023/1`3oool08>`7
0?ooo`02023/1`030000000Pk0L08>`700X08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7
023/1`03023/1`80oooo100Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700808>`7
00<0oooo023/1`0Pk0L01`0Pk0L20?ooo`@08>`70P3oool00`0Pk0L0oooo023/1`030?ooo`808>`7
0P3oool00`000000oooo023/1`090?ooo`03023/1`3oool0oooo04<0oooo00<000000?ooo`3oool0
6@3oool001L0oooo00<000000?ooo`3oool0703oool00`0Pk0L0oooo0?ooo`0F0?ooo`03023/1`3o
ool08>`70080oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool08>`70080
oooo00<08>`70?ooo`0Pk0L00`0Pk0L0103oool08>`7023/1`00000<023/1`030?ooo`0Pk0L08>`7
00<08>`700<0oooo023/1`3oool00`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L0100Pk0L00`3o
ool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700L08>`70P3oool4023/1`80oooo0`0Pk0L30?oo
o`808>`70P3oool00`000000oooo023/1`090?ooo`03023/1`3oool0oooo04<0oooo00<000000?oo
o`3oool06@3oool001L0oooo00<000000?ooo`3oool06`3oool00`0Pk0L0oooo0?ooo`0G0?ooo`03
023/1`3oool08>`70080oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool0
8>`70080oooo00<08>`70?ooo`0Pk0L00`0Pk0L0103oool08>`7023/1`00000<023/1`030?ooo`0P
k0L08>`700<08>`700<0oooo023/1`3oool00`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L0100P
k0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700L08>`70P3oool4023/1`80oooo0`0P
k0L30?ooo`808>`70P3oool00`000000oooo023/1`090?ooo`03023/1`3oool0oooo04<0oooo00<0
00000?ooo`3oool06@3oool001L0oooo00<000000?ooo`3oool06`3oool00`0Pk0L0oooo0?ooo`0G
0?ooo`03023/1`3oool08>`70080oooo00H08>`70?ooo`3oool08>`70?ooo`0Pk0L30?ooo`03023/
1`3oool08>`70080oooo00<08>`70?ooo`0Pk0L00`0Pk0L0103oool08>`7023/1`00000<023/1`03
0?ooo`0Pk0L08>`700<08>`700<0oooo023/1`3oool00`0Pk0L20?ooo`@08>`700<0oooo023/1`0P
k0L02@0Pk0L00`3oool08>`7023/1`07023/1`80oooo100Pk0L20?ooo`<08>`70`3oool2023/1`80
oooo00<000000?ooo`0Pk0L02@3oool00`0Pk0L0oooo0?ooo`130?ooo`030000003oool0oooo01T0
oooo000G0?ooo`030000003oool0oooo01/0oooo00<08>`70?ooo`3oool05`3oool00`0Pk0L0oooo
023/1`020?ooo`06023/1`3oool0oooo023/1`3oool08>`70`3oool00`0Pk0L0oooo023/1`020?oo
o`03023/1`3oool08>`700<08>`700@0oooo023/1`0Pk0L00000300Pk0L00`3oool08>`7023/1`03
023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo
023/1`0Pk0L01`0Pk0L20?ooo`@08>`70P3oool3023/1`<0oooo0P0Pk0L20?ooo`030000003oool0
8>`700T0oooo00<08>`70?ooo`3oool0@`3oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`00
0000oooo0?ooo`0K0?ooo`03023/1`3oool0oooo01L0oooo00<08>`70?ooo`0Pk0L00P3oool01P0P
k0L0oooo0?ooo`0Pk0L0oooo023/1`@0oooo0P0Pk0L20?ooo`03023/1`3oool08>`700<08>`700@0
oooo023/1`0Pk0L00000300Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`7
0P3oool4023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`0Pk0L01`0Pk0L20?ooo`@08>`7
0P3oool3023/1`<0oooo0P0Pk0L20?ooo`030000003oool08>`700T0oooo00<08>`70?ooo`3oool0
@`3oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0K0?ooo`03023/1`3o
ool0oooo01L0oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`@0
oooo0P0Pk0L20?ooo`03023/1`3oool08>`700<08>`700@0oooo023/1`0Pk0L00000300Pk0L00`3o
ool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4023/1`030?ooo`0Pk0L08>`7
00T08>`700<0oooo023/1`0Pk0L01`0Pk0L20?ooo`@08>`70P3oool3023/1`<0oooo0P0Pk0L20?oo
o`030000003oool08>`700T0oooo00<08>`70?ooo`3oool0@`3oool00`000000oooo0?ooo`0I0?oo
o`005`3oool00`000000oooo0?ooo`0K0?ooo`03023/1`3oool0oooo01L0oooo00<08>`70?ooo`0P
k0L00P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`@0oooo0P0Pk0L20?ooo`03023/1`3oool0
8>`700<08>`700@0oooo023/1`0Pk0L00000300Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0P
k0L08>`700<08>`70P3oool4023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`0Pk0L01`0P
k0L20?ooo`@08>`70P3oool3023/1`<0oooo0P0Pk0L20?ooo`030000003oool08>`700T0oooo00<0
8>`70?ooo`3oool0@`3oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0K
0?ooo`03023/1`3oool0oooo01L0oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo0?ooo`0P
k0L0oooo023/1`@0oooo0P0Pk0L20?ooo`H08>`700@0oooo023/1`0Pk0L00000300Pk0L00`3oool0
8>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4023/1`030?ooo`0Pk0L08>`700T0
8>`700<0oooo023/1`0Pk0L01`0Pk0L20?ooo`@08>`70P3oool3023/1`<0oooo0P0Pk0L20?ooo`03
0000003oool08>`700T0oooo00<08>`70?ooo`3oool0@`3oool00`000000oooo0?ooo`0I0?ooo`00
5`3oool00`000000oooo0?ooo`0K0?ooo`03023/1`3oool0oooo01L0oooo00<08>`70?ooo`0Pk0L0
0P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`@0oooo0P0Pk0L30?ooo`D08>`700@0oooo023/
1`0Pk0L00000300Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4
023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`0Pk0L01`0Pk0L20?ooo`@08>`70P3oool3
023/1`<0oooo0P0Pk0L20?ooo`030000003oool08>`700T0oooo00<08>`70?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0K0?ooo`03023/1`3oool0oooo
01L0oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`@0oooo0P0P
k0L30?ooo`D08>`700@0oooo023/1`0Pk0L00000300Pk0L00`3oool08>`7023/1`03023/1`030?oo
o`0Pk0L08>`700<08>`70P3oool4023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`0Pk0L0
1`0Pk0L20?ooo`@08>`70P3oool3023/1`<0oooo0P0Pk0L20?ooo`030000003oool08>`700T0oooo
00<08>`70?ooo`3oool0@`3oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?oo
o`0K0?ooo`03023/1`3oool0oooo01P0oooo0P0Pk0L20?ooo`06023/1`3oool0oooo023/1`3oool0
8>`7103oool2023/1`<0oooo1@0Pk0L0103oool08>`7023/1`00000<023/1`030?ooo`0Pk0L08>`7
00<08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L02@0Pk0L00`3o
ool08>`7023/1`07023/1`80oooo100Pk0L20?ooo`<08>`70`3oool2023/1`80oooo00<000000?oo
o`0Pk0L02@3oool00`0Pk0L0oooo0?ooo`130?ooo`030000003oool0oooo01T0oooo000G0?ooo`03
0000003oool0oooo01X0oooo00<08>`70?ooo`3oool06@3oool2023/1`<0oooo00D08>`70?ooo`0P
k0L0oooo023/1`040?ooo`808>`70`3oool5023/1`040?ooo`0Pk0L08>`7000000`08>`700<0oooo
023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03023/1`80oooo100Pk0L00`3oool08>`7023/1`09
023/1`030?ooo`0Pk0L08>`700L08>`70P3oool4023/1`80oooo0`0Pk0L30?ooo`808>`70P3oool0
0`000000oooo023/1`090?ooo`03023/1`3oool0oooo04<0oooo00<000000?ooo`3oool06@3oool0
01L0oooo00<000000?ooo`3oool06P3oool00`0Pk0L0oooo0?ooo`0I0?ooo`808>`70`3oool01@0P
k0L0oooo023/1`3oool08>`700@0oooo0P0Pk0L30?ooo`D08>`700@0oooo023/1`0Pk0L000003@0P
k0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`70P3oool4023/1`030?ooo`0P
k0L08>`700T08>`700<0oooo023/1`0Pk0L01`0Pk0L20?ooo`@08>`70P3oool3023/1`<0oooo0P0P
k0L20?ooo`030000000Pk0L08>`700T0oooo00<08>`70?ooo`3oool0@`3oool00`000000oooo0?oo
o`0I0?ooo`005`3oool00`000000oooo0?ooo`0J0?ooo`03023/1`3oool0oooo01T0oooo0P0Pk0L3
0?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool2023/1`<0oooo1@0Pk0L0103oool08>`7023/
1`00000=023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`@08>`7
00<0oooo023/1`0Pk0L02@0Pk0L00`3oool08>`7023/1`07023/1`80oooo100Pk0L20?ooo`<08>`7
0`3oool2023/1`80oooo00<00000023/1`0Pk0L02@3oool00`0Pk0L0oooo0?ooo`130?ooo`030000
003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo01X0oooo00<08>`70?ooo`3oool06@3o
ool2023/1`<0oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`808>`70`3oool5023/1`040?oo
o`0Pk0L08>`7000000d08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`80
oooo100Pk0L00`3oool08>`7023/1`09023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0P
k0L00`0Pk0L20?ooo`<08>`70`3oool2023/1`80oooo00<00000023/1`0Pk0L02@3oool00`0Pk0L0
oooo0?ooo`130?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo01X0oooo
00<08>`70?ooo`3oool06@3oool2023/1`<0oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`80
8>`70`3oool5023/1`030?ooo`0Pk0L08>`700h08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool0
8>`7023/1`03023/1`80oooo100Pk0L00`3oool08>`7023/1`09023/1`030?ooo`0Pk0L08>`700L0
8>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`<08>`70`3oool2023/1`80oooo00<00000023/1`0P
k0L02@3oool00`0Pk0L0oooo0?ooo`130?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000
003oool0oooo01X0oooo00<08>`70?ooo`3oool06@3oool2023/1`<0oooo00D08>`70?ooo`0Pk0L0
oooo023/1`040?ooo`808>`70`3oool5023/1`030?ooo`0Pk0L08>`700h08>`700<0oooo023/1`0P
k0L00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo100Pk0L00`3oool08>`7023/1`09023/1`03
0?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`<08>`70`3oool2023/1`03
0?ooo`0Pk0L0000000808>`72@3oool00`0Pk0L0oooo0?ooo`130?ooo`030000003oool0oooo01T0
oooo000G0?ooo`030000003oool0oooo01X0oooo00<08>`70?ooo`3oool06@3oool2023/1`<0oooo
00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`808>`70`3oool5023/1`030?ooo`0Pk0L08>`700h0
8>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`80oooo100Pk0L00`3oool0
8>`7023/1`09023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`<0
8>`70`3oool2023/1`030?ooo`0Pk0L0000000808>`72@3oool00`0Pk0L0oooo0?ooo`130?ooo`03
0000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo01X0oooo00<08>`70?ooo`3oool0
6@3oool2023/1`<0oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`808>`70`3oool5023/1`03
0?ooo`0Pk0L08>`700h08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`80
oooo100Pk0L00`3oool08>`7023/1`09023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0P
k0L00`0Pk0L20?ooo`<08>`70`3oool2023/1`040?ooo`0Pk0L00000023/1`X0oooo00<08>`70?oo
o`3oool0@`3oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0J0?ooo`03
023/1`3oool0oooo01T0oooo0P0Pk0L30?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool2023/
1`<0oooo1@0Pk0L00`3oool08>`7023/1`0>023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/
1`0Pk0L00`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L0200Pk0L20?ooo`T08>`700<0oooo023/
1`0Pk0L00`0Pk0L20?ooo`<08>`70`3oool2023/1`040?ooo`0Pk0L00000023/1`X0oooo00<08>`7
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0J0?oo
o`03023/1`3oool0oooo01T0oooo0P0Pk0L30?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool2
023/1`<0oooo1@0Pk0L00`3oool08>`7023/1`0>023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`0Pk0L00`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L0200Pk0L20?ooo`T08>`700<0oooo
023/1`0Pk0L00`0Pk0L20?ooo`<08>`70`3oool2023/1`040?ooo`0Pk0L00000023/1`X0oooo00<0
8>`70?ooo`3oool0@`3oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0J
0?ooo`03023/1`3oool0oooo01T0oooo0P0Pk0L30?ooo`03023/1`3oool08>`700808>`7103oool2
023/1`<0oooo1@0Pk0L00`3oool08>`7023/1`0>023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`0Pk0L00`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L0200Pk0L20?ooo`T08>`700<0oooo
023/1`0Pk0L00`0Pk0L20?ooo`<08>`70`3oool2023/1`040?ooo`0Pk0L00000023/1`X0oooo00<0
8>`70?ooo`3oool0@`3oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0I
0?ooo`03023/1`3oool0oooo01X0oooo0P0Pk0L30?ooo`03023/1`3oool08>`700808>`7103oool2
023/1`<0oooo1@0Pk0L00`3oool08>`7023/1`0>023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`0Pk0L00`0Pk0L20?ooo`@08>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`80oooo200P
k0L20?ooo`D08>`70P3oool3023/1`<0oooo0P0Pk0L0103oool08>`70000000Pk0L:0?ooo`03023/
1`3oool0oooo04<0oooo00<000000?ooo`3oool06@3oool001L0oooo00<000000?ooo`3oool06@3o
ool00`0Pk0L0oooo0?ooo`0J0?ooo`808>`70`3oool00`0Pk0L0oooo023/1`02023/1`@0oooo0P0P
k0L30?ooo`D08>`700<0oooo023/1`0Pk0L03P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`D08>`7
0P3oool4023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L20?ooo`P08>`70P3oool5023/1`80
oooo0`0Pk0L30?ooo`808>`700@0oooo023/1`0000008>`72@3oool00`0Pk0L0oooo0?ooo`140?oo
o`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo01T0oooo00<08>`70?ooo`3o
ool06P3oool2023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`808>`70`3oool5023/1`03
0?ooo`0Pk0L08>`700h08>`700@0oooo023/1`0Pk0L08>`70P3oool5023/1`030?ooo`0Pk0L08>`7
00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`80oooo200Pk0L20?ooo`D08>`700<0oooo
023/1`0Pk0L00P0Pk0L30?ooo`06023/1`3oool0oooo023/1`0000008>`72@3oool00`0Pk0L0oooo
0?ooo`140?ooo`030000003oool0oooo01T0oooo000G0?ooo`030000003oool0oooo01T0oooo00<0
8>`70?ooo`3oool06P3oool2023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`808>`70`3o
ool5023/1`030?ooo`0Pk0L08>`700h08>`700@0oooo023/1`0Pk0L08>`70P3oool5023/1`030?oo
o`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`P08>`70P3oool5023/1`030?oo
o`0Pk0L08>`700808>`70`3oool01P0Pk0L0oooo0?ooo`0Pk0L00000023/1`T0oooo00<08>`70?oo
o`3oool0A03oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0I0?ooo`03
023/1`3oool0oooo01X0oooo0P0Pk0L30?ooo`03023/1`3oool08>`700808>`7103oool2023/1`<0
oooo1@0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700D08>`700@0oooo023/1`0P
k0L08>`70P3oool5023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L0100Pk0L20?oo
o`P08>`70P3oool5023/1`040?ooo`0Pk0L08>`7023/1`@0oooo00H08>`70?ooo`3oool08>`70000
000Pk0L90?ooo`03023/1`3oool0oooo04@0oooo00<000000?ooo`3oool06@3oool001L0oooo00<0
00000?ooo`3oool06@3oool00`0Pk0L0oooo0?ooo`0J0?ooo`808>`70`3oool00`0Pk0L0oooo023/
1`02023/1`@0oooo0P0Pk0L30?ooo`D08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/
1`05023/1`040?ooo`0Pk0L08>`7023/1`80oooo1@0Pk0L00`3oool08>`7023/1`07023/1`030?oo
o`0Pk0L08>`700@08>`70P3oool8023/1`80oooo1@0Pk0L0103oool08>`7023/1`0Pk0L40?ooo`06
023/1`3oool0oooo023/1`0000008>`72@3oool00`0Pk0L0oooo0?ooo`140?ooo`030000003oool0
oooo01T0oooo000G0?ooo`030000003oool0oooo01T0oooo00<08>`70?ooo`3oool06P3oool2023/
1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`808>`70`3oool5023/1`040?ooo`0Pk0L08>`7
000000D08>`700<0oooo023/1`0Pk0L01@0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`D08>`700<0
oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`04023/1`80oooo200Pk0L20?ooo`D08>`700@0
oooo023/1`0Pk0L08>`7103oool01P0Pk0L0oooo0?ooo`0Pk0L00000023/1`T0oooo00<08>`70?oo
o`3oool0A03oool00`000000oooo0?ooo`0I0?ooo`005`3oool00`000000oooo0?ooo`0I0?ooo`03
023/1`3oool0oooo01X0oooo0P0Pk0L30?ooo`03023/1`3oool08>`700808>`7103oool2023/1`<0
oooo1@0Pk0L0103oool08>`7023/1`000005023/1`030?ooo`0Pk0L08>`700D08>`700@0oooo023/
1`0Pk0L08>`70P3oool5023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L0100Pk0L2
0?ooo`P08>`70P3oool5023/1`040?ooo`0Pk0L08>`7023/1`<0oooo0P0Pk0L20?ooo`03023/1`00
00008>`700T0oooo00<08>`70?ooo`3oool0A@3oool00`000000oooo0?ooo`0H0?ooo`005`3oool0
0`000000oooo0?ooo`0I0?ooo`03023/1`3oool0oooo01X0oooo0P0Pk0L30?ooo`03023/1`3oool0
8>`700808>`7103oool2023/1`<0oooo1@0Pk0L0103oool08>`7023/1`000005023/1`030?ooo`0P
k0L08>`700D08>`700@0oooo023/1`0Pk0L08>`70P3oool5023/1`030?ooo`0Pk0L08>`700L08>`7
00<0oooo023/1`0Pk0L0100Pk0L20?ooo`P08>`70P3oool5023/1`040?ooo`0Pk0L08>`7023/1`<0
oooo0P0Pk0L20?ooo`03023/1`0000008>`700T0oooo00<08>`70?ooo`3oool0A@3oool00`000000
oooo0?ooo`0H0?ooo`005`3oool00`000000oooo0?ooo`0I0?ooo`03023/1`3oool0oooo01X0oooo
0P0Pk0L30?ooo`03023/1`3oool08>`700808>`71@3oool0100Pk0L0oooo0?ooo`3oool5023/1`04
0?ooo`0Pk0L08>`7000000D08>`700<0oooo023/1`0Pk0L01@0Pk0L0103oool08>`7023/1`0Pk0L2
0?ooo`D08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`030?ooo`0Pk0L08>`700@08>`70P3o
ool8023/1`80oooo1@0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`808>`70P3oool00`0Pk0L00000
023/1`090?ooo`03023/1`3oool0oooo04D0oooo00<000000?ooo`3oool0603oool001L0oooo00<0
00000?ooo`3oool0603oool00`0Pk0L0oooo0?ooo`0K0?ooo`808>`70`3oool00`0Pk0L0oooo023/
1`02023/1`D0oooo00@08>`70?ooo`3oool0oooo1@0Pk0L0103oool08>`7023/1`000005023/1`03
0?ooo`0Pk0L08>`700D08>`700@0oooo023/1`0Pk0L08>`70P3oool5023/1`050?ooo`0Pk0L08>`7
023/1`3oool01@0Pk0L00`3oool08>`7023/1`04023/1`80oooo200Pk0L20?ooo`D08>`700@0oooo
023/1`0Pk0L08>`70`3oool2023/1`80oooo00<08>`70000000Pk0L02@3oool00`0Pk0L0oooo0?oo
o`150?ooo`030000003oool0oooo01P0oooo000G0?ooo`030000003oool0oooo01P0oooo00<08>`7
0?ooo`3oool06`3oool2023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L50?ooo`04023/1`3oool0
oooo0?ooo`D08>`700@0oooo023/1`0Pk0L000001@0Pk0L00`3oool08>`7023/1`05023/1`040?oo
o`0Pk0L08>`7023/1`80oooo1@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700<0oooo023/
1`0Pk0L0100Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`D08>`700@0oooo023/
1`0Pk0L08>`70`3oool2023/1`80oooo00<08>`70000000Pk0L02@3oool00`0Pk0L0oooo0?ooo`15
0?ooo`030000003oool0oooo01P0oooo000G0?ooo`030000003oool0oooo01P0oooo00<08>`70?oo
o`3oool06`3oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3oool08>`7023/1`3oool08>`7103o
ool0100Pk0L0oooo0?ooo`3oool5023/1`040?ooo`0Pk0L08>`7000000D08>`700<0oooo023/1`0P
k0L01@0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`D08>`700D0oooo023/1`0Pk0L08>`70?ooo`05
023/1`030?ooo`0Pk0L08>`700@08>`70P3oool2023/1`030?ooo`0Pk0L08>`700<08>`70P3oool5
023/1`040?ooo`0Pk0L08>`7023/1`<0oooo0P0Pk0L20?ooo`03023/1`0000008>`700T0oooo00<0
8>`70?ooo`3oool0A@3oool00`000000oooo0?ooo`0H0?ooo`005`3oool00`000000oooo0?ooo`0H
0?ooo`03023/1`3oool0oooo01/0oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo023/1`0P
k0L0oooo023/1`@0oooo00@08>`70?ooo`3oool0oooo1@0Pk0L0103oool08>`7023/1`000005023/
1`030?ooo`0Pk0L08>`700D08>`700@0oooo023/1`0Pk0L08>`70P3oool5023/1`050?ooo`0Pk0L0
8>`7023/1`3oool01@0Pk0L00`3oool08>`7023/1`04023/1`80oooo0P0Pk0L00`3oool08>`7023/
1`03023/1`80oooo1@0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`808>`70P3oool00`0Pk0L00000
023/1`090?ooo`03023/1`3oool0oooo04D0oooo00<000000?ooo`3oool0603oool001L0oooo00<0
00000?ooo`3oool0603oool00`0Pk0L0oooo0?ooo`0K0?ooo`03023/1`3oool08>`70080oooo00H0
8>`70?ooo`0Pk0L08>`70?ooo`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`D08>`700@0oooo023/
1`0Pk0L000001@0Pk0L00`3oool08>`7023/1`05023/1`040?ooo`0Pk0L08>`7023/1`80oooo1@0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`808>`7
00<0oooo023/1`0Pk0L00`0Pk0L20?ooo`D08>`700@0oooo023/1`0Pk0L08>`70`3oool2023/1`80
oooo00<08>`70000000Pk0L02@3oool00`0Pk0L0oooo0?ooo`150?ooo`030000003oool0oooo01P0
oooo000G0?ooo`030000003oool0oooo01P0oooo00<08>`70?ooo`3oool06`3oool00`0Pk0L0oooo
023/1`020?ooo`06023/1`3oool08>`7023/1`3oool08>`7103oool0100Pk0L0oooo0?ooo`3oool5
023/1`040?ooo`0Pk0L08>`7000000D08>`700<0oooo023/1`0Pk0L01@0Pk0L0103oool08>`7023/
1`0Pk0L20?ooo`D08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`030?ooo`0Pk0L08>`700@0
8>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`80oooo100Pk0L20?ooo`03023/1`3oool08>`7
00<0oooo0P0Pk0L01@3oool08>`70?ooo`0000008>`700T0oooo00<08>`70?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0H0?ooo`005`3oool00`000000oooo0?ooo`0H0?ooo`03023/1`3oool0oooo
01/0oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`@0oooo00<0
8>`70?ooo`3oool00P3oool4023/1`040?ooo`0Pk0L08>`7000000D08>`700<0oooo023/1`0Pk0L0
1@0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`D08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/
1`030?ooo`0Pk0L08>`700@08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`80oooo100Pk0L2
0?ooo`03023/1`3oool08>`700<0oooo0P0Pk0L01@3oool08>`70?ooo`0000008>`700T0oooo00<0
8>`70?ooo`3oool0A@3oool00`000000oooo0?ooo`0H0?ooo`005`3oool00`000000oooo0?ooo`0H
0?ooo`03023/1`3oool0oooo01/0oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo023/1`0P
k0L0oooo023/1`@0oooo0P0Pk0L30?ooo`@08>`700@0oooo023/1`0Pk0L000001@0Pk0L0103oool0
8>`7023/1`3oool4023/1`040?ooo`0Pk0L08>`7023/1`80oooo1@0Pk0L01@3oool08>`7023/1`0P
k0L0oooo00D08>`700<0oooo023/1`0Pk0L0100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`7
0P3oool4023/1`80oooo00<08>`70?ooo`0Pk0L00`3oool2023/1`050?ooo`0Pk0L0oooo0000000P
k0L02@3oool00`0Pk0L0oooo0?ooo`150?ooo`030000003oool0oooo01P0oooo000G0?ooo`030000
003oool0oooo01P0oooo00<08>`70?ooo`3oool06`3oool00`0Pk0L0oooo023/1`020?ooo`06023/
1`3oool08>`7023/1`3oool08>`7103oool2023/1`<0oooo100Pk0L0103oool08>`7023/1`000005
023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/
1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L00`3oool08>`7023/1`04023/1`030?oo
o`0Pk0L08>`700L08>`70P3oool4023/1`80oooo00<08>`70?ooo`0Pk0L00`3oool2023/1`050?oo
o`0Pk0L0oooo0000000Pk0L02@3oool00`0Pk0L0oooo0?ooo`150?ooo`030000003oool0oooo01P0
oooo000G0?ooo`030000003oool0oooo01P0oooo00<08>`70?ooo`3oool06`3oool00`0Pk0L0oooo
023/1`020?ooo`06023/1`3oool08>`7023/1`3oool08>`7103oool2023/1`<0oooo100Pk0L0103o
ool08>`7023/1`000005023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L00P0P
k0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L00`3oool08>`7
023/1`04023/1`030?ooo`0Pk0L08>`700L08>`70P3oool4023/1`80oooo00<08>`70?ooo`0Pk0L0
0`3oool2023/1`050?ooo`0Pk0L0oooo0000000Pk0L02@3oool00`0Pk0L0oooo0?ooo`150?ooo`03
0000003oool0oooo01P0oooo000G0?ooo`030000003oool0oooo01P0oooo00<08>`70?ooo`3oool0
6`3oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3oool08>`7023/1`3oool08>`7103oool2023/
1`<0oooo100Pk0L0103oool08>`7023/1`000005023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0
oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool0
1@0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L0
0`0Pk0L20?ooo`03023/1`3oool08>`700<0oooo0P0Pk0L01@3oool08>`70?ooo`0000008>`700T0
oooo00<08>`70?ooo`3oool0A@3oool00`000000oooo0?ooo`0H0?ooo`005`3oool00`000000oooo
0?ooo`0G0?ooo`03023/1`3oool0oooo01`0oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo
023/1`0Pk0L0oooo023/1`@0oooo0P0Pk0L30?ooo`@08>`700@0oooo023/1`0Pk0L000001@0Pk0L0
103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7
023/1`07023/1`030?ooo`0Pk0L08>`700<08>`70P3oool3023/1`<0oooo0P0Pk0L01@3oool08>`7
0?ooo`0000008>`700T0oooo00<08>`70?ooo`3oool0A@3oool00`000000oooo0?ooo`0H0?ooo`00
5`3oool00`000000oooo0?ooo`0G0?ooo`03023/1`3oool0oooo01`0oooo00<08>`70?ooo`0Pk0L0
0P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`@0oooo0P0Pk0L30?ooo`@08>`700@0oooo023/
1`0Pk0L000001@0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`700808>`700<0
oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0
oooo1P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700<08>`70P3oool3023/1`<0
oooo0P0Pk0L01@3oool08>`70?ooo`0000008>`700T0oooo00<08>`70?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0H0?ooo`005`3oool00`000000oooo0?ooo`0G0?ooo`03023/1`3oool0oooo01`0
oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`@0oooo0P0Pk0L3
0?ooo`@08>`700@0oooo023/1`0Pk0L000001@0Pk0L0103oool08>`7023/1`3oool4023/1`030?oo
o`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo0080
8>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`7
00<08>`70P3oool3023/1`<0oooo0P0Pk0L01@3oool08>`70?ooo`0000008>`700T0oooo00<08>`7
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0H0?ooo`005`3oool00`000000oooo0?ooo`0G0?oo
o`03023/1`3oool0oooo01`0oooo00<08>`70?ooo`0Pk0L00P3oool01P0Pk0L0oooo023/1`0Pk0L0
oooo023/1`@0oooo0P0Pk0L30?ooo`@08>`700@0oooo023/1`0Pk0L000001@0Pk0L0103oool08>`7
023/1`3oool4023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool0
8>`7023/1`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L00`3oool08>`7023/1`07
023/1`030?ooo`0Pk0L08>`700<08>`70P3oool3023/1`<0oooo0P0Pk0L01@3oool08>`70?ooo`00
00008>`700T0oooo00<08>`70?ooo`3oool0A@3oool00`000000oooo0?ooo`0H0?ooo`005`3oool0
0`000000oooo0?ooo`0G0?ooo`03023/1`3oool0oooo01`0oooo00<08>`70?ooo`0Pk0L00P3oool0
1P0Pk0L0oooo023/1`0Pk0L0oooo023/1`@0oooo0P0Pk0L30?ooo`@08>`700@0oooo023/1`0Pk0L0
00001@0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/
1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo1P0P
k0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700<08>`70P3oool3023/1`<0oooo0P0P
k0L0103oool08>`70?ooo`00000:0?ooo`03023/1`3oool0oooo04D0oooo00<000000?ooo`3oool0
603oool001L0oooo00<000000?ooo`3oool05`3oool00`0Pk0L0oooo0?ooo`0L0?ooo`03023/1`3o
ool08>`70080oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L40?ooo`808>`70`3oool4023/1`03
0?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`7023/1`02023/
1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`040?ooo`0Pk0L0
8>`70?ooo`H08>`700<0oooo023/1`0Pk0L01`0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo
0`0Pk0L30?ooo`808>`700@0oooo023/1`3oool000002P3oool00`0Pk0L0oooo0?ooo`150?ooo`03
0000003oool0oooo01P0oooo000G0?ooo`030000003oool0oooo01L0oooo00<08>`70?ooo`3oool0
703oool00`0Pk0L0oooo023/1`020?ooo`06023/1`3oool08>`7023/1`3oool08>`7103oool2023/
1`<0oooo100Pk0L00`3oool08>`7023/1`06023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo
023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0P
k0L0103oool08>`7023/1`3oool6023/1`030?ooo`0Pk0L08>`700L08>`700@0oooo023/1`0Pk0L0
oooo0P0Pk0L00`3oool08>`7023/1`02023/1`<0oooo0P0Pk0L0103oool08>`70?ooo`00000:0?oo
o`03023/1`3oool0oooo04D0oooo00<000000?ooo`3oool0603oool001L0oooo00<000000?ooo`3o
ool05`3oool00`0Pk0L0oooo0?ooo`0L0?ooo`03023/1`3oool08>`70080oooo00H08>`70?ooo`0P
k0L08>`70?ooo`0Pk0L40?ooo`808>`70`3oool4023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo
023/1`0Pk0L0oooo100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700D0
oooo023/1`0Pk0L08>`70?ooo`02023/1`040?ooo`0Pk0L08>`70?ooo`H08>`700<0oooo023/1`0P
k0L01`0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`70`3oool2023/
1`040?ooo`0Pk0L0oooo000000T0oooo00<08>`70?ooo`3oool0AP3oool00`000000oooo0?ooo`0H
0?ooo`005`3oool00`000000oooo0?ooo`0G0?ooo`03023/1`3oool0oooo01d0oooo0P0Pk0L20?oo
o`06023/1`3oool08>`7023/1`3oool08>`7103oool2023/1`<0oooo100Pk0L00`3oool08>`7023/
1`06023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7
023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L0103oool08>`7023/1`3oool6023/
1`030?ooo`0Pk0L08>`700L08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`02
023/1`<0oooo0P0Pk0L0103oool08>`70?ooo`0000090?ooo`03023/1`3oool0oooo04H0oooo00<0
00000?ooo`3oool0603oool001L0oooo00<000000?ooo`3oool05`3oool00`0Pk0L0oooo0?ooo`0M
0?ooo`808>`70P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`@0oooo0P0Pk0L30?ooo`@08>`7
00<0oooo023/1`0Pk0L01P0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`70080
8>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700@0oooo023/
1`0Pk0L0oooo1P0Pk0L00`3oool08>`7023/1`06023/1`80oooo0P0Pk0L0103oool08>`7023/1`3o
ool4023/1`<0oooo0P0Pk0L0103oool08>`70?ooo`0000090?ooo`03023/1`3oool0oooo04H0oooo
00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool05`3oool00`0Pk0L0oooo0?oo
o`0N0?ooo`808>`70P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`@0oooo0P0Pk0L30?ooo`@0
8>`700<0oooo023/1`0Pk0L01P0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`7
00808>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700@0oooo
023/1`0Pk0L0oooo1P0Pk0L00`3oool08>`7023/1`06023/1`80oooo0P0Pk0L0103oool08>`7023/
1`3oool4023/1`<0oooo0P0Pk0L0103oool08>`70?ooo`0000090?ooo`03023/1`3oool0oooo04H0
oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool05`3oool00`0Pk0L0oooo
0?ooo`0N0?ooo`808>`70P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`@0oooo0P0Pk0L30?oo
o`@08>`700<0oooo023/1`0Pk0L01P0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0
8>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700@0
oooo023/1`0Pk0L0oooo1P0Pk0L00`3oool08>`7023/1`06023/1`80oooo1@0Pk0L00`3oool08>`7
023/1`02023/1`<0oooo0P0Pk0L0103oool08>`70?ooo`0000090?ooo`03023/1`3oool0oooo04H0
oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool05`3oool00`0Pk0L0oooo
0?ooo`0N0?ooo`808>`70P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`@0oooo0P0Pk0L30?oo
o`d08>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0
8>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`040?ooo`0Pk0L08>`70?ooo`H08>`7
00<0oooo023/1`0Pk0L01P0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`808>`7
00@0oooo023/1`3oool000002@3oool00`0Pk0L0oooo0?ooo`160?ooo`030000003oool0oooo01P0
oooo000F0?ooo`030000003oool0oooo01L0oooo00<08>`70?ooo`3oool07P3oool2023/1`80oooo
00H08>`70?ooo`3oool08>`70?ooo`0Pk0L40?ooo`808>`70`3oool=023/1`040?ooo`0Pk0L08>`7
0?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L0
8>`7023/1`3oool00P0Pk0L0103oool08>`7023/1`3oool6023/1`030?ooo`0Pk0L08>`700H08>`7
0P3oool5023/1`030?ooo`0Pk0L08>`700808>`70`3oool2023/1`040?ooo`0Pk0L0oooo000000T0
oooo00<08>`70?ooo`3oool0AP3oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo
0?ooo`0G0?ooo`03023/1`3oool0oooo01h0oooo0P0Pk0L20?ooo`06023/1`3oool0oooo023/1`3o
ool08>`7103oool2023/1`<0oooo2@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700<0oooo
023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo
023/1`0Pk0L08>`70?ooo`02023/1`040?ooo`0Pk0L08>`70?ooo`H08>`700<0oooo023/1`0Pk0L0
1P0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`<08>`70P3oool00`000000oooo
0?ooo`070?ooo`03023/1`3oool0oooo04H0oooo00<000000?ooo`3oool0603oool001H0oooo00<0
00000?ooo`3oool05`3oool00`0Pk0L0oooo0?ooo`0N0?ooo`808>`70P3oool01P0Pk0L0oooo0?oo
o`0Pk0L0oooo023/1`@0oooo0P0Pk0L30?ooo`T08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/
1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/
1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L0103oool08>`7023/1`3oool6023/1`030?ooo`0P
k0L08>`700H08>`70P3oool5023/1`030?ooo`0Pk0L08>`700808>`70`3oool3023/1`80oooo00<0
00000?ooo`3oool01`3oool00`0Pk0L0oooo0?ooo`160?ooo`030000003oool0oooo01P0oooo000F
0?ooo`030000003oool0oooo01L0oooo00<08>`70?ooo`3oool07P3oool2023/1`<0oooo00D08>`7
0?ooo`0Pk0L0oooo023/1`050?ooo`04023/1`3oool0oooo0?ooo`T08>`700D0oooo023/1`0Pk0L0
8>`70?ooo`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool0
8>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L0103oool08>`7023/1`3oool6
023/1`030?ooo`0Pk0L08>`700H08>`70P3oool5023/1`030?ooo`0Pk0L08>`700808>`70`3oool3
023/1`030?ooo`0Pk0L0000000T0oooo00<08>`70?ooo`3oool0AP3oool00`000000oooo0?ooo`0H
0?ooo`005P3oool00`000000oooo0?ooo`0G0?ooo`03023/1`3oool0oooo01h0oooo0P0Pk0L30?oo
o`05023/1`3oool08>`70?ooo`0Pk0L01@3oool0100Pk0L0oooo0?ooo`3oool9023/1`050?ooo`0P
k0L08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700808>`7
00<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700@0oooo023/1`0P
k0L0oooo1P0Pk0L00`3oool08>`7023/1`06023/1`80oooo1@0Pk0L00`3oool08>`7023/1`02023/
1`<0oooo0`0Pk0L00`3oool08>`7000000090?ooo`03023/1`3oool0oooo04H0oooo00<000000?oo
o`3oool0603oool001H0oooo00<000000?ooo`3oool05`3oool00`0Pk0L0oooo0?ooo`0N0?ooo`80
8>`70`3oool01@0Pk0L0oooo023/1`3oool08>`700D0oooo00@08>`70?ooo`3oool0oooo2@0Pk0L0
1@3oool08>`7023/1`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/
1`02023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`040?oo
o`0Pk0L08>`70?ooo`H08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`D08>`700<0oooo023/1`0P
k0L00P0Pk0L30?ooo`<08>`700<0oooo023/1`0000002@3oool00`0Pk0L0oooo0?ooo`160?ooo`03
0000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo01L0oooo00<08>`70?ooo`3oool0
7P3oool2023/1`<0oooo00D08>`70?ooo`0Pk0L0oooo023/1`050?ooo`04023/1`3oool0oooo0?oo
o`T08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0P
k0L0103oool08>`7023/1`3oool6023/1`030?ooo`0Pk0L08>`700H08>`70P3oool5023/1`030?oo
o`0Pk0L08>`700808>`70`3oool3023/1`030?ooo`0Pk0L0000000T0oooo00<08>`70?ooo`3oool0
AP3oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?ooo`0F0?ooo`03023/1`3o
ool0oooo01l0oooo0P0Pk0L30?ooo`05023/1`3oool08>`70?ooo`0Pk0L01@3oool0100Pk0L0oooo
0?ooo`3oool9023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`02023/
1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0
oooo00808>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L00`3oool08>`7023/1`06023/1`80oooo1@0P
k0L00`3oool08>`7023/1`02023/1`<0oooo0`0Pk0L00`3oool08>`7000000090?ooo`03023/1`3o
ool0oooo04H0oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool05P3oool0
0`0Pk0L0oooo0?ooo`0O0?ooo`808>`70`3oool01@0Pk0L0oooo023/1`3oool08>`700D0oooo00@0
8>`70?ooo`3oool0oooo2@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00L08>`700<0oooo023/1`0P
k0L00P0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L0103o
ool08>`7023/1`3oool6023/1`030?ooo`0Pk0L08>`700H08>`70P3oool5023/1`030?ooo`0Pk0L0
8>`700808>`70`3oool01P0Pk0L0oooo023/1`3oool08>`7000000T0oooo00<08>`70?ooo`3oool0
AP3oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?ooo`0F0?ooo`03023/1`3o
ool0oooo01l0oooo0P0Pk0L30?ooo`05023/1`3oool08>`70?ooo`0Pk0L01@3oool0100Pk0L0oooo
0?ooo`3oool9023/1`050?ooo`0Pk0L08>`7023/1`3oool01`0Pk0L00`3oool08>`7023/1`02023/
1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`040?ooo`0Pk0L0
8>`70?ooo`H08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L00P0P
k0L30?ooo`06023/1`3oool08>`70?ooo`0Pk0L000002@3oool00`0Pk0L0oooo0?ooo`160?ooo`03
0000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo01H0oooo00<08>`70?ooo`3oool0
7`3oool2023/1`<0oooo00D08>`70?ooo`0Pk0L0oooo023/1`050?ooo`04023/1`3oool0oooo0?oo
o`<08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00L08>`700<0oooo
023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0P
k0L0103oool08>`7023/1`3oool6023/1`030?ooo`0Pk0L08>`700H08>`70P3oool5023/1`030?oo
o`0Pk0L08>`700808>`70`3oool01P0Pk0L0oooo023/1`3oool08>`7000000T0oooo00<08>`70?oo
o`3oool0AP3oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?ooo`0F0?ooo`03
023/1`3oool0oooo01l0oooo0P0Pk0L30?ooo`05023/1`3oool08>`70?ooo`0Pk0L01@3oool0100P
k0L0oooo0?ooo`3oool3023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?oo
o`07023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo1P0Pk0L00`3oool08>`7023/1`06023/1`80
oooo1@0Pk0L00`3oool08>`7023/1`02023/1`<0oooo00H08>`70?ooo`0Pk0L0oooo023/1`000009
0?ooo`03023/1`3oool0oooo04H0oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?oo
o`3oool05P3oool00`0Pk0L0oooo0?ooo`0O0?ooo`808>`70`3oool01@0Pk0L0oooo023/1`3oool0
8>`700D0oooo00@08>`70?ooo`3oool0oooo0`0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0P
k0L08>`7023/1`3oool01`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`02023/1`040?ooo`0Pk0L08>`70?ooo`H08>`700<0oooo023/
1`0Pk0L01P0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`06023/1`3oool08>`7
0?ooo`0Pk0L000002@3oool00`0Pk0L0oooo0?ooo`160?ooo`030000003oool0oooo01P0oooo000F
0?ooo`030000003oool0oooo01H0oooo00<08>`70?ooo`3oool07`3oool2023/1`<0oooo00D08>`7
0?ooo`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo0080oooo0P0Pk0L00`3oool08>`7023/
1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool01`0Pk0L00`3oool08>`7023/1`02023/1`030?oo
o`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`040?ooo`0Pk0L08>`70?oo
o`H08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L20?oo
o`808>`700D0oooo023/1`3oool08>`7000000090?ooo`03023/1`3oool0oooo04H0oooo00<00000
0?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool05P3oool00`0Pk0L0oooo0?ooo`0O0?oo
o`808>`70`3oool01@0Pk0L0oooo023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool00P3oool8
023/1`050?ooo`0Pk0L08>`7023/1`3oool01`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0P
k0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`040?ooo`0Pk0L0oooo0?ooo`H0
8>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`D08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`80
8>`700D0oooo023/1`3oool08>`7000000090?ooo`03023/1`3oool0oooo04H0oooo00<000000?oo
o`3oool0603oool001H0oooo00<000000?ooo`3oool05P3oool00`0Pk0L0oooo0?ooo`0O0?ooo`80
8>`70`3oool01@0Pk0L0oooo023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool00P3oool8023/
1`050?ooo`0Pk0L08>`7023/1`3oool01`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0
8>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`040?ooo`0Pk0L0oooo0?ooo`H08>`7
00<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700808>`7
0P3oool2023/1`050?ooo`0Pk0L0oooo023/1`0000002@3oool00`0Pk0L0oooo0?ooo`160?ooo`03
0000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo01H0oooo00<08>`70?ooo`3oool0
7`3oool2023/1`<0oooo00<08>`70?ooo`0Pk0L00P0Pk0L50?ooo`03023/1`3oool0oooo0080oooo
200Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool0
8>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L00`3oool08>`70?ooo`07023/
1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`02023/
1`80oooo0P0Pk0L01@3oool08>`70?ooo`0Pk0L0000000T0oooo00<08>`70?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?ooo`0F0?ooo`03023/1`3oool0oooo
01l0oooo0P0Pk0L30?ooo`03023/1`3oool08>`700808>`71@3oool00`0Pk0L0oooo0?ooo`020?oo
o`P08>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700<0oooo023/1`3oool01`0P
k0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L00P0P
k0L20?ooo`808>`700D0oooo023/1`3oool08>`7000000090?ooo`03023/1`3oool0oooo04H0oooo
00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool05@3oool00`0Pk0L0oooo0?oo
o`0P0?ooo`808>`70`3oool00`0Pk0L0oooo023/1`02023/1`D0oooo00<08>`70?ooo`3oool00P3o
ool8023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L00`3oool08>`7023/1`02023/1`030?oo
o`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo0100
8>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`030?ooo`808>`700D0oooo023/1`3o
ool08>`7000000090?ooo`03023/1`3oool0oooo04H0oooo00<000000?ooo`3oool0603oool001H0
oooo00<000000?ooo`3oool05@3oool00`0Pk0L0oooo0?ooo`0P0?ooo`808>`70`3oool00`0Pk0L0
oooo023/1`02023/1`D0oooo00<08>`70?ooo`3oool00P3oool8023/1`040?ooo`0Pk0L08>`7023/
1`80oooo1P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/
1`0Pk0L08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo01008>`700@0oooo023/1`0Pk0L0oooo100P
k0L00`3oool08>`7023/1`030?ooo`808>`700D0oooo023/1`3oool08>`7000000090?ooo`03023/
1`3oool0oooo04H0oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool05@3o
ool00`0Pk0L0oooo0?ooo`0P0?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`0Pk0L00P0P
k0L50?ooo`03023/1`3oool0oooo0080oooo200Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`7
00<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3o
ool0100Pk0L00`3oool08>`7023/1`0>023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/
1`0Pk0L00`3oool2023/1`050?ooo`0Pk0L0oooo023/1`0000002@3oool00`0Pk0L0oooo0?ooo`16
0?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo01D0oooo00<08>`70?oo
o`3oool0803oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700808>`71@3oool00`0P
k0L0oooo0?ooo`020?ooo`P08>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L0
8>`700<08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`700<0
oooo023/1`0Pk0L03P0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`700<0oooo
0P0Pk0L01@3oool08>`70?ooo`0Pk0L0000000T0oooo00<08>`70?ooo`3oool0AP3oool00`000000
oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?ooo`0E0?ooo`03023/1`3oool0oooo0200oooo
00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo023/1`02023/1`D0oooo00<08>`70?ooo`3oool0
0P3oool8023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L00`3oool08>`7023/1`03023/1`03
0?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`030?ooo`0Pk0L08>`7
00h08>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`7023/1`030?ooo`<08>`70P3oool0
0`0Pk0L000000?ooo`070?ooo`03023/1`3oool0oooo04L0oooo00<000000?ooo`3oool0603oool0
01H0oooo00<000000?ooo`3oool05@3oool00`0Pk0L0oooo0?ooo`0P0?ooo`03023/1`3oool08>`7
0080oooo00<08>`70?ooo`0Pk0L00P0Pk0L50?ooo`03023/1`3oool0oooo0080oooo200Pk0L0103o
ool08>`7023/1`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`02
023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`7023/1`0>023/1`040?ooo`0P
k0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L00`3oool3023/1`040?ooo`0Pk0L0oooo000000P0
oooo00<08>`70?ooo`3oool0A`3oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo
0?ooo`0E0?ooo`03023/1`3oool0oooo0200oooo00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo
023/1`02023/1`D0oooo00<08>`70?ooo`3oool00P3oool8023/1`040?ooo`0Pk0L08>`7023/1`80
oooo1P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0P
k0L08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700h08>`700@0oooo023/1`0Pk0L0oooo100Pk0L0
0`3oool08>`7023/1`030?ooo`<08>`700@0oooo023/1`3oool00000203oool00`0Pk0L0oooo0?oo
o`170?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo01D0oooo00<08>`7
0?ooo`3oool0803oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700808>`71@3oool0
0`0Pk0L0oooo0?ooo`020?ooo`P08>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0P
k0L08>`700<08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`7
00<0oooo023/1`0Pk0L03P0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`700<0
oooo0`0Pk0L0103oool08>`70?ooo`0000080?ooo`03023/1`3oool0oooo04L0oooo00<000000?oo
o`3oool0603oool001H0oooo00<000000?ooo`3oool05@3oool00`0Pk0L0oooo0?ooo`0P0?ooo`03
023/1`3oool08>`70080oooo00<08>`70?ooo`0Pk0L00P0Pk0L50?ooo`03023/1`3oool0oooo0080
oooo200Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3o
ool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`7023/1`0>
023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L00`3oool3023/1`040?ooo`0P
k0L0oooo000000P0oooo00<08>`70?ooo`3oool0A`3oool00`000000oooo0?ooo`0H0?ooo`005P3o
ool00`000000oooo0?ooo`0E0?ooo`03023/1`3oool0oooo0200oooo00<08>`70?ooo`0Pk0L00P3o
ool00`0Pk0L0oooo023/1`02023/1`D0oooo00<08>`70?ooo`3oool00P3oool8023/1`040?ooo`0P
k0L08>`7023/1`80oooo1P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700808>`7
00D0oooo023/1`0Pk0L08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700h08>`700@0oooo023/1`0P
k0L0oooo100Pk0L00`3oool08>`7023/1`030?ooo`<08>`700@0oooo023/1`0Pk0L00000203oool0
0`0Pk0L0oooo0?ooo`170?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo
01@0oooo00<08>`70?ooo`3oool08@3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`7
00808>`71@3oool00`0Pk0L0oooo0?ooo`020?ooo`808>`700<0oooo023/1`0Pk0L00`0Pk0L0103o
ool08>`7023/1`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`02
023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`7023/1`0>023/1`040?ooo`0P
k0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L00`3oool3023/1`040?ooo`0Pk0L08>`7000000P0
oooo00<08>`70?ooo`3oool0A`3oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo
0?ooo`0D0?ooo`03023/1`3oool0oooo0240oooo00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo
023/1`02023/1`D0oooo00<08>`70?ooo`3oool00P3oool2023/1`030?ooo`0Pk0L08>`700<08>`7
00@0oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0P
k0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L03P0Pk0L0103o
ool08>`7023/1`3oool7023/1`<0oooo0`0Pk0L0103oool08>`7023/1`0000080?ooo`03023/1`3o
ool0oooo04L0oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool0503oool0
0`0Pk0L0oooo0?ooo`0Q0?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`0Pk0L00P0Pk0L5
0?ooo`808>`70`3oool8023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L00`3oool08>`70?oo
o`03023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`050?oo
o`0Pk0L08>`7023/1`3oool0300Pk0L0103oool08>`7023/1`3oool7023/1`<0oooo0`0Pk0L0103o
ool08>`7023/1`0000080?ooo`03023/1`3oool0oooo04L0oooo00<000000?ooo`3oool0603oool0
01H0oooo00<000000?ooo`3oool0503oool00`0Pk0L0oooo0?ooo`0Q0?ooo`03023/1`3oool08>`7
0080oooo00<08>`70?ooo`0Pk0L00P0Pk0L50?ooo`808>`70`3oool8023/1`040?ooo`0Pk0L08>`7
023/1`80oooo1P0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`700D0oooo
023/1`0Pk0L08>`70?ooo`04023/1`050?ooo`0Pk0L08>`7023/1`3oool0300Pk0L0103oool08>`7
023/1`3oool7023/1`<0oooo0`0Pk0L0103oool08>`7023/1`0000080?ooo`03023/1`3oool0oooo
04L0oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool0503oool00`0Pk0L0
oooo0?ooo`0Q0?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`0Pk0L00P0Pk0L50?ooo`80
8>`70`3oool8023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L00`3oool08>`70?ooo`03023/
1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`050?ooo`0Pk0L0
8>`7023/1`3oool0300Pk0L0103oool08>`7023/1`3oool7023/1`<0oooo0`0Pk0L0103oool08>`7
023/1`0000080?ooo`03023/1`3oool0oooo04L0oooo00<000000?ooo`3oool0603oool001H0oooo
00<000000?ooo`3oool0503oool00`0Pk0L0oooo0?ooo`0Q0?ooo`03023/1`3oool08>`70080oooo
00<08>`70?ooo`0Pk0L00P0Pk0L50?ooo`808>`70`3oool8023/1`040?ooo`0Pk0L08>`7023/1`80
oooo1P0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0P
k0L08>`70?ooo`04023/1`050?ooo`0Pk0L08>`7023/1`3oool0300Pk0L0103oool08>`7023/1`3o
ool7023/1`<0oooo0`0Pk0L0103oool08>`7023/1`0000080?ooo`03023/1`3oool0oooo04L0oooo
00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool0503oool00`0Pk0L0oooo0?oo
o`0Q0?ooo`03023/1`3oool08>`70080oooo00<08>`70?ooo`0Pk0L00P0Pk0L50?ooo`808>`70`3o
ool8023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L00`3oool08>`70?ooo`03023/1`030?oo
o`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`050?ooo`0Pk0L08>`7023/
1`3oool0300Pk0L0103oool08>`7023/1`3oool7023/1`<0oooo0`0Pk0L0103oool08>`7023/1`00
00080?ooo`03023/1`3oool0oooo04L0oooo00<000000?ooo`3oool0603oool001H0oooo00<00000
0?ooo`3oool0503oool00`0Pk0L0oooo0?ooo`0Q0?ooo`03023/1`3oool08>`70080oooo00H08>`7
0?ooo`0Pk0L08>`70?ooo`0Pk0L40?ooo`808>`70`3oool8023/1`040?ooo`0Pk0L08>`7023/1`80
oooo1P0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0P
k0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00`08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L0
0`3oool08>`70?ooo`020?ooo`<08>`700@0oooo023/1`0Pk0L00000203oool00`0Pk0L0oooo0?oo
o`170?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo01@0oooo00<08>`7
0?ooo`3oool08P3oool2023/1`80oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L40?ooo`808>`7
0`3oool8023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L00`3oool08>`70?ooo`03023/1`03
0?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00`08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L00`3oool08>`70?ooo`020?ooo`<08>`700@0oooo
023/1`0Pk0L00000203oool00`0Pk0L0oooo0?ooo`170?ooo`030000003oool0oooo01P0oooo000F
0?ooo`030000003oool0oooo01@0oooo00<08>`70?ooo`3oool08P3oool2023/1`80oooo00H08>`7
0?ooo`0Pk0L08>`70?ooo`0Pk0L40?ooo`808>`70`3oool8023/1`040?ooo`0Pk0L08>`7023/1`80
oooo1P0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0P
k0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00`08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L0
0`3oool08>`70?ooo`020?ooo`<08>`700@0oooo023/1`0Pk0L00000203oool00`0Pk0L0oooo0?oo
o`170?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo01@0oooo00<08>`7
0?ooo`3oool08P3oool2023/1`80oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L40?ooo`808>`7
0`3oool8023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L00`3oool08>`70?ooo`03023/1`03
0?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00`08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L00`3oool08>`70?ooo`020?ooo`<08>`700@0oooo
023/1`0Pk0L00000203oool00`0Pk0L0oooo0?ooo`170?ooo`030000003oool0oooo01P0oooo000F
0?ooo`030000003oool0oooo01<0oooo00<08>`70?ooo`3oool08`3oool2023/1`80oooo00H08>`7
0?ooo`0Pk0L08>`70?ooo`0Pk0L40?ooo`808>`70`3oool8023/1`040?ooo`0Pk0L08>`7023/1`80
oooo1P0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0P
k0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00`08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L0
1@3oool08>`7023/1`3oool08>`700<0oooo0`0Pk0L0103oool08>`7023/1`0000080?ooo`03023/
1`3oool0oooo04L0oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool04`3o
ool00`0Pk0L0oooo0?ooo`0S0?ooo`808>`70P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`@0
oooo0P0Pk0L30?ooo`P08>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L0oooo
00@08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7
023/1`3oool0300Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700808>`70`3o
ool3023/1`040?ooo`0Pk0L08>`7000000P0oooo00<08>`70?ooo`3oool0A`3oool00`000000oooo
0?ooo`0H0?ooo`005P3oool00`000000oooo0?ooo`0C0?ooo`03023/1`3oool0oooo02<0oooo0P0P
k0L20?ooo`06023/1`3oool08>`7023/1`3oool08>`7103oool2023/1`<0oooo200Pk0L0103oool0
8>`7023/1`0Pk0L20?ooo`H08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`05023/
1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/1`0Pk0L08>`70?ooo`0<023/1`040?ooo`0Pk0L0
8>`70?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`<08>`700@0oooo023/1`0Pk0L00000
203oool00`0Pk0L0oooo0?ooo`170?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000003o
ool0oooo01<0oooo00<08>`70?ooo`3oool08`3oool2023/1`80oooo00H08>`70?ooo`0Pk0L08>`7
0?ooo`0Pk0L40?ooo`808>`70`3oool8023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L00`3o
ool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3oool00P0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00`08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L0103oool08>`7023/
1`0Pk0L30?ooo`<08>`700@0oooo023/1`0Pk0L00000203oool00`0Pk0L0oooo0?ooo`170?ooo`03
0000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo01<0oooo00<08>`70?ooo`3oool0
8`3oool2023/1`80oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L40?ooo`808>`70`3oool8023/
1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L0
8>`700D08>`700<0oooo023/1`3oool00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00l08>`700D0
oooo023/1`0Pk0L08>`70?ooo`03023/1`<0oooo0P0Pk0L01@3oool08>`70?ooo`0Pk0L0000000P0
oooo00<08>`70?ooo`3oool0A`3oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo
0?ooo`0C0?ooo`03023/1`3oool0oooo02<0oooo0P0Pk0L20?ooo`06023/1`3oool08>`7023/1`3o
ool08>`7103oool2023/1`<0oooo200Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`700<0oooo
023/1`3oool0100Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00808>`700D0oooo
023/1`0Pk0L08>`70?ooo`0?023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L30?ooo`808>`7
00D0oooo023/1`3oool08>`7000000080?ooo`03023/1`3oool0oooo04L0oooo00<000000?ooo`3o
ool0603oool001H0oooo00<000000?ooo`3oool04`3oool00`0Pk0L0oooo0?ooo`0S0?ooo`808>`7
0P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/1`@0oooo0P0Pk0L30?ooo`P08>`700@0oooo023/
1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L01@0Pk0L0
0`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L08>`7023/1`3oool03`0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00<08>`70`3oool2023/1`050?ooo`0Pk0L0oooo023/1`000000203oool00`0Pk0L0
oooo0?ooo`170?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo01<0oooo
00<08>`70?ooo`3oool08`3oool2023/1`80oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L40?oo
o`808>`70`3oool8023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L00`3oool08>`70?ooo`04
023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3oool00P0Pk0L01@3oool08>`7023/1`0P
k0L0oooo00l08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`<0oooo0P0Pk0L01@3oool08>`7
0?ooo`0Pk0L0000000P0oooo00<08>`70?ooo`3oool0A`3oool00`000000oooo0?ooo`0H0?ooo`00
5P3oool00`000000oooo0?ooo`0C0?ooo`03023/1`3oool0oooo02<0oooo0P0Pk0L20?ooo`06023/
1`3oool08>`7023/1`3oool08>`7103oool2023/1`<0oooo200Pk0L0103oool08>`7023/1`0Pk0L2
0?ooo`H08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0
oooo00808>`700D0oooo023/1`0Pk0L08>`70?ooo`0>023/1`80oooo0`0Pk0L0103oool08>`7023/
1`0Pk0L30?ooo`808>`700D0oooo023/1`3oool08>`7000000080?ooo`03023/1`3oool0oooo04L0
oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool04`3oool00`0Pk0L0oooo
0?ooo`0S0?ooo`808>`70P3oool01P0Pk0L0oooo0?ooo`0Pk0L0oooo023/1`@0oooo0P0Pk0L30?oo
o`P08>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo
023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L08>`7023/1`3oool03P0P
k0L20?ooo`<08>`700@0oooo023/1`0Pk0L08>`70`3oool2023/1`050?ooo`0Pk0L0oooo023/1`00
0000203oool00`0Pk0L0oooo0?ooo`170?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000
003oool0oooo0180oooo00<08>`70?ooo`3oool0903oool2023/1`80oooo00H08>`70?ooo`3oool0
8>`70?ooo`0Pk0L40?ooo`808>`70`3oool8023/1`040?ooo`0Pk0L08>`7023/1`80oooo1P0Pk0L0
0`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3oool00P0Pk0L0
1@3oool08>`7023/1`0Pk0L0oooo00h08>`70P3oool3023/1`040?ooo`0Pk0L08>`7023/1`<0oooo
0P0Pk0L01@3oool08>`70?ooo`0Pk0L0000000L0oooo00<08>`70?ooo`3oool0B03oool00`000000
oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?ooo`0B0?ooo`03023/1`3oool0oooo02@0oooo
0P0Pk0L20?ooo`06023/1`3oool0oooo023/1`3oool08>`7103oool2023/1`<0oooo200Pk0L0103o
ool08>`7023/1`0Pk0L20?ooo`H08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`05
023/1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/1`0Pk0L08>`70?ooo`0>023/1`80oooo0`0P
k0L0103oool08>`7023/1`0Pk0L30?ooo`808>`700D0oooo023/1`3oool08>`7000000070?ooo`03
023/1`3oool0oooo04P0oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool0
4P3oool00`0Pk0L0oooo0?ooo`0T0?ooo`808>`70`3oool01@0Pk0L0oooo023/1`3oool08>`700@0
oooo0P0Pk0L30?ooo`P08>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0Pk0L0oooo
00@08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L08>`7
023/1`3oool03P0Pk0L20?ooo`<08>`700@0oooo023/1`0Pk0L08>`70`3oool2023/1`050?ooo`0P
k0L0oooo023/1`0000001`3oool00`0Pk0L0oooo0?ooo`180?ooo`030000003oool0oooo01P0oooo
000F0?ooo`030000003oool0oooo0180oooo00<08>`70?ooo`3oool0903oool2023/1`<0oooo00D0
8>`70?ooo`0Pk0L0oooo023/1`040?ooo`808>`70`3oool8023/1`040?ooo`0Pk0L08>`7023/1`80
oooo1P0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3o
ool00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00h08>`70P3oool3023/1`040?ooo`0Pk0L08>`7
023/1`<0oooo0P0Pk0L01@3oool08>`70?ooo`0Pk0L0000000L0oooo00<08>`70?ooo`3oool0B03o
ool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?ooo`0B0?ooo`03023/1`3oool0
oooo02@0oooo0P0Pk0L30?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool2023/1`<0oooo200P
k0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7
023/1`05023/1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/1`0Pk0L08>`70?ooo`0>023/1`80
oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`<08>`700D0oooo023/1`3oool08>`700000007
0?ooo`03023/1`3oool0oooo04P0oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?oo
o`3oool04P3oool00`0Pk0L0oooo0?ooo`0T0?ooo`808>`70`3oool01@0Pk0L0oooo023/1`3oool0
8>`700@0oooo0P0Pk0L30?ooo`P08>`700@0oooo023/1`0Pk0L08>`70P3oool6023/1`030?ooo`0P
k0L0oooo00@08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0P
k0L08>`7023/1`3oool03P0Pk0L20?ooo`<08>`700@0oooo023/1`0Pk0L08>`70P3oool3023/1`05
0?ooo`0Pk0L0oooo023/1`0000001`3oool00`0Pk0L0oooo0?ooo`180?ooo`030000003oool0oooo
01P0oooo000F0?ooo`030000003oool0oooo0180oooo00<08>`70?ooo`3oool0903oool2023/1`<0
oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`808>`70`3oool8023/1`040?ooo`0Pk0L08>`7
023/1`80oooo1P0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo
023/1`3oool00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00h08>`70P3oool3023/1`040?ooo`0P
k0L08>`7023/1`80oooo0`0Pk0L01@3oool08>`70?ooo`0Pk0L0000000L0oooo00<08>`70?ooo`3o
ool0B03oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?ooo`0B0?ooo`03023/
1`3oool0oooo02@0oooo0P0Pk0L30?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool2023/1`80
oooo2@0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`H08>`700<0oooo023/1`3oool0100Pk0L00`3o
ool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/1`0Pk0L08>`70?ooo`0>
023/1`80oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`<08>`700D0oooo023/1`3oool08>`7
000000070?ooo`03023/1`3oool0oooo04P0oooo00<000000?ooo`3oool0603oool001H0oooo00<0
00000?ooo`3oool04P3oool00`0Pk0L0oooo0?ooo`0T0?ooo`808>`70`3oool01@0Pk0L0oooo023/
1`3oool08>`700@0oooo0`0Pk0L00`3oool08>`7023/1`07023/1`040?ooo`0Pk0L08>`7023/1`80
oooo1P0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3o
ool00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700<0oooo023/1`0Pk0L01P0Pk0L20?oo
o`<08>`700@0oooo023/1`0Pk0L08>`70P3oool3023/1`050?ooo`0Pk0L0oooo023/1`0000001`3o
ool00`0Pk0L0oooo0?ooo`180?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0
oooo0180oooo00<08>`70?ooo`3oool0903oool2023/1`<0oooo00D08>`70?ooo`0Pk0L0oooo023/
1`040?ooo`<08>`700<0oooo023/1`0Pk0L01`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`P08>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00808>`7
00D0oooo023/1`0Pk0L08>`70?ooo`0>023/1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`0P
k0L08>`70P3oool3023/1`050?ooo`0Pk0L0oooo023/1`0000001`3oool00`0Pk0L0oooo0?ooo`18
0?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo0180oooo00<08>`70?oo
o`3oool0903oool2023/1`<0oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`<08>`700<0oooo
023/1`0Pk0L01`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`P08>`700<0oooo023/1`0Pk0L00P0P
k0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L0300P
k0L00`3oool08>`7023/1`06023/1`80oooo0`0Pk0L01@3oool08>`70?ooo`0Pk0L0000000L0oooo
00<08>`70?ooo`3oool0B03oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?oo
o`0A0?ooo`03023/1`3oool0oooo02D0oooo0P0Pk0L30?ooo`05023/1`3oool08>`70?ooo`0Pk0L0
103oool3023/1`030?ooo`0Pk0L08>`700L08>`700@0oooo023/1`0Pk0L08>`70P3oool8023/1`03
0?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`06023/1`03
0?ooo`0Pk0L08>`700`08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`<08>`700D0oooo023/1`3o
ool08>`7000000070?ooo`03023/1`3oool0oooo04P0oooo00<000000?ooo`3oool0603oool001H0
oooo00<000000?ooo`3oool04@3oool00`0Pk0L0oooo0?ooo`0U0?ooo`808>`70`3oool01@0Pk0L0
oooo023/1`3oool08>`700@0oooo0`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700@0oooo
023/1`0Pk0L08>`70P3oool8023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01@0P
k0L00`3oool08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700`08>`700<0oooo023/1`0Pk0L01P0P
k0L20?ooo`<08>`700D0oooo023/1`3oool08>`7000000070?ooo`03023/1`3oool0oooo04P0oooo
00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool04@3oool00`0Pk0L0oooo0?oo
o`0U0?ooo`808>`70`3oool01@0Pk0L0oooo023/1`3oool08>`700@0oooo0`0Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00D08>`700@0oooo023/1`0Pk0L08>`70P3oool8023/1`030?ooo`0Pk0L08>`7
00808>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`06023/1`030?ooo`0Pk0L08>`7
00`08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`<08>`700D0oooo023/1`0Pk0L0oooo00000007
0?ooo`03023/1`3oool0oooo04P0oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?oo
o`3oool04@3oool00`0Pk0L0oooo0?ooo`0U0?ooo`03023/1`3oool08>`70080oooo00D08>`70?oo
o`0Pk0L0oooo023/1`040?ooo`<08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`040?ooo`0P
k0L08>`7023/1`80oooo200Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700D08>`7
00<0oooo023/1`3oool00`0Pk0L0103oool08>`7023/1`3oool>023/1`030?ooo`0Pk0L08>`700H0
8>`70P3oool3023/1`050?ooo`0Pk0L08>`70?ooo`0000001`3oool00`0Pk0L0oooo0?ooo`180?oo
o`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo0140oooo00<08>`70?ooo`3o
ool09@3oool00`0Pk0L0oooo023/1`020?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool3023/
1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`P08>`700<0
oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00<08>`700@0
oooo023/1`0Pk0L0oooo3P0Pk0L00`3oool08>`7023/1`06023/1`80oooo0P0Pk0L01P3oool08>`7
0?ooo`0Pk0L0oooo000000L0oooo00<08>`70?ooo`3oool0B03oool00`000000oooo0?ooo`0H0?oo
o`005P3oool00`000000oooo0?ooo`0A0?ooo`03023/1`3oool0oooo02D0oooo00<08>`70?ooo`0P
k0L00P3oool01@0Pk0L0oooo023/1`3oool08>`700@0oooo0`0Pk0L01@3oool08>`7023/1`0Pk0L0
oooo00D08>`700@0oooo023/1`0Pk0L08>`70P3oool8023/1`030?ooo`0Pk0L08>`700808>`700<0
oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`H08>`7
00<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`05023/1`<0oooo0P0Pk0L01P3oool08>`7
0?ooo`0Pk0L0oooo000000L0oooo00<08>`70?ooo`3oool0B03oool00`000000oooo0?ooo`0H0?oo
o`005P3oool00`000000oooo0?ooo`0A0?ooo`03023/1`3oool0oooo02D0oooo00<08>`70?ooo`0P
k0L00P3oool01@0Pk0L0oooo023/1`3oool08>`700@0oooo0`0Pk0L01@3oool08>`7023/1`0Pk0L0
oooo00D08>`700@0oooo023/1`0Pk0L08>`70P3oool8023/1`030?ooo`0Pk0L08>`700808>`700<0
oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`H08>`7
00<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`05023/1`<0oooo0P0Pk0L01P3oool08>`7
0?ooo`0Pk0L0oooo000000L0oooo00<08>`70?ooo`3oool0B03oool00`000000oooo0?ooo`0H0?oo
o`005P3oool00`000000oooo0?ooo`0A0?ooo`03023/1`3oool0oooo02D0oooo00<08>`70?ooo`0P
k0L00P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo0`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00D08>`700@0oooo023/1`0Pk0L08>`70P3oool8023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`H08>`700<0
oooo023/1`0Pk0L01@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70`3oool2023/1`060?oo
o`0Pk0L0oooo023/1`3oool000001`3oool00`0Pk0L0oooo0?ooo`180?ooo`030000003oool0oooo
01P0oooo000F0?ooo`030000003oool0oooo0140oooo00<08>`70?ooo`3oool09@3oool00`0Pk0L0
oooo023/1`020?ooo`03023/1`3oool08>`700808>`7103oool3023/1`050?ooo`0Pk0L08>`7023/
1`3oool01@0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`P08>`700<0oooo023/1`0Pk0L00P0Pk0L0
0`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L0oooo1P0P
k0L00`3oool08>`7023/1`05023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L30?ooo`808>`7
00H0oooo023/1`3oool08>`70?ooo`0000070?ooo`03023/1`3oool0oooo04P0oooo00<000000?oo
o`3oool0603oool001H0oooo00<000000?ooo`3oool04@3oool00`0Pk0L0oooo0?ooo`0U0?ooo`03
023/1`3oool08>`70080oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`<08>`700D0oooo023/1`0P
k0L08>`70?ooo`05023/1`040?ooo`0Pk0L08>`7023/1`80oooo200Pk0L00`3oool08>`7023/1`02
023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3oool00`0Pk0L0103oool08>`7023/1`3o
ool6023/1`030?ooo`0Pk0L08>`700D08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`<0oooo
0P0Pk0L01P3oool08>`70?ooo`0Pk0L0oooo000000L0oooo00<08>`70?ooo`3oool0B03oool00`00
0000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?ooo`0@0?ooo`03023/1`3oool0oooo02H0
oooo00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo0`0Pk0L01@3oool0
8>`7023/1`0Pk0L0oooo00D08>`700@0oooo023/1`0Pk0L08>`70P3oool8023/1`030?ooo`0Pk0L0
8>`700808>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L0
8>`70?ooo`H08>`700<0oooo023/1`0Pk0L01@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`7
0`3oool2023/1`060?ooo`0Pk0L0oooo023/1`3oool000001`3oool00`0Pk0L0oooo0?ooo`180?oo
o`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo0100oooo00<08>`70?ooo`3o
ool09P3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700808>`7103oool4023/1`04
0?ooo`0Pk0L08>`70?ooo`D08>`700@0oooo023/1`0Pk0L08>`70P3oool8023/1`030?ooo`0Pk0L0
8>`700808>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L0
8>`70?ooo`H08>`700<0oooo023/1`0Pk0L01@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`7
0`3oool2023/1`060?ooo`0Pk0L0oooo023/1`3oool000001`3oool00`0Pk0L0oooo0?ooo`180?oo
o`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo0100oooo00<08>`70?ooo`3o
ool09P3oool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700808>`7103oool4023/1`03
0?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L08>`70P3oool8023/1`030?ooo`0Pk0L08>`7
00808>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`7
00@08>`700<0oooo023/1`0Pk0L01@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70`3oool2
023/1`060?ooo`0Pk0L0oooo023/1`3oool000001`3oool00`0Pk0L0oooo0?ooo`180?ooo`030000
003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo0100oooo00<08>`70?ooo`3oool09P3o
ool00`0Pk0L0oooo023/1`020?ooo`03023/1`3oool08>`700808>`7103oool4023/1`030?ooo`0P
k0L08>`700H08>`700@0oooo023/1`0Pk0L08>`70P3oool8023/1`030?ooo`0Pk0L08>`700808>`7
00<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700@08>`7
00<0oooo023/1`0Pk0L01@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70`3oool2023/1`06
0?ooo`0Pk0L0oooo023/1`3oool000001`3oool00`0Pk0L0oooo0?ooo`180?ooo`030000003oool0
oooo01P0oooo000F0?ooo`030000003oool0oooo0100oooo00<08>`70?ooo`3oool09P3oool00`0P
k0L0oooo023/1`020?ooo`03023/1`3oool08>`700808>`71@3oool3023/1`030?ooo`0Pk0L08>`7
00H08>`700@0oooo023/1`0Pk0L08>`70P3oool8023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo
023/1`0Pk0L0100Pk0L20?ooo`<08>`700@0oooo023/1`0Pk0L08>`70`3oool2023/1`060?ooo`0P
k0L0oooo023/1`3oool000001`3oool00`0Pk0L0oooo0?ooo`180?ooo`030000003oool0oooo01P0
oooo000F0?ooo`030000003oool0oooo0100oooo00<08>`70?ooo`3oool09P3oool00`0Pk0L0oooo
023/1`020?ooo`03023/1`3oool08>`700808>`71@3oool3023/1`030?ooo`0Pk0L08>`700808>`7
00D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo200Pk0L00`3oool08>`7023/1`02023/1`03
0?ooo`0Pk0L08>`700h08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`04023/1`80
oooo0`0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`00
00070?ooo`03023/1`3oool0oooo04P0oooo00<000000?ooo`3oool0603oool001H0oooo00<00000
0?ooo`3oool0403oool00`0Pk0L0oooo0?ooo`0V0?ooo`03023/1`3oool08>`70080oooo00<08>`7
0?ooo`0Pk0L00P0Pk0L50?ooo`<08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0P
k0L0oooo00<08>`70P3oool8023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L03P0P
k0L00`3oool08>`7023/1`0;023/1`80oooo0`0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`808>`7
00H0oooo023/1`3oool08>`70?ooo`0000070?ooo`03023/1`3oool0oooo04P0oooo00<000000?oo
o`3oool0603oool001H0oooo00<000000?ooo`3oool0403oool00`0Pk0L0oooo0?ooo`0W0?ooo`80
8>`70P3oool00`0Pk0L0oooo023/1`02023/1`D0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`05
0?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`@08>`700D0oooo023/1`0Pk0L08>`70?ooo`04
023/1`030?ooo`0Pk0L08>`700h08>`700<0oooo023/1`0Pk0L02`0Pk0L20?ooo`<08>`700@0oooo
023/1`3oool08>`70`3oool2023/1`060?ooo`0Pk0L0oooo023/1`3oool000001P3oool00`0Pk0L0
oooo0?ooo`190?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo0100oooo
00<08>`70?ooo`3oool09`3oool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L50?ooo`<08>`7
00<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70P3oool4023/1`05
0?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`7023/1`0>023/1`030?ooo`0Pk0L08>`7
00/08>`70P3oool3023/1`040?ooo`0Pk0L0oooo023/1`<0oooo0P0Pk0L01P3oool08>`70?ooo`0P
k0L0oooo000000H0oooo00<08>`70?ooo`3oool0B@3oool00`000000oooo0?ooo`0H0?ooo`005P3o
ool00`000000oooo0?ooo`0@0?ooo`03023/1`3oool0oooo02L0oooo0P0Pk0L20?ooo`03023/1`3o
ool08>`700808>`71@3oool3023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`7
0?ooo`03023/1`80oooo100Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`700<0oooo023/1`0P
k0L03P0Pk0L00`3oool08>`7023/1`0;023/1`80oooo0`0Pk0L0103oool08>`70?ooo`0Pk0L30?oo
o`808>`700H0oooo023/1`3oool08>`70?ooo`0000060?ooo`03023/1`3oool0oooo04T0oooo00<0
00000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool03`3oool00`0Pk0L0oooo0?ooo`0X
0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`D0oooo0`0Pk0L00`3oool08>`7023/1`02
023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`@08>`700D0oooo023/1`0Pk0L08>`7
0?ooo`0S023/1`80oooo0`0Pk0L0103oool08>`70?ooo`0Pk0L30?ooo`808>`700H0oooo023/1`3o
ool08>`70?ooo`0000060?ooo`03023/1`3oool0oooo04T0oooo00<000000?ooo`3oool0603oool0
01H0oooo00<000000?ooo`3oool03`3oool00`0Pk0L0oooo0?ooo`0X0?ooo`808>`70P3oool00`0P
k0L0oooo023/1`02023/1`D0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7
023/1`3oool00`0Pk0L20?ooo`@08>`700D0oooo023/1`0Pk0L08>`70?ooo`0S023/1`80oooo0`0P
k0L0103oool08>`70?ooo`0Pk0L30?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`0000060?oo
o`03023/1`3oool0oooo04T0oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3o
ool03`3oool00`0Pk0L0oooo0?ooo`0X0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`D0
oooo0`0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?oo
o`@08>`700D0oooo023/1`0Pk0L08>`70?ooo`0S023/1`80oooo0`0Pk0L0103oool08>`70?ooo`0P
k0L30?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`0000060?ooo`03023/1`3oool0oooo04T0
oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool03`3oool00`0Pk0L0oooo
0?ooo`0X0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`D0oooo0`0Pk0L00`3oool08>`7
023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`@08>`700D0oooo023/1`0P
k0L08>`70?ooo`0S023/1`80oooo1@0Pk0L00`3oool08>`70?ooo`020?ooo`808>`700H0oooo023/
1`3oool08>`70?ooo`0000060?ooo`03023/1`3oool0oooo04T0oooo00<000000?ooo`3oool0603o
ool001H0oooo00<000000?ooo`3oool03`3oool00`0Pk0L0oooo0?ooo`0X0?ooo`808>`70P3oool0
0`0Pk0L0oooo023/1`02023/1`D0oooo00@08>`70?ooo`0Pk0L0oooo100Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00<08>`70P3oool8023/1`030?ooo`0Pk0L08>`702408>`70P3oool5023/1`030?oo
o`0Pk0L0oooo0080oooo0`0Pk0L20?ooo`03023/1`3oool0000000H0oooo00<08>`70?ooo`3oool0
B@3oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?ooo`0?0?ooo`03023/1`3o
ool0oooo02P0oooo0P0Pk0L20?ooo`03023/1`3oool08>`700808>`71@3oool3023/1`030?ooo`0P
k0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo200Pk0L00`3oool08>`7
023/1`0Q023/1`80oooo1@0Pk0L00`3oool08>`70?ooo`020?ooo`<08>`70P3oool00`0Pk0L0oooo
000000060?ooo`03023/1`3oool0oooo04T0oooo00<000000?ooo`3oool0603oool001H0oooo00<0
00000?ooo`3oool03`3oool00`0Pk0L0oooo0?ooo`0X0?ooo`808>`70P3oool00`0Pk0L0oooo023/
1`02023/1`D0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0
0`0Pk0L20?ooo`P08>`700<0oooo023/1`0Pk0L08@0Pk0L20?ooo`D08>`700<0oooo023/1`3oool0
0P3oool3023/1`80oooo00<08>`70?ooo`0000001P3oool00`0Pk0L0oooo0?ooo`190?ooo`030000
003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo00l0oooo00<08>`70?ooo`3oool0:03o
ool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L50?ooo`<08>`700<0oooo023/1`0Pk0L00P0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70P3oool8023/1`030?ooo`0Pk0L08>`702408>`7
0P3oool5023/1`030?ooo`0Pk0L0oooo0080oooo0`0Pk0L20?ooo`03023/1`3oool0000000H0oooo
00<08>`70?ooo`3oool0B@3oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?oo
o`0?0?ooo`03023/1`3oool0oooo02P0oooo0P0Pk0L20?ooo`03023/1`3oool08>`700808>`71@3o
ool3023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo
200Pk0L00`3oool08>`7023/1`0Q023/1`80oooo1`0Pk0L30?ooo`<08>`70P3oool00`0Pk0L0oooo
000000060?ooo`03023/1`3oool0oooo04T0oooo00<000000?ooo`3oool0603oool001H0oooo00<0
00000?ooo`3oool03`3oool00`0Pk0L0oooo0?ooo`0X0?ooo`808>`70P3oool00`0Pk0L0oooo023/
1`02023/1`D0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0
0`0Pk0L20?ooob`08>`70P3oool7023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo
000000060?ooo`03023/1`3oool0oooo04T0oooo00<000000?ooo`3oool0603oool001H0oooo00<0
00000?ooo`3oool03`3oool00`0Pk0L0oooo0?ooo`0X0?ooo`808>`70P3oool00`0Pk0L0oooo023/
1`02023/1`D0oooo0`0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0
0`0Pk0L20?ooob`08>`70P3oool7023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool00`0Pk0L0oooo
000000060?ooo`03023/1`3oool0oooo04T0oooo00<000000?ooo`3oool0603oool001H0oooo00<0
00000?ooo`3oool03P3oool00`0Pk0L0oooo0?ooo`0Y0?ooo`808>`70P3oool01P0Pk0L0oooo023/
1`0Pk0L0oooo023/1`@0oooo0P0000000`0Pk0L0oooo023/1`03023/1`050?ooo`0Pk0L08>`7023/
1`3oool00`0Pk0L20?ooob`08>`70P3oool7023/1`<0oooo00<08>`70?ooo`0Pk0L00P3oool00`0P
k0L0oooo000000060?ooo`03023/1`3oool0oooo04T0oooo00<000000?ooo`3oool0603oool001H0
oooo00<000000?ooo`3oool03P3oool00`0Pk0L0oooo0?ooo`0Y0?ooo`808>`70P3oool01P0Pk0L0
oooo023/1`0Pk0L0oooo023/1`@0oooo0P0000000`0Pk0L0oooo023/1`07023/1`040?ooo`0Pk0L0
8>`7023/1`80oooo;00Pk0L20?ooo`L08>`70P3oool2023/1`070?ooo`0Pk0L0oooo0?ooo`0Pk0L0
oooo000000060?ooo`03023/1`3oool0oooo04T0oooo00<000000?ooo`3oool0603oool001H0oooo
00<000000?ooo`3oool03P3oool00`0Pk0L0oooo0?ooo`0Y0?ooo`808>`70P3oool01P0Pk0L0oooo
023/1`0Pk0L0oooo023/1`@0oooo00@08>`70?ooo`0Pk0L0oooo200Pk0L0103oool08>`7023/1`0P
k0L20?ooob`08>`70P3oool7023/1`80oooo0P0Pk0L01`3oool08>`70?ooo`3oool08>`70?ooo`00
00001P3oool00`0Pk0L0oooo0?ooo`190?ooo`030000003oool0oooo01P0oooo000F0?ooo`030000
003oool0oooo00h0oooo00<08>`70?ooo`3oool0:@3oool2023/1`80oooo00H08>`70?ooo`0Pk0L0
8>`70?ooo`0Pk0L40?ooo`04023/1`3oool08>`70?ooo`P08>`700@0oooo023/1`0Pk0L08>`70P3o
ool/023/1`80oooo1`0Pk0L20?ooo`808>`700L0oooo023/1`3oool0oooo023/1`3oool0000000H0
oooo00<08>`70?ooo`3oool0B@3oool00`000000oooo0?ooo`0H0?ooo`005P3oool00`000000oooo
0?ooo`0>0?ooo`03023/1`3oool0oooo02T0oooo0P0Pk0L20?ooo`06023/1`3oool08>`7023/1`3o
ool08>`7103oool0100Pk0L0oooo023/1`3oool8023/1`040?ooo`0Pk0L08>`7023/1`80oooo;00P
k0L20?ooo`L08>`70P3oool2023/1`070?ooo`0Pk0L0oooo0?ooo`0Pk0L0oooo000000060?ooo`03
023/1`3oool0oooo04T0oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?ooo`3oool0
3P3oool00`0Pk0L0oooo0?ooo`0Y0?ooo`808>`70P3oool01P0Pk0L0oooo023/1`0Pk0L0oooo023/
1`@0oooo00@08>`70?ooo`0Pk0L0oooo200Pk0L0103oool08>`7023/1`0Pk0L20?oooa<08>`700<0
oooo023/1`0Pk0L05P0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`808>`700L0
oooo023/1`3oool0oooo023/1`3oool0000000H0oooo00<08>`70?ooo`3oool0B@3oool00`000000
oooo0?ooo`0H0?ooo`005P3oool00`000000oooo0?ooo`0>0?ooo`03023/1`3oool0oooo02T0oooo
0P0Pk0L20?ooo`06023/1`3oool08>`7023/1`3oool08>`7103oool0100Pk0L0oooo023/1`3oool8
023/1`040?ooo`0Pk0L08>`7023/1`80oooo2@0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0P
k0L08>`701H08>`70P3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool2023/1`040?ooo`0P
k0L0oooo023/1`80oooo00<000000?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`190?ooo`030000
003oool0oooo01P0oooo000F0?ooo`030000003oool0oooo00h0oooo00<08>`70?ooo`3oool0:@3o
ool2023/1`80oooo00H08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L40?ooo`04023/1`3oool08>`70?oo
o`P08>`700@0oooo023/1`0Pk0L08>`70P3oool9023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo
023/1`0Pk0L05P0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`808>`700@0oooo
023/1`3oool08>`70P3oool00`000000oooo0?ooo`040?ooo`03023/1`3oool0oooo04X0oooo00<0
00000?ooo`3oool05`3oool001H0oooo00<000000?ooo`3oool03P3oool00`0Pk0L0oooo0?ooo`0Y
0?ooo`808>`70`3oool3023/1`030?ooo`0Pk0L0oooo00<0oooo00@08>`70?ooo`0Pk0L0oooo200P
k0L0103oool08>`7023/1`0Pk0L20?ooo`T08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7
023/1`0F023/1`80oooo0P0Pk0L00`3oool08>`7023/1`02023/1`80oooo0P0Pk0L0103oool08>`7
0?ooo`0Pk0L20?ooo`030000003oool0oooo00@0oooo00<08>`70?ooo`3oool0BP3oool00`000000
oooo0?ooo`0G0?ooo`005P3oool00`000000oooo0?ooo`0>0?ooo`03023/1`3oool0oooo02T0oooo
0P0Pk0L30?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo023/1`3oool8023/
1`040?ooo`0Pk0L08>`7023/1`80oooo2@0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L0
8>`701H08>`70P3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool2023/1`040?ooo`0Pk0L0
oooo023/1`80oooo00<000000?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`1:0?ooo`030000003o
ool0oooo01L0oooo000F0?ooo`030000003oool0oooo00d0oooo00<08>`70?ooo`3oool0:P3oool2
023/1`<0oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`04023/1`3oool08>`70?ooo`P08>`7
00@0oooo023/1`0Pk0L08>`70P3oool9023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0P
k0L05P0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`808>`700@0oooo023/1`3o
ool08>`70P3oool00`000000oooo0?ooo`040?ooo`03023/1`3oool0oooo04X0oooo00<000000?oo
o`3oool05`3oool001H0oooo00<000000?ooo`3oool03@3oool00`0Pk0L0oooo0?ooo`0Z0?ooo`80
8>`70`3oool01@0Pk0L0oooo023/1`3oool08>`700@0oooo00@08>`70?ooo`0Pk0L0oooo200Pk0L0
103oool08>`7023/1`0Pk0L20?ooo`T08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/
1`0E023/1`<0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`80oooo0P0Pk0L0103oool08>`70?oo
o`0Pk0L20?ooo`030000003oool0oooo00@0oooo00<08>`70?ooo`3oool0BP3oool00`000000oooo
0?ooo`0G0?ooo`005P3oool00`000000oooo0?ooo`0=0?ooo`03023/1`3oool0oooo02X0oooo0P0P
k0L30?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo023/1`3oool8023/1`04
0?ooo`0Pk0L08>`7023/1`80oooo2@0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`7
01D08>`70`3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool2023/1`040?ooo`0Pk0L0oooo
023/1`80oooo00<000000?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`1:0?ooo`030000003oool0
oooo01L0oooo000F0?ooo`030000003oool0oooo00d0oooo00<08>`70?ooo`3oool0:P3oool2023/
1`<0oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`04023/1`3oool08>`70?ooo`P08>`700@0
oooo023/1`0Pk0L08>`70P3oool9023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L0
4P0Pk0L00`3oool08>`7023/1`030?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`7
0P3oool0100Pk0L0oooo0?ooo`0000050?ooo`03023/1`3oool0oooo04/0oooo00<000000?ooo`3o
ool05`3oool001H0oooo00<000000?ooo`3oool03@3oool00`0Pk0L0oooo0?ooo`0Z0?ooo`03023/
1`3oool08>`70080oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`04023/1`3oool08>`70?oo
o`P08>`700@0oooo023/1`0Pk0L08>`70P3oool9023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo
023/1`0Pk0L04P0Pk0L00`3oool08>`7023/1`030?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L2
0?ooo`<08>`70P3oool0100Pk0L0oooo0?ooo`0000050?ooo`03023/1`3oool0oooo04/0oooo00<0
00000?ooo`3oool05`3oool001H0oooo00<000000?ooo`3oool03@3oool00`0Pk0L0oooo0?ooo`0Z
0?ooo`03023/1`3oool08>`70080oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`04023/1`3o
ool08>`70?ooo`P08>`700@0oooo023/1`0Pk0L08>`70P3oool9023/1`030?ooo`0Pk0L08>`700L0
8>`700<0oooo023/1`0Pk0L05@0Pk0L30?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<0
8>`70P3oool0100Pk0L0oooo0?ooo`0000050?ooo`03023/1`3oool0oooo04/0oooo00<000000?oo
o`3oool05`3oool001H0oooo00<000000?ooo`3oool03@3oool00`0Pk0L0oooo0?ooo`0Z0?ooo`03
023/1`3oool08>`70080oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`04023/1`3oool08>`7
0?ooo`P08>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0P
k0L08>`700L08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`0>023/1`<0oooo0`0P
k0L0103oool08>`7023/1`0Pk0L20?ooo`<08>`70P3oool0100Pk0L0oooo0?ooo`0000050?ooo`03
023/1`3oool0oooo04/0oooo00<000000?ooo`3oool05`3oool001H0oooo00<000000?ooo`3oool0
3@3oool00`0Pk0L0oooo0?ooo`0Z0?ooo`03023/1`3oool08>`70080oooo00D08>`70?ooo`0Pk0L0
oooo023/1`040?ooo`04023/1`3oool08>`70?ooo`P08>`700@0oooo023/1`0Pk0L08>`70P3oool0
0`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L0100Pk0L0
0`3oool08>`7023/1`0>023/1`<0oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`<08>`70P3o
ool0100Pk0L0oooo0?ooo`0000050?ooo`03023/1`3oool0oooo04/0oooo00<000000?ooo`3oool0
5`3oool001H0oooo00<000000?ooo`3oool03@3oool00`0Pk0L0oooo0?ooo`0Z0?ooo`03023/1`3o
ool08>`70080oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`04023/1`3oool08>`70?ooo`P0
8>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`7
00L08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`0@023/1`<0oooo0`0Pk0L0103o
ool08>`7023/1`0Pk0L20?ooo`<08>`70P3oool0100Pk0L0oooo0?ooo`0000050?ooo`03023/1`3o
ool0oooo04/0oooo00<000000?ooo`3oool05`3oool001H0oooo00<000000?ooo`3oool03@3oool0
0`0Pk0L0oooo0?ooo`0Z0?ooo`03023/1`3oool08>`70080oooo00D08>`70?ooo`0Pk0L0oooo023/
1`040?ooo`04023/1`3oool08>`70?ooo`P08>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0
oooo023/1`06023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool0
8>`70?ooo`0@023/1`<0oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`<08>`70P3oool0100P
k0L0oooo0?ooo`0000050?ooo`03023/1`3oool0oooo04/0oooo00<000000?ooo`3oool05`3oool0
01H0oooo00<000000?ooo`3oool0303oool00`0Pk0L0oooo0?ooo`0[0?ooo`03023/1`3oool08>`7
0080oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00T08>`700@0oooo
023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700L08>`700<0
oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`0@023/1`<0oooo0`0Pk0L0103oool08>`7023/
1`0Pk0L20?ooo`<08>`70P3oool0100Pk0L0oooo0?ooo`0000050?ooo`03023/1`3oool0oooo04/0
oooo00<000000?ooo`3oool05`3oool001H0oooo00<000000?ooo`3oool0303oool00`0Pk0L0oooo
0?ooo`0[0?ooo`03023/1`3oool08>`70080oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`03
023/1`3oool0oooo00T08>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`06023/
1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`0@023/
1`<0oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`<08>`70P3oool0100Pk0L0oooo0?ooo`00
00050?ooo`03023/1`3oool0oooo04/0oooo00<000000?ooo`3oool05`3oool001H0oooo00<00000
0?ooo`3oool0303oool00`0Pk0L0oooo0?ooo`0[0?ooo`03023/1`3oool08>`70080oooo00D08>`7
0?ooo`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00T08>`700@0oooo023/1`0Pk0L08>`7
0P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L0
0P0Pk0L00`3oool08>`70?ooo`0@023/1`<0oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`<08>`7
0P3oool0100Pk0L0oooo0?ooo`0000050?ooo`03023/1`3oool0oooo04/0oooo00<000000?ooo`3o
ool05`3oool001H0oooo00<000000?ooo`3oool0303oool00`0Pk0L0oooo0?ooo`0[0?ooo`03023/
1`3oool08>`70080oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`05023/1`3oool0oooo023/
1`3oool01`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo
023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`701008>`70`3oool3
023/1`030?ooo`0Pk0L08>`700<0oooo0`0Pk0L20?ooo`04023/1`3oool0oooo000000D0oooo00<0
8>`70?ooo`3oool0B`3oool00`000000oooo0?ooo`0G0?ooo`005P3oool00`000000oooo0?ooo`0<
0?ooo`03023/1`3oool0oooo02/0oooo00<08>`70?ooo`0Pk0L00P3oool01@0Pk0L0oooo023/1`3o
ool08>`700@0oooo00D08>`70?ooo`3oool08>`70?ooo`07023/1`040?ooo`0Pk0L08>`7023/1`80
oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`70080
8>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`06023/1`<0oooo0`0Pk0L00`3oool0
8>`7023/1`030?ooo`<08>`70P3oool0100Pk0L0oooo0?ooo`0000050?ooo`03023/1`3oool0oooo
04/0oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool03@3oool00`0Pk0L0
oooo0?ooo`0[0?ooo`03023/1`3oool08>`70080oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?oo
o`05023/1`3oool0oooo023/1`3oool01`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`03023/1`3o
ool08>`700H08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0P
k0L08>`700L08>`700<0oooo023/1`0Pk0L01P0Pk0L30?ooo`<08>`700<0oooo023/1`0Pk0L00`3o
ool3023/1`80oooo00@08>`70?ooo`3oool000001@3oool00`0Pk0L0oooo0?ooo`1;0?ooo`030000
003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00d0oooo00<08>`70?ooo`3oool0:`3o
ool00`0Pk0L0oooo023/1`020?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool01@0Pk0L0oooo
0?ooo`0Pk0L0oooo00L08>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`06023/
1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`07023/
1`030?ooo`0Pk0L08>`700H08>`70`3oool3023/1`030?ooo`0Pk0L08>`700<0oooo0`0Pk0L20?oo
o`04023/1`3oool0oooo000000D0oooo00<08>`70?ooo`3oool0B`3oool00`000000oooo0?ooo`0G
0?ooo`005@3oool00`000000oooo0?ooo`0=0?ooo`03023/1`3oool0oooo02`0oooo0P0Pk0L20?oo
o`05023/1`3oool08>`70?ooo`0Pk0L0103oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00L08>`700@0
oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700L08>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700H08>`7
0`3oool3023/1`030?ooo`0Pk0L08>`700<0oooo0`0Pk0L20?ooo`04023/1`3oool0oooo000000D0
oooo00<08>`70?ooo`3oool0B`3oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo
0?ooo`0=0?ooo`03023/1`3oool0oooo02`0oooo0P0Pk0L20?ooo`03023/1`3oool08>`700808>`7
103oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00L08>`700@0oooo023/1`0Pk0L08>`70P3oool00`0P
k0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3o
ool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool0200Pk0L20?ooo`@08>`700<0oooo
023/1`0Pk0L00`3oool3023/1`80oooo00@08>`70?ooo`3oool000001@3oool00`0Pk0L0oooo0?oo
o`1;0?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00d0oooo00<08>`7
0?ooo`3oool0;03oool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`05023/1`3oool0
oooo023/1`3oool01`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`03023/1`3oool08>`700H08>`7
00<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`08023/1`80oooo100Pk0L00`3oool08>`7023/1`030?ooo`<0
8>`70P3oool0100Pk0L0oooo0?ooo`0000050?ooo`03023/1`3oool0oooo04/0oooo00<000000?oo
o`3oool05`3oool001D0oooo00<000000?ooo`3oool0303oool00`0Pk0L0oooo0?ooo`0]0?ooo`80
8>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00D08>`70?ooo`3oool08>`70?ooo`07023/
1`040?ooo`0Pk0L08>`7023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`07
023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0P
k0L0oooo00P08>`70P3oool4023/1`030?ooo`0Pk0L08>`700<0oooo0`0Pk0L20?ooo`04023/1`3o
ool0oooo000000D0oooo00<08>`70?ooo`3oool0B`3oool00`000000oooo0?ooo`0G0?ooo`005@3o
ool00`000000oooo0?ooo`0<0?ooo`03023/1`3oool0oooo02d0oooo0P0Pk0L20?ooo`03023/1`3o
ool08>`700808>`7103oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00L08>`700@0oooo023/1`0Pk0L0
8>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0P
k0L00P0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool0200Pk0L20?oo
o`@08>`700<0oooo023/1`0Pk0L00`3oool3023/1`80oooo00@08>`70?ooo`3oool000001@3oool0
0`0Pk0L0oooo0?ooo`1;0?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo
00`0oooo00<08>`70?ooo`3oool0;@3oool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?oo
o`05023/1`3oool0oooo023/1`3oool01`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`03023/1`3o
ool08>`700H08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0P
k0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`08023/1`80oooo100Pk0L00`3oool08>`7
023/1`030?ooo`<08>`70P3oool0100Pk0L0oooo0?ooo`0000050?ooo`03023/1`3oool0oooo04/0
oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool0303oool00`0Pk0L0oooo
0?ooo`0]0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00D08>`70?ooo`3oool0
8>`70?ooo`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`03023/1`3oool08>`7
00H08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`7
00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`08023/1`80oooo100Pk0L00`3oool08>`7023/1`03
0?ooo`<08>`70P3oool0100Pk0L0oooo0?ooo`0000050?ooo`03023/1`3oool0oooo04/0oooo00<0
00000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool0303oool00`0Pk0L0oooo0?ooo`0]
0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00D08>`70?ooo`3oool08>`70?oo
o`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`03023/1`3oool08>`700H08>`7
00<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`08023/1`80oooo1@0Pk0L00`3oool08>`70?ooo`020?ooo`80
8>`70`3oool0100Pk0L0oooo0?ooo`0000050?ooo`03023/1`3oool0oooo04/0oooo00<000000?oo
o`3oool05`3oool001D0oooo00<000000?ooo`3oool0303oool00`0Pk0L0oooo0?ooo`0]0?ooo`80
8>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00D08>`70?ooo`3oool08>`70?ooo`03023/
1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo
023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo
023/1`0Pk0L02P0Pk0L20?ooo`D08>`700<0oooo023/1`3oool00P3oool2023/1`<0oooo00@08>`7
0?ooo`3oool000001@3oool00`0Pk0L0oooo0?ooo`1;0?ooo`030000003oool0oooo01L0oooo000E
0?ooo`030000003oool0oooo00`0oooo00<08>`70?ooo`3oool0;@3oool2023/1`80oooo00<08>`7
0?ooo`0Pk0L00P0Pk0L40?ooo`05023/1`3oool0oooo023/1`3oool00`0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00<08>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700L08>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700X08>`7
0P3oool5023/1`030?ooo`0Pk0L0oooo0080oooo0P0Pk0L30?ooo`04023/1`3oool0oooo000000D0
oooo00<08>`70?ooo`3oool0B`3oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo
0?ooo`0<0?ooo`03023/1`3oool0oooo02d0oooo0P0Pk0L20?ooo`03023/1`3oool08>`700808>`7
103oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/
1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`7
00808>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`0:023/1`80oooo1@0Pk0L0103o
ool08>`70?ooo`3oool3023/1`<0oooo00@08>`70?ooo`3oool000001@3oool00`0Pk0L0oooo0?oo
o`1;0?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00`0oooo00<08>`7
0?ooo`3oool0;@3oool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`05023/1`3oool0
oooo023/1`3oool00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70P3oool00`0Pk0L0oooo
023/1`06023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7
023/1`03023/1`030?ooo`0Pk0L08>`700T08>`70`3oool5023/1`040?ooo`0Pk0L0oooo0?ooo`<0
8>`70`3oool0100Pk0L0oooo0?ooo`0000050?ooo`03023/1`3oool0oooo04/0oooo00<000000?oo
o`3oool05`3oool001D0oooo00<000000?ooo`3oool0303oool00`0Pk0L0oooo0?ooo`0]0?ooo`80
8>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00D08>`70?ooo`3oool08>`70?ooo`03023/
1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo
023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`09023/1`<0oooo1@0Pk0L0103oool08>`70?ooo`3o
ool3023/1`<0oooo00@08>`70?ooo`3oool000001@3oool00`0Pk0L0oooo0?ooo`1;0?ooo`030000
003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00`0oooo00<08>`70?ooo`3oool0;@3o
ool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`808>`700<0oooo023/1`3oool00`0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?oo
o`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?oo
o`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L02@0Pk0L30?ooo`<08>`700@0oooo023/1`3oool0
8>`70P3oool3023/1`<0oooo00@08>`70?ooo`3oool000001@3oool00`0Pk0L0oooo0?ooo`1;0?oo
o`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00/0oooo00<08>`70?ooo`3o
ool0;P3oool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`808>`700<0oooo023/1`3o
ool01`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/
1`0Pk0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/
1`0Pk0L00`0Pk0L00`3oool08>`7023/1`09023/1`<0oooo0`0Pk0L0103oool08>`70?ooo`0Pk0L2
0?ooo`<08>`70`3oool0100Pk0L0oooo0?ooo`0000040?ooo`03023/1`3oool0oooo04`0oooo00<0
00000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool02`3oool00`0Pk0L0oooo0?ooo`0^
0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo0P0Pk0L00`3oool08>`70?ooo`07
023/1`040?ooo`0Pk0L08>`7023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/
1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/
1`03023/1`030?ooo`0Pk0L08>`700T08>`70`3oool3023/1`040?ooo`0Pk0L0oooo023/1`80oooo
0`0Pk0L20?ooo`05023/1`3oool0oooo0?ooo`000000103oool00`0Pk0L0oooo0?ooo`1<0?ooo`03
0000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00/0oooo00<08>`70?ooo`3oool0
;P3oool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`808>`700<0oooo023/1`3oool0
1`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`05023/1`3oool08>`7023/1`3oool0100Pk0L00`3o
ool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3o
ool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700T08>`70`3oool3023/1`040?ooo`0Pk0L0oooo
023/1`80oooo0`0Pk0L20?ooo`05023/1`3oool0oooo0?ooo`000000103oool00`0Pk0L0oooo0?oo
o`1<0?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00/0oooo00<08>`7
0?ooo`3oool0;P3oool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`808>`700<0oooo
023/1`3oool01`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`05023/1`3oool08>`7023/1`3oool0
100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L0
0P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700T08>`70`3oool3023/1`040?oo
o`0Pk0L0oooo023/1`80oooo0`0Pk0L20?ooo`05023/1`3oool0oooo0?ooo`000000103oool00`0P
k0L0oooo0?ooo`1<0?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00/0
oooo00<08>`70?ooo`3oool0;P3oool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`80
8>`700<0oooo023/1`3oool01P0Pk0L00`3oool08>`7023/1`02023/1`80oooo00D08>`70?ooo`0P
k0L08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3o
ool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L02@0Pk0L30?oo
o`<08>`700@0oooo023/1`0Pk0L08>`70P3oool3023/1`80oooo00D08>`70?ooo`3oool0oooo0000
00040?ooo`03023/1`3oool0oooo04`0oooo00<000000?ooo`3oool05`3oool001D0oooo00<00000
0?ooo`3oool02`3oool00`0Pk0L0oooo0?ooo`0^0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02
023/1`@0oooo0P0Pk0L00`3oool08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700808>`70P3oool0
1@0Pk0L0oooo023/1`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/
1`02023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/
1`09023/1`<0oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`<08>`70P3oool01@0Pk0L0oooo
0?ooo`3oool0000000@0oooo00<08>`70?ooo`3oool0C03oool00`000000oooo0?ooo`0G0?ooo`00
5@3oool00`000000oooo0?ooo`0;0?ooo`03023/1`3oool0oooo02h0oooo0P0Pk0L20?ooo`03023/
1`3oool08>`700808>`7103oool2023/1`80oooo1`0Pk0L00`3oool08>`7023/1`02023/1`80oooo
00D08>`70?ooo`0Pk0L08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0P
k0L00P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0P
k0L02@0Pk0L30?ooo`<08>`700@0oooo023/1`0Pk0L08>`70P3oool3023/1`80oooo00D08>`70?oo
o`3oool0oooo000000040?ooo`03023/1`3oool0oooo04`0oooo00<000000?ooo`3oool05`3oool0
01D0oooo00<000000?ooo`3oool02`3oool00`0Pk0L0oooo0?ooo`0^0?ooo`808>`70P3oool00`0P
k0L0oooo023/1`02023/1`@0oooo0P0Pk0L20?ooo`L08>`700<0oooo023/1`0Pk0L00P0Pk0L20?oo
o`05023/1`3oool08>`7023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0
8>`700808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0
8>`700T08>`70`3oool3023/1`040?ooo`0Pk0L08>`7023/1`80oooo0`0Pk0L20?ooo`05023/1`3o
ool0oooo0?ooo`000000103oool00`0Pk0L0oooo0?ooo`1<0?ooo`030000003oool0oooo01L0oooo
000E0?ooo`030000003oool0oooo00/0oooo00<08>`70?ooo`3oool0;P3oool2023/1`80oooo00<0
8>`70?ooo`0Pk0L00P0Pk0L40?ooo`808>`70P3oool7023/1`030?ooo`0Pk0L08>`700808>`70P3o
ool01@0Pk0L0oooo023/1`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700T08>`7
0`3oool3023/1`040?ooo`0Pk0L08>`7023/1`80oooo0`0Pk0L20?ooo`05023/1`3oool0oooo0?oo
o`000000103oool00`0Pk0L0oooo0?ooo`1<0?ooo`030000003oool0oooo01L0oooo000E0?ooo`03
0000003oool0oooo00/0oooo00<08>`70?ooo`3oool0;P3oool2023/1`80oooo00<08>`70?ooo`0P
k0L00P0Pk0L40?ooo`808>`70P3oool<023/1`80oooo00D08>`70?ooo`0Pk0L08>`70?ooo`04023/
1`030?ooo`0Pk0L08>`700808>`70P3oool3023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/
1`0Pk0L00`0Pk0L00`3oool08>`7023/1`09023/1`<0oooo0`0Pk0L0103oool08>`7023/1`0Pk0L2
0?ooo`<08>`70P3oool01@0Pk0L0oooo0?ooo`3oool0000000@0oooo00<08>`70?ooo`3oool0C03o
ool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`0:0?ooo`03023/1`3oool0
oooo02l0oooo0P0Pk0L20?ooo`03023/1`3oool08>`700808>`7103oool2023/1`80oooo300Pk0L2
0?ooo`05023/1`3oool08>`7023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0P
k0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L02@0P
k0L30?ooo`<08>`700@0oooo023/1`0Pk0L08>`70P3oool3023/1`80oooo00D08>`70?ooo`3oool0
oooo000000040?ooo`03023/1`3oool0oooo04`0oooo00<000000?ooo`3oool05`3oool001D0oooo
00<000000?ooo`3oool02P3oool00`0Pk0L0oooo0?ooo`0_0?ooo`808>`70P3oool00`0Pk0L0oooo
023/1`02023/1`@0oooo0P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`05023/
1`3oool08>`7023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L00`3oool0
8>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L02@0Pk0L30?ooo`<0
8>`700@0oooo023/1`0Pk0L08>`70P3oool3023/1`80oooo00D08>`70?ooo`3oool0oooo00000004
0?ooo`03023/1`3oool0oooo04`0oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?oo
o`3oool02P3oool00`0Pk0L0oooo0?ooo`0_0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/
1`@0oooo0P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`05023/1`3oool08>`7
023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L00`3oool08>`7023/1`02
023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L02@0Pk0L30?ooo`<08>`700@0oooo
023/1`0Pk0L08>`70P3oool3023/1`80oooo00D08>`70?ooo`3oool0oooo000000040?ooo`03023/
1`3oool0oooo04`0oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool02P3o
ool00`0Pk0L0oooo0?ooo`0_0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`D0oooo00<0
8>`70?ooo`3oool00`0Pk0L00`3oool08>`7023/1`06023/1`80oooo00D08>`70?ooo`0Pk0L08>`7
0?ooo`04023/1`030?ooo`0Pk0L08>`700808>`70P3oool3023/1`030?ooo`0Pk0L08>`700808>`7
00<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`09023/1`<0oooo0`0Pk0L0103oool08>`7
023/1`0Pk0L20?ooo`808>`70`3oool01@0Pk0L0oooo0?ooo`3oool0000000@0oooo00<08>`70?oo
o`3oool0C03oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`0:0?ooo`03
023/1`3oool0oooo02l0oooo0P0Pk0L20?ooo`06023/1`3oool08>`7023/1`3oool08>`7103oool0
0`0Pk0L0oooo0?ooo`03023/1`030?ooo`0Pk0L08>`700H08>`70P3oool01@0Pk0L0oooo023/1`0P
k0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0200P
k0L00`3oool08>`7023/1`09023/1`<0oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`808>`7
0`3oool01@0Pk0L0oooo0?ooo`3oool0000000@0oooo00<08>`70?ooo`3oool0C03oool00`000000
oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`0:0?ooo`03023/1`3oool0oooo02l0oooo
0P0Pk0L30?ooo`<08>`700<0oooo023/1`3oool00`3oool00`0Pk0L0oooo0?ooo`03023/1`030?oo
o`0Pk0L08>`700H08>`70P3oool01@0Pk0L0oooo023/1`0Pk0L0oooo00@08>`700<0oooo023/1`0P
k0L00P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`7023/1`09023/1`<0
oooo0`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`808>`70`3oool01@0Pk0L0oooo0?ooo`3oool0
000000@0oooo00<08>`70?ooo`3oool0C03oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`00
0000oooo0?ooo`0:0?ooo`03023/1`3oool0oooo02l0oooo00<08>`70?ooo`0Pk0L00P3oool3023/
1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`7023/1`06023/
1`80oooo00D08>`70?ooo`0Pk0L08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`70P3oool3
023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L02@0Pk0L30?ooo`<08>`700@0oooo
023/1`0Pk0L08>`70P3oool2023/1`<0oooo00D08>`70?ooo`3oool0oooo000000040?ooo`03023/
1`3oool0oooo04`0oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool02P3o
ool00`0Pk0L0oooo0?ooo`0_0?ooo`03023/1`3oool08>`70080oooo0`0Pk0L00`3oool08>`70?oo
o`030?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`05023/1`3o
ool08>`7023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L00`3oool08>`7
023/1`08023/1`030?ooo`0Pk0L08>`700T08>`70`3oool3023/1`050?ooo`0Pk0L08>`7023/1`3o
ool00`0Pk0L30?ooo`05023/1`3oool0oooo0?ooo`000000103oool00`0Pk0L0oooo0?ooo`1<0?oo
o`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00X0oooo00<08>`70?ooo`3o
ool0;`3oool00`0Pk0L0oooo023/1`020?ooo`<08>`700<0oooo023/1`3oool00`3oool00`0Pk0L0
oooo0?ooo`03023/1`030?ooo`0Pk0L08>`700H08>`70P3oool01@0Pk0L0oooo023/1`0Pk0L0oooo
00@08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0200Pk0L0103o
ool08>`7023/1`3oool8023/1`<0oooo0`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70`3o
ool01@0Pk0L0oooo0?ooo`3oool0000000@0oooo00<08>`70?ooo`3oool0C03oool00`000000oooo
0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`0:0?ooo`03023/1`3oool0oooo02l0oooo00<0
8>`70?ooo`0Pk0L00P3oool3023/1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool00`0P
k0L00`3oool08>`7023/1`06023/1`80oooo00D08>`70?ooo`0Pk0L08>`70?ooo`04023/1`030?oo
o`0Pk0L08>`700808>`70P3oool3023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L0
0P0Pk0L0103oool08>`7023/1`3oool8023/1`<0oooo0`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00<08>`70`3oool01@0Pk0L0oooo0?ooo`3oool0000000@0oooo00<08>`70?ooo`3oool0C03oool0
0`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`090?ooo`03023/1`3oool0oooo
0300oooo00<08>`70?ooo`0Pk0L00P3oool01@0Pk0L0oooo023/1`3oool08>`700@0oooo00<08>`7
0?ooo`3oool00`0Pk0L00`3oool08>`7023/1`06023/1`80oooo00D08>`70?ooo`0Pk0L08>`70?oo
o`04023/1`030?ooo`0Pk0L08>`700808>`70P3oool3023/1`030?ooo`0Pk0L08>`700<08>`700<0
oooo023/1`0Pk0L00P0Pk0L0103oool08>`7023/1`3oool8023/1`<0oooo0`0Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00<08>`70`3oool01@0Pk0L0oooo0?ooo`3oool0000000@0oooo00<08>`70?oo
o`3oool0C03oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`090?ooo`03
023/1`3oool0oooo0300oooo00<08>`70?ooo`0Pk0L00P3oool01@0Pk0L0oooo023/1`3oool08>`7
00@0oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`7023/1`06023/1`80oooo00<08>`70?oo
o`0Pk0L01P0Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L00`3oool08>`7023/1`03023/
1`030?ooo`0Pk0L0oooo00808>`700@0oooo023/1`0Pk0L0oooo200Pk0L30?ooo`<08>`700D0oooo
023/1`0Pk0L08>`70?ooo`03023/1`<0oooo00D08>`70?ooo`3oool0oooo000000040?ooo`03023/
1`3oool0oooo04`0oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool02@3o
ool00`0Pk0L0oooo0?ooo`0`0?ooo`03023/1`3oool08>`70080oooo00D08>`70?ooo`0Pk0L0oooo
023/1`040?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`03023/
1`3oool08>`700H08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L0
0`0Pk0L00`3oool08>`70?ooo`02023/1`040?ooo`0Pk0L08>`70?ooo`P08>`70`3oool3023/1`05
0?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L30?ooo`05023/1`3oool0oooo0?ooo`000000103oool0
0`0Pk0L0oooo0?ooo`1<0?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo
00T0oooo00<08>`70?ooo`3oool0<03oool00`0Pk0L0oooo023/1`020?ooo`05023/1`3oool08>`7
0?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`03023/1`030?ooo`0Pk0L08>`700H08>`70P3oool0
0`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700808>`70P3oool3023/1`030?ooo`0Pk0L0
8>`700<08>`700<0oooo023/1`3oool00P0Pk0L0103oool08>`7023/1`3oool8023/1`<0oooo0P0P
k0L20?ooo`<08>`700@0oooo023/1`0Pk0L08>`70`3oool01@0Pk0L0oooo0?ooo`3oool0000000@0
oooo00<08>`70?ooo`3oool0C03oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo
0?ooo`090?ooo`03023/1`3oool0oooo0300oooo00<08>`70?ooo`0Pk0L00P3oool01@0Pk0L0oooo
023/1`3oool08>`700@0oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`7023/1`06023/1`80
oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L00`3oool0
8>`7023/1`05023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L01P0Pk0L30?oo
o`808>`70P3oool3023/1`040?ooo`0Pk0L08>`7023/1`<0oooo00D08>`70?ooo`3oool0oooo0000
00040?ooo`03023/1`3oool0oooo04`0oooo00<000000?ooo`3oool05`3oool001D0oooo00<00000
0?ooo`3oool02@3oool00`0Pk0L0oooo0?ooo`0`0?ooo`03023/1`3oool08>`70080oooo00D08>`7
0?ooo`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0Pk0L01P0P
k0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`700D0
oooo023/1`0Pk0L08>`70?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0P
k0L01P0Pk0L30?ooo`808>`70P3oool3023/1`040?ooo`0Pk0L08>`7023/1`<0oooo00D08>`70?oo
o`3oool0oooo000000040?ooo`03023/1`3oool0oooo04`0oooo00<000000?ooo`3oool05`3oool0
01D0oooo00<000000?ooo`3oool02@3oool00`0Pk0L0oooo0?ooo`0`0?ooo`03023/1`3oool08>`7
0080oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00<08>`700<0oooo
023/1`0Pk0L01P0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L00P0Pk0L2
0?ooo`<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`808>`7
00<0oooo023/1`0Pk0L01P0Pk0L30?ooo`808>`70P3oool3023/1`040?ooo`0Pk0L08>`7023/1`<0
oooo00D08>`70?ooo`3oool0oooo000000040?ooo`03023/1`3oool0oooo04`0oooo00<000000?oo
o`3oool05`3oool001D0oooo00<000000?ooo`3oool02@3oool00`0Pk0L0oooo0?ooo`0a0?ooo`80
8>`70P3oool01@0Pk0L0oooo023/1`3oool08>`700@0oooo00<08>`70?ooo`3oool00`0Pk0L00`3o
ool08>`7023/1`06023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`02023/
1`80oooo0`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`700@0oooo023/1`0Pk0L0oooo0P0P
k0L00`3oool08>`7023/1`06023/1`<0oooo0P0Pk0L20?ooo`<08>`700@0oooo023/1`0Pk0L08>`7
0`3oool01@0Pk0L0oooo0?ooo`3oool0000000<0oooo00<08>`70?ooo`3oool0C@3oool00`000000
oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`090?ooo`03023/1`3oool0oooo0340oooo
0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`03023/1`03
0?ooo`0Pk0L08>`700H08>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`70080
8>`70P3oool3023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L0103oool08>`7023/1`3oool3
023/1`030?ooo`0Pk0L08>`700@08>`7103oool2023/1`80oooo0`0Pk0L0103oool08>`7023/1`0P
k0L30?ooo`05023/1`3oool0oooo0?ooo`0000000`3oool00`0Pk0L0oooo0?ooo`1=0?ooo`030000
003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00T0oooo00<08>`70?ooo`3oool0<@3o
ool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00<08>`7
00<0oooo023/1`0Pk0L01P0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L0
0P0Pk0L20?ooo`<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`040?ooo`0Pk0L08>`70?oo
o`<08>`700<0oooo023/1`0Pk0L0100Pk0L40?ooo`808>`70P3oool2023/1`80oooo0`0Pk0L30?oo
o`05023/1`3oool0oooo0?ooo`0000000`3oool00`0Pk0L0oooo0?ooo`1=0?ooo`030000003oool0
oooo01L0oooo000E0?ooo`030000003oool0oooo00P0oooo00<08>`70?ooo`3oool0<P3oool2023/
1`80oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00<08>`700<0oooo
023/1`0Pk0L01P0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L00P0Pk0L2
0?ooo`<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`<08>`7
00<0oooo023/1`0Pk0L0100Pk0L40?ooo`808>`70P3oool2023/1`80oooo0`0Pk0L30?ooo`05023/
1`3oool0oooo0?ooo`0000000`3oool00`0Pk0L0oooo0?ooo`1=0?ooo`030000003oool0oooo01L0
oooo000E0?ooo`030000003oool0oooo00P0oooo00<08>`70?ooo`3oool0<P3oool2023/1`80oooo
00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0P
k0L01P0Pk0L20?ooo`03023/1`3oool08>`700@08>`700<0oooo023/1`3oool0100Pk0L20?ooo`<0
8>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo
023/1`0Pk0L0100Pk0L40?ooo`808>`70P3oool2023/1`80oooo0`0Pk0L30?ooo`05023/1`3oool0
oooo0?ooo`0000000`3oool00`0Pk0L0oooo0?ooo`1=0?ooo`030000003oool0oooo01L0oooo000E
0?ooo`030000003oool0oooo00P0oooo00<08>`70?ooo`3oool0<P3oool2023/1`80oooo00D08>`7
0?ooo`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0Pk0L01P0P
k0L20?ooo`03023/1`3oool08>`700@08>`700<0oooo023/1`3oool0100Pk0L20?ooo`<08>`700D0
oooo023/1`0Pk0L08>`70?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo023/1`0P
k0L0100Pk0L40?ooo`808>`70P3oool2023/1`80oooo0`0Pk0L30?ooo`05023/1`3oool0oooo0?oo
o`0000000`3oool00`0Pk0L0oooo0?ooo`1=0?ooo`030000003oool0oooo01L0oooo000E0?ooo`03
0000003oool0oooo00P0oooo00<08>`70?ooo`3oool0<P3oool2023/1`80oooo00D08>`70?ooo`0P
k0L0oooo023/1`040?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0Pk0L01P0Pk0L20?oo
o`03023/1`3oool08>`700@08>`700<0oooo023/1`3oool0100Pk0L20?ooo`<08>`700D0oooo023/
1`0Pk0L08>`70?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo023/1`0Pk0L0100P
k0L40?ooo`808>`70P3oool2023/1`80oooo0`0Pk0L30?ooo`05023/1`3oool0oooo0?ooo`000000
0`3oool00`0Pk0L0oooo0?ooo`1=0?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000003o
ool0oooo00P0oooo00<08>`70?ooo`3oool0<P3oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo
023/1`040?ooo`04023/1`3oool0oooo0?ooo`808>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`03
023/1`3oool08>`700@08>`700<0oooo023/1`3oool0100Pk0L20?ooo`<08>`700D0oooo023/1`0P
k0L08>`70?ooo`03023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L4
0?ooo`808>`70P3oool2023/1`80oooo0`0Pk0L30?ooo`05023/1`3oool0oooo0?ooo`0000000`3o
ool00`0Pk0L0oooo0?ooo`1=0?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0
oooo00P0oooo00<08>`70?ooo`3oool0<P3oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/
1`040?ooo`04023/1`3oool0oooo0?ooo`808>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`03023/
1`3oool08>`700@08>`700<0oooo023/1`3oool0100Pk0L20?ooo`<08>`700D0oooo023/1`0Pk0L0
8>`70?ooo`03023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`<0
8>`70P3oool2023/1`80oooo0`0Pk0L30?ooo`05023/1`3oool0oooo0?ooo`0000000`3oool00`0P
k0L0oooo0?ooo`1=0?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00P0
oooo00<08>`70?ooo`3oool0<P3oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?oo
o`04023/1`3oool0oooo0?ooo`808>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`03023/1`3oool0
8>`700@08>`700<0oooo023/1`3oool0100Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L01@0Pk0L0
0`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700@08>`70`3oool3023/1`80oooo0P0Pk0L2
0?ooo`<08>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0Pk0L0C`3o
ool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`03023/1`3oool0
oooo0380oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo0?oo
o`3oool2023/1`030?ooo`0Pk0L08>`700H08>`70P3oool00`0Pk0L0oooo023/1`04023/1`030?oo
o`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`05023/1`030?oo
o`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`<08>`70P3oool2023/1`80oooo
0P0Pk0L30?ooo`03023/1`3oool0oooo0080oooo00D000000?ooo`3oool0oooo023/1`1?0?ooo`03
0000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00P0oooo00<08>`70?ooo`3oool0
<P3oool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`80
8>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`03023/1`3oool08>`700@08>`700<0oooo023/1`3o
ool0100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3o
ool0100Pk0L00`3oool08>`7023/1`04023/1`<0oooo0`0Pk0L20?ooo`808>`700@0oooo023/1`3o
ool08>`70`3oool00`0Pk0L0oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0Pk0L0C`3oool0
0`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`03023/1`3oool0oooo
0380oooo0P0Pk0L20?ooo`03023/1`3oool08>`700808>`7103oool0100Pk0L0oooo0?ooo`3oool2
023/1`030?ooo`0Pk0L08>`700H08>`70P3oool00`0Pk0L0oooo023/1`04023/1`030?ooo`0Pk0L0
oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0
oooo00@08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`<08>`70P3oool2023/1`040?ooo`0Pk0L0
oooo023/1`<0oooo00<08>`70?ooo`3oool00P3oool01@000000oooo0?ooo`3oool08>`704l0oooo
00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool01`3oool00`0Pk0L0oooo0?oo
o`0c0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00@08>`70?ooo`3oool0oooo
0P0Pk0L00`3oool08>`7023/1`06023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`7
0?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7
0?ooo`04023/1`030?ooo`0Pk0L08>`700@08>`70`3oool3023/1`80oooo0P0Pk0L0103oool08>`7
023/1`0Pk0L30?ooo`03023/1`3oool0oooo0080oooo00D000000?ooo`3oool0oooo023/1`1?0?oo
o`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00L0oooo00<08>`70?ooo`3o
ool0<`3oool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`04023/1`3oool0oooo0?oo
o`808>`700<0oooo023/1`0Pk0L01P0Pk0L20?ooo`03023/1`3oool08>`700@08>`700<0oooo023/
1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/
1`3oool02`0Pk0L30?ooo`<08>`70P3oool2023/1`040?ooo`0Pk0L08>`7023/1`<0oooo00<08>`7
0?ooo`3oool00`3oool010000000oooo0?ooo`0Pk0M?0?ooo`030000003oool0oooo01L0oooo000E
0?ooo`030000003oool0oooo00L0oooo00<08>`70?ooo`3oool0<`3oool2023/1`80oooo00<08>`7
0?ooo`0Pk0L00P0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo023/1`0Pk0L08>`7
0?ooo`04023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`70?ooo`04023/1`030?oo
o`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?ooo`0;023/1`<0oooo
0`0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool00`0Pk0L0oooo0?ooo`030?ooo`04
0000003oool0oooo023/1dl0oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3o
ool01`3oool00`0Pk0L0oooo0?ooo`0c0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0
oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool0
0`0Pk0L0oooo023/1`04023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00P0Pk0L0
0`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00/08>`70`3oool3023/1`050?ooo`0Pk0L0
oooo023/1`3oool00`0Pk0L30?ooo`03023/1`3oool0oooo00<0oooo00@000000?ooo`3oool08>`7
C`3oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`070?ooo`03023/1`3o
ool0oooo03<0oooo0P0Pk0L20?ooo`03023/1`3oool08>`700808>`7103oool0100Pk0L0oooo0?oo
o`3oool2023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L20?ooo`03023/1`3oool08>`700@0
8>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700D0
8>`700<0oooo023/1`3oool02`0Pk0L30?ooo`<08>`700D0oooo023/1`3oool08>`70?ooo`03023/
1`<0oooo00<08>`70?ooo`3oool00`3oool010000000oooo0?ooo`0Pk0M?0?ooo`030000003oool0
oooo01L0oooo000E0?ooo`030000003oool0oooo00L0oooo00<08>`70?ooo`3oool0<`3oool2023/
1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`808>`700D0oooo
023/1`0Pk0L08>`70?ooo`04023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L00`3oool08>`70?oo
o`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?oo
o`0;023/1`<0oooo0`0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`70`3oool00`0Pk0L0oooo
0?ooo`030?ooo`040000003oool0oooo023/1dl0oooo00<000000?ooo`3oool05`3oool001D0oooo
00<000000?ooo`3oool01`3oool00`0Pk0L0oooo0?ooo`0c0?ooo`808>`70P3oool00`0Pk0L0oooo
023/1`02023/1`@0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00@08>`70P3oool00`0Pk0L0oooo023/1`04023/1`030?ooo`0Pk0L0oooo00@08>`700<0oooo023/
1`0Pk0L00P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00/08>`70`3oool3023/
1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L30?ooo`03023/1`3oool0oooo00<0oooo00@00000
0?ooo`3oool08>`7C`3oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`07
0?ooo`03023/1`3oool0oooo03<0oooo0P0Pk0L20?ooo`03023/1`3oool08>`700808>`7103oool0
100Pk0L0oooo0?ooo`3oool2023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L20?ooo`03023/
1`3oool08>`700@08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`02023/1`030?oo
o`0Pk0L08>`700D08>`700<0oooo023/1`3oool02`0Pk0L30?ooo`<08>`700D0oooo023/1`3oool0
8>`70?ooo`03023/1`<0oooo00<08>`70?ooo`3oool00`3oool010000000oooo0?ooo`0Pk0M?0?oo
o`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00L0oooo00<08>`70?ooo`3o
ool0<`3oool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`04023/1`3oool0oooo0?oo
o`808>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`80oooo00<08>`70?ooo`0Pk0L0100Pk0L0
0`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01@0Pk0L0
0`3oool08>`70?ooo`0;023/1`<0oooo0`0Pk0L01@3oool08>`70?ooo`0Pk0L0oooo00<08>`70`3o
ool00`0Pk0L0oooo0?ooo`030?ooo`040000003oool0oooo023/1dl0oooo00<000000?ooo`3oool0
5`3oool001D0oooo00<000000?ooo`3oool01`3oool00`0Pk0L0oooo0?ooo`0c0?ooo`808>`70P3o
ool00`0Pk0L0oooo023/1`02023/1`@0oooo00@08>`70?ooo`3oool0oooo0P0Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00@08>`70P3oool00`0Pk0L0oooo023/1`04023/1`030?ooo`0Pk0L0oooo00@0
8>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00/0
8>`70`3oool3023/1`050?ooo`0Pk0L0oooo023/1`3oool00`0Pk0L30?ooo`03023/1`3oool0oooo
00<0oooo00@000000?ooo`3oool08>`7C`3oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`00
0000oooo0?ooo`070?ooo`03023/1`3oool0oooo03<0oooo0P0Pk0L20?ooo`03023/1`3oool08>`7
00808>`7103oool0100Pk0L0oooo0?ooo`3oool2023/1`050?ooo`0Pk0L08>`7023/1`3oool0100P
k0L20?ooo`03023/1`3oool08>`700@08>`700<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/
1`0:023/1`030?ooo`0Pk0L0oooo00/08>`70`3oool3023/1`050?ooo`0Pk0L0oooo023/1`3oool0
0`0Pk0L30?ooo`03023/1`3oool0oooo00<0oooo00@000000?ooo`3oool08>`7C`3oool00`000000
oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`060?ooo`03023/1`3oool0oooo03@0oooo
0P0Pk0L20?ooo`03023/1`3oool08>`700808>`7103oool0100Pk0L0oooo0?ooo`3oool6023/1`03
0?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`70080
8>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`0;023/1`<0oooo0`0Pk0L01@3oool0
8>`70?ooo`0Pk0L0oooo00<08>`70`3oool00`0Pk0L0oooo0?ooo`030?ooo`040000003oool0oooo
023/1dl0oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool01P3oool00`0P
k0L0oooo0?ooo`0d0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00@08>`70?oo
o`3oool0oooo1P0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L0
0`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`3oool02`0Pk0L3
0?ooo`<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`<0oooo00<08>`70?ooo`3oool00`3o
ool010000000oooo0?ooo`0Pk0M?0?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000003o
ool0oooo00H0oooo00<08>`70?ooo`3oool0=03oool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0P
k0L40?ooo`04023/1`3oool0oooo0?ooo`H08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/
1`3oool08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700X0
8>`700<0oooo023/1`3oool02`0Pk0L30?ooo`<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/
1`<0oooo00<08>`70?ooo`3oool00`3oool010000000oooo0?ooo`0Pk0M?0?ooo`030000003oool0
oooo01L0oooo000E0?ooo`030000003oool0oooo00H0oooo00<08>`70?ooo`3oool0=03oool2023/
1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`/08>`70P3oool0
0`0Pk0L0oooo023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`7023/
1`0:023/1`030?ooo`0Pk0L0oooo00/08>`70`3oool3023/1`050?ooo`0Pk0L08>`7023/1`3oool0
0`0Pk0L30?ooo`03023/1`3oool0oooo00<0oooo00@000000?ooo`3oool08>`7C`3oool00`000000
oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`060?ooo`03023/1`3oool0oooo03@0oooo
0P0Pk0L20?ooo`03023/1`3oool08>`700808>`7103oool0100Pk0L0oooo0?ooo`3oool;023/1`80
oooo00<08>`70?ooo`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`700<0oooo023/
1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`0;023/1`<0oooo0`0Pk0L01@3oool08>`7023/1`0Pk0L0
oooo00<08>`70`3oool00`0Pk0L0oooo0?ooo`030?ooo`030000003oool08>`70500oooo00<00000
0?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool01P3oool00`0Pk0L0oooo0?ooo`0d0?oo
o`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00@08>`70?ooo`3oool0oooo2`0Pk0L2
0?ooo`03023/1`3oool08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`030?ooo`0P
k0L08>`700X08>`700<0oooo023/1`3oool02`0Pk0L30?ooo`<08>`700D0oooo023/1`0Pk0L08>`7
0?ooo`03023/1`<0oooo00<08>`70?ooo`3oool00`3oool00`000000oooo023/1`1@0?ooo`030000
003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00H0oooo00<08>`70?ooo`3oool0=03o
ool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`/08>`7
0P3oool00`0Pk0L0oooo023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool0
8>`7023/1`0:023/1`030?ooo`0Pk0L0oooo00/08>`70`3oool3023/1`050?ooo`0Pk0L08>`7023/
1`3oool00`0Pk0L30?ooo`03023/1`3oool0oooo00<0oooo00<000000?ooo`0Pk0L0D03oool00`00
0000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`060?ooo`03023/1`3oool0oooo03@0
oooo0P0Pk0L20?ooo`03023/1`3oool08>`700808>`7103oool0100Pk0L0oooo0?ooo`3oool;023/
1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`700<0oooo
023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`0;023/1`<0oooo0`0Pk0L01@3oool08>`7023/1`0P
k0L0oooo00<08>`70`3oool00`0Pk0L0oooo0?ooo`030?ooo`030000003oool08>`70500oooo00<0
00000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool01P3oool00`0Pk0L0oooo0?ooo`0d
0?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`/0
8>`70P3oool00`0Pk0L0oooo023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3o
ool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo00/08>`70`3oool3023/1`030?ooo`0Pk0L08>`7
00808>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`030?ooo`030000003oool08>`7
0500oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool01P3oool00`0Pk0L0
oooo0?ooo`0d0?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L40?ooo`04023/1`3oool0
oooo0?ooo`/08>`70P3oool00`0Pk0L0oooo023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0
100Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo00/08>`70P3oool4023/1`030?oo
o`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`030?ooo`030000
003oool08>`70500oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool01@3o
ool00`0Pk0L0oooo0?ooo`0e0?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L40?ooo`04
023/1`3oool0oooo0?ooo`/08>`70P3oool00`0Pk0L0oooo023/1`02023/1`050?ooo`0Pk0L08>`7
023/1`3oool0100Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo
023/1`0Pk0L01@0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03
0?ooo`03023/1`3oool0oooo00<0oooo00<000000?ooo`0Pk0L0D03oool00`000000oooo0?ooo`0G
0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`03023/1`3oool0oooo03D0oooo00H08>`70?oo
o`0Pk0L0oooo023/1`3oool3023/1`@0oooo00@08>`70?ooo`3oool0oooo2`0Pk0L20?ooo`03023/
1`3oool08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700X0
8>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`05023/1`80oooo100Pk0L00`3oool0
8>`7023/1`02023/1`030?ooo`0Pk0L08>`700<0oooo00<08>`70?ooo`3oool00`3oool00`000000
oooo023/1`1@0?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00D0oooo
00<08>`70?ooo`3oool0=@3oool00`0Pk0L0oooo023/1`020?ooo`@08>`7103oool0100Pk0L0oooo
0?ooo`3oool;023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00@08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7
023/1`3oool01`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03
0?ooo`03023/1`3oool0oooo00<0oooo00<000000?ooo`0Pk0L0D03oool00`000000oooo0?ooo`0G
0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`03023/1`3oool0oooo03D0oooo00<08>`70?oo
o`0Pk0L00P3oool4023/1`@0oooo00@08>`70?ooo`3oool0oooo2`0Pk0L20?ooo`03023/1`3oool0
8>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700L08>`700<0
oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00L08>`70P3oool4023/1`030?oo
o`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`030?ooo`030000
003oool08>`70500oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool01@3o
ool00`0Pk0L0oooo0?ooo`0e0?ooo`03023/1`3oool08>`70080oooo100Pk0L40?ooo`04023/1`3o
ool0oooo0?ooo`/08>`70P3oool00`0Pk0L0oooo023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3o
ool0100Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0P
k0L08>`70?ooo`07023/1`80oooo100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`7
00<0oooo00<08>`70?ooo`3oool00`3oool00`000000oooo023/1`1@0?ooo`030000003oool0oooo
01L0oooo000E0?ooo`030000003oool0oooo00D0oooo00<08>`70?ooo`3oool0=@3oool00`0Pk0L0
oooo023/1`020?ooo`@08>`7103oool0100Pk0L0oooo0?ooo`3oool;023/1`80oooo00<08>`70?oo
o`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00`0Pk0L0
1@3oool08>`7023/1`0Pk0L0oooo00@08>`700D0oooo023/1`0Pk0L08>`70?ooo`07023/1`80oooo
100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<0oooo00<08>`70?ooo`3oool0
0`3oool00`000000oooo023/1`1@0?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000003o
ool0oooo00D0oooo00<08>`70?ooo`3oool0=@3oool00`0Pk0L0oooo023/1`020?ooo`@08>`7103o
ool0100Pk0L0oooo0?ooo`3oool;023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`06023/1`05
0?ooo`0Pk0L08>`7023/1`3oool01`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3o
ool08>`7023/1`030?ooo`03023/1`3oool0oooo00<0oooo00<000000?ooo`0Pk0L0D03oool00`00
0000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`03023/1`3oool0oooo03H0
oooo0P0Pk0L20?ooo`@08>`7103oool0100Pk0L0oooo0?ooo`3oool;023/1`80oooo00<08>`70?oo
o`0Pk0L01P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/
1`0Pk0L01P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00L08>`70P3oool4023/1`030?ooo`0Pk0L0
8>`700808>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`030?ooo`030000003oool0
8>`70500oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool01@3oool00`0P
k0L0oooo0?ooo`0f0?ooo`808>`70P3oool3023/1`030?ooo`0Pk0L0oooo0080oooo00@08>`70?oo
o`3oool0oooo2`0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L00P0Pk0L0
0`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700H08>`700D0oooo023/1`0Pk0L08>`70?oo
o`07023/1`80oooo100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<0oooo00<0
8>`70?ooo`3oool00`3oool00`000000oooo023/1`1@0?ooo`030000003oool0oooo01L0oooo000E
0?ooo`030000003oool0oooo00D0oooo00<08>`70?ooo`3oool0=P3oool2023/1`80oooo0`0Pk0L0
0`3oool08>`70?ooo`020?ooo`04023/1`3oool0oooo0?ooo`/08>`70P3oool00`0Pk0L0oooo023/
1`06023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/
1`06023/1`050?ooo`0Pk0L08>`7023/1`3oool01`0Pk0L20?ooo`@08>`700<0oooo023/1`0Pk0L0
0P0Pk0L00`3oool08>`7023/1`030?ooo`03023/1`3oool0oooo00<0oooo00<000000?ooo`0Pk0L0
D03oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`03023/1`3o
ool0oooo03L0oooo0P0Pk0L20?ooo`<08>`700<0oooo023/1`3oool00P3oool0100Pk0L0oooo0?oo
o`3oool;023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`02023/1`030?oo
o`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L01P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00L0
8>`70P3oool4023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0
oooo0?ooo`040?ooo`030000003oool08>`70500oooo00<000000?ooo`3oool05`3oool001D0oooo
00<000000?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`0g0?ooo`808>`70P3oool01@0Pk0L0oooo
023/1`3oool08>`700<0oooo00@08>`70?ooo`3oool0oooo2`0Pk0L20?ooo`03023/1`3oool08>`7
00H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`7
01808>`70P3oool4023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00P3oool00`0P
k0L0oooo0?ooo`040?ooo`030000003oool08>`70500oooo00<000000?ooo`3oool05`3oool001D0
oooo00<000000?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`0g0?ooo`808>`70P3oool01@0Pk0L0
oooo023/1`3oool08>`700<0oooo0P0Pk0L20?ooo`/08>`70P3oool00`0Pk0L0oooo023/1`06023/
1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`70?ooo`0B023/
1`80oooo100Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?oo
o`3oool0103oool00`000000oooo023/1`1@0?ooo`030000003oool0oooo01L0oooo000E0?ooo`03
0000003oool0oooo00@0oooo00<08>`70?ooo`3oool0=`3oool2023/1`80oooo00D08>`70?ooo`0P
k0L0oooo023/1`030?ooo`808>`70P3oool;023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3o
ool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`3oool04P0Pk0L20?oo
o`@08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00<000000?oo
o`0Pk0L0D03oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`03
023/1`3oool0oooo03L0oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L00`3oool2023/
1`80oooo2`0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3o
ool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo01808>`70P3oool4023/1`030?ooo`0Pk0L08>`7
00D08>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`030000003oool08>`70500oooo00<000000?oo
o`3oool05`3oool001D0oooo00<000000?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`0g0?ooo`80
8>`70P3oool01@0Pk0L0oooo023/1`3oool08>`700<0oooo0P0Pk0L20?ooo`/08>`70P3oool00`0P
k0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`0Pk0L00`3o
ool08>`70?ooo`0B023/1`80oooo100Pk0L0103oool08>`7023/1`3oool4023/1`80oooo00<08>`7
0?ooo`3oool0103oool00`000000oooo023/1`1@0?ooo`030000003oool0oooo01L0oooo000E0?oo
o`030000003oool0oooo00@0oooo00<08>`70?ooo`3oool0=`3oool2023/1`80oooo00D08>`70?oo
o`0Pk0L0oooo023/1`030?ooo`808>`70P3oool;023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L0
0`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`3oool04P0Pk0L2
0?ooo`@08>`700@0oooo023/1`0Pk0L0oooo100Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00<0
00000?ooo`0Pk0L0D03oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`04
0?ooo`03023/1`3oool0oooo03L0oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L00`3o
ool2023/1`80oooo2`0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L00P0P
k0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo01808>`70P3oool3023/1`80oooo0P0P
k0L0103oool08>`7023/1`0Pk0L30?ooo`03023/1`3oool0oooo00@0oooo00<000000?ooo`0Pk0L0
D03oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`03023/1`3o
ool0oooo03L0oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L00`3oool2023/1`80oooo
2`0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7
023/1`03023/1`030?ooo`0Pk0L0oooo01808>`70P3oool3023/1`80oooo0P0Pk0L0103oool08>`7
023/1`0Pk0L30?ooo`03023/1`3oool0oooo00@0oooo00<000000?ooo`0Pk0L0D03oool00`000000
oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`03023/1`3oool0oooo03L0oooo
0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L00`3oool2023/1`80oooo2`0Pk0L20?ooo`03
023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`03
0?ooo`0Pk0L0oooo01808>`70P3oool3023/1`80oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`03
023/1`3oool0oooo00@0oooo00<000000?ooo`0Pk0L0D03oool00`000000oooo0?ooo`0G0?ooo`00
5@3oool00`000000oooo0?ooo`030?ooo`03023/1`3oool0oooo03P0oooo0P0Pk0L20?ooo`05023/
1`3oool08>`70?ooo`0Pk0L00`3oool2023/1`80oooo2`0Pk0L20?ooo`03023/1`3oool08>`700H0
8>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo0180
8>`70P3oool3023/1`80oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`03023/1`3oool0oooo00@0
oooo00<000000?ooo`0Pk0L0D03oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo
0?ooo`030?ooo`03023/1`3oool0oooo03P0oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0P
k0L00`3oool2023/1`80oooo2`0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0P
k0L00P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo01808>`70P3oool3023/1`80
oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`03023/1`3oool0oooo00@0oooo00<00000023/1`3o
ool0D03oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`03023/
1`3oool0oooo03P0oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L00`3oool2023/1`<0
oooo2P0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool0
8>`7023/1`03023/1`030?ooo`0Pk0L0oooo01808>`70P3oool3023/1`80oooo0`0Pk0L00`3oool0
8>`7023/1`030?ooo`03023/1`3oool0oooo00@0oooo00<00000023/1`3oool0D03oool00`000000
oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`03023/1`3oool0oooo03P0oooo
0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L00`3oool2023/1`<0oooo2P0Pk0L20?ooo`03
023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`03023/1`03
0?ooo`0Pk0L0oooo01808>`70P3oool3023/1`80oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`03
023/1`3oool0oooo00@0oooo00<00000023/1`3oool0D03oool00`000000oooo0?ooo`0G0?ooo`00
5@3oool00`000000oooo0?ooo`030?ooo`03023/1`3oool0oooo03P0oooo0P0Pk0L20?ooo`05023/
1`3oool08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo0?ooo`3oool:023/1`80oooo00<08>`70?oo
o`0Pk0L01P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/
1`0Pk0L0400Pk0L00`3oool08>`70?ooo`02023/1`80oooo0`0Pk0L00`3oool08>`7023/1`030?oo
o`03023/1`3oool0oooo00@0oooo00<00000023/1`3oool0D03oool00`000000oooo0?ooo`0G0?oo
o`005@3oool00`000000oooo0?ooo`030?ooo`03023/1`3oool0oooo03P0oooo0P0Pk0L20?ooo`05
023/1`3oool08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo0?ooo`3oool3023/1`030?ooo`0Pk0L0
8>`700@08>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700808>`700<0oooo
023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0@023/1`030?ooo`0Pk0L0oooo00808>`70P3oool3
023/1`030?ooo`0Pk0L08>`700<0oooo00<08>`70?ooo`3oool0103oool00`0000008>`70?ooo`1@
0?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00<0oooo00<08>`70?oo
o`3oool0>03oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/1`040?ooo`04023/1`3oool0
oooo0?ooo`<08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0
oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`701008>`700<0
oooo023/1`3oool00P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?oo
o`040?ooo`030000000Pk0L0oooo0500oooo00<000000?ooo`3oool05`3oool001D0oooo00<00000
0?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`0h0?ooo`808>`70P3oool01@0Pk0L0oooo023/1`3o
ool08>`700@0oooo00@08>`70?ooo`3oool0oooo0`0Pk0L00`3oool08>`7023/1`04023/1`80oooo
00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700D08>`7
00<0oooo023/1`0Pk0L0400Pk0L00`3oool08>`70?ooo`02023/1`80oooo0`0Pk0L00`3oool08>`7
023/1`030?ooo`03023/1`3oool0oooo00@0oooo00<00000023/1`3oool0D03oool00`000000oooo
0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`03023/1`3oool0oooo03P0oooo0P0P
k0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L0103oool0100Pk0L0oooo0?ooo`3oool3023/1`03
0?ooo`0Pk0L08>`700@08>`70P3oool00`0Pk0L0oooo023/1`07023/1`050?ooo`0Pk0L08>`7023/
1`3oool01`0Pk0L00`3oool08>`7023/1`0@023/1`030?ooo`0Pk0L0oooo00808>`70P3oool3023/
1`030?ooo`0Pk0L08>`700<0oooo00<08>`70?ooo`3oool0103oool00`0000008>`70?ooo`1@0?oo
o`030000003oool0oooo01L0oooo000E0?ooo`030000003oool0oooo00<0oooo00<08>`70?ooo`3o
ool0>03oool2023/1`80oooo00<08>`70?ooo`0Pk0L00P0Pk0L40?ooo`04023/1`3oool0oooo0?oo
o`<08>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`03023/1`3oool08>`700L08>`700D0oooo023/
1`0Pk0L08>`70?ooo`07023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`3oool00P0Pk0L2
0?ooo`<08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000000Pk0L0
oooo0500oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool00P3oool00`0P
k0L0oooo0?ooo`0i0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00@08>`70?oo
o`3oool0oooo0`0Pk0L00`3oool08>`7023/1`04023/1`80oooo00<08>`70?ooo`0Pk0L02`0Pk0L0
0`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`3oool00P0Pk0L2
0?ooo`<08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000000Pk0L0
oooo0540oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool00P3oool00`0P
k0L0oooo0?ooo`0i0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00@08>`70?oo
o`3oool0oooo0`0Pk0L00`3oool08>`7023/1`04023/1`80oooo00<08>`70?ooo`0Pk0L02`0Pk0L0
0`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`3oool00P0Pk0L2
0?ooo`<08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000000Pk0L0
oooo0540oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool00P3oool00`0P
k0L0oooo0?ooo`0i0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00@08>`70?oo
o`3oool0oooo0`0Pk0L00`3oool08>`7023/1`04023/1`80oooo00<08>`70?ooo`0Pk0L02`0Pk0L0
0`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`3oool00P0Pk0L2
0?ooo`<08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000000Pk0L0
oooo0540oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool00P3oool00`0P
k0L0oooo0?ooo`0i0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00@08>`70?oo
o`3oool0oooo0`0Pk0L00`3oool08>`7023/1`04023/1`80oooo00<08>`70?ooo`0Pk0L02`0Pk0L0
0`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`3oool00P0Pk0L2
0?ooo`<08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000000Pk0L0
oooo0540oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool00P3oool00`0P
k0L0oooo0?ooo`0i0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00@08>`70?oo
o`3oool0oooo0`0Pk0L00`3oool08>`7023/1`04023/1`80oooo00<08>`70?ooo`0Pk0L02`0Pk0L0
0`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`3oool00P0Pk0L2
0?ooo`H08>`70`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000000Pk0L0oooo0540oooo00<00000
0?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool00P3oool00`0Pk0L0oooo0?ooo`0i0?oo
o`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00@08>`70?ooo`3oool0oooo0`0Pk0L0
0`3oool08>`7023/1`04023/1`80oooo00<08>`70?ooo`0Pk0L01@0Pk0L00`3oool08>`7023/1`03
023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L0400Pk0L00`3oool08>`7023/1`02
023/1`030?ooo`0Pk0L0oooo00D08>`70`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000000Pk0L0
oooo0540oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool00P3oool00`0P
k0L0oooo0?ooo`0i0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00@08>`70?oo
o`3oool0oooo0`0Pk0L00`3oool08>`7023/1`04023/1`80oooo00<08>`70?ooo`0Pk0L01@0Pk0L0
0`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L0400Pk0L0
0`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0oooo00D08>`70`3oool00`0Pk0L0oooo0?ooo`04
0?ooo`030000000Pk0L0oooo0540oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?oo
o`3oool00P3oool00`0Pk0L0oooo0?ooo`0i0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/
1`@0oooo00@08>`70?ooo`3oool0oooo0`0Pk0L00`0000008>`7023/1`04023/1`80oooo00<08>`7
0?ooo`0Pk0L01@0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700D08>`700<0
oooo023/1`0Pk0L0400Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0oooo00D08>`70`3o
ool00`0Pk0L0oooo0?ooo`040?ooo`030000000Pk0L0oooo0540oooo00<000000?ooo`3oool05P3o
ool001D0oooo00<000000?ooo`3oool00P3oool00`0Pk0L0oooo0?ooo`0i0?ooo`808>`70P3oool0
0`0Pk0L0oooo023/1`02023/1`@0oooo00@08>`70?ooo`3oool0oooo0`0Pk0L00`0000008>`7023/
1`04023/1`80oooo00<08>`70?ooo`0Pk0L01@0Pk0L0103oool08>`7023/1`3oool2023/1`030?oo
o`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L0400Pk0L00`3oool08>`7023/1`02023/1`030?oo
o`0Pk0L0oooo00D08>`70`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000000Pk0L0oooo0540oooo
00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool00P3oool00`0Pk0L0oooo0?oo
o`0i0?ooo`808>`70P3oool00`0Pk0L0oooo023/1`02023/1`@0oooo00@08>`70?ooo`3oool0oooo
0`0Pk0L00`0000008>`7023/1`04023/1`80oooo00<08>`70?ooo`0Pk0L01@0Pk0L0103oool08>`7
023/1`3oool2023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L0400Pk0L00`3oool0
8>`7023/1`02023/1`030?ooo`0Pk0L08>`700D08>`70`3oool00`0Pk0L0oooo0?ooo`040?ooo`03
0000000Pk0L0oooo0540oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool0
0P3oool00`0Pk0L0oooo0?ooo`0i0?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L40?oo
o`04023/1`3oool0oooo0?ooo`<08>`700<00000023/1`0Pk0L0100Pk0L20?ooo`03023/1`3oool0
8>`700D08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0P
k0L08>`700/08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`7
0`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000000Pk0L0oooo0540oooo00<000000?ooo`3oool0
5P3oool001D0oooo00D000000?ooo`3oool0oooo023/1`0l0?ooo`06023/1`3oool08>`70?ooo`0P
k0L0oooo0`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`<08>`700<00000023/1`0Pk0L0100Pk0L2
0?ooo`03023/1`3oool08>`700D08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/
1`08023/1`030?ooo`0Pk0L0oooo00d08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00<08>`70`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000000Pk0L0oooo0540oooo
00<000000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3oool00P3oool00`0Pk0L0oooo0?oo
o`0j0?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo0`0Pk0L40?ooo`04023/1`3oool0oooo0?oo
o`<08>`700<00000023/1`0Pk0L0100Pk0L20?ooo`03023/1`3oool08>`700D08>`700@0oooo023/
1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L0oooo00d08>`700<0oooo
023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70`3oool00`0Pk0L0oooo0?oo
o`040?ooo`030000000Pk0L0oooo0540oooo00<000000?ooo`3oool05P3oool001@0oooo00<00000
0?ooo`3oool00P3oool00`0Pk0L0oooo0?ooo`0j0?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo
0`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`<08>`700<00000023/1`0Pk0L0100Pk0L20?ooo`03
023/1`3oool08>`700P08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`70?ooo`0=023/1`03
0?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`<0oooo00<08>`70?oo
o`3oool0103oool00`0000008>`70?ooo`1A0?ooo`030000003oool0oooo01H0oooo000D0?ooo`03
0000003oool0oooo0080oooo00<08>`70?ooo`3oool0>P3oool01P0Pk0L0oooo023/1`3oool08>`7
0?ooo`<08>`7103oool0100Pk0L0oooo0?ooo`3oool3023/1`030000000Pk0L08>`700@08>`70P3o
ool00`0Pk0L0oooo023/1`08023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo023/1`3oool03@0P
k0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L30?ooo`03023/
1`3oool0oooo00@0oooo00<00000023/1`3oool0D@3oool00`000000oooo0?ooo`0F0?ooo`00503o
ool00`000000oooo0?ooo`020?ooo`03023/1`3oool0oooo03X0oooo00H08>`70?ooo`0Pk0L0oooo
023/1`3oool3023/1`@0oooo00@08>`70?ooo`3oool0oooo0`0Pk0L00`0000008>`7023/1`04023/
1`80oooo00<08>`70?ooo`0Pk0L0200Pk0L00`3oool08>`7023/1`0;023/1`030?ooo`0Pk0L0oooo
00d08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70`3oool0
0`0Pk0L0oooo0?ooo`040?ooo`030000000Pk0L0oooo0540oooo00<000000?ooo`3oool05P3oool0
01@0oooo00<000000?ooo`3oool00P3oool00`0Pk0L0oooo0?ooo`0j0?ooo`06023/1`3oool08>`7
0?ooo`0Pk0L0oooo0`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`<08>`700<00000023/1`0Pk0L0
100Pk0L20?ooo`03023/1`3oool08>`700P08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`7
0?ooo`0=023/1`030?ooo`0Pk0L08>`700808>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80
oooo00<08>`70?ooo`3oool01@3oool00`0000008>`70?ooo`1A0?ooo`030000003oool0oooo01H0
oooo000D0?ooo`030000003oool0oooo0080oooo00<08>`70?ooo`3oool0>P3oool01P0Pk0L0oooo
023/1`3oool08>`70?ooo`<08>`7103oool0100Pk0L0oooo0?ooo`3oool3023/1`030000000Pk0L0
8>`700@08>`70P3oool00`0Pk0L0oooo023/1`08023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo
023/1`3oool03@0Pk0L00`3oool08>`7023/1`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0P
k0L20?ooo`03023/1`3oool0oooo00D0oooo00<00000023/1`3oool0D@3oool00`000000oooo0?oo
o`0F0?ooo`00503oool00`000000oooo0?ooo`020?ooo`03023/1`3oool0oooo03/0oooo0P0Pk0L0
0`3oool08>`70?ooo`03023/1`@0oooo00@08>`70?ooo`3oool0oooo0`0Pk0L00`0000008>`7023/
1`04023/1`80oooo00<08>`70?ooo`0Pk0L0200Pk0L00`3oool08>`7023/1`0;023/1`030?ooo`0P
k0L0oooo00d08>`700<0oooo023/1`0Pk0L00P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`7
0P3oool00`0Pk0L0oooo0?ooo`050?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
5P3oool001@0oooo00<000000?ooo`3oool00P3oool00`0Pk0L0oooo0?ooo`0k0?ooo`808>`700<0
oooo023/1`3oool00`0Pk0L40?ooo`04023/1`3oool0oooo0?ooo`<08>`700<00000023/1`0Pk0L0
100Pk0L20?ooo`03023/1`3oool08>`700P08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`7
0?ooo`0<023/1`030?ooo`0Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80
oooo00<08>`70?ooo`3oool01@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01H0
oooo000D0?ooo`030000003oool0oooo0080oooo00<08>`70?ooo`3oool0>`3oool2023/1`80oooo
100Pk0L40?ooo`04023/1`3oool0oooo0?ooo`<08>`700<00000023/1`0Pk0L0100Pk0L20?ooo`/0
8>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`70?ooo`0<023/1`030?ooo`0Pk0L0oooo00<0
8>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo00<08>`70?ooo`3oool01@3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo01H0oooo000D0?ooo`050000003oool0oooo0?oo
o`0Pk0L0?P3oool2023/1`80oooo100Pk0L40?ooo`04023/1`3oool0oooo0?ooo`<08>`700<00000
023/1`0Pk0L0100Pk0L20?ooo`/08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`70?ooo`0<
023/1`030?ooo`0Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`80oooo00<0
8>`70?ooo`3oool01@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01H0oooo000D
0?ooo`050000003oool0oooo0?ooo`0Pk0L0?P3oool2023/1`80oooo100Pk0L40?ooo`04023/1`3o
ool0oooo0?ooo`<08>`700<00000023/1`0Pk0L0100Pk0L20?oooaT08>`700<0oooo023/1`3oool0
300Pk0L00`3oool08>`70?ooo`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L20?ooo`03
023/1`3oool0oooo00D0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0F0?ooo`00
503oool01@000000oooo0?ooo`3oool08>`703h0oooo0P0Pk0L20?ooo`@08>`7103oool0100Pk0L0
oooo0?ooo`3oool3023/1`030000000Pk0L08>`700@08>`70P3ooolI023/1`030?ooo`0Pk0L0oooo
00`08>`700<0oooo023/1`3oool00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<08>`70P3oool0
0`0Pk0L0oooo0?ooo`050?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool05P3oool0
01@0oooo00D000000?ooo`3oool0oooo023/1`0n0?ooo`808>`70P3oool4023/1`@0oooo00@08>`7
0?ooo`3oool0oooo0`0Pk0L00`0000008>`7023/1`04023/1`80oooo6@0Pk0L00`3oool08>`70?oo
o`0<023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/
1`020?ooo`03023/1`3oool0oooo00D0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`0F0?ooo`00503oool00`000000oooo0?ooo`02000003h0oooo0P0Pk0L20?ooo`@08>`7103oool0
100Pk0L0oooo0?ooo`3oool3023/1`030000000Pk0L08>`700@08>`70P3ooolI023/1`030?ooo`0P
k0L0oooo00`08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0P
k0L08>`70080oooo00<08>`70?ooo`3oool01@3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo01H0oooo000D0?ooo`030000003oool0oooo00800000?P3oool2023/1`80oooo100Pk0L4
0?ooo`04023/1`3oool0oooo0?ooo`<08>`700<00000023/1`0Pk0L0100Pk0L20?oooaT08>`700<0
oooo023/1`3oool0300Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`700<0
oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`050?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3oool0@03oool2023/1`80oooo100Pk0L4
0?ooo`04023/1`3oool0oooo0?ooo`<08>`700<00000023/1`0Pk0L0100Pk0L20?oooaT08>`700<0
oooo023/1`3oool0300Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700808>`700<0
oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`050?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3oool0@03oool2023/1`80oooo100Pk0L4
0?ooo`04023/1`3oool0oooo0?ooo`<08>`700<00000023/1`0Pk0L0100Pk0L20?oooa<08>`700<0
oooo023/1`0Pk0L00`0Pk0L00`3oool08>`70?ooo`0<023/1`030?ooo`0Pk0L0oooo00<08>`700<0
oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo00D0oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`10
0?ooo`808>`70P3oool4023/1`@0oooo00@08>`70?ooo`3oool0oooo0`0Pk0L00`0000008>`7023/
1`04023/1`80oooo4`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo00`08>`700<0
oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo00<08>`70?ooo`3oool01@3o
ool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0
oooo0400oooo0P0Pk0L20?ooo`@08>`7103oool0100Pk0L0oooo0?ooo`3oool3023/1`030000000P
k0L08>`700@08>`70P3ooolC023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`3oool0300P
k0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700@08>`70`3oool00`0Pk0L0oooo0?oo
o`050?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool05P3oool001@0oooo00<00000
0?ooo`3oool0@03oool2023/1`80oooo100Pk0L40?ooo`04023/1`3oool0oooo0?ooo`<08>`700<0
0000023/1`0Pk0L0100Pk0L20?oooa<08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`70?oo
o`02023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/
1`04023/1`<0oooo00<08>`70?ooo`3oool01@3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo01H0oooo000D0?ooo`030000003oool0oooo0400oooo0P0Pk0L20?ooo`@08>`7103oool0
100Pk0L0oooo0?ooo`3oool3023/1`030000000Pk0L08>`700@08>`70P3ooolC023/1`030?ooo`0P
k0L08>`700<08>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0P
k0L08>`700<08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`03023/1`3oool0oooo00D0oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`10
0?ooo`808>`70P3oool3023/1`030?ooo`0Pk0L0oooo0080oooo00@08>`70?ooo`3oool0oooo0`0P
k0L00`0000008>`7023/1`04023/1`80oooo4`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0P
k0L0oooo00808>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0P
k0L08>`70?ooo`<08>`70`3oool00`0Pk0L0oooo0?ooo`050?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3oool0@03oool2023/1`80oooo00D0
8>`70?ooo`0Pk0L0oooo023/1`030?ooo`04023/1`3oool0oooo0?ooo`<08>`700<00000023/1`0P
k0L0100Pk0L20?oooa<08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`70?ooo`02023/1`03
0?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool3023/
1`<0oooo00<08>`70?ooo`3oool01@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
01H0oooo000D0?ooo`030000003oool0oooo0400oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?oo
o`0Pk0L00`3oool0100Pk0L0oooo0?ooo`3oool3023/1`030000000Pk0L08>`700@08>`70P3oool3
023/1`030?ooo`0Pk0L08>`700d08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`70?ooo`02
023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3o
ool3023/1`<0oooo00<08>`70?ooo`3oool01@3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo01H0oooo000D0?ooo`030000003oool0oooo0400oooo0P0Pk0L20?ooo`05023/1`3oool0
8>`70?ooo`0Pk0L00`3oool0100Pk0L0oooo0?ooo`3oool3023/1`030000000Pk0L08>`700@08>`7
0P3oool3023/1`030?ooo`0Pk0L08>`700d08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7
0?ooo`0<023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L30?ooo`03
023/1`3oool0oooo00D0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0F0?ooo`00
503oool00`000000oooo0?ooo`100?ooo`808>`70P3oool01@0Pk0L0oooo023/1`3oool08>`700<0
oooo00@08>`70?ooo`3oool0oooo0`0Pk0L00`0000008>`7023/1`04023/1`80oooo0`0Pk0L00`3o
ool08>`7023/1`0=023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`3oool0300Pk0L00`3o
ool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`<08>`70`3oool00`0Pk0L0oooo0?ooo`05
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool05P3oool001@0oooo00<000000?oo
o`3oool0@03oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/1`030?ooo`04023/1`3oool0
oooo0?ooo`<08>`700<00000023/1`0Pk0L0100Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L03@0P
k0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo00`08>`700<0oooo023/1`0Pk0L00`0P
k0L0103oool08>`7023/1`3oool3023/1`<0oooo00<08>`70?ooo`3oool01@3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0400oooo0P0P
k0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L00`3oool0100Pk0L0oooo0?ooo`3oool3023/1`03
0000000Pk0L08>`700@08>`70P3oool3023/1`030?ooo`0Pk0L08>`700d08>`700<0oooo023/1`0P
k0L00`0Pk0L00`3oool08>`70?ooo`0<023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0P
k0L0oooo0`0Pk0L30?ooo`03023/1`3oool0oooo00D0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`100?ooo`808>`70P3oool01@0Pk0L0
oooo023/1`3oool08>`700<0oooo00@08>`70?ooo`3oool0oooo0`0Pk0L00`0000008>`7023/1`04
023/1`80oooo0`0Pk0L00`3oool08>`7023/1`0=023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo
023/1`3oool0300Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`<08>`70`3o
ool00`0Pk0L0oooo0?ooo`050?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool05P3o
ool001@0oooo00<000000?ooo`3oool0@03oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/
1`030?ooo`04023/1`3oool0oooo0?ooo`<08>`700<00000023/1`0Pk0L0100Pk0L20?ooo`<08>`7
00<0oooo023/1`0Pk0L03@0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo00`08>`7
00<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool3023/1`<0oooo00<08>`70?ooo`3o
ool01@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000
003oool0oooo0400oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L00`3oool0100Pk0L0
oooo0?ooo`3oool3023/1`030000000Pk0L08>`700@08>`70P3oool3023/1`030?ooo`0Pk0L08>`7
00d08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`70?ooo`0<023/1`030?ooo`0Pk0L08>`7
00<08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L30?ooo`03023/1`3oool0oooo00D0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`100?oo
o`808>`70P3oool01@0Pk0L0oooo023/1`3oool08>`700<0oooo00@08>`70?ooo`3oool0oooo0`0P
k0L00`0000008>`7023/1`04023/1`80oooo0`0Pk0L00`3oool08>`7023/1`0C023/1`030?ooo`0P
k0L0oooo00`08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3oool3023/1`<0oooo
00<08>`70?ooo`3oool01@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01H0oooo
000D0?ooo`030000003oool0oooo0400oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L0
0`3oool0100Pk0L0oooo0?ooo`3oool3023/1`030000000Pk0L08>`700@08>`70P3oool3023/1`03
0?ooo`0Pk0L08>`701<08>`700<0oooo023/1`3oool03@0Pk0L0103oool08>`7023/1`0Pk0L20?oo
o`<08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`050?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3oool0@03oool2023/1`80
oooo00D08>`70?ooo`0Pk0L0oooo023/1`030?ooo`04023/1`3oool0oooo0?ooo`<08>`700<00000
023/1`0Pk0L0100Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L04`0Pk0L00`3oool08>`70?ooo`0=
023/1`040?ooo`0Pk0L08>`7023/1`80oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`03023/1`3o
ool0oooo00D0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0F0?ooo`00503oool0
0`000000oooo0?ooo`100?ooo`808>`70P3oool01@0Pk0L0oooo023/1`3oool08>`700<0oooo00@0
8>`70?ooo`3oool0oooo0`0Pk0L00`0000008>`7023/1`04023/1`80oooo0`0Pk0L00`3oool08>`7
023/1`0C023/1`030?ooo`0Pk0L0oooo00d08>`700@0oooo023/1`0Pk0L08>`70P3oool3023/1`03
0?ooo`0Pk0L08>`700<0oooo00<08>`70?ooo`3oool0103oool00`0Pk0L000000?ooo`1B0?ooo`03
0000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0400oooo0P0Pk0L20?ooo`05023/
1`3oool08>`70?ooo`0Pk0L00`3oool0100Pk0L0oooo0?ooo`3oool3023/1`030000000Pk0L08>`7
00@08>`70P3oool3023/1`030?ooo`0Pk0L08>`701<08>`700<0oooo023/1`3oool03@0Pk0L0103o
ool08>`7023/1`0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`04
0?ooo`03023/1`000000oooo0580oooo00<000000?ooo`3oool05P3oool001@0oooo00<000000?oo
o`3oool0@03oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/1`030?ooo`04023/1`3oool0
oooo0?ooo`<08>`700<00000023/1`0Pk0L0100Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L05@0P
k0L00`3oool08>`7023/1`0;023/1`040?ooo`0Pk0L08>`7023/1`80oooo0`0Pk0L00`3oool08>`7
023/1`030?ooo`03023/1`3oool0oooo00@0oooo00<08>`70000003oool0DP3oool00`000000oooo
0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`100?ooo`808>`70P3oool01@0Pk0L0oooo023/
1`3oool08>`700<0oooo00@08>`70?ooo`3oool0oooo0`0Pk0L00`0000008>`7023/1`04023/1`80
oooo0`0Pk0L00`3oool08>`7023/1`0E023/1`030?ooo`0Pk0L08>`700/08>`700@0oooo023/1`0P
k0L08>`70P3oool3023/1`030?ooo`0Pk0L08>`700<0oooo00<08>`70?ooo`3oool0103oool00`0P
k0L000000?ooo`1B0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0400
oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L00`3oool0100Pk0L0oooo0?ooo`3oool3
023/1`030000000Pk0L08>`700@08>`70P3oool3023/1`030?ooo`0Pk0L08>`701D08>`700<0oooo
023/1`0Pk0L02`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00`3o
ool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`000000oooo0580oooo00<000000?ooo`3oool05P3o
ool001@0oooo00<000000?ooo`3oool0@03oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/
1`030?ooo`04023/1`3oool0oooo0?ooo`X08>`70P3oool3023/1`030?ooo`0Pk0L08>`701D08>`7
00<0oooo023/1`0Pk0L02`0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`<08>`700<0oooo023/1`0P
k0L00P3oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`000000oooo0580oooo00<000000?ooo`3o
ool05P3oool001@0oooo00<000000?ooo`3oool0@03oool2023/1`80oooo00D08>`70?ooo`0Pk0L0
oooo023/1`030?ooo`04023/1`3oool0oooo0?ooo`X08>`70P3oool3023/1`030?ooo`0Pk0L08>`7
01808>`700@0oooo023/1`0Pk0L0oooo3@0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`<08>`700<0
oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`000000oooo0580oooo00<0
00000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3oool0@03oool01P0Pk0L0oooo023/1`3o
ool08>`70?ooo`<08>`70`3oool0100Pk0L0oooo0?ooo`3oool2023/1`030?ooo`0Pk0L08>`700D0
8>`70P3oool3023/1`030?ooo`0Pk0L08>`701808>`700<0oooo023/1`0Pk0L03`0Pk0L00`3oool0
8>`7023/1`020?ooo`<08>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`050?ooo`03
023/1`000000oooo0580oooo00<000000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3oool0
@03oool01P0Pk0L0oooo023/1`3oool08>`70?ooo`<08>`70`3oool0100Pk0L0oooo0?ooo`3oool2
023/1`030?ooo`0Pk0L08>`700D08>`70P3oool3023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo
023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0?023/1`030?ooo`0Pk0L08>`70080oooo0`0Pk0L0
0`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00D0oooo00<08>`70000003oool0DP3oool0
0`000000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`100?ooo`06023/1`3oool08>`7
0?ooo`0Pk0L0oooo0`0Pk0L30?ooo`04023/1`3oool0oooo0?ooo`808>`700<0oooo023/1`0Pk0L0
1@0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`05023/1`030?oo
o`0Pk0L08>`700l08>`700<0oooo023/1`0Pk0L00P3oool3023/1`030?ooo`0Pk0L08>`70080oooo
00<08>`70?ooo`3oool01@3oool00`0Pk0L000000?ooo`1B0?ooo`030000003oool0oooo01H0oooo
000D0?ooo`030000003oool0oooo0400oooo00H08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`<0
oooo0P0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`<08>`700<0oooo023/1`0P
k0L02P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700l08>`700<0oooo023/1`0P
k0L00P3oool3023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool01@3oool00`0Pk0L0
00000?ooo`1B0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0400oooo
00H08>`70?ooo`0Pk0L0oooo023/1`3oool3023/1`<0oooo0P0Pk0L20?ooo`808>`700<0oooo023/
1`0Pk0L01@0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`05023/
1`030?ooo`0Pk0L08>`700l08>`700<0oooo023/1`0Pk0L00P3oool3023/1`030?ooo`0Pk0L08>`7
0080oooo00<08>`70?ooo`3oool01@3oool00`0Pk0L000000?ooo`1B0?ooo`030000003oool0oooo
01H0oooo000D0?ooo`030000003oool0oooo0400oooo00H08>`70?ooo`0Pk0L0oooo023/1`3oool3
023/1`<0oooo0P0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`<08>`700<0oooo
023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700l08>`700<0oooo
023/1`0Pk0L00P3oool3023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool01@3oool0
0`0Pk0L000000?ooo`1B0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo
0440oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`<0oooo0P0Pk0L20?ooo`808>`700<0oooo023/
1`0Pk0L01@0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`05023/
1`030?ooo`0Pk0L08>`700l08>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`7023/1`02
0?ooo`03023/1`3oool0oooo00D0oooo00<08>`70000003oool0DP3oool00`000000oooo0?ooo`0F
0?ooo`00503oool00`000000oooo0?ooo`110?ooo`808>`700<0oooo023/1`3oool00`0Pk0L30?oo
o`808>`70P3oool2023/1`030?ooo`0Pk0L08>`700D08>`70P3oool3023/1`030?ooo`0Pk0L08>`7
00X08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0?023/1`040?ooo`0Pk0L08>`7
0?ooo`@08>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`000000
oooo0580oooo00<000000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3oool0@@3oool2023/
1`030?ooo`0Pk0L0oooo00<08>`70`3oool2023/1`80oooo0P0Pk0L00`3oool08>`7023/1`05023/
1`80oooo0`0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/
1`0Pk0L03`0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`70080oooo00<08>`7
0?ooo`3oool01@3oool00`0Pk0L000000?ooo`1B0?ooo`030000003oool0oooo01H0oooo000D0?oo
o`030000003oool0oooo0440oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`<0oooo0P0Pk0L20?oo
o`808>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3o
ool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700l08>`700@0oooo023/1`0Pk0L0oooo100Pk0L0
0`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00D0oooo00<08>`70000003oool0DP3oool0
0`000000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`110?ooo`808>`700<0oooo023/
1`3oool00`0Pk0L30?ooo`808>`70P3oool2023/1`030?ooo`0Pk0L08>`700D08>`70P3oool3023/
1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0?023/
1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`05
0?ooo`03023/1`000000oooo0580oooo00<000000?ooo`3oool05P3oool001@0oooo00<000000?oo
o`3oool0@@3oool2023/1`030?ooo`0Pk0L0oooo00<08>`70`3oool2023/1`80oooo0P0Pk0L00`3o
ool08>`7023/1`05023/1`80oooo0`0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`7
00D08>`700<0oooo023/1`0Pk0L03`0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0
8>`70080oooo00<08>`70?ooo`3oool01@3oool00`0Pk0L000000?ooo`1B0?ooo`030000003oool0
oooo01H0oooo000D0?ooo`030000003oool0oooo0440oooo0P0Pk0L00`3oool08>`70?ooo`03023/
1`@0oooo00<08>`70?ooo`3oool00P0Pk0L00`3oool08>`7023/1`05023/1`80oooo0`0Pk0L00`3o
ool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3o
ool08>`7023/1`0:023/1`040?ooo`0Pk0L08>`70?ooo`<08>`70P3oool2023/1`80oooo00<08>`7
0?ooo`3oool01@3oool00`0Pk0L000000?ooo`1B0?ooo`030000003oool0oooo01H0oooo000D0?oo
o`030000003oool0oooo0440oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`@0oooo00<08>`70?oo
o`3oool00P0Pk0L00`3oool08>`7023/1`05023/1`80oooo0`0Pk0L00`3oool08>`7023/1`0:023/
1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`0:023/
1`040?ooo`0Pk0L08>`70?ooo`<08>`70P3oool2023/1`80oooo00<08>`70?ooo`3oool01@3oool0
0`0Pk0L000000?ooo`1B0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo
0440oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`@0oooo00<08>`70?ooo`3oool02P0Pk0L20?oo
o`<08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`7
00808>`700<0oooo023/1`0Pk0L02P0Pk0L0103oool08>`7023/1`3oool3023/1`80oooo00D08>`7
0?ooo`3oool0oooo023/1`070?ooo`03023/1`000000oooo0580oooo00<000000?ooo`3oool05P3o
ool001@0oooo00<000000?ooo`3oool0@@3oool2023/1`80oooo100Pk0L40?ooo`03023/1`3oool0
oooo00X08>`70P3oool3023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L01@0Pk0L0
0`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`3oool00P0Pk0L0
103oool08>`7023/1`0Pk0L20?ooo`05023/1`3oool0oooo0?ooo`0Pk0L01`3oool00`0Pk0L00000
0?ooo`1B0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0440oooo0P0P
k0L20?ooo`@08>`7103oool00`0Pk0L0oooo0?ooo`0:023/1`80oooo0`0Pk0L00`3oool08>`7023/
1`0:023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/
1`08023/1`030?ooo`0Pk0L0oooo00808>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`<0oooo
00<08>`70?ooo`3oool01@3oool00`0Pk0L000000?ooo`1B0?ooo`030000003oool0oooo01H0oooo
000D0?ooo`030000003oool0oooo0440oooo0P0Pk0L20?ooo`@08>`7103oool00`0Pk0L0oooo0?oo
o`0:023/1`80oooo0`0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700D08>`700<0
oooo023/1`0Pk0L03@0Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0
0P0Pk0L30?ooo`03023/1`3oool0oooo00D0oooo00<08>`70000003oool0DP3oool00`000000oooo
0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`110?ooo`808>`70P3oool4023/1`@0oooo00<0
8>`70?ooo`3oool02P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/
1`05023/1`030?ooo`0Pk0L08>`700d08>`700<0oooo023/1`3oool00P0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00808>`70`3oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`000000oooo0580oooo
00<000000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3oool0@@3oool2023/1`80oooo100P
k0L40?ooo`03023/1`3oool0oooo00X08>`70P3oool3023/1`030?ooo`0Pk0L08>`700X08>`700<0
oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0=023/1`030?ooo`0Pk0L0oooo00808>`700D0
oooo023/1`0Pk0L08>`70?ooo`02023/1`<0oooo00<08>`70?ooo`3oool01@3oool00`0Pk0L00000
0?ooo`1B0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0440oooo0P0P
k0L20?ooo`@08>`7103oool00`0Pk0L0oooo0?ooo`0:023/1`80oooo0`0Pk0L00`3oool08>`7023/
1`0:023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L03@0Pk0L00`3oool08>`70?oo
o`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L30?ooo`03023/1`3oool0oooo00@0oooo
00<08>`70?ooo`000000D`3oool00`000000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?oo
o`110?ooo`808>`70P3oool4023/1`@0oooo00<08>`70?ooo`3oool02P0Pk0L20?ooo`<08>`700<0
oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700H08>`700<0
oooo023/1`0Pk0L0100Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0
0P0Pk0L30?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`000000D`3oool00`000000oooo
0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`110?ooo`808>`70P3oool4023/1`@0oooo00<0
8>`70?ooo`3oool02P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/
1`05023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`70?oo
o`02023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L30?ooo`03023/1`3oool0oooo00@0oooo
00<08>`70?ooo`000000D`3oool00`000000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?oo
o`110?ooo`808>`70P3oool4023/1`@0oooo00<08>`70?ooo`3oool02P0Pk0L20?ooo`<08>`700<0
oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700H08>`700<0
oooo023/1`0Pk0L0100Pk0L00`3oool08>`70?ooo`02023/1`050?ooo`0Pk0L08>`7023/1`3oool0
0P0Pk0L30?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`000000D`3oool00`000000oooo
0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`110?ooo`808>`70P3oool4023/1`@0oooo00<0
8>`70?ooo`3oool02P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/
1`05023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L01@0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/
1`3oool0000005<0oooo00<000000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3oool0@@3o
ool2023/1`80oooo100Pk0L40?ooo`03023/1`3oool0oooo00X08>`70P3oool3023/1`030?ooo`0P
k0L08>`700H08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`050?ooo`0Pk0L08>`7023/1`3o
ool0200Pk0L00`3oool08>`7023/1`05023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3o
ool08>`7023/1`030?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`000000D`3oool00`00
0000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`110?ooo`808>`70P3oool4023/1`@0
oooo00<08>`70?ooo`3oool02P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L01P0Pk0L01@3oool0
8>`7023/1`0Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`08023/1`030?ooo`0Pk0L0
8>`700D08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700<0oooo00<0
8>`70?ooo`3oool0103oool00`0Pk0L0oooo0000001C0?ooo`030000003oool0oooo01H0oooo000D
0?ooo`030000003oool0oooo0440oooo0P0Pk0L20?ooo`@08>`7103oool00`0Pk0L0oooo0?ooo`0:
023/1`80oooo0`0Pk0L00`3oool08>`7023/1`06023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00P08>`700<0oooo023/1`0Pk0L01@0Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`040?ooo`03
023/1`3oool0000005<0oooo00<000000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3oool0
@@3oool2023/1`80oooo100Pk0L40?ooo`03023/1`3oool0oooo00X08>`70P3oool3023/1`030?oo
o`0Pk0L08>`700H08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`050?ooo`0Pk0L08>`7023/
1`3oool0200Pk0L00`3oool08>`7023/1`05023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L0
0`3oool08>`7023/1`030?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`000000D`3oool0
0`000000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`110?ooo`808>`70P3oool4023/
1`@0oooo00<08>`70?ooo`3oool02`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00P08>`700D0oooo
023/1`0Pk0L08>`70?ooo`03023/1`050?ooo`0Pk0L08>`7023/1`3oool0200Pk0L00`3oool08>`7
023/1`05023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`7023/1`030?ooo`03
023/1`3oool0oooo00@0oooo00<08>`70?ooo`000000D`3oool00`000000oooo0?ooo`0F0?ooo`00
503oool00`000000oooo0?ooo`110?ooo`808>`70P3oool4023/1`@0oooo00<08>`70?ooo`3oool0
2`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00P08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/
1`050?ooo`0Pk0L08>`7023/1`3oool0200Pk0L00`3oool08>`7023/1`05023/1`050?ooo`0Pk0L0
8>`7023/1`3oool00`0Pk0L00`3oool08>`7023/1`030?ooo`03023/1`3oool0oooo00@0oooo00<0
8>`70?ooo`000000D`3oool00`000000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`11
0?ooo`808>`70P3oool4023/1`@0oooo00<08>`70?ooo`3oool02`0Pk0L01@3oool08>`7023/1`0P
k0L0oooo00P08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`050?ooo`0Pk0L08>`7023/1`3o
ool0200Pk0L00`3oool08>`7023/1`05023/1`050?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3o
ool08>`7023/1`030?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`000000D`3oool00`00
0000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`110?ooo`808>`70P3oool4023/1`@0
oooo00<08>`70?ooo`3oool02`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00P08>`700D0oooo023/
1`0Pk0L08>`70?ooo`03023/1`050?ooo`0Pk0L08>`7023/1`3oool0200Pk0L00`3oool08>`7023/
1`05023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L20?ooo`808>`70`3oool00`0Pk0L0oooo
0?ooo`040?ooo`03023/1`3oool0000005<0oooo00<000000?ooo`3oool05P3oool001@0oooo00<0
00000?ooo`3oool0@@3oool2023/1`80oooo00@08>`70?ooo`0Pk0L08>`7103oool00`0Pk0L0oooo
0?ooo`0;023/1`050?ooo`0Pk0L08>`7023/1`3oool0200Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00<08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`7
00D08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0
oooo00D0oooo00<08>`70?ooo`000000D`3oool00`000000oooo0?ooo`0F0?ooo`00503oool00`00
0000oooo0?ooo`110?ooo`808>`70P3oool0100Pk0L0oooo023/1`0Pk0L40?ooo`03023/1`3oool0
oooo00/08>`700D0oooo023/1`0Pk0L08>`70?ooo`08023/1`050?ooo`0Pk0L08>`7023/1`3oool0
0`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L0
1@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70P3oool2023/1`80oooo00<08>`70?ooo`3o
ool01@3oool00`0Pk0L0oooo0000001C0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000
003oool0oooo0440oooo0P0Pk0L20?ooo`04023/1`3oool08>`7023/1`@0oooo00<08>`70?ooo`3o
ool02`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00P08>`700D0oooo023/1`0Pk0L08>`70?ooo`03
023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`05
023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L20?ooo`808>`70P3oool00`0Pk0L0oooo0?oo
o`050?ooo`03023/1`3oool0000005<0oooo00<000000?ooo`3oool05P3oool001@0oooo00<00000
0?ooo`3oool0@@3oool2023/1`80oooo00@08>`70?ooo`0Pk0L08>`7103oool00`0Pk0L0oooo0?oo
o`0;023/1`050?ooo`0Pk0L08>`7023/1`3oool0200Pk0L01@3oool08>`7023/1`0Pk0L0oooo00<0
8>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700D0
8>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0oooo
00D0oooo00<08>`70?ooo`000000D`3oool00`000000oooo0?ooo`0F0?ooo`00503oool00`000000
oooo0?ooo`110?ooo`808>`70P3oool01@0Pk0L0oooo023/1`3oool08>`700<0oooo00<08>`70?oo
o`3oool02`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00P08>`700D0oooo023/1`0Pk0L08>`70?oo
o`03023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/
1`05023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L20?ooo`808>`70P3oool00`0Pk0L0oooo
0?ooo`050?ooo`03023/1`3oool0000005<0oooo00<000000?ooo`3oool05P3oool001@0oooo00<0
00000?ooo`3oool0@@3oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo023/1`030?ooo`03023/
1`3oool0oooo00/08>`700D0oooo023/1`0Pk0L08>`70?ooo`08023/1`050?ooo`0Pk0L08>`7023/
1`3oool00`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/
1`0Pk0L01@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70P3oool2023/1`80oooo00<08>`7
0?ooo`3oool01@3oool00`0Pk0L0oooo0000001C0?ooo`030000003oool0oooo01H0oooo000D0?oo
o`030000003oool0oooo0440oooo0P0Pk0L20?ooo`05023/1`3oool08>`70?ooo`0Pk0L00`3oool0
0`0Pk0L0oooo0?ooo`0;023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3oool08>`70?oo
o`03023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool08>`7023/1`05023/1`030?oo
o`0Pk0L08>`700D08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`80oooo0P0Pk0L20?ooo`03
023/1`3oool0oooo00D0oooo00<08>`70?ooo`000000D`3oool00`000000oooo0?ooo`0F0?ooo`00
503oool00`000000oooo0?ooo`110?ooo`808>`70P3oool01@0Pk0L0oooo023/1`3oool08>`700<0
oooo00@08>`70?ooo`3oool0oooo2P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo
023/1`3oool00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L01@0P
k0L00`3oool08>`7023/1`05023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L20?ooo`808>`7
0P3oool00`0Pk0L0oooo0?ooo`050?ooo`03023/1`3oool0000005<0oooo00<000000?ooo`3oool0
5P3oool001@0oooo00<000000?ooo`3oool0@@3oool2023/1`80oooo00D08>`70?ooo`0Pk0L0oooo
023/1`030?ooo`04023/1`3oool0oooo0?ooo`X08>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/
1`030?ooo`0Pk0L0oooo00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`030?ooo`0Pk0L0
8>`700D08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`04023/1`80oooo0P0Pk0L2
0?ooo`03023/1`3oool0oooo00D0oooo00<08>`70?ooo`000000D`3oool00`000000oooo0?ooo`0F
0?ooo`00503oool00`000000oooo0?ooo`110?ooo`09023/1`3oool08>`70?ooo`0Pk0L0oooo023/
1`3oool08>`700<0oooo00@08>`70?ooo`3oool0oooo2P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00H08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`7
00D08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`04023/1`80oooo0P0Pk0L20?oo
o`03023/1`3oool0oooo00D0oooo00<08>`70?ooo`000000D`3oool00`000000oooo0?ooo`0F0?oo
o`00503oool00`000000oooo0?ooo`110?ooo`09023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3o
ool08>`700<0oooo00@08>`70?ooo`3oool0oooo2P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H0
8>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700D0
8>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`04023/1`80oooo0P0Pk0L20?ooo`03
023/1`3oool0oooo00D0oooo00<08>`70?ooo`000000D`3oool00`000000oooo0?ooo`0F0?ooo`00
503oool00`000000oooo0?ooo`110?ooo`09023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool0
8>`700<0oooo00@08>`70?ooo`3oool0oooo2P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`7
00<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700D08>`7
00<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`04023/1`80oooo0P0Pk0L20?ooo`03023/
1`3oool0oooo00D0oooo00<08>`70?ooo`000000D`3oool00`000000oooo0?ooo`0F0?ooo`00503o
ool00`000000oooo0?ooo`110?ooo`09023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`7
00<0oooo00@08>`70?ooo`3oool0oooo2P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0
oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700D08>`700<0
oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`04023/1`80oooo0P0Pk0L20?ooo`03023/1`3o
ool0oooo00D0oooo00<08>`70?ooo`000000D`3oool00`000000oooo0?ooo`0F0?ooo`00503oool0
0`000000oooo0?ooo`110?ooo`09023/1`3oool08>`70?ooo`0Pk0L0oooo023/1`3oool08>`700<0
oooo00@08>`70?ooo`3oool0oooo2P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo
023/1`3oool00`0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo
023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`04023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0
oooo00D0oooo00<08>`70?ooo`000000D`3oool00`000000oooo0?ooo`0F0?ooo`00503oool00`00
0000oooo0?ooo`120?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L30?ooo`04023/1`3o
ool0oooo0?ooo`X08>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L0oooo00<0
8>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700D0
8>`700<0oooo023/1`0Pk0L0100Pk0L20?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`04
023/1`3oool0oooo000005<0oooo00<000000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3o
ool0@P3oool2023/1`060?ooo`0Pk0L0oooo023/1`3oool08>`70`3oool0100Pk0L0oooo0?ooo`3o
ool:023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3oool08>`70?ooo`03023/1`030?oo
o`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`04023/1`80oooo
0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`04
023/1`3oool0oooo000005<0oooo00<000000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3o
ool0@P3oool2023/1`060?ooo`0Pk0L0oooo023/1`3oool08>`70`3oool0100Pk0L0oooo0?ooo`3o
ool:023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3oool08>`70?ooo`03023/1`030?oo
o`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`04023/1`80oooo
0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`04
023/1`3oool0oooo000005<0oooo00<000000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3o
ool0@P3oool2023/1`060?ooo`0Pk0L0oooo023/1`3oool08>`70`3oool0100Pk0L0oooo0?ooo`3o
ool:023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3oool08>`70?ooo`03023/1`030?oo
o`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L0300Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L0
8>`70P3oool2023/1`80oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`00001C0?oo
o`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0480oooo0P0Pk0L01P3oool0
8>`70?ooo`0Pk0L0oooo023/1`<0oooo00@08>`70?ooo`3oool0oooo2P0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00P08>`700D0oooo023/1`0Pk0L08>`70?ooo`08023/1`030?ooo`0Pk0L08>`700@0
8>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool2023/
1`80oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`00001C0?ooo`030000003oool0
oooo01H0oooo000D0?ooo`030000003oool0oooo0480oooo0P0Pk0L01P3oool08>`70?ooo`0Pk0L0
oooo023/1`<0oooo00@08>`70?ooo`3oool0oooo2P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00P0
8>`700D0oooo023/1`0Pk0L08>`70?ooo`08023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/
1`0Pk0L01@0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool2023/1`80oooo00<08>`7
0?ooo`3oool0103oool0100Pk0L0oooo0?ooo`00001C0?ooo`030000003oool0oooo01H0oooo000D
0?ooo`030000003oool0oooo0480oooo0P0Pk0L01P3oool08>`70?ooo`0Pk0L0oooo023/1`<0oooo
00@08>`70?ooo`3oool0oooo2P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00P08>`700D0oooo023/
1`0Pk0L08>`70?ooo`08023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L01@0Pk0L2
0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool2023/1`80oooo00<08>`70?ooo`3oool0103o
ool0100Pk0L0oooo0?ooo`00001C0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003o
ool0oooo0480oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`<0oooo00@08>`70?ooo`3oool0oooo
2P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00P08>`700D0oooo023/1`0Pk0L08>`70?ooo`08023/
1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`808>`700@0oooo023/
1`0Pk0L08>`70P3oool2023/1`80oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`00
001C0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0480oooo0P0Pk0L0
0`3oool08>`70?ooo`03023/1`<0oooo00@08>`70?ooo`3oool0oooo2P0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00P08>`700D0oooo023/1`0Pk0L08>`70?ooo`08023/1`030?ooo`0Pk0L08>`700@0
8>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`808>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/
1`<0oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`00001C0?ooo`030000003oool0
oooo01H0oooo000D0?ooo`030000003oool0oooo0480oooo0P0Pk0L00`3oool08>`70?ooo`03023/
1`<0oooo00@08>`70?ooo`3oool0oooo2P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00P08>`700D0
oooo023/1`0Pk0L08>`70?ooo`08023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L0
1@0Pk0L20?ooo`808>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`<0oooo00<08>`70?ooo`3o
ool0103oool0100Pk0L0oooo0?ooo`00001C0?ooo`030000003oool0oooo01H0oooo000D0?ooo`03
0000003oool0oooo0480oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`<0oooo00@08>`70?ooo`3o
ool0oooo2P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00P08>`700D0oooo023/1`0Pk0L08>`70?oo
o`08023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`808>`700D0
oooo023/1`0Pk0L08>`70?ooo`02023/1`<0oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo
0?ooo`00001C0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0480oooo
0P0Pk0L00`3oool08>`70?ooo`03023/1`<0oooo00@08>`70?ooo`3oool0oooo2P0Pk0L01@3oool0
8>`7023/1`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0
oooo00P08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`05023/1`80oooo0P0Pk0L0
1@3oool08>`7023/1`0Pk0L0oooo00808>`70`3oool00`0Pk0L0oooo0?ooo`040?ooo`04023/1`3o
ool0oooo000005<0oooo00<000000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3oool0@P3o
ool2023/1`030?ooo`0Pk0L0oooo00<08>`70`3oool0100Pk0L0oooo0?ooo`3oool:023/1`050?oo
o`0Pk0L08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/
1`3oool0200Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700D08>`70P3oool2023/
1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L30?ooo`03023/1`3oool0oooo00@0oooo00@08>`7
0?ooo`3oool00000D`3oool00`000000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`12
0?ooo`808>`700<0oooo023/1`3oool00`0Pk0L30?ooo`04023/1`3oool0oooo0?ooo`X08>`700D0
oooo023/1`0Pk0L08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L0
8>`70?ooo`08023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`80
8>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`<0oooo00<08>`70?ooo`3oool0103oool0100P
k0L0oooo0?ooo`00001C0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo
0480oooo0P0Pk0L00`3oool08>`70?ooo`03023/1`<0oooo00@08>`70?ooo`3oool0oooo2P0Pk0L0
1@3oool08>`7023/1`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00P08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`05023/1`80oooo
0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70`3oool00`0Pk0L0oooo0?ooo`040?ooo`04
023/1`3oool0oooo000005<0oooo00<000000?ooo`3oool05P3oool001@0oooo00<000000?ooo`3o
ool0@P3oool2023/1`030?ooo`0Pk0L0oooo00<08>`70`3oool0100Pk0L0oooo0?ooo`3oool9023/
1`030?ooo`0Pk0L08>`700808>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L00`3oool08>`7023/1`02
0?ooo`P08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`05023/1`80oooo1P0Pk0L0
0`3oool08>`7023/1`030?ooo`03023/1`3oool0oooo00@0oooo00@08>`70?ooo`3oool00000D`3o
ool00`000000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`120?ooo`808>`70P3oool4
023/1`<0oooo00@08>`70?ooo`3oool0oooo2@0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0P
k0L08>`700H08>`700<0oooo023/1`0Pk0L00P3oool8023/1`030?ooo`0Pk0L08>`700@08>`700<0
oooo023/1`0Pk0L01@0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?oo
o`040?ooo`04023/1`3oool0oooo000005<0oooo00<000000?ooo`3oool05P3oool001@0oooo00<0
00000?ooo`3oool0@P3oool2023/1`80oooo100Pk0L30?ooo`04023/1`3oool0oooo0?ooo`T08>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`70080oooo
200Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700D08>`70P3oool6023/1`030?oo
o`0Pk0L08>`700<0oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`00001C0?ooo`03
0000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0480oooo0P0Pk0L20?ooo`@08>`7
0`3oool0100Pk0L0oooo0?ooo`3oool9023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0P
k0L01P0Pk0L00`3oool08>`7023/1`020?ooo`P08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool0
8>`7023/1`05023/1`80oooo1P0Pk0L00`3oool08>`7023/1`030?ooo`03023/1`3oool0oooo00@0
oooo00@08>`70?ooo`3oool00000D`3oool00`000000oooo0?ooo`0F0?ooo`00503oool00`000000
oooo0?ooo`120?ooo`808>`70P3oool4023/1`<0oooo00@08>`70?ooo`3oool0oooo2@0Pk0L00`3o
ool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo2@0Pk0L0
0`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700D08>`70P3oool6023/1`030?ooo`0Pk0L0
8>`700<0oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`00001C0?ooo`030000003o
ool0oooo01H0oooo000D0?ooo`030000003oool0oooo0480oooo0P0Pk0L20?ooo`@08>`70`3oool0
100Pk0L0oooo0?ooo`3oool>023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo
2@0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700D08>`70P3oool6023/1`030?oo
o`0Pk0L08>`700<0oooo00<08>`70?ooo`3oool0103oool0100Pk0L0oooo0?ooo`00001C0?ooo`03
0000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0480oooo0P0Pk0L20?ooo`@08>`7
0`3oool0100Pk0L0oooo0?ooo`3oool>023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0P
k0L0oooo2@0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700D08>`70P3oool6023/
1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool01@3oool0100Pk0L0oooo0?ooo`00001C
0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0480oooo0P0Pk0L20?oo
o`@08>`70`3oool0100Pk0L0oooo0?ooo`3oool>023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo
023/1`0Pk0L0oooo2@0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700D08>`70P3o
ool6023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool01@3oool0100Pk0L0oooo0?oo
o`00001C0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0480oooo0P0P
k0L20?ooo`@08>`70`3oool0100Pk0L0oooo0?ooo`3oool>023/1`030?ooo`0Pk0L08>`700H08>`7
00@0oooo023/1`0Pk0L0oooo2@0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700D0
8>`70P3oool6023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool01@3oool0100Pk0L0
oooo0?ooo`00001C0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0oooo0480
oooo0P0Pk0L20?ooo`@08>`70`3oool0100Pk0L0oooo0?ooo`3oool>023/1`030?ooo`0Pk0L08>`7
00H08>`700@0oooo023/1`0Pk0L0oooo200Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0
8>`700D08>`70P3oool6023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool01@3oool0
100Pk0L0oooo0?ooo`00001C0?ooo`030000003oool0oooo01H0oooo000D0?ooo`030000003oool0
oooo0480oooo0P0Pk0L20?ooo`@08>`70`3oool0100Pk0L0oooo0?ooo`3oool>023/1`030?ooo`0P
k0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo200Pk0L00`3oool08>`7023/1`05023/1`030?oo
o`0Pk0L08>`700@08>`70`3oool6023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool0
1@3oool0100Pk0L0oooo0?ooo`00001D0?ooo`030000003oool0oooo01D0oooo000D0?ooo`030000
003oool0oooo0480oooo0P0Pk0L20?ooo`@08>`70`3oool0100Pk0L0oooo0?ooo`3oool>023/1`03
0?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo200Pk0L00`3oool08>`7023/1`05023/
1`030?ooo`0Pk0L08>`700@08>`70`3oool6023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?oo
o`3oool01@3oool0100Pk0L0oooo0?ooo`00001D0?ooo`030000003oool0oooo01D0oooo000D0?oo
o`030000003oool0oooo0480oooo0P0Pk0L20?ooo`@08>`70`3oool0100Pk0L0oooo0?ooo`3oool>
023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo200Pk0L00`3oool08>`7023/
1`05023/1`030?ooo`0Pk0L08>`700@08>`70`3oool6023/1`030?ooo`0Pk0L08>`70080oooo00<0
8>`70?ooo`3oool01@3oool0100Pk0L0oooo0?ooo`00001D0?ooo`030000003oool0oooo01D0oooo
000D0?ooo`030000003oool0oooo0480oooo0P0Pk0L20?ooo`@08>`70`3oool0100Pk0L0oooo0?oo
o`3oool>023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L02@0Pk0L00`3oool08>`7
023/1`05023/1`030?ooo`0Pk0L08>`700@08>`70`3oool5023/1`80oooo0P0Pk0L20?ooo`03023/
1`3oool0oooo00@0oooo00D08>`70?ooo`3oool0oooo0000001D0?ooo`030000003oool0oooo01D0
oooo000D0?ooo`030000003oool0oooo0480oooo0P0Pk0L20?ooo`@08>`70`3oool2023/1`80oooo
3P0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`0Pk0L0
1@0Pk0L00`3oool08>`7023/1`04023/1`<0oooo1@0Pk0L20?ooo`808>`70P3oool00`0Pk0L0oooo
0?ooo`040?ooo`05023/1`3oool0oooo0?ooo`000000E03oool00`000000oooo0?ooo`0E0?ooo`00
503oool00`000000oooo0?ooo`120?ooo`808>`70P3oool4023/1`<0oooo0P0Pk0L20?ooo`h08>`7
00<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`09023/1`030?ooo`0Pk0L08>`700D08>`7
00<0oooo023/1`0Pk0L0100Pk0L30?ooo`D08>`70P3oool2023/1`80oooo00<08>`70?ooo`3oool0
103oool01@0Pk0L0oooo0?ooo`3oool0000005@0oooo00<000000?ooo`3oool05@3oool001<0oooo
00<000000?ooo`3oool0@`3oool2023/1`80oooo100Pk0L30?ooo`808>`70P3oool>023/1`030?oo
o`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L02@0Pk0L00`3oool08>`7023/1`05023/1`030?oo
o`0Pk0L08>`700@08>`70`3oool5023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo
00D08>`70?ooo`3oool0oooo0000001D0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000
003oool0oooo04<0oooo0P0Pk0L20?ooo`@08>`70`3oool2023/1`80oooo3P0Pk0L00`3oool08>`7
023/1`06023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`0Pk0L0300Pk0L30?ooo`D08>`7
0P3oool2023/1`80oooo00<08>`70?ooo`3oool0103oool01@0Pk0L0oooo0?ooo`3oool0000005@0
oooo00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0@`3oool2023/1`80oooo
100Pk0L30?ooo`808>`70P3oool>023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L0
0P0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700`08>`70`3oool5023/1`80oooo
0P0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00D08>`70?ooo`3oool0oooo0000001D0?ooo`03
0000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04<0oooo0P0Pk0L20?ooo`@08>`7
0`3oool2023/1`80oooo3P0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700808>`7
00<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`0<023/1`<0oooo1@0Pk0L20?ooo`808>`7
0P3oool00`0Pk0L0oooo0?ooo`040?ooo`05023/1`3oool0oooo0?ooo`000000E03oool00`000000
oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`130?ooo`808>`70P3oool4023/1`<0oooo
0P0Pk0L20?ooo`h08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`02023/1`030?oo
o`0Pk0L08>`700@08>`700@0oooo023/1`0Pk0L0oooo2`0Pk0L30?ooo`D08>`70P3oool2023/1`80
oooo00<08>`70?ooo`3oool0103oool01@0Pk0L0oooo0?ooo`3oool0000005@0oooo00<000000?oo
o`3oool05@3oool001<0oooo00<000000?ooo`3oool0@`3oool2023/1`80oooo100Pk0L30?ooo`80
8>`70P3oool>023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool0
8>`7023/1`04023/1`030?ooo`0Pk0L08>`700`08>`70`3oool2023/1`030?ooo`0Pk0L08>`70080
oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00D08>`70?ooo`3oool0oooo0000001D0?oo
o`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04<0oooo0P0Pk0L20?ooo`@0
8>`7103oool00`0Pk0L0oooo0?ooo`0>023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0P
k0L00P0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700`08>`70P3oool3023/1`03
0?ooo`0Pk0L08>`70080oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00D08>`70?ooo`3o
ool0oooo0000001D0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04<0
oooo00H08>`70?ooo`0Pk0L0oooo023/1`3oool2023/1`@0oooo00<08>`70?ooo`3oool03P0Pk0L0
0`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L0100Pk0L0
0`3oool08>`7023/1`0<023/1`80oooo0`0Pk0L00`3oool08>`7023/1`020?ooo`808>`70P3oool0
0`0Pk0L0oooo0?ooo`040?ooo`05023/1`3oool0oooo0?ooo`000000E03oool00`000000oooo0?oo
o`0E0?ooo`004`3oool00`000000oooo0?ooo`130?ooo`06023/1`3oool08>`70?ooo`0Pk0L0oooo
0P0Pk0L40?ooo`03023/1`3oool0oooo00l08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7
023/1`02023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L0300Pk0L20?ooo`<08>`7
00<0oooo023/1`0Pk0L00P3oool2023/1`80oooo00<08>`70?ooo`3oool0103oool01@0Pk0L0oooo
0?ooo`3oool0000005@0oooo00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0
@`3oool01P0Pk0L0oooo023/1`3oool08>`70?ooo`808>`7103oool00`0Pk0L0oooo0?ooo`0?023/
1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`04023/
1`030?ooo`0Pk0L08>`700`08>`70P3oool3023/1`030?ooo`0Pk0L08>`70080oooo0P0Pk0L20?oo
o`03023/1`3oool0oooo00@0oooo00D08>`70?ooo`3oool0oooo0000001D0?ooo`030000003oool0
oooo01D0oooo000C0?ooo`030000003oool0oooo04@0oooo0P0Pk0L00`3oool08>`70?ooo`02023/
1`@0oooo00<08>`70?ooo`3oool03`0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`7
00808>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`0<023/1`80oooo0`0Pk0L00`3o
ool08>`7023/1`020?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`05023/1`3oool0oooo
0?ooo`000000E03oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`140?oo
o`808>`700<0oooo023/1`3oool00P0Pk0L40?ooo`03023/1`3oool0oooo00H08>`700<0oooo023/
1`0Pk0L01P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/
1`0Pk0L0300Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L00P3oool2023/1`80oooo00<08>`70?oo
o`3oool0103oool01@0Pk0L0oooo0?ooo`3oool0000005@0oooo00<000000?ooo`3oool05@3oool0
01<0oooo00<000000?ooo`3oool0A03oool2023/1`030?ooo`0Pk0L0oooo00808>`7103oool00`0P
k0L0oooo0?ooo`06023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3o
ool08>`7023/1`09023/1`030?ooo`0Pk0L08>`700`08>`70P3oool3023/1`030?ooo`0Pk0L08>`7
0080oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00D08>`70?ooo`3oool0oooo0000001D
0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04@0oooo0P0Pk0L00`3o
ool08>`70?ooo`02023/1`@0oooo00<08>`70?ooo`3oool01P0Pk0L00`3oool08>`7023/1`06023/
1`030?ooo`0Pk0L08>`700@08>`70P3oool;023/1`030?ooo`0Pk0L08>`700`08>`70P3oool3023/
1`030?ooo`0Pk0L08>`70080oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00D08>`70?oo
o`3oool0oooo0000001D0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo
04@0oooo0P0Pk0L00`3oool08>`70?ooo`02023/1`@0oooo00<08>`70?ooo`3oool01P0Pk0L00`3o
ool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700@08>`70P3oool;023/1`030?ooo`0Pk0L08>`7
00`08>`70P3oool3023/1`030?ooo`0Pk0L08>`70080oooo0P0Pk0L20?ooo`03023/1`3oool0oooo
00@0oooo00D08>`70?ooo`3oool0oooo0000001D0?ooo`030000003oool0oooo01D0oooo000C0?oo
o`030000003oool0oooo04@0oooo0P0Pk0L00`3oool08>`70?ooo`02023/1`@0oooo00<08>`70?oo
o`3oool01P0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700@08>`70P3oool;023/
1`030?ooo`0Pk0L08>`700`08>`70P3oool6023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0oooo
00@0oooo00D08>`70?ooo`3oool0oooo0000001D0?ooo`030000003oool0oooo01D0oooo000C0?oo
o`030000003oool0oooo04@0oooo0P0Pk0L00`3oool08>`70?ooo`02023/1`@0oooo00<08>`70?oo
o`3oool01P0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/
1`0Pk0L02P0Pk0L00`3oool08>`7023/1`0<023/1`80oooo1P0Pk0L20?ooo`808>`70P3oool00`0P
k0L0oooo0?ooo`040?ooo`05023/1`3oool0oooo0?ooo`000000E03oool00`000000oooo0?ooo`0E
0?ooo`004`3oool00`000000oooo0?ooo`140?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`0P
k0L30?ooo`03023/1`3oool0oooo00H08>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`030?oo
o`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`0<023/1`80oooo
1P0Pk0L00`3oool08>`7023/1`030?ooo`03023/1`3oool0oooo00@0oooo00D08>`70?ooo`3oool0
oooo0000001D0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04@0oooo
0P0Pk0L01P3oool08>`70?ooo`0Pk0L0oooo023/1`<0oooo00<08>`70?ooo`3oool01P0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00@08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`0:
023/1`030?ooo`0Pk0L08>`700`08>`70P3oool6023/1`030?ooo`0Pk0L08>`700<0oooo00<08>`7
0?ooo`3oool0103oool01@0Pk0L0oooo0?ooo`3oool0000005@0oooo00<000000?ooo`3oool05@3o
ool001<0oooo00<000000?ooo`3oool0A03oool2023/1`060?ooo`0Pk0L0oooo023/1`3oool08>`7
0`3oool00`0Pk0L0oooo0?ooo`06023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L00`3oool0
8>`7023/1`04023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L0300Pk0L20?ooo`H0
8>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`040?ooo`05023/1`3oool0oooo0?oo
o`000000E03oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`140?ooo`80
8>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool0oooo00H08>`700<0oooo
023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo
023/1`0Pk0L0300Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`04
0?ooo`05023/1`3oool0oooo0?ooo`000000E03oool00`000000oooo0?ooo`0E0?ooo`004`3oool0
0`000000oooo0?ooo`140?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L30?ooo`03023/
1`3oool0oooo00H08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`04023/1`030?oo
o`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L0300Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L0
0`3oool00`0Pk0L0oooo0?ooo`040?ooo`05023/1`3oool0oooo0?ooo`000000E03oool00`000000
oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`140?ooo`808>`700H0oooo023/1`3oool0
8>`70?ooo`0Pk0L30?ooo`03023/1`3oool0oooo00H08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3o
ool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L0300Pk0L20?oo
o`H08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?ooo`040?ooo`05023/1`3oool0oooo
0?ooo`000000E03oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`140?oo
o`808>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool0oooo00H08>`700<0
oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700X08>`700<0
oooo023/1`0Pk0L0300Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00`3oool00`0Pk0L0oooo0?oo
o`040?ooo`05023/1`3oool0oooo0?ooo`000000E03oool00`000000oooo0?ooo`0E0?ooo`004`3o
ool00`000000oooo0?ooo`140?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L30?ooo`03
023/1`3oool0oooo00H08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`04023/1`03
0?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L0300Pk0L20?ooo`H08>`700<0oooo023/1`0P
k0L00`3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo0080oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`140?ooo`808>`7
00H0oooo023/1`3oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool0oooo00H08>`700<0oooo023/
1`0Pk0L01P0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/
1`0Pk0L0300Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`040?oo
o`03023/1`3oool0oooo0080oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?oo
o`004`3oool00`000000oooo0?ooo`140?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L3
0?ooo`03023/1`3oool0oooo00H08>`700<0oooo023/1`0Pk0L01P0Pk0L0103oool08>`7023/1`3o
ool3023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L0300Pk0L20?ooo`H08>`700<0
oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo0080oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`14
0?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L30?ooo`03023/1`3oool0oooo00<08>`7
00@0oooo023/1`0Pk0L0oooo200Pk0L0103oool08>`7023/1`3oool3023/1`030?ooo`0Pk0L08>`7
00X08>`700<0oooo023/1`0Pk0L0300Pk0L20?ooo`808>`700D0oooo023/1`0Pk0L08>`70?ooo`02
023/1`80oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`020?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0A03oool2023/
1`060?ooo`0Pk0L0oooo023/1`3oool08>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`040?ooo`0P
k0L08>`70?ooo`P08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3oool08>`7023/1`0I023/1`80
oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70P3oool00`0Pk0L0oooo0?ooo`040?oo
o`03023/1`3oool0oooo0080oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?oo
o`004`3oool00`000000oooo0?ooo`140?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L3
0?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0Pk0L0300Pk0L01@3oool08>`7023/1`0P
k0L0oooo01/08>`70P3oool2023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L20?ooo`03023/
1`3oool0oooo00@0oooo00<08>`70?ooo`3oool00P3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04@0oooo0P0Pk0L00`3oool08>`70?oo
o`03023/1`<0oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`7023/1`0<023/1`050?ooo`0P
k0L08>`7023/1`3oool06`0Pk0L20?ooo`808>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`80
oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`020?ooo`030000003oool0oooo0580
oooo00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0A03oool2023/1`030?oo
o`0Pk0L0oooo00<08>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`030?ooo`0Pk0L08>`700`08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`0K023/1`80oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00808>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo0080oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`140?ooo`80
8>`700<0oooo023/1`3oool00`0Pk0L30?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0P
k0L0300Pk0L01@3oool08>`7023/1`0Pk0L0oooo01/08>`70P3oool2023/1`050?ooo`0Pk0L08>`7
023/1`3oool00P0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3oool00P3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo
04@0oooo0P0Pk0L20?ooo`@08>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`030?ooo`0Pk0L08>`7
00`08>`700D0oooo023/1`0Pk0L08>`70?ooo`0K023/1`80oooo0P0Pk0L01@3oool08>`7023/1`0P
k0L0oooo00808>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo0080oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`14
0?ooo`808>`70P3oool4023/1`<0oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`7023/1`0<
023/1`050?ooo`0Pk0L08>`7023/1`3oool06`0Pk0L20?ooo`808>`700D0oooo023/1`0Pk0L08>`7
0?ooo`02023/1`80oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`020?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0A03o
ool2023/1`80oooo100Pk0L30?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0Pk0L0300P
k0L01@3oool08>`7023/1`0Pk0L0oooo01/08>`70P3oool6023/1`030?ooo`0Pk0L08>`70080oooo
00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`020?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0A03oool2023/1`80oooo100P
k0L30?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0Pk0L0300Pk0L01@3oool08>`7023/
1`0Pk0L0oooo01/08>`70P3oool6023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool0
103oool00`0Pk0L0oooo0?ooo`020?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
5@3oool001<0oooo00<000000?ooo`3oool0A03oool2023/1`80oooo100Pk0L30?ooo`03023/1`3o
ool0oooo00<08>`700<0oooo023/1`0Pk0L0300Pk0L01@3oool08>`7023/1`0Pk0L0oooo01/08>`7
0P3oool6023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo
0?ooo`020?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo00<0
00000?ooo`3oool0A03oool2023/1`80oooo100Pk0L30?ooo`03023/1`3oool0oooo00<08>`700<0
oooo023/1`0Pk0L0300Pk0L01@3oool08>`7023/1`0Pk0L0oooo01/08>`70P3oool6023/1`030?oo
o`0Pk0L08>`70080oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`020?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0A03o
ool2023/1`80oooo100Pk0L30?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0Pk0L0300P
k0L01@3oool08>`7023/1`0Pk0L0oooo01/08>`70P3oool6023/1`030?ooo`0Pk0L08>`70080oooo
00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`020?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0A03oool2023/1`80oooo100P
k0L30?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0Pk0L0300Pk0L00`3oool08>`7023/
1`0M023/1`80oooo1P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00@0oooo00<0
8>`70?ooo`3oool00P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C
0?ooo`030000003oool0oooo04@0oooo0P0Pk0L20?ooo`@08>`70`3oool00`0Pk0L0oooo0?ooo`03
023/1`030?ooo`0Pk0L08>`700`08>`700<0oooo023/1`0Pk0L07@0Pk0L20?ooo`H08>`700<0oooo
023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo0080oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`140?oo
o`808>`70P3oool4023/1`<0oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`7023/1`0<023/
1`030?ooo`0Pk0L08>`701d08>`70P3oool6023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?oo
o`3oool0103oool00`0Pk0L0oooo0?ooo`020?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool05@3oool001<0oooo00<000000?ooo`3oool0A03oool2023/1`80oooo100Pk0L30?ooo`03
023/1`3oool0oooo00<08>`700<0oooo023/1`0Pk0L0300Pk0L00`3oool08>`7023/1`0M023/1`80
oooo1P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3o
ool00P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000
003oool0oooo04@0oooo0P0Pk0L20?ooo`@08>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`030?oo
o`0Pk0L08>`700`08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`7023/1`0?023/1`80oooo
1P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3oool0
0P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003o
ool0oooo04@0oooo0P0Pk0L20?ooo`@08>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`030?ooo`0P
k0L08>`700`08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`7023/1`0?023/1`80oooo1@0P
k0L20?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo0080oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`14
0?ooo`808>`70P3oool4023/1`<0oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`7023/1`0<
023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo023/1`0Pk0L03`0Pk0L20?ooo`D08>`70P3oool2
023/1`80oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`020?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0A03oool2023/
1`80oooo100Pk0L30?ooo`03023/1`3oool0oooo00<08>`700<0oooo023/1`0Pk0L0300Pk0L00`3o
ool08>`7023/1`0;023/1`030?ooo`0Pk0L08>`700l08>`70P3oool5023/1`80oooo0P0Pk0L20?oo
o`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3oool00P3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04@0oooo0P0Pk0L20?ooo`@0
8>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`030?ooo`0Pk0L08>`700`08>`700<0oooo023/1`0P
k0L02`0Pk0L00`3oool08>`7023/1`0?023/1`80oooo1@0Pk0L20?ooo`808>`70P3oool00`0Pk0L0
oooo0?ooo`040?ooo`03023/1`3oool0oooo0080oooo00<000000?ooo`3oool0DP3oool00`000000
oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`140?ooo`04023/1`3oool08>`70?ooo`@0
8>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`030?ooo`0Pk0L08>`700`08>`700<0oooo023/1`0P
k0L02`0Pk0L00`3oool08>`7023/1`0?023/1`80oooo1@0Pk0L20?ooo`808>`70P3oool00`0Pk0L0
oooo0?ooo`040?ooo`03023/1`3oool0oooo0080oooo00<000000?ooo`3oool0DP3oool00`000000
oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`140?ooo`04023/1`3oool08>`70?ooo`@0
8>`70`3oool00`0Pk0L0oooo0?ooo`03023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0P
k0L0100Pk0L00`3oool08>`7023/1`0;023/1`030?ooo`0Pk0L08>`700l08>`70P3oool5023/1`80
oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3oool00P3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04D0oooo
0P0Pk0L00`3oool08>`7023/1`02023/1`<0oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`7
023/1`05023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`7
023/1`08023/1`030?ooo`0Pk0L08>`700@08>`70P3oool5023/1`80oooo0P0Pk0L20?ooo`03023/
1`3oool0oooo00<0oooo00<08>`70?ooo`3oool00`3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04D0oooo0P0Pk0L00`3oool08>`7023/
1`02023/1`<0oooo00<08>`70?ooo`3oool00`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0P
k0L08>`700H08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0P
k0L08>`700<08>`70`3oool5023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00<0oooo00<0
8>`70?ooo`3oool00`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C
0?ooo`030000003oool0oooo04D0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`<0oooo00<08>`7
0?ooo`3oool00`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo
023/1`0Pk0L02`0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L08>`700<08>`70`3oool5
023/1`80oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool00`3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo
04D0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`<0oooo00<08>`70?ooo`3oool00`0Pk0L00`3o
ool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3o
ool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L00`0Pk0L30?oo
o`D08>`70P3oool2023/1`80oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`030?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3o
ool0A@3oool2023/1`030?ooo`0Pk0L08>`700808>`70`3oool00`0Pk0L0oooo0?ooo`02023/1`03
0000000Pk0L08>`700@08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`06023/1`03
0?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`7023/1`03023/1`<0
oooo1@0Pk0L20?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00<0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo
0?ooo`150?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`03023/1`3oool0oooo00808>`7
00<00000023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700H08>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L08>`700<08>`7
0`3oool2023/1`030?ooo`0Pk0L08>`70080oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00<0oooo
00<08>`70?ooo`3oool00`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo
000C0?ooo`030000003oool0oooo04D0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`<0oooo00<0
8>`70?ooo`3oool02@0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700H08>`700<0
oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L08>`700<08>`70`3o
ool2023/1`040?ooo`0Pk0L08>`70?ooo`808>`70`3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/
1`3oool0oooo00<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3o
ool00`000000oooo0?ooo`150?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`03023/1`3o
ool0oooo00T08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0P
k0L08>`700808>`700<0oooo023/1`3oool0200Pk0L00`3oool08>`7023/1`03023/1`<0oooo0P0P
k0L0103oool08>`7023/1`3oool2023/1`<0oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo
0?ooo`030?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo00<0
00000?ooo`3oool0A@3oool2023/1`030?ooo`0Pk0L0oooo00808>`70`3oool00`0Pk0L0oooo0?oo
o`09023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/
1`02023/1`030?ooo`0Pk0L0oooo00P08>`700<0oooo023/1`0Pk0L00`0Pk0L30?ooo`808>`700@0
oooo023/1`0Pk0L0oooo0P0Pk0L30?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool0
0`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003o
ool0oooo04D0oooo0P0Pk0L00`3oool08>`70?ooo`02023/1`<0oooo00<08>`70?ooo`3oool02@0P
k0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo023/1`3oool0200P
k0L00`3oool08>`7023/1`03023/1`<0oooo0P0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo
00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`030?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0A@3oool2023/1`030?ooo`0P
k0L0oooo00808>`70`3oool00`0Pk0L0oooo0?ooo`09023/1`030?ooo`0Pk0L08>`700H08>`700<0
oooo023/1`0Pk0L02`0Pk0L00`3oool08>`70?ooo`08023/1`030?ooo`0Pk0L08>`700<08>`70`3o
ool2023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/
1`3oool0oooo00<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3o
ool00`000000oooo0?ooo`150?ooo`808>`700<0oooo023/1`3oool00P0Pk0L30?ooo`03023/1`3o
ool0oooo00T08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`0;023/1`030?ooo`0P
k0L0oooo00P08>`700<0oooo023/1`0Pk0L00`0Pk0L30?ooo`808>`700@0oooo023/1`0Pk0L0oooo
0P0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3oool00`3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04D0oooo0P0P
k0L00`3oool08>`70?ooo`02023/1`<0oooo00@08>`70?ooo`3oool0oooo200Pk0L00`3oool08>`7
023/1`06023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo023/1`0Pk0L01@0Pk0L0103oool08>`7
023/1`3oool5023/1`<0oooo0P0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo00<08>`70?oo
o`3oool0103oool00`0Pk0L0oooo0?ooo`030?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool05@3oool001<0oooo00<000000?ooo`3oool0A@3oool2023/1`030?ooo`0Pk0L0oooo0080
8>`70`3oool0100Pk0L0oooo0?ooo`3oool8023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/
1`0Pk0L02`0Pk0L00`3oool08>`7023/1`05023/1`040?ooo`0Pk0L08>`70?ooo`D08>`70`3oool2
023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3o
ool0oooo00<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool0
0`000000oooo0?ooo`150?ooo`808>`700<0oooo023/1`3oool00P0Pk0L30?ooo`04023/1`3oool0
oooo0?ooo`P08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`0;023/1`030?ooo`0P
k0L08>`700D08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L30?ooo`808>`700@0oooo023/1`0Pk0L0
oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3oool00`3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04D0oooo
0P0Pk0L00`3oool08>`70?ooo`02023/1`<0oooo00@08>`70?ooo`3oool0oooo200Pk0L00`3oool0
8>`7023/1`06023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo023/1`0Pk0L01@0Pk0L0103oool0
8>`7023/1`3oool5023/1`80oooo0`0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo00<08>`7
0?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`030?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0A@3oool2023/1`030?ooo`0Pk0L0oooo
00808>`70`3oool0100Pk0L0oooo0?ooo`3oool8023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo
023/1`0Pk0L02`0Pk0L00`3oool08>`7023/1`05023/1`040?ooo`0Pk0L08>`70?ooo`D08>`70P3o
ool3023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/
1`3oool0oooo00<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3o
ool00`000000oooo0?ooo`150?ooo`808>`700<0oooo023/1`3oool00P0Pk0L30?ooo`04023/1`3o
ool0oooo0?ooo`P08>`700<0oooo023/1`0Pk0L0500Pk0L00`3oool08>`7023/1`05023/1`040?oo
o`0Pk0L08>`70?ooo`D08>`70P3oool3023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool00`0P
k0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo00<0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`150?ooo`808>`700<0oooo023/1`3o
ool00P0Pk0L30?ooo`04023/1`3oool0oooo0?ooo`P08>`700<0oooo023/1`0Pk0L0700Pk0L0103o
ool08>`7023/1`3oool5023/1`80oooo0`0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo00<0
8>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`030?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0A@3oool2023/1`030?ooo`0Pk0L0
oooo00808>`70`3oool0100Pk0L0oooo0?ooo`3oool8023/1`030?ooo`0Pk0L08>`701`08>`700@0
oooo023/1`0Pk0L0oooo1@0Pk0L20?ooo`<08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`03
023/1`3oool0oooo00@0oooo00<08>`70?ooo`3oool00`3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04D0oooo0P0Pk0L00`3oool08>`7
0?ooo`02023/1`<0oooo00@08>`70?ooo`3oool0oooo200Pk0L00`3oool08>`7023/1`0L023/1`04
0?ooo`0Pk0L08>`70?ooo`D08>`70P3oool3023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool0
0`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo00<0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`150?ooo`808>`700<0oooo023/
1`3oool00P0Pk0L30?ooo`808>`70P3oool8023/1`030?ooo`0Pk0L08>`701`08>`700@0oooo023/
1`0Pk0L0oooo1@0Pk0L20?ooo`<08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`03023/1`3o
ool0oooo00@0oooo00<08>`70?ooo`3oool00`3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo01D0oooo000C0?ooo`030000003oool0oooo04D0oooo0P0Pk0L00`3oool08>`70?ooo`02
023/1`<0oooo0P0Pk0L20?ooo`P08>`700<0oooo023/1`0Pk0L0700Pk0L0103oool08>`7023/1`3o
ool5023/1`80oooo0`0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo00<08>`70?ooo`3oool0
103oool00`0Pk0L0oooo0?ooo`030?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
5@3oool001<0oooo00<000000?ooo`3oool0A@3oool2023/1`030?ooo`0Pk0L0oooo00808>`70`3o
ool2023/1`80oooo200Pk0L00`3oool08>`7023/1`0L023/1`040?ooo`0Pk0L08>`70?ooo`D08>`7
0P3oool3023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`03
023/1`3oool0oooo00<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`00
4`3oool00`000000oooo0?ooo`150?ooo`808>`700<0oooo023/1`3oool00P0Pk0L30?ooo`808>`7
0P3oool8023/1`030?ooo`0Pk0L08>`701`08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L20?ooo`<0
8>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?oo
o`3oool00`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C0?ooo`03
0000003oool0oooo04D0oooo0P0Pk0L01P3oool08>`70?ooo`0Pk0L0oooo023/1`80oooo0P0Pk0L2
0?ooo`P08>`700<0oooo023/1`0Pk0L0700Pk0L0103oool08>`7023/1`3oool5023/1`80oooo0`0P
k0L0103oool08>`7023/1`3oool2023/1`80oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo
0?ooo`030?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo00<0
00000?ooo`3oool0A@3oool2023/1`060?ooo`0Pk0L0oooo023/1`3oool08>`70P3oool2023/1`80
oooo200Pk0L00`3oool08>`7023/1`0L023/1`040?ooo`0Pk0L08>`70?ooo`D08>`70P3oool3023/
1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0
oooo00<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`00
0000oooo0?ooo`150?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L20?ooo`808>`70P3o
ool8023/1`030?ooo`0Pk0L08>`701`08>`700@0oooo023/1`0Pk0L0oooo1@0Pk0L20?ooo`<08>`7
00@0oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3o
ool00`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000
003oool0oooo04D0oooo0P0Pk0L01P3oool08>`70?ooo`0Pk0L0oooo023/1`<0oooo00<08>`70?oo
o`3oool0200Pk0L00`3oool08>`7023/1`0L023/1`040?ooo`0Pk0L08>`70?ooo`D08>`70P3oool3
023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3o
ool0oooo00@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool0
0`000000oooo0?ooo`150?ooo`808>`700H0oooo023/1`3oool08>`70?ooo`0Pk0L30?ooo`03023/
1`3oool0oooo00P08>`700<0oooo023/1`0Pk0L0700Pk0L0103oool08>`7023/1`3oool5023/1`80
oooo0`0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo00<08>`70?ooo`3oool00`3oool00`0P
k0L0oooo0?ooo`040?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool001<0
oooo00<000000?ooo`3oool0A@3oool2023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`020?ooo`03
023/1`3oool0oooo00P08>`700<0oooo023/1`0Pk0L0700Pk0L0103oool08>`7023/1`3oool5023/
1`80oooo0`0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo00<08>`70?ooo`3oool00`3oool0
0`0Pk0L0oooo0?ooo`040?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool0
01<0oooo00<000000?ooo`3oool0A@3oool2023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`020?oo
o`03023/1`3oool0oooo00P08>`700<0oooo023/1`0Pk0L0700Pk0L0103oool08>`7023/1`3oool5
023/1`80oooo0`0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo00<08>`70?ooo`3oool00`3o
ool00`0Pk0L0oooo0?ooo`040?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3o
ool001<0oooo00<000000?ooo`3oool0A@3oool2023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`02
0?ooo`03023/1`3oool0oooo00P08>`700<0oooo023/1`0Pk0L0700Pk0L0103oool08>`7023/1`3o
ool5023/1`80oooo0`0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo00<08>`70?ooo`3oool0
0`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
5@3oool001<0oooo00<000000?ooo`3oool0A@3oool2023/1`80oooo100Pk0L30?ooo`03023/1`3o
ool0oooo00P08>`700<0oooo023/1`0Pk0L0700Pk0L0103oool08>`7023/1`3oool5023/1`80oooo
0`0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0
oooo0?ooo`040?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo
00<000000?ooo`3oool0A@3oool2023/1`80oooo100Pk0L30?ooo`03023/1`3oool0oooo00P08>`7
00<0oooo023/1`0Pk0L0700Pk0L0103oool08>`7023/1`3oool5023/1`80oooo0P0Pk0L20?ooo`80
8>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00@0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo
0?ooo`150?ooo`808>`70P3oool4023/1`<0oooo00<08>`70?ooo`3oool0200Pk0L00`3oool08>`7
023/1`0O023/1`030?ooo`0Pk0L08>`700<08>`70P3oool2023/1`80oooo0P0Pk0L00`3oool08>`7
023/1`020?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool0103oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04D0oooo0P0P
k0L20?ooo`@08>`70`3oool00`0Pk0L0oooo0?ooo`08023/1`030?ooo`0Pk0L08>`701l08>`700<0
oooo023/1`0Pk0L00`0Pk0L20?ooo`808>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`80oooo
00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0A@3oool2023/1`80oooo100P
k0L30?ooo`03023/1`3oool0oooo00P08>`700<0oooo023/1`0Pk0L07`0Pk0L00`3oool08>`7023/
1`03023/1`80oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70P3oool00`0Pk0L0oooo
0?ooo`030?ooo`03023/1`3oool0oooo00@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`150?ooo`808>`70P3oool4023/1`<0oooo00<0
8>`70?ooo`3oool0200Pk0L00`3oool08>`7023/1`0O023/1`030?ooo`0Pk0L08>`700<08>`700D0
oooo023/1`0Pk0L08>`70?ooo`03023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool0
0`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
5@3oool001<0oooo00<000000?ooo`3oool0A@3oool2023/1`80oooo100Pk0L30?ooo`03023/1`3o
ool0oooo00P08>`700<0oooo023/1`0Pk0L03@0Pk0L00`3oool08>`7023/1`0?023/1`030?ooo`0P
k0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`030?ooo`0Pk0L08>`70080oooo
00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0A@3oool2023/1`80oooo100P
k0L30?ooo`03023/1`3oool0oooo00P08>`700<0oooo023/1`0Pk0L03@0Pk0L0103oool08>`7023/
1`3oool>023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`03023/1`03
0?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`040?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0
AP3oool2023/1`030?ooo`0Pk0L08>`700808>`70`3oool00`0Pk0L0oooo0?ooo`08023/1`030?oo
o`0Pk0L08>`700d08>`700@0oooo023/1`0Pk0L0oooo3P0Pk0L00`3oool08>`7023/1`03023/1`05
0?ooo`0Pk0L08>`7023/1`3oool00`0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo
00<0oooo00<08>`70?ooo`3oool0103oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
01D0oooo000C0?ooo`030000003oool0oooo04H0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`<0
oooo00<08>`70?ooo`3oool0200Pk0L00`3oool08>`7023/1`0=023/1`040?ooo`0Pk0L08>`70?oo
o`h08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`70P3oool2
023/1`80oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`040?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0AP3oool2023/
1`030?ooo`0Pk0L08>`700808>`70`3oool00`0Pk0L0oooo0?ooo`08023/1`030?ooo`0Pk0L08>`7
01008>`700<0oooo023/1`0Pk0L0300Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7
023/1`3oool00P0Pk0L20?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0
oooo00@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`00
0000oooo0?ooo`160?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`03023/1`3oool0oooo
00P08>`700<0oooo023/1`0Pk0L0400Pk0L00`3oool08>`7023/1`0<023/1`030?ooo`0Pk0L08>`7
00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`05
0?ooo`03023/1`3oool0oooo00@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E
0?ooo`004`3oool00`000000oooo0?ooo`160?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?oo
o`03023/1`3oool0oooo00P08>`700<0oooo023/1`0Pk0L07`0Pk0L00`3oool08>`7023/1`03023/
1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L20?ooo`808>`700<0oooo023/1`3oool01@3oool0
0`0Pk0L0oooo0?ooo`040?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool0
01<0oooo00<000000?ooo`3oool0AP3oool2023/1`030?ooo`0Pk0L08>`700808>`70`3oool00`0P
k0L0oooo0?ooo`08023/1`030?ooo`0Pk0L08>`701l08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`04
0?ooo`03023/1`3oool0oooo00@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E
0?ooo`004`3oool00`000000oooo0?ooo`160?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?oo
o`03023/1`3oool0oooo00P08>`700<0oooo023/1`0Pk0L07`0Pk0L00`3oool08>`7023/1`03023/
1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0
oooo00@0oooo00<08>`70?ooo`3oool0103oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo01D0oooo000C0?ooo`030000003oool0oooo04H0oooo0P0Pk0L00`3oool08>`7023/1`02023/
1`<0oooo00<08>`70?ooo`3oool0200Pk0L00`3oool08>`7023/1`0O023/1`030?ooo`0Pk0L08>`7
00<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`030?ooo`0Pk0L08>`70080oooo00<08>`7
0?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`040?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0AP3oool2023/1`030?ooo`0Pk0L08>`7
00808>`70`3oool00`0Pk0L0oooo0?ooo`08023/1`030?ooo`0Pk0L08>`701l08>`700<0oooo023/
1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00P3oool0
0`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo00@0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`160?ooo`808>`700<0oooo023/
1`0Pk0L00P0Pk0L30?ooo`03023/1`3oool0oooo00P08>`700<0oooo023/1`0Pk0L07`0Pk0L00`3o
ool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`02
0?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3oool0103oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04H0oooo0P0Pk0L00`3o
ool08>`7023/1`02023/1`<0oooo00<08>`70?ooo`3oool0200Pk0L00`3oool08>`7023/1`0O023/
1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L08>`70?ooo`02023/1`030?ooo`0Pk0L0
8>`70080oooo00<08>`70?ooo`3oool0103oool00`0Pk0L0oooo0?ooo`040?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo00<000000?ooo`3oool0AP3oool2023/
1`030?ooo`0Pk0L08>`700808>`70`3oool00`0Pk0L0oooo0?ooo`08023/1`030?ooo`0Pk0L08>`7
01l08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700<0oooo
023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`040?ooo`03023/1`3oool0oooo00@0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`000000oooo0?ooo`160?oo
o`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`03023/1`3oool0oooo00P08>`700<0oooo023/
1`0Pk0L07`0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L0
0`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00@0oooo00<08>`70?ooo`3oool0103oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo
04H0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`<0oooo00<08>`70?ooo`3oool0200Pk0L00`3o
ool08>`7023/1`0<023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`0Pk0L00`0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`04
0?ooo`03023/1`3oool0oooo00@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E
0?ooo`004`3oool00`000000oooo0?ooo`160?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?oo
o`03023/1`3oool0oooo00P08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`05023/
1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`0Pk0L0
oooo00808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0
oooo00D0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`004`3oool00`00
0000oooo0?ooo`160?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`03023/1`3oool0oooo
00P08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`7
00D08>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7
023/1`3oool00P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00<0oooo00<08>`7
0?ooo`3oool01@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000C0?oo
o`030000003oool0oooo04H0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`<0oooo00<08>`70?oo
o`3oool0200Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/
1`0Pk0L01@0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/
1`0Pk0L08>`70?ooo`02023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool00`3oool0
0`0Pk0L0oooo0?ooo`050?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool0
01<0oooo00<000000?ooo`3oool0AP3oool2023/1`030?ooo`0Pk0L08>`700808>`70`3oool00`0P
k0L0oooo0?ooo`08023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3o
ool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`03
0?ooo`03023/1`3oool0oooo00D0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E
0?ooo`004`3oool00`000000oooo0?ooo`160?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?oo
o`03023/1`3oool0oooo00P08>`700<0oooo023/1`0Pk0L0300Pk0L00`3oool08>`7023/1`05023/
1`030?ooo`0Pk0L08>`700l08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`02
0?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01@3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04H0oooo0P0Pk0L00`3o
ool08>`7023/1`02023/1`<0oooo00<08>`70?ooo`3oool05`0Pk0L00`3oool08>`7023/1`05023/
1`030?ooo`0Pk0L08>`700l08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`02
0?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01@3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04H0oooo0P0Pk0L00`3o
ool08>`70?ooo`02023/1`<0oooo00<08>`70?ooo`3oool02P0Pk0L00`3oool08>`7023/1`0:023/
1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L03`0Pk0L0103oool08>`7023/1`3oool2
023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`05
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo00<000000?oo
o`3oool0AP3oool2023/1`030?ooo`0Pk0L0oooo00808>`70`3oool00`0Pk0L0oooo0?ooo`0:023/
1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0?023/
1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`03
0?ooo`03023/1`3oool0oooo00D0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E
0?ooo`004`3oool00`000000oooo0?ooo`160?ooo`808>`700<0oooo023/1`3oool00P0Pk0L30?oo
o`03023/1`3oool0oooo00X08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`05023/
1`030?ooo`0Pk0L08>`700l08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`02
0?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01@3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000003oool0oooo04H0oooo0P0Pk0L00`3o
ool08>`70?ooo`02023/1`<0oooo00<08>`70?ooo`3oool02P0Pk0L00`3oool08>`7023/1`0:023/
1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L03`0Pk0L0103oool08>`7023/1`3oool2
023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`05
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool001<0oooo00<000000?oo
o`3oool0AP3oool2023/1`030?ooo`0Pk0L0oooo00808>`70`3oool00`0Pk0L0oooo0?ooo`0:023/
1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0?023/
1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`03
0?ooo`03023/1`3oool0oooo00D0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E
0?ooo`004`3oool00`000000oooo0?ooo`160?ooo`808>`700<0oooo023/1`3oool00P0Pk0L30?oo
o`03023/1`3oool0oooo00X08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`05023/
1`030?ooo`0Pk0L08>`701808>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`03023/1`3oool0
oooo00<0oooo00<08>`70?ooo`3oool01@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo01D0oooo000C0?ooo`030000003oool0oooo04H0oooo0P0Pk0L00`3oool08>`70?ooo`02023/
1`<0oooo00<08>`70?ooo`3oool02P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`7
00D08>`700<0oooo023/1`0Pk0L04P0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo00<08>`7
0?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`050?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool05@3oool00180oooo00<000000?ooo`3oool0A`3oool2023/1`030?ooo`0Pk0L0oooo
00808>`70`3oool00`0Pk0L0oooo0?ooo`0:023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/
1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0B023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool0
0`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00D0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`170?ooo`808>`700<0oooo023/
1`3oool00P0Pk0L30?ooo`03023/1`3oool0oooo00X08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3o
ool08>`7023/1`05023/1`030?ooo`0Pk0L08>`701808>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L2
0?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01@3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04L0oooo0P0Pk0L00`3o
ool08>`70?ooo`02023/1`<0oooo00<08>`70?ooo`3oool02P0Pk0L00`3oool08>`7023/1`0:023/
1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L04P0Pk0L0103oool08>`7023/1`3oool2
023/1`80oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`050?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3oool0A`3oool2023/
1`030?ooo`0Pk0L0oooo00808>`70`3oool00`0Pk0L0oooo0?ooo`0:023/1`030?ooo`0Pk0L08>`7
00X08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0B023/1`040?ooo`0Pk0L08>`7
0?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00D0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`170?oo
o`808>`700<0oooo023/1`3oool00P0Pk0L30?ooo`03023/1`3oool0oooo00X08>`700<0oooo023/
1`0Pk0L02P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`701808>`700@0oooo023/
1`0Pk0L0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01@3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo
04L0oooo0P0Pk0L00`3oool08>`70?ooo`02023/1`<0oooo00<08>`70?ooo`3oool02P0Pk0L00`3o
ool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3o
ool08>`7023/1`0<023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`03
0?ooo`03023/1`3oool0oooo00D0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D
0?ooo`004P3oool00`000000oooo0?ooo`170?ooo`808>`700<0oooo023/1`3oool00P0Pk0L30?oo
o`03023/1`3oool0oooo00X08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`05023/
1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L0300Pk0L0103oool08>`7023/1`3oool2
023/1`80oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`050?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3oool0A`3oool2023/
1`030?ooo`0Pk0L0oooo00808>`70`3oool00`0Pk0L0oooo0?ooo`0:023/1`030?ooo`0Pk0L08>`7
00X08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`7
00`08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00<0oooo00<08>`7
0?ooo`3oool01@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?oo
o`030000003oool0oooo04L0oooo0P0Pk0L00`3oool08>`70?ooo`02023/1`<0oooo00<08>`70?oo
o`3oool02P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/
1`0Pk0L00`0Pk0L00`3oool08>`7023/1`0<023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool0
0`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00D0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`170?ooo`808>`700<0oooo023/
1`3oool00P0Pk0L30?ooo`03023/1`3oool0oooo00X08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3o
ool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L0300Pk0L0103o
ool08>`7023/1`3oool2023/1`030?ooo`0Pk0L0oooo00D0oooo00<08>`70?ooo`3oool01@3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo
04L0oooo0P0Pk0L20?ooo`<08>`70`3oool00`0Pk0L0oooo0?ooo`0:023/1`030?ooo`0Pk0L08>`7
00X08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`7
00`08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`70?ooo`050?ooo`03023/1`3oool0
oooo00D0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`00
0000oooo0?ooo`170?ooo`808>`70P3oool3023/1`<0oooo00<08>`70?ooo`3oool02P0Pk0L00`3o
ool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3o
ool08>`7023/1`0<023/1`040?ooo`0Pk0L08>`70?ooo`808>`700<0oooo023/1`3oool01@3oool0
0`0Pk0L0oooo0?ooo`050?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0503oool0
0180oooo00<000000?ooo`3oool0A`3oool2023/1`80oooo0`0Pk0L30?ooo`03023/1`3oool0oooo
00X08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`7
00<08>`700<0oooo023/1`0Pk0L0300Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L0
oooo00D0oooo00<08>`70?ooo`3oool01@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo01@0oooo000B0?ooo`030000003oool0oooo04L0oooo0P0Pk0L20?ooo`<08>`70`3oool00`0P
k0L0oooo0?ooo`0:023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3o
ool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700P08>`700D0oooo023/1`0Pk0L08>`70?ooo`02
023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01P3oool00`0Pk0L0oooo0?ooo`050?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3oool0B03oool0
0`0Pk0L0oooo0?ooo`03023/1`<0oooo00<08>`70?ooo`3oool02P0Pk0L00`3oool08>`7023/1`0:
023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`08
023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L01@3oool08>`7023/1`3oool08>`700D0oooo
00<08>`70?ooo`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo
000B0?ooo`030000003oool0oooo04P0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`70080oooo
00<08>`70?ooo`3oool02P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700/08>`7
00<0oooo023/1`3oool0200Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700D0oooo023/1`0P
k0L0oooo023/1`050?ooo`03023/1`3oool0oooo00H0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`180?ooo`808>`700D0oooo023/1`0P
k0L0oooo023/1`020?ooo`03023/1`3oool0oooo00X08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3o
ool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo023/1`3oool0200Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00808>`700D0oooo023/1`0Pk0L0oooo023/1`050?ooo`03023/1`3o
ool0oooo00H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool0
0`000000oooo0?ooo`180?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`020?ooo`03023/1`3o
ool0oooo00X08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0P
k0L08>`700/08>`700<0oooo023/1`3oool0200Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`7
00D0oooo023/1`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00H0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`180?ooo`808>`7
00D0oooo023/1`0Pk0L0oooo023/1`020?ooo`03023/1`3oool0oooo00X08>`700<0oooo023/1`0P
k0L00`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo023/1`3o
ool0300Pk0L0203oool08>`7023/1`0Pk0L0oooo023/1`3oool08>`71@3oool00`0Pk0L0oooo0?oo
o`060?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<00000
0?ooo`3oool0B03oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`08
023/1`030?ooo`0Pk0L0oooo00D08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`0;
023/1`030?ooo`0Pk0L0oooo00`08>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0
oooo00<0oooo00<08>`70?ooo`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo01@0oooo000B0?ooo`030000003oool0oooo04P0oooo0P0Pk0L00`3oool08>`7023/1`02023/
1`80oooo00<08>`70?ooo`3oool0200Pk0L00`3oool08>`70?ooo`05023/1`030?ooo`0Pk0L08>`7
00@08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`70?ooo`0<023/1`030?ooo`0Pk0L08>`7
00808>`70P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00H0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`180?ooo`80
8>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00P08>`700<0oooo023/1`3o
ool01@0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo023/1`3o
ool03P0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3o
ool01P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000
003oool0oooo04P0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool0
200Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L0
2`0Pk0L00`3oool08>`70?ooo`0>023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool0
0`3oool00`0Pk0L0oooo0?ooo`060?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
503oool00180oooo00<000000?ooo`3oool0B03oool2023/1`030?ooo`0Pk0L08>`700808>`70P3o
ool00`0Pk0L0oooo0?ooo`08023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L0100P
k0L00`3oool08>`7023/1`0=023/1`030?ooo`0Pk0L08>`700T08>`700@0oooo023/1`0Pk0L0oooo
0P0Pk0L20?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04P0oooo0P0P
k0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool0200Pk0L00`3oool08>`7023/
1`05023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L03@0Pk0L00`3oool08>`7023/
1`09023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/
1`3oool0oooo00H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3o
ool00`000000oooo0?ooo`180?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3o
ool0oooo00P08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0P
k0L08>`700d08>`700<0oooo023/1`0Pk0L02@0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo
00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`060?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3oool0B03oool2023/1`030?ooo`0P
k0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`08023/1`030?ooo`0Pk0L08>`700D08>`700<0
oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`0=023/1`030?ooo`0Pk0L08>`700T08>`700@0
oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool0
1P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003o
ool0oooo04P0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`80oooo0P0Pk0L00`3oool08>`7023/
1`06023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L0500Pk0L00`3oool08>`7023/
1`09023/1`040?ooo`0Pk0L08>`70?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/
1`3oool0oooo00H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3o
ool00`000000oooo0?ooo`180?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`808>`700<0
oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`701@08>`700<0
oooo023/1`0Pk0L02@0Pk0L0103oool08>`7023/1`3oool2023/1`80oooo00<08>`70?ooo`3oool0
0`3oool00`0Pk0L0oooo0?ooo`060?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
503oool00180oooo00<000000?ooo`3oool0B03oool2023/1`030?ooo`0Pk0L08>`700808>`70P3o
ool2023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/
1`0D023/1`030?ooo`0Pk0L08>`700T08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`03023/
1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04P0oooo0P0Pk0L00`3oool08>`7023/
1`02023/1`80oooo0P0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700D08>`700<0
oooo023/1`0Pk0L0500Pk0L00`3oool08>`7023/1`09023/1`040?ooo`0Pk0L08>`70?ooo`808>`7
0P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00H0oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`180?ooo`808>`700<0
oooo023/1`0Pk0L00P0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/
1`05023/1`030?ooo`0Pk0L08>`701@08>`700<0oooo023/1`0Pk0L02@0Pk0L0103oool08>`7023/
1`3oool2023/1`80oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`060?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3oool0B03o
ool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool2023/1`030?ooo`0Pk0L08>`700H08>`700<0
oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0D023/1`030?ooo`0Pk0L08>`700T08>`700@0
oooo023/1`0Pk0L0oooo0P0Pk0L20?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool0
1P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003o
ool0oooo04P0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`<0oooo00<08>`70?ooo`0Pk0L01`0P
k0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`701@08>`700<0oooo023/1`0Pk0L02@0P
k0L0103oool08>`7023/1`3oool2023/1`80oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo
0?ooo`060?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<0
00000?ooo`3oool0B03oool2023/1`030?ooo`0Pk0L08>`700808>`70`3oool00`0Pk0L0oooo023/
1`07023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L0500Pk0L00`3oool08>`7023/
1`05023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L00`3oool08>`7023/1`020?ooo`03023/
1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04P0oooo0P0Pk0L00`3oool08>`7023/
1`02023/1`<0oooo00<08>`70?ooo`0Pk0L01`0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0P
k0L08>`701@08>`700<0oooo023/1`0Pk0L01@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`7
00<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00H0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?oo
o`180?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`03023/1`3oool08>`700L08>`700<0
oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0D023/1`030?ooo`0Pk0L08>`700D08>`700D0
oooo023/1`0Pk0L08>`70?ooo`02023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool0
0`3oool00`0Pk0L0oooo0?ooo`060?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
503oool00180oooo00<000000?ooo`3oool0B03oool2023/1`030?ooo`0Pk0L08>`700808>`70`3o
ool00`0Pk0L0oooo023/1`07023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L0500P
k0L00`3oool08>`7023/1`05023/1`050?ooo`0Pk0L08>`7023/1`3oool00P0Pk0L00`3oool08>`7
023/1`020?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04P0oooo0P0P
k0L00`3oool08>`7023/1`02023/1`<0oooo00<08>`70?ooo`0Pk0L01`0Pk0L00`3oool08>`7023/
1`05023/1`030?ooo`0Pk0L08>`701@08>`700<0oooo023/1`0Pk0L01@0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/
1`3oool0oooo00H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3o
ool00`000000oooo0?ooo`180?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`03023/1`3o
ool08>`700L08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0D023/1`030?ooo`0P
k0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`020?ooo`03023/
1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04P0oooo0P0Pk0L00`3oool08>`7023/
1`02023/1`<0oooo00<08>`70?ooo`0Pk0L01`0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0P
k0L08>`701@08>`700<0oooo023/1`0Pk0L01P0Pk0L0103oool08>`7023/1`3oool2023/1`030?oo
o`0Pk0L08>`70080oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`060?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3oool0B03o
ool2023/1`030?ooo`0Pk0L08>`700808>`70`3oool00`0Pk0L0oooo023/1`07023/1`030?ooo`0P
k0L08>`700D08>`700<0oooo023/1`0Pk0L0500Pk0L00`3oool08>`7023/1`06023/1`040?ooo`0P
k0L08>`70?ooo`808>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/
1`3oool0oooo00H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3o
ool00`000000oooo0?ooo`180?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`03023/1`3o
ool08>`700L08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0D023/1`030?ooo`0P
k0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3oool08>`7023/1`020?ooo`03023/
1`3oool0oooo0080oooo00<08>`70?ooo`3oool01`3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04P0oooo0P0Pk0L00`3oool08>`7023/
1`02023/1`<0oooo00<08>`70?ooo`0Pk0L01`0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0P
k0L08>`701@08>`700<0oooo023/1`3oool01P0Pk0L0103oool08>`7023/1`3oool2023/1`050?oo
o`0Pk0L08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`070?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3oool0B03oool2023/1`030?oo
o`0Pk0L08>`700808>`70`3oool00`0Pk0L0oooo023/1`07023/1`030?ooo`0Pk0L08>`700D08>`7
00<0oooo023/1`0Pk0L0500Pk0L00`3oool08>`7023/1`06023/1`040?ooo`0Pk0L08>`70?ooo`80
8>`700D0oooo023/1`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00L0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`180?ooo`80
8>`700<0oooo023/1`3oool00P0Pk0L30?ooo`03023/1`3oool0oooo00L08>`700<0oooo023/1`0P
k0L01@0Pk0L00`3oool08>`7023/1`0D023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0P
k0L0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool01`3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo
04P0oooo0P0Pk0L00`3oool08>`70?ooo`02023/1`<0oooo00<08>`70?ooo`3oool01`0Pk0L00`3o
ool08>`7023/1`05023/1`030?ooo`0Pk0L08>`701@08>`700<0oooo023/1`0Pk0L01P0Pk0L0103o
ool08>`7023/1`3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?oo
o`070?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<00000
0?ooo`3oool0B03oool2023/1`030?ooo`0Pk0L0oooo00808>`70`3oool00`0Pk0L0oooo0?ooo`07
023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L02@0Pk0L00`3oool08>`7023/1`08
023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L01@3oool08>`7023/
1`3oool08>`700D0oooo00<08>`70?ooo`3oool01`3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04P0oooo0P0Pk0L00`3oool08>`70?oo
o`02023/1`<0oooo00<08>`70?ooo`3oool01`0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0P
k0L08>`700T08>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`7023/1`06023/1`040?ooo`0P
k0L08>`70?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00L0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo
0?ooo`180?ooo`808>`700<0oooo023/1`3oool00P0Pk0L30?ooo`03023/1`3oool0oooo00L08>`7
00<0oooo023/1`0Pk0L04@0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L08>`700H08>`7
00@0oooo023/1`0Pk0L0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700D0oooo00<08>`70?oo
o`3oool01`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`03
0000003oool0oooo04P0oooo0P0Pk0L00`3oool08>`70?ooo`02023/1`<0oooo00<08>`70?ooo`3o
ool01`0Pk0L00`3oool08>`7023/1`0A023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0P
k0L01P0Pk0L0103oool08>`7023/1`3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01@3oool0
0`0Pk0L0oooo0?ooo`070?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0503oool0
0180oooo00<000000?ooo`3oool0B03oool2023/1`030?ooo`0Pk0L0oooo00808>`70`3oool00`0P
k0L0oooo0?ooo`07023/1`030?ooo`0Pk0L08>`701408>`700<0oooo023/1`0Pk0L0200Pk0L00`3o
ool08>`7023/1`06023/1`040?ooo`0Pk0L08>`70?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/
1`050?ooo`03023/1`3oool0oooo00L0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0D0?ooo`004P3oool00`000000oooo0?ooo`180?ooo`808>`700<0oooo023/1`3oool00P0Pk0L3
0?ooo`03023/1`3oool0oooo00L08>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`7023/1`06
023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L01P0Pk0L0103oool08>`7023/1`3o
ool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`070?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3oool0B03o
ool2023/1`030?ooo`0Pk0L0oooo00808>`70`3oool00`0Pk0L0oooo0?ooo`07023/1`030?ooo`0P
k0L08>`700P08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0P
k0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700D0
oooo00<08>`70?ooo`3oool01`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0
oooo000B0?ooo`030000003oool0oooo04P0oooo0P0Pk0L00`3oool08>`70?ooo`02023/1`<0oooo
00<08>`70?ooo`3oool01`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo023/1`0P
k0L01P0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0P
k0L0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool01`3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo
04T0oooo00@08>`70?ooo`0Pk0L0oooo0P0Pk0L30?ooo`03023/1`3oool0oooo00L08>`700D0oooo
023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L0200P
k0L00`3oool08>`7023/1`06023/1`040?ooo`0Pk0L08>`70?ooo`808>`700D0oooo023/1`0Pk0L0
oooo023/1`050?ooo`03023/1`3oool0oooo00L0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`190?ooo`04023/1`3oool08>`70?ooo`80
8>`70`3oool00`0Pk0L0oooo0?ooo`07023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3o
ool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L01P0Pk0L0103o
ool08>`7023/1`3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?oo
o`070?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<00000
0?ooo`3oool0B@3oool0100Pk0L0oooo023/1`3oool2023/1`<0oooo00<08>`70?ooo`3oool01`0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7
023/1`08023/1`030?ooo`0Pk0L08>`700H08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L0103oool0
8>`70?ooo`0Pk0L50?ooo`03023/1`3oool0oooo00L0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`190?ooo`808>`700@0oooo023/1`0P
k0L08>`70`3oool00`0Pk0L0oooo0?ooo`07023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L0
0`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L01P0Pk0L0
103oool08>`7023/1`3oool3023/1`040?ooo`0Pk0L0oooo023/1`D0oooo00<08>`70?ooo`3oool0
1`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003o
ool0oooo04T0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`03023/1`3oool0oooo00L08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0P
k0L0200Pk0L00`3oool08>`7023/1`05023/1`80oooo0P0Pk0L00`3oool08>`7023/1`02023/1`80
oooo00<08>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`070?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3oool0B@3oool2023/1`040?oo
o`0Pk0L08>`7023/1`<0oooo00<08>`70?ooo`3oool01`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00H08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L08>`7
00D08>`70P3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`030?oo
o`03023/1`3oool0oooo00L0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?oo
o`004P3oool00`000000oooo0?ooo`190?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool00`0P
k0L0oooo0?ooo`07023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3oool08>`7023/1`06
023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`808>`700<0oooo
023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01`3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo
04T0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`03023/1`3oool0oooo00L08>`700D0oooo
023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L0200P
k0L00`3oool08>`7023/1`05023/1`80oooo0P0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<0
8>`70?ooo`3oool00`3oool00`0Pk0L0oooo0?ooo`070?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool0503oool00180oooo00<000000?ooo`3oool0B@3oool2023/1`040?ooo`0Pk0L0
8>`7023/1`<0oooo00<08>`70?ooo`3oool01`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`7
00<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700D08>`7
0P3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/
1`3oool0oooo00L0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3o
ool00`000000oooo0?ooo`190?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool00`0Pk0L0oooo
0?ooo`07023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3oool08>`7023/1`07023/1`03
0?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`808>`700<0oooo023/1`0P
k0L00P0Pk0L20?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01`3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04T0oooo
0P0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`03023/1`3oool0oooo00L08>`700D0oooo023/1`0P
k0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00L08>`70P3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool0
0`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00L0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`190?ooo`808>`700@0oooo023/
1`0Pk0L08>`70`3oool00`0Pk0L0oooo0?ooo`07023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0P
k0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L08>`7
0?ooo`07023/1`80oooo0P0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool0
0`3oool00`0Pk0L0oooo0?ooo`070?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
503oool00180oooo00<000000?ooo`3oool0B@3oool2023/1`040?ooo`0Pk0L08>`7023/1`<0oooo
00<08>`70?ooo`3oool01`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo023/1`0P
k0L01`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700T08>`70P3oool2023/1`03
0?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`030?ooo`03023/1`3oool0oooo00L0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo
0?ooo`190?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool00`0Pk0L0oooo0?ooo`07023/1`05
0?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`7
00<08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`7
023/1`3oool0100Pk0L20?ooo`03023/1`3oool0oooo00<0oooo00<08>`70?ooo`3oool01`3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo
04T0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`05023/1`3oool0oooo023/1`3oool01@0P
k0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7
023/1`03023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00`0Pk0L01`3oool08>`7
023/1`0Pk0L0oooo023/1`3oool00P0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00<08>`70?oo
o`3oool0203oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`03
0000003oool0oooo04T0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`05023/1`3oool0oooo
023/1`3oool01@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L01`0P
k0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00`0P
k0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool00P0Pk0L20?ooo`03023/1`3oool0oooo0080
oooo00<08>`70?ooo`3oool0203oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0
oooo000B0?ooo`030000003oool0oooo04T0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`05
023/1`3oool0oooo023/1`3oool01@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo
023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo
023/1`0Pk0L00`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool00P0Pk0L20?ooo`03023/
1`3oool0oooo0080oooo00<08>`70?ooo`3oool0203oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04T0oooo0P0Pk0L0103oool08>`7023/
1`0Pk0L30?ooo`05023/1`3oool0oooo023/1`3oool01@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00H08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo
00<08>`700<0oooo023/1`0Pk0L00`0Pk0L01`3oool08>`7023/1`0Pk0L0oooo023/1`3oool00P0P
k0L20?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`3oool0203oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04T0oooo0P0Pk0L0
0`3oool08>`7023/1`02023/1`80oooo00D08>`70?ooo`3oool08>`70?ooo`05023/1`050?ooo`0P
k0L08>`7023/1`3oool01P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700<08>`7
00<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`03023/1`070?ooo`0Pk0L08>`7023/1`3o
ool08>`70?ooo`02023/1`80oooo00<08>`70?ooo`3oool00P3oool00`0Pk0L0oooo0?ooo`080?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3o
ool0B@3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool01@0Pk0L0oooo0?ooo`0Pk0L0oooo
00D08>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo
023/1`0Pk0L00`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo
023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo0080oooo00<08>`7
0?ooo`3oool0203oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?oo
o`030000003oool0oooo04T0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?oo
o`3oool01`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L01`0Pk0L0
0`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00`0Pk0L0
0`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`3oool00P3oool0
0`0Pk0L0oooo0?ooo`080?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0503oool0
0180oooo00<000000?ooo`3oool0B@3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0P
k0L0oooo0?ooo`07023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3oool08>`7023/1`07
023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`03
023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo0?ooo`02
0?ooo`03023/1`3oool0oooo00P0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D
0?ooo`004P3oool00`000000oooo0?ooo`190?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?oo
o`03023/1`3oool0oooo00L08>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L0
8>`700L08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`70?ooo`03023/1`030?ooo`0Pk0L0
8>`700<08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`3oool08>`700D0oooo00<0
8>`70?ooo`3oool0203oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B
0?ooo`030000003oool0oooo04T0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`7
0?ooo`3oool01`0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L01`0P
k0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo00<08>`700<0oooo023/1`0Pk0L00`0P
k0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo
0?ooo`080?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<0
00000?ooo`3oool0B@3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?oo
o`07023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3oool08>`7023/1`07023/1`030?oo
o`0Pk0L08>`700<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7023/1`03023/1`030?oo
o`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00P0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo
0?ooo`190?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00L08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0P
k0L01@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L0
1@3oool08>`7023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool0203oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04T0oooo0P0Pk0L0
0`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool01`0Pk0L01@3oool08>`7023/1`0P
k0L0oooo00H08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`05023/1`050?ooo`0P
k0L08>`7023/1`3oool01@0Pk0L0103oool08>`7023/1`3oool2023/1`050?ooo`0Pk0L08>`70?oo
o`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`080?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool0503oool00180oooo00<000000?ooo`3oool0B@3oool2023/1`030?ooo`0Pk0L08>`70080
8>`70P3oool00`0Pk0L0oooo0?ooo`07023/1`050?ooo`0Pk0L08>`7023/1`3oool01P0Pk0L00`3o
ool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700D08>`700D0oooo023/1`0Pk0L08>`70?ooo`05
023/1`040?ooo`0Pk0L08>`70?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`050?ooo`03023/
1`3oool0oooo00P0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3o
ool00`000000oooo0?ooo`190?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3o
ool0oooo00L08>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700L08>`7
00<0oooo023/1`0Pk0L01@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00D08>`700@0oooo023/1`0P
k0L0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700D0oooo00<08>`70?ooo`3oool0203oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo
04T0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool01`0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00H08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`05
023/1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L0103oool08>`7023/1`3oool2023/1`050?oo
o`0Pk0L08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`080?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3oool0B@3oool2023/1`030?oo
o`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`07023/1`050?ooo`0Pk0L08>`7023/1`3o
ool01P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700D08>`700D0oooo023/1`0P
k0L08>`70?ooo`05023/1`040?ooo`0Pk0L08>`70?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/
1`050?ooo`03023/1`3oool0oooo00P0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0D0?ooo`004P3oool00`000000oooo0?ooo`190?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L2
0?ooo`03023/1`3oool0oooo00L08>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0P
k0L08>`700l08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`040?ooo`0Pk0L08>`70?ooo`80
8>`700D0oooo023/1`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00P0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`190?ooo`80
8>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00L08>`700D0oooo023/1`0P
k0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700l08>`700D0oooo023/1`0Pk0L08>`70?ooo`05
023/1`040?ooo`0Pk0L08>`70?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`050?ooo`03023/
1`3oool0oooo00P0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3o
ool00`000000oooo0?ooo`190?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3o
ool0oooo00L08>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700l08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`05023/1`040?ooo`0Pk0L08>`70?ooo`808>`700D0oooo023/
1`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00P0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`190?ooo`808>`700<0oooo023/
1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00L08>`700D0oooo023/1`0Pk0L08>`70?ooo`06
023/1`030?ooo`0Pk0L08>`700l08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`040?ooo`0P
k0L08>`70?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00P0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo
0?ooo`190?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00L08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0Pk0L08>`700l08>`700D0oooo023/1`0P
k0L08>`70?ooo`05023/1`040?ooo`0Pk0L08>`70?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/
1`050?ooo`03023/1`3oool0oooo00P0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0D0?ooo`004P3oool00`000000oooo0?ooo`190?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L2
0?ooo`03023/1`3oool0oooo00L08>`700D0oooo023/1`0Pk0L08>`70?ooo`06023/1`030?ooo`0P
k0L08>`700l08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`040?ooo`0Pk0L08>`70?ooo`80
8>`700D0oooo023/1`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00P0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`190?ooo`80
8>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00L08>`700<0oooo023/1`0P
k0L0200Pk0L00`3oool08>`7023/1`0?023/1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L0103o
ool08>`7023/1`3oool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?oo
o`080?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<00000
0?ooo`3oool0B@3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`07
023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L03`0Pk0L01@3oool08>`7023/1`0P
k0L0oooo00D08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L01@3oool08>`7023/1`3oool08>`700D0
oooo00<08>`70?ooo`3oool0203oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0
oooo000B0?ooo`030000003oool0oooo04T0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`80oooo
00<08>`70?ooo`3oool01`0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L08>`700l08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`05023/1`040?ooo`0Pk0L08>`70?ooo`808>`700D0oooo023/
1`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo00P0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`190?ooo`808>`700<0oooo023/
1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo00L08>`700<0oooo023/1`0Pk0L0200Pk0L00`3o
ool08>`7023/1`0?023/1`050?ooo`0Pk0L08>`7023/1`3oool01@0Pk0L0103oool08>`7023/1`3o
ool2023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L01@3oool00`0Pk0L0oooo0?ooo`080?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3oool0BP3o
ool00`0Pk0L0oooo023/1`03023/1`80oooo00<08>`70?ooo`3oool01`0Pk0L00`3oool08>`7023/
1`08023/1`030?ooo`0Pk0L08>`700l08>`700D0oooo023/1`0Pk0L08>`70?ooo`05023/1`040?oo
o`0Pk0L08>`70?ooo`808>`700D0oooo023/1`0Pk0L0oooo023/1`050?ooo`03023/1`3oool0oooo
00P0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000
oooo0?ooo`1:0?ooo`04023/1`3oool08>`70?ooo`808>`70P3oool00`0Pk0L0oooo0?ooo`07023/
1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L03`0Pk0L01@3oool08>`7023/1`0Pk0L0
oooo00@08>`70P3oool2023/1`080?ooo`0Pk0L08>`7023/1`3oool08>`70?ooo`0Pk0L40?ooo`03
023/1`3oool0oooo00T0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`00
4P3oool00`000000oooo0?ooo`1:0?ooo`04023/1`3oool08>`70?ooo`808>`70P3oool00`0Pk0L0
oooo0?ooo`07023/1`030?ooo`0Pk0L08>`701X08>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/
1`80oooo0P0Pk0L0203oool08>`7023/1`0Pk0L0oooo023/1`3oool08>`7103oool00`0Pk0L0oooo
0?ooo`090?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0503oool00180oooo00<0
00000?ooo`3oool0BP3oool0100Pk0L0oooo023/1`3oool2023/1`80oooo00<08>`70?ooo`3oool0
1`0Pk0L00`3oool08>`7023/1`0J023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L20?ooo`80
8>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo0080oooo00<08>`70?ooo`3o
ool02@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000
003oool0oooo04X0oooo0`0Pk0L00`3oool08>`7023/1`020?ooo`03023/1`3oool0oooo00L08>`7
00<0oooo023/1`0Pk0L06P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool2023/1`03
0?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00T0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo
0?ooo`1:0?ooo`<08>`700<0oooo023/1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L08>`700D08>`7
00<0oooo023/1`0Pk0L06P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool2023/1`03
0?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00T0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo
0?ooo`1:0?ooo`<08>`700<0oooo023/1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L08>`700D08>`7
00<0oooo023/1`0Pk0L06P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool2023/1`03
0?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00T0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo
0?ooo`1:0?ooo`<08>`700<0oooo023/1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L08>`700D08>`7
00<0oooo023/1`0Pk0L06P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool2023/1`03
0?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00T0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo
0?ooo`1:0?ooo`<08>`700<0oooo023/1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L08>`700D08>`7
00<0oooo023/1`0Pk0L06P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool2023/1`03
0?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00T0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo
0?ooo`1:0?ooo`<08>`700<0oooo023/1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L08>`700D08>`7
00<0oooo023/1`0Pk0L06P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool2023/1`03
0?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00T0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo
0?ooo`1:0?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool00`0Pk0L0oooo023/1`06023/1`03
0?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L03@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo
00@08>`70P3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`020?oo
o`03023/1`3oool0oooo00T0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?oo
o`004P3oool00`000000oooo0?ooo`1:0?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool00`0P
k0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L03@0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00@08>`70P3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool0
0`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00T0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`1:0?ooo`808>`700@0oooo023/
1`0Pk0L08>`70`3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo
023/1`0Pk0L03@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool2023/1`030?ooo`0P
k0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/1`3oool0oooo00T0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`1:
0?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0P
k0L08>`700X08>`700<0oooo023/1`0Pk0L03@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`7
0P3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo0?ooo`020?ooo`03023/
1`3oool0oooo00T0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?ooo`004P3o
ool00`000000oooo0?ooo`1:0?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool00`0Pk0L0oooo
023/1`06023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L03@0Pk0L01@3oool08>`7
023/1`0Pk0L0oooo00@08>`70P3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0
oooo0?ooo`020?ooo`03023/1`3oool0oooo00T0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`1:0?ooo`808>`700@0oooo023/1`0Pk0L0
8>`70`3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0P
k0L03@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00@08>`70P3oool2023/1`030?ooo`0Pk0L08>`7
00808>`700<0oooo023/1`3oool0103oool00`0Pk0L0oooo0?ooo`090?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3oool0BP3oool2023/1`04
0?ooo`0Pk0L08>`7023/1`<0oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`0:023/
1`030?ooo`0Pk0L08>`700d08>`700D0oooo023/1`0Pk0L08>`70?ooo`04023/1`80oooo0P0Pk0L0
0`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0oooo00@0oooo00<08>`70?ooo`3oool02P3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo
04X0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`03023/1`3oool08>`700H08>`700<0oooo
023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`0=023/1`050?ooo`0Pk0L08>`7023/1`3oool0100P
k0L20?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`040?ooo`03023/1`3o
ool0oooo00X0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0D0?ooo`004P3oool0
0`000000oooo0?ooo`1:0?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool00`0Pk0L0oooo023/
1`06023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L03@0Pk0L01@3oool08>`7023/
1`0Pk0L0oooo00@08>`70P3oool2023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`3oool0
103oool00`0Pk0L0oooo0?ooo`0:0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
503oool00180oooo00<000000?ooo`3oool0BP3oool2023/1`040?ooo`0Pk0L08>`7023/1`<0oooo
00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700d08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`04023/1`80oooo0P0Pk0L00`3oool08>`7023/1`02023/1`03
0?ooo`0Pk0L0oooo00@0oooo00<08>`70?ooo`3oool02P3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04X0oooo0P0Pk0L0103oool08>`7
023/1`0Pk0L30?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool0
8>`7023/1`0=023/1`050?ooo`0Pk0L08>`7023/1`3oool0100Pk0L20?ooo`808>`700<0oooo023/
1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`040?ooo`03023/1`3oool0oooo00X0oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`1:0?ooo`80
8>`700@0oooo023/1`0Pk0L08>`70`3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`7
00X08>`700<0oooo023/1`0Pk0L04@0Pk0L00`3oool08>`7023/1`02023/1`80oooo0P0Pk0L00`3o
ool08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo00@0oooo00<08>`70?ooo`3oool02P3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo01@0oooo000B0?ooo`030000003oool0oooo04X0
oooo0P0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`03023/1`3oool08>`700H08>`700<0oooo023/
1`0Pk0L02P0Pk0L00`3oool08>`7023/1`0A023/1`030?ooo`0Pk0L08>`700808>`70P3oool2023/
1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`3oool0103oool00`0Pk0L0oooo0?ooo`0:0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool0503oool00180oooo00<000000?ooo`3o
ool0BP3oool2023/1`040?ooo`0Pk0L08>`7023/1`<0oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3o
ool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`701408>`700<0oooo023/1`0Pk0L00P0Pk0L20?oo
o`808>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`70?ooo`040?ooo`03023/1`3oool0oooo
00X0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0D0?ooo`004@3oool00`000000
oooo0?ooo`1;0?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool00`0Pk0L0oooo023/1`06023/
1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L04@0Pk0L00`3oool08>`7023/1`02023/
1`80oooo0P0Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo00@0oooo00<08>`70?oo
o`3oool02P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01@0oooo000A0?ooo`03
0000003oool0oooo04/0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`03023/1`3oool08>`7
00H08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`0A023/1`030?ooo`0Pk0L08>`7
00808>`70P3oool2023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/1`3oool0103oool00`0P
k0L0oooo0?ooo`0:0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0503oool00140
oooo00<000000?ooo`3oool0B`3oool2023/1`040?ooo`0Pk0L08>`7023/1`<0oooo00<08>`70?oo
o`0Pk0L01P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`701408>`700<0oooo023/
1`0Pk0L00P0Pk0L20?ooo`808>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`70?ooo`040?oo
o`03023/1`3oool0oooo00X0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0D0?oo
o`004@3oool00`000000oooo0?ooo`1;0?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool00`0P
k0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L04@0Pk0L00`3o
ool08>`7023/1`02023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo
00@0oooo00<08>`70?ooo`3oool02P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
01@0oooo000A0?ooo`030000003oool0oooo04/0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L30?oo
o`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`0A023/
1`030?ooo`0Pk0L08>`700808>`70P3oool2023/1`030?ooo`0Pk0L0oooo00808>`700<0oooo023/
1`3oool00`3oool00`0Pk0L0oooo0?ooo`0;0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool0503oool00140oooo00<000000?ooo`3oool0B`3oool2023/1`040?ooo`0Pk0L08>`7023/
1`<0oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`7
00/08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`02023/1`80oooo0P0Pk0L00`3o
ool08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool02`3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04/0
oooo0P0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`03023/1`3oool08>`700H08>`700<0oooo023/
1`0Pk0L02P0Pk0L00`3oool08>`7023/1`0;023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/
1`0Pk0L00P0Pk0L20?ooo`808>`700<0oooo023/1`3oool00P0Pk0L00`3oool08>`70?ooo`030?oo
o`03023/1`3oool0oooo00/0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?oo
o`004@3oool00`000000oooo0?ooo`1;0?ooo`808>`700@0oooo023/1`0Pk0L08>`70`3oool00`0P
k0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3o
ool08>`7023/1`08023/1`80oooo0P0Pk0L00`3oool08>`70?ooo`02023/1`030?ooo`0Pk0L0oooo
00<0oooo00<08>`70?ooo`3oool02`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
01<0oooo000A0?ooo`030000003oool0oooo04/0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L30?oo
o`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`0;023/
1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`3oool0
8>`700@0oooo00<08>`70?ooo`3oool02`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo01<0oooo000A0?ooo`030000003oool0oooo04/0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L3
0?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`02
023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`7023/1`03
023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`0;0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0B`3oool2
023/1`040?ooo`0Pk0L08>`7023/1`<0oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/
1`0:023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/
1`08023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/1`0Pk0L0oooo023/1`040?ooo`03023/
1`3oool0oooo00/0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3o
ool00`000000oooo0?ooo`1;0?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3o
ool08>`700H08>`700<0oooo023/1`0Pk0L01`0Pk0L0103oool08>`7023/1`3oool4023/1`030?oo
o`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`7023/1`03023/1`050?oo
o`0Pk0L08>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?ooo`0;0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0B`3oool2023/1`030?oo
o`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700L08>`7
00@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700P0
8>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`3oool08>`700@0oooo00<08>`70?oo
o`3oool02`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A0?ooo`03
0000003oool0oooo04/0oooo0P0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`0P
k0L01P0Pk0L00`3oool08>`7023/1`07023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/
1`0Pk0L01P0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo023/
1`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00/0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1;0?ooo`808>`700<0oooo023/
1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L01`0Pk0L0103o
ool08>`7023/1`3oool4023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L0200Pk0L0
0`3oool08>`7023/1`03023/1`050?ooo`0Pk0L08>`70?ooo`0Pk0L0103oool00`0Pk0L0oooo0?oo
o`0;0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140oooo00<00000
0?ooo`3oool0B`3oool2023/1`030?ooo`0Pk0L08>`700808>`70P3oool00`0Pk0L0oooo023/1`06
023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`06
023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L00`0Pk0L01@3oool08>`7023/1`3o
ool08>`700@0oooo00<08>`70?ooo`3oool02`3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo01<0oooo000A0?ooo`030000003oool0oooo04/0oooo0P0Pk0L00`3oool08>`7023/1`02
023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L0
8>`700D08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L0
8>`700<08>`700D0oooo023/1`0Pk0L0oooo023/1`040?ooo`03023/1`3oool0oooo00/0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1<
0?ooo`03023/1`3oool08>`700<08>`70P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L0
8>`700L08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L0
8>`700P08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L0103oool08>`70?ooo`0Pk0L40?ooo`03023/
1`3oool0oooo00/0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3o
ool00`000000oooo0?ooo`1<0?ooo`03023/1`3oool08>`700<08>`70P3oool00`0Pk0L0oooo023/
1`06023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/
1`06023/1`030?ooo`0Pk0L08>`700P08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L0103oool08>`7
0?ooo`0Pk0L40?ooo`03023/1`3oool0oooo00/0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1<0?ooo`03023/1`3oool08>`700<08>`7
0P3oool00`0Pk0L0oooo023/1`06023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L0
3P0Pk0L00`3oool08>`7023/1`08023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700@0oooo023/1`3o
ool08>`7103oool00`0Pk0L0oooo0?ooo`0;0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool04`3oool00140oooo00<000000?ooo`3oool0C03oool00`0Pk0L0oooo023/1`03023/1`80
oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700h0
8>`700<0oooo023/1`0Pk0L0200Pk0L0103oool08>`7023/1`3oool4023/1`80oooo00<08>`70?oo
o`3oool00P3oool00`0Pk0L0oooo0?ooo`0;0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool04`3oool00140oooo00<000000?ooo`3oool0C03oool00`0Pk0L0oooo023/1`03023/1`80
oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700h0
8>`700<0oooo023/1`0Pk0L0200Pk0L0103oool08>`7023/1`3oool4023/1`80oooo00<08>`70?oo
o`3oool00P3oool00`0Pk0L0oooo0?ooo`0;0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool04`3oool00140oooo00<000000?ooo`3oool0C03oool00`0Pk0L0oooo023/1`03023/1`80
oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700h0
8>`700<0oooo023/1`0Pk0L0200Pk0L0103oool08>`7023/1`3oool4023/1`80oooo00<08>`70?oo
o`3oool00P3oool00`0Pk0L0oooo0?ooo`0;0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool04`3oool00140oooo00<000000?ooo`3oool0C03oool6023/1`80oooo00<08>`70?ooo`0P
k0L01P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700h08>`700<0oooo023/1`0P
k0L0200Pk0L0103oool08>`7023/1`3oool4023/1`80oooo00<08>`70?ooo`3oool00P3oool00`0P
k0L0oooo0?ooo`0;0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140
oooo00<000000?ooo`3oool0C03oool6023/1`80oooo00<08>`70?ooo`0Pk0L01P0Pk0L00`3oool0
8>`7023/1`04023/1`040?ooo`0Pk0L08>`70?oooa008>`700<0oooo023/1`0Pk0L0200Pk0L0103o
ool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0oooo00@0oooo00<08>`70?ooo`3oool02`3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo
04`0oooo1P0Pk0L20?ooo`03023/1`3oool08>`700H08>`700<0oooo023/1`0Pk0L0100Pk0L0103o
ool08>`7023/1`3oool@023/1`030?ooo`0Pk0L08>`700P08>`700@0oooo023/1`0Pk0L0oooo100P
k0L00`3oool08>`70?ooo`040?ooo`03023/1`3oool0oooo00/0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1<0?ooo`H08>`70P3oool0
0`0Pk0L0oooo00000006023/1`030?ooo`0Pk0L08>`700@08>`700@0oooo023/1`0Pk0L0oooo400P
k0L00`3oool08>`7023/1`08023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`3oool0
103oool00`0Pk0L0oooo0?ooo`0;0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
4`3oool00140oooo00<000000?ooo`3oool0C03oool6023/1`80oooo00<08>`70?ooo`0000001P0P
k0L00`3oool08>`7023/1`04023/1`040?ooo`0Pk0L08>`70?oooa008>`700<0oooo023/1`0Pk0L0
200Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0oooo00@0oooo00<08>`70?ooo`3o
ool02`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000
003oool0oooo04`0oooo1P0Pk0L20?ooo`03023/1`3oool0000000H08>`700<0oooo023/1`0Pk0L0
100Pk0L0103oool08>`7023/1`3oool@023/1`030?ooo`0Pk0L08>`700P08>`700@0oooo023/1`0P
k0L0oooo100Pk0L00`3oool08>`70?ooo`040?ooo`03023/1`3oool0oooo00/0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1<0?ooo`<0
8>`700<0oooo023/1`0Pk0L00P3oool00`0Pk0L0oooo00000006023/1`030?ooo`0Pk0L08>`700@0
8>`700@0oooo023/1`0Pk0L0oooo400Pk0L00`3oool08>`7023/1`08023/1`040?ooo`0Pk0L08>`7
0?ooo`@08>`700<0oooo023/1`3oool0103oool00`0Pk0L0oooo0?ooo`0;0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0C03oool3023/
1`030?ooo`0Pk0L08>`70080oooo00<08>`70?ooo`0000001P0Pk0L00`3oool08>`7023/1`07023/
1`030?ooo`0Pk0L08>`700h08>`700<0oooo023/1`0Pk0L0200Pk0L0103oool08>`7023/1`3oool4
023/1`030?ooo`0Pk0L0oooo00@0oooo00<08>`70?ooo`3oool02`3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04`0oooo0`0Pk0L00`3o
ool08>`7023/1`020?ooo`03023/1`3oool0000000H08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3o
ool08>`7023/1`0>023/1`030?ooo`0Pk0L08>`700P08>`700@0oooo023/1`0Pk0L0oooo100Pk0L0
0`3oool08>`70?ooo`030?ooo`03023/1`3oool0oooo00`0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1<0?ooo`<08>`700<0oooo023/
1`0Pk0L00P3oool00`0Pk0L0oooo00000006023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/
1`0Pk0L03P0Pk0L00`3oool08>`7023/1`08023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo
023/1`3oool00`3oool00`0Pk0L0oooo0?ooo`0<0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0C03oool3023/1`030?ooo`0Pk0L08>`7
0080oooo00<08>`70?ooo`0000001P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`7
00h08>`700<0oooo023/1`0Pk0L0200Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0
oooo00<0oooo00<08>`70?ooo`3oool0303oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo01<0oooo000A0?ooo`030000003oool0oooo04`0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L2
0?ooo`03023/1`3oool0000000H08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`0>
023/1`030?ooo`0Pk0L08>`700P08>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`70?oo
o`030?ooo`03023/1`3oool0oooo00`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0C0?ooo`004@3oool00`000000oooo0?ooo`1<0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3o
ool00`0Pk0L0oooo00000006023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L03P0P
k0L00`3oool08>`7023/1`08023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`3oool0
0`3oool00`0Pk0L0oooo0?ooo`0<0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
4`3oool00140oooo00<000000?ooo`3oool0C03oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo
00<08>`70?ooo`0000001P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700h08>`7
00<0oooo023/1`0Pk0L0200Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0oooo00<0
oooo00<08>`70?ooo`3oool0303oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0
oooo000A0?ooo`030000003oool0oooo04`0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`03
023/1`3oool0000000H08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`0>023/1`03
0?ooo`0Pk0L08>`700P08>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`70?ooo`030?oo
o`03023/1`3oool0oooo00`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?oo
o`004@3oool00`000000oooo0?ooo`1<0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool00`0P
k0L0oooo00000006023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L03P0Pk0L00`3o
ool08>`7023/1`08023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`3oool00`3oool0
0`0Pk0L0oooo0?ooo`0<0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04`3oool0
0140oooo00<000000?ooo`3oool0C03oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo00<08>`7
0?ooo`0000001P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700h08>`700<0oooo
023/1`0Pk0L0200Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0oooo00<0oooo00<0
8>`70?ooo`3oool0303oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A
0?ooo`030000003oool0oooo04`0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`03023/1`3o
ool0000000H08>`700<0oooo023/1`0Pk0L01`0Pk0L00`3oool08>`7023/1`0>023/1`030?ooo`0P
k0L08>`700P08>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`70?ooo`030?ooo`03023/
1`3oool0oooo00`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3o
ool00`000000oooo0?ooo`1<0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo
00000006023/1`030?ooo`0Pk0L08>`701P08>`700<0oooo023/1`0Pk0L0200Pk0L0103oool08>`7
023/1`3oool4023/1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool0303oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04`0oooo
0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`03023/1`3oool0000000H08>`700<0oooo023/1`0P
k0L0600Pk0L00`3oool08>`7023/1`08023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/
1`3oool00`3oool00`0Pk0L0oooo0?ooo`0<0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool04`3oool00140oooo00<000000?ooo`3oool0C03oool2023/1`040?ooo`0Pk0L08>`7023/
1`80oooo00<08>`70?ooo`0000001P0Pk0L00`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`7
00P08>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`70?ooo`030?ooo`03023/1`3oool0
oooo00`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`00
0000oooo0?ooo`1<0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo00000006
023/1`030?ooo`0Pk0L08>`701P08>`700<0oooo023/1`3oool0200Pk0L01P3oool08>`7023/1`3o
ool08>`70?ooo`808>`700<0oooo023/1`3oool00`3oool00`0Pk0L0oooo0?ooo`0<0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0C03o
ool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo00<08>`70?ooo`0000001P0Pk0L00`3oool08>`7
023/1`0H023/1`030?ooo`0Pk0L0oooo00P08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool2023/
1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool0303oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04`0oooo0P0Pk0L0103oool0
8>`7023/1`0Pk0L20?ooo`03023/1`3oool0000000H08>`700<0oooo023/1`0Pk0L0600Pk0L00`3o
ool08>`70?ooo`08023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L00`3oool08>`70?oo
o`030?ooo`03023/1`3oool0oooo00`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0C0?ooo`004@3oool00`000000oooo0?ooo`1<0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3o
ool00`0Pk0L0oooo00000006023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`0Pk0L03P0P
k0L00`3oool08>`7023/1`06023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L00`3oool0
8>`70?ooo`030?ooo`03023/1`3oool0oooo00`0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1<0?ooo`808>`700@0oooo023/1`0Pk0L0
8>`70P3oool00`0Pk0L0oooo00000006023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`0P
k0L03P0Pk0L00`3oool08>`7023/1`06023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L0
0`3oool08>`70?ooo`030?ooo`03023/1`3oool0oooo00`0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1<0?ooo`808>`700@0oooo023/
1`0Pk0L08>`70P3oool00`0Pk0L0oooo00000006023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo
023/1`0Pk0L03P0Pk0L00`3oool08>`7023/1`06023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo
0P0Pk0L00`3oool08>`70?ooo`030?ooo`03023/1`3oool0oooo00`0oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1<0?ooo`808>`700@0
oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo00000006023/1`030?ooo`0Pk0L08>`700T08>`7
00<0oooo023/1`0Pk0L03P0Pk0L00`3oool08>`7023/1`06023/1`060?ooo`0Pk0L08>`70?ooo`0P
k0L0oooo0P0Pk0L00`3oool08>`70?ooo`030?ooo`03023/1`3oool0oooo00`0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1<0?ooo`80
8>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo00000006023/1`030?ooo`0Pk0L08>`7
00T08>`700<0oooo023/1`0Pk0L03P0Pk0L00`3oool08>`7023/1`06023/1`060?ooo`0Pk0L08>`7
0?ooo`0Pk0L0oooo0P0Pk0L00`3oool08>`70?ooo`030?ooo`03023/1`3oool0oooo00`0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1<
0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo00000006023/1`030?ooo`0P
k0L08>`700T08>`700<0oooo023/1`0Pk0L03P0Pk0L00`3oool08>`7023/1`06023/1`060?ooo`0P
k0L08>`70?ooo`0Pk0L0oooo0P0Pk0L00`3oool08>`70?ooo`030?ooo`03023/1`3oool0oooo00`0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo
0?ooo`1<0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo00000006023/1`03
0?ooo`0Pk0L08>`700T08>`700<0oooo023/1`0Pk0L03P0Pk0L00`3oool08>`7023/1`06023/1`06
0?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L00`3oool08>`70?ooo`030?ooo`03023/1`3oool0
oooo00`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`00
0000oooo0?ooo`1<0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo00000006
023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`0Pk0L03P0Pk0L00`3oool08>`7023/1`06
023/1`060?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo0P0Pk0L00`3oool08>`70?ooo`030?ooo`03023/
1`3oool0oooo00`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3o
ool00`000000oooo0?ooo`1<0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool2023/1`030000
000Pk0L08>`700@08>`700<0oooo023/1`0Pk0L02@0Pk0L00`3oool08>`7023/1`0>023/1`030?oo
o`0Pk0L08>`700H08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool2023/1`030?ooo`0Pk0L0oooo
00<0oooo00<08>`70?ooo`3oool0303oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
01<0oooo000A0?ooo`030000003oool0oooo04`0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?oo
o`808>`700<00000023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`09023/1`030?ooo`0Pk0L08>`7
00h08>`700<0oooo023/1`0Pk0L01P0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`808>`700<0
oooo023/1`3oool00`3oool00`0Pk0L0oooo0?ooo`0<0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0C03oool2023/1`040?ooo`0Pk0L0
8>`7023/1`80oooo0P0Pk0L00`0000008>`7023/1`04023/1`030?ooo`0Pk0L08>`700T08>`700<0
oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L08>`700H08>`700@0
oooo023/1`0Pk0L0oooo0P0Pk0L0103oool08>`70?ooo`0Pk0L40?ooo`03023/1`3oool0oooo00`0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo
0?ooo`1=0?ooo`03023/1`3oool08>`700808>`70P3oool2023/1`030000000Pk0L08>`700@08>`7
00<0oooo023/1`0Pk0L02@0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700P08>`7
00<0oooo023/1`0Pk0L01P0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700D0
oooo00<08>`70?ooo`3oool0303oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0
oooo000A0?ooo`030000003oool0oooo04d0oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?ooo`808>`7
00<00000023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`09023/1`030?ooo`0Pk0L08>`700<08>`7
00<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`7023/1`05023/1`80oooo0P0Pk0L0103oool08>`7
023/1`3oool2023/1`@0oooo00<08>`70?ooo`3oool03@3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04d0oooo00<08>`70?ooo`0Pk0L0
0P0Pk0L30?ooo`03023/1`0000008>`700D08>`700<0oooo023/1`0Pk0L02@0Pk0L00`3oool08>`7
023/1`03023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L01@0Pk0L20?ooo`808>`7
00H0oooo023/1`0Pk0L08>`70?ooo`0Pk0L40?ooo`03023/1`3oool0oooo00d0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1=0?ooo`03
023/1`3oool08>`700808>`70`3oool00`0Pk0L00000023/1`05023/1`030?ooo`0Pk0L08>`700T0
8>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L08>`700D0
8>`70P3oool6023/1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool03@3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04d0oooo
00<08>`70?ooo`0Pk0L00P0Pk0L30?ooo`03023/1`0000008>`700D08>`700<0oooo023/1`0Pk0L0
2@0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`0Pk0L0
1@0Pk0L20?ooo`H08>`700<0oooo023/1`3oool00`3oool00`0Pk0L0oooo0?ooo`0=0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0C@3o
ool00`0Pk0L0oooo023/1`02023/1`<0oooo00<08>`70000000Pk0L01@0Pk0L00`3oool08>`7023/
1`09023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`7023/
1`05023/1`80oooo1P0Pk0L00`3oool08>`70?ooo`030?ooo`03023/1`3oool0oooo00d0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1=
0?ooo`03023/1`3oool08>`700808>`70`3oool00`0Pk0L00000023/1`05023/1`030?ooo`0Pk0L0
8>`700T08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`05023/1`040?ooo`0Pk0L0
8>`70?ooo`L08>`70P3oool6023/1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool03@3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0
oooo04d0oooo1@0Pk0L30?ooo`03023/1`0000008>`700D08>`700<0oooo023/1`0Pk0L02@0Pk0L0
0`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700D08>`700@0oooo023/1`0Pk0L0oooo1`0P
k0L20?ooo`H08>`700<0oooo023/1`3oool00`3oool00`0Pk0L0oooo0?ooo`0=0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0C@3oool5
023/1`<0oooo00<08>`70000000Pk0L01@0Pk0L00`3oool08>`7023/1`09023/1`030?ooo`0Pk0L0
8>`700/08>`700@0oooo023/1`0Pk0L0oooo1`0Pk0L20?ooo`H08>`700<0oooo023/1`3oool00`3o
ool00`0Pk0L0oooo0?ooo`0=0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04`3o
ool00140oooo00<000000?ooo`3oool0C@3oool5023/1`<0oooo00<08>`70000000Pk0L01@0Pk0L0
0`3oool08>`7023/1`09023/1`030?ooo`0Pk0L08>`700/08>`700@0oooo023/1`0Pk0L0oooo1`0P
k0L20?ooo`H08>`700<0oooo023/1`3oool00`3oool00`0Pk0L0oooo0?ooo`0=0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0C@3oool5
023/1`<0oooo00<08>`70000000Pk0L01@0Pk0L00`3oool08>`7023/1`0G023/1`040?ooo`0Pk0L0
8>`70?ooo`L08>`70P3oool6023/1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool03@3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0
oooo04d0oooo1@0Pk0L30?ooo`03023/1`0000008>`700D08>`700<0oooo023/1`0Pk0L05P0Pk0L0
1@3oool08>`7023/1`0Pk0L0oooo00L08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`70?oo
o`030?ooo`03023/1`3oool0oooo00d0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0C0?ooo`004@3oool00`000000oooo0?ooo`1=0?ooo`H08>`70P3oool00`0Pk0L00000023/1`05
023/1`030?ooo`0Pk0L08>`701H08>`700D0oooo023/1`0Pk0L08>`70?ooo`07023/1`030?ooo`0P
k0L08>`700D08>`700<0oooo023/1`3oool00`3oool00`0Pk0L0oooo0?ooo`0=0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0C@3oool6
023/1`80oooo00<08>`70000000Pk0L01@0Pk0L00`3oool08>`7023/1`0F023/1`050?ooo`0Pk0L0
8>`7023/1`3oool01`0Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L0oooo00<0oooo00<0
8>`70?ooo`3oool03@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A
0?ooo`030000003oool0oooo04d0oooo1P0Pk0L20?ooo`03023/1`0000008>`700D08>`700<0oooo
023/1`0Pk0L05P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00L08>`700<0oooo023/1`0Pk0L01@0P
k0L00`3oool08>`70?ooo`030?ooo`03023/1`3oool0oooo00d0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1=0?ooo`H08>`70P3oool0
0`0Pk0L00000023/1`05023/1`030?ooo`0Pk0L08>`701H08>`700D0oooo023/1`0Pk0L08>`70?oo
o`07023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`3oool00`3oool00`0Pk0L0oooo0?oo
o`0=0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140oooo00<00000
0?ooo`3oool0C@3oool6023/1`80oooo00<08>`70000000Pk0L01@0Pk0L00`3oool08>`7023/1`0F
023/1`050?ooo`0Pk0L08>`7023/1`3oool01`0Pk0L0103oool08>`7023/1`3oool4023/1`030?oo
o`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool03@3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04d0oooo1P0Pk0L20?ooo`03023/1`00
00008>`700D08>`700<0oooo023/1`0Pk0L05P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00L08>`7
00@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`70?ooo`030?ooo`03023/1`3oool0oooo00d0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo
0?ooo`1=0?ooo`H08>`70P3oool00`0Pk0L00000023/1`05023/1`030?ooo`0Pk0L08>`701H08>`7
00D0oooo023/1`0Pk0L08>`70?ooo`07023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/
1`3oool00`3oool00`0Pk0L0oooo0?ooo`0=0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool04`3oool00140oooo00<000000?ooo`3oool0C@3oool6023/1`80oooo00<08>`70?ooo`0P
k0L01@0Pk0L00`3oool08>`7023/1`0F023/1`050?ooo`0Pk0L08>`7023/1`3oool01`0Pk0L0103o
ool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool03@3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo
04d0oooo1P0Pk0L20?ooo`03023/1`3oool08>`700D08>`700<0oooo023/1`0Pk0L05P0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00L08>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`70?oo
o`030?ooo`03023/1`3oool0oooo00d0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0C0?ooo`004@3oool00`000000oooo0?ooo`1=0?ooo`H08>`70P3oool00`0Pk0L0oooo023/1`05
023/1`030?ooo`0Pk0L08>`701H08>`700D0oooo023/1`0Pk0L08>`70?ooo`07023/1`040?ooo`0P
k0L08>`70?ooo`@08>`700<0oooo023/1`3oool00`3oool00`0Pk0L0oooo0?ooo`0=0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0C@3o
ool6023/1`80oooo00<08>`70?ooo`0Pk0L01@0Pk0L00`3oool08>`7023/1`0F023/1`050?ooo`0P
k0L08>`7023/1`3oool01`0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0oooo00<0
oooo00<08>`70?ooo`3oool03@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0
oooo000A0?ooo`030000003oool0oooo04d0oooo0`0Pk0L00`3oool08>`7023/1`020?ooo`03023/
1`3oool08>`700D08>`700<0oooo023/1`0Pk0L05P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00L0
8>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`70?ooo`030?ooo`03023/1`3oool0oooo
00d0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000
oooo0?ooo`1=0?ooo`808>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`05023/
1`030?ooo`0Pk0L08>`701H08>`700D0oooo023/1`0Pk0L08>`70?ooo`07023/1`040?ooo`0Pk0L0
8>`70?ooo`@08>`700<0oooo023/1`3oool00`3oool00`0Pk0L0oooo0?ooo`0=0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0C@3oool2
023/1`040?ooo`0Pk0L08>`7023/1`80oooo00@08>`70?ooo`0Pk0L0oooo100Pk0L00`3oool08>`7
023/1`0F023/1`050?ooo`0Pk0L08>`7023/1`3oool01`0Pk0L0103oool08>`7023/1`3oool4023/
1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool03@3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04d0oooo0P0Pk0L0103oool0
8>`7023/1`0Pk0L20?ooo`04023/1`3oool08>`70?ooo`@08>`700<0oooo023/1`0Pk0L05P0Pk0L0
1@3oool08>`7023/1`0Pk0L0oooo00L08>`700@0oooo023/1`0Pk0L0oooo100Pk0L00`3oool08>`7
0?ooo`030?ooo`03023/1`3oool0oooo00d0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1=0?ooo`808>`700@0oooo023/1`0Pk0L08>`7
0P3oool00`0Pk0L0oooo023/1`05023/1`030?ooo`0Pk0L08>`701H08>`700D0oooo023/1`0Pk0L0
8>`70?ooo`07023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo023/1`3oool00`3oool00`0P
k0L0oooo0?ooo`0=0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140
oooo00<000000?ooo`3oool0C@3oool2023/1`040?ooo`0Pk0L08>`7023/1`80oooo00<08>`70?oo
o`0Pk0L01@0Pk0L00`3oool08>`7023/1`0F023/1`050?ooo`0Pk0L08>`7023/1`3oool01`0Pk0L0
103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool03P3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0
oooo04d0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`03023/1`3oool08>`700D08>`700<0
oooo023/1`0Pk0L05P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00L08>`700@0oooo023/1`0Pk0L0
oooo100Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo00h0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1=0?ooo`808>`7
00@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`05023/1`030?ooo`0Pk0L08>`701H0
8>`700D0oooo023/1`0Pk0L08>`70?ooo`07023/1`040?ooo`0Pk0L08>`70?ooo`@08>`700<0oooo
023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`0>0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0C@3oool2023/1`040?ooo`0Pk0L08>`7
023/1`80oooo00<08>`70?ooo`0Pk0L01@0Pk0L00`3oool08>`7023/1`0F023/1`050?ooo`0Pk0L0
8>`7023/1`3oool01`0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0oooo0080oooo
00<08>`70?ooo`3oool03P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo
000A0?ooo`030000003oool0oooo04d0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`03023/
1`3oool08>`700D08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`0=023/1`050?oo
o`0Pk0L08>`7023/1`3oool01`0Pk0L0103oool08>`7023/1`3oool4023/1`030?ooo`0Pk0L0oooo
0080oooo00<08>`70?ooo`3oool03P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
01<0oooo000A0?ooo`030000003oool0oooo04d0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?oo
o`03023/1`3oool08>`700D08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`0=023/
1`050?ooo`0Pk0L08>`7023/1`3oool01`0Pk0L01P3oool08>`7023/1`3oool08>`70?ooo`808>`7
00<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`0>0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0C@3oool2023/1`040?ooo`0P
k0L08>`7023/1`80oooo00<08>`70?ooo`0Pk0L01@0Pk0L00`3oool08>`7023/1`06023/1`030?oo
o`0Pk0L08>`700d08>`700D0oooo023/1`0Pk0L08>`70?ooo`07023/1`060?ooo`0Pk0L08>`70?oo
o`0Pk0L0oooo0`0Pk0L40?ooo`03023/1`3oool0oooo00h0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1=0?ooo`808>`700@0oooo023/
1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`05023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo
023/1`0Pk0L03@0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00L08>`700H0oooo023/1`0Pk0L0oooo
023/1`3oool3023/1`@0oooo00<08>`70?ooo`3oool03P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04d0oooo0P0Pk0L0103oool08>`7
023/1`0Pk0L20?ooo`03023/1`3oool08>`700D08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool0
8>`7023/1`0=023/1`050?ooo`0Pk0L08>`7023/1`3oool01`0Pk0L01P3oool08>`7023/1`3oool0
8>`70?ooo`<08>`7103oool00`0Pk0L0oooo0?ooo`0>0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool04`3oool00140oooo00<000000?ooo`3oool0C@3oool2023/1`040?ooo`0Pk0L0
8>`7023/1`80oooo00<08>`70?ooo`0Pk0L01@0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0P
k0L08>`700X08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3oool08>`7023/1`05023/1`060?oo
o`0Pk0L08>`70?ooo`0Pk0L0oooo0`0Pk0L40?ooo`03023/1`3oool0oooo00h0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1=0?ooo`80
8>`700@0oooo023/1`0Pk0L08>`70P3oool00`0Pk0L0oooo023/1`05023/1`030?ooo`0Pk0L08>`7
00H08>`700<0oooo023/1`0Pk0L02P0Pk0L0103oool08>`7023/1`3oool3023/1`030?ooo`0Pk0L0
8>`700D08>`700H0oooo023/1`0Pk0L0oooo023/1`3oool3023/1`@0oooo00<08>`70?ooo`3oool0
3P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003o
ool0oooo04d0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`03023/1`3oool08>`700D08>`7
00<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700@08>`7
00<0oooo023/1`0Pk0L01@0Pk0L0103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700@0
oooo00<08>`70?ooo`3oool03P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0
oooo000A0?ooo`030000003oool0oooo04d0oooo0P0Pk0L0103oool08>`7023/1`0Pk0L20?ooo`03
023/1`3oool08>`700D08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`0:023/1`03
0?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L01@0Pk0L0103oool08>`7023/1`3oool2023/
1`030?ooo`0Pk0L08>`700@0oooo00<08>`70?ooo`3oool03P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04h0oooo00<08>`70?ooo`0P
k0L00P0Pk0L20?ooo`03023/1`3oool08>`700D08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool0
8>`7023/1`0:023/1`030?ooo`0Pk0L08>`700`08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L00`3o
ool08>`7023/1`040?ooo`03023/1`3oool0oooo00h0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1>0?ooo`03023/1`3oool08>`70080
8>`70P3oool00`0Pk0L0oooo023/1`05023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0P
k0L02P0Pk0L00`3oool08>`7023/1`0<023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo023/
1`3oool00`3oool00`0Pk0L0oooo0?ooo`0>0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool04`3oool00140oooo00<000000?ooo`3oool0CP3oool00`0Pk0L0oooo023/1`02023/1`80
oooo00<08>`70?ooo`0Pk0L01@0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`701T0
8>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3oool08>`70?ooo`030?ooo`03023/1`3oool0oooo
00h0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000
oooo0?ooo`1>0?ooo`03023/1`3oool08>`700808>`70P3oool00`0Pk0L0oooo023/1`05023/1`03
0?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L06@0Pk0L0103oool08>`7023/1`3oool3023/
1`030?ooo`0Pk0L0oooo00<0oooo00<08>`70?ooo`3oool03P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04h0oooo00<08>`70?ooo`0P
k0L00P0Pk0L20?ooo`03023/1`3oool08>`700D08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool0
8>`7023/1`0I023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo023/1`3oool00`3oool00`0P
k0L0oooo0?ooo`0>0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140
oooo00<000000?ooo`3oool0CP3oool00`0Pk0L0oooo023/1`02023/1`80oooo00<08>`70?ooo`0P
k0L01@0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`701T08>`700@0oooo023/1`0P
k0L0oooo0`0Pk0L00`3oool08>`70?ooo`030?ooo`03023/1`3oool0oooo00h0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1>0?ooo`03
023/1`3oool08>`700808>`70P3oool00`0Pk0L0oooo023/1`05023/1`030?ooo`0Pk0L08>`700H0
8>`700<0oooo023/1`0Pk0L06@0Pk0L0103oool08>`7023/1`3oool3023/1`030?ooo`0Pk0L0oooo
00<0oooo00<08>`70?ooo`3oool03P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
01<0oooo000A0?ooo`030000003oool0oooo04h0oooo00<08>`70?ooo`0Pk0L00P0Pk0L20?ooo`03
023/1`3oool08>`700D08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`0I023/1`04
0?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo023/1`3oool00`3oool00`0Pk0L0oooo0?ooo`0>0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140oooo00<000000?ooo`3o
ool0CP3oool00`0Pk0L0oooo023/1`02023/1`80oooo00<08>`70?ooo`0Pk0L01@0Pk0L00`3oool0
8>`7023/1`06023/1`030?ooo`0Pk0L08>`701T08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3o
ool08>`70?ooo`030?ooo`03023/1`3oool0oooo00h0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1>0?ooo`D08>`70P3oool00`0Pk0L0
oooo023/1`0>023/1`030?ooo`0Pk0L08>`701T08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3o
ool08>`70?ooo`030?ooo`03023/1`3oool0oooo00h0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1>0?ooo`D08>`70P3oool00`0Pk0L0
oooo023/1`0>023/1`030?ooo`0Pk0L08>`701T08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3o
ool08>`70?ooo`030?ooo`03023/1`3oool0oooo00h0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1>0?ooo`D08>`70P3oool00`0Pk0L0
oooo023/1`0>023/1`030?ooo`0Pk0L08>`701T08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3o
ool08>`70?ooo`030?ooo`03023/1`3oool0oooo00h0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1>0?ooo`D08>`70P3oool00`0Pk0L0
oooo023/1`0>023/1`030?ooo`0Pk0L08>`701T08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3o
ool08>`70?ooo`030?ooo`03023/1`3oool0oooo00h0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1>0?ooo`D08>`70P3oool00`0Pk0L0
oooo023/1`0Z023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo023/1`3oool00`3oool00`0P
k0L0oooo0?ooo`0>0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140
oooo00<000000?ooo`3oool0CP3oool5023/1`80oooo00<08>`70?ooo`0Pk0L0:P0Pk0L0103oool0
8>`7023/1`3oool3023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool03`3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04h0
oooo1@0Pk0L20?ooo`03023/1`3oool08>`702X08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool0
8>`70?ooo`020?ooo`03023/1`3oool0oooo00l0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0C0?ooo`004@3oool00`000000oooo0?ooo`1>0?ooo`D08>`70P3oool00`0Pk0L0oooo
023/1`0Z023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo
0?ooo`0?0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04`3oool00140oooo00<0
00000?ooo`3oool0CP3oool5023/1`80oooo00<08>`70?ooo`0Pk0L0:P0Pk0L00`3oool08>`7023/
1`04023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool03`3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04h0oooo1@0Pk0L2
0?ooo`03023/1`3oool08>`700P08>`700<0oooo023/1`0Pk0L07`0Pk0L00`3oool08>`7023/1`04
023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool03`3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo04h0oooo1@0Pk0L20?oo
o`03023/1`3oool08>`700P08>`700<0oooo023/1`0Pk0L07`0Pk0L00`3oool08>`7023/1`04023/
1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool03`3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo01<0oooo000@0?ooo`030000003oool0oooo04l0oooo1@0Pk0L20?ooo`03
023/1`3oool08>`700P08>`700<0oooo023/1`0Pk0L07`0Pk0L00`3oool08>`7023/1`04023/1`03
0?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool03`3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo01<0oooo000@0?ooo`030000003oool0oooo04l0oooo1@0Pk0L20?ooo`03023/
1`3oool08>`700P08>`700<0oooo023/1`0Pk0L07`0Pk0L00`3oool08>`7023/1`04023/1`030?oo
o`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool03`3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo01<0oooo000@0?ooo`030000003oool0oooo04l0oooo1@0Pk0L20?ooo`03023/1`3o
ool08>`700P08>`700<0oooo023/1`0Pk0L07`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0P
k0L0oooo0080oooo00<08>`70?ooo`3oool03`3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo01<0oooo000@0?ooo`030000003oool0oooo04l0oooo1@0Pk0L20?ooo`03023/1`3oool0
8>`700P08>`700<0oooo023/1`0Pk0L07`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L0
oooo0080oooo00<08>`70?ooo`3oool03`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo01<0oooo000@0?ooo`030000003oool0oooo04l0oooo1@0Pk0L20?ooo`03023/1`3oool08>`7
00P08>`700<0oooo023/1`0Pk0L07`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L0oooo
0080oooo00<08>`70?ooo`3oool03`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
01<0oooo000@0?ooo`030000003oool0oooo04l0oooo1@0Pk0L20?ooo`03023/1`3oool08>`700P0
8>`700<0oooo023/1`0Pk0L07`0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L0oooo0080
oooo00<08>`70?ooo`3oool03`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0
oooo000@0?ooo`030000003oool0oooo04l0oooo1@0Pk0L20?ooo`03023/1`3oool08>`700P08>`7
00<0oooo023/1`0Pk0L07`0Pk0L00`3oool08>`7023/1`05023/1`@0oooo00<08>`70?ooo`3oool0
3`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000@0?ooo`030000003o
ool0oooo04l0oooo1@0Pk0L20?ooo`03023/1`3oool08>`700P08>`700<0oooo023/1`0Pk0L07`0P
k0L00`3oool08>`7023/1`05023/1`@0oooo00<08>`70?ooo`3oool03`3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo01<0oooo000@0?ooo`030000003oool0oooo04l0oooo1@0Pk0L2
0?ooo`03023/1`3oool0oooo00P08>`700<0oooo023/1`0Pk0L07`0Pk0L00`3oool08>`7023/1`05
023/1`@0oooo00<08>`70?ooo`3oool03`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo01<0oooo000@0?ooo`030000003oool0oooo04l0oooo1P0Pk0L0103oool08>`7023/1`3oool8
023/1`030?ooo`0Pk0L08>`701l08>`700<0oooo023/1`0Pk0L01@0Pk0L40?ooo`03023/1`3oool0
oooo00l0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`00403oool00`00
0000oooo0?ooo`1?0?ooo`H08>`700@0oooo023/1`0Pk0L0oooo200Pk0L00`3oool08>`7023/1`0W
023/1`@0oooo00<08>`70?ooo`3oool03`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo01<0oooo000@0?ooo`030000003oool0oooo04l0oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0
oooo00808>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`0W023/1`@0oooo00<08>`7
0?ooo`3oool03`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?oo
o`030000003oool0oooo04l0oooo0P0Pk0L01@3oool08>`7023/1`0Pk0L0oooo00808>`700<0oooo
023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`09023/1`030?ooo`0Pk0L08>`701D08>`700<0oooo
023/1`0Pk0L00`0Pk0L40?ooo`03023/1`3oool0oooo00l0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1?0?ooo`808>`700D0oooo023/
1`0Pk0L08>`70?ooo`02023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/1`0Pk0L02@0Pk0L0
0`3oool08>`7023/1`0E023/1`030?ooo`0Pk0L08>`700<08>`7103oool00`0Pk0L0oooo0?ooo`0?
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool00100oooo00<000000?oo
o`3oool0C`3oool2023/1`080?ooo`0Pk0L08>`7023/1`3oool00000023/1`3oool8023/1`030?oo
o`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L03@0Pk0L00`3oool08>`7023/1`04023/1`030?oo
o`0Pk0L08>`700<08>`7103oool00`0Pk0L0oooo0?ooo`0?0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0C`3oool2023/1`080?ooo`0P
k0L08>`7023/1`3oool00000023/1`3oool8023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/
1`0Pk0L03@0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700<08>`7103oool00`0P
k0L0oooo0?ooo`0?0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool00100
oooo00<000000?ooo`3oool0C`3oool2023/1`080?ooo`0Pk0L08>`7023/1`3oool00000023/1`3o
ool8023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/
1`06023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L00`0Pk0L40?ooo`03023/1`3o
ool0oooo00l0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool0
0`000000oooo0?ooo`1?0?ooo`808>`700P0oooo023/1`0Pk0L08>`70?ooo`0000008>`70?ooo`P0
8>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700H0
8>`700<0oooo023/1`0Pk0L0100Pk0L0103oool08>`7023/1`3oool2023/1`@0oooo00<08>`70?oo
o`3oool03`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`03
0000003oool0oooo04l0oooo0P0Pk0L0203oool08>`7023/1`0Pk0L0oooo0000000Pk0L0oooo200P
k0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L01P0P
k0L00`3oool08>`7023/1`04023/1`040?ooo`0Pk0L08>`70?ooo`808>`7103oool00`0Pk0L0oooo
0?ooo`0?0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool00100oooo00<0
00000?ooo`3oool0C`3oool2023/1`080?ooo`0Pk0L08>`7023/1`3oool00000023/1`3oool8023/
1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`06023/
1`030?ooo`0Pk0L08>`700@08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L40?ooo`03023/1`3oool0
oooo00l0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`00
0000oooo0?ooo`1?0?ooo`808>`700P0oooo023/1`0Pk0L08>`70?ooo`0000008>`70?ooo`P08>`7
00<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700H08>`7
00<0oooo023/1`0Pk0L0100Pk0L0103oool08>`7023/1`3oool2023/1`@0oooo00<08>`70?ooo`3o
ool03`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000
003oool0oooo0500oooo00<08>`70?ooo`0Pk0L00P0Pk0L0103oool00000023/1`3oool8023/1`03
0?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`70?ooo`06023/1`03
0?ooo`0Pk0L08>`700@08>`700@0oooo023/1`0Pk0L0oooo0P0Pk0L40?ooo`03023/1`3oool0oooo
00l0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000
oooo0?ooo`1@0?ooo`03023/1`3oool08>`700808>`700@0oooo0000000Pk0L0oooo200Pk0L00`3o
ool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`3oool01P0Pk0L01@3o
ool08>`7023/1`0Pk0L0oooo00808>`700H0oooo023/1`0Pk0L08>`70?ooo`0Pk0L30?ooo`03023/
1`3oool0oooo0100oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403o
ool00`000000oooo0?ooo`1@0?ooo`03023/1`3oool08>`700808>`700@0oooo0000000Pk0L0oooo
200Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`3oool0
2P0Pk0L0103oool08>`7023/1`3oool3023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3o
ool0403oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000
003oool0oooo0500oooo00<08>`70?ooo`0Pk0L00P0Pk0L0103oool00000023/1`3oool8023/1`03
0?ooo`0Pk0L08>`701408>`700<0oooo023/1`3oool02P0Pk0L0103oool08>`7023/1`3oool3023/
1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0403oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0500oooo00<08>`70?ooo`0P
k0L00P0Pk0L0103oool00000023/1`3oool8023/1`030?ooo`0Pk0L08>`701408>`700<0oooo023/
1`3oool02P0Pk0L0103oool08>`7023/1`3oool3023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`7
0?ooo`3oool0403oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?oo
o`030000003oool0oooo0500oooo00<08>`70?ooo`0Pk0L00P0Pk0L0103oool00000023/1`3oool8
023/1`030?ooo`0Pk0L08>`701408>`700<0oooo023/1`3oool02P0Pk0L0103oool08>`7023/1`3o
ool3023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0403oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0500oooo00<08>`7
0?ooo`0Pk0L00P0Pk0L0103oool00000023/1`3oool8023/1`030?ooo`0Pk0L08>`701408>`700<0
oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`<08>`7
00<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`0@0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0D03oool00`0Pk0L0oooo023/
1`02023/1`040?ooo`0000008>`70?ooo`P08>`700<0oooo023/1`0Pk0L04`0Pk0L00`3oool08>`7
023/1`02023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3oool0
8>`70?ooo`020?ooo`03023/1`3oool0oooo0100oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`03023/1`3oool08>`700808>`7
00@0oooo0000000Pk0L0oooo200Pk0L00`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<0
8>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo
0100oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000
oooo0?ooo`1@0?ooo`03023/1`3oool08>`700808>`700@0oooo0000000Pk0L0oooo200Pk0L00`3o
ool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L0
0`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo0100oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0oooo0000
000Pk0L0oooo200Pk0L00`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo
023/1`0Pk0L0oooo0`0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo0100oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@
0?ooo`D08>`700@0oooo0000000Pk0L0oooo200Pk0L00`3oool08>`7023/1`0H023/1`030?ooo`0P
k0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3oool08>`70?ooo`020?ooo`03023/
1`3oool0oooo0100oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403o
ool00`000000oooo0?ooo`1@0?ooo`D08>`700@0oooo0000000Pk0L0oooo200Pk0L00`3oool08>`7
023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3oool0
8>`70?ooo`020?ooo`03023/1`3oool0oooo0100oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0oooo0000000Pk0L0
oooo200Pk0L00`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0P
k0L0oooo0`0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo0100oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D0
8>`700@0oooo0000000Pk0L0oooo200Pk0L00`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`7
00<08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0
oooo0100oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`00
0000oooo0?ooo`1@0?ooo`D08>`700@0oooo0000000Pk0L0oooo200Pk0L00`3oool08>`7023/1`0>
023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`0Pk0L00`0Pk0L0103oool08>`7023/1`3o
ool3023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool0403oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0500oooo1@0Pk0L0
103oool00000023/1`3oool8023/1`030?ooo`0Pk0L08>`700h08>`700<0oooo023/1`0Pk0L01`0P
k0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L08>`70?ooo`<08>`700<0oooo023/1`3oool0
0P3oool00`0Pk0L0oooo0?ooo`0@0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
4P3oool00100oooo00<000000?ooo`3oool0D03oool5023/1`040?ooo`0000008>`70?ooo`P08>`7
00<0oooo023/1`0Pk0L03P0Pk0L00`3oool08>`7023/1`07023/1`030?ooo`0Pk0L08>`700<08>`7
00@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo0100
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo
0?ooo`1@0?ooo`D08>`700@0oooo0000000Pk0L0oooo200Pk0L00`3oool08>`7023/1`0H023/1`03
0?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo0`0Pk0L00`3oool08>`70?ooo`020?oo
o`03023/1`3oool0oooo0100oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?oo
o`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0oooo0000000Pk0L0oooo200Pk0L00`3o
ool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo100Pk0L4
0?ooo`03023/1`3oool0oooo0100oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B
0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0oooo0000000Pk0L0oooo200Pk0L0
0`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo100P
k0L40?ooo`03023/1`3oool0oooo0100oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0oooo0000000Pk0L0oooo200P
k0L00`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0oooo
100Pk0L40?ooo`03023/1`3oool0oooo0100oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0oooo0000000Pk0L0oooo
200Pk0L00`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0Pk0L0
oooo100Pk0L40?ooo`03023/1`3oool0oooo0100oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0oooo0000000Pk0L0
oooo200Pk0L00`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/1`0P
k0L0oooo100Pk0L40?ooo`03023/1`3oool0oooo0100oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0oooo0000000P
k0L0oooo200Pk0L00`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/
1`0Pk0L0oooo100Pk0L40?ooo`03023/1`3oool0oooo0100oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0oooo0000
000Pk0L0oooo200Pk0L00`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo
023/1`0Pk0L0oooo100Pk0L40?ooo`03023/1`3oool0oooo0100oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0oooo
0000000Pk0L0oooo200Pk0L00`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`700@0
oooo023/1`0Pk0L0oooo100Pk0L40?ooo`03023/1`3oool0oooo0100oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0
oooo0000000Pk0L0oooo200Pk0L00`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`7
00<0oooo023/1`0Pk0L01@0Pk0L40?ooo`03023/1`3oool0oooo0100oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0
oooo0000000Pk0L0oooo200Pk0L00`3oool08>`7023/1`0H023/1`030?ooo`0Pk0L08>`700<08>`7
00<0oooo023/1`0Pk0L01@0Pk0L30?ooo`03023/1`3oool0oooo0140oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0
oooo0000000Pk0L0oooo200Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`701<08>`7
00<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`05023/1`<0oooo00<08>`70?ooo`3oool0
4@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003o
ool0oooo0500oooo1@0Pk0L0103oool00000023/1`3oool8023/1`030?ooo`0Pk0L08>`700808>`7
00<0oooo023/1`0Pk0L04`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700D08>`7
0`3oool00`0Pk0L0oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
4P3oool00100oooo00<000000?ooo`3oool0D03oool5023/1`040?ooo`0000008>`70?ooo`P08>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700`08>`7
00<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`05023/1`<0oooo00<08>`70?ooo`3oool0
4@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003o
ool0oooo0500oooo1@0Pk0L0103oool00000023/1`3oool8023/1`030?ooo`0Pk0L08>`700808>`7
00<0oooo023/1`3oool0100Pk0L00`3oool08>`7023/1`0<023/1`030?ooo`0Pk0L08>`700<08>`7
00<0oooo023/1`0Pk0L01@0Pk0L30?ooo`03023/1`3oool0oooo0140oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1@0?ooo`D08>`700@0
oooo0000000Pk0L0oooo200Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L0oooo00@08>`7
00<0oooo023/1`0Pk0L0300Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700D08>`7
0`3oool00`0Pk0L0oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
4P3oool00100oooo00<000000?ooo`3oool0D03oool5023/1`040?ooo`0000008>`70?ooo`P08>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`04023/1`030?ooo`0Pk0L08>`700`08>`7
00<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`05023/1`<0oooo00<08>`70?ooo`3oool0
4@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003o
ool0oooo0500oooo1@0Pk0L0103oool00000023/1`3oool=023/1`030?ooo`0Pk0L08>`700@08>`7
00<0oooo023/1`0Pk0L0300Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700D08>`7
0`3oool00`0Pk0L0oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
4P3oool00100oooo00<000000?ooo`3oool0D03oool5023/1`040?ooo`0000008>`70?ooo`d08>`7
00<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`0<023/1`030?ooo`0Pk0L08>`700<08>`7
00<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`030?ooo`03023/1`3oool0oooo0140oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?oo
o`1@0?ooo`D08>`700@0oooo0000000Pk0L0oooo3@0Pk0L00`3oool08>`7023/1`04023/1`030?oo
o`0Pk0L08>`700`08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/1`02023/1`030?oo
o`0Pk0L08>`700<0oooo00<08>`70?ooo`3oool04@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0500oooo0P0Pk0L01`3oool08>`7023/
1`3oool00000023/1`3oool03@0Pk0L00`3oool08>`7023/1`0C023/1`030?ooo`0Pk0L08>`700<0
8>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`030?ooo`03023/1`3oool0oooo0140
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo
0?ooo`1@0?ooo`808>`700L0oooo023/1`0Pk0L0oooo0000000Pk0L0oooo02<08>`700<0oooo023/
1`0Pk0L00`0Pk0L00`3oool08>`7023/1`02023/1`030?ooo`0Pk0L08>`700<0oooo00<08>`70?oo
o`3oool04@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`03
0000003oool0oooo0500oooo0P0Pk0L01`3oool08>`7023/1`3oool00000023/1`3oool08`0Pk0L0
0`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700808>`700<0oooo023/1`0Pk0L00`3oool0
0`0Pk0L0oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool0
0100oooo00<000000?ooo`3oool0D@3oool0200Pk0L0oooo023/1`0Pk0L0oooo0000000Pk0L0oooo
8`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`3oool0
0P3oool00`0Pk0L0oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
4P3oool00100oooo00<000000?ooo`3oool0D@3oool0200Pk0L0oooo023/1`0Pk0L0oooo0000000P
k0L0oooo8`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/
1`3oool00P3oool00`0Pk0L0oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool04P3oool00100oooo00<000000?ooo`3oool0D@3oool0200Pk0L0oooo023/1`0Pk0L0oooo
0000000Pk0L0oooo8`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<08>`700<0
oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0D@3oool0200Pk0L0oooo023/1`0P
k0L0oooo0000000Pk0L0oooo8`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700<0
8>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`0A0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0D@3oool0200Pk0L0oooo
023/1`0Pk0L0oooo0000000Pk0L0oooo8`0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0
8>`700<08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`0A0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0D@3oool00`0P
k0L0oooo023/1`02023/1`030000000Pk0L0oooo02<08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3o
ool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool04@3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0540
oooo00<08>`70?ooo`0Pk0L00P0Pk0L00`0000008>`70?ooo`0S023/1`030?ooo`0Pk0L08>`700<0
8>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`70?ooo`020?ooo`03023/1`3oool0oooo0140
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo
0?ooo`1A0?ooo`03023/1`3oool08>`700808>`700<00000023/1`3oool0700Pk0L00`3oool08>`7
023/1`04023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`3oool00`0Pk0L00`3oool08>`7
0?ooo`020?ooo`03023/1`3oool0oooo0140oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1A0?ooo`03023/1`3oool08>`700808>`700<0
0000023/1`3oool0700Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700D08>`700H0
oooo023/1`0Pk0L08>`70?ooo`0Pk0L30?ooo`03023/1`3oool0oooo0140oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1A0?ooo`03023/
1`3oool08>`700808>`700<00000023/1`3oool0700Pk0L00`3oool08>`7023/1`04023/1`030?oo
o`0Pk0L08>`700D08>`700H0oooo023/1`0Pk0L08>`70?ooo`0Pk0L30?ooo`03023/1`3oool0oooo
0140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000
oooo0?ooo`1A0?ooo`03023/1`3oool08>`700808>`700<00000023/1`3oool0700Pk0L00`3oool0
8>`7023/1`04023/1`030?ooo`0Pk0L08>`700D08>`700H0oooo023/1`0Pk0L08>`70?ooo`0Pk0L3
0?ooo`03023/1`3oool0oooo0140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B
0?ooo`00403oool00`000000oooo0?ooo`1A0?ooo`03023/1`3oool08>`700808>`700<00000023/
1`3oool0700Pk0L00`3oool08>`7023/1`0<023/1`060?ooo`0Pk0L08>`7023/1`3oool08>`70`3o
ool00`0Pk0L0oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3o
ool00100oooo00<000000?ooo`3oool0D@3oool5023/1`030000000Pk0L0oooo01`08>`700<0oooo
023/1`0Pk0L0300Pk0L00`3oool08>`7023/1`02023/1`@0oooo00<08>`70?ooo`3oool04@3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo
0540oooo1@0Pk0L00`0000008>`70?ooo`0L023/1`030?ooo`0Pk0L08>`700`08>`700<0oooo023/
1`0Pk0L00P0Pk0L40?ooo`03023/1`3oool0oooo0140oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1A0?ooo`D08>`700<00000023/1`3o
ool0700Pk0L00`3oool08>`7023/1`0<023/1`030?ooo`0Pk0L08>`700808>`70`3oool00`0Pk0L0
oooo0?ooo`0B0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool00100oooo
00<000000?ooo`3oool0D@3oool5023/1`030000000Pk0L0oooo01`08>`700<0oooo023/1`0Pk0L0
300Pk0L00`3oool08>`7023/1`02023/1`<0oooo00<08>`70?ooo`3oool04P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0540oooo1@0P
k0L00`0000008>`70?ooo`0L023/1`030?ooo`0Pk0L08>`700`08>`700<0oooo023/1`0Pk0L00P0P
k0L30?ooo`03023/1`3oool0oooo0180oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`0B0?ooo`00403oool00`000000oooo0?ooo`1A0?ooo`D08>`700<00000023/1`3oool0:`0Pk0L0
0`3oool08>`7023/1`02023/1`<0oooo00<08>`70?ooo`3oool04P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0540oooo1@0Pk0L00`00
00008>`70?ooo`0[023/1`030?ooo`0Pk0L08>`700808>`70`3oool00`0Pk0L0oooo0?ooo`0B0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3o
ool0D@3oool5023/1`030000000Pk0L0oooo02/08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`03
023/1`3oool0oooo0180oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00
403oool00`000000oooo0?ooo`1A0?ooo`D08>`700<00000023/1`3oool0:`0Pk0L00`3oool08>`7
023/1`02023/1`<0oooo00<08>`70?ooo`3oool04P3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0540oooo1@0Pk0L00`0000008>`7023/
1`0[023/1`030?ooo`0Pk0L08>`700808>`70`3oool00`0Pk0L0oooo0?ooo`0B0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0D@3oool5
023/1`030000000Pk0L08>`702/08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`03023/1`3oool0
oooo0180oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`00
0000oooo0?ooo`1A0?ooo`D08>`700<00000023/1`0Pk0L0:`0Pk0L00`3oool08>`7023/1`02023/
1`<0oooo00<08>`70?ooo`3oool04P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0180oooo000@0?ooo`030000003oool0oooo0540oooo1@0Pk0L00`0000008>`7023/1`0[023/1`03
0?ooo`0Pk0L08>`700808>`70`3oool00`0Pk0L0oooo0?ooo`0B0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0D@3oool5023/1`030000
003oool08>`702/08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`03023/1`3oool0oooo0180oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?oo
o`1A0?ooo`D08>`700<000000?ooo`0Pk0L0:`0Pk0L00`3oool08>`7023/1`02023/1`<0oooo00<0
8>`70?ooo`3oool04P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@
0?ooo`030000003oool0oooo0540oooo1@0Pk0L00`000000oooo023/1`0[023/1`030?ooo`0Pk0L0
8>`700808>`70`3oool00`0Pk0L0oooo0?ooo`0B0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0D@3oool5023/1`030000003oool08>`7
02/08>`700<0oooo023/1`0Pk0L00P0Pk0L30?ooo`03023/1`3oool0oooo0180oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1A0?ooo`D0
8>`700<000000?ooo`0Pk0L0:`0Pk0L00`3oool08>`7023/1`02023/1`<0oooo00<08>`70?ooo`3o
ool04P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000
003oool0oooo0540oooo1@0Pk0L00`000000oooo023/1`0[023/1`030?ooo`0Pk0L08>`700808>`7
0`3oool00`0Pk0L0oooo0?ooo`0B0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
4P3oool00100oooo00<000000?ooo`3oool0D@3oool5023/1`030000003oool08>`702/08>`700<0
oooo023/1`0Pk0L00P0Pk0L30?ooo`03023/1`3oool0oooo0180oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1A0?ooo`D08>`700<00000
0?ooo`0Pk0L0:`0Pk0L00`3oool08>`7023/1`02023/1`<0oooo00<08>`70?ooo`3oool04P3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo
0540oooo1@0Pk0L00`000000oooo023/1`0[023/1`030?ooo`0Pk0L08>`700808>`70`3oool00`0P
k0L0oooo0?ooo`0B0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool00100
oooo00<000000?ooo`3oool0D@3oool5023/1`030000003oool08>`702/08>`700<0oooo023/1`0P
k0L00P0Pk0L30?ooo`03023/1`3oool0oooo0180oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1A0?ooo`D08>`700<000000?ooo`0Pk0L0
:`0Pk0L00`3oool08>`70?ooo`02023/1`<0oooo00<08>`70?ooo`3oool04P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0540oooo1@0P
k0L00`000000oooo023/1`0]023/1`030?ooo`0Pk0L08>`700<0oooo00<08>`70?ooo`3oool04P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0
oooo0540oooo1@0Pk0L00`000000oooo023/1`0]023/1`030?ooo`0Pk0L08>`700<0oooo00<08>`7
0?ooo`3oool04P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?oo
o`030000003oool0oooo0540oooo1@0Pk0L00`000000oooo023/1`0]023/1`030?ooo`0Pk0L08>`7
00<0oooo00<08>`70?ooo`3oool04P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0180oooo000@0?ooo`030000003oool0oooo0540oooo1@0Pk0L00`000000oooo023/1`0]023/1`03
0?ooo`0Pk0L08>`700<0oooo00<08>`70?ooo`3oool04P3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0540oooo1@0Pk0L00`000000oooo
023/1`0^023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool04P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0580oooo100P
k0L00`000000oooo023/1`0^023/1`030?ooo`0Pk0L0oooo0080oooo00<08>`70?ooo`3oool04P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0
oooo0580oooo100Pk0L00`000000oooo023/1`0X023/1`030?ooo`0Pk0L08>`700<08>`700D0oooo
023/1`3oool0oooo023/1`0E0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3o
ool00100oooo00<000000?ooo`3oool0DP3oool4023/1`030000003oool08>`702P08>`700<0oooo
023/1`0Pk0L00`0Pk0L01@3oool08>`70?ooo`3oool08>`701D0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1B0?ooo`@08>`700<00000
0?ooo`0Pk0L0:00Pk0L00`3oool08>`7023/1`03023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L05@3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0
oooo0580oooo00H08>`70?ooo`0Pk0L08>`70000003ooolY023/1`030?ooo`0Pk0L08>`700<08>`7
00D0oooo023/1`3oool0oooo023/1`0E0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool04P3oool00100oooo00<000000?ooo`3oool0DP3oool01P0Pk0L0oooo023/1`0Pk0L000000?oo
obT08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`03023/1`3oool0oooo01<0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1B0?ooo`06
023/1`3oool08>`7023/1`000000oooo:@0Pk0L00`3oool08>`7023/1`04023/1`<0oooo00<08>`7
0?ooo`3oool04`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000@0?oo
o`030000003oool0oooo0580oooo00P08>`70?ooo`0Pk0L08>`70000003oool08>`70?ooobL08>`7
00<0oooo023/1`0Pk0L0100Pk0L30?ooo`03023/1`3oool0oooo01<0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1B0?ooo`08023/1`3o
ool08>`7023/1`000000oooo023/1`3ooolW023/1`030?ooo`0Pk0L08>`700@08>`70`3oool00`0P
k0L0oooo0?ooo`0C0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool00100
oooo00<000000?ooo`3oool0DP3oool0200Pk0L0oooo023/1`0Pk0L000000?ooo`0Pk0L0oooo9`0P
k0L00`3oool08>`7023/1`04023/1`<0oooo00<08>`70?ooo`3oool04`3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0580oooo00P08>`7
0?ooo`0Pk0L08>`70000003oool08>`70?ooobL08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`03
023/1`3oool0oooo01<0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00
403oool00`000000oooo0?ooo`1B0?ooo`08023/1`3oool08>`7023/1`000000oooo023/1`3ooolW
023/1`030?ooo`0Pk0L08>`700@08>`70`3oool00`0Pk0L0oooo0?ooo`0C0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0DP3oool0200P
k0L0oooo023/1`0Pk0L000000?ooo`0Pk0L0oooo9`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo
00<08>`70?ooo`3oool04`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo
000@0?ooo`030000003oool0oooo0580oooo100Pk0L010000000oooo023/1`3ooolW023/1`030?oo
o`0Pk0L08>`700@08>`70`3oool00`0Pk0L0oooo0?ooo`0C0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0DP3oool4023/1`040000003o
ool08>`70?ooobL08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`03023/1`3oool0oooo01<0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?oo
o`1B0?ooo`@08>`700@000000?ooo`0Pk0L0oooo9`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo
00<08>`70?ooo`3oool04`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo
000?0?ooo`030000003oool0oooo05<0oooo100Pk0L010000000oooo023/1`3ooolW023/1`030?oo
o`0Pk0L08>`700@08>`70`3oool00`0Pk0L0oooo0?ooo`0C0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool0D`3oool4023/1`040000003o
ool08>`70?ooobL08>`700<0oooo023/1`0Pk0L0100Pk0L30?ooo`03023/1`3oool0oooo01<0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?oo
o`1C0?ooo`@08>`700@000000?ooo`0Pk0L0oooo9`0Pk0L00`3oool08>`7023/1`04023/1`<0oooo
00<08>`70?ooo`3oool04`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo
000?0?ooo`030000003oool0oooo05<0oooo100Pk0L010000000oooo023/1`3ooolW023/1`030?oo
o`0Pk0L08>`700@08>`70`3oool00`0Pk0L0oooo0?ooo`0C0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool0D`3oool4023/1`040000003o
ool08>`70?oooaL08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`06023/1`030?oo
o`0Pk0L08>`700@08>`70`3oool00`0Pk0L0oooo0?ooo`0C0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool0D`3oool4023/1`040000003o
ool08>`70?oooaL08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`06023/1`030?oo
o`0Pk0L08>`700@08>`70`3oool00`0Pk0L0oooo0?ooo`0C0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool0D`3oool4023/1`040000003o
ool08>`70?oooaL08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`08023/1`030?oo
o`0Pk0L08>`700@08>`70`3oool00`0Pk0L0oooo0?ooo`0C0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool0D`3oool5023/1`030?ooo`0P
k0L0oooo01L08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`08023/1`030?ooo`0P
k0L0oooo00@08>`70`3oool00`0Pk0L0oooo0?ooo`0C0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool0D`3oool5023/1`030?ooo`0Pk0L0
oooo01`08>`700<0oooo023/1`3oool0200Pk0L00`3oool08>`70?ooo`04023/1`<0oooo00<08>`7
0?ooo`3oool04`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000?0?oo
o`030000003oool0oooo05<0oooo1@0Pk0L00`3oool08>`70?ooo`0L023/1`030?ooo`0Pk0L0oooo
00P08>`700<0oooo023/1`3oool0100Pk0L30?ooo`03023/1`3oool0oooo01<0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`1C0?ooo`D0
8>`700<0oooo023/1`3oool0700Pk0L00`3oool08>`70?ooo`08023/1`030?ooo`0Pk0L0oooo00@0
8>`70`3oool00`0Pk0L0oooo0?ooo`0C0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool04P3oool000l0oooo00<000000?ooo`3oool0D`3oool5023/1`030?ooo`0Pk0L0oooo01`08>`7
00<0oooo023/1`3oool0200Pk0L00`3oool08>`70?ooo`04023/1`<0oooo00<08>`70?ooo`3oool0
4`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000?0?ooo`030000003o
ool0oooo05<0oooo1@0Pk0L00`3oool08>`70?ooo`0L023/1`030?ooo`0Pk0L0oooo00X08>`700<0
oooo023/1`0Pk0L00P0Pk0L20?ooo`03023/1`3oool0oooo01@0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`1C0?ooo`D08>`700<0oooo
023/1`3oool0700Pk0L00`3oool08>`70?ooo`0:023/1`030?ooo`0Pk0L08>`700808>`70P3oool0
0`0Pk0L0oooo0?ooo`0D0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool0
00l0oooo00<000000?ooo`3oool0D`3oool5023/1`030?ooo`0Pk0L0oooo01`08>`700<0oooo023/
1`3oool02P0Pk0L00`3oool08>`7023/1`02023/1`80oooo00<08>`70?ooo`3oool0503oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000?0?ooo`030000003oool0oooo05<0
oooo1@0Pk0L00`3oool08>`70?ooo`0L023/1`030?ooo`0Pk0L0oooo00X08>`700<0oooo023/1`0P
k0L00P0Pk0L20?ooo`03023/1`3oool0oooo01@0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`1C0?ooo`D08>`700<0oooo023/1`3oool0
5P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo00X08>`700<0oooo023/1`0Pk0L0
0P0Pk0L20?ooo`03023/1`3oool0oooo01@0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`1C0?ooo`D08>`700<0oooo023/1`3oool05P0P
k0L00`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo00X08>`700<0oooo023/1`0Pk0L00P0P
k0L20?ooo`03023/1`3oool0oooo01@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`003`3oool00`000000oooo0?ooo`1C0?ooo`D08>`700<0oooo023/1`3oool05P0Pk0L0
0`3oool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo00X08>`700<0oooo023/1`3oool00P0Pk0L2
0?ooo`03023/1`3oool0oooo01@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`003`3oool00`000000oooo0?ooo`1C0?ooo`D08>`700<0oooo023/1`3oool05P0Pk0L00`3o
ool08>`7023/1`03023/1`030?ooo`0Pk0L0oooo00X08>`700<0oooo023/1`3oool00P0Pk0L20?oo
o`03023/1`3oool0oooo01@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?oo
o`003`3oool00`000000oooo0?ooo`1C0?ooo`D08>`700<0oooo023/1`3oool05P0Pk0L00`3oool0
8>`7023/1`03023/1`030?ooo`0Pk0L0oooo00X08>`700<0oooo023/1`3oool00P0Pk0L20?ooo`03
023/1`3oool0oooo01@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00
3`3oool00`000000oooo0?ooo`1C0?ooo`D08>`700<0oooo023/1`3oool05P0Pk0L00`3oool08>`7
023/1`03023/1`030?ooo`0Pk0L0oooo00X08>`700<0oooo023/1`3oool00P0Pk0L20?ooo`03023/
1`3oool0oooo01@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`003`3o
ool00`000000oooo0?ooo`1C0?ooo`D08>`700<0oooo023/1`3oool05P0Pk0L00`3oool08>`7023/
1`03023/1`030?ooo`0Pk0L0oooo00X08>`700@0oooo023/1`3oool08>`70`3oool00`0Pk0L0oooo
0?ooo`0D0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<0
00000?ooo`3oool0D`3oool5023/1`030?ooo`0Pk0L0oooo01H08>`700<0oooo023/1`0Pk0L00`0P
k0L00`3oool08>`70?ooo`0:023/1`040?ooo`0Pk0L0oooo023/1`<0oooo00<08>`70?ooo`3oool0
503oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003o
ool0oooo05<0oooo1@0Pk0L00`3oool08>`70?ooo`0F023/1`030?ooo`0Pk0L08>`700<08>`700<0
oooo023/1`3oool02P0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`03023/1`3oool0oooo01@0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?oo
o`1D0?ooo`@08>`700<0oooo023/1`3oool05P0Pk0L00`3oool08>`7023/1`03023/1`030?ooo`0P
k0L0oooo00X08>`700@0oooo023/1`0Pk0L08>`70`3oool00`0Pk0L0oooo0?ooo`0D0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0E03o
ool4023/1`030?ooo`0Pk0L0oooo01H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`70?oo
o`0:023/1`040?ooo`0Pk0L08>`7023/1`<0oooo00<08>`70?ooo`3oool0503oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo05@0oooo100P
k0L00`3oool08>`70?ooo`0F023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L03P0P
k0L30?ooo`03023/1`3oool0oooo01@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`003`3oool00`000000oooo0?ooo`1D0?ooo`@08>`700<0oooo023/1`3oool05P0Pk0L0
0`3oool08>`7023/1`03023/1`030?ooo`0Pk0L08>`700h08>`70`3oool00`0Pk0L0oooo0?ooo`0D
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?oo
o`3oool0E03oool4023/1`030?ooo`0Pk0L0oooo01H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3o
ool08>`7023/1`0>023/1`<0oooo00<08>`70?ooo`3oool0503oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo05@0oooo100Pk0L00`3oool0
8>`70?ooo`0F023/1`030?ooo`0Pk0L08>`700<08>`700<0oooo023/1`0Pk0L03P0Pk0L30?ooo`03
023/1`3oool0oooo01@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00
3`3oool00`000000oooo0?ooo`1D0?ooo`@08>`700<0oooo023/1`3oool05P0Pk0L00`3oool08>`7
023/1`03023/1`030?ooo`0Pk0L08>`700h08>`70`3oool00`0Pk0L0oooo0?ooo`0D0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0E03o
ool4023/1`030?ooo`0Pk0L0oooo01H08>`700<0oooo023/1`0Pk0L00`0Pk0L00`3oool08>`7023/
1`0>023/1`<0oooo00<08>`70?ooo`3oool0503oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo000?0?ooo`030000003oool0oooo05@0oooo100Pk0L00`3oool08>`70?ooo`0]
023/1`<0oooo00<08>`70?ooo`3oool0503oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo0140oooo000?0?ooo`030000003oool0oooo05@0oooo100Pk0L00`3oool08>`70?ooo`0]023/
1`<0oooo00<08>`70?ooo`3oool0503oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo000?0?ooo`030000003oool0oooo05@0oooo100Pk0L00`3oool08>`70?ooo`0]023/1`<0
oooo00<08>`70?ooo`3oool0503oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0140
oooo000?0?ooo`030000003oool0oooo05@0oooo00L08>`70?ooo`0Pk0L08>`70?ooo`0Pk0L0oooo
02d08>`70`3oool00`0Pk0L0oooo0?ooo`0D0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool04@3oool000l0oooo00<000000?ooo`3oool0E03oool01`0Pk0L0oooo023/1`0Pk0L0oooo
023/1`3oool0;@0Pk0L30?ooo`03023/1`3oool0oooo01@0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1D0?ooo`05023/1`3oool08>`7
023/1`3oool0;`0Pk0L30?ooo`03023/1`3oool0oooo01@0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1D0?ooo`05023/1`3oool08>`7
023/1`3oool0;`0Pk0L20?ooo`03023/1`3oool0oooo01D0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1D0?ooo`@08>`700<0oooo023/
1`0Pk0L0;@0Pk0L20?ooo`03023/1`3oool0oooo01D0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1D0?ooo`@08>`70P3oool^023/1`80
oooo00<08>`70?ooo`3oool05@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0140
oooo000?0?ooo`030000003oool0oooo05@0oooo100Pk0L20?ooobh08>`70P3oool00`0Pk0L0oooo
0?ooo`0E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<0
00000?ooo`3oool0E03oool4023/1`80oooo;P0Pk0L20?ooo`03023/1`3oool0oooo01D0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1D
0?ooo`@08>`70P3oool^023/1`80oooo00<08>`70?ooo`3oool05@3oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo05@0oooo100Pk0L20?oo
obh08>`70P3oool00`0Pk0L0oooo0?ooo`0E0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool04@3oool000l0oooo00<000000?ooo`3oool0E03oool4023/1`80oooo4@0Pk0L00`3oool0
8>`7023/1`0J023/1`80oooo00<08>`70?ooo`3oool05@3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo05@0oooo100Pk0L20?oooa408>`7
00<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`0C023/1`80oooo00<08>`70?ooo`3oool0
5@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003o
ool0oooo05@0oooo100Pk0L20?oooa408>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/
1`0C023/1`80oooo00<08>`70?ooo`3oool05@3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo000?0?ooo`030000003oool0oooo05@0oooo100Pk0L20?oooaP08>`700<0oooo
023/1`0Pk0L04`0Pk0L20?ooo`03023/1`3oool0oooo01D0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1D0?ooo`@08>`70P3ooolH023/
1`80oooo500Pk0L20?ooo`03023/1`3oool0oooo01D0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1D0?ooo`@08>`70P3ooolH023/1`80
oooo500Pk0L20?ooo`03023/1`3oool0oooo01D0oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1D0?ooo`@08>`70P3ooolH023/1`80oooo
500Pk0L20?ooo`03023/1`3oool0oooo01D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1D0?ooo`@08>`70P3ooolH023/1`80oooo500P
k0L20?ooo`03023/1`3oool0oooo01D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`003`3oool00`000000oooo0?ooo`1D0?ooo`@08>`70P3ooolH023/1`80oooo500Pk0L2
0?ooo`03023/1`3oool0oooo01D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`003`3oool00`000000oooo0?ooo`1D0?ooo`@08>`70P3ooolH023/1`030?ooo`0Pk0L08>`7
01<08>`70P3oool00`0Pk0L0oooo0?ooo`0E0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool04@3oool000l0oooo00<000000?ooo`3oool0E03oool4023/1`80oooo600Pk0L00`3oool0
8>`7023/1`0B023/1`<0oooo00<08>`70?ooo`3oool05@3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo05@0oooo100Pk0L20?oooaP08>`7
00<0oooo023/1`0Pk0L04P0Pk0L30?ooo`03023/1`3oool0oooo01D0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1D0?ooo`@08>`70P3o
oolH023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?oo
o`0E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<00000
0?ooo`3oool0E03oool4023/1`80oooo600Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L0
8>`700L08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`0E0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0E03oool4023/
1`80oooo600Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/
1`3oool00P3oool00`0Pk0L0oooo0?ooo`0E0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool04@3oool000l0oooo00<000000?ooo`3oool0E03oool4023/1`80oooo600Pk0L00`3oool0
8>`7023/1`06023/1`030?ooo`0Pk0L08>`700L08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0
oooo0?ooo`0E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo
00<000000?ooo`3oool0E03oool4023/1`80oooo600Pk0L00`3oool08>`7023/1`06023/1`030?oo
o`0Pk0L08>`700L08>`700<0oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`0E0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0E03o
ool4023/1`80oooo600Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700L08>`700<0
oooo023/1`3oool00P3oool00`0Pk0L0oooo0?ooo`0E0?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0E03oool4023/1`80oooo600Pk0L0
0`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700T08>`70`3oool00`0Pk0L0oooo0?ooo`0E
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?oo
o`3oool0E03oool5023/1`030?ooo`0Pk0L08>`701H08>`700<0oooo023/1`0Pk0L01P0Pk0L00`3o
ool08>`7023/1`05023/1`040?ooo`0Pk0L08>`7023/1`<0oooo00<08>`70?ooo`3oool05@3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo
05D0oooo100Pk0L00`3oool08>`7023/1`0F023/1`030?ooo`0Pk0L08>`700H08>`700<0oooo023/
1`0Pk0L01@0Pk0L0103oool08>`7023/1`0Pk0L30?ooo`03023/1`3oool0oooo01D0oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1E0?oo
o`@08>`700<0oooo023/1`0Pk0L05P0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`7
00<08>`700<0oooo023/1`3oool00`0Pk0L20?ooo`03023/1`3oool0oooo01H0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1E0?ooo`@0
8>`700<0oooo023/1`0Pk0L05P0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700<0
8>`700<0oooo023/1`3oool00`0Pk0L20?ooo`03023/1`3oool0oooo01H0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1E0?ooo`@08>`7
00<0oooo023/1`0Pk0L05P0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0Pk0L08>`700<08>`7
00<0oooo023/1`3oool00`0Pk0L20?ooo`03023/1`3oool0oooo01H0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1E0?ooo`@08>`700<0
oooo023/1`0Pk0L05P0Pk0L00`3oool08>`7023/1`0<023/1`030?ooo`0Pk0L0oooo00<08>`70P3o
ool00`0Pk0L0oooo0?ooo`0F0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool000l0oooo00<000000?ooo`3oool0E@3oool4023/1`030?ooo`0Pk0L08>`701H08>`700<0oooo
023/1`0Pk0L0300Pk0L00`3oool08>`70?ooo`03023/1`80oooo00<08>`70?ooo`3oool05P3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo
05D0oooo100Pk0L00`3oool08>`7023/1`0F023/1`030?ooo`0Pk0L08>`700`08>`700<0oooo023/
1`3oool00`0Pk0L20?ooo`03023/1`3oool0oooo01H0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1E0?ooo`@08>`700<0oooo023/1`0P
k0L05P0Pk0L00`3oool08>`7023/1`0<023/1`030?ooo`0Pk0L0oooo00<08>`70P3oool00`0Pk0L0
oooo0?ooo`0F0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo
00<000000?ooo`3oool0E@3oool4023/1`030?ooo`0Pk0L08>`701H08>`700<0oooo023/1`0Pk0L0
300Pk0L00`3oool08>`70?ooo`03023/1`80oooo00<08>`70?ooo`3oool05P3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo05D0oooo100P
k0L00`3oool08>`7023/1`0F023/1`030?ooo`0Pk0L08>`700`08>`700<0oooo023/1`0Pk0L00`0P
k0L20?ooo`03023/1`3oool0oooo01H0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`003`3oool00`000000oooo0?ooo`1E0?ooo`@08>`700<0oooo023/1`0Pk0L09@0Pk0L0
0`3oool08>`7023/1`03023/1`80oooo00<08>`70?ooo`3oool05P3oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo05D0oooo100Pk0L00`3o
ool08>`7023/1`0U023/1`030?ooo`0Pk0L08>`700<08>`70P3oool00`0Pk0L0oooo0?ooo`0F0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3o
ool0E@3oool4023/1`030?ooo`0Pk0L08>`702/08>`70P3oool00`0Pk0L0oooo0?ooo`0F0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0
E@3oool4023/1`030?ooo`0Pk0L08>`702/08>`70P3oool00`0Pk0L0oooo0?ooo`0F0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0E@3o
ool4023/1`030?ooo`0Pk0L08>`702/08>`70P3oool00`0Pk0L0oooo0?ooo`0F0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0E@3oool4
023/1`030?ooo`0Pk0L08>`702/08>`70P3oool00`0Pk0L0oooo0?ooo`0F0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0E@3oool4023/
1`030?ooo`0Pk0L08>`702/08>`70P3oool00`0Pk0L0oooo0?ooo`0F0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0E@3oool4023/1`03
0?ooo`0Pk0L08>`702/08>`70P3oool00`0Pk0L0oooo0?ooo`0F0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0E@3oool4023/1`030?oo
o`0Pk0L08>`700h08>`700<0oooo023/1`0Pk0L06P0Pk0L20?ooo`03023/1`3oool0oooo01H0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?oo
o`1E0?ooo`@08>`700<0oooo023/1`0Pk0L03P0Pk0L00`3oool08>`7023/1`0J023/1`80oooo00<0
8>`70?ooo`3oool05P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?
0?ooo`030000003oool0oooo05D0oooo100Pk0L00`3oool08>`7023/1`0>023/1`030?ooo`0Pk0L0
8>`701X08>`70P3oool00`0Pk0L0oooo0?ooo`0F0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0E@3oool4023/1`030?ooo`0Pk0L08>`7
02/08>`70P3oool00`0Pk0L0oooo0?ooo`0F0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool04@3oool000l0oooo00<000000?ooo`3oool0E@3oool4023/1`030?ooo`0Pk0L08>`701L0
8>`700<0oooo023/1`0Pk0L04@0Pk0L20?ooo`03023/1`3oool0oooo01H0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1E0?ooo`@08>`7
00<0oooo023/1`0Pk0L05`0Pk0L00`3oool08>`7023/1`0A023/1`80oooo00<08>`70?ooo`3oool0
5P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003o
ool0oooo05D0oooo100Pk0L00`3oool08>`7023/1`0G023/1`030?ooo`0Pk0L08>`701408>`70P3o
ool00`0Pk0L0oooo0?ooo`0F0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool000l0oooo00<000000?ooo`3oool0E@3oool4023/1`030?ooo`0Pk0L08>`701L08>`700<0oooo
023/1`0Pk0L0400Pk0L30?ooo`03023/1`3oool0oooo01H0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1E0?ooo`@08>`700<0oooo023/
1`0Pk0L05`0Pk0L00`3oool08>`7023/1`0@023/1`<0oooo00<08>`70?ooo`3oool05P3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo05D0
oooo100Pk0L00`3oool08>`7023/1`0G023/1`030?ooo`0Pk0L08>`701008>`70`3oool00`0Pk0L0
oooo0?ooo`0F0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo
00<000000?ooo`3oool0E@3oool4023/1`030?ooo`0Pk0L08>`701L08>`700<0oooo023/1`0Pk0L0
0P0Pk0L00`3oool08>`7023/1`0;023/1`80oooo00<08>`70?ooo`3oool05`3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo05D0oooo100P
k0L00`3oool08>`7023/1`0D023/1`030?ooo`0Pk0L08>`70080oooo0`0Pk0L00`3oool08>`7023/
1`0;023/1`80oooo00<08>`70?ooo`3oool05`3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo000?0?ooo`030000003oool0oooo05D0oooo100Pk0L00`3oool08>`7023/1`0G
023/1`80oooo0`0Pk0L00`3oool08>`7023/1`0;023/1`80oooo00<08>`70?ooo`3oool05`3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo
05D0oooo100Pk0L00`3oool08>`7023/1`0G023/1`80oooo0`0Pk0L00`3oool08>`7023/1`0;023/
1`80oooo00<08>`70?ooo`3oool05`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo000?0?ooo`030000003oool0oooo05D0oooo100Pk0L00`3oool08>`7023/1`0G023/1`80
oooo0`0Pk0L00`3oool08>`7023/1`09023/1`050?ooo`0Pk0L0oooo0?ooo`0Pk0L06@3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo05D0
oooo100Pk0L00`3oool08>`7023/1`0B023/1`030?ooo`0Pk0L08>`700808>`70P3oool3023/1`03
0?ooo`0Pk0L08>`700T08>`700D0oooo023/1`3oool0oooo023/1`0I0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0E@3oool4023/1`03
0?ooo`0Pk0L08>`701808>`700<0oooo023/1`0Pk0L00P0Pk0L20?ooo`<08>`700<0oooo023/1`0P
k0L02@0Pk0L01@3oool08>`70?ooo`3oool08>`701T0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1E0?ooo`@08>`700<0oooo023/1`0P
k0L04P0Pk0L00`3oool08>`7023/1`02023/1`80oooo0`0Pk0L00`3oool08>`7023/1`09023/1`05
0?ooo`0Pk0L0oooo0?ooo`0Pk0L06@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo000?0?ooo`030000003oool0oooo05D0oooo100Pk0L00`3oool08>`7023/1`0B023/1`03
0?ooo`0Pk0L08>`700808>`70P3oool3023/1`030?ooo`0Pk0L08>`700T08>`700D0oooo023/1`3o
ool0oooo023/1`0I0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0
oooo00<000000?ooo`3oool0E@3oool4023/1`030?ooo`0Pk0L08>`701808>`700<0oooo023/1`0P
k0L00P0Pk0L20?ooo`<08>`700<0oooo023/1`0Pk0L02`0Pk0L20?ooo`03023/1`3oool0oooo01L0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo
0?ooo`1E0?ooo`@08>`700<0oooo023/1`0Pk0L04P0Pk0L00`3oool08>`7023/1`02023/1`80oooo
0`0Pk0L00`3oool08>`7023/1`0;023/1`80oooo00<08>`70?ooo`3oool05`3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo05D0oooo100P
k0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`0Pk0L00P0P
k0L20?ooo`<08>`700<0oooo023/1`0Pk0L02`0Pk0L20?ooo`03023/1`3oool0oooo01L0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1E
0?ooo`@08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0
8>`700808>`70P3oool3023/1`030?ooo`0Pk0L08>`700/08>`70P3oool00`0Pk0L0oooo0?ooo`0G
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?oo
o`3oool0EP3oool3023/1`030?ooo`0Pk0L08>`700D08>`700<0oooo023/1`0Pk0L02P0Pk0L00`3o
ool08>`7023/1`02023/1`80oooo4@0Pk0L20?ooo`03023/1`3oool0oooo01L0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1F0?ooo`<0
8>`700<0oooo023/1`3oool01@0Pk0L00`3oool08>`7023/1`0?023/1`80oooo4@0Pk0L20?ooo`03
023/1`3oool0oooo01L0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00
3`3oool00`000000oooo0?ooo`1F0?ooo`<08>`700<0oooo023/1`3oool01@0Pk0L00`3oool08>`7
023/1`0?023/1`80oooo4@0Pk0L20?ooo`03023/1`3oool0oooo01L0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1F0?ooo`<08>`700<0
oooo023/1`3oool01@0Pk0L00`3oool08>`7023/1`0?023/1`80oooo4@0Pk0L20?ooo`03023/1`3o
ool0oooo01L0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool0
0`000000oooo0?ooo`1F0?ooo`<08>`700<0oooo023/1`3oool01@0Pk0L00`3oool08>`7023/1`0?
023/1`80oooo4@0Pk0L20?ooo`03023/1`3oool0oooo01L0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1F0?ooo`<08>`700<0oooo023/
1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0?023/1`80oooo4@0Pk0L20?ooo`03023/1`3oool0oooo
01L0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000
oooo0?ooo`1F0?ooo`<08>`700<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`0?023/1`80
oooo4@0Pk0L20?ooo`03023/1`3oool0oooo01L0oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`1F0?ooo`<08>`70P3oool6023/1`030?oo
o`0Pk0L08>`700l08>`70P3ooolA023/1`80oooo00<08>`70?ooo`3oool05`3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo05H0oooo0`0P
k0L20?ooo`H08>`700<0oooo023/1`0Pk0L03`0Pk0L20?oooa408>`70P3oool00`0Pk0L0oooo0?oo
o`0G0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000l0oooo00<00000
0?ooo`3oool0EP3oool3023/1`80oooo1P0Pk0L00`3oool08>`7023/1`0?023/1`80oooo4@0Pk0L2
0?ooo`03023/1`3oool0oooo01L0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`003`3oool00`000000oooo0?ooo`1F0?ooo`<08>`70P3oool6023/1`030?ooo`0Pk0L08>`7
00l08>`70P3ooolA023/1`80oooo00<08>`70?ooo`3oool05`3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo05H0oooo0`0Pk0L20?ooo`H0
8>`700<0oooo023/1`0Pk0L03`0Pk0L20?oooa408>`70P3oool00`0Pk0L0oooo0?ooo`0G0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000h0oooo00<000000?ooo`3oool0
E`3oool3023/1`80oooo1P0Pk0L00`3oool08>`7023/1`0;023/1`040?ooo`0Pk0L08>`7023/1`80
oooo4@0Pk0L20?ooo`03023/1`3oool0oooo01L0oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`003P3oool00`000000oooo0?ooo`1G0?ooo`<08>`70P3oool6023/1`030?oo
o`0Pk0L08>`700/08>`700@0oooo023/1`0Pk0L08>`70P3ooolA023/1`80oooo00<08>`70?ooo`3o
ool05`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000>0?ooo`030000
003oool0oooo05L0oooo0`0Pk0L20?ooo`H08>`700<0oooo023/1`0Pk0L02`0Pk0L0103oool08>`7
023/1`0Pk0L20?oooa408>`700<0oooo023/1`3oool06@3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo000>0?ooo`030000003oool0oooo05L0oooo0`0Pk0L20?ooo`H08>`7
00<0oooo023/1`0Pk0L01@0Pk0L00`3oool08>`7023/1`03023/1`040?ooo`0Pk0L08>`7023/1`80
oooo3@0Pk0L01P3oool08>`7023/1`0Pk0L0oooo023/1aX0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`003P3oool00`000000oooo0?ooo`1G0?ooo`@08>`700<0oooo023/
1`0Pk0L0100Pk0L00`3oool08>`7023/1`05023/1`030?ooo`0Pk0L08>`700<08>`700@0oooo023/
1`0Pk0L08>`70P3ooolA023/1`030?ooo`0Pk0L0oooo01T0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`003P3oool00`000000oooo0?ooo`1G0?ooo`@08>`700<0oooo023/
1`0Pk0L0100Pk0L00`3oool08>`7023/1`0;023/1`040?ooo`0Pk0L08>`7023/1`80oooo4@0Pk0L0
0`3oool08>`70?ooo`0I0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool0
00h0oooo00<000000?ooo`3oool0E`3oool4023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/
1`0Pk0L02`0Pk0L0103oool08>`7023/1`0Pk0L20?oooa408>`700<0oooo023/1`3oool06@3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000>0?ooo`030000003oool0oooo
05L0oooo100Pk0L00`3oool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/
1`3oool00`0Pk0L20?oooa408>`700<0oooo023/1`3oool06@3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo000>0?ooo`030000003oool0oooo05L0oooo100Pk0L00`3oool0
8>`7023/1`04023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`3oool00`0Pk0L20?oooa40
8>`700<0oooo023/1`3oool06@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0140
oooo000>0?ooo`030000003oool0oooo05L0oooo100Pk0L00`3oool08>`7023/1`04023/1`030?oo
o`0Pk0L08>`700T08>`700<0oooo023/1`3oool00`0Pk0L20?oooa008>`70P3oool00`0Pk0L0oooo
0?ooo`0H0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3oool000h0oooo00<0
00000?ooo`3oool0E`3oool4023/1`030?ooo`0Pk0L08>`700@08>`700<0oooo023/1`0Pk0L02@0P
k0L00`3oool08>`70?ooo`03023/1`80oooo400Pk0L20?ooo`03023/1`3oool0oooo01P0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`003P3oool00`000000oooo0?ooo`1G
0?ooo`@08>`700<0oooo023/1`0Pk0L0100Pk0L00`3oool08>`7023/1`09023/1`030?ooo`0Pk0L0
oooo00<08>`70P3oool@023/1`80oooo00<08>`70?ooo`3oool0603oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo0140oooo000>0?ooo`030000003oool0oooo05L0oooo100Pk0L00`3o
ool08>`7023/1`04023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`3oool0100Pk0L00`3o
ool08>`7023/1`0>023/1`80oooo00<08>`70?ooo`3oool0603oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo000>0?ooo`030000003oool0oooo05L0oooo100Pk0L00`3oool0
8>`7023/1`04023/1`030?ooo`0Pk0L08>`700T08>`700<0oooo023/1`3oool0100Pk0L00`3oool0
8>`7023/1`0>023/1`80oooo00<08>`70?ooo`3oool0603oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo000>0?ooo`030000003oool0oooo05L0oooo100Pk0L00`3oool08>`7
023/1`04023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7
023/1`0>023/1`80oooo00<08>`70?ooo`3oool0603oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo0140oooo000>0?ooo`030000003oool0oooo05L0oooo100Pk0L00`3oool08>`7023/
1`04023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/
1`0>023/1`80oooo00<08>`70?ooo`3oool0603oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo000>0?ooo`030000003oool0oooo05L0oooo100Pk0L00`3oool08>`7023/1`04
023/1`030?ooo`0Pk0L08>`700/08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`0>
023/1`80oooo00<08>`70?ooo`3oool0603oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo0140oooo000>0?ooo`030000003oool0oooo05L0oooo100Pk0L00`3oool08>`7023/1`04023/
1`030?ooo`0Pk0L08>`700/08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`0>023/
1`80oooo00<08>`70?ooo`3oool0603oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo000>0?ooo`030000003oool0oooo05L0oooo100Pk0L00`3oool08>`7023/1`04023/1`03
0?ooo`0Pk0L08>`700/08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`0<023/1`05
0?ooo`0Pk0L0oooo0?ooo`0Pk0L06P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo000>0?ooo`030000003oool0oooo05L0oooo100Pk0L00`3oool08>`7023/1`04023/1`03
0?ooo`0Pk0L08>`700/08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7023/1`0<023/1`05
0?ooo`0Pk0L0oooo0?ooo`0Pk0L06P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo000>0?ooo`030000003oool0oooo05L0oooo100Pk0L00`3oool08>`7023/1`04023/1`03
0?ooo`0Pk0L08>`701008>`700<0oooo023/1`0Pk0L0300Pk0L01@3oool08>`70?ooo`3oool08>`7
01X0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`003P3oool00`000000
oooo0?ooo`1G0?ooo`@08>`700<0oooo023/1`0Pk0L05`0Pk0L00`3oool08>`7023/1`0<023/1`05
0?ooo`0Pk0L0oooo0?ooo`0Pk0L06P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo000>0?ooo`030000003oool0oooo05L0oooo100Pk0L00`3oool08>`7023/1`0G023/1`80
oooo3@0Pk0L01@3oool08>`70?ooo`3oool08>`701X0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`003P3oool00`000000oooo0?ooo`1G0?ooo`@08>`700<0oooo023/1`0P
k0L05`0Pk0L20?ooo`d08>`700D0oooo023/1`3oool0oooo023/1`0J0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0E`3oool4023/1`03
0?ooo`0Pk0L08>`701408>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`l08>`70P3oool00`0Pk0L0
oooo0?ooo`0H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0403oool000h0oooo
00<000000?ooo`3oool0E`3oool4023/1`030?ooo`0Pk0L08>`701408>`700<0oooo023/1`0Pk0L0
0`0Pk0L20?ooo`l08>`70P3oool00`0Pk0L0oooo0?ooo`0H0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0E`3oool4023/1`030?ooo`0P
k0L08>`701408>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`l08>`70P3oool00`0Pk0L0oooo0?oo
o`0H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0403oool000h0oooo00<00000
0?ooo`3oool0E`3oool4023/1`030?ooo`0Pk0L08>`701408>`700<0oooo023/1`0Pk0L00`0Pk0L2
0?ooo`l08>`70P3oool00`0Pk0L0oooo0?ooo`0H0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`7
01408>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`l08>`70P3oool00`0Pk0L0oooo0?ooo`0H0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3o
ool0F03oool3023/1`030?ooo`0Pk0L08>`701408>`700<0oooo023/1`0Pk0L00`0Pk0L20?ooo`l0
8>`70P3oool00`0Pk0L0oooo0?ooo`0H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool0403oool000h0oooo00<000000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`701408>`7
00<0oooo023/1`3oool00`0Pk0L20?ooo`X08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`7
0?ooo`0J0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0403oool000h0oooo00<0
00000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`701408>`700@0oooo023/1`3oool0oooo
0P0Pk0L20?ooo`X08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`0J0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03o
ool3023/1`030?ooo`0Pk0L08>`701408>`700@0oooo023/1`3oool0oooo0P0Pk0L20?ooo`l08>`7
00<0oooo023/1`3oool06P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0100oooo
000>0?ooo`030000003oool0oooo05P0oooo0`0Pk0L00`3oool08>`7023/1`0A023/1`040?ooo`0P
k0L0oooo0?ooo`808>`70P3oool?023/1`030?ooo`0Pk0L0oooo01X0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1H0?ooo`<08>`700<0
oooo023/1`0Pk0L04@0Pk0L0103oool08>`70?ooo`3oool2023/1`80oooo3`0Pk0L00`3oool08>`7
0?ooo`0J0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0403oool000h0oooo00<0
00000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`700l08>`700@0oooo023/1`3oool08>`7
0P3oool2023/1`80oooo3`0Pk0L00`3oool08>`70?ooo`0J0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool3023/1`030?ooo`0P
k0L08>`700l08>`700@0oooo023/1`3oool08>`70P3oool2023/1`80oooo3`0Pk0L00`3oool08>`7
0?ooo`0J0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0403oool000h0oooo00<0
00000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`700l08>`700@0oooo023/1`3oool08>`7
0P3oool2023/1`80oooo3`0Pk0L00`3oool08>`70?ooo`0J0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool3023/1`030?ooo`0P
k0L08>`700l08>`700@0oooo023/1`3oool08>`70P3oool2023/1`80oooo3`0Pk0L00`3oool08>`7
0?ooo`0J0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0403oool000h0oooo00<0
00000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`701408>`700@0oooo023/1`3oool0oooo
0P0Pk0L20?ooo`l08>`700<0oooo023/1`3oool06P3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0100oooo000>0?ooo`030000003oool0oooo05P0oooo0`0Pk0L00`3oool08>`7023/
1`0A023/1`040?ooo`0Pk0L0oooo0?ooo`808>`70P3oool?023/1`030?ooo`0Pk0L0oooo01X0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?oo
o`1H0?ooo`<08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`7023/1`05023/1`80oooo0P0P
k0L20?ooo`l08>`700<0oooo023/1`3oool06P3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0100oooo000>0?ooo`030000003oool0oooo05P0oooo0`0Pk0L00`3oool08>`7023/1`0;
023/1`030?ooo`0Pk0L08>`700D08>`70P3oool2023/1`80oooo3`0Pk0L00`3oool08>`70?ooo`0J
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?oo
o`3oool0F03oool3023/1`030?ooo`0Pk0L08>`701<08>`70P3oool2023/1`80oooo3`0Pk0L00`3o
ool08>`70?ooo`0J0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0403oool000h0
oooo00<000000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`701<08>`70P3oool2023/1`80
oooo3`0Pk0L00`3oool08>`70?ooo`0J0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool0403oool000h0oooo00<000000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`701<08>`7
0P3oool3023/1`030?ooo`0Pk0L08>`700`08>`70P3oool00`0Pk0L0oooo0?ooo`0I0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03o
ool3023/1`030?ooo`0Pk0L08>`701<08>`70P3oool3023/1`030?ooo`0Pk0L08>`700`08>`70P3o
ool00`0Pk0L0oooo0?ooo`0I0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0403o
ool000h0oooo00<000000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`701<08>`70P3oool3
023/1`030?ooo`0Pk0L08>`700`08>`70P3oool00`0Pk0L0oooo0?ooo`0J0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool3023/
1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`0Pk0L00P3oool3023/1`030?ooo`0Pk0L08>`7
00`08>`70P3oool00`0Pk0L0oooo0?ooo`0J0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`70100
8>`700<0oooo023/1`0Pk0L00P3oool3023/1`030?ooo`0Pk0L08>`700`08>`70P3oool00`0Pk0L0
oooo0?ooo`0J0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo
00<000000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`3oool0
0P3oool3023/1`030?ooo`0Pk0L08>`700`08>`70P3oool00`0Pk0L0oooo0?ooo`0J0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03o
ool3023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`3oool00P3oool3023/1`030?ooo`0P
k0L08>`700`08>`70P3oool00`0Pk0L0oooo0?ooo`0J0?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L0
8>`701008>`700<0oooo023/1`3oool00P3oool3023/1`030?ooo`0Pk0L08>`700`08>`70P3oool0
0`0Pk0L0oooo0?ooo`0J0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool0
00h0oooo00<000000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/
1`3oool00P3oool3023/1`030?ooo`0Pk0L08>`700`08>`70P3oool00`0Pk0L0oooo0?ooo`0J0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3o
ool0F03oool3023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`3oool00P3oool3023/1`03
0?ooo`0Pk0L08>`700`08>`70P3oool00`0Pk0L0oooo0?ooo`0J0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool3023/1`030?oo
o`0Pk0L08>`701008>`700<0oooo023/1`3oool00P3oool3023/1`030?ooo`0Pk0L08>`700`08>`7
0P3oool00`0Pk0L0oooo0?ooo`0J0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
403oool000h0oooo00<000000?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`701008>`700<0
oooo023/1`3oool00P3oool3023/1`030?ooo`0Pk0L08>`700`08>`70P3oool00`0Pk0L0oooo0?oo
o`0J0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<00000
0?ooo`3oool0F03oool3023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`3oool00P3oool3
023/1`030?ooo`0Pk0L08>`700`08>`700<0oooo023/1`3oool0703oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo0100oooo000>0?ooo`030000003oool0oooo05P0oooo0`0Pk0L00`3o
ool08>`7023/1`0@023/1`030?ooo`0Pk0L0oooo0080oooo0`0Pk0L00`3oool08>`7023/1`0<023/
1`030?ooo`0Pk0L0oooo01`0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?oo
o`003P3oool00`000000oooo0?ooo`1H0?ooo`<08>`700<0oooo023/1`0Pk0L0400Pk0L00`3oool0
8>`70?ooo`030?ooo`808>`700<0oooo023/1`0Pk0L0300Pk0L00`3oool08>`70?ooo`0L0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0
F03oool3023/1`030?ooo`0Pk0L08>`701008>`700<0oooo023/1`3oool00`3oool2023/1`030?oo
o`0Pk0L08>`700`08>`700<0oooo023/1`3oool0703oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo0100oooo000>0?ooo`030000003oool0oooo05P0oooo0`0Pk0L00`3oool08>`7023/
1`0@023/1`030?ooo`0Pk0L0oooo00<0oooo0P0Pk0L00`3oool08>`7023/1`0<023/1`030?ooo`0P
k0L0oooo01`0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool0
0`000000oooo0?ooo`1H0?ooo`<08>`700<0oooo023/1`0Pk0L04P0Pk0L40?ooo`808>`700<0oooo
023/1`0Pk0L0300Pk0L00`3oool08>`70?ooo`0L0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03ooolD023/1`040?ooo`0Pk0L08>`7
023/1`@0oooo0P0Pk0L00`3oool08>`7023/1`0<023/1`030?ooo`0Pk0L0oooo01`0oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1H0?oo
oaP08>`7103oool2023/1`030?ooo`0Pk0L08>`700`08>`700<0oooo023/1`3oool0703oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000>0?ooo`030000003oool0oooo05P0
oooo600Pk0L40?ooo`808>`700<0oooo023/1`0Pk0L0300Pk0L00`3oool08>`70?ooo`0L0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0
F03ooolH023/1`@0oooo0P0Pk0L00`3oool08>`7023/1`0<023/1`030?ooo`0Pk0L0oooo01`0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?oo
o`1H0?ooo`030000000Pk0L08>`701D08>`7103oool2023/1`030?ooo`0Pk0L08>`700`08>`700<0
oooo023/1`3oool0703oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000>
0?ooo`030000003oool0oooo05P0oooo00<00000023/1`0Pk0L05@0Pk0L40?ooo`808>`70P3oool=
023/1`030?ooo`0Pk0L0oooo01`0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@
0?ooo`003P3oool00`000000oooo0?ooo`1H0?ooo`050000000Pk0L08>`7023/1`3oool04`0Pk0L4
0?ooo`808>`70P3oool=023/1`030?ooo`0Pk0L0oooo01`0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1H0?ooo`050000000Pk0L08>`7
023/1`3oool04`0Pk0L40?ooo`808>`70P3oool=023/1`030?ooo`0Pk0L0oooo01`0oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1H0?oo
o`050000000Pk0L08>`7023/1`3oool04P0Pk0L50?ooo`808>`70P3oool=023/1`030?ooo`0Pk0L0
oooo01`0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`00
0000oooo0?ooo`1H0?ooo`050000000Pk0L08>`7023/1`3oool0400Pk0L00`3oool08>`70?ooo`04
0?ooo`808>`70P3oool=023/1`030?ooo`0Pk0L0oooo01`0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1H0?ooo`050000000Pk0L08>`7
023/1`3oool0400Pk0L00`3oool08>`70?ooo`040?ooo`808>`70P3oool=023/1`030?ooo`0Pk0L0
oooo01`0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`00
0000oooo0?ooo`1H0?ooo`050000000Pk0L08>`7023/1`3oool0400Pk0L00`3oool08>`70?ooo`04
0?ooo`808>`70P3oool=023/1`030?ooo`0Pk0L0oooo01`0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1H0?ooo`050000000Pk0L08>`7
023/1`3oool0400Pk0L00`3oool08>`70?ooo`040?ooo`808>`70P3oool=023/1`030?ooo`0Pk0L0
oooo01`0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`00
0000oooo0?ooo`1H0?ooo`050000000Pk0L08>`7023/1`3oool0400Pk0L00`3oool08>`70?ooo`04
0?ooo`808>`70P3oool=023/1`030?ooo`0Pk0L0oooo01`0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1H0?ooo`050000000Pk0L08>`7
023/1`3oool0400Pk0L00`3oool08>`70?ooo`040?ooo`808>`70P3oool=023/1`030?ooo`0Pk0L0
oooo01`0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`00
0000oooo0?ooo`1H0?ooo`050000000Pk0L08>`7023/1`3oool0400Pk0L00`3oool08>`70?ooo`04
0?ooo`<08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`70?ooo`0L0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool01@00
00008>`7023/1`0Pk0L0oooo00/08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`04
0?ooo`<08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`70?ooo`0L0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool01@00
00008>`7023/1`0Pk0L0oooo00/08>`700<0oooo023/1`0Pk0L00P0Pk0L00`3oool08>`70?ooo`04
0?ooo`<08>`700<0oooo023/1`0Pk0L02`0Pk0L00`3oool08>`70?ooo`0L0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool01@00
00008>`7023/1`0Pk0L0oooo01008>`700<0oooo023/1`3oool0103oool3023/1`030?ooo`0Pk0L0
8>`700X08>`70P3oool00`0Pk0L0oooo0?ooo`0K0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool01@0000008>`7023/1`0Pk0L0
oooo01008>`700<0oooo023/1`3oool0103oool3023/1`030?ooo`0Pk0L08>`700X08>`70P3oool0
0`0Pk0L0oooo0?ooo`0K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool0
00h0oooo00<000000?ooo`3oool0F03oool01@0000008>`7023/1`0Pk0L0oooo01808>`71@3oool3
023/1`030?ooo`0Pk0L08>`700X08>`70P3oool00`0Pk0L0oooo0?ooo`0K0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool01@00
00008>`7023/1`0Pk0L0oooo01808>`71@3oool3023/1`030?ooo`0Pk0L08>`700X08>`70P3oool0
0`0Pk0L0oooo0?ooo`0K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool0
00h0oooo00<000000?ooo`3oool0F03oool01@0000008>`7023/1`0Pk0L0oooo01808>`71@3oool3
023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`3oool07@3oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo0100oooo000>0?ooo`030000003oool0oooo05P0oooo00D00000023/
1`0Pk0L08>`70?ooo`0B023/1`H0oooo0P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0
oooo01d0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`00
0000oooo0?ooo`1H0?ooo`050000000Pk0L08>`7023/1`3oool04P0Pk0L60?ooo`808>`700<0oooo
023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`0M0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool01@0000008>`7023/1`0Pk0L0
oooo01808>`71P3oool2023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`3oool07@3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000>0?ooo`030000003oool0oooo
05P0oooo00D00000023/1`0Pk0L08>`70?ooo`0B023/1`H0oooo0P0Pk0L00`3oool08>`7023/1`0:
023/1`030?ooo`0Pk0L0oooo01d0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@
0?ooo`003P3oool00`000000oooo0?ooo`1H0?ooo`050000000Pk0L08>`7023/1`3oool04P0Pk0L6
0?ooo`808>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`0M0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool01@00
00008>`7023/1`0Pk0L0oooo01408>`71`3oool2023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo
023/1`3oool07@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000>0?oo
o`030000003oool0oooo05P0oooo00D00000023/1`0Pk0L08>`70?ooo`0A023/1`L0oooo0P0Pk0L0
0`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo01d0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1H0?ooo`050000000Pk0L08>`7
023/1`3oool04@0Pk0L70?ooo`808>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`0M
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?oo
o`3oool0F03oool01@0000008>`7023/1`0Pk0L0oooo01408>`71`3oool2023/1`030?ooo`0Pk0L0
8>`700X08>`700<0oooo023/1`3oool07@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo0100oooo000>0?ooo`030000003oool0oooo05P0oooo00D00000023/1`0Pk0L08>`70?ooo`0A
023/1`L0oooo0P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo01d0oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1H0?oo
o`050000000Pk0L08>`7023/1`3oool03`0Pk0L00`3oool08>`70?ooo`060?ooo`808>`700<0oooo
023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`0M0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool01@0000008>`7023/1`0Pk0L0
oooo00l08>`700<0oooo023/1`3oool01P3oool2023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo
023/1`3oool07@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000>0?oo
o`030000003oool0oooo05P0oooo00D00000023/1`0Pk0L08>`70?ooo`0?023/1`030?ooo`0Pk0L0
oooo00H0oooo0P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo01d0oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1H0?oo
o`050000000Pk0L08>`7023/1`3oool03`0Pk0L00`3oool08>`70?ooo`060?ooo`808>`700<0oooo
023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`0M0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool01@0000008>`7023/1`0Pk0L0
oooo00l08>`700<0oooo023/1`3oool01P3oool2023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo
023/1`3oool07@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000>0?oo
o`030000003oool0oooo05P0oooo00D00000023/1`0Pk0L08>`70?ooo`0?023/1`030?ooo`0Pk0L0
oooo00H0oooo0P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo01d0oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1H0?oo
o`050000000Pk0L08>`7023/1`3oool03`0Pk0L00`3oool08>`70?ooo`060?ooo`808>`700<0oooo
023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`0M0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool01@0000008>`7023/1`0Pk0L0
oooo00l08>`700<0oooo023/1`3oool01P3oool2023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo
023/1`3oool07@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000>0?oo
o`030000003oool0oooo05P0oooo00D00000023/1`0Pk0L08>`70?ooo`0A023/1`L0oooo0P0Pk0L0
0`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo01d0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1H0?ooo`050000000Pk0L08>`7
023/1`3oool04@0Pk0L70?ooo`808>`700<0oooo023/1`0Pk0L02P0Pk0L00`3oool08>`70?ooo`0M
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?oo
o`3oool0F03oool01@0000008>`7023/1`0Pk0L0oooo01408>`71`3oool2023/1`030?ooo`0Pk0L0
8>`700X08>`700<0oooo023/1`3oool07@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo0100oooo000>0?ooo`030000003oool0oooo05P0oooo00D000000?ooo`0Pk0L08>`70?ooo`0A
023/1`L0oooo0P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0oooo01d0oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`1H0?oo
o`050000003oool08>`7023/1`3oool04@0Pk0L70?ooo`808>`700<0oooo023/1`0Pk0L02P0Pk0L0
0`3oool08>`70?ooo`0M0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool0
00h0oooo00<000000?ooo`3oool0F03oool01@000000oooo023/1`0Pk0L0oooo01408>`71`3oool2
023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`3oool07@3oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo0100oooo000>0?ooo`030000003oool0oooo05P0oooo00D000000?oo
o`0Pk0L08>`70?ooo`0A023/1`L0oooo0P0Pk0L00`3oool08>`7023/1`0:023/1`030?ooo`0Pk0L0
oooo01d0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`00
0000oooo0?ooo`1H0?ooo`050000003oool08>`7023/1`3oool0400Pk0L80?ooo`l08>`700<0oooo
023/1`3oool07@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000>0?oo
o`030000003oool0oooo05P0oooo00D000000?ooo`0Pk0L08>`70?ooo`0@023/1`P0oooo400Pk0LO
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?oo
o`3oool0F03oool01@000000oooo023/1`0Pk0L0oooo01008>`72@3oool2023/1`030?ooo`0Pk0L0
8>`700X08>`77`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000>0?oo
o`030000003oool0oooo05P0oooo00D000000?ooo`0Pk0L08>`70?ooo`0@023/1`T0oooo0P0Pk0L0
0`3oool08>`7023/1`0:023/1al0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@
0?ooo`003P3oool00`000000oooo0?ooo`1H0?ooo`050000003oool08>`7023/1`3oool0400Pk0L9
0?ooo`808>`700<0oooo023/1`0Pk0L02P0Pk0LO0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0F03oool01@000000oooo023/1`0Pk0L0
oooo01008>`72@3oool2023/1`030?ooo`0Pk0L08>`700X08>`77`3oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo0100oooo000>0?ooo`030000003oool0oooo05P0oooo00D000000?oo
o`0Pk0L08>`70?ooo`0:023/1`030?ooo`0Pk0L08>`700<08>`72@3oool2023/1`030?ooo`0Pk0L0
8>`700X08>`77`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000>0?oo
o`030000003oool0oooo05P0oooo00D000000?ooo`0Pk0L08>`70?ooo`0@023/1`T0oooo0P0Pk0L0
0`3oool08>`7023/1`08023/1`030?ooo`0Pk0L0oooo01h0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0@0?ooo`003@3oool00`000000oooo0?ooo`1I0?ooo`050000003oool08>`7
023/1`3oool0400Pk0L90?ooo`808>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`70?ooo`0N
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool000d0oooo00<000000?oo
o`3oool0F@3oool01@000000oooo023/1`0Pk0L0oooo00h08>`700<0oooo023/1`3oool0203oool2
023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`3oool07P3oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo0100oooo000=0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`0Pk0L0400Pk0L00`3oool08>`70?ooo`080?ooo`808>`700<0oooo023/1`0Pk0L0200Pk0L00`3o
ool08>`70?ooo`0N0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool000d0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo023/1`0@023/1`030?ooo`0Pk0L0oooo00P0
oooo0P0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L0oooo01h0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0@0?ooo`003@3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool08>`701008>`700<0oooo023/1`3oool0203oool2023/1`030?ooo`0Pk0L08>`700P08>`7
00<0oooo023/1`3oool07P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo
000=0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`0Pk0L0400Pk0L00`3oool08>`70?oo
o`080?ooo`808>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`70?ooo`0N0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0403oool000d0oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo023/1`0B023/1`T0oooo0P0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L0
oooo01h0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003@3oool00`00
0000oooo0?ooo`1I0?ooo`030000003oool08>`701808>`72@3oool2023/1`030?ooo`0Pk0L08>`7
00P08>`700<0oooo023/1`3oool07P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0100oooo000=0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`0Pk0L04P0Pk0L90?ooo`80
8>`700<0oooo023/1`0Pk0L0200Pk0L00`3oool08>`70?ooo`0N0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool0403oool000d0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
023/1`0B023/1`T0oooo0P0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L0oooo01h0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003@3oool00`000000oooo0?oo
o`1I0?ooo`030000003oool08>`701808>`72@3oool2023/1`030?ooo`0Pk0L08>`700P08>`700<0
oooo023/1`3oool07P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000=
0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`0Pk0L04P0Pk0L90?ooo`808>`700<0oooo
023/1`0Pk0L0200Pk0L00`3oool08>`70?ooo`0N0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool0403oool000d0oooo00<000000?ooo`3oool0F@3oool00`000000oooo023/1`0B023/
1`T0oooo0P0Pk0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L0oooo01h0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003@3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool08>`701408>`72P3oool2023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`3o
ool07P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000=0?ooo`030000
003oool0oooo05T0oooo00<000000?ooo`0Pk0L04@0Pk0L:0?ooo`808>`700<0oooo023/1`0Pk0L0
200Pk0L00`3oool08>`70?ooo`0N0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
403oool000d0oooo00<000000?ooo`3oool0F@3oool00`000000oooo023/1`0A023/1`X0oooo0P0P
k0L00`3oool08>`7023/1`08023/1`030?ooo`0Pk0L0oooo01h0oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0@0?ooo`003@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0
8>`701408>`72P3oool2023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`3oool07P3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000=0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`0Pk0L04@0Pk0L:0?ooo`808>`700<0oooo023/1`0Pk0L0200Pk0L00`3o
ool08>`70?ooo`0N0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool000d0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo023/1`0A023/1`X0oooo0P0Pk0L00`3oool0
8>`7023/1`08023/1`030?ooo`0Pk0L0oooo01h0oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0@0?ooo`003@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool08>`701408>`7
2P3oool2023/1`030?ooo`0Pk0L08>`700P08>`700<0oooo023/1`3oool07P3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0100oooo000=0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`0Pk0L04@0Pk0L:0?ooo`808>`700<0oooo023/1`0Pk0L02@0Pk0LP0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0403oool000d0oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo023/1`0A023/1`/0oooo00<08>`70?ooo`0Pk0L02P0Pk0LP0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0403oool000d0oooo00<000000?ooo`3oool0F@3oool00`00
0000oooo023/1`0A023/1`/0oooo00<08>`70?ooo`0Pk0L02P0Pk0LP0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool0403oool000d0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo023/1`02023/1`030?ooo`0Pk0L08>`700`08>`72`3oool00`0Pk0L0oooo023/1`0:023/1b00
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003@3oool00`000000oooo
0?ooo`1I0?ooo`030000003oool08>`700808>`700<0oooo023/1`0Pk0L0300Pk0L;0?ooo`03023/
1`3oool08>`700X08>`7803oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo
000=0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`0Pk0L00P0Pk0L00`3oool08>`7023/
1`0:023/1`030?ooo`0Pk0L0oooo00X0oooo3@0Pk0LP0?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool0403oool000d0oooo00<000000?ooo`3oool0F@3oool00`000000oooo023/1`02
023/1`030?ooo`0Pk0L08>`700X08>`700<0oooo023/1`3oool02P3oool=023/1b00oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`003@3oool00`000000oooo0?ooo`1I0?oo
o`030000003oool08>`700808>`700<0oooo023/1`0Pk0L0300Pk0L;0?ooo`d08>`7803oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo000=0?ooo`030000003oool0oooo05T0
oooo00<000000?ooo`3oool00P0Pk0L00`3oool08>`7023/1`0<023/1`/0oooo3@0Pk0LP0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0403oool000d0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`02023/1`030?ooo`0Pk0L08>`700`08>`72`3oool=023/1b00oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?oo
o`1I0?ooo`030000003oool0oooo00808>`700<0oooo023/1`0Pk0L0300Pk0L;0?ooo`d08>`7803o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool00P0Pk0L00`3oool08>`7023/1`0<023/1`/0oooo3@0Pk0LP
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`02023/1`030?ooo`0Pk0L08>`700`08>`72`3oool=023/
1b00oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo00808>`700<0oooo023/1`0Pk0L02`0Pk0L<0?ooo`d0
8>`7803oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000
003oool0oooo05T0oooo00<000000?ooo`3oool00P0Pk0L00`3oool08>`7023/1`0;023/1``0oooo
3@0Pk0LP0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`02023/1`030?ooo`0Pk0L08>`700/08>`7303o
ool;023/1`030?ooo`0Pk0L0oooo01l0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0?0?ooo`003@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00808>`700<0oooo
023/1`0Pk0L01P0Pk0L00`3oool08>`7023/1`02023/1``0oooo2`0Pk0L00`3oool08>`70?ooo`0O
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`02023/1`030?ooo`0Pk0L08>`700/08>`7303oool;023/
1`030?ooo`0Pk0L0oooo01l0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?oo
o`003@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00808>`700<0oooo023/1`0P
k0L02`0Pk0L<0?ooo`/08>`700<0oooo023/1`3oool07`3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0
0P0Pk0L00`3oool08>`7023/1`0;023/1``0oooo2`0Pk0L00`3oool08>`70?ooo`0O0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`02023/1`030?ooo`0Pk0L08>`700/08>`7303oool2023/1`030?ooo`0P
k0L08>`700H08>`700<0oooo023/1`3oool07`3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00@000000?ooo`3oool0oooo0P0P
k0L00`3oool08>`7023/1`0;023/1``0oooo0P0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0P
k0L0oooo01l0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool0
0`000000oooo0?ooo`1H0?ooo`040000003oool0oooo0?ooo`808>`700<0oooo023/1`0Pk0L02`0P
k0L<0?ooo`808>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`70?ooo`0O0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool0
10000000oooo0?ooo`3oool2023/1`030?ooo`0Pk0L08>`700/08>`7303oool2023/1`030?ooo`0P
k0L08>`700H08>`700<0oooo023/1`3oool07`3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00@000000?ooo`3oool0oooo0P0P
k0L00`3oool08>`7023/1`0;023/1``0oooo0P0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0P
k0L0oooo01l0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool0
0`000000oooo0?ooo`1H0?ooo`040000003oool0oooo0?ooo`808>`700<0oooo023/1`0Pk0L02`0P
k0L<0?ooo`808>`700<0oooo023/1`0Pk0L01P0Pk0L00`3oool08>`70?ooo`0O0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool0
10000000oooo0?ooo`3oool2023/1`030?ooo`0Pk0L08>`700/08>`7303oool2023/1`030?ooo`0P
k0L08>`700H08>`700<0oooo023/1`3oool07`3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00@000000?ooo`3oool0oooo0P0P
k0L00`3oool08>`7023/1`0;023/1``0oooo0P0Pk0L00`3oool08>`7023/1`06023/1`030?ooo`0P
k0L0oooo01l0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool0
0`000000oooo0?ooo`1H0?ooo`040000003oool0oooo0?ooo`808>`700<0oooo023/1`0Pk0L02`0P
k0L=0?ooo`03023/1`3oool08>`700P08>`78@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00@000000?ooo`3oool0oooo0P0P
k0L00`3oool08>`7023/1`0;023/1`d0oooo00<08>`70?ooo`0Pk0L0200Pk0LQ0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool0
10000000oooo0?ooo`3oool2023/1`030?ooo`0Pk0L08>`700/08>`73@3oool00`0Pk0L0oooo023/
1`08023/1b40oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool0
0`000000oooo0?ooo`1H0?ooo`040000003oool0oooo0?ooo`808>`700<0oooo023/1`0Pk0L02`0P
k0L=0?ooo`03023/1`3oool08>`700P08>`78@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00@000000?ooo`3oool0oooo0P0P
k0L00`3oool08>`7023/1`0;023/1`d0oooo00<08>`70?ooo`0Pk0L0200Pk0LQ0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool0
10000000oooo0?ooo`3oool2023/1`030?ooo`0Pk0L08>`700X08>`73P3oool00`0Pk0L0oooo023/
1`08023/1b40oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool0
0`000000oooo0?ooo`1H0?ooo`040000003oool0oooo0?ooo`808>`700<0oooo023/1`0Pk0L02P0P
k0L>0?ooo`03023/1`3oool08>`700P08>`78@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00@000000?ooo`3oool0oooo0P0P
k0L00`3oool08>`7023/1`0:023/1`h0oooo00<08>`70?ooo`0Pk0L0200Pk0LQ0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool0
10000000oooo0?ooo`3oool2023/1`030?ooo`0Pk0L08>`700X08>`73P3oool00`0Pk0L0oooo023/
1`08023/1b40oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool0
0`000000oooo0?ooo`1H0?ooo`040000003oool0oooo0?ooo`808>`700<0oooo023/1`0Pk0L02P0P
k0L>0?ooo`/08>`78@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000=
0?ooo`030000003oool0oooo05P0oooo00@000000?ooo`3oool0oooo0P0Pk0L00`3oool08>`7023/
1`0:023/1`h0oooo2`0Pk0LQ0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3o
ool000d0oooo00<000000?ooo`3oool0F03oool010000000oooo0?ooo`3oool2023/1`030?ooo`0P
k0L08>`700X08>`73P3oool;023/1b40oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0?0?ooo`003@3oool00`000000oooo0?ooo`1H0?ooo`040000003oool0oooo0?ooo`l08>`73P3o
ool;023/1b40oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool0
0`000000oooo0?ooo`1H0?ooo`040000003oool0oooo0?ooo`l08>`73P3oool;023/1b40oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`1H
0?ooo`040000003oool0oooo0?ooo`l08>`73P3oool;023/1b40oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`1H0?ooo`040000003oool0
oooo0?ooo`l08>`73P3oool;023/1b40oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0?0?ooo`003@3oool00`000000oooo0?ooo`1H0?ooo`040000003oool0oooo0?ooo`l08>`73P3o
ool;023/1b40oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool0
0`000000oooo0?ooo`1H0?ooo`040000003oool0oooo0?ooo`l08>`73P3oool;023/1b40oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`1H
0?ooo`040000003oool0oooo0?ooo`l08>`73P3oool;023/1b40oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo0080oooo3P0Pk0L>0?ooo`/08>`78@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00P3oool>023/
1`h0oooo2`0Pk0LQ0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`020?ooo`h08>`73P3oool;023/1b40
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0080oooo3P0Pk0L>0?ooo`/08>`78@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool00P3oool>023/1`h0oooo2`0Pk0LQ0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`02
0?ooo`h08>`73P3oool9023/1`030?ooo`0Pk0L0oooo0200oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
0080oooo2@0Pk0L00`3oool08>`7023/1`02023/1`h0oooo2@0Pk0L00`3oool08>`70?ooo`0P0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`020?ooo`d08>`73`3oool9023/1`030?ooo`0Pk0L0oooo0200
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0080oooo3@0Pk0L?0?ooo`X08>`78P3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool00P3oool=023/1a00oooo2@0Pk0LR0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`02
0?ooo`d08>`7403oool9023/1b80oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?
0?ooo`003@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0080oooo3@0Pk0L@0?oo
o`T08>`78P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000=0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool00P3oool=023/1a00oooo2@0Pk0LR0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`020?ooo`d08>`7403oool9023/1b80oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo0080oooo3@0Pk0L@0?ooo`T08>`78P3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00P3oool=
023/1a00oooo2@0Pk0LR0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool0
00d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`020?ooo`d08>`7403oool9023/
1b80oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo0080oooo3@0Pk0L@0?ooo`T08>`78P3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool00P3oool=023/1a00oooo2@0Pk0LR0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`020?ooo`d08>`7403oool9023/1b80oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0?0?ooo`003@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0080oooo3@0Pk0L@
0?ooo`T08>`78P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000=0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool00P3oool=023/1a00oooo2@0Pk0LR0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`020?ooo`d08>`7403oool9023/1b80oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0080oooo3@0Pk0L@0?ooo`T08>`78P3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00P3o
ool=023/1a00oooo2@0Pk0LR0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3o
ool000d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`020?ooo`d08>`7403oool9
023/1b80oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo0080oooo1@0Pk0L00`3oool08>`7023/1`05023/
1a00oooo2@0Pk0LR0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`020?ooo`D08>`700<0oooo023/1`0P
k0L0100Pk0LA0?ooo`T08>`78P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00l0
oooo000=0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00P3oool5023/1`030?oo
o`0Pk0L08>`700@08>`74@3oool9023/1b80oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0080oooo0P0P
k0L0103oool08>`7023/1`3oool6023/1a40oooo2@0Pk0LR0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`020?ooo`808>`700@0oooo023/1`0Pk0L0oooo1P0Pk0LA0?ooo`T08>`78P3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool00P3oool2023/1`040?ooo`0Pk0L08>`70?ooo`H08>`74@3oool9023/1b80oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo0080oooo0P0Pk0L0103oool08>`7023/1`3oool6023/1a40oooo
2@0Pk0LR0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`020?ooo`808>`700@0oooo023/1`0Pk0L0oooo
1P0Pk0LA0?ooo`T08>`78P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00l0oooo
000=0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00P3oool2023/1`040?ooo`0P
k0L08>`70?ooo`H08>`74@3oool9023/1b80oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0080oooo0P0P
k0L0103oool08>`7023/1`3oool6023/1a40oooo200Pk0LS0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`020?ooo`808>`700@0oooo023/1`0Pk0L0oooo1P0Pk0LB0?ooo`L08>`78`3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool00P3oool2023/1`040?ooo`0Pk0L08>`70?ooo`H08>`74P3oool7023/1b<0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo0080oooo0P0Pk0L00`3oool08>`7023/1`07023/1a80oooo1`0P
k0LS0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`020?ooo`808>`700<0oooo023/1`0Pk0L01`0Pk0LB
0?ooo`L08>`78`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000=0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool00`0Pk0L0oooo023/1`08023/
1a80oooo1`0Pk0LS0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`03023/1`3oool08>`700P0
8>`74P3oool7023/1b<0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`00
3@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo00<08>`70?ooo`0Pk0L0
200Pk0LB0?ooo`L08>`78`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00l0oooo
000=0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool00`0Pk0L0oooo023/
1`08023/1a80oooo1`0Pk0LS0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3o
ool000d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`03023/1`3oool0
8>`700@08>`700@0oooo023/1`0Pk0L08>`74P3oool7023/1b<0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo00<0oooo00<08>`70?ooo`0Pk0L0200Pk0LB0?ooo`L08>`78`3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool00`3oool00`0Pk0L0oooo023/1`08023/1a80oooo1`0Pk0LS0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`030?ooo`03023/1`3oool08>`700L08>`74`3oool7023/1b<0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo00<0oooo00<08>`70?ooo`0Pk0L01`0Pk0LC0?ooo`L08>`78`3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool00`3oool00`0Pk0L0oooo023/1`07023/1a<0oooo1`0Pk0LS0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`030?ooo`03023/1`3oool08>`700L08>`74`3oool7023/1b<0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo00<0oooo00<08>`70?ooo`0Pk0L01`0Pk0LC0?ooo`L08>`78`3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000<0?ooo`030000003oool0oooo05T0
oooo00<000000?ooo`3oool00`3oool:023/1a<0oooo1`0Pk0LS0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool03`3oool000`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`030?ooo`X08>`74`3oool7023/1b<0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0?0?ooo`00303oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00<0oooo2P0P
k0LC0?ooo`L08>`78`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000<
0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool00`3oool:023/1a<0oooo1`0Pk0LS
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000`0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`030?ooo`X08>`74`3oool7023/1b<0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`00303oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo00<0oooo2P0Pk0LC0?ooo`L08>`78`3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo00l0oooo000<0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0
0`3oool:023/1a<0oooo1`0Pk0LS0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
3`3oool000`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`X08>`74`3o
ool7023/1b<0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`00303oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00<0oooo2P0Pk0LC0?ooo`L08>`78`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00l0oooo000<0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool00`3oool:023/1a<0oooo1`0Pk0LS0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool03`3oool000`0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`030?ooo`X08>`74`3oool7023/1b<0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0?0?ooo`00303oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00<0oooo
2P0Pk0LD0?ooo`D08>`7903oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00l0oooo
000<0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool00`3oool:023/1a@0oooo1@0P
k0LT0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool000`0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`X08>`7503oool5023/1b@0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`00303oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo00<0oooo2P0Pk0LD0?ooo`D08>`78P3oool4000005L0oooo00<000000?oo
o`3oool03`3oool000`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`X0
8>`7503oool5023/1ah0oooo100000040?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool03`3oool000`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`T08>`7
5@3oool5023/1a/0oooo0`0000090?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
3`3oool000`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`T08>`75@3o
ool5023/1aL0oooo1000000=0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool03`3o
ool000`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`T08>`75@3oool5
023/1a<0oooo1000000B0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool03`3oool0
00`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`T08>`75@3oool5023/
1`l0oooo1000000G0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool03`3oool000`0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`T08>`75@3oool5023/1``0
oooo0`00000L0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03`3oool000`0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`T08>`75@3oool5023/1`P0oooo
1000000P0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool03`3oool000`0oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`T08>`75@3oool5023/1`@0oooo1000
000U0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool03`3oool000`0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`T08>`75@3oool5023/1`@00000:P3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00l0oooo000<0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool00`3oool9023/1aD0oooo0P0Pk0L3000002l0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`0?0?ooo`00303oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo00<0oooo2@0Pk0LC0?ooo`@000000`0Pk0L`0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool03`3oool000`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`030?ooo`T08>`73`3oool400000080oooo1@0Pk0La0?ooo`800000BP3oool00`000000oooo
0?ooo`0?0?ooo`00303oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00<0oooo2@0P
k0L;0?ooo`@000001P3oool5023/1c<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0?0?ooo`00303oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00@0oooo200Pk0L8
0?ooo`<000002P3oool5023/1c@0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?
0?ooo`00303oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00@0oooo200Pk0L40?oo
o`@000003@3oool5023/1cD0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?oo
o`00303oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00@0oooo1@0Pk0L00`3oool0
8>`7023/1`0400000140oooo1@0Pk0Lf0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool03`3oool000`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`040?ooo`@08>`7
1000000E0?ooo`D08>`7=`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00l0oooo
000<0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0103oool0100Pk0L000000000
00000004023/1aD0oooo1@0Pk0Lh0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
3`3oool000`0oooo00<000000?ooo`3oool0F@3oool010000000oooo0?ooo`3oool4000000L08>`7
5@3oool5023/1cT0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0?0?ooo`00303o
ool00`000000oooo0?ooo`1I0?ooo`@000000`3oool8023/1aD0oooo1@0Pk0Lj0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool03`3oool000`0oooo00<000000?ooo`3oool0E@3oool5
000000H0oooo200Pk0LE0?ooo`D08>`7>`3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo00h0oooo000<0?ooo`030000003oool0oooo0540oooo100000040?ooo`030000003oool0oooo
00@0oooo1`0Pk0LF0?ooo`D08>`7?03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
00h0oooo000<0?ooo`030000003oool0oooo04h0oooo0`0000080?ooo`030000003oool0oooo00@0
oooo1`0Pk0LF0?ooo`D08>`7?@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00h0
oooo000<0?ooo`030000003oool0oooo04X0oooo1000000;0?ooo`030000003oool0oooo00@0oooo
1`0Pk0LF0?ooo`@08>`7?`3oool2000003h0oooo00<000000?ooo`3oool03P3oool000`0oooo00<0
00000?ooo`3oool0AP3oool4000000l0oooo00<000000?ooo`3oool0103oool7023/1aH0oooo100P
k0M10?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03P3oool000`0oooo00<00000
0?ooo`3oool0@P3oool4000001<0oooo00<000000?ooo`3oool0103oool7023/1aH0oooo100Pk0M2
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool03P3oool000`0oooo00<000000?oo
o`3oool0?`3oool3000001L0oooo00<000000?ooo`3oool0103oool7023/1aH0oooo100Pk0M30?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool03P3oool000`0oooo00<000000?ooo`3o
ool0>`3oool4000001X0oooo00<000000?ooo`3oool0103oool7023/1aH0oooo100Pk0M40?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool03P3oool000`0oooo00<000000?ooo`3oool0
=`3oool4000001h0oooo00<000000?ooo`3oool0103oool7023/1aL0oooo0`0Pk0M50?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool03P3oool000`0oooo00<000000?ooo`3oool0<`3o
ool400000280oooo00<000000?ooo`3oool0103oool7023/1aL0oooo0`0Pk0M60?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool03P3oool000`0oooo00<000000?ooo`3oool0<03oool3
000002H0oooo00<000000?ooo`3oool0103oool7023/1aL0oooo0`0Pk0M70?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool03P3oool000`0oooo00<000000?ooo`3oool0;03oool40000
02T0oooo00<000000?ooo`3oool0103oool7023/1aL0oooo0`0Pk0M80?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool03P3oool000`0oooo00<000000?ooo`3oool0:03oool4000002d0
oooo00<000000?ooo`3oool0103oool7023/1aL0oooo0`0Pk0M90?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool03P3oool000`0oooo00<000000?ooo`3oool0903oool400000340oooo
00<000000?ooo`3oool0103oool7023/1aL0oooo0`0Pk0M:0?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool03P3oool000`0oooo00<000000?ooo`3oool08@3oool3000003D0oooo00<0
00000?ooo`3oool0103oool7023/1aL0oooo0`0Pk0M;0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool03P3oool000`0oooo00<000000?ooo`3oool07@3oool4000003P0oooo00<00000
0?ooo`3oool0103oool00`0Pk0L0oooo023/1`04023/1aL0oooo0`0Pk0M<0?ooo`800000<@3oool0
0`000000oooo0?ooo`0>0?ooo`00303oool00`000000oooo0?ooo`0I0?ooo`@00000?03oool00`00
0000oooo0?ooo`040?ooo`03023/1`3oool08>`700@08>`75`3oool3023/1dh0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0>0?ooo`00303oool00`000000oooo0?ooo`0E0?ooo`@0
0000@03oool00`000000oooo0?ooo`040?ooo`03023/1`3oool08>`700@08>`75`3oool3023/1dl0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0>0?ooo`00303oool00`000000oooo
0?ooo`0B0?ooo`<00000A03oool00`000000oooo0?ooo`040?ooo`03023/1`3oool08>`700@08>`7
5`3oool3023/1e00oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0>0?ooo`00303o
ool00`000000oooo0?ooo`0>0?ooo`@00000A`3oool00`000000oooo0?ooo`040?ooo`03023/1`3o
ool08>`700@08>`75`3oool3023/1e40oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0>0?ooo`00303oool00`000000oooo0?ooo`0:0?ooo`@00000B`3oool00`000000oooo0?ooo`04
0?ooo`03023/1`3oool08>`700@08>`75`3oool3023/1e80oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0>0?ooo`00303oool00`000000oooo0?ooo`060?ooo`@00000C`3oool00`00
0000oooo0?ooo`040?ooo`03023/1`3oool08>`700<08>`7603oool3023/1e<0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0>0?ooo`00303oool00`000000oooo0?ooo`030?ooo`<0
0000D`3oool00`000000oooo0?ooo`040?ooo`03023/1`3oool08>`700<08>`7603oool3023/1e@0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0>0?ooo`00303oool00`000000oooo
00000003000005H0oooo00<000000?ooo`3oool0103oool6023/1aP0oooo0`0Pk0ME0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool03P3oool000`0oooo0P00001J0?ooo`030000003o
ool0oooo00@0oooo1P0Pk0LH0?ooo`<08>`7EP3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00h0oooo000>0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0103oool6
023/1aP0oooo0`0Pk0MG0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool03P3oool0
00l0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`040?ooo`H08>`7603oool3023/
1eP0oooo0P00000U0?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool0103oool6023/1aP0oooo0`0Pk0MJ0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool03P3oool00140oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`040?ooo`H08>`7603oool3023/1e/0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0>0?ooo`004P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00@0oooo1P0P
k0LH0?ooo`<08>`7G03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00h0oooo000C
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0103oool6023/1aP0oooo0P0Pk0MN
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03P3oool001@0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`040?ooo`H08>`7603oool2023/1el0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0>0?ooo`005@3oool200000540oooo00<000000?ooo`3o
ool01@3oool5023/1aP0oooo0P0Pk0MP0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool03P3oool001L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`D08>`7
603oool2023/1f40oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`00603o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00D0oooo1@0Pk0LH0?ooo`808>`7HP3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00h0oooo000I0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool01@3oool5023/1aP0oooo0P0Pk0MS0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool03P3oool001X0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`050?ooo`D08>`7603oool2023/1f@0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0>0?ooo`006`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00D0
oooo1@0Pk0LH0?ooo`808>`7I@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00h0
oooo000L0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool01@3oool5023/1aP0oooo
0P0Pk0MV0?ooo`800000603oool00`000000oooo0?ooo`0>0?ooo`007@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo00D0oooo1@0Pk0LH0?ooo`808>`7J03oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00h0oooo000N0?ooo`800000B03oool00`000000oooo0?ooo`05
0?ooo`D08>`7603oool2023/1fT0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0>
0?ooo`00803oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00D0oooo1@0Pk0LH0?oo
o`808>`7JP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00h0oooo000Q0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool01@3oool4023/1aT0oooo0P0Pk0M[0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool00280oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`050?ooo`@08>`7603oool4000006/0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0>0?ooo`008`3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00D0oooo100Pk0LH0?ooo`@00000K03oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00h0oooo000T0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool01@3oool4
023/1hT0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00D0oooo100Pk0N:0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool002H0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`050?ooo`@08>`7R`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo000W0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool4023/1h`0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`00:03oool2000003h0oooo00<0
00000?ooo`3oool01@3oool4023/1hd0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0>0?ooo`00:P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00D0oooo0P000000
0`0Pk0L000000000002=0?ooo`8000002`3oool00`000000oooo0?ooo`0>0?ooo`00:`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00D0oooo0`0000000`0Pk0L000000?ooo`2>0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool002`0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`050?ooo`D00000T03oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00h0oooo000]0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo000^0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00h0oooo000_0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0W@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo000`0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00h0oooo000a0?ooo`800000=@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03P3oool003<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`2P0?ooo`050000003oool0oooo0?ooo`000000403oool003@0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2Q0?ooo`040000003oool0oooo00000100oooo000e0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0XP3oool00`000000oooo0000000@0?ooo`00=P3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0:<0oooo0P00000@0?ooo`00=`3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0:80oooo0`00000@0?ooo`00>03oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo09h0oooo1000000C0?ooo`00>@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo09/0oooo0`00000G0?ooo`00>P3oool2000002`0oooo
00<000000?ooo`3oool0U`3oool4000001X0oooo000l0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0T`3oool4000001h0oooo000m0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0S`3oool400000280oooo000n0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0R`3oool4000002H0oooo000o0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0R03oool3000002X0oooo00100?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
Q03oool4000002d0oooo00110?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0P03o
ool400000340oooo00120?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0O03oool4
000003D0oooo00130?ooo`8000008`3oool00`000000oooo0?ooo`1h0?ooo`@00000>@3oool004D0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1e0?ooo`<00000?@3oool004H0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1a0?ooo`@00000@03oool004L0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1]0?ooo`@00000A03oool004P0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1Y0?ooo`@00000B03oool004T0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`1U0?ooo`@00000C03oool004X0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`1R0?ooo`<00000D03oool004/0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1N0?ooo`@00000D`3oool004`0oooo0P00000J0?ooo`030000003o
ool0oooo05X0oooo1000001G0?ooo`00CP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo05H0oooo1000001K0?ooo`00C`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0580oooo1000001O0?ooo`00D03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04l0
oooo0`00001S0?ooo`00D@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04/0oooo
1000001V0?ooo`00DP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04L0oooo1000
001Z0?ooo`00D`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04<0oooo1000001^
0?ooo`00E03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03l0oooo1000001b0?oo
o`00E@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03`0oooo0`00001f0?ooo`00
EP3oool200000100oooo00<000000?ooo`3oool0>03oool4000007T0oooo001H0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0=03oool4000007d0oooo001I0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0<03oool400000840oooo001J0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0;03oool4000008D0oooo001K0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0:@3oool3000008T0oooo001L0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool09@3oool4000008`0oooo001M0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool08@3oool400000900oooo001N0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool07@3oool4000009@0oooo001O0?ooo`8000001`3oool00`000000oooo0?ooo`0I0?oo
o`@00000V03oool00640oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0F0?ooo`<0
0000W03oool00680oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`@00000
W`3oool006<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`@00000X`3o
ool006@0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`@00000Y`3oool006D0oooo00@00000
0?ooo`3oool00000203oool400000:/0oooo001V0?ooo`030000003oool0000000D0oooo0`00002_
0?ooo`00I`3oool2000000030?ooo`000000000000800000/P3oool006P0oooo0P00002f0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {2673.75, 0}} -> {0.449861, 0.0702776, \
0.000348258, 0.000348258}},
  CellTags->"Laser Radar Example"],

Cell[BoxData[
    \({194.2833333333333`\ Second, Null}\)], "Output",
  CellTags->"Laser Radar Example"]
}, Open  ]],

Cell[TextData[{
  "Finally, we are ready to run the actual trace of the forest with more \
rays. In the previous simulation, we stored all of the traced ray segments \
from every optical surface in order to get a visual picture about what was \
happening throughout the trace. This, however, consumes much more computer \
memory than if we only store the information at the last optical surface.  \
This time we will only report the rays that reach the detector pupil surface \
(with ",
  StyleBox["PlotType->Surface", "Input"],
  " and ",
  StyleBox["ReportedSurfaces->Last", "Input"],
  "). In addition, we will now nearly superimpose the light source and \
detector positions, but with the detector surface placed at a slightly higher \
position than the light source to prevent any untraced rays from affecting \
the results."
}], "Text",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{

Cell["\<\
Timing[res = TurboPlot[
\t{Move[GaussianBeam[20, .05, NumberOfRays->50, MonteCarlo->Stratified, \
FullForm->True, SpatialScale->1/10], {0,0,50000},{0,0,-1},0],
\tfocusedtreecomposite,
\tMove[Screen[25],{0,0,50001},{0,0,1},0]}, PlotType->Surface, \
ReportedSurfaces->Last,
\tCreateClones->treepositions, RunningCommentary->TurboTrace];]\
\>", "Input",\

  CellTags->"Laser Radar Example"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00551 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.49474 0.0385161 0.502754 0.0385161 [
[ 0 0 0 0 ]
[ 1 1.00551 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.127 .923 .03 r
2.5 Mabswid
.68497 .47972 Mdot
.67505 .38865 Mdot
.31737 .64373 Mdot
.30565 .75148 Mdot
.51485 .41281 Mdot
.65643 .20782 Mdot
.19782 .50824 Mdot
.62631 .77474 Mdot
.31124 .25919 Mdot
.43218 .80332 Mdot
.44558 .39579 Mdot
.6532 .34994 Mdot
.16931 .25039 Mdot
.45371 .83758 Mdot
.62041 .20601 Mdot
.30078 .7519 Mdot
.59605 .8154 Mdot
.70207 .61864 Mdot
.37018 .82527 Mdot
.57855 .55199 Mdot
.50613 .78667 Mdot
.33207 .50034 Mdot
.12098 .56919 Mdot
.26063 .76842 Mdot
.79545 .25729 Mdot
.65373 .28497 Mdot
.53354 .41225 Mdot
.25179 .65519 Mdot
.3808 .30459 Mdot
.33562 .20067 Mdot
.17231 .39651 Mdot
.34183 .3178 Mdot
.69448 .42535 Mdot
.4665 .22517 Mdot
.26082 .56614 Mdot
.80066 .39238 Mdot
.57703 .35538 Mdot
.40525 .51946 Mdot
.54645 .57138 Mdot
.74528 .60702 Mdot
.53983 .36481 Mdot
.13968 .36776 Mdot
.76298 .56807 Mdot
.70526 .54762 Mdot
.28754 .4136 Mdot
.70811 .29195 Mdot
.41289 .15287 Mdot
.40706 .38905 Mdot
.32841 .3132 Mdot
.49959 .18755 Mdot
.54702 .57215 Mdot
.48496 .86766 Mdot
.19732 .48932 Mdot
.32433 .4157 Mdot
.53249 .75178 Mdot
.32307 .75829 Mdot
.60877 .70796 Mdot
.66515 .18759 Mdot
.57262 .79979 Mdot
.66294 .59862 Mdot
.61908 .18072 Mdot
.65129 .48748 Mdot
.33261 .71835 Mdot
.37743 .47019 Mdot
.47777 .75573 Mdot
.42004 .18133 Mdot
.57637 .28736 Mdot
.54506 .17212 Mdot
.73978 .59907 Mdot
.32107 .60037 Mdot
.4359 .59173 Mdot
.53198 .75513 Mdot
.53856 .57906 Mdot
.40112 .53342 Mdot
.45562 .44128 Mdot
.62906 .11668 Mdot
.40417 .84592 Mdot
.66944 .34824 Mdot
.70702 .40943 Mdot
.7238 .65545 Mdot
.11694 .46582 Mdot
.42511 .55347 Mdot
.31238 .46765 Mdot
.34675 .09458 Mdot
.13575 .60978 Mdot
.52049 .18052 Mdot
.2991 .41689 Mdot
.33202 .48939 Mdot
.42425 .61015 Mdot
.32679 .54835 Mdot
.71013 .62416 Mdot
.77538 .27788 Mdot
.70676 .61486 Mdot
.57313 .73279 Mdot
.5262 .68642 Mdot
.60229 .46408 Mdot
.71146 .56611 Mdot
.65111 .79042 Mdot
.48253 .36173 Mdot
.17511 .37184 Mdot
.65871 .14864 Mdot
.75106 .55124 Mdot
.33053 .40689 Mdot
.4968 .32952 Mdot
.22522 .67826 Mdot
.47238 .78327 Mdot
.51492 .66934 Mdot
.21678 .45025 Mdot
.30316 .30567 Mdot
.19644 .19829 Mdot
.28046 .74495 Mdot
.56933 .31237 Mdot
.49146 .79769 Mdot
.56162 .46715 Mdot
.5756 .20136 Mdot
.86518 .48664 Mdot
.21004 .44234 Mdot
.44089 .27356 Mdot
.65012 .51135 Mdot
.2905 .67119 Mdot
.69179 .31562 Mdot
.23196 .6587 Mdot
.51519 .83955 Mdot
.34731 .79818 Mdot
.54553 .34187 Mdot
.70659 .49802 Mdot
.36828 .54101 Mdot
.46278 .33327 Mdot
.65828 .78768 Mdot
.49138 .66273 Mdot
.44663 .45233 Mdot
.33689 .38851 Mdot
.25923 .70032 Mdot
.72137 .62353 Mdot
.36145 .2122 Mdot
.67777 .60963 Mdot
.70216 .71627 Mdot
.84248 .61218 Mdot
.7161 .20318 Mdot
.23727 .72693 Mdot
.29577 .16667 Mdot
.30006 .88916 Mdot
.28839 .46285 Mdot
.79273 .48817 Mdot
.37223 .64415 Mdot
.55738 .74758 Mdot
.26886 .59952 Mdot
.73165 .43312 Mdot
.65393 .78131 Mdot
.35673 .60446 Mdot
.46316 .46676 Mdot
.27346 .56882 Mdot
.67231 .63609 Mdot
.37811 .80014 Mdot
.77187 .54125 Mdot
.40286 .20494 Mdot
.81785 .48012 Mdot
.45358 .37704 Mdot
.16627 .72375 Mdot
.4763 .52627 Mdot
.24609 .52066 Mdot
.23258 .60273 Mdot
.73715 .6909 Mdot
.83061 .28558 Mdot
.64476 .29914 Mdot
.44064 .69863 Mdot
.5479 .46664 Mdot
.46184 .48376 Mdot
.63015 .2767 Mdot
.5229 .6031 Mdot
.70145 .1201 Mdot
.55772 .68954 Mdot
.40071 .66644 Mdot
.41935 .33309 Mdot
.53707 .40343 Mdot
.50872 .66478 Mdot
.44927 .6757 Mdot
.51464 .86793 Mdot
.76425 .72547 Mdot
.64514 .76715 Mdot
.26721 .26773 Mdot
.3404 .77034 Mdot
.20648 .51059 Mdot
.279 .44195 Mdot
.50745 .64427 Mdot
.72829 .65046 Mdot
.60901 .57247 Mdot
.75794 .47485 Mdot
.33558 .4994 Mdot
.71267 .87269 Mdot
.74802 .31989 Mdot
.35232 .402 Mdot
.80789 .25421 Mdot
.28578 .41045 Mdot
.29046 .5635 Mdot
.41463 .48961 Mdot
.32606 .51635 Mdot
.54737 .61186 Mdot
.53272 .74471 Mdot
.6979 .52743 Mdot
.37663 .36962 Mdot
.12029 .62306 Mdot
.18379 .64007 Mdot
.81707 .54318 Mdot
.80679 .63683 Mdot
.1825 .61522 Mdot
.55123 .72125 Mdot
.52387 .16119 Mdot
.71862 .26617 Mdot
.34724 .16648 Mdot
.63808 .30712 Mdot
.78842 .4237 Mdot
.35295 .76132 Mdot
.23038 .6109 Mdot
.48446 .72965 Mdot
.42517 .3967 Mdot
.83769 .50204 Mdot
.41531 .53073 Mdot
.50063 .43341 Mdot
.55114 .74507 Mdot
.48679 .67942 Mdot
.85871 .44007 Mdot
.17446 .5658 Mdot
.67199 .39059 Mdot
.72208 .87736 Mdot
.55619 .34664 Mdot
.18824 .25757 Mdot
.717 .23789 Mdot
.47103 .40613 Mdot
.70115 .5697 Mdot
.49605 .78437 Mdot
.62784 .81336 Mdot
.215 .47471 Mdot
.39505 .32556 Mdot
.71711 .4586 Mdot
.26219 .70352 Mdot
.49846 .54711 Mdot
.69101 .66025 Mdot
.24738 .69107 Mdot
.32272 .82853 Mdot
.22852 .35509 Mdot
.20616 .58108 Mdot
.61464 .81296 Mdot
.47051 .92703 Mdot
.4918 .37508 Mdot
.53203 .3107 Mdot
.4855 .3477 Mdot
.34217 .28546 Mdot
.45648 .37006 Mdot
.2071 .63898 Mdot
.32786 .26102 Mdot
.5787 .47138 Mdot
.54331 .55656 Mdot
.53984 .90968 Mdot
.67298 .42184 Mdot
.24573 .72213 Mdot
.44619 .46377 Mdot
.66965 .27891 Mdot
.6601 .18595 Mdot
.21162 .61037 Mdot
.55519 .57534 Mdot
.45184 .85722 Mdot
.498 .16356 Mdot
.58304 .48947 Mdot
.61961 .31006 Mdot
.32344 .64067 Mdot
.33923 .29231 Mdot
.57054 .5355 Mdot
.69437 .21342 Mdot
.21981 .48983 Mdot
.47187 .24198 Mdot
.3924 .42456 Mdot
.60406 .42909 Mdot
.81377 .43479 Mdot
.30036 .61111 Mdot
.74015 .53797 Mdot
.37567 .62035 Mdot
.24491 .25249 Mdot
.63968 .64972 Mdot
.69488 .64228 Mdot
.77502 .43512 Mdot
.18296 .3686 Mdot
.32789 .71289 Mdot
.59674 .41501 Mdot
.33845 .28674 Mdot
.48471 .77756 Mdot
.55865 .55874 Mdot
.80586 .39873 Mdot
.2089 .4662 Mdot
.62083 .27567 Mdot
.45169 .4989 Mdot
.48714 .23674 Mdot
.20608 .50979 Mdot
.17367 .44783 Mdot
.42448 .75844 Mdot
.41163 .31214 Mdot
.1296 .42101 Mdot
.21337 .63665 Mdot
.51844 .83846 Mdot
.50217 .69041 Mdot
.71433 .70472 Mdot
.37659 .57818 Mdot
.23863 .61767 Mdot
.2373 .69669 Mdot
.85532 .61654 Mdot
.50956 .35579 Mdot
.17808 .59397 Mdot
.40855 .34954 Mdot
.64913 .55428 Mdot
.44976 .8039 Mdot
.81013 .44392 Mdot
.68729 .18812 Mdot
.78025 .29439 Mdot
.66943 .34465 Mdot
.21434 .42019 Mdot
.4362 .85498 Mdot
.30959 .20732 Mdot
.70561 .82566 Mdot
.78969 .23884 Mdot
.80788 .60705 Mdot
.54465 .41325 Mdot
.78141 .49925 Mdot
.17576 .35995 Mdot
.29925 .23948 Mdot
.271 .26434 Mdot
.55915 .55042 Mdot
.49413 .4758 Mdot
.45041 .23219 Mdot
.82361 .54645 Mdot
.27458 .42161 Mdot
.69417 .16639 Mdot
.50198 .85319 Mdot
.47776 .2021 Mdot
.25119 .60877 Mdot
.65883 .68313 Mdot
.61938 .20825 Mdot
.43844 .10771 Mdot
.17117 .67846 Mdot
.3837 .71157 Mdot
.66994 .57705 Mdot
.51187 .52771 Mdot
.2612 .32573 Mdot
.44088 .14021 Mdot
.63497 .30263 Mdot
.82211 .31966 Mdot
.77011 .43202 Mdot
.33068 .49345 Mdot
.36923 .84524 Mdot
.33045 .78764 Mdot
.51742 .52083 Mdot
.19236 .28923 Mdot
.44346 .88606 Mdot
.45316 .39364 Mdot
.39154 .66016 Mdot
.53341 .79462 Mdot
.16529 .56315 Mdot
.25506 .71195 Mdot
.30339 .8796 Mdot
.30692 .68643 Mdot
.3623 .65722 Mdot
.48471 .73928 Mdot
.64378 .43885 Mdot
.6692 .3801 Mdot
.24228 .16888 Mdot
.72959 .33268 Mdot
.4094 .70728 Mdot
.50756 .7545 Mdot
.31406 .21583 Mdot
.21915 .57519 Mdot
.64208 .7249 Mdot
.62464 .54216 Mdot
.76341 .57268 Mdot
.55786 .60638 Mdot
.36087 .88886 Mdot
.70232 .45347 Mdot
.4959 .83019 Mdot
.4698 .78205 Mdot
.49258 .8112 Mdot
.05695 .57918 Mdot
.1763 .49406 Mdot
.23386 .5895 Mdot
.29227 .45345 Mdot
.41298 .86668 Mdot
.16734 .63824 Mdot
.77654 .29364 Mdot
.32106 .80116 Mdot
.14513 .35271 Mdot
.58589 .5023 Mdot
.42472 .37408 Mdot
.72001 .59902 Mdot
.41531 .72744 Mdot
.48617 .5311 Mdot
.41672 .62802 Mdot
.47174 .19327 Mdot
.33896 .5261 Mdot
.79293 .43636 Mdot
.59948 .58673 Mdot
.60754 .45583 Mdot
.68426 .55738 Mdot
.41021 .49147 Mdot
.45057 .65206 Mdot
.37101 .55698 Mdot
.49477 .70456 Mdot
.81205 .48996 Mdot
.30789 .22796 Mdot
.26008 .47584 Mdot
.70618 .35446 Mdot
.59533 .29454 Mdot
.24492 .24329 Mdot
.25738 .2691 Mdot
.38516 .4056 Mdot
.51402 .85909 Mdot
.46787 .05468 Mdot
.64365 .74702 Mdot
.63032 .23593 Mdot
.58172 .81192 Mdot
.56741 .22894 Mdot
.21529 .51119 Mdot
.67243 .26836 Mdot
.54539 .2132 Mdot
.81725 .48474 Mdot
.51845 .58873 Mdot
.33817 .71301 Mdot
.48936 .12033 Mdot
.31744 .26013 Mdot
.8815 .44932 Mdot
.23468 .35516 Mdot
.32216 .60353 Mdot
.28514 .55656 Mdot
.54916 .82353 Mdot
.21772 .64407 Mdot
.78323 .69889 Mdot
.60246 .35881 Mdot
.62536 .50578 Mdot
.16016 .59159 Mdot
.7977 .34513 Mdot
.4875 .74536 Mdot
.63264 .201 Mdot
.31741 .27877 Mdot
.49791 .82708 Mdot
.22868 .50408 Mdot
.45898 .23261 Mdot
.42044 .2776 Mdot
.21483 .48625 Mdot
.3795 .5766 Mdot
.39431 .80913 Mdot
.63529 .3006 Mdot
.25895 .47902 Mdot
.46624 .42549 Mdot
.41662 .49129 Mdot
.30998 .43355 Mdot
.80408 .62839 Mdot
.71242 .69379 Mdot
.38491 .43645 Mdot
.61327 .27064 Mdot
.89773 .61064 Mdot
.54374 .43243 Mdot
.74724 .23072 Mdot
.46129 .18445 Mdot
.48003 .79673 Mdot
.66601 .66185 Mdot
.74145 .42468 Mdot
.52853 .47032 Mdot
.65366 .42246 Mdot
.50834 .61085 Mdot
.72372 .47947 Mdot
.64845 .65507 Mdot
.3747 .43763 Mdot
.68479 .76864 Mdot
.33925 .20169 Mdot
.39609 .16155 Mdot
.38332 .57873 Mdot
.2455 .51753 Mdot
.63241 .33663 Mdot
.44994 .93097 Mdot
.1935 .65791 Mdot
.56378 .91994 Mdot
.37688 .30119 Mdot
.24983 .27296 Mdot
.32966 .80025 Mdot
.50065 .48181 Mdot
.69189 .22467 Mdot
.43103 .93203 Mdot
.22255 .37811 Mdot
.2749 .59329 Mdot
.22582 .30253 Mdot
.59709 .72549 Mdot
.83112 .33325 Mdot
.43407 .33748 Mdot
.55242 .17247 Mdot
.50232 .66337 Mdot
.28441 .68054 Mdot
.426 .43841 Mdot
.44812 .40625 Mdot
.72354 .52432 Mdot
.75098 .50345 Mdot
.61768 .89926 Mdot
.77018 .56223 Mdot
.40205 .62699 Mdot
.83166 .55504 Mdot
.65324 .40407 Mdot
.4773 .25494 Mdot
.36288 .8452 Mdot
.82991 .62697 Mdot
.79775 .6069 Mdot
.77937 .44908 Mdot
.26435 .29442 Mdot
.50109 .62639 Mdot
.525 .63523 Mdot
.15586 .49051 Mdot
.56174 .33842 Mdot
.44474 .55431 Mdot
.60783 .3131 Mdot
.49137 .83602 Mdot
.39323 .80772 Mdot
.72776 .34759 Mdot
.36889 .41564 Mdot
.34014 .51762 Mdot
.48641 .44015 Mdot
.66436 .51655 Mdot
.56311 .34462 Mdot
.41292 .56718 Mdot
.31884 .44108 Mdot
.31686 .2485 Mdot
.34229 .44632 Mdot
.7641 .36701 Mdot
.54797 .18215 Mdot
.58308 .24522 Mdot
.62309 .50851 Mdot
.62801 .66248 Mdot
.44942 .82543 Mdot
.46198 .40004 Mdot
.65951 .16703 Mdot
.70287 .4045 Mdot
.47362 .50205 Mdot
.70507 .50584 Mdot
.59933 .49938 Mdot
.58226 .33381 Mdot
.77744 .65994 Mdot
.83897 .63146 Mdot
.68979 .40178 Mdot
.5774 .19954 Mdot
.37814 .91874 Mdot
.602 .35488 Mdot
.50349 .45776 Mdot
.73498 .58638 Mdot
.45155 .79701 Mdot
.63345 .58877 Mdot
.54212 .27406 Mdot
.40496 .52388 Mdot
.33461 .24582 Mdot
.51586 .5213 Mdot
.57749 .89139 Mdot
.70908 .64365 Mdot
.17387 .39577 Mdot
.7006 .26694 Mdot
.28455 .50134 Mdot
.6111 .44351 Mdot
.71571 .20927 Mdot
.75949 .41635 Mdot
.68412 .70155 Mdot
.32425 .60974 Mdot
.55497 .44006 Mdot
.71398 .36007 Mdot
.19547 .53784 Mdot
.68641 .52985 Mdot
.40496 .56212 Mdot
.62845 .69182 Mdot
.47529 .54585 Mdot
.37688 .71501 Mdot
.78259 .63788 Mdot
.59197 .13601 Mdot
.22919 .60462 Mdot
.33148 .70421 Mdot
.45129 .57931 Mdot
.63747 .78833 Mdot
.71875 .71377 Mdot
.42777 .77542 Mdot
.51169 .3773 Mdot
.29353 .74132 Mdot
.68937 .31688 Mdot
.80058 .47971 Mdot
.84385 .55137 Mdot
.22622 .6346 Mdot
.5906 .22466 Mdot
.66519 .68393 Mdot
.58701 .65809 Mdot
.24151 .62885 Mdot
.65982 .68357 Mdot
.65361 .90253 Mdot
.52893 .5706 Mdot
.82521 .42104 Mdot
.75824 .29892 Mdot
.38154 .39836 Mdot
.74495 .36612 Mdot
.30846 .43427 Mdot
.35979 .67675 Mdot
.53464 .23429 Mdot
.3984 .30341 Mdot
.87637 .31111 Mdot
.47388 .23947 Mdot
.54789 .28972 Mdot
.27352 .68057 Mdot
.54388 .59637 Mdot
.62772 .75261 Mdot
.58562 .8169 Mdot
.81768 .25826 Mdot
.74946 .19172 Mdot
.53248 .3668 Mdot
.20665 .76587 Mdot
.64343 .4595 Mdot
.74191 .20612 Mdot
.82831 .48549 Mdot
.3636 .29446 Mdot
.54896 .78521 Mdot
.8102 .6633 Mdot
.59841 .39538 Mdot
.28254 .48974 Mdot
.40814 .80847 Mdot
.70211 .47642 Mdot
.26681 .59284 Mdot
.35393 .19689 Mdot
.89724 .50819 Mdot
.57787 .10795 Mdot
.76327 .62299 Mdot
.45929 .56121 Mdot
.35174 .18144 Mdot
.52768 .24892 Mdot
.58018 .20567 Mdot
.30615 .72419 Mdot
.36436 .76393 Mdot
.54801 .74438 Mdot
.55046 .36206 Mdot
.68185 .54512 Mdot
.46225 .31096 Mdot
.25419 .81922 Mdot
.74114 .7308 Mdot
.28407 .31097 Mdot
.66592 .32707 Mdot
.78468 .73665 Mdot
.87949 .42617 Mdot
.45317 .68819 Mdot
.25672 .72957 Mdot
.20812 .45728 Mdot
.68958 .21157 Mdot
.5648 .31838 Mdot
.29036 .5384 Mdot
.38122 .80029 Mdot
.4839 .26717 Mdot
.69419 .74595 Mdot
.61002 .11984 Mdot
.59579 .77167 Mdot
.61247 .73363 Mdot
.76053 .62538 Mdot
.74808 .4684 Mdot
.3188 .11548 Mdot
.72207 .65899 Mdot
.24579 .22616 Mdot
.17358 .60872 Mdot
.23445 .25788 Mdot
.20086 .23276 Mdot
.41185 .34185 Mdot
.20398 .61948 Mdot
.49207 .30842 Mdot
.21829 .68545 Mdot
.37611 .46731 Mdot
.42379 .31924 Mdot
.3878 .27667 Mdot
.19489 .55728 Mdot
.72929 .58383 Mdot
.2634 .27878 Mdot
.66991 .3503 Mdot
.13909 .61579 Mdot
.27612 .6056 Mdot
.37413 .63539 Mdot
.46167 .57927 Mdot
.17776 .61136 Mdot
.10536 .49625 Mdot
.72595 .37986 Mdot
.45305 .18035 Mdot
.43637 .71158 Mdot
.53466 .78993 Mdot
.42967 .83658 Mdot
.47324 .76285 Mdot
.21408 .487 Mdot
.63094 .43124 Mdot
.50368 .28809 Mdot
.49113 .7283 Mdot
.6188 .25056 Mdot
.35727 .1817 Mdot
.16497 .23431 Mdot
.16382 .30466 Mdot
.50151 .32722 Mdot
.17063 .22491 Mdot
.35697 .51112 Mdot
.58344 .48087 Mdot
.61 .64482 Mdot
.20383 .68122 Mdot
.54398 .73022 Mdot
.34578 .54894 Mdot
.18709 .72686 Mdot
.37024 .21084 Mdot
.58107 .6032 Mdot
.52647 .46702 Mdot
.27969 .75166 Mdot
.88392 .41314 Mdot
.26138 .39584 Mdot
.53531 .64779 Mdot
.2554 .22832 Mdot
.314 .54398 Mdot
.52083 .19542 Mdot
.61293 .45695 Mdot
.29843 .66009 Mdot
.48971 .25638 Mdot
.24927 .74639 Mdot
.33893 .24668 Mdot
.58923 .68831 Mdot
.5443 .40253 Mdot
.66237 .72855 Mdot
.2682 .52385 Mdot
.31669 .22261 Mdot
.20718 .57357 Mdot
.50728 .43793 Mdot
.58871 .57409 Mdot
.36797 .59324 Mdot
.3229 .48897 Mdot
.38823 .21077 Mdot
.80545 .60323 Mdot
.63484 .56364 Mdot
.46396 .70297 Mdot
.2537 .29468 Mdot
.20455 .51903 Mdot
.8162 .74143 Mdot
.44646 .23109 Mdot
.5983 .31482 Mdot
.31213 .80994 Mdot
.31347 .5864 Mdot
.81831 .61275 Mdot
.36248 .20467 Mdot
.73994 .76821 Mdot
.47671 .70867 Mdot
.83594 .40714 Mdot
.4001 .7839 Mdot
.37417 .6619 Mdot
.63283 .32314 Mdot
.44639 .43793 Mdot
.33146 .15152 Mdot
.18063 .56532 Mdot
.36195 .46158 Mdot
.55096 .20566 Mdot
.67658 .10429 Mdot
.26433 .32137 Mdot
.31946 .34922 Mdot
.27668 .34426 Mdot
.37268 .75069 Mdot
.8156 .44362 Mdot
.55288 .3748 Mdot
.40729 .4654 Mdot
.76068 .45978 Mdot
.44923 .45555 Mdot
.18369 .73406 Mdot
.17613 .62481 Mdot
.7183 .23712 Mdot
.28123 .49206 Mdot
.77884 .35858 Mdot
.34639 .42939 Mdot
.58275 .45893 Mdot
.63472 .54725 Mdot
.45465 .46477 Mdot
.24901 .36828 Mdot
.39507 .38785 Mdot
.53047 .62973 Mdot
.43209 .76126 Mdot
.45307 .8474 Mdot
.73491 .12734 Mdot
.67516 .47494 Mdot
.60547 .45892 Mdot
.28893 .29947 Mdot
.24222 .41261 Mdot
.29154 .56862 Mdot
.68819 .2963 Mdot
.7145 .77365 Mdot
.22123 .72165 Mdot
.61271 .56584 Mdot
.39933 .65471 Mdot
.6844 .58645 Mdot
.39281 .33044 Mdot
.55035 .66103 Mdot
.43211 .07841 Mdot
.2574 .384 Mdot
.55047 .62498 Mdot
.30361 .37492 Mdot
.36263 .76432 Mdot
.23519 .41648 Mdot
.56072 .63682 Mdot
.25065 .21738 Mdot
.32985 .37019 Mdot
.70493 .44845 Mdot
.48134 .56734 Mdot
.51425 .39471 Mdot
.20353 .35657 Mdot
.36228 .69028 Mdot
.66654 .40029 Mdot
.65855 .69362 Mdot
.81224 .62187 Mdot
.26153 .50228 Mdot
.62498 .60886 Mdot
.24334 .80232 Mdot
.26022 .28165 Mdot
.28565 .22186 Mdot
.54077 .53302 Mdot
.89272 .33495 Mdot
.45229 .11553 Mdot
.4378 .18497 Mdot
.22468 .54401 Mdot
.61029 .57522 Mdot
.74428 .28962 Mdot
.57779 .7209 Mdot
.73997 .57667 Mdot
.22805 .26405 Mdot
.49377 .65218 Mdot
.60139 .39339 Mdot
.25435 .39556 Mdot
.70205 .42893 Mdot
.3386 .1965 Mdot
.32251 .25752 Mdot
.34938 .66157 Mdot
.33248 .49144 Mdot
.57411 .48668 Mdot
.53381 .20131 Mdot
.6316 .11246 Mdot
.45864 .38251 Mdot
.37388 .6314 Mdot
.22748 .36655 Mdot
.36807 .87864 Mdot
.43582 .48411 Mdot
.16915 .40064 Mdot
.60424 .92152 Mdot
.37715 .62242 Mdot
.60685 .75482 Mdot
.37283 .50732 Mdot
.48779 .12236 Mdot
.29139 .7226 Mdot
.18104 .72293 Mdot
.59388 .73435 Mdot
.47329 .76712 Mdot
.66206 .56909 Mdot
.16554 .77004 Mdot
.37756 .68631 Mdot
.32679 .35103 Mdot
.41113 .44901 Mdot
.32689 .71065 Mdot
.34704 .80846 Mdot
.46362 .1689 Mdot
.51652 .81591 Mdot
.73128 .45796 Mdot
.26031 .55898 Mdot
.25653 .38569 Mdot
.55775 .74802 Mdot
.6779 .54404 Mdot
.70297 .60768 Mdot
.40286 .78415 Mdot
.70091 .56684 Mdot
.16934 .52616 Mdot
.30305 .80714 Mdot
.18596 .50667 Mdot
.52873 .87857 Mdot
.47251 .67986 Mdot
.46108 .32062 Mdot
.75581 .58951 Mdot
.42961 .66126 Mdot
.32951 .67511 Mdot
.17287 .56604 Mdot
.66323 .60452 Mdot
.24596 .30559 Mdot
.67527 .16999 Mdot
.06611 .56711 Mdot
.83612 .58684 Mdot
.52582 .85838 Mdot
.77725 .42065 Mdot
.6812 .6235 Mdot
.35705 .18038 Mdot
.67267 .6248 Mdot
.53199 .28523 Mdot
.42659 .6582 Mdot
.6726 .45903 Mdot
.42192 .50878 Mdot
.55833 .76318 Mdot
.23986 .63933 Mdot
.21357 .43068 Mdot
.13792 .50233 Mdot
.50298 .75774 Mdot
.24006 .38768 Mdot
.48915 .56986 Mdot
.64979 .39194 Mdot
.67741 .34057 Mdot
.60979 .48587 Mdot
.33991 .83071 Mdot
.59005 .15272 Mdot
.81548 .65085 Mdot
.49327 .47398 Mdot
.37567 .53874 Mdot
.307 .53073 Mdot
.74476 .59597 Mdot
.75111 .26587 Mdot
.47603 .32895 Mdot
.52071 .69877 Mdot
.6779 .56939 Mdot
.26532 .28573 Mdot
.28911 .386 Mdot
.33951 .35308 Mdot
.56124 .32918 Mdot
.44487 .3403 Mdot
.76931 .36217 Mdot
.72649 .37339 Mdot
.34782 .31341 Mdot
.19817 .50477 Mdot
.5318 .5531 Mdot
.48581 .55062 Mdot
.21975 .51907 Mdot
.77937 .3292 Mdot
.38456 .25037 Mdot
.38923 .52987 Mdot
.85734 .35067 Mdot
.82228 .46098 Mdot
.42644 .87809 Mdot
.55765 .69289 Mdot
.36343 .50695 Mdot
.5374 .81736 Mdot
.70903 .47863 Mdot
.682 .29895 Mdot
.45675 .52111 Mdot
.25361 .21383 Mdot
.38773 .17259 Mdot
.83324 .51466 Mdot
.47655 .47854 Mdot
.50266 .30351 Mdot
.47206 .62375 Mdot
.42158 .29004 Mdot
.52891 .37299 Mdot
.56694 .40691 Mdot
.71699 .69253 Mdot
.38989 .80227 Mdot
.75329 .48438 Mdot
.54632 .5701 Mdot
.69323 .32936 Mdot
.48338 .24883 Mdot
.64923 .45074 Mdot
.46644 .67304 Mdot
.31334 .61119 Mdot
.32887 .51527 Mdot
.40977 .56274 Mdot
.76802 .29282 Mdot
.40282 .44141 Mdot
.81233 .3774 Mdot
.07815 .5956 Mdot
.20501 .43245 Mdot
.64752 .60107 Mdot
.56876 .08732 Mdot
.45953 .24404 Mdot
.58982 .53874 Mdot
.65287 .63901 Mdot
.60452 .52065 Mdot
.22325 .28995 Mdot
.63081 .3509 Mdot
.61298 .75158 Mdot
.60432 .33438 Mdot
.25257 .12985 Mdot
.14833 .43061 Mdot
.50233 .72828 Mdot
.22347 .34453 Mdot
.26357 .65029 Mdot
.65073 .65892 Mdot
.42383 .48582 Mdot
.14016 .53591 Mdot
.3402 .66654 Mdot
.71079 .61996 Mdot
.61841 .2407 Mdot
.6433 .4362 Mdot
.61449 .26104 Mdot
.6742 .38047 Mdot
.33193 .54893 Mdot
.23217 .67595 Mdot
.3452 .54155 Mdot
.43508 .81201 Mdot
.24399 .40814 Mdot
.56747 .3633 Mdot
.74634 .56298 Mdot
.25609 .48197 Mdot
.62182 .75869 Mdot
.40785 .64814 Mdot
.62543 .56552 Mdot
.25088 .71981 Mdot
.50948 .61043 Mdot
.5586 .33525 Mdot
.69408 .65486 Mdot
.53621 .83354 Mdot
.64119 .63491 Mdot
.58137 .31254 Mdot
.78281 .31726 Mdot
.61954 .42127 Mdot
.48697 .45712 Mdot
.44677 .35176 Mdot
.08858 .67995 Mdot
.3618 .59901 Mdot
.35321 .79721 Mdot
.7189 .58038 Mdot
.548 .44181 Mdot
.83165 .36017 Mdot
.5727 .79364 Mdot
.58324 .28884 Mdot
.66663 .66841 Mdot
.34878 .73388 Mdot
.55818 .65304 Mdot
.37655 .30105 Mdot
.50076 .21088 Mdot
.24528 .60971 Mdot
.10336 .62682 Mdot
.58328 .56362 Mdot
.78126 .62744 Mdot
.77818 .54907 Mdot
.28676 .56736 Mdot
.55413 .1369 Mdot
.19751 .76579 Mdot
.47218 .51507 Mdot
.34354 .42256 Mdot
.64791 .59528 Mdot
.62053 .50276 Mdot
.18805 .35884 Mdot
.59953 .40944 Mdot
.44725 .55668 Mdot
.42368 .23522 Mdot
.71388 .69698 Mdot
.74003 .46914 Mdot
.85237 .54291 Mdot
.34399 .78281 Mdot
.59821 .19065 Mdot
.45869 .35137 Mdot
.28658 .37519 Mdot
.66548 .63109 Mdot
.48806 .53242 Mdot
.27761 .71833 Mdot
.35264 .80471 Mdot
.62337 .50506 Mdot
.22614 .40989 Mdot
.48531 .46519 Mdot
.48797 .4614 Mdot
.70798 .64615 Mdot
.5972 .31745 Mdot
.51492 .55813 Mdot
.69773 .29627 Mdot
.69487 .24404 Mdot
.62015 .17479 Mdot
.36374 .46686 Mdot
.46801 .53849 Mdot
.40083 .61035 Mdot
.22716 .52422 Mdot
.68032 .25496 Mdot
.3857 .5613 Mdot
.47478 .15155 Mdot
.5355 .18001 Mdot
.3041 .31757 Mdot
.44544 .85193 Mdot
.24984 .79006 Mdot
.82111 .72671 Mdot
.50146 .26127 Mdot
.67828 .67328 Mdot
.73728 .8136 Mdot
.50514 .76413 Mdot
.7186 .51772 Mdot
.36981 .41184 Mdot
.55777 .55366 Mdot
.29363 .57427 Mdot
.20046 .35596 Mdot
.694 .46817 Mdot
.35032 .75141 Mdot
.48033 .43644 Mdot
.25777 .39837 Mdot
.41434 .32541 Mdot
.79678 .5608 Mdot
.46733 .32582 Mdot
.66232 .26118 Mdot
.61468 .66131 Mdot
.71658 .47314 Mdot
.7393 .4789 Mdot
.77097 .34881 Mdot
.33363 .73861 Mdot
.18913 .49135 Mdot
.44343 .78675 Mdot
.19046 .38185 Mdot
.51808 .94454 Mdot
.41344 .2471 Mdot
.63442 .4239 Mdot
.33714 .46282 Mdot
.39526 .66939 Mdot
.4918 .7207 Mdot
.37135 .42364 Mdot
.18496 .19684 Mdot
.47315 .53838 Mdot
.27694 .72674 Mdot
.45302 .61062 Mdot
.5288 .70039 Mdot
.44231 .38751 Mdot
.78565 .57037 Mdot
.66837 .37609 Mdot
.23744 .69112 Mdot
.70484 .30634 Mdot
.66025 .56253 Mdot
.21893 .26908 Mdot
.24087 .24926 Mdot
.74952 .47043 Mdot
.40653 .20409 Mdot
.181 .47288 Mdot
.20326 .23311 Mdot
.70461 .30931 Mdot
.55854 .25119 Mdot
.58851 .6481 Mdot
.75547 .31248 Mdot
.18966 .55602 Mdot
.68887 .69778 Mdot
.63313 .23011 Mdot
.56078 .63058 Mdot
.43835 .63097 Mdot
.32746 .77373 Mdot
.58882 .68285 Mdot
.47121 .22267 Mdot
.28633 .56867 Mdot
.78242 .716 Mdot
.65885 .34197 Mdot
.25239 .24717 Mdot
.33188 .57545 Mdot
.14488 .43908 Mdot
.12941 .40938 Mdot
.70222 .64874 Mdot
.46304 .60989 Mdot
.36421 .33118 Mdot
.28365 .52563 Mdot
.57936 .29003 Mdot
.32741 .36604 Mdot
.65958 .78374 Mdot
.49024 .14827 Mdot
.81924 .31276 Mdot
.84711 .34786 Mdot
.42716 .48142 Mdot
.3665 .71843 Mdot
.78815 .54432 Mdot
.61243 .58873 Mdot
.51545 .19041 Mdot
.30424 .54957 Mdot
.10596 .68745 Mdot
.60709 .43419 Mdot
.81292 .34916 Mdot
.49256 .53225 Mdot
.37675 .27741 Mdot
.54205 .3981 Mdot
.41046 .56217 Mdot
.75738 .56623 Mdot
.7349 .18178 Mdot
.43278 .34805 Mdot
.42957 .29463 Mdot
.17778 .70652 Mdot
.46166 .08765 Mdot
.20663 .3757 Mdot
.27892 .58678 Mdot
.29259 .58412 Mdot
.36389 .5852 Mdot
.67597 .7216 Mdot
.32669 .40875 Mdot
.25631 .64026 Mdot
.64831 .30132 Mdot
.28609 .23643 Mdot
.79838 .34912 Mdot
.23311 .28156 Mdot
.57678 .42602 Mdot
.18956 .51809 Mdot
.6935 .42127 Mdot
.72985 .48191 Mdot
.65695 .67623 Mdot
.21679 .39922 Mdot
.58385 .52096 Mdot
.36231 .69135 Mdot
.36394 .80622 Mdot
.34628 .41549 Mdot
.65282 .37302 Mdot
.71363 .29434 Mdot
.13318 .42031 Mdot
.5 .06224 Mdot
.22801 .23205 Mdot
.29712 .38573 Mdot
.72863 .32673 Mdot
.18329 .41783 Mdot
.45002 .26364 Mdot
.69575 .40861 Mdot
.55865 .32891 Mdot
.63007 .41091 Mdot
.25288 .42376 Mdot
.68577 .69453 Mdot
.55658 .30422 Mdot
.67499 .47513 Mdot
.38781 .65228 Mdot
.30837 .27056 Mdot
.5117 .62864 Mdot
.78034 .39787 Mdot
.20564 .41764 Mdot
.51429 .76972 Mdot
.26874 .61258 Mdot
.53419 .62562 Mdot
.64894 .41481 Mdot
.41414 .30243 Mdot
.53776 .27832 Mdot
.24341 .39432 Mdot
.64742 .63001 Mdot
.43398 .60444 Mdot
.71183 .79699 Mdot
.80851 .51047 Mdot
.26853 .53817 Mdot
.33997 .24706 Mdot
.31592 .4988 Mdot
.74218 .70344 Mdot
.36179 .20231 Mdot
.83666 .55087 Mdot
.24645 .45285 Mdot
.45301 .43801 Mdot
.31457 .34612 Mdot
.78198 .60615 Mdot
.56682 .28027 Mdot
.83678 .47736 Mdot
.82835 .52238 Mdot
.66517 .78155 Mdot
.49377 .51104 Mdot
.41768 .6888 Mdot
.77951 .43387 Mdot
.32594 .71372 Mdot
.47402 .45944 Mdot
.32181 .33851 Mdot
.2768 .3282 Mdot
.68843 .36609 Mdot
.55116 .71409 Mdot
.72315 .6384 Mdot
.81792 .46328 Mdot
.2521 .79979 Mdot
.26929 .45141 Mdot
.74729 .41548 Mdot
.2898 .61725 Mdot
.54223 .71073 Mdot
.58991 .5136 Mdot
.58741 .28968 Mdot
.63889 .51469 Mdot
.76485 .58283 Mdot
.44578 .50903 Mdot
.39255 .1648 Mdot
.68513 .44563 Mdot
.46338 .64971 Mdot
.65614 .48138 Mdot
.49397 .4686 Mdot
.2559 .51064 Mdot
.29212 .76474 Mdot
.42764 .38738 Mdot
.32753 .49031 Mdot
.38588 .32467 Mdot
.35476 .28698 Mdot
.50101 .84947 Mdot
.83937 .63201 Mdot
.50118 .2661 Mdot
.37035 .37802 Mdot
.8268 .27503 Mdot
.60362 .56507 Mdot
.16505 .51325 Mdot
.27983 .45456 Mdot
.36267 .68456 Mdot
.82476 .29227 Mdot
.23359 .27193 Mdot
.70283 .44906 Mdot
.73293 .60402 Mdot
.90903 .59645 Mdot
.55044 .76497 Mdot
.25613 .55801 Mdot
.23008 .44815 Mdot
.26497 .36158 Mdot
.40357 .24621 Mdot
.73434 .70861 Mdot
.25718 .60872 Mdot
.65883 .48532 Mdot
.53221 .2373 Mdot
.51658 .47233 Mdot
.47412 .63744 Mdot
.66163 .57517 Mdot
.72619 .37538 Mdot
.31474 .6756 Mdot
.37739 .27172 Mdot
.31135 .44528 Mdot
.22104 .65364 Mdot
.43283 .81789 Mdot
.87704 .55221 Mdot
.55007 .38205 Mdot
.57389 .87539 Mdot
.48098 .52661 Mdot
.5634 .21563 Mdot
.52166 .7379 Mdot
.50406 .43437 Mdot
.61769 .41995 Mdot
.51321 .73259 Mdot
.49767 .16128 Mdot
.51395 .68751 Mdot
.46992 .54001 Mdot
.46336 .26905 Mdot
.15971 .55001 Mdot
.74574 .37227 Mdot
.16809 .57379 Mdot
.29373 .78251 Mdot
.14398 .3143 Mdot
.69817 .72969 Mdot
.43244 .42546 Mdot
.60157 .84012 Mdot
.35664 .37453 Mdot
.45058 .57941 Mdot
.73303 .50527 Mdot
.19326 .65979 Mdot
.46723 .18291 Mdot
.24297 .48082 Mdot
.58903 .30809 Mdot
.70307 .25223 Mdot
.62995 .7098 Mdot
.76916 .59688 Mdot
.5163 .6002 Mdot
.75692 .48373 Mdot
.72941 .73752 Mdot
.36359 .66447 Mdot
.8765 .44318 Mdot
.52667 .65045 Mdot
.54596 .36531 Mdot
.57279 .26092 Mdot
.50653 .29121 Mdot
.49513 .63036 Mdot
.78444 .16955 Mdot
.41613 .40802 Mdot
.675 .72387 Mdot
.57783 .4599 Mdot
.31952 .53371 Mdot
.45048 .32588 Mdot
.70986 .59252 Mdot
.12029 .42734 Mdot
.71665 .30319 Mdot
.36443 .71664 Mdot
.7535 .59859 Mdot
.4265 .67103 Mdot
.80495 .60885 Mdot
.5958 .19573 Mdot
.36713 .26424 Mdot
.49217 .27535 Mdot
.66726 .76048 Mdot
0 0 0 r
.0002 w
[ ] 0 setdash
.97619 .50275 m
.93457 .69858 L
.81689 .86054 L
.64352 .96064 L
.44441 .98157 L
.25401 .9197 L
.10524 .78574 L
.02381 .60285 L
.02381 .40265 L
.10524 .21976 L
.25401 .08581 L
.44441 .02394 L
.64352 .04487 L
.81689 .14497 L
.93457 .30693 L
.97619 .50275 L
s
0 0 m
1 0 L
1 1.00551 L
0 1.00551 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 289.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00018B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00O@3oool8000009/0oooo001j0?ooo`<00000203oool900000980oooo
001g0?ooo`<00000503oool:000008P0oooo001d0?ooo`<000008@3oool9000007l0oooo001a0?oo
o`<00000;@3oool:000007D0oooo001^0?ooo`<00000>P3oool9000006`0oooo001[0?ooo`<00000
AP3oool6000006H0oooo001X0?ooo`<00000C`3oool2000006@0oooo001U0?ooo`<000007@3oool2
023/1cD0oooo00<000000?ooo`3oool0H@3oool00680oooo0`00000P0?ooo`808>`7=P3oool20000
0640oooo001O0?ooo`<00000G@3oool2000005l0oooo001L0?ooo`<00000;`3oool2023/1c40oooo
00<000000?ooo`3oool0G03oool005T0oooo0`00000b0?ooo`808>`7<P3oool2000005`0oooo001F
0?ooo`<00000J`3oool2000005X0oooo001C0?ooo`<00000L03oool2000005P0oooo001@0?ooo`<0
0000:03oool2023/1d/0oooo00<000000?ooo`3oool0E@3oool004d0oooo0`00000[0?ooo`808>`7
C03oool2000005D0oooo001:0?ooo`<00000OP3oool2000005<0oooo00170?ooo`<00000>@3oool2
023/1ad0oooo0P0Pk0LY0?ooo`800000D@3oool004H0oooo00<000000?ooo`3oool0>P3oool2023/
1ad0oooo0P0Pk0L[0?ooo`030000003oool0oooo04h0oooo00150?ooo`030000003oool0oooo01X0
oooo0P0Pk0M/0?ooo`800000CP3oool004@0oooo00<000000?ooo`3oool06`3oool2023/1fh0oooo
0P00001<0?ooo`00@`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo04T0oooo0012
0?ooo`030000003oool0oooo07`0oooo0P0Pk0LB0?ooo`800000B@3oool00440oooo00<000000?oo
o`3oool0>@3oool2023/1bH0oooo0P0Pk0LJ0?ooo`808>`7503oool2000004L0oooo00100?ooo`03
0000003oool0oooo03X0oooo0P0Pk0LV0?ooo`808>`73@3oool2023/1b<0oooo0P0000150?ooo`00
?`3oool00`000000oooo0?ooo`0H0?ooo`808>`79@3oool2023/1c00oooo0`0Pk0LU0?ooo`030000
003oool0oooo0480oooo000m0?ooo`8000006`3oool2023/1bD0oooo0P0Pk0L80?ooo`808>`78@3o
ool2023/1`<0oooo0P0Pk0LC0?ooo`808>`74P3oool200000480oooo000l0?ooo`030000003oool0
oooo04`0oooo0P0Pk0LQ0?ooo`808>`7603oool2023/1a@0oooo0P0000100?ooo`00>`3oool00`00
0000oooo0?ooo`1=0?ooo`808>`7A@3oool2023/1``0oooo0P00000n0?ooo`00>P3oool00`000000
oooo0?ooo`0:0?ooo`808>`7R@3oool2023/1`h0oooo00<000000?ooo`3oool0>`3oool003T0oooo
00<000000?ooo`3oool02`3oool2023/1iX0oooo0P00000k0?ooo`00>03oool00`000000oooo0?oo
o`1S0?ooo`808>`72@3oool2023/1cX0oooo0P00000i0?ooo`00=`3oool00`000000oooo0?ooo`13
0?ooo`808>`77`3oool2023/1`T0oooo0P0Pk0Ll0?ooo`030000003oool0oooo03H0oooo000f0?oo
o`030000003oool0oooo04@0oooo0P0Pk0MY0?ooo`800000=P3oool003D0oooo00<000000?ooo`3o
ool0D`3oool2023/1bl0oooo0P0Pk0L/0?ooo`030000003oool0oooo03<0oooo000d0?ooo`030000
003oool0oooo02L0oooo0P0Pk0LW0?ooo`808>`70P3oool2023/1bl0oooo0P0Pk0L/0?ooo`030000
003oool0oooo03<0oooo000b0?ooo`800000:P3oool2023/1aD0oooo0P0Pk0L@0?ooo`808>`77`3o
ool2023/1d40oooo00<000000?ooo`3oool0<P3oool00340oooo00<000000?ooo`3oool0@@3oool2
023/1c40oooo0P0Pk0M20?ooo`030000003oool0oooo0340oooo000`0?ooo`030000003oool0oooo
03d0oooo0P0Pk0LL0?ooo`808>`71@3oool2023/1eH0oooo00<000000?ooo`3oool0<03oool002l0
oooo00<000000?ooo`3oool0<03oool2023/1`/0oooo0`0Pk0LL0?ooo`808>`71@3oool2023/1bl0
oooo0P0Pk0LU0?ooo`030000003oool0oooo0300oooo000^0?ooo`030000003oool0oooo01<0oooo
0P0Pk0L>0?ooo`808>`7303oool2023/1`/0oooo0P0Pk0LC0?ooo`808>`7203oool2023/1b`0oooo
0P0Pk0L30?ooo`808>`70`3oool2023/1aP0oooo0P0Pk0L<0?ooo`030000003oool0oooo02l0oooo
000]0?ooo`030000003oool0oooo01@0oooo0P0Pk0L>0?ooo`808>`7603oool2023/1a@0oooo0P0P
k0LE0?ooo`@08>`77@3oool2023/1`<0oooo0P0Pk0LM0?ooo`808>`73@3oool00`000000oooo0?oo
o`0^0?ooo`00;03oool00`000000oooo0?ooo`0o0?ooo`808>`7:`3oool4023/1a80oooo0P0Pk0Lm
0?ooo`030000003oool0oooo02d0oooo000[0?ooo`030000003oool0oooo03L0oooo0P0Pk0LJ0?oo
o`808>`74@3oool2023/1`80oooo0P0Pk0LG0?ooo`808>`7?@3oool00`000000oooo0?ooo`0]0?oo
o`00:P3oool00`000000oooo0?ooo`0g0?ooo`<08>`7403oool2023/1`P0oooo0P0Pk0L20?ooo`80
8>`73@3oool2023/1`80oooo0P0Pk0L20?ooo`808>`74P3oool2023/1b00oooo0P0Pk0LM0?ooo`03
0000003oool0oooo02`0oooo000X0?ooo`800000>P3oool3023/1a00oooo0P0Pk0L30?ooo`808>`7
1@3oool4023/1aD0oooo0P0Pk0LB0?ooo`808>`72P3oool2023/1a@0oooo0P0Pk0LN0?ooo`030000
003oool0oooo02/0oooo000W0?ooo`030000003oool0oooo0580oooo0P0Pk0L50?ooo`808>`72@3o
ool2023/1`<0oooo0P0Pk0LE0?ooo`808>`7403oool4023/1`@0oooo0P0Pk0L]0?ooo`030000003o
ool0oooo02X0oooo000V0?ooo`030000003oool0oooo05d0oooo0P0Pk0L60?ooo`808>`70`3oool2
023/1aD0oooo0P0Pk0LB0?ooo`808>`7103oool2023/1a00oooo0P0Pk0LK0?ooo`030000003oool0
oooo02X0oooo000U0?ooo`030000003oool0oooo00`0oooo0P0Pk0LZ0?ooo`808>`70P3oool2023/
1b00oooo0P0Pk0L<0?ooo`808>`7503oool2023/1bX0oooo0P0Pk0LL0?ooo`030000003oool0oooo
02T0oooo000T0?ooo`030000003oool0oooo00d0oooo0P0Pk0L00`3oool08>`7023/1`0V0?ooo`<0
8>`70P3oool2023/1bh0oooo0P0Pk0L20?ooo`808>`72P3oool2023/1`@0oooo0P0Pk0L80?ooo`80
8>`7?`3oool00`000000oooo0?ooo`0X0?ooo`008`3oool00`000000oooo0?ooo`0A0?ooo`808>`7
9P3oool3023/1`D0oooo0P0Pk0L:0?ooo`808>`74`3oool2023/1`h0oooo0P0Pk0L:0?ooo`808>`7
3P3oool2023/1aH0oooo0P0Pk0LW0?ooo`030000003oool0oooo02P0oooo000R0?ooo`030000003o
ool0oooo03<0oooo0P0Pk0L60?ooo`808>`71@3oool2023/1`T0oooo0`0Pk0LC0?ooo`808>`74`3o
ool2023/1`H0oooo0P0Pk0L:0?ooo`808>`7203oool2023/1`l0oooo0P0Pk0L60?ooo`808>`7803o
ool00`000000oooo0?ooo`0W0?ooo`008@3oool00`000000oooo0?ooo`0d0?ooo`808>`73`3oool2
023/1`<0oooo0P0Pk0L20?ooo`808>`76P3oool2023/1`d0oooo0P0Pk0L60?ooo`808>`72P3oool2
023/1`P0oooo0P0Pk0L80?ooo`808>`71@3oool2023/1`H0oooo0P0Pk0LQ0?ooo`030000003oool0
oooo02H0oooo000P0?ooo`030000003oool0oooo02D0oooo0P0Pk0LL0?ooo`808>`700<0oooo023/
1`0Pk0L00`3oool2023/1ah0oooo0P0Pk0L;0?ooo`808>`7:03oool3023/1`@0oooo0P0Pk0LZ0?oo
o`030000003oool0oooo02D0oooo000O0?ooo`030000003oool0oooo02D0oooo0`0Pk0L?0?ooo`80
8>`72`3oool2023/1c<0oooo0P0Pk0L30?ooo`808>`7903oool2023/1c00oooo00<000000?ooo`3o
ool09@3oool001h0oooo00<000000?ooo`3oool09P3oool2023/1`P0oooo0P0Pk0L60?ooo`808>`7
A@3oool2023/1eL0oooo00<000000?ooo`3oool0903oool001h0oooo00<000000?ooo`3oool03`3o
ool2023/1al0oooo0P0Pk0L70?ooo`808>`7:@3oool3023/1b00oooo0P0Pk0LK0?ooo`808>`7<`3o
ool00`000000oooo0?ooo`0S0?ooo`007@3oool00`000000oooo0?ooo`0@0?ooo`808>`74`3oool2
023/1`030?ooo`0Pk0L08>`700d0oooo0P0Pk0L00`3oool08>`7023/1`0Y0?ooo`<08>`76P3oool2
023/1`@0oooo0P0Pk0LK0?ooo`808>`7=03oool00`000000oooo0?ooo`0R0?ooo`007@3oool00`00
0000oooo0?ooo`0H0?ooo`808>`71P3oool2023/1`<0oooo0P0Pk0L00`3oool08>`7023/1`0=0?oo
o`808>`79P3oool5023/1ah0oooo0P0Pk0L@0?ooo`808>`77`3oool2023/1b@0oooo00<000000?oo
o`3oool08P3oool001`0oooo00<000000?ooo`3oool03`3oool2023/1`P0oooo0`0Pk0L50?ooo`80
8>`7=P3oool2023/1`D0oooo1@0Pk0LD0?ooo`808>`76P3oool2023/1al0oooo0P0Pk0LU0?ooo`03
0000003oool0oooo0240oooo000L0?ooo`030000003oool0oooo00l0oooo0P0Pk0L90?ooo`808>`7
5P3oool2023/1`80oooo0P0Pk0LQ0?ooo`808>`73@3oool2023/1`80oooo0P0Pk0L:0?ooo`<08>`7
6P3oool2023/1aL0oooo0P0Pk0LB0?ooo`808>`76P3oool00`000000oooo0?ooo`0P0?ooo`006`3o
ool00`000000oooo0?ooo`0c0?ooo`808>`70P3oool2023/1bl0oooo0`0Pk0L20?ooo`808>`72P3o
ool2023/1aL0oooo0P0Pk0LK0?ooo`808>`74P3oool2023/1a/0oooo00<000000?ooo`3oool07`3o
ool001/0oooo00<000000?ooo`3oool09`3oool2023/1aP0oooo0`0Pk0LA0?ooo`808>`73P3oool2
023/1`030?ooo`0Pk0L08>`701h0oooo0P0Pk0L80?ooo`808>`7503oool2023/1cH0oooo00<00000
0?ooo`3oool07`3oool001/0oooo00<000000?ooo`3oool09P3oool5023/1a40oooo0P0Pk0L30?oo
o`<08>`74@3oool4023/1``0oooo0P0Pk0L40?ooo`808>`72`3oool2023/1`h0oooo0P0Pk0LN0?oo
o`808>`7=`3oool00`000000oooo0?ooo`0N0?ooo`006P3oool00`000000oooo0?ooo`0B0?ooo`80
8>`74`3oool5023/1a40oooo0P0Pk0L40?ooo`808>`72`3oool2023/1`H0oooo0P0Pk0LB0?ooo`80
8>`72`3oool2023/1`L0oooo0P0Pk0L?0?ooo`808>`75`3oool2023/1cD0oooo00<000000?ooo`3o
ool07@3oool001X0oooo00<000000?ooo`3oool04P3oool2023/1a@0oooo0P0Pk0LV0?ooo`808>`7
6@3oool2023/1`030?ooo`0Pk0L08>`70180oooo0P0Pk0L?0?ooo`808>`7403oool2023/1`D0oooo
0P0Pk0LL0?ooo`808>`7603oool00`000000oooo0?ooo`0L0?ooo`006@3oool00`000000oooo0?oo
o`0I0?ooo`808>`72`3oool2023/1a@0oooo1@0Pk0L[0?ooo`808>`700<0oooo023/1`0Pk0L0=@3o
ool2023/1al0oooo0P0Pk0L20?ooo`@08>`75P3oool00`000000oooo0?ooo`0L0?ooo`006@3oool0
0`000000oooo0?ooo`0I0?ooo`808>`72@3oool4023/1a@0oooo1`0Pk0LQ0?ooo`808>`73@3oool2
023/1a80oooo0P0Pk0L:0?ooo`808>`7303oool2023/1b@0oooo0P0Pk0L40?ooo`808>`75`3oool0
0`000000oooo0?ooo`0K0?ooo`00603oool00`000000oooo0?ooo`0U0?ooo`808>`72`3oool2023/
1`h0oooo0P0Pk0L90?ooo`808>`75P3oool2023/1`P0oooo0P0Pk0L30?ooo`808>`74P3oool2023/
1`X0oooo0P0Pk0L<0?ooo`808>`72@3oool2023/1`<0oooo0P0Pk0L70?ooo`808>`7:`3oool00`00
0000oooo0?ooo`0J0?ooo`00603oool00`000000oooo0?ooo`0S0?ooo`808>`72@3oool6023/1`P0
oooo0P0Pk0L?0?ooo`808>`76P3oool2023/1`@0oooo0P0Pk0L30?ooo`808>`77P3oool2023/1`l0
oooo0P0Pk0L60?ooo`808>`70`3oool2023/1`L0oooo0P0Pk0L/0?ooo`030000003oool0oooo01T0
oooo000G0?ooo`030000003oool0oooo02@0oooo0P0Pk0L20?ooo`808>`70P3oool2023/1`030?oo
o`0Pk0L08>`700808>`72P3oool2023/1a80oooo0P0Pk0L@0?ooo`808>`71@3oool2023/1a@0oooo
0P0Pk0LC0?ooo`808>`73`3oool2023/1d80oooo00<000000?ooo`3oool06@3oool001L0oooo00<0
00000?ooo`3oool0:03oool2023/1`80oooo0P0Pk0LS0?ooo`808>`700<0oooo023/1`0Pk0L01`3o
ool2023/1`@0oooo0P0Pk0L=0?ooo`808>`7303oool2023/1aD0oooo0P0Pk0L00`3oool08>`7023/
1`0W0?ooo`808>`73@3oool2023/1aL0oooo00<000000?ooo`3oool0603oool001H0oooo00<00000
0?ooo`3oool0:@3oool2023/1`H0oooo0P0Pk0L>0?ooo`808>`73`3oool2023/1`030?ooo`0Pk0L0
8>`700L0oooo0P0Pk0LC0?ooo`808>`72`3oool2023/1`H0oooo0P0Pk0L>0?ooo`808>`700<0oooo
023/1`0Pk0L02@3oool2023/1a`0oooo0P0Pk0L=0?ooo`808>`7603oool00`000000oooo0?ooo`0G
0?ooo`005P3oool00`000000oooo0?ooo`0Y0?ooo`808>`71@3oool3023/1`h0oooo0P0Pk0Lm0?oo
o`808>`71P3oool2023/1aL0oooo0P0Pk0L30?ooo`808>`7A@3oool00`000000oooo0?ooo`0G0?oo
o`005@3oool00`000000oooo0?ooo`0a0?ooo`@08>`74`3oool3023/1`80oooo0P0Pk0LX0?ooo`80
8>`71P3oool2023/1`/0oooo0P0Pk0LD0?ooo`808>`7<@3oool2023/1aP0oooo00<000000?ooo`3o
ool05P3oool001D0oooo00<000000?ooo`3oool07P3oool2023/1`L0oooo0P0Pk0L:0?ooo`808>`7
4`3oool3023/1`80oooo0P0Pk0LA0?ooo`808>`75@3oool3023/1`D0oooo0P0Pk0L30?ooo`808>`7
1P3oool5023/1b40oooo0P0Pk0L80?ooo`808>`75`3oool2023/1aT0oooo00<000000?ooo`3oool0
5@3oool001D0oooo00<000000?ooo`3oool07P3oool2023/1`L0oooo0P0Pk0L70?ooo`808>`700<0
oooo023/1`0Pk0L04`3oool2023/1`D0oooo0P0Pk0L?0?ooo`@08>`7503oool2023/1`X0oooo0P0P
k0L70?ooo`@08>`700<0oooo023/1`0Pk0L07P3oool4023/1`H0oooo0P0Pk0L50?ooo`808>`700@0
oooo023/1`0Pk0L08>`72P3oool2023/1a`0oooo00<000000?ooo`3oool0503oool001@0oooo00<0
00000?ooo`3oool0<@3oool2023/1`030?ooo`0Pk0L08>`701<0oooo0P0Pk0L50?ooo`808>`74@3o
ool2023/1bh0oooo0P0Pk0LF0?ooo`@08>`700<0oooo023/1`0Pk0L00`3oool2023/1`X0oooo0P0P
k0L0103oool08>`7023/1`3oool3023/1`X0oooo0P0Pk0LL0?ooo`030000003oool0oooo01@0oooo
000D0?ooo`030000003oool0oooo03/0oooo0P0Pk0LG0?ooo`808>`72@3oool2023/1cd0oooo0P0P
k0L0103oool08>`7023/1`0Pk0L70?ooo`@08>`700<0oooo023/1`0Pk0L03`3oool2023/1c00oooo
00<000000?ooo`3oool04`3oool001<0oooo00<000000?ooo`3oool0603oool2023/1a00oooo0P0P
k0L30?ooo`808>`72`3oool2023/1`80oooo0P0Pk0LC0?ooo`<08>`70`3oool2023/1`<0oooo0P0P
k0LG0?ooo`808>`73@3oool2023/1aD0oooo0P0Pk0L0103oool08>`7023/1`0Pk0LA0?ooo`808>`7
?@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`000000oooo0?ooo`0H0?ooo`808>`7403o
ool2023/1`<0oooo0P0Pk0L?0?ooo`808>`7503oool2023/1`<0oooo0P0Pk0LI0?ooo`808>`700<0
oooo023/1`0Pk0L03@3oool2023/1`P0oooo0P0Pk0L;0?ooo`<08>`74@3oool2023/1`030?ooo`0P
k0L08>`703h0oooo00<000000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool0>`3oool2
023/1b<0oooo0P0Pk0L<0?ooo`808>`71`3oool2023/1`T0oooo0P0Pk0L90?ooo`808>`70P3oool4
023/1`L0oooo0P0Pk0L30?ooo`808>`74@3oool2023/1`d0oooo0P0Pk0L@0?ooo`808>`73P3oool2
023/1a00oooo00<000000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool04`3oool2023/
1bH0oooo0P0Pk0L;0?ooo`808>`7103oool2023/1a00oooo0P0Pk0L<0?ooo`808>`74P3oool2023/
1`T0oooo0P0Pk0L20?ooo`808>`70P3oool2023/1`030?ooo`0Pk0L08>`70080oooo0P0Pk0LB0?oo
o`808>`74@3oool2023/1a00oooo0P0Pk0L>0?ooo`808>`7403oool00`000000oooo0?ooo`0A0?oo
o`004@3oool00`000000oooo0?ooo`0D0?ooo`808>`7;03oool2023/1`D0oooo0P0Pk0L20?ooo`@0
8>`74`3oool2023/1bL0oooo0P0Pk0L70?ooo`808>`700<0oooo023/1`0Pk0L05P3oool2023/1`h0
oooo0P0Pk0L80?ooo`808>`72P3oool2023/1b00oooo00<000000?ooo`3oool0403oool00140oooo
00<000000?ooo`3oool0=`3oool2023/1`T0oooo0P0Pk0L90?ooo`808>`75@3oool2023/1`T0oooo
0P0Pk0LL0?ooo`808>`71`3oool2023/1`P0oooo0P0Pk0L?0?ooo`808>`73P3oool2023/1`P0oooo
0P0Pk0L:0?ooo`808>`7803oool00`000000oooo0?ooo`0@0?ooo`00403oool00`000000oooo0?oo
o`0g0?ooo`<08>`78@3oool4023/1`@0oooo0P0Pk0L80?ooo`808>`700<0oooo023/1`0Pk0L00P0P
k0L]0?ooo`808>`76P3oool2023/1c/0oooo00<000000?ooo`3oool0403oool00100oooo00<00000
0?ooo`3oool0=`3oool2023/1`80oooo0P0Pk0LN0?ooo`@08>`7103oool2023/1`P0oooo0P0Pk0L3
0?ooo`@08>`7103oool4023/1`h0oooo0`0Pk0LL0?ooo`808>`71P3oool2023/1`P0oooo0P0Pk0L<
0?ooo`808>`7;@3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`0l0?oo
o`808>`75`3oool2023/1`H0oooo0P0Pk0L60?ooo`808>`72`3oool2023/1`030?ooo`0Pk0L08>`7
00@0oooo100Pk0L>0?ooo`<08>`7103oool2023/1aH0oooo0P0Pk0L60?ooo`808>`7203oool2023/
1``0oooo0P0Pk0L=0?ooo`808>`77P3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000
oooo0?ooo`1E0?ooo`808>`71P3oool2023/1`H0oooo0P0Pk0L;0?ooo`808>`76@3oool2023/1`D0
oooo0P0Pk0L40?ooo`808>`71P3oool2023/1aX0oooo0P0Pk0LK0?ooo`808>`7403oool2023/1`d0
oooo00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool0B@3oool2023/1ah0oooo
0P0Pk0L00`3oool08>`7023/1`0O0?ooo`<08>`72P3oool2023/1`H0oooo0P0Pk0L;0?ooo`808>`7
?03oool2023/1`d0oooo00<000000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3oool0?@3o
ool2023/1`/0oooo0P0Pk0LH0?ooo`808>`7103oool2023/1`030?ooo`0Pk0L08>`701/0oooo0P0P
k0L30?ooo`808>`76P3oool2023/1`<0oooo0P0Pk0M;0?ooo`030000003oool0oooo00l0oooo000>
0?ooo`030000003oool0oooo02h0oooo0P0Pk0L=0?ooo`808>`72@3oool2023/1aX0oooo0P0Pk0LC
0?ooo`808>`73`3oool2023/1`030?ooo`0Pk0L08>`700808>`76P3oool2023/1`030?ooo`0Pk0L0
8>`700l0oooo0P0Pk0LB0?ooo`808>`7:03oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`00
0000oooo0?ooo`0_0?ooo`808>`7603oool3023/1`030?ooo`0Pk0L08>`701D0oooo0P0Pk0L50?oo
o`808>`73@3oool2023/1a80oooo100Pk0LB0?ooo`808>`7103oool2023/1`<0oooo0P0Pk0L?0?oo
o`808>`72P3oool2023/1`H0oooo0P0Pk0L20?ooo`808>`7203oool2023/1`030?ooo`0Pk0L08>`7
01L0oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0603oool2023/1c00
oooo0P0Pk0L0103oool08>`7023/1`3oool2023/1a80oooo0P0Pk0L50?ooo`808>`70P3oool2023/
1`030?ooo`0Pk0L08>`70300oooo0P0Pk0L40?ooo`808>`70`3oool2023/1`P0oooo0P0Pk0LA0?oo
o`808>`71P3oool2023/1`80oooo0P0Pk0L80?ooo`808>`700<0oooo023/1`0Pk0L0603oool00`00
0000oooo0?ooo`0>0?ooo`00303oool00`000000oooo0?ooo`0I0?ooo`808>`73P3oool3023/1`D0
oooo100Pk0LL0?ooo`808>`77@3oool2023/1`030?ooo`0Pk0L08>`700d0oooo0P0Pk0LA0?ooo`80
8>`71P3oool2023/1a/0oooo0P0Pk0M40?ooo`030000003oool0oooo00h0oooo000<0?ooo`030000
003oool0oooo0280oooo0P0Pk0L20?ooo`808>`700@0oooo023/1`0Pk0L08>`71@3oool4023/1`L0
oooo0P0Pk0Ll0?ooo`808>`71P3oool2023/1a40oooo0P0Pk0L60?ooo`808>`77P3oool2023/1a00
oooo0P0Pk0L=0?ooo`808>`7803oool00`000000oooo0?ooo`0>0?ooo`002`3oool00`000000oooo
0?ooo`0S0?ooo`808>`70P3oool2023/1a@0oooo0P0Pk0Ll0?ooo`808>`73`3oool2023/1`030?oo
o`0Pk0L08>`700<0oooo0P0Pk0L80?ooo`808>`77P3oool2023/1`h0oooo100Pk0L=0?ooo`808>`7
803oool00`000000oooo0?ooo`0>0?ooo`002`3oool00`000000oooo0?ooo`0I0?ooo`808>`72P3o
ool2023/1`/0oooo0P0Pk0L40?ooo`808>`75@3oool2023/1cT0oooo1`0Pk0L30?ooo`808>`7803o
ool2023/1`l0oooo0P0Pk0L30?ooo`@08>`7<P3oool00`000000oooo0?ooo`0=0?ooo`002P3oool0
0`000000oooo0?ooo`0J0?ooo`808>`7203oool4023/1`/0oooo0P0Pk0L40?ooo`808>`75@3oool2
023/1``0oooo0P0Pk0LE0?ooo`808>`7503oool2023/1`030?ooo`0Pk0L08>`702L0oooo0P0Pk0L?
0?ooo`808>`70`3oool2023/1c@0oooo00<000000?ooo`3oool03@3oool000X0oooo00<000000?oo
o`3oool0903oool2023/1ah0oooo0P0Pk0L30?ooo`808>`71@3oool2023/1`H0oooo0P0Pk0L40?oo
o`808>`7303oool2023/1`L0oooo0P0Pk0L80?ooo`808>`72@3oool2023/1`@0oooo0P0Pk0LK0?oo
o`808>`74`3oool2023/1`@0oooo0P0Pk0Li0?ooo`030000003oool0oooo00d0oooo00090?ooo`03
0000003oool0oooo02h0oooo0P0Pk0L30?ooo`808>`7403oool2023/1`<0oooo0P0Pk0L=0?ooo`80
8>`70P3oool2023/1`h0oooo0P0Pk0L60?ooo`808>`72@3oool2023/1`@0oooo0P0Pk0L30?ooo`80
8>`7103oool2023/1a/0oooo0P0Pk0L30?ooo`808>`73P3oool2023/1`@0oooo0P0Pk0LA0?ooo`80
8>`79P3oool00`000000oooo0?ooo`0=0?ooo`002@3oool00`000000oooo0?ooo`0Y0?ooo`808>`7
0`3oool2023/1`<0oooo0P0Pk0LX0?ooo`808>`75P3oool3023/1`h0oooo0P0Pk0L90?ooo`808>`7
803oool3023/1`d0oooo0P0Pk0LG0?ooo`808>`79P3oool00`000000oooo0?ooo`0=0?ooo`002@3o
ool00`000000oooo0?ooo`0Y0?ooo`808>`74@3oool3023/1`L0oooo100Pk0L/0?ooo`808>`76@3o
ool2023/1b00oooo0`0Pk0L=0?ooo`808>`7@03oool00`000000oooo0?ooo`0<0?ooo`00203oool0
0`000000oooo0?ooo`0i0?ooo`808>`70P3oool3023/1`L0oooo100Pk0L90?ooo`808>`73`3oool2
023/1`80oooo0P0Pk0L30?ooo`808>`70`3oool2023/1d00oooo0P0Pk0M?0?ooo`030000003oool0
oooo00`0oooo00080?ooo`030000003oool0oooo03T0oooo0P0Pk0LI0?ooo`808>`73`3oool2023/
1`80oooo0P0Pk0L30?ooo`808>`70`3oool2023/1cT0oooo0P0Pk0L50?ooo`808>`78`3oool2023/
1bX0oooo00<000000?ooo`3oool0303oool000L0oooo00<000000?ooo`3oool09P3oool3023/1a80
oooo0P0Pk0L00`3oool08>`7023/1`02023/1c<0oooo100Pk0L?0?ooo`808>`75P3oool3023/1``0
oooo0P0Pk0L50?ooo`808>`78`3oool2023/1bX0oooo00<000000?ooo`3oool0303oool000L0oooo
00<000000?ooo`3oool09P3oool3023/1`X0oooo0P0Pk0L60?ooo`808>`700<0oooo023/1`0Pk0L0
0P0Pk0LP0?ooo`808>`72`3oool2023/1`@0oooo1P0Pk0L=0?ooo`808>`71P3oool2023/1`h0oooo
0`0Pk0Lb0?ooo`808>`71@3oool2023/1bT0oooo00<000000?ooo`3oool0303oool000H0oooo00<0
00000?ooo`3oool09P3oool2023/1``0oooo0P0Pk0L:0?ooo`808>`76@3oool2023/1`H0oooo0P0P
k0L;0?ooo`808>`7203oool2023/1a@0oooo100Pk0LQ0?ooo`808>`71@3oool2023/1aP0oooo0P0P
k0L50?ooo`808>`7:P3oool00`000000oooo0?ooo`0;0?ooo`001P3oool00`000000oooo0?ooo`0V
0?ooo`808>`7;@3oool2023/1`@0oooo0P0Pk0L70?ooo`808>`7403oool2023/1`D0oooo0P0Pk0LA
0?ooo`@08>`7103oool2023/1aL0oooo0P0Pk0L20?ooo`808>`71@3oool2023/1`030?ooo`0Pk0L0
8>`704P0oooo00<000000?ooo`3oool02`3oool000H0oooo00<000000?ooo`3oool06`3oool2023/
1aX0oooo0P0Pk0L30?ooo`808>`72P3oool2023/1`X0oooo0`0Pk0L=0?ooo`808>`71`3oool2023/
1`L0oooo0P0Pk0L50?ooo`808>`76@3oool2023/1`P0oooo0P0Pk0L=0?ooo`808>`72P3oool6023/
1b<0oooo0P0Pk0LQ0?ooo`030000003oool0oooo00/0oooo00060?ooo`030000003oool0oooo01/0
oooo0P0Pk0LJ0?ooo`808>`70P3oool3023/1`X0oooo0P0Pk0L:0?ooo`808>`72P3oool2023/1`/0
oooo0P0Pk0LK0?ooo`808>`70`3oool2023/1`030?ooo`0Pk0L08>`700h0oooo0P0Pk0L70?ooo`80
8>`7403oool2023/1`80oooo0P0Pk0LS0?ooo`808>`72`3oool2023/1a@0oooo00<000000?ooo`3o
ool02`3oool000H0oooo00<000000?ooo`3oool0>@3oool4023/1`/0oooo0P0Pk0L20?ooo`808>`7
1@3oool2023/1`@0oooo0P0Pk0L50?ooo`808>`7:03oool2023/1`<0oooo0P0Pk0L00`3oool08>`7
023/1`0=0?ooo`808>`7203oool2023/1`<0oooo0P0Pk0LJ0?ooo`808>`70P3oool2023/1b40oooo
0P0Pk0LE0?ooo`030000003oool0oooo00X0oooo00060?ooo`030000003oool0oooo01`0oooo0P0P
k0L<0?ooo`808>`71@3oool4023/1`@0oooo0P0Pk0LA0?ooo`808>`71@3oool2023/1`@0oooo0P0P
k0L50?ooo`808>`7?`3oool2023/1`@0oooo0P0Pk0L70?ooo`808>`76P3oool2023/1`80oooo0P0P
k0L30?ooo`808>`7<`3oool00`000000oooo0?ooo`0:0?ooo`001P3oool00`000000oooo0?ooo`0K
0?ooo`<08>`7303oool2023/1`D0oooo100Pk0L90?ooo`808>`71@3oool2023/1a40oooo0P0Pk0L6
0?ooo`808>`7A@3oool3023/1`80oooo0P0Pk0L30?ooo`808>`7103oool2023/1`@0oooo0P0Pk0LF
0?ooo`808>`700<0oooo023/1`0Pk0L02@3oool2023/1bD0oooo00<000000?ooo`3oool02P3oool0
00H0oooo00<000000?ooo`3oool0603oool2023/1`030?ooo`0Pk0L08>`70240oooo0P0Pk0L50?oo
o`808>`74@3oool2023/1`H0oooo0P0Pk0L40?ooo`808>`72P3oool2023/1`P0oooo0P0Pk0LM0?oo
o`808>`72`3oool2023/1`80oooo0P0Pk0L30?ooo`808>`7103oool2023/1`@0oooo0P0Pk0L<0?oo
o`808>`72`3oool2023/1`T0oooo0P0Pk0L=0?ooo`808>`75P3oool00`000000oooo0?ooo`0:0?oo
o`001P3oool00`000000oooo0?ooo`0H0?ooo`808>`71P3oool2023/1a40oooo0P0Pk0LT0?ooo`80
8>`72`3oool2023/1`X0oooo0P0Pk0L80?ooo`808>`77@3oool2023/1`H0oooo0P0Pk0L60?ooo`80
8>`7403oool4023/1`X0oooo0P0Pk0LU0?ooo`808>`75P3oool00`000000oooo0?ooo`0:0?ooo`00
1P3oool00`000000oooo0?ooo`0P0?ooo`808>`73`3oool4023/1aT0oooo0`0Pk0L80?ooo`808>`7
:P3oool3023/1`X0oooo0P0Pk0L?0?ooo`<08>`71@3oool2023/1a80oooo0P0Pk0L70?ooo`808>`7
2@3oool4023/1`P0oooo0P0Pk0LZ0?ooo`030000003oool0oooo00T0oooo00060?ooo`030000003o
ool0oooo0340oooo0P0Pk0LK0?ooo`<08>`7403oool2023/1`030?ooo`0Pk0L08>`70100oooo100P
k0L60?ooo`808>`70`3oool4023/1`T0oooo0P0Pk0L@0?ooo`808>`7203oool2023/1aP0oooo0P0P
k0L90?ooo`@08>`70P3oool2023/1`@0oooo0P0Pk0LZ0?ooo`030000003oool0oooo00T0oooo0006
0?ooo`030000003oool0oooo01l0oooo0P0Pk0L`0?ooo`808>`73P3oool2023/1`030?ooo`0Pk0L0
8>`700<0oooo0P0Pk0L50?ooo`808>`7103oool5023/1`D0oooo0`0Pk0L40?ooo`808>`72P3oool4
023/1aL0oooo0`0Pk0LS0?ooo`808>`70`3oool2023/1a40oooo0P0Pk0LM0?ooo`030000003oool0
oooo00T0oooo00060?ooo`030000003oool0oooo01l0oooo0P0Pk0LA0?ooo`808>`74P3oool2023/
1`L0oooo100Pk0LF0?ooo`808>`71@3oool2023/1`L0oooo0P0Pk0L60?ooo`808>`7403oool4023/
1`h0oooo0P0Pk0L80?ooo`808>`7;@3oool4023/1`X0oooo0P0Pk0L30?ooo`808>`7603oool00`00
0000oooo0?ooo`090?ooo`001P3oool00`000000oooo0?ooo`0X0?ooo`808>`7203oool2023/1`@0
oooo0P0Pk0L<0?ooo`808>`71`3oool2023/1`L0oooo0P0Pk0M;0?ooo`808>`74`3oool2023/1`@0
oooo0P0Pk0LL0?ooo`@08>`73`3oool2023/1aP0oooo00<000000?ooo`3oool02@3oool000H0oooo
00<000000?ooo`3oool0:03oool2023/1`X0oooo0P0Pk0L20?ooo`808>`72@3oool2023/1a<0oooo
0P0Pk0LB0?ooo`808>`7203oool2023/1cP0oooo0P0Pk0L80?ooo`808>`70`3oool3023/1a<0oooo
0P0Pk0LL0?ooo`808>`75`3oool00`000000oooo0?ooo`080?ooo`001P3oool00`000000oooo0?oo
o`0d0?ooo`808>`71P3oool2023/1`D0oooo0P0Pk0L00`3oool08>`7023/1`020?ooo`808>`7803o
ool2023/1`P0oooo0`0Pk0Lg0?ooo`808>`73@3oool2023/1a@0oooo0P0Pk0LL0?ooo`808>`75`3o
ool00`000000oooo0?ooo`080?ooo`001P3oool00`000000oooo0?ooo`0a0?ooo`808>`72@3oool2
023/1`P0oooo0P0Pk0L20?ooo`808>`7:`3oool2023/1`T0oooo0P0Pk0L20?ooo`808>`75@3oool2
023/1`D0oooo100Pk0L?0?ooo`808>`71P3oool2023/1`<0oooo0P0Pk0L20?ooo`808>`7@P3oool0
0`000000oooo0?ooo`080?ooo`001P3oool00`000000oooo0?ooo`0a0?ooo`808>`7:`3oool2023/
1ah0oooo0P0Pk0L20?ooo`808>`70P3oool2023/1a@0oooo0`0Pk0L50?ooo`@08>`71P3oool2023/
1`L0oooo0P0Pk0L;0?ooo`808>`70P3oool2023/1`H0oooo0P0Pk0L@0?ooo`808>`7:03oool00`00
0000oooo0?ooo`080?ooo`001P3oool00`000000oooo0?ooo`0G0?ooo`808>`76@3oool2023/1aD0
oooo0P0Pk0L<0?ooo`808>`71@3oool2023/1`/0oooo0P0Pk0L90?ooo`@08>`7103oool2023/1`04
0?ooo`0Pk0L08>`7023/1aP0oooo0P0Pk0L50?ooo`808>`72@3oool2023/1b00oooo0P0Pk0L>0?oo
o`@08>`7:@3oool00`000000oooo0?ooo`070?ooo`001P3oool00`000000oooo0?ooo`0G0?ooo`80
8>`76@3oool2023/1aD0oooo0P0Pk0L40?ooo`808>`71P3oool2023/1`D0oooo0P0Pk0L20?ooo`80
8>`71`3oool2023/1`T0oooo100Pk0L00`3oool08>`7023/1`040?ooo`808>`700<0oooo023/1`0P
k0L01`3oool2023/1`@0oooo0P0Pk0L20?ooo`808>`72P3oool2023/1aP0oooo0P0Pk0L;0?ooo`@0
8>`74P3oool2023/1b/0oooo00<000000?ooo`3oool01`3oool000H0oooo00<000000?ooo`3oool0
:P3oool2023/1b<0oooo0P0Pk0L=0?ooo`808>`70P3oool2023/1aL0oooo0P0Pk0L70?ooo`808>`7
103oool2023/1`030?ooo`0Pk0L08>`700@0oooo0P0Pk0L20?ooo`808>`70`3oool2023/1al0oooo
0P0Pk0L40?ooo`808>`71@3oool5023/1ch0oooo00<000000?ooo`3oool01`3oool000H0oooo00<0
00000?ooo`3oool0:P3oool2023/1`L0oooo0P0Pk0L;0?ooo`808>`7803oool2023/1al0oooo0`0P
k0L40?ooo`808>`700<0oooo023/1`0Pk0L03@3oool2023/1aT0oooo0`0Pk0L50?ooo`808>`70P3o
ool2023/1`P0oooo100Pk0Ll0?ooo`030000003oool0oooo00L0oooo00060?ooo`030000003oool0
oooo03<0oooo0P0Pk0L;0?ooo`808>`7?@3oool2023/1`80oooo0`0Pk0La0?ooo`D08>`70`3oool4
023/1`80oooo0P0Pk0L30?ooo`808>`70`3oool2023/1`/0oooo0P0Pk0L20?ooo`808>`7103oool2
023/1bD0oooo00<000000?ooo`3oool01`3oool000H0oooo00<000000?ooo`3oool0>`3oool2023/
1`80oooo0`0Pk0L^0?ooo`808>`73@3oool2023/1`@0oooo0P0Pk0LF0?ooo`808>`74`3oool2023/
1`H0oooo0P0Pk0L50?ooo`808>`70P3oool4023/1`030?ooo`0Pk0L08>`70100oooo0P0Pk0L20?oo
o`808>`7103oool2023/1bH0oooo00<000000?ooo`3oool01P3oool000H0oooo00<000000?ooo`3o
ool0<`3oool2023/1`H0oooo0P0Pk0L20?ooo`808>`7;P3oool3023/1`030?ooo`0Pk0L08>`700D0
oooo0P0Pk0L90?ooo`808>`7503oool4023/1`H0oooo0P0Pk0L;0?ooo`<08>`74P3oool2023/1`D0
oooo0`0Pk0L?0?ooo`808>`700<0oooo023/1`0Pk0L02@3oool2023/1ah0oooo00<000000?ooo`3o
ool01P3oool000H0oooo00<000000?ooo`3oool08P3oool2023/1`X0oooo0P0Pk0L30?ooo`@08>`7
403oool2023/1`T0oooo1@0Pk0LF0?ooo`@08>`70P3oool2023/1`D0oooo0P0Pk0LO0?ooo`@08>`7
1P3oool2023/1`X0oooo100Pk0LI0?ooo`<08>`7203oool2023/1`@0oooo0`0Pk0L00`3oool08>`7
023/1`090?ooo`808>`77P3oool00`000000oooo0?ooo`060?ooo`001P3oool00`000000oooo0?oo
o`0R0?ooo`808>`7103oool2023/1`80oooo100Pk0L50?ooo`808>`73`3oool3023/1`T0oooo1@0P
k0LD0?ooo`@08>`7;P3oool2023/1a80oooo0P0Pk0LV0?ooo`808>`7103oool2023/1bd0oooo00<0
00000?ooo`3oool01P3oool000H0oooo00<000000?ooo`3oool0503oool2023/1a80oooo0P0Pk0L2
0?ooo`808>`7603oool2023/1`d0oooo0P0Pk0LD0?ooo`@08>`7W`3oool00`000000oooo0?ooo`06
0?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`808>`7>P3oool2023/1`<0oooo0`0Pk0LO0?oo
o`808>`7:@3oool2023/1ad0oooo0P0Pk0LC0?ooo`808>`7=`3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0M0?ooo`808>`7603oool2023/1`P0oooo0P0Pk0L40?ooo`80
8>`71`3oool2023/1`<0oooo0`0Pk0LO0?ooo`808>`71@3oool2023/1ah0oooo0P0Pk0L20?ooo`80
8>`7103oool2023/1aL0oooo0P0Pk0L:0?ooo`808>`71`3oool2023/1`h0oooo0P0Pk0LW0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo01d0oooo0P0Pk0L<0?ooo`808>`7
0P3oool2023/1`H0oooo0P0Pk0L80?ooo`808>`7103oool2023/1aD0oooo0P0Pk0L00`3oool08>`7
023/1`0K0?ooo`808>`77P3oool2023/1`P0oooo0`0Pk0LE0?ooo`808>`71P3oool2023/1`<0oooo
0P0Pk0LG0?ooo`808>`79`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`0[0?ooo`808>`70P3oool4023/1`030?ooo`0Pk0L08>`700T0oooo0P0Pk0LK0?ooo`@08>`700<0
oooo023/1`0Pk0L0303oool2023/1`D0oooo0P0Pk0L;0?ooo`808>`7903oool2023/1`D0oooo0P0P
k0L>0?ooo`808>`71P3oool2023/1a@0oooo0P0Pk0LG0?ooo`808>`75P3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`0U0?ooo`808>`7203oool4023/1`030?ooo`0Pk0L0
8>`700T0oooo0P0Pk0LK0?ooo`808>`74@3oool2023/1`D0oooo0P0Pk0L;0?ooo`808>`76P3oool2
023/1`P0oooo0P0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L0;03oool2023/1`D0oooo0P0Pk0L@
0?ooo`808>`75@3oool00`000000oooo0?ooo`060?ooo`001P3oool00`000000oooo0?ooo`0U0?oo
o`808>`71@3oool2023/1`h0oooo0P0Pk0LE0?ooo`<08>`700<0oooo023/1`0Pk0L0903oool2023/
1b00oooo0P0Pk0L<0?ooo`808>`71@3oool2023/1`h0oooo0P0Pk0LO0?ooo`808>`79`3oool00`00
0000oooo0?ooo`060?ooo`001P3oool00`000000oooo0?ooo`0/0?ooo`808>`70P3oool2023/1`<0
oooo0P0Pk0L50?ooo`808>`75@3oool3023/1`030?ooo`0Pk0L08>`70140oooo0P0Pk0L=0?ooo`80
8>`70P3oool2023/1`/0oooo0P0Pk0LA0?ooo`808>`7103oool2023/1`l0oooo0P0Pk0L>0?ooo`80
8>`7B03oool00`000000oooo0?ooo`060?ooo`001P3oool00`000000oooo0?ooo`0`0?ooo`808>`7
0`3oool4023/1`<0oooo0P0Pk0L50?ooo`808>`79@3oool2023/1`d0oooo0P0Pk0L?0?ooo`808>`7
4@3oool2023/1`@0oooo0P0Pk0LP0?ooo`808>`7703oool2023/1bT0oooo00<000000?ooo`3oool0
1P3oool000H0oooo00<000000?ooo`3oool09P3oool2023/1`l0oooo0P0Pk0L:0?ooo`808>`70P3o
ool2023/1`h0oooo0P0Pk0LA0?ooo`808>`74P3oool4023/1`L0oooo0P0Pk0Lc0?ooo`808>`71@3o
ool2023/1a`0oooo0P0Pk0LY0?ooo`030000003oool0oooo00H0oooo00060?ooo`030000003oool0
oooo02H0oooo0P0Pk0LO0?ooo`808>`71@3oool2023/1`L0oooo0P0Pk0L<0?ooo`808>`71P3oool2
023/1`l0oooo1`0Pk0L40?ooo`808>`7<03oool2023/1`030?ooo`0Pk0L08>`704d0oooo00<00000
0?ooo`3oool01`3oool000H0oooo00<000000?ooo`3oool07P3oool2023/1bh0oooo0P0Pk0L00`3o
ool08>`7023/1`0B0?ooo`808>`70P3oool2023/1`80oooo0P0Pk0LB0?ooo`@08>`7303oool2023/
1`H0oooo0P0Pk0LP0?ooo`808>`7D03oool00`000000oooo0?ooo`070?ooo`001P3oool00`000000
oooo0?ooo`0N0?ooo`808>`73P3oool2023/1a<0oooo0P0Pk0L40?ooo`808>`71P3oool2023/1`l0
oooo0P0Pk0L50?ooo`808>`74@3oool4023/1a40oooo0P0Pk0L60?ooo`808>`7103oool2023/1bT0
oooo0P0Pk0M10?ooo`030000003oool0oooo00L0oooo00060?ooo`030000003oool0oooo02h0oooo
0P0Pk0LC0?ooo`808>`7103oool2023/1`h0oooo0P0Pk0L40?ooo`808>`700<0oooo023/1`0Pk0L0
603oool4023/1al0oooo0P0Pk0L80?ooo`808>`77`3oool2023/1`L0oooo0P0Pk0LE0?ooo`808>`7
8@3oool00`000000oooo0?ooo`070?ooo`001P3oool00`000000oooo0?ooo`0f0?ooo`808>`7603o
ool2023/1`L0oooo0P0Pk0L40?ooo`808>`7703oool3023/1bT0oooo0P0Pk0L=0?ooo`<08>`7603o
ool2023/1`<0oooo0P0Pk0L60?ooo`808>`7203oool2023/1b40oooo00<000000?ooo`3oool01`3o
ool000H0oooo00<000000?ooo`3oool0=P3oool2023/1aD0oooo0P0Pk0L00`3oool08>`7023/1`02
0?ooo`<08>`70P3oool2023/1b<0oooo0P0Pk0L50?ooo`808>`79@3oool2023/1`X0oooo0`0Pk0L5
0?ooo`808>`74`3oool2023/1`030?ooo`0Pk0L08>`700H0oooo100Pk0LX0?ooo`030000003oool0
oooo00P0oooo00060?ooo`030000003oool0oooo02@0oooo0P0Pk0LW0?ooo`808>`71@3oool3023/
1`80oooo0P0Pk0LV0?ooo`808>`70P3oool2023/1`L0oooo0P0Pk0L60?ooo`808>`7103oool2023/
1`h0oooo0P0Pk0LB0?ooo`808>`72`3oool2023/1`H0oooo0P0Pk0L;0?ooo`808>`70P3oool4023/
1`L0oooo0P0Pk0LI0?ooo`030000003oool0oooo00P0oooo00060?ooo`030000003oool0oooo02@0
oooo0P0Pk0L60?ooo`808>`76P3oool2023/1bH0oooo0P0Pk0L30?ooo`<08>`72@3oool2023/1`/0
oooo0P0Pk0L20?ooo`808>`70P3oool2023/1`@0oooo0P0Pk0LB0?ooo`808>`76`3oool2023/1aD0
oooo1P0Pk0L70?ooo`808>`76@3oool00`000000oooo0?ooo`080?ooo`001P3oool00`000000oooo
0?ooo`0/0?ooo`@08>`73`3oool3023/1`H0oooo0P0Pk0LF0?ooo`808>`73P3oool2023/1`<0oooo
0`0Pk0LB0?ooo`808>`71P3oool2023/1`80oooo0P0Pk0LH0?ooo`808>`7203oool2023/1bP0oooo
0P0Pk0LV0?ooo`030000003oool0oooo00P0oooo00060?ooo`030000003oool0oooo02D0oooo0P0P
k0L70?ooo`808>`73`3oool3023/1`L0oooo0P0Pk0LE0?ooo`808>`70P3oool2023/1`@0oooo100P
k0L<0?ooo`808>`73P3oool2023/1`X0oooo0P0Pk0L50?ooo`808>`73@3oool2023/1`D0oooo0P0P
k0L50?ooo`808>`7403oool2023/1`D0oooo0P0Pk0L50?ooo`808>`7;`3oool00`000000oooo0?oo
o`090?ooo`001P3oool00`000000oooo0?ooo`090?ooo`808>`76P3oool7023/1aD0oooo0P0Pk0L6
0?ooo`808>`76@3oool2023/1`@0oooo100Pk0L<0?ooo`808>`78@3oool2023/1`@0oooo0P0Pk0L0
103oool08>`7023/1`3oool2023/1`030?ooo`0Pk0L08>`700D0oooo0P0Pk0L:0?ooo`808>`700<0
oooo023/1`0Pk0L0203oool2023/1`030?ooo`0Pk0L08>`70080oooo0P0Pk0L50?ooo`808>`7;`3o
ool00`000000oooo0?ooo`090?ooo`001P3oool00`000000oooo0?ooo`090?ooo`808>`73@3oool2
023/1`d0oooo1@0Pk0LE0?ooo`808>`700<0oooo023/1`0Pk0L00P3oool3023/1b40oooo0P0Pk0LB
0?ooo`@08>`72P3oool2023/1`<0oooo0P0Pk0L>0?ooo`808>`700@0oooo023/1`0Pk0L0oooo0P0P
k0L90?ooo`808>`70P3oool2023/1`D0oooo0P0Pk0L00`3oool08>`7023/1`0;0?ooo`@08>`7103o
ool2023/1c80oooo00<000000?ooo`3oool02@3oool000H0oooo00<000000?ooo`3oool0603oool2
023/1``0oooo0P0Pk0L90?ooo`808>`74@3oool2023/1`80oooo100Pk0Ld0?ooo`@08>`72P3oool2
023/1`<0oooo0P0Pk0L:0?ooo`808>`7103oool2023/1`d0oooo0P0Pk0L20?ooo`808>`71@3oool2
023/1a00oooo0P0Pk0L40?ooo`808>`7<P3oool00`000000oooo0?ooo`090?ooo`001P3oool00`00
0000oooo0?ooo`0V0?ooo`808>`72@3oool2023/1`80oooo0P0Pk0LC0?ooo`808>`72@3oool2023/
1``0oooo0P0Pk0L^0?ooo`@08>`7203oool2023/1`@0oooo0P0Pk0L=0?ooo`@08>`74P3oool2023/
1`D0oooo0P0Pk0Lh0?ooo`030000003oool0oooo00T0oooo00060?ooo`030000003oool0oooo00H0
oooo0P0Pk0LY0?ooo`808>`70P3oool2023/1ah0oooo0P0Pk0L;0?ooo`@08>`74@3oool2023/1`03
0?ooo`0Pk0L08>`701@0oooo0P0Pk0L30?ooo`808>`73P3oool2023/1`d0oooo100Pk0L<0?ooo`80
8>`7103oool2023/1ch0oooo00<000000?ooo`3oool02P3oool000H0oooo00<000000?ooo`3oool0
1P3oool2023/1bT0oooo0P0Pk0LG0?ooo`808>`75P3oool4023/1a40oooo0P0Pk0L00`3oool08>`7
023/1`0D0?ooo`808>`7<P3oool2023/1`030?ooo`0Pk0L08>`700P0oooo0P0Pk0Lg0?ooo`030000
003oool0oooo00X0oooo00060?ooo`030000003oool0oooo04H0oooo0P0Pk0L20?ooo`808>`7103o
ool2023/1``0oooo0P0Pk0M20?ooo`808>`75P3oool2023/1`/0oooo100Pk0L60?ooo`808>`74`3o
ool2023/1b80oooo00<000000?ooo`3oool02P3oool000H0oooo00<000000?ooo`3oool0903oool2
023/1a<0oooo0P0Pk0L;0?ooo`808>`7203oool2023/1``0oooo0P0Pk0L[0?ooo`808>`75@3oool2
023/1`80oooo0P0Pk0L40?ooo`808>`7303oool2023/1`d0oooo0P0Pk0L40?ooo`808>`75@3oool2
023/1b80oooo00<000000?ooo`3oool02P3oool000H0oooo00<000000?ooo`3oool0903oool2023/
1`<0oooo0P0Pk0L>0?ooo`808>`71`3oool2023/1`030?ooo`0Pk0L08>`701P0oooo0P0Pk0LB0?oo
o`808>`75P3oool2023/1aT0oooo0P0Pk0L40?ooo`808>`74`3oool2023/1``0oooo0P0Pk0Li0?oo
o`030000003oool0oooo00X0oooo00060?ooo`030000003oool0oooo00`0oooo0P0Pk0LK0?ooo`80
8>`75`3oool2023/1`030?ooo`0Pk0L08>`701P0oooo0P0Pk0LB0?ooo`808>`77@3oool2023/1a`0
oooo0P0Pk0L20?ooo`808>`72`3oool2023/1`P0oooo0P0Pk0L00`3oool08>`7023/1`020?ooo`80
8>`79`3oool2023/1``0oooo00<000000?ooo`3oool02`3oool000H0oooo00<000000?ooo`3oool0
303oool2023/1cD0oooo0P0Pk0L=0?ooo`808>`72P3oool2023/1bX0oooo0P0Pk0L60?ooo`808>`7
703oool2023/1`80oooo0P0Pk0L>0?ooo`808>`7103oool3023/1`030?ooo`0Pk0L08>`70080oooo
0P0Pk0LW0?ooo`808>`7303oool00`000000oooo0?ooo`0;0?ooo`001P3oool00`000000oooo0?oo
o`0h0?ooo`<08>`7203oool4023/1`/0oooo0P0Pk0L80?ooo`@08>`74P3oool2023/1aH0oooo100P
k0L?0?ooo`808>`74@3oool2023/1`80oooo0P0Pk0L>0?ooo`808>`70P3oool4023/1a40oooo0P0P
k0LZ0?ooo`030000003oool0oooo00/0oooo00060?ooo`030000003oool0oooo02P0oooo0P0Pk0L>
0?ooo`<08>`70`3oool4023/1`<0oooo0P0Pk0L;0?ooo`808>`7203oool2023/1a@0oooo0P0Pk0LH
0?ooo`808>`7203oool2023/1`D0oooo0P0Pk0L:0?ooo`808>`72@3oool2023/1`T0oooo0P0Pk0L7
0?ooo`808>`70P3oool2023/1`P0oooo0P0Pk0L30?ooo`D08>`7:@3oool00`000000oooo0?ooo`0;
0?ooo`001`3oool00`000000oooo0?ooo`0L0?ooo`808>`72@3oool3023/1`L0oooo0P0Pk0L40?oo
o`808>`70P3oool6023/1`030?ooo`0Pk0L08>`700L0oooo0P0Pk0L20?ooo`808>`700<0oooo023/
1`0Pk0L0503oool2023/1`D0oooo0P0Pk0L60?ooo`808>`700<0oooo023/1`0Pk0L02`3oool2023/
1`T0oooo0P0Pk0L00`3oool08>`7023/1`0A0?ooo`808>`73@3oool2023/1`D0oooo0P0Pk0L;0?oo
o`808>`7203oool2023/1`<0oooo1@0Pk0L80?ooo`808>`73@3oool2023/1`l0oooo00<000000?oo
o`3oool0303oool000L0oooo00<000000?ooo`3oool0703oool3023/1`T0oooo0`0Pk0L60?ooo`80
8>`7103oool2023/1`80oooo0P0Pk0L50?ooo`808>`71`3oool2023/1`80oooo0P0Pk0L00`3oool0
8>`7023/1`0D0?ooo`808>`71@3oool2023/1`H0oooo0P0Pk0L00`3oool08>`7023/1`0;0?ooo`80
8>`72@3oool2023/1b<0oooo0P0Pk0L70?ooo`808>`77P3oool2023/1`D0oooo0P0Pk0L=0?ooo`80
8>`73`3oool00`000000oooo0?ooo`0<0?ooo`00203oool00`000000oooo0?ooo`0L0?ooo`808>`7
2P3oool2023/1`@0oooo0P0Pk0L80?ooo`808>`73@3oool2023/1g@0oooo100Pk0LN0?ooo`808>`7
203oool2023/1a/0oooo00<000000?ooo`3oool0303oool000P0oooo00<000000?ooo`3oool05P3o
ool2023/1aH0oooo0P0Pk0L80?ooo`808>`73@3oool2023/1aL0oooo0P0Pk0MK0?ooo`808>`700<0
oooo023/1`0Pk0L03@3oool2023/1``0oooo0P0Pk0L:0?ooo`808>`76`3oool00`000000oooo0?oo
o`0<0?ooo`002@3oool00`000000oooo0?ooo`0E0?ooo`808>`73P3oool2023/1cP0oooo0P0Pk0LI
0?ooo`808>`71`3oool2023/1`L0oooo0P0Pk0L30?ooo`808>`78@3oool4023/1`L0oooo0P0Pk0L0
0`3oool08>`7023/1`090?ooo`<08>`7303oool2023/1bL0oooo00<000000?ooo`3oool0303oool0
00T0oooo00<000000?ooo`3oool0403oool2023/1a<0oooo0P0Pk0LA0?ooo`808>`7;03oool2023/
1`80oooo0P0Pk0L>0?ooo`808>`71`3oool2023/1`030?ooo`0Pk0L08>`700<0oooo0`0Pk0L30?oo
o`808>`76P3oool2023/1`D0oooo100Pk0L70?ooo`808>`700<0oooo023/1`0Pk0L02@3oool2023/
1`@0oooo0P0Pk0L50?ooo`808>`71@3oool2023/1b40oooo00<000000?ooo`3oool03@3oool000T0
oooo00<000000?ooo`3oool0403oool2023/1bH0oooo0P0Pk0LT0?ooo`808>`71P3oool2023/1`80
oooo0P0Pk0L50?ooo`808>`73P3oool2023/1`<0oooo0P0Pk0L30?ooo`808>`71`3oool2023/1aL0
oooo0P0Pk0L30?ooo`808>`77`3oool2023/1`D0oooo0P0Pk0L50?ooo`808>`700<0oooo023/1`0P
k0L07P3oool00`000000oooo0?ooo`0=0?ooo`002P3oool00`000000oooo0?ooo`0_0?ooo`808>`7
0P3oool2023/1bP0oooo0P0Pk0LA0?ooo`808>`73P3oool2023/1`H0oooo0P0Pk0L90?ooo`808>`7
5@3oool2023/1`D0oooo100Pk0LT0?ooo`808>`7203oool2023/1ah0oooo00<000000?ooo`3oool0
3@3oool000X0oooo00<000000?ooo`3oool08P3oool2023/1`<0oooo0P0Pk0L40?ooo`@08>`70P3o
ool2023/1`80oooo0P0Pk0L20?ooo`808>`7803oool2023/1a/0oooo0P0Pk0L<0?ooo`808>`72@3o
ool2023/1aD0oooo0P0Pk0L00`3oool08>`7023/1`040?ooo`808>`7303oool2023/1`l0oooo0P0P
k0L50?ooo`808>`7:03oool00`000000oooo0?ooo`0=0?ooo`002`3oool00`000000oooo0?ooo`0Q
0?ooo`808>`70`3oool2023/1`@0oooo0P0Pk0L80?ooo`808>`70P3oool2023/1a00oooo100Pk0LY
0?ooo`808>`7<@3oool2023/1`X0oooo0P0Pk0L20?ooo`808>`70P3oool2023/1`l0oooo0P0Pk0L_
0?ooo`030000003oool0oooo00d0oooo000;0?ooo`030000003oool0oooo02l0oooo0P0Pk0LK0?oo
o`@08>`7303oool2023/1b@0oooo0P0Pk0LL0?ooo`808>`75P3oool2023/1`80oooo0P0Pk0M30?oo
o`030000003oool0oooo00h0oooo000<0?ooo`030000003oool0oooo02h0oooo0P0Pk0L;0?ooo`80
8>`77P3oool2023/1`P0oooo0P0Pk0L>0?ooo`808>`72P3oool2023/1`@0oooo100Pk0L>0?ooo`80
8>`7103oool2023/1`H0oooo0P0Pk0L@0?ooo`@08>`7103oool2023/1aL0oooo0P0Pk0LT0?ooo`03
0000003oool0oooo00h0oooo000<0?ooo`030000003oool0oooo02l0oooo0P0Pk0L:0?ooo`808>`7
8P3oool2023/1`@0oooo0P0Pk0L:0?ooo`808>`70P3oool2023/1`H0oooo0P0Pk0L80?ooo`@08>`7
1@3oool2023/1`L0oooo0P0Pk0L<0?ooo`808>`7403oool2023/1`H0oooo0P0Pk0LG0?ooo`808>`7
903oool00`000000oooo0?ooo`0>0?ooo`003@3oool00`000000oooo0?ooo`0V0?ooo`808>`71P3o
ool2023/1`L0oooo0P0Pk0LN0?ooo`808>`71@3oool2023/1`030?ooo`0Pk0L08>`700d0oooo0P0P
k0L:0?ooo`808>`74@3oool2023/1aP0oooo0P0Pk0L;0?ooo`808>`71P3oool2023/1cl0oooo00<0
00000?ooo`3oool03P3oool000d0oooo00<000000?ooo`3oool09P3oool2023/1`T0oooo0P0Pk0L4
0?ooo`808>`72`3oool2023/1a40oooo0P0Pk0L60?ooo`@08>`71P3oool3023/1b40oooo0P0Pk0L8
0?ooo`808>`71P3oool2023/1`P0oooo0`0Pk0L90?ooo`<08>`71P3oool2023/1`h0oooo0P0Pk0L^
0?ooo`030000003oool0oooo00l0oooo000>0?ooo`030000003oool0oooo02D0oooo0P0Pk0L90?oo
o`808>`74@3oool2023/1`d0oooo0P0Pk0L20?ooo`808>`700<0oooo023/1`0Pk0L00`3oool2023/
1`P0oooo0`0Pk0L@0?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0L:0?ooo`808>`7203oool2023/
1`H0oooo0P0Pk0L20?ooo`808>`71@3oool2023/1`80oooo0P0Pk0L50?ooo`808>`71`3oool2023/
1`h0oooo0P0Pk0L70?ooo`808>`79@3oool00`000000oooo0?ooo`0?0?ooo`003P3oool00`000000
oooo0?ooo`1?0?ooo`808>`700<0oooo023/1`0Pk0L00P3oool2023/1`030?ooo`0Pk0L08>`700H0
oooo0P0Pk0LH0?ooo`808>`700<0oooo023/1`0Pk0L00P0Pk0LP0?ooo`808>`72@3oool2023/1bL0
oooo0P0Pk0LU0?ooo`030000003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo0400oooo
0P0Pk0L<0?ooo`808>`73P3oool4023/1`D0oooo0P0Pk0LH0?ooo`808>`7:@3oool2023/1dh0oooo
00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool0@03oool2023/1`T0oooo0P0P
k0LA0?ooo`808>`71`3oool2023/1`X0oooo0P0Pk0L<0?ooo`808>`7:@3oool2023/1`030?ooo`0P
k0L08>`704/0oooo00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool07P3oool2
023/1`d0oooo100Pk0LF0?ooo`808>`70P3oool2023/1`L0oooo0P0Pk0LH0?ooo`808>`70`3oool2
023/1c@0oooo0P0Pk0L40?ooo`808>`7BP3oool00`000000oooo0?ooo`0@0?ooo`00403oool00`00
0000oooo0?ooo`050?ooo`808>`75P3oool2023/1`L0oooo0P0Pk0L40?ooo`@08>`72P3oool2023/
1`030?ooo`0Pk0L08>`700L0oooo0P0Pk0L;0?ooo`808>`7603oool2023/1`@0oooo0P0Pk0L20?oo
o`808>`7;`3oool2023/1e00oooo00<000000?ooo`3oool0403oool00100oooo00<000000?ooo`3o
ool01@3oool2023/1al0oooo0P0Pk0L20?ooo`808>`73P3oool2023/1`030?ooo`0Pk0L08>`701D0
oooo0P0Pk0LM0?ooo`808>`70P3oool2023/1a`0oooo0P0Pk0LB0?ooo`@08>`7C@3oool00`000000
oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`090?ooo`808>`77P3oool2023/1aP0oooo
0P0Pk0L>0?ooo`808>`70P3oool2023/1`X0oooo0P0Pk0L80?ooo`808>`73`3oool2023/1`80oooo
0P0Pk0L@0?ooo`808>`74P3oool4023/1dd0oooo00<000000?ooo`3oool0403oool00140oooo00<0
00000?ooo`3oool02@3oool2023/1b@0oooo0P0Pk0L00`3oool08>`7023/1`0?0?ooo`808>`73P3o
ool2023/1`80oooo0P0Pk0L:0?ooo`808>`7203oool2023/1``0oooo0P0Pk0L00`3oool08>`7023/
1`020?ooo`808>`71`3oool2023/1`L0oooo0P0Pk0L90?ooo`808>`7603oool2023/1`<0oooo0P0P
k0Li0?ooo`030000003oool0oooo0100oooo000B0?ooo`030000003oool0oooo02h0oooo0P0Pk0L0
0`3oool08>`7023/1`0O0?ooo`808>`79P3oool2023/1`h0oooo0P0Pk0LB0?ooo`808>`71`3oool2
023/1`H0oooo0P0Pk0L50?ooo`@08>`70`3oool2023/1cP0oooo00<000000?ooo`3oool04@3oool0
0180oooo00<000000?ooo`3oool0;P3oool2023/1cP0oooo0P0Pk0LE0?ooo`808>`72@3oool2023/
1a/0oooo0P0Pk0L60?ooo`808>`71@3oool3023/1a80oooo0P0Pk0LZ0?ooo`030000003oool0oooo
0140oooo000C0?ooo`030000003oool0oooo02d0oooo0P0Pk0L40?ooo`808>`7<P3oool2023/1`D0
oooo0P0Pk0L>0?ooo`808>`700<0oooo023/1`0Pk0L0:P3oool3023/1`H0oooo0P0Pk0LB0?ooo`80
8>`7:P3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`0L0?ooo`808>`7
5@3oool3023/1a80oooo0P0Pk0LT0?ooo`808>`71`3oool2023/1`P0oooo0P0Pk0LZ0?ooo`808>`7
1`3oool2023/1`H0oooo0P0Pk0Le0?ooo`030000003oool0oooo0180oooo000D0?ooo`030000003o
ool0oooo01/0oooo0P0Pk0LF0?ooo`808>`74P3oool2023/1a@0oooo0P0Pk0LB0?ooo`808>`70`3o
ool2023/1ah0oooo0P0Pk0L50?ooo`808>`75P3oool2023/1`@0oooo100Pk0Ld0?ooo`030000003o
ool0oooo01<0oooo000D0?ooo`030000003oool0oooo0340oooo0P0Pk0LC0?ooo`808>`700<0oooo
023/1`0Pk0L02`3oool2023/1`D0oooo0P0Pk0L60?ooo`808>`72P3oool2023/1a00oooo0P0Pk0LA
0?ooo`808>`71@3oool2023/1a`0oooo0P0Pk0Le0?ooo`030000003oool0oooo01@0oooo000E0?oo
o`030000003oool0oooo0300oooo0P0Pk0LB0?ooo`<08>`700<0oooo023/1`0Pk0L01@3oool2023/
1`80oooo100Pk0L=0?ooo`808>`7703oool2023/1`030?ooo`0Pk0L08>`702T0oooo0P0Pk0L30?oo
o`808>`7403oool2023/1bP0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3o
ool0;`3oool2023/1`D0oooo0P0Pk0L<0?ooo`@08>`71`3oool3023/1`030?ooo`0Pk0L08>`70300
oooo0P0Pk0LY0?ooo`808>`70`3oool2023/1a00oooo0P0Pk0LW0?ooo`030000003oool0oooo01D0
oooo000E0?ooo`030000003oool0oooo01H0oooo0P0Pk0L30?ooo`808>`72@3oool2023/1`D0oooo
100Pk0L50?ooo`808>`70P3oool2023/1`X0oooo0P0Pk0L80?ooo`808>`78P3oool2023/1`l0oooo
0P0Pk0L60?ooo`808>`76@3oool3023/1d@0oooo00<000000?ooo`3oool05P3oool001H0oooo00<0
00000?ooo`3oool05@3oool2023/1`<0oooo0`0Pk0L80?ooo`808>`70`3oool4023/1`L0oooo0P0P
k0L20?ooo`808>`70`3oool2023/1ad0oooo0P0Pk0LD0?ooo`808>`73`3oool2023/1`H0oooo0P0P
k0L30?ooo`808>`72`3oool2023/1`L0oooo0`0Pk0LG0?ooo`808>`73P3oool2023/1a/0oooo00<0
00000?ooo`3oool05P3oool001H0oooo00<000000?ooo`3oool06`3oool2023/1`d0oooo0P0Pk0L3
0?ooo`808>`7103oool2023/1`L0oooo0P0Pk0LM0?ooo`808>`74P3oool4023/1`030?ooo`0Pk0L0
8>`700X0oooo0P0Pk0L=0?ooo`808>`72`3oool2023/1`@0oooo0P0Pk0L80?ooo`808>`72P3oool2
023/1`D0oooo0P0Pk0L>0?ooo`808>`76P3oool00`000000oooo0?ooo`0G0?ooo`005`3oool00`00
0000oooo0?ooo`0I0?ooo`808>`74`3oool2023/1aT0oooo0P0Pk0LU0?ooo`@08>`700@0oooo023/
1`0Pk0L0oooo0P0Pk0L70?ooo`808>`71P3oool2023/1`@0oooo0P0Pk0L40?ooo`808>`7303oool2
023/1`P0oooo0P0Pk0L:0?ooo`808>`7<03oool00`000000oooo0?ooo`0H0?ooo`005`3oool00`00
0000oooo0?ooo`0I0?ooo`808>`7;P3oool2023/1bd0oooo100Pk0L=0?ooo`808>`7103oool2023/
1`@0oooo0P0Pk0LO0?ooo`808>`73P3oool2023/1b80oooo00<000000?ooo`3oool06@3oool001P0
oooo00<000000?ooo`3oool0>03oool2023/1`X0oooo0P0Pk0LY0?ooo`808>`7203oool2023/1cX0
oooo0P0Pk0L>0?ooo`808>`71`3oool2023/1aT0oooo00<000000?ooo`3oool06@3oool001P0oooo
00<000000?ooo`3oool0=03oool2023/1`80oooo0P0Pk0L:0?ooo`808>`7:@3oool2023/1``0oooo
0P0Pk0L20?ooo`808>`7B`3oool2023/1aP0oooo00<000000?ooo`3oool06P3oool001T0oooo00<0
00000?ooo`3oool0:P3oool2023/1`L0oooo0P0Pk0Lj0?ooo`808>`72`3oool2023/1`80oooo1@0P
k0LF0?ooo`808>`73@3oool2023/1cX0oooo00<000000?ooo`3oool06`3oool001T0oooo00<00000
0?ooo`3oool0:P3oool2023/1`L0oooo0P0Pk0L40?ooo`<08>`72`3oool2023/1`D0oooo0P0Pk0LO
0?ooo`808>`72`3oool2023/1`<0oooo100Pk0L>0?ooo`808>`71P3oool2023/1`d0oooo0P0Pk0Lj
0?ooo`030000003oool0oooo01/0oooo000J0?ooo`030000003oool0oooo0380oooo0P0Pk0L40?oo
o`<08>`72`3oool2023/1`D0oooo0P0Pk0LT0?ooo`808>`71@3oool3023/1a<0oooo100Pk0L20?oo
o`808>`7C03oool00`000000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`0n0?ooo`80
8>`7703oool2023/1`d0oooo0P0Pk0L50?ooo`<08>`71@3oool2023/1a@0oooo0P0Pk0L20?ooo`@0
8>`7B`3oool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0m0?ooo`808>`7
1`3oool2023/1a<0oooo100Pk0L;0?ooo`808>`71@3oool2023/1b00oooo0P0Pk0L;0?ooo`808>`7
?`3oool00`000000oooo0?ooo`0N0?ooo`006`3oool00`000000oooo0?ooo`0I0?ooo`808>`700<0
oooo023/1`0Pk0L05`3oool2023/1`l0oooo0P0Pk0L00`3oool08>`7023/1`0B0?ooo`808>`72P3o
ool2023/1`L0oooo0P0Pk0L;0?ooo`@08>`77@3oool2023/1cl0oooo00<000000?ooo`3oool07P3o
ool001/0oooo00<000000?ooo`3oool06@3oool2023/1`030?ooo`0Pk0L08>`700h0oooo0P0Pk0L7
0?ooo`808>`74P3oool2023/1ah0oooo0P0Pk0L70?ooo`808>`72`3oool4023/1aL0oooo0P0Pk0L9
0?ooo`808>`73P3oool2023/1bT0oooo00<000000?ooo`3oool07`3oool001`0oooo00<000000?oo
o`3oool03`3oool2023/1aX0oooo0P0Pk0LD0?ooo`808>`79@3oool2023/1`T0oooo0P0Pk0LF0?oo
o`808>`7303oool2023/1`T0oooo0P0Pk0L>0?ooo`808>`7:03oool00`000000oooo0?ooo`0P0?oo
o`00703oool00`000000oooo0?ooo`0?0?ooo`808>`7;@3oool2023/1`030?ooo`0Pk0L08>`701P0
oooo0P0Pk0LF0?ooo`808>`75P3oool2023/1`L0oooo0P0Pk0LG0?ooo`808>`7;P3oool00`000000
oooo0?ooo`0Q0?ooo`007@3oool00`000000oooo0?ooo`0m0?ooo`808>`76`3oool2023/1`h0oooo
0P0Pk0LW0?ooo`808>`75`3oool2023/1bh0oooo00<000000?ooo`3oool08@3oool001d0oooo00<0
00000?ooo`3oool0<`3oool2023/1``0oooo0P0Pk0LS0?ooo`808>`70P3oool2023/1bh0oooo0P0P
k0L20?ooo`808>`7>`3oool00`000000oooo0?ooo`0R0?ooo`007P3oool2000003<0oooo0P0Pk0L<
0?ooo`808>`73`3oool2023/1`X0oooo0P0Pk0L60?ooo`808>`71@3oool2023/1`030?ooo`0Pk0L0
8>`700X0oooo0P0Pk0LL0?ooo`H08>`7>P3oool00`000000oooo0?ooo`0S0?ooo`00803oool00`00
0000oooo0?ooo`0S0?ooo`808>`75P3oool2023/1a80oooo0P0Pk0L:0?ooo`808>`73@3oool2023/
1`030?ooo`0Pk0L08>`700H0oooo0P0Pk0L20?ooo`808>`7603oool2023/1`@0oooo0P0Pk0Ll0?oo
o`030000003oool0oooo02<0oooo000Q0?ooo`030000003oool0oooo0280oooo0P0Pk0LF0?ooo`80
8>`7>03oool2023/1`T0oooo0P0Pk0LA0?ooo`808>`70P3oool4023/1c/0oooo00<000000?ooo`3o
ool0903oool00280oooo00<000000?ooo`3oool0?`3oool2023/1aX0oooo0P0Pk0L70?ooo`808>`7
3@3oool2023/1`T0oooo0P0Pk0LE0?ooo`808>`73`3oool2023/1b/0oooo00<000000?ooo`3oool0
9@3oool002<0oooo00<000000?ooo`3oool08@3oool2023/1a@0oooo0P0Pk0L30?ooo`@08>`71@3o
ool3023/1a80oooo0P0Pk0L70?ooo`808>`700<0oooo023/1`0Pk0L02P3oool2023/1`T0oooo0P0P
k0LV0?ooo`808>`7:P3oool00`000000oooo0?ooo`0V0?ooo`00903oool00`000000oooo0?ooo`0N
0?ooo`@08>`74P3oool4023/1`<0oooo0P0Pk0L70?ooo`<08>`700<0oooo023/1`0Pk0L02P3oool2
023/1`<0oooo0P0Pk0L:0?ooo`808>`75@3oool2023/1e80oooo00<000000?ooo`3oool09P3oool0
02D0oooo00<000000?ooo`3oool07@3oool2023/1`l0oooo0P0Pk0L30?ooo`808>`71`3oool2023/
1`030?ooo`0Pk0L08>`700H0oooo0`0Pk0L90?ooo`808>`70`3oool2023/1g@0oooo00<000000?oo
o`3oool09`3oool002H0oooo00<000000?ooo`3oool0;@3oool4023/1`P0oooo100Pk0L00`3oool0
8>`7023/1`070?ooo`808>`70P3oool2023/1aH0oooo0P0Pk0MW0?ooo`030000003oool0oooo02P0
oooo000W0?ooo`030000003oool0oooo02h0oooo0P0Pk0L80?ooo`808>`7303oool2023/1`80oooo
0P0Pk0L60?ooo`808>`73P3oool2023/1aP0oooo0P0Pk0L70?ooo`808>`70P3oool2023/1ad0oooo
0P0Pk0LP0?ooo`030000003oool0oooo02T0oooo000X0?ooo`030000003oool0oooo0500oooo0`0P
k0LE0?ooo`808>`7103oool2023/1`/0oooo0`0Pk0L00`3oool08>`7023/1`030?ooo`808>`70P3o
ool2023/1ad0oooo0P0Pk0LP0?ooo`030000003oool0oooo02T0oooo000Y0?ooo`030000003oool0
oooo01`0oooo0P0Pk0La0?ooo`808>`75P3oool2023/1`@0oooo0P0Pk0L<0?ooo`808>`700<0oooo
023/1`0Pk0L0A`3oool00`000000oooo0?ooo`0Z0?ooo`00:P3oool00`000000oooo0?ooo`0K0?oo
o`808>`7DP3oool2023/1e@0oooo00<000000?ooo`3oool0:`3oool002/0oooo00<000000?ooo`3o
ool0;@3oool2023/1``0oooo0P0Pk0LE0?ooo`808>`7303oool2023/1``0oooo0P0Pk0L[0?ooo`80
8>`79`3oool00`000000oooo0?ooo`0[0?ooo`00;03oool2000002d0oooo0P0Pk0L30?ooo`808>`7
1`3oool2023/1aD0oooo0P0Pk0L;0?ooo`<08>`7>@3oool2023/1bH0oooo00<000000?ooo`3oool0
;03oool002h0oooo00<000000?ooo`3oool0;`3oool2023/1b/0oooo0P0Pk0L:0?ooo`808>`7E@3o
ool00`000000oooo0?ooo`0]0?ooo`00;`3oool00`000000oooo0?ooo`180?ooo`808>`71@3oool2
023/1`T0oooo0P0Pk0L60?ooo`808>`70`3oool2023/1e@0oooo00<000000?ooo`3oool0;P3oool0
0300oooo00<000000?ooo`3oool0A`3oool2023/1`D0oooo0P0Pk0L90?ooo`808>`71@3oool3023/
1aD0oooo0P0Pk0M20?ooo`030000003oool0oooo02h0oooo000a0?ooo`030000003oool0oooo03<0
oooo100Pk0L80?ooo`808>`77P3oool2023/1aH0oooo0P0Pk0M10?ooo`030000003oool0oooo02l0
oooo000b0?ooo`030000003oool0oooo0380oooo100Pk0L80?ooo`808>`7303oool2023/1``0oooo
0P0Pk0ML0?ooo`030000003oool0oooo0300oooo000c0?ooo`030000003oool0oooo04T0oooo100P
k0L<0?ooo`808>`7G03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`15
0?ooo`808>`700<0oooo023/1`0Pk0L03P3oool2023/1e/0oooo00<000000?ooo`3oool0<@3oool0
03D0oooo00<000000?ooo`3oool0A03oool2023/1`80oooo0P0Pk0L=0?ooo`808>`700<0oooo023/
1`0Pk0L00P3oool2023/1e<0oooo00<000000?ooo`3oool0<P3oool003H0oooo00<000000?ooo`3o
ool0A`3oool2023/1a00oooo0P0Pk0L20?ooo`808>`7D@3oool2000003D0oooo000g0?ooo`030000
003oool0oooo03/0oooo0P0Pk0M`0?ooo`800000=`3oool003P0oooo00<000000?ooo`3oool0>P3o
ool2023/1a<0oooo0P0Pk0L60?ooo`808>`7DP3oool00`000000oooo0?ooo`0g0?ooo`00>@3oool0
0`000000oooo0?ooo`1>0?ooo`808>`71P3oool2023/1cL0oooo0P0Pk0LG0?ooo`800000>P3oool0
03X0oooo0P00001W0?ooo`808>`79P3oool2023/1`030?ooo`0Pk0L08>`70180oooo0P00000l0?oo
o`00?03oool00`000000oooo0?ooo`0G0?ooo`808>`7403oool2023/1`l0oooo0P0Pk0LK0?ooo`80
8>`72`3oool2023/1bT0oooo0P0Pk0LA0?ooo`030000003oool0oooo03`0oooo000m0?ooo`030000
003oool0oooo01H0oooo0P0Pk0L@0?ooo`808>`73`3oool2023/1a/0oooo0P0Pk0M70?ooo`800000
?`3oool003h0oooo00<000000?ooo`3oool0?@3oool2023/1ed0oooo0P0000110?ooo`00?`3oool0
0`000000oooo0?ooo`0C0?ooo`808>`73`3oool2023/1aH0oooo0P0Pk0LT0?ooo`808>`7=@3oool2
000004<0oooo00100?ooo`030000003oool0oooo0180oooo0P0Pk0L?0?ooo`808>`7?03oool2023/
1c@0oooo00<000000?ooo`3oool0@`3oool00440oooo00<000000?ooo`3oool0U03oool2000004H0
oooo00120?ooo`030000003oool0oooo06/0oooo0P0Pk0LT0?ooo`800000B03oool004<0oooo00<0
00000?ooo`3oool0JP3oool2023/1`P0oooo0P0Pk0LH0?ooo`800000BP3oool004@0oooo00<00000
0?ooo`3oool0L`3oool2023/1aL0oooo00<000000?ooo`3oool0BP3oool004D0oooo00<000000?oo
o`3oool0DP3oool2023/1cD0oooo0P00001=0?ooo`00AP3oool00`000000oooo0?ooo`1A0?ooo`80
8>`7<`3oool2000004l0oooo00170?ooo`030000003oool0oooo0240oooo0P0Pk0MQ0?ooo`030000
003oool0oooo04l0oooo00180?ooo`<00000803oool2023/1c@0oooo0P0Pk0L90?ooo`808>`77P3o
ool200000580oooo001;0?ooo`<00000D`3oool2023/1`T0oooo0P0Pk0LL0?ooo`800000E03oool0
04h0oooo0`00000e0?ooo`808>`7@03oool2000005H0oooo001A0?ooo`<000009P3oool2023/1`@0
oooo0P0Pk0L40?ooo`808>`7?`3oool00`000000oooo0?ooo`1F0?ooo`00E03oool3000002<0oooo
0P0Pk0L40?ooo`808>`7@`3oool2000005T0oooo001G0?ooo`<00000J@3oool2000005/0oooo001J
0?ooo`<00000I03oool2000005d0oooo001M0?ooo`<00000<`3oool2023/1b/0oooo00<000000?oo
o`3oool0G@3oool00600oooo0`00000`0?ooo`808>`7:@3oool200000600oooo001S0?ooo`<00000
EP3oool200000680oooo001V0?ooo`<00000DP3oool00`000000oooo0?ooo`1R0?ooo`00J@3oool3
000004d0oooo0P00001U0?ooo`00K03oool3000004@0oooo1P00001W0?ooo`00K`3oool3000003P0
oooo2@00001]0?ooo`00LP3oool3000002/0oooo2P00001f0?ooo`00M@3oool3000001l0oooo2@00
00200?ooo`00N03oool300000180oooo2P0000290?ooo`00N`3oool3000000H0oooo2@00002C0?oo
o`00OP3oool6000009`0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {288.562, 0}} -> {-12.846, -13.0532, \
0.0904708, 0.0904708}},
  CellTags->"Laser Radar Example"],

Cell[BoxData[
    \({586.8500000000004`\ Second, Null}\)], "Output",
  CellTags->"Laser Radar Example"]
}, Open  ]],

Cell[TextData[{
  "Note that this result with ",
  StyleBox["CreateClones", "Input"],
  " uses nine times as many optical surfaces than before. Nevertheless, the \
overall calculation time is only two times longer than before. This is \
because the trace algorithms used with ",
  StyleBox["CreateClones", "Input"],
  " are much more efficient than for normal tracing."
}], "Text",
  CellTags->"Laser Radar Example"],

Cell["\<\
Finally, we calcaluate the temporal signal at the detector surface.\
\
\>", "Text",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{

Cell["\<\
Timing[timesignal = ExtractTemporalSignal[res, 1*10^-9, \
100.];]\
\>", "Input",
  CellTags->"Laser Radar Example"],

Cell[BoxData[
    \({26.033333333333758`\ Second, Null}\)], "Output",
  CellTags->"Laser Radar Example"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ListPlot[timesignal];", "Input",
  CellTags->"Laser Radar Example"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-13.0474 3.9672e+06 0.0147151 7.56095e-05 [
[.24273 .00222 -25.5 -12.5 ]
[.24273 .00222 25.5 0 ]
[.44109 .00222 -22.5 -12.5 ]
[.44109 .00222 22.5 0 ]
[.63945 .00222 -25.5 -12.5 ]
[.63945 .00222 25.5 0 ]
[.83781 .00222 -22.5 -12.5 ]
[.83781 .00222 22.5 0 ]
[.03187 .16593 -24 -4.5 ]
[.03187 .16593 0 4.5 ]
[.03187 .31715 -24 -4.5 ]
[.03187 .31715 0 4.5 ]
[.03187 .46837 -24 -4.5 ]
[.03187 .46837 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.24273 .01472 m
.24273 .02097 L
s
gsave
.24273 .00222 -25.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3.35) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.44109 .01472 m
.44109 .02097 L
s
gsave
.44109 .00222 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3.4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.63945 .01472 m
.63945 .02097 L
s
gsave
.63945 .00222 -25.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3.45) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.83781 .01472 m
.83781 .02097 L
s
gsave
.83781 .00222 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.08404 .01472 m
.08404 .01847 L
s
.12372 .01472 m
.12372 .01847 L
s
.16339 .01472 m
.16339 .01847 L
s
.20306 .01472 m
.20306 .01847 L
s
.2824 .01472 m
.2824 .01847 L
s
.32208 .01472 m
.32208 .01847 L
s
.36175 .01472 m
.36175 .01847 L
s
.40142 .01472 m
.40142 .01847 L
s
.48076 .01472 m
.48076 .01847 L
s
.52044 .01472 m
.52044 .01847 L
s
.56011 .01472 m
.56011 .01847 L
s
.59978 .01472 m
.59978 .01847 L
s
.67912 .01472 m
.67912 .01847 L
s
.7188 .01472 m
.7188 .01847 L
s
.75847 .01472 m
.75847 .01847 L
s
.79814 .01472 m
.79814 .01847 L
s
.0047 .01472 m
.0047 .01847 L
s
.87748 .01472 m
.87748 .01847 L
s
.91716 .01472 m
.91716 .01847 L
s
.95683 .01472 m
.95683 .01847 L
s
.9965 .01472 m
.9965 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.04437 .16593 m
.05062 .16593 L
s
[(2000)] .03187 .16593 1 0 Mshowa
.04437 .31715 m
.05062 .31715 L
s
[(4000)] .03187 .31715 1 0 Mshowa
.04437 .46837 m
.05062 .46837 L
s
[(6000)] .03187 .46837 1 0 Mshowa
.125 Mabswid
.04437 .05252 m
.04812 .05252 L
s
.04437 .09032 m
.04812 .09032 L
s
.04437 .12813 m
.04812 .12813 L
s
.04437 .20374 m
.04812 .20374 L
s
.04437 .24154 m
.04812 .24154 L
s
.04437 .27935 m
.04812 .27935 L
s
.04437 .35496 m
.04812 .35496 L
s
.04437 .39276 m
.04812 .39276 L
s
.04437 .43057 m
.04812 .43057 L
s
.04437 .50618 m
.04812 .50618 L
s
.04437 .54398 m
.04812 .54398 L
s
.04437 .58179 m
.04812 .58179 L
s
.25 Mabswid
.04437 0 m
.04437 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .0517 Mdot
.02462 .05863 Mdot
.02549 .06492 Mdot
.02558 .06552 Mdot
.02654 .07062 Mdot
.02766 .07392 Mdot
.02814 .07434 Mdot
.02822 .07435 Mdot
.029 .07345 Mdot
.02948 .07196 Mdot
.02952 .07183 Mdot
.02961 .07143 Mdot
.02965 .07126 Mdot
.0301 .06899 Mdot
.03015 .06871 Mdot
.0302 .06841 Mdot
.03033 .06765 Mdot
.031 .06283 Mdot
.03136 .05981 Mdot
.0315 .05862 Mdot
.03159 .05781 Mdot
.03229 .05142 Mdot
.03287 .0461 Mdot
.03644 .02336 Mdot
.13029 .1473 Mdot
.1306 .16069 Mdot
.13073 .16644 Mdot
.13114 .18425 Mdot
.13121 .18706 Mdot
.13125 .18896 Mdot
.13161 .205 Mdot
.13171 .2091 Mdot
.13212 .22701 Mdot
.13227 .23341 Mdot
.13276 .25332 Mdot
.1328 .25524 Mdot
.13283 .25644 Mdot
.13314 .26848 Mdot
.1332 .27053 Mdot
.13348 .28075 Mdot
.13365 .28682 Mdot
.13366 .28696 Mdot
.1338 .29177 Mdot
.13381 .29218 Mdot
.13392 .29591 Mdot
.134 .29835 Mdot
.13411 .30177 Mdot
.13422 .30525 Mdot
.1344 .31038 Mdot
.13448 .31269 Mdot
.13454 .31431 Mdot
.13459 .31545 Mdot
.13463 .31655 Mdot
.1347 .31831 Mdot
.13484 .32182 Mdot
.13493 .32403 Mdot
.13494 .32432 Mdot
.135 .32557 Mdot
.13504 .32644 Mdot
.1351 .32782 Mdot
.13513 .32845 Mdot
.13514 .32869 Mdot
.13541 .33417 Mdot
.13557 .33691 Mdot
.13568 .33871 Mdot
.13572 .33941 Mdot
.13579 .34052 Mdot
.13589 .34195 Mdot
.13594 .34255 Mdot
.13598 .34306 Mdot
.136 .34339 Mdot
.13619 .34556 Mdot
.1362 .34567 Mdot
.13621 .34576 Mdot
.13622 .34592 Mdot
.13644 .34793 Mdot
.13644 .34793 Mdot
.13649 .34835 Mdot
.13653 .34861 Mdot
.1366 .3491 Mdot
.13661 .34919 Mdot
.13665 .34945 Mdot
.1367 .34973 Mdot
.13683 .35034 Mdot
.13688 .35053 Mdot
.13691 .35064 Mdot
.13697 .35082 Mdot
.13697 .35083 Mdot
.13699 .35088 Mdot
.13704 .351 Mdot
.13712 .35112 Mdot
.13721 .35119 Mdot
.13723 .35119 Mdot
.13724 .35119 Mdot
.13741 .35103 Mdot
.13743 .351 Mdot
.13778 .34971 Mdot
.13778 .34971 Mdot
.13782 .34948 Mdot
.13786 .34922 Mdot
.13791 .34891 Mdot
.13791 .34889 Mdot
.13791 .34886 Mdot
.13814 .34704 Mdot
.1383 .34549 Mdot
.1383 .34541 Mdot
.13833 .34511 Mdot
.13836 .3448 Mdot
.13838 .34453 Mdot
.13838 .3445 Mdot
.13849 .34316 Mdot
.13852 .3429 Mdot
.13852 .34283 Mdot
.13867 .34075 Mdot
.13871 .34021 Mdot
.13879 .33897 Mdot
.13881 .33871 Mdot
.13886 .33777 Mdot
.13894 .33648 Mdot
.13899 .33569 Mdot
.13899 .33569 Mdot
.13907 .33422 Mdot
.1392 .33175 Mdot
.13925 .33077 Mdot
.13925 .33063 Mdot
.13949 .32556 Mdot
.13955 .32412 Mdot
.1396 .32302 Mdot
.13969 .3208 Mdot
.13971 .32027 Mdot
.13972 .32016 Mdot
.13993 .31464 Mdot
.14001 .31251 Mdot
.14018 .30749 Mdot
.1402 .30691 Mdot
.14022 .30633 Mdot
.14027 .305 Mdot
.14033 .30301 Mdot
.14038 .30151 Mdot
.14051 .29747 Mdot
.14052 .29714 Mdot
.14061 .2943 Mdot
.14062 .29384 Mdot
.14063 .29367 Mdot
.14066 .2926 Mdot
.14067 .29221 Mdot
.14074 .28969 Mdot
.14078 .28854 Mdot
.14086 .28585 Mdot
.14088 .28507 Mdot
.14088 .28489 Mdot
.14089 .28461 Mdot
.14094 .28292 Mdot
.14094 .28281 Mdot
.14108 .27797 Mdot
.14111 .2766 Mdot
.14119 .27367 Mdot
.14122 .27263 Mdot
.14137 .26689 Mdot
.14155 .25988 Mdot
.14167 .25515 Mdot
.14167 .25498 Mdot
.14168 .25476 Mdot
.14171 .25345 Mdot
.14172 .25304 Mdot
.14173 .25278 Mdot
.14196 .24312 Mdot
.14212 .23652 Mdot
.14212 .23651 Mdot
.14212 .23634 Mdot
.14217 .23446 Mdot
.1422 .23328 Mdot
.14228 .2297 Mdot
.14228 .22951 Mdot
.1424 .22477 Mdot
.1425 .22009 Mdot
.14251 .21971 Mdot
.14263 .2146 Mdot
.14267 .21307 Mdot
.14277 .20856 Mdot
.14286 .20477 Mdot
.14306 .19615 Mdot
.14329 .1862 Mdot
.14346 .17893 Mdot
.14361 .17285 Mdot
.1439 .16083 Mdot
.14396 .15844 Mdot
.14419 .14929 Mdot
.14455 .1357 Mdot
.14464 .13243 Mdot
.14471 .13007 Mdot
.14487 .12455 Mdot
.14539 .10794 Mdot
.14637 .08377 Mdot
.14667 .07799 Mdot
.14884 .05668 Mdot
.14912 .05566 Mdot
.14954 .05457 Mdot
.14994 .05378 Mdot
.15101 .05192 Mdot
.15116 .05162 Mdot
.15183 .0499 Mdot
.15234 .04814 Mdot
.15239 .04798 Mdot
.15306 .04503 Mdot
.15308 .04489 Mdot
.15424 .03856 Mdot
.1548 .03519 Mdot
.24596 .01653 Mdot
.26115 .09272 Mdot
.26139 .09975 Mdot
.26235 .13078 Mdot
.26287 .14871 Mdot
.26344 .16886 Mdot
.26393 .1863 Mdot
.26396 .1873 Mdot
.26401 .18903 Mdot
.26418 .19498 Mdot
.26426 .1978 Mdot
.26434 .20032 Mdot
.26452 .20666 Mdot
.26453 .20703 Mdot
.26461 .20969 Mdot
.26529 .23163 Mdot
.26575 .24517 Mdot
.26584 .24755 Mdot
.26596 .25088 Mdot
.26605 .25323 Mdot
.26606 .25345 Mdot
.26628 .25913 Mdot
.26629 .25936 Mdot
.26637 .26127 Mdot
.26656 .26572 Mdot
.26659 .2664 Mdot
.26677 .27033 Mdot
.26705 .2759 Mdot
.26706 .276 Mdot
.26706 .27606 Mdot
.26727 .27983 Mdot
.2673 .28019 Mdot
.26733 .28075 Mdot
.26755 .28413 Mdot
.26759 .28478 Mdot
.2677 .28625 Mdot
.2677 .2863 Mdot
.26803 .29033 Mdot
.26805 .29056 Mdot
.2681 .29104 Mdot
.2681 .29109 Mdot
.26819 .29201 Mdot
.26825 .29252 Mdot
.26836 .29353 Mdot
.26838 .29367 Mdot
.2684 .29388 Mdot
.26842 .29401 Mdot
.26847 .29444 Mdot
.26857 .29511 Mdot
.26866 .29575 Mdot
.26869 .29593 Mdot
.2687 .296 Mdot
.26887 .29696 Mdot
.2689 .29706 Mdot
.26904 .2977 Mdot
.2691 .29794 Mdot
.26917 .29817 Mdot
.26921 .29829 Mdot
.26928 .29851 Mdot
.26939 .29877 Mdot
.2694 .29879 Mdot
.26942 .29883 Mdot
.26949 .29896 Mdot
.26952 .299 Mdot
.2697 .29921 Mdot
.26974 .29923 Mdot
.26996 .29927 Mdot
.26999 .29927 Mdot
.26999 .29927 Mdot
.27032 .29901 Mdot
.27034 .299 Mdot
.27057 .29866 Mdot
.27059 .29863 Mdot
.27065 .29853 Mdot
.27069 .29846 Mdot
.27084 .29816 Mdot
.2709 .29806 Mdot
.27105 .29775 Mdot
.27108 .29768 Mdot
.27116 .29751 Mdot
.27116 .29751 Mdot
.27122 .29738 Mdot
.27126 .29731 Mdot
.2714 .29701 Mdot
.27149 .29684 Mdot
.27164 .29653 Mdot
.27167 .29647 Mdot
.27172 .29638 Mdot
.27183 .2962 Mdot
.27195 .296 Mdot
.2722 .29567 Mdot
.27231 .29556 Mdot
.27233 .29555 Mdot
.27239 .2955 Mdot
.27242 .29548 Mdot
.27245 .29545 Mdot
.2726 .29539 Mdot
.27262 .29538 Mdot
.27267 .29537 Mdot
.27286 .29539 Mdot
.2729 .29541 Mdot
.27291 .29542 Mdot
.27292 .29542 Mdot
.27299 .29546 Mdot
.27308 .29554 Mdot
.27314 .2956 Mdot
.27316 .29562 Mdot
.27317 .29563 Mdot
.27322 .29569 Mdot
.27324 .29571 Mdot
.27351 .29619 Mdot
.27357 .29631 Mdot
.27365 .29651 Mdot
.27367 .29655 Mdot
.27384 .29705 Mdot
.27394 .29738 Mdot
.2741 .29794 Mdot
.2741 .29796 Mdot
.27413 .29809 Mdot
.27431 .29883 Mdot
.27438 .29915 Mdot
.27438 .29917 Mdot
.27439 .29921 Mdot
.27441 .29928 Mdot
.27463 .30041 Mdot
.27467 .30063 Mdot
.27486 .30174 Mdot
.27523 .30414 Mdot
.27525 .30429 Mdot
.27525 .30431 Mdot
.27527 .30447 Mdot
.27531 .30475 Mdot
.27552 .3063 Mdot
.27556 .30656 Mdot
.27565 .30727 Mdot
.27569 .30756 Mdot
.27575 .3081 Mdot
.27587 .30908 Mdot
.27594 .30965 Mdot
.27603 .3104 Mdot
.27604 .31049 Mdot
.27615 .3114 Mdot
.27621 .31193 Mdot
.27621 .31194 Mdot
.27629 .31257 Mdot
.27635 .31314 Mdot
.27642 .31374 Mdot
.27647 .31417 Mdot
.27658 .31513 Mdot
.27682 .31721 Mdot
.2772 .32037 Mdot
.27722 .3205 Mdot
.27741 .32199 Mdot
.27743 .32211 Mdot
.27749 .32259 Mdot
.27753 .32288 Mdot
.27764 .32362 Mdot
.27766 .32381 Mdot
.2777 .32407 Mdot
.27776 .32445 Mdot
.27789 .32528 Mdot
.27819 .32683 Mdot
.27821 .3269 Mdot
.27823 .32699 Mdot
.27831 .32733 Mdot
.27843 .32775 Mdot
.27846 .32783 Mdot
.27848 .32791 Mdot
.2785 .32796 Mdot
.27855 .32809 Mdot
.27866 .32831 Mdot
.27867 .32832 Mdot
.2787 .32837 Mdot
.27939 .3276 Mdot
.27945 .32731 Mdot
.27948 .32718 Mdot
.27959 .32663 Mdot
.27965 .32624 Mdot
.27969 .32599 Mdot
.27979 .32528 Mdot
.2798 .32525 Mdot
.2798 .32524 Mdot
.27981 .32514 Mdot
.27983 .32498 Mdot
.27986 .32479 Mdot
.27986 .32477 Mdot
.27994 .32405 Mdot
.27995 .32402 Mdot
.27997 .32379 Mdot
.28006 .32287 Mdot
.28009 .3226 Mdot
.28011 .32237 Mdot
.28012 .32232 Mdot
.28016 .32186 Mdot
.28023 .32105 Mdot
.28044 .31844 Mdot
.28054 .31698 Mdot
.28075 .31358 Mdot
.28079 .31292 Mdot
.28086 .31172 Mdot
.2809 .31088 Mdot
.28101 .30892 Mdot
.28122 .30448 Mdot
.28125 .30391 Mdot
.28127 .30344 Mdot
.28137 .30125 Mdot
.28142 .29996 Mdot
.28158 .29622 Mdot
.28167 .29399 Mdot
.28174 .29204 Mdot
.28179 .29089 Mdot
.28192 .28722 Mdot
.28201 .28485 Mdot
.28209 .28246 Mdot
.28227 .27702 Mdot
.28242 .27262 Mdot
.28244 .27182 Mdot
.28245 .27165 Mdot
.28249 .27043 Mdot
.28251 .26972 Mdot
.28259 .26707 Mdot
.28268 .26422 Mdot
.28272 .26302 Mdot
.28272 .26301 Mdot
.28277 .26134 Mdot
.28283 .25901 Mdot
.28291 .25656 Mdot
.28308 .25057 Mdot
.28309 .25045 Mdot
.28312 .24918 Mdot
.28318 .24729 Mdot
.28319 .24677 Mdot
.28327 .24389 Mdot
.28335 .24114 Mdot
.28341 .23892 Mdot
.28343 .23838 Mdot
.28346 .23716 Mdot
.28348 .2366 Mdot
.28359 .23232 Mdot
.28363 .23108 Mdot
.28374 .22695 Mdot
.28378 .22548 Mdot
.28382 .22423 Mdot
.28384 .22321 Mdot
.28408 .21468 Mdot
.28424 .20889 Mdot
.2844 .20291 Mdot
.28479 .18889 Mdot
.28492 .18427 Mdot
.28512 .17717 Mdot
.28527 .17224 Mdot
.28538 .16847 Mdot
.28539 .16805 Mdot
.28581 .15461 Mdot
.28609 .14599 Mdot
.28617 .14342 Mdot
.28624 .14151 Mdot
.28681 .12589 Mdot
.28705 .11982 Mdot
.28714 .11783 Mdot
.28736 .11258 Mdot
.28738 .11228 Mdot
.28795 .10044 Mdot
.28798 .09979 Mdot
.28851 .0904 Mdot
.28852 .09016 Mdot
.28855 .08968 Mdot
.28876 .08623 Mdot
.28891 .08398 Mdot
.2894 .07718 Mdot
.28964 .07405 Mdot
.29053 .06412 Mdot
.29079 .06163 Mdot
.29084 .06116 Mdot
.29125 .05743 Mdot
.29183 .05278 Mdot
.2925 .0481 Mdot
.29279 .04624 Mdot
.29307 .04459 Mdot
.29424 .03857 Mdot
.29431 .03822 Mdot
.29616 .03144 Mdot
.29827 .02614 Mdot
.29866 .02531 Mdot
.30348 .01755 Mdot
.39839 .17449 Mdot
.39843 .17634 Mdot
.39852 .18119 Mdot
.39876 .1937 Mdot
.39928 .2216 Mdot
.39954 .23597 Mdot
.39992 .25576 Mdot
.39996 .25787 Mdot
.40009 .26514 Mdot
.4001 .26571 Mdot
.40025 .27304 Mdot
.40027 .27442 Mdot
.40047 .28459 Mdot
.40048 .28492 Mdot
.40048 .28496 Mdot
.40095 .30772 Mdot
.40098 .30916 Mdot
.40098 .30932 Mdot
.40114 .31677 Mdot
.40122 .32019 Mdot
.40139 .3277 Mdot
.4014 .32808 Mdot
.40157 .33535 Mdot
.4016 .33664 Mdot
.40174 .34267 Mdot
.40181 .34547 Mdot
.40184 .34652 Mdot
.40187 .34756 Mdot
.40188 .34805 Mdot
.40199 .35241 Mdot
.40202 .35328 Mdot
.40202 .35345 Mdot
.40218 .35935 Mdot
.4022 .3601 Mdot
.40224 .36136 Mdot
.40261 .37373 Mdot
.40273 .37742 Mdot
.40274 .37766 Mdot
.40284 .38063 Mdot
.40285 .38093 Mdot
.40289 .38195 Mdot
.40289 .3821 Mdot
.4029 .38234 Mdot
.40294 .38349 Mdot
.40299 .38478 Mdot
.40318 .3899 Mdot
.40328 .39221 Mdot
.40332 .39328 Mdot
.40336 .39408 Mdot
.40368 .40086 Mdot
.40379 .40292 Mdot
.40384 .40385 Mdot
.40385 .40393 Mdot
.40396 .40589 Mdot
.40405 .4072 Mdot
.40409 .40782 Mdot
.40418 .40907 Mdot
.40425 .41004 Mdot
.40426 .41016 Mdot
.40431 .41078 Mdot
.40433 .41092 Mdot
.40435 .4112 Mdot
.40436 .41138 Mdot
.40456 .41339 Mdot
.40462 .41394 Mdot
.40477 .41507 Mdot
.40484 .41548 Mdot
.40493 .41599 Mdot
.40493 .41601 Mdot
.40498 .41624 Mdot
.40507 .41658 Mdot
.40519 .41692 Mdot
.40521 .41696 Mdot
.40526 .41703 Mdot
.40532 .41709 Mdot
.40533 .4171 Mdot
.40537 .41711 Mdot
.4054 .41711 Mdot
.4055 .41703 Mdot
.40552 .417 Mdot
.40557 .41692 Mdot
.4059 .41573 Mdot
.40591 .41564 Mdot
.40592 .41561 Mdot
.40592 .4156 Mdot
.40606 .41477 Mdot
.40608 .41458 Mdot
.4061 .41446 Mdot
.40613 .41422 Mdot
.40618 .41383 Mdot
.40621 .41365 Mdot
.40623 .41348 Mdot
.40624 .41334 Mdot
.40627 .41311 Mdot
.40642 .41177 Mdot
.40646 .41128 Mdot
.4065 .41095 Mdot
.40664 .40932 Mdot
.40668 .40889 Mdot
.40678 .40763 Mdot
.40689 .40624 Mdot
.40696 .40535 Mdot
.40701 .40458 Mdot
.40708 .40367 Mdot
.40711 .40316 Mdot
.40712 .40306 Mdot
.40713 .40291 Mdot
.40713 .4029 Mdot
.40715 .40262 Mdot
.40717 .40234 Mdot
.40727 .40084 Mdot
.4073 .40047 Mdot
.4073 .40039 Mdot
.40731 .40029 Mdot
.40734 .39985 Mdot
.40736 .39944 Mdot
.40736 .39942 Mdot
.40741 .39874 Mdot
.40747 .39782 Mdot
.4075 .39733 Mdot
.40755 .39656 Mdot
.40757 .39623 Mdot
.40773 .39358 Mdot
.40774 .39343 Mdot
.40774 .39337 Mdot
.40795 .38994 Mdot
.40801 .38901 Mdot
.40821 .38566 Mdot
.40826 .38485 Mdot
.40829 .38439 Mdot
.40839 .38269 Mdot
.40848 .38137 Mdot
.40849 .38116 Mdot
.40851 .38086 Mdot
.40865 .37867 Mdot
.40875 .37728 Mdot
.40877 .37698 Mdot
.40878 .37683 Mdot
.40879 .37669 Mdot
.40903 .37326 Mdot
.40909 .3725 Mdot
.40912 .37217 Mdot
.40912 .37212 Mdot
.40916 .37164 Mdot
.40918 .37134 Mdot
.4095 .36789 Mdot
.40955 .36734 Mdot
.40963 .36664 Mdot
.40972 .36588 Mdot
.40976 .36562 Mdot
.40979 .36537 Mdot
.40983 .36509 Mdot
.40986 .36488 Mdot
.40987 .36479 Mdot
.41003 .36386 Mdot
.41009 .36361 Mdot
.41011 .3635 Mdot
.41016 .3633 Mdot
.41029 .36288 Mdot
.41045 .36261 Mdot
.4106 .36257 Mdot
.41076 .36279 Mdot
.41109 .364 Mdot
.41112 .36416 Mdot
.41129 .36527 Mdot
.41142 .36627 Mdot
.41146 .36657 Mdot
.41163 .36813 Mdot
.4117 .36888 Mdot
.41172 .36903 Mdot
.41173 .36913 Mdot
.41173 .36918 Mdot
.41179 .3698 Mdot
.41181 .37008 Mdot
.41184 .3704 Mdot
.41188 .37091 Mdot
.41189 .37093 Mdot
.41191 .37126 Mdot
.412 .37227 Mdot
.41207 .37322 Mdot
.41208 .37332 Mdot
.41211 .37371 Mdot
.41246 .37866 Mdot
.41255 .37992 Mdot
.41256 .38012 Mdot
.41256 .38018 Mdot
.41259 .38066 Mdot
.4126 .38073 Mdot
.4126 .38079 Mdot
.4126 .3808 Mdot
.41276 .38317 Mdot
.41282 .38424 Mdot
.41285 .38458 Mdot
.41295 .38622 Mdot
.41296 .38637 Mdot
.41298 .38664 Mdot
.41304 .38773 Mdot
.41329 .39174 Mdot
.41334 .39246 Mdot
.41353 .39563 Mdot
.41358 .39636 Mdot
.41361 .3969 Mdot
.41364 .39728 Mdot
.41376 .39915 Mdot
.41385 .40045 Mdot
.41391 .4014 Mdot
.41406 .40359 Mdot
.4142 .40545 Mdot
.4142 .40554 Mdot
.41423 .40586 Mdot
.41427 .40648 Mdot
.41428 .40664 Mdot
.41434 .40731 Mdot
.41439 .408 Mdot
.41442 .40837 Mdot
.41452 .40956 Mdot
.41456 .41001 Mdot
.41457 .41011 Mdot
.41461 .4106 Mdot
.41466 .41112 Mdot
.4147 .41151 Mdot
.41477 .41218 Mdot
.41489 .41337 Mdot
.41491 .41352 Mdot
.41491 .41353 Mdot
.41492 .41359 Mdot
.41497 .41407 Mdot
.41504 .4146 Mdot
.41518 .41562 Mdot
.41527 .41613 Mdot
.41559 .41748 Mdot
.4156 .41752 Mdot
.4156 .41752 Mdot
.41565 .41763 Mdot
.41565 .41764 Mdot
.41578 .41782 Mdot
.41579 .41782 Mdot
.41598 .41774 Mdot
.416 .41772 Mdot
.41601 .4177 Mdot
.41605 .41762 Mdot
.41609 .41752 Mdot
.41617 .41726 Mdot
.41624 .417 Mdot
.41628 .41682 Mdot
.41629 .41678 Mdot
.41638 .41627 Mdot
.4164 .41618 Mdot
.41649 .41555 Mdot
.41665 .41422 Mdot
.41667 .4141 Mdot
.41675 .41327 Mdot
.41677 .41303 Mdot
.41679 .41286 Mdot
.41697 .41065 Mdot
.41705 .40965 Mdot
.41709 .40904 Mdot
.4171 .40896 Mdot
.41714 .40836 Mdot
.41716 .40799 Mdot
.41723 .40687 Mdot
.41729 .40582 Mdot
.41744 .40307 Mdot
.41758 .40033 Mdot
.41769 .39795 Mdot
.41774 .39678 Mdot
.418 .39059 Mdot
.41811 .38752 Mdot
.41811 .38747 Mdot
.41821 .38461 Mdot
.41823 .38402 Mdot
.41826 .38337 Mdot
.41829 .38221 Mdot
.41832 .38144 Mdot
.41842 .3782 Mdot
.41845 .37725 Mdot
.41851 .37537 Mdot
.41852 .37523 Mdot
.41854 .37439 Mdot
.41854 .37439 Mdot
.41865 .37083 Mdot
.41874 .36765 Mdot
.41875 .36729 Mdot
.41882 .36469 Mdot
.41887 .36302 Mdot
.4189 .36197 Mdot
.41901 .35766 Mdot
.41903 .35688 Mdot
.41907 .35527 Mdot
.41908 .35506 Mdot
.41915 .3522 Mdot
.41917 .3515 Mdot
.41924 .34857 Mdot
.41931 .34567 Mdot
.41937 .34318 Mdot
.41937 .34294 Mdot
.4194 .34176 Mdot
.41948 .33816 Mdot
.41962 .33235 Mdot
.41967 .32974 Mdot
.41981 .32329 Mdot
.41982 .32305 Mdot
.41987 .32075 Mdot
.41992 .31835 Mdot
.41992 .31815 Mdot
.42019 .30531 Mdot
.42024 .30291 Mdot
.42031 .29921 Mdot
.42032 .29869 Mdot
.42038 .29588 Mdot
.42039 .29527 Mdot
.4206 .28482 Mdot
.42063 .28328 Mdot
.42069 .28011 Mdot
.42069 .28009 Mdot
.42083 .27308 Mdot
.42084 .27249 Mdot
.42084 .27217 Mdot
.42088 .27048 Mdot
.42092 .26831 Mdot
.42093 .2675 Mdot
.42098 .26505 Mdot
.42123 .25178 Mdot
.42138 .24415 Mdot
.42145 .24065 Mdot
.42145 .24053 Mdot
.42167 .22905 Mdot
.42181 .2217 Mdot
.42189 .21778 Mdot
.42192 .21616 Mdot
.42194 .2151 Mdot
.422 .21188 Mdot
.42216 .20426 Mdot
.42237 .19392 Mdot
.42257 .18438 Mdot
.42266 .17997 Mdot
.42327 .15376 Mdot
.42413 .12343 Mdot
.42472 .10799 Mdot
.42488 .10451 Mdot
.42636 .08523 Mdot
.42696 .08283 Mdot
.42718 .08245 Mdot
.42753 .0823 Mdot
.42762 .08232 Mdot
.42776 .0824 Mdot
.42816 .08283 Mdot
.42821 .0829 Mdot
.42826 .08296 Mdot
.42847 .08326 Mdot
.42855 .08337 Mdot
.42915 .08399 Mdot
.42952 .08407 Mdot
.42965 .08401 Mdot
.42968 .08399 Mdot
.4298 .08388 Mdot
.43043 .08259 Mdot
.43071 .08161 Mdot
.43074 .08152 Mdot
.4308 .08123 Mdot
.43096 .08055 Mdot
.43124 .0791 Mdot
.43132 .07864 Mdot
.43147 .07774 Mdot
.43226 .07225 Mdot
.4328 .06798 Mdot
.43371 .06089 Mdot
.43505 .05286 Mdot
.43592 .04977 Mdot
.43687 .04785 Mdot
.43749 .04694 Mdot
.43801 .0461 Mdot
.43809 .04594 Mdot
.43844 .04521 Mdot
.43893 .04391 Mdot
.43903 .0436 Mdot
.43938 .04237 Mdot
.43992 .04018 Mdot
.43999 .03984 Mdot
.44004 .03963 Mdot
.44463 .01926 Mdot
.48969 .01774 Mdot
.52273 .02421 Mdot
.52602 .03824 Mdot
.52608 .03854 Mdot
.52787 .04572 Mdot
.52858 .04762 Mdot
.52896 .04838 Mdot
.52904 .04854 Mdot
.52981 .04965 Mdot
.53096 .05161 Mdot
.5318 .05524 Mdot
.53211 .05757 Mdot
.53223 .0586 Mdot
.53459 .11608 Mdot
.53499 .13544 Mdot
.53744 .31363 Mdot
.53752 .32014 Mdot
.53763 .32958 Mdot
.53764 .33035 Mdot
.53764 .33071 Mdot
.53771 .33692 Mdot
.53787 .35099 Mdot
.53795 .35833 Mdot
.5382 .38024 Mdot
.53833 .39175 Mdot
.53836 .394 Mdot
.53844 .40139 Mdot
.53859 .41365 Mdot
.53892 .44125 Mdot
.53896 .44468 Mdot
.53902 .44909 Mdot
.53909 .45496 Mdot
.53916 .46065 Mdot
.53919 .46228 Mdot
.53919 .46244 Mdot
.53922 .46499 Mdot
.5393 .47128 Mdot
.5394 .47874 Mdot
.53942 .47971 Mdot
.53942 .47975 Mdot
.53952 .48702 Mdot
.53953 .48789 Mdot
.53956 .48978 Mdot
.5397 .49996 Mdot
.5397 .50019 Mdot
.53979 .50588 Mdot
.53981 .50718 Mdot
.54001 .51976 Mdot
.54004 .52209 Mdot
.54007 .52382 Mdot
.54009 .52459 Mdot
.54009 .52491 Mdot
.54009 .52496 Mdot
.54011 .52597 Mdot
.54018 .52998 Mdot
.54023 .53322 Mdot
.54024 .53355 Mdot
.54028 .53562 Mdot
.5403 .53683 Mdot
.54031 .53776 Mdot
.54034 .53914 Mdot
.54035 .53951 Mdot
.5405 .54777 Mdot
.54054 .54969 Mdot
.54059 .55219 Mdot
.54066 .55527 Mdot
.54072 .55809 Mdot
.54076 .55997 Mdot
.54081 .56223 Mdot
.5409 .56579 Mdot
.54091 .56644 Mdot
.54094 .56742 Mdot
.54097 .5688 Mdot
.54099 .56952 Mdot
.541 .56982 Mdot
.54101 .57041 Mdot
.54112 .57438 Mdot
.54114 .57518 Mdot
.54116 .5759 Mdot
.54122 .57777 Mdot
.54123 .57815 Mdot
.54127 .57957 Mdot
.5414 .58342 Mdot
.54146 .58505 Mdot
.5415 .58632 Mdot
.54157 .58797 Mdot
.54164 .58975 Mdot
.54188 .59485 Mdot
.54191 .59534 Mdot
.54192 .5954 Mdot
.54192 .59548 Mdot
.54195 .59595 Mdot
.54202 .59712 Mdot
.54203 .59722 Mdot
.54204 .5975 Mdot
.54215 .59892 Mdot
.5422 .59954 Mdot
.5422 .59961 Mdot
.54222 .59978 Mdot
.54226 .60028 Mdot
.54235 .60113 Mdot
.54241 .60158 Mdot
.54241 .60158 Mdot
.54257 .60261 Mdot
.54257 .60263 Mdot
.54257 .60263 Mdot
.54261 .60282 Mdot
.54267 .60301 Mdot
.54271 .60313 Mdot
.54277 .60324 Mdot
.5428 .60328 Mdot
.54287 .60332 Mdot
.54289 .60331 Mdot
.54295 .60326 Mdot
.54303 .6031 Mdot
.54306 .60303 Mdot
.54319 .60254 Mdot
.54321 .60247 Mdot
.54326 .6022 Mdot
.54328 .60206 Mdot
.54329 .60204 Mdot
.54329 .60203 Mdot
.54331 .60189 Mdot
.54338 .60146 Mdot
.54341 .60124 Mdot
.54343 .60109 Mdot
.54346 .60088 Mdot
.54357 .59991 Mdot
.54358 .59982 Mdot
.54361 .59956 Mdot
.54376 .59801 Mdot
.54377 .59788 Mdot
.54381 .59748 Mdot
.54381 .59744 Mdot
.54391 .59633 Mdot
.54399 .59538 Mdot
.54404 .59466 Mdot
.54405 .59453 Mdot
.54409 .59403 Mdot
.54411 .59377 Mdot
.54412 .59368 Mdot
.54417 .59298 Mdot
.54421 .59234 Mdot
.54422 .59227 Mdot
.54428 .59138 Mdot
.54428 .59136 Mdot
.54428 .59134 Mdot
.54436 .5903 Mdot
.54439 .58982 Mdot
.5444 .58964 Mdot
.54445 .58889 Mdot
.54445 .58889 Mdot
.5445 .58812 Mdot
.54464 .58598 Mdot
.54466 .5856 Mdot
.54468 .58532 Mdot
.54482 .58314 Mdot
.54486 .58257 Mdot
.54487 .58241 Mdot
.54498 .58053 Mdot
.54507 .57905 Mdot
.54522 .57668 Mdot
.54524 .57633 Mdot
.54525 .5763 Mdot
.5453 .57539 Mdot
.54535 .57458 Mdot
.54537 .57441 Mdot
.54546 .57296 Mdot
.54547 .57285 Mdot
.5455 .57234 Mdot
.54556 .57139 Mdot
.54557 .5712 Mdot
.54566 .56983 Mdot
.54571 .56918 Mdot
.54573 .56881 Mdot
.54578 .56808 Mdot
.54598 .56541 Mdot
.54599 .56524 Mdot
.54603 .56468 Mdot
.54606 .56424 Mdot
.54607 .56419 Mdot
.54609 .56383 Mdot
.54615 .5631 Mdot
.54622 .56228 Mdot
.54622 .56221 Mdot
.54627 .56162 Mdot
.54629 .56139 Mdot
.54639 .56021 Mdot
.54641 .56 Mdot
.54646 .55953 Mdot
.54668 .55732 Mdot
.5467 .55714 Mdot
.54674 .55678 Mdot
.54681 .55618 Mdot
.54681 .55611 Mdot
.54702 .55459 Mdot
.54703 .55452 Mdot
.54703 .55449 Mdot
.54711 .55397 Mdot
.54715 .55377 Mdot
.54715 .55376 Mdot
.54718 .55356 Mdot
.54732 .55287 Mdot
.5474 .55253 Mdot
.54744 .55239 Mdot
.54744 .55238 Mdot
.54744 .55237 Mdot
.54752 .55213 Mdot
.54752 .55212 Mdot
.54757 .55198 Mdot
.5476 .55189 Mdot
.54765 .55177 Mdot
.5478 .55154 Mdot
.5479 .55147 Mdot
.54794 .55145 Mdot
.54798 .55145 Mdot
.54801 .55146 Mdot
.54807 .55149 Mdot
.54819 .5516 Mdot
.54821 .55164 Mdot
.54824 .55167 Mdot
.54827 .55172 Mdot
.5483 .55179 Mdot
.54835 .55188 Mdot
.54846 .55214 Mdot
.54848 .55221 Mdot
.54851 .5523 Mdot
.54852 .55231 Mdot
.54855 .55239 Mdot
.54862 .55264 Mdot
.54865 .55271 Mdot
.54866 .55277 Mdot
.54877 .55313 Mdot
.5488 .55327 Mdot
.54884 .5534 Mdot
.54898 .55398 Mdot
.549 .55405 Mdot
.54909 .55441 Mdot
.5491 .55444 Mdot
.54913 .55457 Mdot
.54916 .5547 Mdot
.54916 .55471 Mdot
.54917 .55472 Mdot
.54922 .55496 Mdot
.54924 .55504 Mdot
.54928 .55517 Mdot
.54931 .5553 Mdot
.54936 .5555 Mdot
.54938 .55558 Mdot
.54943 .55576 Mdot
.54946 .55588 Mdot
.54955 .55619 Mdot
.54956 .55623 Mdot
.54959 .5563 Mdot
.54959 .55632 Mdot
.54972 .55669 Mdot
.54986 .557 Mdot
.55015 .55719 Mdot
.55021 .55714 Mdot
.55029 .55703 Mdot
.5503 .557 Mdot
.5503 .55699 Mdot
.55031 .55698 Mdot
.55033 .55695 Mdot
.55036 .55686 Mdot
.55046 .55655 Mdot
.55047 .55649 Mdot
.55054 .55621 Mdot
.55062 .55574 Mdot
.55075 .55485 Mdot
.55077 .55474 Mdot
.55078 .5546 Mdot
.55084 .55413 Mdot
.55086 .55389 Mdot
.55086 .55389 Mdot
.55087 .55389 Mdot
.55087 .55383 Mdot
.55089 .55361 Mdot
.5509 .55356 Mdot
.55107 .55161 Mdot
.55115 .55049 Mdot
.55115 .55047 Mdot
.55121 .54965 Mdot
.55122 .5494 Mdot
.55124 .54919 Mdot
.55124 .54912 Mdot
.5513 .54821 Mdot
.55136 .54714 Mdot
.55139 .54653 Mdot
.55143 .54579 Mdot
.55151 .54412 Mdot
.55153 .54371 Mdot
.55153 .54359 Mdot
.55155 .54323 Mdot
.5516 .54213 Mdot
.55162 .5416 Mdot
.55164 .5411 Mdot
.5517 .5398 Mdot
.55172 .53931 Mdot
.55186 .53548 Mdot
.5519 .53425 Mdot
.5519 .53407 Mdot
.55196 .53238 Mdot
.55204 .52975 Mdot
.55205 .52944 Mdot
.55207 .52877 Mdot
.55208 .52837 Mdot
.5521 .52788 Mdot
.55213 .5269 Mdot
.55214 .52661 Mdot
.55221 .52379 Mdot
.55227 .52164 Mdot
.55228 .52128 Mdot
.55228 .52117 Mdot
.55231 .52003 Mdot
.55246 .5142 Mdot
.55246 .51413 Mdot
.55254 .51044 Mdot
.55264 .50616 Mdot
.55273 .50174 Mdot
.55273 .50174 Mdot
.55276 .5004 Mdot
.55277 .49984 Mdot
.55278 .49911 Mdot
.55282 .49724 Mdot
.55285 .49551 Mdot
.55287 .49482 Mdot
.55287 .49466 Mdot
.55287 .49441 Mdot
.55288 .49428 Mdot
.55288 .4941 Mdot
.55292 .49215 Mdot
.55298 .48855 Mdot
.55302 .48681 Mdot
.55303 .4862 Mdot
.55311 .48166 Mdot
.55311 .48156 Mdot
.55311 .48141 Mdot
.55315 .47951 Mdot
.55315 .47937 Mdot
.55315 .47934 Mdot
.55325 .47307 Mdot
.55328 .47125 Mdot
.55347 .45967 Mdot
.55351 .45709 Mdot
.55357 .45323 Mdot
.55363 .44912 Mdot
.55371 .44333 Mdot
.55379 .43822 Mdot
.5538 .43701 Mdot
.55381 .4366 Mdot
.55382 .436 Mdot
.55385 .43414 Mdot
.55387 .43244 Mdot
.55387 .43214 Mdot
.55393 .4281 Mdot
.55398 .42476 Mdot
.554 .42288 Mdot
.55415 .4118 Mdot
.55428 .40156 Mdot
.55429 .40139 Mdot
.55429 .40104 Mdot
.5543 .39989 Mdot
.55435 .39598 Mdot
.5544 .39228 Mdot
.55447 .38706 Mdot
.55449 .38557 Mdot
.55451 .38402 Mdot
.55478 .36162 Mdot
.5548 .35998 Mdot
.55505 .33959 Mdot
.55508 .33721 Mdot
.55523 .32458 Mdot
.55529 .32004 Mdot
.55531 .31845 Mdot
.55533 .31672 Mdot
.55541 .31008 Mdot
.55543 .30783 Mdot
.55543 .30779 Mdot
.55544 .30723 Mdot
.55549 .30285 Mdot
.55556 .29742 Mdot
.55557 .29654 Mdot
.55561 .29314 Mdot
.55566 .28887 Mdot
.55572 .28404 Mdot
.55582 .2761 Mdot
.55598 .26284 Mdot
.55602 .25963 Mdot
.5561 .25362 Mdot
.55632 .2358 Mdot
.55809 .12142 Mdot
.56114 .03999 Mdot
.56418 .04502 Mdot
.56491 .0505 Mdot
.56568 .0563 Mdot
.56683 .06381 Mdot
.56708 .06513 Mdot
.56732 .06625 Mdot
.56735 .06636 Mdot
.56756 .06722 Mdot
.5682 .0693 Mdot
.5696 .0711 Mdot
.56988 .07109 Mdot
.57008 .07103 Mdot
.5704 .07083 Mdot
.57048 .07076 Mdot
.57172 .06905 Mdot
.57179 .06891 Mdot
.57252 .06744 Mdot
.57279 .06686 Mdot
.57319 .06598 Mdot
.57346 .06542 Mdot
.57362 .06507 Mdot
.57376 .06481 Mdot
.57436 .06379 Mdot
.57442 .0637 Mdot
.57443 .06369 Mdot
.57694 .06396 Mdot
.5772 .06432 Mdot
.57744 .06464 Mdot
.5778 .06511 Mdot
.5788 .06575 Mdot
.57941 .06528 Mdot
.57969 .06477 Mdot
.58016 .06349 Mdot
.58038 .06269 Mdot
.58044 .06244 Mdot
.58157 .05628 Mdot
.5816 .05611 Mdot
.58188 .05414 Mdot
.58252 .04935 Mdot
.58338 .0424 Mdot
.58343 .04202 Mdot
.64864 .01986 Mdot
.65344 .02997 Mdot
.65436 .03208 Mdot
.65654 .03443 Mdot
.65774 .03337 Mdot
.65831 .03228 Mdot
.65934 .02965 Mdot
.66449 .02735 Mdot
.66695 .03499 Mdot
.66697 .03503 Mdot
.668 .03743 Mdot
.66857 .03835 Mdot
.66958 .03925 Mdot
.67039 .03931 Mdot
.67189 .03802 Mdot
.67224 .03747 Mdot
.67327 .03539 Mdot
.67384 .03398 Mdot
.67573 .02868 Mdot
.67738 .0241 Mdot
.68625 .02313 Mdot
.68653 .02345 Mdot
.6886 .02391 Mdot
.69446 .02229 Mdot
.69551 .02262 Mdot
.69602 .02267 Mdot
.70011 .02274 Mdot
.70187 .02246 Mdot
.70214 .02229 Mdot
.70234 .02213 Mdot
.71021 .01583 Mdot
.76132 .01741 Mdot
.7743 .01594 Mdot
.79486 .01739 Mdot
.80103 .01715 Mdot
.81215 .02072 Mdot
.8152 .02541 Mdot
.81614 .02575 Mdot
.81645 .02566 Mdot
.81775 .0243 Mdot
.94468 .01579 Mdot
.95456 .01744 Mdot
.97619 .01571 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{805.75, 498},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<U0001lR000`400?l00000o`00003oo`3ooooo
0?ooool0oooo:03oool00?l0ooooo`3ooooo0?ooobP0oooo003o0?ooool0ooooo`3ooolX0?ooo`00
o`3ooooo0?ooool0oooo:03oool00:l0oooo0`0000040?ooo`030000003oool0oooo0080oooo0`00
00030?ooo`<000000`3oool01@000000oooo0?ooo`3oool000000080oooo0`0000040?ooo`800000
M`3oool3000000@0oooo00<000000?ooo`3oool00`3oool300000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`<00000103oool2000007L0oooo0`0000040?ooo`030000003oool0oooo00<0
oooo0`0000020?ooo`<000000`3oool01@000000oooo0?ooo`3oool000000080oooo0`0000040?oo
o`800000M`3oool3000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`<00000103oool2000007d0oooo002^0?ooo`050000003oool0oooo
0?ooo`0000001`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01`000000oooo
0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000007D0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000007D0oooo
00D000000?ooo`3oool0oooo0000000:0?ooo`040000003oool0oooo000000<0oooo00L000000?oo
o`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00001e0?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000007`0oooo002b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00001i0?ooo`030000003oool0oooo00D0oooo1@0000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00001i0?ooo`030000003o
ool0oooo00D0oooo1@0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000007T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00001l0?ooo`00/03oool2000000X0oooo0P0000060?ooo`070000
003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000M`3oool2000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0000
00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000M`3oool2000000P0oooo
00@000000?ooo`3oool000001P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000007L0oooo0P00000<0?ooo`070000003o
ool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000O03oool00;80oooo00<000000?ooo`3oool02@3oool00`000000oooo00000003000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000N@3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
N@3oool00`000000oooo0?ooo`060?ooo`030000003oool000000080oooo100000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
07T0oooo00<000000?ooo`3oool01@3oool4000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000O03oool00:h0oooo00D00000
0?ooo`3oool0oooo000000070?ooo`070000003oool0oooo0?ooo`000000oooo0000000=0?ooo`80
0000103oool010000000oooo0?ooo`0000080?ooo`800000J`3oool01@000000oooo0?ooo`3oool0
000000T0oooo0P00000:0?ooo`800000103oool010000000oooo0?ooo`0000080?ooo`800000J`3o
ool01@000000oooo0?ooo`3oool0000000T0oooo0P0000020?ooo`030000003oool0oooo00/0oooo
0P0000040?ooo`040000003oool0oooo000000P0oooo0P00001[0?ooo`050000003oool0oooo0?oo
o`0000001`3oool00`000000oooo0?ooo`0;0?ooo`800000103oool010000000oooo0?ooo`000008
0?ooo`800000LP3oool00:l0oooo0`0000090?ooo`<000000P3oool5000000X0oooo00<000000?oo
o`3oool00`3oool2000000<0oooo10000000103oool000000?ooo`00001/0?ooo`<000002`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`@0000000@0oooo
0000003oool00000K03oool3000000/0oooo00<000000?ooo`3oool01@00000:0?ooo`030000003o
ool0oooo00<0oooo0P0000030?ooo`@0000000@0oooo0000003oool00000K03oool3000000P0oooo
1@00000:0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`@0000000@0oooo0000003oool0
0000LP3oool002/0oooo00<000000?ooo`3oool0/@3oool3000009H0oooo0`00002L0?ooo`<00000
UP3oool300000780oooo000[0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0LP3o
ool002/0oooo00<000000?ooo`3oool0/P3oool2000009L0oooo0P00002M0?ooo`800000U`3oool2
00000780oooo000[0?ooo`030000003oool0oooo0?l0ooooo`3ooooi0?ooo`00:`3oool00`000000
oooo0?ooo`3o0?ooool0oooon@3oool002/0oooo00<000000?ooo`3oool0o`3ooooo0?ooooT0oooo
000[0?ooo`030000003oool0oooo0?l0ooooo`3ooooi0?ooo`00:`3oool00`000000oooo0?ooo`3o
0?ooool0oooon@3oool002/0oooo00<000000?ooo`3oool0o`3ooooo0?ooooT0oooo000[0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooi0?ooo`00:`3oool00`000000oooo0?ooo`3o0?ooool0oooo
2P3oool4000002h0oooo100000220?ooo`@000005@3oool4000001X0oooo000[0?ooo`030000003o
ool0oooo09X0oooo1000003o0?ooofX0oooo1P00000/0?ooo`H00000403oool4000006`0oooo1P00
000C0?ooo`H000006@3oool000P0ooooo`00003o00000?l000005`0000090?ooo`00303oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool60000
01X0oooo00<000000?ooo`3oool02`3oool6000000/0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo1@00000J0?ooo`040000003oool0oooo
0?ooo`H000005@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo1P000003
0?ooo`030000003oool0oooo01`0oooo1P0000040?ooo`H000002P3oool;000001X0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0100oooo1P000002
0?ooo`H000002`3oool6000000d0oooo00<000000?ooo`3oool02@3oool000`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo1P00000J0?oo
o`030000003oool0oooo00/0oooo1P00000;0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0M0?ooo`H000006@3oool010000000oooo0?ooo`3oool6
000001D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool00P3oool4000001H0oooo00<000000?ooo`3oool04`3oool6
000000<0oooo00<000000?ooo`3oool0703oool6000000@0oooo1P00000:0?ooo`/00000103oool4
00000180oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0100oooo1P0000020?ooo`H000002`3oool6000000d0oooo00<000000?ooo`3oool02@3oool0
00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01`0oooo1P00000J0?ooo`030000003oool0oooo00/0oooo1P00000;0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`H000006@3oool01000
0000oooo0?ooo`3oool6000001D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01d0oooo00@000000?ooo`3oool0oooo1P00000E0?ooo`030000003o
ool0oooo00L0oooo100000020?ooo`@000000`3oool4000000@0oooo00<000000?ooo`3oool0703o
ool6000000D0oooo1000000;0?ooo`/000000`3oool600000140oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0140oooo100000030?ooo`H00000303o
ool4000000h0oooo00<000000?ooo`3oool02@3oool002@0oooo100000030?ooo`030000003oool0
oooo09T0oooo1@00000Y0?ooo`H00000J@3oool6000001d0oooo1P00001c0?ooo`040000003oool0
oooo0?ooo`H000006@3oool4000000030?ooo`000000000000X00000:@3oool6000001@0oooo2P00
00040?ooo`H000004@3oool00`000000oooo0?ooo`1F0?ooo`H00000:P3oool002<0oooo1P000002
0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0;03oool4000006X0oooo1P00000N
0?ooo`@000005P3oool4000005X0oooo00@000000?ooo`3oool0oooo1P00000B0?ooo`@000000P3o
oolB000002X0oooo1000000F0?ooo`@000002@3oool9000000h0oooo00<000000?ooo`3oool0E`3o
ool4000002/0oooo000S0?ooo`H000000P3oool00`000000oooo0?ooo`340?ooo`@00000K`3oool4
000003P0oooo1P00001M0?ooo`H000004@3oool6000000030?ooo`000000000001000000D@3oool:
000009H0oooo000S0?ooo`H000000P3oool00`000000oooo0?ooo`330?ooo`H00000ZP3oool60000
05h0oooo100000090?ooo`@000001@3oool6000000030?ooo`000000000001000000DP3oool90000
09H0oooo000S0?ooo`H000000P3oool00`000000oooo0?ooo`330?ooo`H00000ZP3oool6000006X0
oooo1P0000040?ooo`H0000000<0oooo0000000000004000001C0?ooo`P00000UP3oool002@0oooo
100000030?ooo`030000003oool0oooo0<<0oooo1P00002Z0?ooo`H00000HP3oool4000000030?oo
o`000000000000L000000`3oool700000080oooo4000001D0?ooo`P00000UP3oool002/0oooo00<0
00000?ooo`3oool0``3oool600000:/0oooo1000001R0?ooo`l000000`3oool6000000D0oooo1000
001N0?ooo`L00000U`3oool002/0oooo00<000000?ooo`3oool0`P3oool600000?l0oooo4`3oool?
000000<0oooo1P00001X0?ooo`D00000V03oool002/0oooo00<000000?ooo`3oool0`@3oool60000
0?l0oooo503oool>000000@0oooo1P00003o0?ooo`H0oooo000[0?ooo`030000003oool0oooo0<40
oooo1P00003o0?oooa@0oooo2`0000000`3oool0000000000002000000030?ooo`000000000000@0
0000o`3oool70?ooo`00:`3oool00`000000oooo0?ooo`1C0?ooo`@00000JP3oool600000?l0oooo
5@3oool9000000030?ooo`000000000000T00000o`3oool80?ooo`00:`3oool00`000000oooo0?oo
o`1B0?ooo`H00000J@3oool600000?l0oooo5@3oool9000000030?ooo`000000000000T00000o`3o
ool80?ooo`00:`3oool00`000000oooo0?ooo`1B0?ooo`H00000J03oool600000;40oooo1000001Q
0?ooo`L000000P3oool;00000?l0oooo203oool002/0oooo00<000000?ooo`3oool0D@3oool70000
06L0oooo1P00001^0?ooo`@00000?`3oool6000001H0oooo100000160?ooo`H000000`3oool;0000
0?l0oooo203oool002/0oooo00<000000?ooo`3oool0D@3oool7000006L0oooo1P00001]0?ooo`H0
0000?P3oool6000001D0oooo1P0000160?ooo`@00000103oool;00000?l0oooo203oool002/0oooo
00<000000?ooo`3oool0D@3oool6000006P0oooo1P00001]0?ooo`H00000?P3oool6000001D0oooo
1P00000=0?ooo`@00000?@3oool:00000?l0oooo2@3oool002/0oooo00<000000?ooo`3oool0D@3o
ool6000006P0oooo1P00001]0?ooo`H00000?P3oool6000001D0oooo1P00000<0?ooo`H00000?@3o
ool800000?l0oooo2P3oool002/0oooo00<000000?ooo`3oool0D@3oool5000006T0oooo1@00001]
0?ooo`L00000?`3oool4000001H0oooo2000000:0?ooo`H00000?P3oool600000?l0oooo2`3oool0
0240oooo100000060?ooo`030000003oool0oooo0500oooo1P00001X0?ooo`H00000K@3oool70000
0400oooo1000000F0?ooo`P000002@3oool6000003l0oooo1000003o0?ooo``0oooo000P0?ooo`H0
00001@3oool00`000000oooo0?ooo`1@0?ooo`H00000J03oool6000006`0oooo2000000o0?ooo`H0
00005`3oool6000000T0oooo1P00003o0?ooodl0oooo000P0?ooo`H000001@3oool00`000000oooo
0?ooo`1@0?ooo`H00000J03oool6000006`0oooo1`0000100?ooo`L000005P3oool6000000X0oooo
1000003o0?oooe00oooo000P0?ooo`H000001@3oool00`000000oooo0?ooo`1@0?ooo`H00000J03o
ool6000006`0oooo1`0000100?ooo`L000005P3oool6000000T0oooo1000003o0?oooe40oooo000P
0?ooo`H000001@3oool00`000000oooo0?ooo`1?0?ooo`L00000J03oool6000006/0oooo20000010
0?ooo`P000005P3oool4000000T0oooo1P00003o0?oooe00oooo000J0?ooo`@0000000<0oooo0000
00000000100000060?ooo`030000003oool0oooo04l0oooo1`00001X0?ooo`H00000J`3oool70000
0480oooo2000000D0?ooo`H00000203oool600000?l0ooooD03oool001T0oooo300000060?ooo`03
0000003oool0oooo04l0oooo1`00001W0?ooo`L00000JP3oool800000480oooo2000000D0?ooo`H0
0000203oool600000?l0ooooD03oool001T0oooo300000060?ooo`030000003oool0oooo04h0oooo
1`00001X0?ooo`H00000J`3oool7000004@0oooo1`00000D0?ooo`H00000203oool600000?l0oooo
D03oool001T0oooo300000060?ooo`@00000C@3oool7000006P0oooo1P00001[0?ooo`H00000AP3o
ool6000001@0oooo1P0000080?ooo`H00000o`3ooom@0?ooo`006@3oool6000000030?ooo`000000
0000008000001`3oool00`000000oooo0?ooo`1=0?ooo`P00000J03oool6000006/0oooo1P000016
0?ooo`H000005@3oool6000000H0oooo1`00003o0?oooe00oooo000J0?ooo`@0000000<0oooo0000
00000000100000060?ooo`030000003oool0oooo04d0oooo1`00001Y0?ooo`H00000K03oool40000
04L0oooo1`00000D0?ooo`H000001P3oool700000?l0ooooD03oool001T0oooo300000060?ooo`03
0000003oool0oooo04d0oooo1`00001Y0?ooo`H00000]`3oool7000001@0oooo1P0000060?ooo`H0
0000o`3ooomA0?ooo`006@3oool<000000H0oooo00<000000?ooo`3oool0C@3oool6000006X0oooo
1P00001[0?ooo`@00000B@3oool6000001@0oooo1P0000060?ooo`H00000o`3ooomA0?ooo`006@3o
ool<000000H0oooo00<000000?ooo`3oool0CP3oool4000006/0oooo1P00001Z0?ooo`H00000B03o
ool6000001D0oooo100000070?ooo`D00000o`3ooomB0?ooo`006@3oool<000000H0oooo00<00000
0?ooo`3oool0_@3oool6000006X0oooo1P0000180?ooo`H000005P3oool400000080oooo2P00003o
0?oooe40oooo000J0?ooo`/000001P3oool00`000000oooo0?ooo`2l0?ooo`L00000JP3oool60000
04T0oooo1000000F0?oooa400000o`3ooomA0?ooo`006P3oool:000000L0oooo00<000000?ooo`3o
ool0_03oool7000006X0oooo1P00001S0?oooa400000o`3ooomA0?ooo`006P3oool:000000L0oooo
00<000000?ooo`3oool0_03oool6000006/0oooo1@00001T0?oooa400000o`3ooomA0?ooo`006P3o
ool:000000L0oooo00<000000?ooo`3oool0_03oool6000006X0oooo1P00001T0?oooa000000o`3o
oomB0?ooo`006P3oool:000000L0oooo00<000000?ooo`3oool0_@3oool4000006/0oooo1P00001T
0?oooa000000o`3ooomB0?ooo`006`3oool9000000L0oooo00<000000?ooo`3oool0o`3oool]0?oo
o`H00000I03oool?00000?l0ooooD`3oool001/0oooo2@0000070?ooo`030000003oool0oooo0?l0
oooo;@3oool6000006@0oooo3P00003o0?oooe@0oooo000K0?ooo`T000001`3oool00`000000oooo
0?ooo`2m0?ooo`@00000J`3oool6000006D0oooo2@00003o0?oooeP0oooo000K0?ooo`P00000203o
ool00`000000oooo0?ooo`2l0?ooo`H00000JP3oool6000006H0oooo1`00003o0?oooeT0oooo000L
0?ooo`L00000203oool00`000000oooo0?ooo`2l0?ooo`H00000JP3oool6000006H0oooo1`00003o
0?oooeT0oooo000L0?ooo`L00000203oool00`000000oooo0?ooo`1<0?ooo`@00000K03oool60000
06X0oooo1P00001W0?ooo`D00000o`3ooomJ0?ooo`00703oool7000000P0oooo00<000000?ooo`3o
ool0B`3oool6000006/0oooo1P00001Y0?ooo`H00000o`3oooo70?ooo`007@3oool5000000T0oooo
00<000000?ooo`3oool0B`3oool6000006/0oooo1P00001Y0?ooo`H00000o`3oooo70?ooo`00:`3o
ool00`000000oooo0?ooo`1;0?ooo`H00000J`3oool6000006T0oooo1P00003o0?ooolL0oooo000[
0?ooo`030000003oool0oooo04/0oooo1P00001[0?ooo`H00000I`3oool800000?l0ooooa`3oool0
02/0oooo00<000000?ooo`3oool0C03oool4000006`0oooo1@00001W0?ooo`T00000o`3oooo70?oo
o`00:`3oool00`000000oooo0?ooo`1;0?ooo`H00000JP3oool6000006L0oooo2@00003o0?ooolL0
oooo000[0?ooo`030000003oool0oooo04/0oooo1P00001Z0?ooo`H00000IP3oool:00000?l0oooo
a`3oool002/0oooo00<000000?ooo`3oool0B`3oool6000006X0oooo1P00001V0?ooo`X00000o`3o
ooo70?ooo`00:`3oool00`000000oooo0?ooo`1;0?ooo`H00000JP3oool6000006H0oooo2@00003o
0?ooolP0oooo000[0?ooo`030000003oool0oooo04`0oooo1000001[0?ooo`H00000IP3oool80000
0?l0oooob@3oool002/0oooo00<000000?ooo`3oool0^`3oool6000006L0oooo1000003o0?oool`0
oooo000[0?ooo`@00000Y@3oool400000140oooo1P00003o0?ooool0oooo>03oool002/0oooo00<0
00000?ooo`3oool0Y@3oool600000100oooo1P00003o0?ooool0oooo>03oool002/0oooo00<00000
0?ooo`3oool0Y@3oool600000100oooo1P00003o0?ooool0oooo>03oool002/0oooo00<000000?oo
o`3oool0Y@3oool600000140oooo1000003o0?ooool0oooo>@3oool002/0oooo00<000000?ooo`3o
ool0Y@3oool600000?l0ooooo`3ooom>0?ooo`00:`3oool00`000000oooo0?ooo`2V0?ooo`D00000
403oool400000?l0ooooo`3ooolj0?ooo`00:`3oool00`000000oooo0?ooo`2V0?ooo`H000003P3o
ool600000?l0ooooo`3oooli0?ooo`00:`3oool00`000000oooo0?ooo`2V0?ooo`H000003P3oool6
00000?l0ooooo`3oooli0?ooo`00:`3oool00`000000oooo0?ooo`2V0?ooo`H000003P3oool60000
0?l0ooooo`3oooli0?ooo`00:`3oool00`000000oooo0?ooo`2V0?ooo`H000003P3oool6000006L0
oooo1000003o0?ooold0oooo000[0?ooo`030000003oool0oooo0:L0oooo1000000?0?ooo`H00000
IP3oool600000?l0ooooc03oool002/0oooo00<000000?ooo`3oool0^`3oool4000006L0oooo1P00
003o0?oool`0oooo000[0?ooo`030000003oool0oooo04/0oooo1000003G0?ooo`H00000o`3oooo<
0?ooo`00:`3oool00`000000oooo0?ooo`1:0?ooo`H00000eP3oool600000?l0ooooc03oool002/0
oooo00<000000?ooo`3oool0BP3oool600000=H0oooo1P00003o0?oool`0oooo000[0?ooo`030000
003oool0oooo04X0oooo1P00001[0?ooo`@00000I`3oool600000?l0ooooc03oool002/0oooo00<0
00000?ooo`3oool0BP3oool6000006X0oooo1P00001V0?ooo`H00000o`3oooo<0?ooo`00:`3oool0
0`000000oooo0?ooo`1;0?ooo`@00000J`3oool6000006L0oooo1000003o0?ooold0oooo000[0?oo
o`030000003oool0oooo0;X0oooo1P00002m0?ooo`@00000o`3ooomg0?ooo`00:`3oool00`000000
oooo0?ooo`2j0?ooo`H00000_03oool600000?l0ooooMP3oool002/0oooo00<000000?ooo`3oool0
^`3oool400000;d0oooo1P00003o0?ooogH0oooo000[0?ooo`030000003oool0oooo0;X0oooo1P00
002l0?ooo`H00000o`3ooomf0?ooo`00:`3oool00`000000oooo0?ooo`2j0?ooo`H00000_03oool6
000000h0oooo1000003o0?ooof@0oooo000[0?ooo`030000003oool0oooo0;X0oooo1P00002m0?oo
o`@000003P3oool600000?l0ooooH`3oool002/0oooo00<000000?ooo`3oool0^P3oool6000006L0
oooo1000001T0?ooo`H00000o`3ooomS0?ooo`00:`3oool00`000000oooo0?ooo`1;0?ooo`@00000
J`3oool6000006H0oooo1P00001S0?ooo`H00000o`3ooomS0?ooo`00:`3oool00`000000oooo0?oo
o`1:0?ooo`H00000J`3oool4000006L0oooo1P00001S0?ooo`H00000o`3ooomS0?ooo`00:`3oool0
0`000000oooo0?ooo`1:0?ooo`H00000JP3oool6000006H0oooo1P00001T0?ooo`@00000o`3ooomT
0?ooo`00:`3oool00`000000oooo0?ooo`1:0?ooo`H00000JP3oool6000006H0oooo1P00003o0?oo
ol`0oooo000[0?ooo`030000003oool0oooo04X0oooo1P00001Z0?ooo`H00000I`3oool400000?l0
ooooc@3oool002/0oooo100000190?ooo`H00000E`3oool4000000l0oooo1P00003o0?ooool0oooo
>@3oool002/0oooo00<000000?ooo`3oool0BP3oool6000005H0oooo1P00000?0?ooo`@00000o`3o
oooo0?ooocX0oooo000[0?ooo`030000003oool0oooo04X0oooo1P00001F0?ooo`H00000o`3ooooo
0?ooodd0oooo000[0?ooo`030000003oool0oooo04X0oooo1P00001F0?ooo`H00000dP3oool40000
0?l0ooooMP3oool002/0oooo00<000000?ooo`3oool0BP3oool6000005H0oooo1P00003A0?ooo`H0
0000o`3ooome0?ooo`00:`3oool00`000000oooo0?ooo`1:0?ooo`H00000E`3oool400000=80oooo
1P00003o0?ooogD0oooo000[0?ooo`030000003oool0oooo04X0oooo1P00003o0?ooobh0oooo1P00
003o0?ooogD0oooo000[0?ooo`030000003oool0oooo04X0oooo1P00003o0?ooobh0oooo1P00003o
0?ooogD0oooo000[0?ooo`030000003oool0oooo04X0oooo1P00001Z0?ooo`@00000`03oool40000
0?l0ooooMP3oool002/0oooo00<000000?ooo`3oool0B`3oool4000006X0oooo1P00003o0?ooool0
oooo>P3oool002/0oooo00<000000?ooo`3oool0^@3oool600000?l0ooooo`3ooolj0?ooo`00:`3o
ool00`000000oooo0?ooo`2i0?ooo`H00000o`3ooooo0?ooocX0oooo000[0?ooo`030000003oool0
oooo0;T0oooo1P00003o0?ooool0oooo>P3oool002/0oooo00<000000?ooo`3oool0?`3oool40000
07H0oooo1P00003o0?ooool0oooo>P3oool002/0oooo00<000000?ooo`3oool0?P3oool6000000H0
oooo1000001J0?ooo`@000003@3oool600000?l0ooooo`3ooolj0?ooo`00:`3oool00`000000oooo
0?ooo`0n0?ooo`H000001@3oool6000005P0oooo1P00000<0?ooo`H00000o`3ooooo0?ooocX0oooo
000[0?ooo`030000003oool0oooo03h0oooo1P0000050?ooo`H00000F03oool6000000`0oooo1P00
003o0?ooool0oooo>P3oool002/0oooo00<000000?ooo`3oool0?P3oool6000000D0oooo1P00001H
0?ooo`H000003@3oool400000?l0ooooo`3ooolk0?ooo`00:`3oool00`000000oooo0?ooo`0o0?oo
o`@000001P3oool6000005P0oooo1P00001i0?ooo`@00000o`3oooo>0?ooo`00:`3oool00`000000
oooo0?ooo`1:0?ooo`@00000FP3oool4000000h0oooo1000001W0?ooo`H00000o`3oooo=0?ooo`00
:`3oool00`000000oooo0?ooo`2i0?ooo`H00000IP3oool600000?l0ooooc@3oool002/0oooo00<0
00000?ooo`3oool0^@3oool6000006H0oooo1P00003o0?ooold0oooo000[0?ooo`030000003oool0
oooo04X0oooo1000001[0?ooo`H00000IP3oool600000?l0ooooc@3oool002/0oooo00<000000?oo
o`3oool0@03oool4000000D0oooo1P00001Z0?ooo`H00000I`3oool400000?l0oooocP3oool002/0
oooo00<000000?ooo`3oool0?`3oool6000000@0oooo1P00001[0?ooo`@00000o`3ooooo0?oooc/0
oooo000[0?ooo`030000003oool0oooo03l0oooo1P0000040?ooo`H00000o`3ooooo0?ooojX0oooo
000[0?ooo`030000003oool0oooo03l0oooo1P0000040?ooo`H00000o`3ooooo0?ooojX0oooo000:
0?ooo`D000000`3oool2000000@0oooo0P0000040?ooo`8000002`3oool00`000000oooo0?ooo`0o
0?ooo`H00000103oool600000?l0ooooo`3ooonZ0?ooo`002`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo0400oooo100000060?ooo`@00000o`3ooooo0?oooj/0
oooo000<0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0?`3oool6
000007@0oooo1000003o0?ooool0oooo?03oool000d0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`080?ooo`H00000?03oool6000006<0oooo1000000<0?ooo`H00000o`3ooooo0?oooc/0oooo
000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0o
0?ooo`H00000HP3oool6000000/0oooo1P00003o0?ooool0oooo>`3oool000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo03l0oooo1P00001R0?ooo`H0
00002`3oool600000?l0ooooo`3ooolk0?ooo`002`3oool3000000@0oooo0P0000040?ooo`800000
103oool2000000/0oooo00<000000?ooo`3oool0@03oool4000000H0oooo1000001I0?ooo`H00000
2`3oool600000?l0ooooo`3ooolk0?ooo`00:`3oool00`000000oooo0?ooo`190?ooo`H00000F03o
ool6000000/0oooo1P00001D0?ooo`@00000o`3ooooR0?ooo`00:`3oool00`000000oooo0?ooo`19
0?ooo`H00000F@3oool4000000`0oooo1P00001C0?ooo`H00000o`3ooooQ0?ooo`00:`3oool00`00
0000oooo0?ooo`190?ooo`H00000J@3oool6000005<0oooo1P00003o0?ooon40oooo000[0?ooo`03
0000003oool0oooo04T0oooo1P00001Y0?ooo`H00000D`3oool600000?l0ooooh@3oool002/0oooo
00<000000?ooo`3oool0BP3oool4000006X0oooo1P00001C0?ooo`H000003P3oool400000?l0oooo
c`3oool002/0oooo00<000000?ooo`3oool0B@3oool6000006T0oooo1P00001C0?ooo`H000003@3o
ool600000?l0oooocP3oool002/0oooo00<000000?ooo`3oool0B@3oool6000006T0oooo1P00001C
0?ooo`H000003@3oool600000?l0oooocP3oool002/0oooo00<000000?ooo`3oool0B@3oool60000
06X0oooo1000001D0?ooo`H000003@3oool600000?l0oooocP3oool002/0oooo00<000000?ooo`3o
ool0@03oool4000000D0oooo1P00001Z0?ooo`@00000E03oool6000000d0oooo1P00003o0?ooolh0
oooo000[0?ooo`030000003oool0oooo03l0oooo1P0000050?ooo`@00000F`3oool4000000/0oooo
1P00001C0?ooo`H000003@3oool600000?l0oooocP3oool002/0oooo00<000000?ooo`3oool0?`3o
ool6000000@0oooo1P00001I0?ooo`H000002P3oool6000005@0oooo1000000>0?ooo`H00000o`3o
ooo>0?ooo`00:`3oool00`000000oooo0?ooo`0o0?ooo`H00000103oool6000005T0oooo1P00000:
0?ooo`H00000IP3oool600000?l0oooocP3oool002/0oooo00<000000?ooo`3oool0?`3oool60000
00@0oooo1P00001I0?ooo`H000002P3oool6000006H0oooo1P00003o0?ooolh0oooo000[0?ooo`03
0000003oool0oooo03l0oooo1P0000040?ooo`H00000F@3oool6000000X0oooo1P00001W0?ooo`@0
0000o`3oooo?0?ooo`00:`3oool00`000000oooo0?ooo`0o0?ooo`H000001@3oool4000005X0oooo
1P00000:0?ooo`H00000o`3ooooo0?oooc/0oooo000[0?ooo`030000003oool0oooo03l0oooo1P00
001S0?ooo`H000002P3oool6000005D0oooo1000000>0?ooo`@00000o`3oooo?0?ooo`00:`3oool0
0`000000oooo0?ooo`0o0?ooo`H00000H`3oool6000000/0oooo1000001E0?ooo`H00000303oool6
00000?l0oooocP3oool002/0oooo00<000000?ooo`3oool0@03oool4000000D0oooo1000001K0?oo
o`H00000I03oool6000000`0oooo1P00003o0?ooolh0oooo000[0?ooo`030000003oool0oooo04P0
oooo1P00001J0?ooo`H00000I03oool6000000`0oooo1P00003o0?ooolh0oooo000[0?ooo`030000
003oool0oooo04P0oooo1P00001J0?ooo`H00000I03oool6000000`0oooo1P00003o0?ooolh0oooo
000[0?ooo`030000003oool0oooo04P0oooo1P00001J0?ooo`H00000I@3oool4000000h0oooo1000
003o0?oooll0oooo000[0?ooo`030000003oool0oooo04P0oooo1P00001J0?ooo`H00000o`3ooooo
0?oood/0oooo000[0?ooo`030000003oool0oooo04T0oooo1000001K0?ooo`H00000o`3ooooo0?oo
od/0oooo000[0?ooo`030000003oool0oooo0:P0oooo1P00000;0?ooo`@00000o`3ooooo0?oooc`0
oooo000[0?ooo`030000003oool0oooo0400oooo100000050?ooo`@00000F`3oool6000000X0oooo
1P00001W0?ooo`@00000o`3oooo?0?ooo`00:`3oool00`000000oooo0?ooo`0o0?ooo`H000000`3o
ool6000005/0oooo1000000;0?ooo`H00000IP3oool600000?l0oooocP3oool002/0oooo1000000n
0?ooo`H000000`3oool6000005X0oooo1P00000:0?ooo`H00000IP3oool600000?l0oooocP3oool0
02/0oooo00<000000?ooo`3oool0?`3oool6000000<0oooo1P00001J0?ooo`H000002P3oool60000
06H0oooo1P00003o0?ooolh0oooo000[0?ooo`030000003oool0oooo03l0oooo1P0000030?ooo`H0
0000FP3oool6000000X0oooo1P00001V0?ooo`H00000o`3oooo>0?ooo`00:`3oool00`000000oooo
0?ooo`0o0?ooo`H000000`3oool6000005X0oooo1P00000:0?ooo`H00000I`3oool400000?l0oooo
c`3oool002/0oooo00<000000?ooo`3oool0?`3oool6000000<0oooo1P00001J0?ooo`H000002P3o
ool6000006L0oooo1000003o0?oooll0oooo000[0?ooo`030000003oool0oooo03l0oooo1P000003
0?ooo`H00000FP3oool6000000X0oooo1P00001V0?ooo`H00000o`3oooo>0?ooo`00:`3oool00`00
0000oooo0?ooo`100?ooo`@00000103oool6000005X0oooo1P00000:0?ooo`D00000I`3oool60000
0?l0oooocP3oool002/0oooo00<000000?ooo`3oool0B03oool6000005/0oooo1000000:0?ooo`H0
0000I`3oool600000?l0oooocP3oool002/0oooo00<000000?ooo`3oool0B03oool6000006T0oooo
1P00001W0?ooo`H00000o`3oooo>0?ooo`00:`3oool00`000000oooo0?ooo`180?ooo`H00000J@3o
ool6000006L0oooo1P00003o0?ooolh0oooo000[0?ooo`030000003oool0oooo04P0oooo1P00001Y
0?ooo`H00000I`3oool600000?l0oooocP3oool002/0oooo00<000000?ooo`3oool0B03oool60000
06X0oooo1000001G0?ooo`@000003@3oool600000?l0oooocP3oool002/0oooo00<000000?ooo`3o
ool0B03oool6000006X0oooo1000001F0?ooo`H00000303oool600000?l0oooocP3oool002/0oooo
00<000000?ooo`3oool0B03oool6000006T0oooo1P00001E0?ooo`H00000303oool600000?l0oooo
cP3oool002/0oooo00<000000?ooo`3oool0B03oool6000006T0oooo1P00001E0?ooo`H00000303o
ool600000?l0oooocP3oool002/0oooo00<000000?ooo`3oool0@@3oool4000000<0oooo1P00001Y
0?ooo`H00000E@3oool6000000`0oooo1P00003o0?ooolh0oooo000[0?ooo`030000003oool0oooo
0400oooo1P0000020?ooo`H00000J@3oool6000005H0oooo1000000>0?ooo`@00000o`3oooo?0?oo
o`00:`3oool00`000000oooo0?ooo`100?ooo`H000000P3oool6000006T0oooo1P00001X0?ooo`@0
0000o`3oooo?0?ooo`00:`3oool00`000000oooo0?ooo`100?ooo`H000000P3oool6000006T0oooo
1P00001W0?ooo`H00000o`3oooo>0?ooo`00:`3oool00`000000oooo0?ooo`100?ooo`H000000P3o
ool6000005`0oooo100000090?ooo`H00000I`3oool600000?l0oooocP3oool002/0oooo00<00000
0?ooo`3oool0@@3oool4000000<0oooo1P00001K0?ooo`H00000203oool6000006L0oooo1P00003o
0?ooolh0oooo000[0?ooo`030000003oool0oooo0440oooo100000030?ooo`H00000F`3oool60000
00P0oooo1P00001W0?ooo`H00000o`3oooo>0?ooo`00:`3oool00`000000oooo0?ooo`100?ooo`H0
00000P3oool6000005/0oooo1P0000080?ooo`H00000J03oool4000006H0oooo1000003o0?ooofD0
oooo000[0?ooo`030000003oool0oooo0400oooo1P0000020?ooo`H00000F`3oool6000000P0oooo
1P00001F0?ooo`@00000M`3oool600000?l0ooooI03oool002/0oooo00<000000?ooo`3oool0@03o
ool600000080oooo1P00001L0?ooo`@000002@3oool6000005D0oooo1P00001f0?ooo`H00000o`3o
oomT0?ooo`00:`3oool00`000000oooo0?ooo`100?ooo`H000000P3oool6000006T0oooo1P00001E
0?ooo`H00000MP3oool600000?l0ooooI03oool002/0oooo00<000000?ooo`3oool0@@3oool40000
00<0oooo1P00001Y0?ooo`H00000E@3oool6000000`0oooo1000001V0?ooo`H00000o`3ooomT0?oo
o`00:`3oool00`000000oooo0?ooo`180?ooo`H00000J@3oool6000005D0oooo1P00000;0?ooo`H0
0000IP3oool400000?l0ooooI@3oool002/0oooo00<000000?ooo`3oool0B@3oool4000006X0oooo
1P00001F0?ooo`@00000303oool600000?l0ooooc`3oool002/0oooo100000170?ooo`H00000J@3o
ool6000006H0oooo1P00003o0?oooll0oooo000[0?ooo`030000003oool0oooo04P0oooo1P00001L
0?ooo`@000002@3oool6000006H0oooo1P00003o0?oooll0oooo000[0?ooo`030000003oool0oooo
04P0oooo1P00001K0?ooo`H00000203oool6000006H0oooo1P00003o0?oooll0oooo000[0?ooo`03
0000003oool0oooo04P0oooo1P00001K0?ooo`H00000203oool6000006H0oooo1P00003o0?oooll0
oooo000[0?ooo`030000003oool0oooo04T0oooo1000001L0?ooo`H00000203oool6000006H0oooo
1P00003o0?oooll0oooo000[0?ooo`030000003oool0oooo0:T0oooo1P0000080?ooo`H00000I`3o
ool400000?l0ooood03oool002/0oooo00<000000?ooo`3oool0Z@3oool6000000P0oooo1P00001W
0?ooo`@00000o`3oooo@0?ooo`00:`3oool00`000000oooo0?ooo`110?ooo`@000000`3oool40000
05d0oooo1P0000080?ooo`H00000IP3oool6000006D0oooo1000003o0?ooofH0oooo000[0?ooo`03
0000003oool0oooo0400oooo1P0000000`3oool0000000000004000005`0oooo1P0000080?ooo`H0
0000IP3oool6000006@0oooo1P00003o0?ooofD0oooo000[0?ooo`030000003oool0oooo0400oooo
1P0000000`3oool0000000000004000005`0oooo1P0000080?ooo`H00000E`3oool4000000/0oooo
1P00001T0?ooo`H00000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`100?ooo`H0000000<0
oooo0000000000001000001L0?ooo`H00000203oool5000005L0oooo1P00000:0?ooo`H00000I03o
ool600000?l0ooooI@3oool002/0oooo00<000000?ooo`3oool0@03oool6000000030?ooo`000000
000000@00000G03oool6000000L0oooo1P00001G0?ooo`H000002`3oool4000006D0oooo1P00003o
0?ooofD0oooo000[0?ooo`030000003oool0oooo0400oooo1P0000000`3oool00000000000040000
05d0oooo100000080?ooo`H00000E`3oool6000007D0oooo1000003o0?ooofH0oooo000[0?ooo`03
0000003oool0oooo0400oooo1P0000000`3oool0000000000004000005`0oooo1P0000070?ooo`H0
0000E`3oool6000007@0oooo1P00003o0?ooofD0oooo000[0?ooo`030000003oool0oooo0400oooo
1P0000000`3oool0000000000004000005`0oooo1P0000070?ooo`H00000E`3oool6000007@0oooo
1P00003o0?ooofD0oooo000[0?ooo`030000003oool0oooo0440oooo100000020?ooo`H00000G03o
ool6000000L0oooo1P00001G0?ooo`H00000M03oool600000?l0ooooI@3oool002/0oooo00<00000
0?ooo`3oool0A`3oool6000005`0oooo1P0000070?ooo`H00000F03oool4000000`0oooo1000001U
0?ooo`H00000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`180?ooo`@00000G@3oool60000
00L0oooo1P00001G0?ooo`H000002P3oool6000006@0oooo1P00003o0?ooofD0oooo000[0?ooo`03
0000003oool0oooo04P0oooo1000001N0?ooo`H000001P3oool6000005L0oooo1P00000:0?ooo`H0
0000I03oool600000?l0ooooI@3oool002/0oooo00<000000?ooo`3oool0@P3oool4000000030?oo
o`000000000000@00000G@3oool6000000H0oooo1P00001G0?ooo`H000002P3oool6000006@0oooo
1P00003o0?ooofD0oooo000[0?ooo`030000003oool0oooo0440oooo3000001M0?ooo`H000001P3o
ool6000005L0oooo1P00000:0?ooo`H00000I@3oool400000?l0ooooIP3oool002/0oooo00<00000
0?ooo`3oool0@@3oool<000005d0oooo1P0000060?ooo`H00000E`3oool6000000X0oooo1P00003o
0?oooll0oooo000[0?ooo`030000003oool0oooo0440oooo3000001M0?ooo`H000001P3oool60000
05P0oooo1000000;0?ooo`H00000o`3oooo?0?ooo`00:`3oool00`000000oooo0?ooo`110?ooo``0
0000G@3oool6000000H0oooo1P00001H0?ooo`@000002`3oool600000?l0ooooc`3oool002/0oooo
00<000000?ooo`3oool0@@3oool<000005d0oooo1P0000060?ooo`H00000E`3oool6000000X0oooo
1P00003o0?oooll0oooo000[0?ooo`030000003oool0oooo0440oooo3000001M0?ooo`H000001P3o
ool6000005L0oooo1P00000:0?ooo`H00000I@3oool400000?l0ooooIP3oool002/0oooo00<00000
0?ooo`3oool0@P3oool4000000030?ooo`000000000000@00000G@3oool6000000H0oooo1P00001G
0?ooo`H000002P3oool6000006@0oooo1P00003o0?ooofD0oooo000[0?ooo`030000003oool0oooo
04L0oooo1P00001M0?ooo`H000001P3oool6000005L0oooo1P00000:0?ooo`H00000I03oool60000
0?l0ooooI@3oool002/0oooo00<000000?ooo`3oool0A`3oool6000005d0oooo1P0000060?ooo`H0
0000E`3oool6000000/0oooo1000001U0?ooo`H00000o`3ooomU0?ooo`00:`3oool00`000000oooo
0?ooo`120?ooo`@0000000<0oooo0000000000001000001M0?ooo`H000001P3oool6000005P0oooo
1000000;0?ooo`H00000I03oool600000?l0ooooI@3oool002/0oooo100000100?ooo``00000G@3o
ool6000000H0oooo1P00001W0?ooo`H00000I@3oool400000?l0ooooIP3oool002/0oooo00<00000
0?ooo`3oool0@@3oool<000005d0oooo1P0000060?ooo`H00000I`3oool6000006D0oooo1000003o
0?ooofH0oooo000[0?ooo`030000003oool0oooo0440oooo3000001M0?ooo`H000001P3oool60000
05P0oooo1000000;0?ooo`H00000I03oool600000?l0ooooI@3oool002/0oooo00<000000?ooo`3o
ool0@@3oool<000005d0oooo1P0000060?ooo`H00000E`3oool6000000X0oooo1P00001T0?ooo`H0
0000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`120?ooo`@0000000<0oooo000000000000
1000001M0?ooo`H000001P3oool6000005L0oooo1P00000:0?ooo`H00000I03oool600000?l0oooo
I@3oool002/0oooo00<000000?ooo`3oool0@@3oool<000005d0oooo1P0000060?ooo`H00000E`3o
ool6000000X0oooo1P00001T0?ooo`H00000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`11
0?ooo``00000G@3oool6000000H0oooo1P00001G0?ooo`H000002P3oool6000006@0oooo1P00003o
0?ooofD0oooo000[0?ooo`030000003oool0oooo0440oooo3000001M0?ooo`L000001@3oool60000
05P0oooo1000000<0?ooo`@00000I@3oool600000?l0ooooI@3oool002/0oooo00<000000?ooo`3o
ool0@@3oool<000005h0oooo1P0000050?ooo`H00000d@3oool600000?l0ooooI@3oool002/0oooo
00<000000?ooo`3oool0@@3oool<000005h0oooo1P0000050?ooo`H00000d@3oool600000?l0oooo
I@3oool002/0oooo00<000000?ooo`3oool0@@3oool<000005h0oooo2@0000000`3oool000000000
0005000006P0oooo1000001U0?ooo`H00000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`11
0?ooo``00000GP3ooolA000006L0oooo1P00001T0?ooo`H00000o`3ooomU0?ooo`00:`3oool00`00
0000oooo0?ooo`110?ooo``00000GP3ooolA000006L0oooo1P00001T0?ooo`H00000o`3ooomU0?oo
o`00:`3oool00`000000oooo0?ooo`110?ooo``00000GP3oool@000006P0oooo1P00001T0?ooo`H0
0000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`110?ooo`/00000G`3oool@000006P0oooo
1P00001T0?ooo`H00000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`110?ooo`/00000G`3o
ool@000006P0oooo1P00001T0?ooo`H00000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`11
0?ooo`/00000G`3oool@000006P0oooo1P00001T0?ooo`H00000o`3ooomU0?ooo`00:`3oool00`00
0000oooo0?ooo`110?ooo`/00000H03oool?000006L0oooo1`00001T0?ooo`H00000o`3ooomU0?oo
o`00:`3oool00`000000oooo0?ooo`110?ooo`/00000H@3oool>000006L0oooo1P00001U0?ooo`H0
0000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`110?ooo`/00000I03oool;000006L0oooo
1P00001U0?ooo`H00000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`110?ooo`/00000I03o
ool;000005T0oooo1000000:0?ooo`H00000I@3oool600000?l0ooooI@3oool002/0oooo00<00000
0?ooo`3oool0@@3oool;000006@0oooo2`00001H0?ooo`H000002@3oool6000006D0oooo1P00003o
0?ooofD0oooo000[0?ooo`030000003oool0oooo0440oooo2`00001T0?ooo`/00000F03oool60000
00T0oooo1P00001U0?ooo`H00000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`120?ooo`X0
0000I@3oool:000005P0oooo1P00000:0?ooo`@00000IP3oool600000?l0ooooI@3oool002/0oooo
00<000000?ooo`3oool0@P3oool:000006D0oooo2P00001H0?ooo`H00000M03oool600000?l0oooo
I@3oool002/0oooo00<000000?ooo`3oool0@P3oool:000006D0oooo2P00001H0?ooo`H00000I`3o
ool4000000T0oooo1P00003o0?ooofD0oooo000[0?ooo`030000003oool0oooo0480oooo2P00001U
0?ooo`X00000F@3oool4000006L0oooo1P0000080?ooo`H00000o`3ooomU0?ooo`00303oool30000
00<0oooo0P0000040?ooo`800000103oool2000000/0oooo00<000000?ooo`3oool0@P3oool:0000
06D0oooo2P00001I0?ooo`@00000I`3oool6000000T0oooo1000003o0?ooofH0oooo000=0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`120?ooo`X00000I@3o
ool:000005P0oooo1P00000:0?ooo`@00000F03oool6000000P0oooo1P00003o0?ooofD0oooo000:
0?ooo`D000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`120?ooo`X00000I@3oool:000005P0
oooo1P0000090?ooo`H00000E`3oool6000000P0oooo1P00003o0?ooofD0oooo000:0?ooo`040000
003oool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000X0oooo1P00000o0?ooo`T00000IP3oool:000005P0oooo1P00
00090?ooo`H00000F03oool4000000T0oooo1P00003o0?ooofD0oooo000;0?ooo`030000003oool0
000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0@P3oool:000006H0oooo2@00001H0?ooo`L0
0000203oool6000005L0oooo1P0000080?ooo`H00000o`3ooomU0?ooo`00303oool2000000<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool0@P3oool:000006H0oooo2@00001I0?ooo`H00000203oool6
000005L0oooo1P0000080?ooo`H00000o`3ooomU0?ooo`003@3oool00`000000oooo0?ooo`020?oo
o`800000103oool2000000@0oooo0P00000;0?ooo`030000003oool0oooo0480oooo2P00001V0?oo
o`P00000FP3oool6000000P0oooo1P00001G0?ooo`H00000203oool600000?l0ooooI@3oool002/0
oooo00<000000?ooo`3oool0@P3oool:000006H0oooo2000001J0?ooo`H00000203oool6000005L0
oooo1P0000080?ooo`H00000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`120?ooo`X00000
IP3oool8000005/0oooo100000090?ooo`H00000F03oool4000000T0oooo1P00003o0?ooofD0oooo
000[0?ooo`030000003oool0oooo0480oooo2P00001V0?ooo`P00000F`3oool4000000T0oooo1P00
001U0?ooo`H00000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`120?ooo`X00000IP3oool8
000005X0oooo1P0000090?ooo`@00000F@3oool4000000T0oooo1P00003o0?ooofD0oooo000[0?oo
o`030000003oool0oooo0480oooo2P00001W0?ooo`L00000FP3oool6000000P0oooo1P00001G0?oo
o`H000002@3oool400000?l0ooooIP3oool002/0oooo00<000000?ooo`3oool0@P3oool9000006P0
oooo1`00001J0?ooo`H00000203oool6000005L0oooo1P00003o0?ooog<0oooo000[0?ooo`030000
003oool0oooo0480oooo2@00001X0?ooo`L00000FP3oool6000000P0oooo1P00001G0?ooo`H00000
o`3ooomc0?ooo`00:`3oool00`000000oooo0?ooo`130?ooo`P00000J@3oool5000005`0oooo1000
00090?ooo`H00000E`3oool600000?l0ooooL`3oool002/0oooo00<000000?ooo`3oool0@P3oool9
00000<X0oooo100000090?ooo`H00000E`3oool600000?l0ooooL`3oool002/0oooo00<000000?oo
o`3oool0@P3oool900000<T0oooo1P0000080?ooo`H00000F03oool4000000X0oooo1000003o0?oo
ofH0oooo000[0?ooo`030000003oool0oooo0480oooo2@0000390?ooo`H000002@3oool4000005P0
oooo1P0000080?ooo`H00000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`120?ooo`T00000
b@3oool6000000P0oooo1P00001G0?ooo`H00000203oool600000?l0ooooI@3oool002/0oooo00<0
00000?ooo`3oool0@`3oool800000<T0oooo1P0000080?ooo`H00000E`3oool6000000P0oooo1P00
003o0?ooofD0oooo000[0?ooo`030000003oool0oooo04<0oooo200000390?ooo`H00000203oool6
000005L0oooo1P0000080?ooo`H00000o`3ooomU0?ooo`00:`3oool00`000000oooo0?ooo`130?oo
o`P00000b@3oool6000000P0oooo1P00001H0?ooo`@000002@3oool600000?l0ooooI@3oool002/0
oooo00<000000?ooo`3oool0@`3oool800000<T0oooo1P0000080?ooo`H00000I@3oool600000?l0
ooooI@3oool002/0oooo00<000000?ooo`3oool0@`3oool800000<T0oooo1P0000080?ooo`H00000
IP3oool400000?l0ooooIP3oool002/0oooo00<000000?ooo`3oool0@`3oool800000<T0oooo1P00
00080?ooo`H00000o`3oooo@0?ooo`00:`3oool00`000000oooo0?ooo`130?ooo`P00000b@3oool6
000000P0oooo1P00003o0?ooom00oooo000[0?ooo`030000003oool0oooo04<0oooo200000390?oo
o`H00000203oool600000?l0ooood03oool002/0oooo00<000000?ooo`3oool0@`3oool800000<T0
oooo1P0000080?ooo`H00000F03oool400000?l0ooooM03oool002/0oooo00<000000?ooo`3oool0
@`3oool800000<T0oooo1P0000080?ooo`H00000E`3oool600000?l0ooooL`3oool002/0oooo00<0
00000?ooo`3oool0@`3oool700000<X0oooo1P0000080?ooo`H00000E`3oool600000?l0ooooL`3o
ool002/0oooo00<000000?ooo`3oool0@`3oool700000<X0oooo1P0000080?ooo`H00000E`3oool6
00000?l0ooooL`3oool002/0oooo00<000000?ooo`3oool0A03oool600000<X0oooo1P0000080?oo
o`H00000E`3oool600000?l0ooooL`3oool002/0oooo00<000000?ooo`3oool0A@3oool400000</0
oooo1P0000080?ooo`H00000F03oool400000?l0ooooM03oool002/0oooo1000003o0?oooa@0oooo
1P0000080?ooo`H00000F03oool400000?l0ooooM03oool002/0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`@000002@3oool6000005L0oooo1P0000080?ooo`@00000o`3ooomW0?ooo`00:`3oool0
0`000000oooo0?ooo`3o0?oooaD0oooo1P0000080?ooo`H00000E`3oool6000000L0oooo1P00003o
0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0oooo5@3oool600000080oooo100000020?oo
o`H00000E`3oool6000000L0oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0
oooo5@3oool6000000030?ooo`000000000000X00000F03oool6000000L0oooo1P00003o0?ooofH0
oooo000[0?ooo`030000003oool0oooo0?l0oooo5@3ooolC000005T0oooo100000080?ooo`H00000
o`3ooomV0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooaD0oooo4`00001U0?ooo`H00000o`3o
oomV0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooaH0oooo100000000`3oool000000000000;
000006H0oooo1000003o0?ooofL0oooo000[0?ooo`030000003oool0oooo0?l0oooo6`3oool=0000
0?l0ooood@3oool002/0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`d00000o`3ooooA0?ooo`00
:`3oool00`000000oooo0?ooo`3o0?oooa/0oooo3@00003o0?ooom40oooo000[0?ooo`030000003o
ool0oooo0?l0oooo6`3oool=00000?l0ooood@3oool002/0oooo00<000000?ooo`3oool0o`3ooolG
0?oooa400000o`3ooooA0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooaH0oooo4P00003o0?oo
om40oooo000[0?ooo`030000003oool0oooo0?l0oooo5P3ooolB00000?l0ooood@3oool002/0oooo
00<000000?ooo`3oool0o`3ooolF0?oooa800000o`3ooooA0?ooo`00:`3oool00`000000oooo0?oo
o`3o0?oooaH0oooo4P00003o0?ooom40oooo000[0?ooo`030000003oool0oooo0?l0oooo5P3ooolB
000005T0oooo1000003o0?ooog@0oooo000[0?ooo`030000003oool0oooo0?l0oooo5P3ooolB0000
05P0oooo1P00003o0?ooog<0oooo000[0?ooo`030000003oool0oooo0?l0oooo5P3ooolB000005P0
oooo1P00003o0?ooog<0oooo000[0?ooo`030000003oool0oooo0?l0oooo5P3ooolB000005P0oooo
1P0000080?ooo`@00000o`3ooomW0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooaH0oooo4P00
001H0?ooo`H000001`3oool600000?l0ooooIP3oool002/0oooo00<000000?ooo`3oool0o`3ooolF
0?oooa800000F@3oool4000000P0oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo
0?l0oooo5P3ooolB000006D0oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0
oooo5P3ooolB000006D0oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0oooo
5P3ooolB000006D0oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0oooo5P3o
oolB000005T0oooo100000080?ooo`H00000o`3ooomV0?ooo`00:`3oool00`000000oooo0?ooo`3o
0?oooaH0oooo4P00001H0?ooo`H00000203oool400000?l0ooooI`3oool002/0oooo00<000000?oo
o`3oool0o`3ooolF0?oooa800000F03oool6000000L0oooo1P00003o0?ooofH0oooo000[0?ooo`@0
0000o`3ooolE0?oooa800000F03oool6000000L0oooo1P00003o0?ooofH0oooo000[0?ooo`030000
003oool0oooo0?l0oooo5P3ooolA000005T0oooo1P0000070?ooo`H00000o`3ooomV0?ooo`00:`3o
ool00`000000oooo0?ooo`3o0?oooaH0oooo4P00001H0?ooo`H000001`3oool600000?l0ooooIP3o
ool002/0oooo00<000000?ooo`3oool0o`3ooolF0?oooa800000F03oool6000000L0oooo1P00003o
0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0oooo5`3ooolA000005T0oooo100000080?oo
o`H00000o`3ooomV0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooaH0oooo4P00001I0?ooo`@0
0000203oool600000?l0ooooIP3oool002/0oooo00<000000?ooo`3oool0o`3ooolF0?oooa400000
F@3oool6000000L0oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0oooo5P3o
oolA000005T0oooo1P0000070?ooo`H00000o`3ooomV0?ooo`00:`3oool00`000000oooo0?ooo`3o
0?oooaH0oooo4@00001I0?ooo`H000001`3oool600000?l0ooooIP3oool002/0oooo00<000000?oo
o`3oool0o`3ooolG0?oooa000000F@3oool6000000L0oooo1P00003o0?ooofH0oooo000[0?ooo`03
0000003oool0oooo0?l0oooo5`3oool@000005X0oooo100000090?ooo`@00000o`3ooomW0?ooo`00
:`3oool00`000000oooo0?ooo`3o0?oooaL0oooo4000003o0?ooom80oooo000[0?ooo`030000003o
ool0oooo0?l0oooo5`3oool@00000?l0oooodP3oool002/0oooo00<000000?ooo`3oool0o`3ooolG
0?oooa000000I`3oool400000?l0ooooI`3oool002/0oooo00<000000?ooo`3oool0o`3ooolG0?oo
oa000000F`3oool4000000L0oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0
oooo5`3oool@000005X0oooo1P0000060?ooo`H00000o`3ooomV0?ooo`00:`3oool00`000000oooo
0?ooo`3o0?oooaL0oooo4000001J0?ooo`H000001P3oool600000?l0ooooIP3oool002/0oooo00<0
00000?ooo`3oool0o`3ooolG0?oooa000000FP3oool6000000H0oooo1P00003o0?ooofH0oooo000[
0?ooo`030000003oool0oooo0?l0oooo5`3oool@000005X0oooo1P0000070?ooo`@00000o`3ooomW
0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooaL0oooo1`0000000`3oool00000000000060000
05/0oooo1000003o0?ooog<0oooo000[0?ooo`030000003oool0oooo0?l0oooo5`3oool700000080
oooo1`00003o0?ooom80oooo000[0?ooo`030000003oool0oooo0?l0oooo603oool600000080oooo
1P00003o0?ooom<0oooo000[0?ooo`030000003oool0oooo0?l0oooo6@3oool4000000<0oooo1P00
001X0?ooo`@00000o`3ooomW0?ooo`00:`3oool00`000000oooo0?ooo`3o0?ooob40oooo1000001X
0?ooo`H00000o`3ooomV0?ooo`00:`3oool00`000000oooo0?ooo`3o0?ooohd0oooo1P00003o0?oo
ofH0oooo000[0?ooo`030000003oool0oooo0?l0ooooS@3oool600000?l0ooooIP3oool002/0oooo
00<000000?ooo`3oool0o`3ooon=0?ooo`H00000o`3ooomV0?ooo`00:`3oool00`000000oooo0?oo
o`3o0?ooohd0oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0ooooS@3oool6
00000?l0ooooIP3oool002/0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`H00000o`3ooomV0?oo
o`00:`3oool400000?l0ooooS03oool600000?l0ooooIP3oool002/0oooo00<000000?ooo`3oool0
o`3ooon=0?ooo`H00000o`3ooomV0?ooo`00:`3oool00`000000oooo0?ooo`3o0?ooohd0oooo1P00
003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0ooooS@3oool600000?l0ooooIP3oool0
02/0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`H00000o`3ooomV0?ooo`00:`3oool00`000000
oooo0?ooo`3o0?ooohd0oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0oooo
PP3oool4000000L0oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0ooooP@3o
ool6000000H0oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0ooooP@3oool6
000000H0oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0ooooP@3oool60000
00H0oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0ooooP@3oool6000000H0
oooo1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0ooooP@3oool6000000H0oooo
1P00003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0ooooP@3oool6000000H0oooo1P00
003o0?ooofH0oooo000[0?ooo`030000003oool0oooo0?l0ooooP@3oool6000000D0oooo1P00003o
0?ooofL0oooo000[0?ooo`030000003oool0oooo0?l0ooooP@3oool6000000D0oooo1P00003o0?oo
ofL0oooo000[0?ooo`030000003oool0oooo0?l0ooooP@3oool6000000D0oooo1P00003o0?ooofL0
oooo000[0?ooo`030000003oool0oooo0?l0ooooP@3oool6000000D0oooo1P00003o0?ooofL0oooo
000[0?ooo`030000003oool0oooo0?l0ooooPP3oool4000000H0oooo1P00003o0?ooofL0oooo000[
0?ooo`030000003oool0oooo0?l0ooooP@3oool6000000D0oooo1P00003o0?ooofL0oooo000[0?oo
o`030000003oool0oooo0?l0ooooP@3oool6000000D0oooo1P00003o0?ooofL0oooo000[0?ooo`03
0000003oool0oooo0?l0ooooP@3oool6000000D0oooo1P00003o0?ooofL0oooo000[0?ooo`030000
003oool0oooo0?l0ooooP@3oool6000000D0oooo1P00003o0?ooofL0oooo000[0?ooo`030000003o
ool0oooo0?l0ooooP@3oool6000000D0oooo1P00003o0?ooofL0oooo000[0?ooo`030000003oool0
oooo0?l0ooooP@3oool6000000D0oooo1P00003o0?ooofL0oooo000[0?ooo`030000003oool0oooo
0?l0ooooP@3oool6000000D0oooo1P00003o0?ooofL0oooo000[0?ooo`030000003oool0oooo0?l0
ooooP@3oool6000000D0oooo1P00003o0?ooofL0oooo000[0?ooo`030000003oool0oooo0?l0oooo
P@3oool6000000H0oooo1000003o0?ooofP0oooo000;0?ooo`<00000103oool2000000@0oooo0P00
00040?ooo`8000002`3oool00`000000oooo0?ooo`3o0?oooh40oooo1P00003o0?ooog80oooo000:
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`3o0?oo
oh40oooo1P00003o0?ooog80oooo000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`3o0?oooh40oooo1P00003o0?ooog80oooo000:0?ooo`@000000`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000002P3oool600000?l0ooooO`3oool4000000L0oooo1000003o0?ooofP0oooo000:0?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0o`3ooon10?ooo`H000001@3o
ool600000?l0ooooI`3oool000/0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`3o0?oooh40oooo1P0000050?ooo`H00000o`3ooomW0?ooo`00303oool2000000@0oooo
0P0000040?ooo`800000103oool2000000/0oooo00<000000?ooo`3oool0o`3ooon10?ooo`H00000
1@3oool600000?l0ooooI`3oool002/0oooo00<000000?ooo`3oool0o`3ooon10?ooo`H000001@3o
ool600000?l0ooooI`3oool002/0oooo00<000000?ooo`3oool0o`3ooon20?ooo`@000001P3oool6
00000?l0ooooI`3oool002/0oooo00<000000?ooo`3oool0o`3ooon20?ooo`@000001`3oool40000
0?l0ooooJ03oool002/0oooo00<000000?ooo`3oool0o`3ooon10?ooo`H000001@3oool600000?l0
ooooI`3oool002/0oooo00<000000?ooo`3oool0o`3ooon10?ooo`H000001@3oool600000?l0oooo
I`3oool002/0oooo00<000000?ooo`3oool0o`3ooon10?ooo`H000001@3oool600000?l0ooooI`3o
ool002/0oooo00<000000?ooo`3oool0o`3ooon10?ooo`H000001@3oool600000?l0ooooI`3oool0
02/0oooo00<000000?ooo`3oool0o`3ooon20?ooo`@000001P3oool600000?l0ooooI`3oool002/0
oooo00<000000?ooo`3oool0o`3ooon20?ooo`@000001P3oool600000?l0ooooI`3oool002/0oooo
00<000000?ooo`3oool0o`3ooon10?ooo`H000001@3oool600000?l0ooooI`3oool002/0oooo00<0
00000?ooo`3oool0o`3ooon10?ooo`H000001@3oool600000?l0ooooI`3oool002/0oooo00<00000
0?ooo`3oool0o`3ooon10?ooo`H000001@3oool600000?l0ooooI`3oool002/0oooo00<000000?oo
o`3oool0o`3ooon10?ooo`H000001@3oool600000?l0ooooI`3oool002/0oooo00<000000?ooo`3o
ool0o`3ooon10?ooo`H000001@3oool600000?l0ooooI`3oool002/0oooo00<000000?ooo`3oool0
o`3ooon10?ooo`H000001@3oool600000?l0ooooI`3oool002/0oooo00<000000?ooo`3oool0o`3o
oon20?ooo`@000001P3oool600000?l0ooooI`3oool002/0oooo00<000000?ooo`3oool0o`3ooon<
0?ooo`H00000o`3ooomW0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh`0oooo1P00003o0?oo
ofL0oooo000[0?ooo`030000003oool0oooo0?l0ooooPP3oool4000000H0oooo1P00003o0?ooofL0
oooo000[0?ooo`030000003oool0oooo0?l0ooooP@3oool6000000D0oooo1P00003o0?ooofL0oooo
000[0?ooo`030000003oool0oooo0?l0ooooP@3oool6000000D0oooo1P00003o0?ooofL0oooo000[
0?ooo`030000003oool0oooo0?l0ooooP@3oool6000000D0oooo1P00003o0?ooofL0oooo000[0?oo
o`030000003oool0oooo0?l0ooooP@3oool6000000D0oooo1P00003o0?ooofL0oooo000[0?ooo`03
0000003oool0oooo0?l0ooooPP3oool5000000D0oooo1P00003o0?ooofL0oooo000[0?ooo`030000
003oool0oooo0?l0ooooPP3oool6000000@0oooo1P00003o0?ooofL0oooo000[0?ooo`@00000o`3o
oon10?ooo`H00000103oool600000?l0ooooI`3oool002/0oooo00<000000?ooo`3oool0o`3ooon2
0?ooo`H00000103oool600000?l0ooooI`3oool002/0oooo00<000000?ooo`3oool0o`3ooon20?oo
o`H00000103oool600000?l0ooooI`3oool002/0oooo00<000000?ooo`3oool0o`3ooon20?ooo`H0
0000103oool600000?l0ooooI`3oool002/0oooo00<000000?ooo`3oool0o`3ooon30?ooo`@00000
1@3oool600000?l0ooooI`3oool002/0oooo00<000000?ooo`3oool0o`3ooon<0?ooo`H00000o`3o
oomW0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh`0oooo1P00003o0?ooofL0oooo000[0?oo
o`030000003oool0oooo0?l0ooooS03oool600000?l0ooooI`3oool002/0oooo00<000000?ooo`3o
ool0o`3ooon<0?ooo`H00000o`3ooomW0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh<0oooo
100000050?ooo`D00000o`3ooomX0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh80oooo1P00
00030?ooo`H00000o`3ooomX0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh80oooo1P000003
0?ooo`H00000o`3ooomX0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh80oooo1P0000030?oo
o`H00000o`3ooomX0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh80oooo1P0000030?ooo`H0
0000o`3ooomX0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh80oooo1P0000030?ooo`H00000
o`3ooomX0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh80oooo1P0000030?ooo`H00000o`3o
oomX0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh80oooo1P0000030?ooo`H00000o`3ooomX
0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh80oooo1P0000030?ooo`H00000o`3ooomX0?oo
o`00:`3oool00`000000oooo0?ooo`3o0?oooh80oooo1P0000030?ooo`H00000o`3ooomX0?ooo`00
:`3oool00`000000oooo0?ooo`3o0?oooh80oooo1P0000030?ooo`H00000o`3ooomX0?ooo`00:`3o
ool00`000000oooo0?ooo`3o0?oooh80oooo1P0000030?ooo`H00000o`3ooomX0?ooo`00:`3oool0
0`000000oooo0?ooo`3o0?oooh80oooo1P0000030?ooo`H00000o`3ooomX0?ooo`00:`3oool00`00
0000oooo0?ooo`3o0?oooh80oooo1P0000030?ooo`H00000o`3ooomX0?ooo`00:`3oool00`000000
oooo0?ooo`3o0?oooh80oooo1P0000030?ooo`H00000o`3ooomX0?ooo`00:`3oool00`000000oooo
0?ooo`3o0?oooh80oooo1P0000030?ooo`H00000o`3ooomX0?ooo`00:`3oool00`000000oooo0?oo
o`3o0?oooh80oooo1P0000030?ooo`H00000o`3ooomX0?ooo`00:`3oool00`000000oooo0?ooo`3o
0?oooh80oooo1P0000030?ooo`H00000o`3ooomX0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oo
oh80oooo1P0000030?ooo`H00000o`3ooomX0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh80
oooo1P0000030?ooo`H00000o`3ooomX0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh<0oooo
100000040?ooo`H00000o`3ooomX0?ooo`00:`3oool400000?l0ooooRP3oool600000?l0ooooJ03o
ool002/0oooo00<000000?ooo`3oool0o`3ooon30?ooo`@00000103oool600000?l0ooooJ03oool0
02/0oooo00<000000?ooo`3oool0o`3ooon20?ooo`H000000`3oool600000?l0ooooJ03oool002/0
oooo00<000000?ooo`3oool0o`3ooon20?ooo`H000000`3oool600000?l0ooooJ03oool002/0oooo
00<000000?ooo`3oool0o`3ooon20?ooo`H0000000<0oooo0000000000001P00003o0?ooofP0oooo
000[0?ooo`030000003oool0oooo0?l0ooooPP3oool?00000?l0ooooJ03oool002/0oooo00<00000
0?ooo`3oool0o`3ooon20?ooo`l00000o`3ooomX0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oo
oh80oooo3P00003o0?ooofT0oooo000[0?ooo`030000003oool0oooo0?l0ooooPP3oool>00000?l0
ooooJ@3oool002/0oooo00<000000?ooo`3oool0o`3ooon20?ooo`h00000o`3ooomY0?ooo`00:`3o
ool00`000000oooo0?ooo`3o0?oooh80oooo3P00003o0?ooofT0oooo000[0?ooo`030000003oool0
oooo0?l0ooooPP3oool>00000?l0ooooJ@3oool002/0oooo00<000000?ooo`3oool0o`3ooon20?oo
o`h00000o`3ooomY0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh80oooo3@00003o0?ooofX0
oooo000[0?ooo`030000003oool0oooo0?l0ooooPP3oool;00000?l0ooooK03oool002/0oooo00<0
00000?ooo`3oool0o`3ooon20?ooo`/00000o`3ooom/0?ooo`00:`3oool00`000000oooo0?ooo`3o
0?oooh80oooo2`00003o0?ooof`0oooo000[0?ooo`030000003oool0oooo0?l0ooooPP3oool;0000
0?l0ooooK03oool002/0oooo00<000000?ooo`3oool0o`3ooon20?ooo`X00000o`3ooom]0?ooo`00
:`3oool00`000000oooo0?ooo`3o0?oooh80oooo2P00003o0?ooofd0oooo000[0?ooo`030000003o
ool0oooo0?l0ooooPP3oool:00000?l0ooooK@3oool002/0oooo00<000000?ooo`3oool0o`3ooon2
0?ooo`X00000o`3ooom]0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh<0oooo2@00003o0?oo
ofd0oooo000[0?ooo`030000003oool0oooo0?l0ooooP`3oool900000?l0ooooK@3oool002/0oooo
00<000000?ooo`3oool0o`3ooon30?ooo`T00000o`3ooom]0?ooo`00:`3oool00`000000oooo0?oo
o`3o0?oooh<0oooo2@00003o0?ooofd0oooo000[0?ooo`030000003oool0oooo0?l0ooooP`3oool9
00000?l0ooooK@3oool002/0oooo00<000000?ooo`3oool0o`3ooon30?ooo`T00000o`3ooom]0?oo
o`00:`3oool00`000000oooo0?ooo`3o0?oooh<0oooo2@00003o0?ooofd0oooo000[0?ooo`030000
003oool0oooo0?l0ooooP`3oool900000?l0ooooK@3oool002/0oooo1000003o0?oooh80oooo2@00
003o0?ooofd0oooo000[0?ooo`030000003oool0oooo0?l0ooooP`3oool900000?l0ooooK@3oool0
02/0oooo00<000000?ooo`3oool0o`3ooon30?ooo`T00000o`3ooom]0?ooo`00:`3oool00`000000
oooo0?ooo`3o0?oooh<0oooo2@00003o0?ooofd0oooo000[0?ooo`030000003oool0oooo0?l0oooo
P`3oool800000?l0ooooKP3oool002/0oooo00<000000?ooo`3oool0o`3ooon30?ooo`P00000o`3o
oom^0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh<0oooo2000003o0?ooofh0oooo000[0?oo
o`030000003oool0oooo0?l0ooooP`3oool800000?l0ooooKP3oool002/0oooo00<000000?ooo`3o
ool0o`3ooon30?ooo`P00000o`3ooom^0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh<0oooo
2000003o0?ooofh0oooo000[0?ooo`030000003oool0oooo0?l0ooooP`3oool800000?l0ooooKP3o
ool002/0oooo00<000000?ooo`3oool0o`3ooon30?ooo`P00000o`3ooom^0?ooo`00:`3oool00`00
0000oooo0?ooo`3o0?oooh<0oooo2000003o0?ooofh0oooo000[0?ooo`030000003oool0oooo0?l0
ooooP`3oool800000?l0ooooKP3oool002/0oooo00<000000?ooo`3oool0o`3ooon30?ooo`P00000
o`3ooom^0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh<0oooo2000003o0?ooofh0oooo000[
0?ooo`030000003oool0oooo0?l0ooooP`3oool800000?l0ooooKP3oool002/0oooo00<000000?oo
o`3oool0o`3ooon40?ooo`H00000o`3ooom_0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooh@0
oooo1P00003o0?ooofl0oooo000[0?ooo`030000003oool0oooo0?l0ooooQ03oool600000?l0oooo
K`3oool002/0oooo00<000000?ooo`3oool0o`3ooon50?ooo`@00000o`3ooom`0?ooo`00:`3oool0
0`000000oooo0?ooo`3o0?ooool0oooon@3oool002/0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ooT0oooo000[0?ooo`030000003oool0oooo0?l0ooooo`3ooooi0?ooo`00:`3oool00`000000oooo
0?ooo`3o0?ooool0oooon@3oool002/0oooo00<000000?ooo`3oool0o`3ooooo0?ooooT0oooo000[
0?ooo`030000003oool0oooo0?l0ooooo`3ooooi0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oo
ool0oooon@3oool002/0oooo00<000000?ooo`3oool0o`3ooooo0?ooooT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 804.75}, {497, 0}} -> {3.28594*^-6, -375.43, \
3.20386*^-10, 16.8105}},
  CellTags->"Laser Radar Example"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1174}},
WindowSize->{1152, 1116},
WindowMargins->{{13, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Laser Radar Example"->{
    Cell[1776, 53, 73, 1, 56, "Section",
      CellTags->"Laser Radar Example"],
    Cell[1874, 58, 85, 1, 46, "Subsection",
      CellTags->"Laser Radar Example"],
    Cell[1984, 63, 85, 1, 42, "Subsubsection",
      CellTags->"Laser Radar Example"],
    Cell[2072, 66, 107, 1, 30, "Text",
      CellTags->"Laser Radar Example"],
    Cell[2182, 69, 74, 1, 27, "Input",
      CellTags->"Laser Radar Example"],
    Cell[2259, 72, 106, 1, 27, "Input",
      CellTags->"Laser Radar Example"],
    Cell[2368, 75, 836, 27, 297, "Input",
      CellTags->{
      "genetic building-blocks", "creating new components", "Resonate", 
        "using LensSurface", "optical fibers", "Laser Radar Example"}],
    Cell[3241, 107, 74, 1, 28, "Subsubsection",
      CellTags->"Laser Radar Example"],
    Cell[3318, 110, 346, 7, 57, "Input",
      CellTags->"Laser Radar Example"],
    Cell[3667, 119, 223, 5, 42, "Input",
      CellTags->"Laser Radar Example"],
    Cell[3893, 126, 328, 6, 57, "Input",
      CellTags->"Laser Radar Example"],
    Cell[4224, 134, 542, 9, 87, "Input",
      CellTags->"Laser Radar Example"],
    Cell[4769, 145, 241, 5, 42, "Input",
      CellTags->"Laser Radar Example"],
    Cell[5047, 155, 80, 1, 28, "Subsubsection",
      CellTags->"Laser Radar Example"],
    Cell[5130, 158, 68, 1, 27, "Input",
      CellTags->"Laser Radar Example"],
    Cell[5201, 161, 716, 21, 237, "Input",
      CellTags->"Laser Radar Example"],
    Cell[5920, 184, 85, 1, 27, "Input",
      CellTags->"Laser Radar Example"],
    Cell[6008, 187, 2833, 90, 1272, "Input",
      CellTags->"Laser Radar Example"],
    Cell[8878, 282, 81, 1, 28, "Subsubsection",
      CellTags->"Laser Radar Example"],
    Cell[8962, 285, 69, 1, 27, "Input",
      CellTags->"Laser Radar Example"],
    Cell[9034, 288, 699, 20, 222, "Input",
      CellTags->"Laser Radar Example"],
    Cell[9736, 310, 86, 1, 27, "Input",
      CellTags->"Laser Radar Example"],
    Cell[9825, 313, 831, 27, 357, "Input",
      CellTags->"Laser Radar Example"],
    Cell[10693, 345, 95, 1, 28, "Subsubsection",
      CellTags->"Laser Radar Example"],
    Cell[10791, 348, 354, 7, 57, "Input",
      CellTags->"Laser Radar Example"],
    Cell[11182, 360, 93, 1, 28, "Subsubsection",
      CellTags->"Laser Radar Example"],
    Cell[11278, 363, 81, 1, 27, "Input",
      CellTags->"Laser Radar Example"],
    Cell[11362, 366, 1014, 38, 552, "Input",
      CellTags->"Laser Radar Example"],
    Cell[12425, 410, 65, 1, 30, "Subsection",
      CellTags->"Laser Radar Example"],
    Cell[12515, 415, 324, 9, 87, "Input",
      CellTags->"Laser Radar Example"],
    Cell[12842, 426, 1049943, 27103, 1272, 230535, 16982, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Laser Radar Example"],
    Cell[1062788, 27531, 104, 2, 27, "Output",
      CellTags->"Laser Radar Example"],
    Cell[1062907, 27536, 443, 11, 50, "Text",
      CellTags->"Laser Radar Example"],
    Cell[1063353, 27549, 1269, 31, 342, "Input",
      CellTags->"Laser Radar Example"],
    Cell[1064647, 27584, 208, 7, 87, "Input",
      CellTags->"Laser Radar Example"],
    Cell[1064858, 27593, 529, 8, 43, "Output",
      CellTags->"Laser Radar Example"],
    Cell[1065402, 27604, 184, 5, 32, "Text",
      CellTags->"Laser Radar Example"],
    Cell[1065611, 27613, 141, 4, 27, "Input",
      CellTags->"Laser Radar Example"],
    Cell[1065755, 27619, 4016576, 115674, 484, 3916372, 114432, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->"Laser Radar Example"],
    Cell[5082346, 143296, 485, 8, 50, "Text",
      CellTags->"Laser Radar Example"],
    Cell[5082856, 143308, 411, 10, 102, "Input",
      CellTags->"Laser Radar Example"],
    Cell[5083270, 143320, 4294692, 113923, 2683, 3236615, 100855, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->"Laser Radar Example"],
    Cell[9377965, 257245, 103, 2, 27, "Output",
      CellTags->"Laser Radar Example"],
    Cell[9378083, 257250, 877, 16, 86, "Text",
      CellTags->"Laser Radar Example"],
    Cell[9378985, 257270, 397, 10, 102, "Input",
      CellTags->"Laser Radar Example"],
    Cell[9379385, 257282, 74739, 2012, 298, 26305, 1409, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Laser Radar Example"],
    Cell[9454127, 259296, 103, 2, 27, "Output",
      CellTags->"Laser Radar Example"],
    Cell[9454245, 259301, 416, 9, 50, "Text",
      CellTags->"Laser Radar Example"],
    Cell[9454664, 259312, 128, 4, 32, "Text",
      CellTags->"Laser Radar Example"],
    Cell[9454817, 259320, 125, 4, 27, "Input",
      CellTags->"Laser Radar Example"],
    Cell[9454945, 259326, 104, 2, 27, "Output",
      CellTags->"Laser Radar Example"],
    Cell[9455086, 259333, 73, 1, 27, "Input",
      CellTags->"Laser Radar Example"],
    Cell[9455162, 259336, 81723, 2245, 506, 29051, 1590, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Laser Radar Example"]},
  "genetic building-blocks"->{
    Cell[2368, 75, 836, 27, 297, "Input",
      CellTags->{
      "genetic building-blocks", "creating new components", "Resonate", 
        "using LensSurface", "optical fibers", "Laser Radar Example"}]},
  "creating new components"->{
    Cell[2368, 75, 836, 27, 297, "Input",
      CellTags->{
      "genetic building-blocks", "creating new components", "Resonate", 
        "using LensSurface", "optical fibers", "Laser Radar Example"}]},
  "Resonate"->{
    Cell[2368, 75, 836, 27, 297, "Input",
      CellTags->{
      "genetic building-blocks", "creating new components", "Resonate", 
        "using LensSurface", "optical fibers", "Laser Radar Example"}]},
  "using LensSurface"->{
    Cell[2368, 75, 836, 27, 297, "Input",
      CellTags->{
      "genetic building-blocks", "creating new components", "Resonate", 
        "using LensSurface", "optical fibers", "Laser Radar Example"}]},
  "optical fibers"->{
    Cell[2368, 75, 836, 27, 297, "Input",
      CellTags->{
      "genetic building-blocks", "creating new components", "Resonate", 
        "using LensSurface", "optical fibers", "Laser Radar Example"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Laser Radar Example", 9537524, 261601},
  {"genetic building-blocks", 9542471, 261715},
  {"creating new components", 9542708, 261720},
  {"Resonate", 9542930, 261725},
  {"using LensSurface", 9543161, 261730},
  {"optical fibers", 9543389, 261735}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 73, 1, 56, "Section",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{
Cell[1874, 58, 85, 1, 46, "Subsection",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{
Cell[1984, 63, 85, 1, 42, "Subsubsection",
  CellTags->"Laser Radar Example"],
Cell[2072, 66, 107, 1, 30, "Text",
  CellTags->"Laser Radar Example"],
Cell[2182, 69, 74, 1, 27, "Input",
  CellTags->"Laser Radar Example"],
Cell[2259, 72, 106, 1, 27, "Input",
  CellTags->"Laser Radar Example"],
Cell[2368, 75, 836, 27, 297, "Input",
  CellTags->{
  "genetic building-blocks", "creating new components", "Resonate", 
    "using LensSurface", "optical fibers", "Laser Radar Example"}]
}, Closed]],

Cell[CellGroupData[{
Cell[3241, 107, 74, 1, 28, "Subsubsection",
  CellTags->"Laser Radar Example"],
Cell[3318, 110, 346, 7, 57, "Input",
  CellTags->"Laser Radar Example"],
Cell[3667, 119, 223, 5, 42, "Input",
  CellTags->"Laser Radar Example"],
Cell[3893, 126, 328, 6, 57, "Input",
  CellTags->"Laser Radar Example"],
Cell[4224, 134, 542, 9, 87, "Input",
  CellTags->"Laser Radar Example"],
Cell[4769, 145, 241, 5, 42, "Input",
  CellTags->"Laser Radar Example"]
}, Closed]],

Cell[CellGroupData[{
Cell[5047, 155, 80, 1, 28, "Subsubsection",
  CellTags->"Laser Radar Example"],
Cell[5130, 158, 68, 1, 27, "Input",
  CellTags->"Laser Radar Example"],
Cell[5201, 161, 716, 21, 237, "Input",
  CellTags->"Laser Radar Example"],
Cell[5920, 184, 85, 1, 27, "Input",
  CellTags->"Laser Radar Example"],
Cell[6008, 187, 2833, 90, 1272, "Input",
  CellTags->"Laser Radar Example"]
}, Closed]],

Cell[CellGroupData[{
Cell[8878, 282, 81, 1, 28, "Subsubsection",
  CellTags->"Laser Radar Example"],
Cell[8962, 285, 69, 1, 27, "Input",
  CellTags->"Laser Radar Example"],
Cell[9034, 288, 699, 20, 222, "Input",
  CellTags->"Laser Radar Example"],
Cell[9736, 310, 86, 1, 27, "Input",
  CellTags->"Laser Radar Example"],
Cell[9825, 313, 831, 27, 357, "Input",
  CellTags->"Laser Radar Example"]
}, Closed]],

Cell[CellGroupData[{
Cell[10693, 345, 95, 1, 28, "Subsubsection",
  CellTags->"Laser Radar Example"],
Cell[10791, 348, 354, 7, 57, "Input",
  CellTags->"Laser Radar Example"]
}, Closed]],

Cell[CellGroupData[{
Cell[11182, 360, 93, 1, 28, "Subsubsection",
  CellTags->"Laser Radar Example"],
Cell[11278, 363, 81, 1, 27, "Input",
  CellTags->"Laser Radar Example"],
Cell[11362, 366, 1014, 38, 552, "Input",
  CellTags->"Laser Radar Example"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12425, 410, 65, 1, 30, "Subsection",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{
Cell[12515, 415, 324, 9, 87, "Input",
  CellTags->"Laser Radar Example"],
Cell[12842, 426, 1049943, 27103, 1272, 230535, 16982, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Laser Radar Example"],
Cell[1062788, 27531, 104, 2, 27, "Output",
  CellTags->"Laser Radar Example"]
}, Open  ]],
Cell[1062907, 27536, 443, 11, 50, "Text",
  CellTags->"Laser Radar Example"],
Cell[1063353, 27549, 1269, 31, 342, "Input",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{
Cell[1064647, 27584, 208, 7, 87, "Input",
  CellTags->"Laser Radar Example"],
Cell[1064858, 27593, 529, 8, 43, "Output",
  CellTags->"Laser Radar Example"]
}, Open  ]],
Cell[1065402, 27604, 184, 5, 32, "Text",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{
Cell[1065611, 27613, 141, 4, 27, "Input",
  CellTags->"Laser Radar Example"],
Cell[1065755, 27619, 4016576, 115674, 484, 3916372, 114432, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Laser Radar Example"]
}, Open  ]],
Cell[5082346, 143296, 485, 8, 50, "Text",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{
Cell[5082856, 143308, 411, 10, 102, "Input",
  CellTags->"Laser Radar Example"],
Cell[5083270, 143320, 4294692, 113923, 2683, 3236615, 100855, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Laser Radar Example"],
Cell[9377965, 257245, 103, 2, 27, "Output",
  CellTags->"Laser Radar Example"]
}, Open  ]],
Cell[9378083, 257250, 877, 16, 86, "Text",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{
Cell[9378985, 257270, 397, 10, 102, "Input",
  CellTags->"Laser Radar Example"],
Cell[9379385, 257282, 74739, 2012, 298, 26305, 1409, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Laser Radar Example"],
Cell[9454127, 259296, 103, 2, 27, "Output",
  CellTags->"Laser Radar Example"]
}, Open  ]],
Cell[9454245, 259301, 416, 9, 50, "Text",
  CellTags->"Laser Radar Example"],
Cell[9454664, 259312, 128, 4, 32, "Text",
  CellTags->"Laser Radar Example"],

Cell[CellGroupData[{
Cell[9454817, 259320, 125, 4, 27, "Input",
  CellTags->"Laser Radar Example"],
Cell[9454945, 259326, 104, 2, 27, "Output",
  CellTags->"Laser Radar Example"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9455086, 259333, 73, 1, 27, "Input",
  CellTags->"Laser Radar Example"],
Cell[9455162, 259336, 81723, 2245, 506, 29051, 1590, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Laser Radar Example"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

