(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     58288,       1891]*)
(*NotebookOutlinePosition[     60064,       1948]*)
(*  CellTagsIndexPosition[     59989,       1942]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Neon Tube", "SubsectionIcon"],

Cell["Model a neon tube", "ObjectName",
  GeneratedCell->False,
  CellTags->"NeonTube"],

Cell["\<\
To model a neon light tube, we combine three sources:
1) The distribution along the tube is represented by LineOfRays
2) Around the diameter we get with WedgeOfRays
3) To get the stray behavior, we add PointOfRays\
\>", "ExampleText",
  GeneratedCell->False,
  FormatType->InputForm,
  CellTags->"NeonTube"],

Cell["\<\
The innermost source is PointOfRays with a divergence of 10 degree.\
\
\>", "ExampleText",
  GeneratedCell->False,
  FormatType->InputForm,
  CellTags->"NeonTube"],

Cell["pointsource = PointOfRays[10];", "Input",
  CellLabel->"In:= ",
  GeneratedCell->False,
  FormatType->InputForm,
  CellTags->"NeonTube"],

Cell["\<\
One turn round the tube yields one \"slice\". A full trip of 360 \
degree would double the first point source.\
\>", "ExampleText",
  GeneratedCell->False,
  FormatType->InputForm,
  CellTags->"NeonTube"],

Cell["\<\
slicesource = WedgeOfRays[pointsource, 360-360/5, NumberOfRays -> \
5];\
\>", "Input",
  CellLabel->"In:= ",
  GeneratedCell->False,
  FormatType->InputForm,
  CellTags->"NeonTube"],

Cell["\<\
This \"slice\" lies in the xy plane. To get it in the yz plane, we \
rotate it at the origin, i. e. translation {0,0,0} combined with correct \
orientation.\
\>", "ExampleText",
  GeneratedCell->False,
  FormatType->InputForm,
  CellTags->"NeonTube"],

Cell["\<\
tubeslice = Move[
\tMove[
\t\tslicesource, 
\t\t{0, 0, 0}, {0, 0, 1}
\t]
,
\t{0, 0, 0}, {0, 1, 0}
];\
\>", "Input",
  CellLabel->"In:= ",
  GeneratedCell->False,
  FormatType->InputForm,
  CellTags->"NeonTube"],

Cell["Finally we distribute these \"slices\" along the tube.", "ExampleText",
  GeneratedCell->False,
  FormatType->InputForm,
  CellTags->"NeonTube"],

Cell["lighttube = LineOfRays[tubeslice, 50, NumberOfRays -> 5];", "Input",
  CellLabel->"In:= ",
  GeneratedCell->False,
  FormatType->InputForm,
  CellTags->"NeonTube"],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{
\tlighttube,
\tBoundary[{-100,-100,-100},{100,100,100}]
}];\
\>", "Input",
  CellLabel->"In:= ",
  GeneratedCell->False,
  CellTags->"NeonTube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.1078 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0682898 1.1142 1.65232e-16 1.1142 [
[ 0 0 0 0 ]
[ 1 1.1078 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07708 .27905 m
0 .98202 L
s
0 .98202 m
.17874 1.1078 L
s
.17874 1.1078 m
.22462 .4295 L
s
.22462 .4295 m
.07708 .27905 L
s
.80248 0 m
.91631 .18547 L
s
.91631 .18547 m
1 .90232 L
s
1 .90232 m
.86933 .74088 L
s
.86933 .74088 m
.80248 0 L
s
.07708 .27905 m
0 .98202 L
s
0 .98202 m
.86933 .74088 L
s
.86933 .74088 m
.80248 0 L
s
.80248 0 m
.07708 .27905 L
s
.22462 .4295 m
.91631 .18547 L
s
.91631 .18547 m
1 .90232 L
s
1 .90232 m
.17874 1.1078 L
s
.17874 1.1078 m
.22462 .4295 L
s
0 0 m
1 0 L
1 1.1078 L
0 1.1078 L
closepath
clip
newpath
0 0 0 r
2 Mabswid
.29739 .41289 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.29739 .41289 L
s
0 0 0 r
2 Mabswid
.2989 .39926 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.2989 .39926 L
s
0 0 0 r
2 Mabswid
.27374 .38779 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.27374 .38779 L
s
0 0 0 r
2 Mabswid
.30041 .38595 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.30041 .38595 L
s
0 0 0 r
2 Mabswid
.28089 .38001 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.28089 .38001 L
s
0 0 0 r
2 Mabswid
.3205 .37881 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.3205 .37881 L
s
0 0 0 r
2 Mabswid
.27513 .37386 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.27513 .37386 L
s
0 0 0 r
2 Mabswid
.26057 .37381 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.26057 .37381 L
s
0 0 0 r
2 Mabswid
.33958 .37203 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.33958 .37203 L
s
0 0 0 r
2 Mabswid
.24958 .36215 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.24958 .36215 L
s
0 0 0 r
2 Mabswid
.27652 .36026 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.27652 .36026 L
s
0 0 0 r
2 Mabswid
.25672 .35419 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.25672 .35419 L
s
0 0 0 r
2 Mabswid
.29676 .35296 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.29676 .35296 L
s
0 0 0 r
2 Mabswid
.25084 .34791 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.25084 .34791 L
s
0 0 0 r
2 Mabswid
.23611 .34785 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.23611 .34785 L
s
0 0 0 r
2 Mabswid
.31598 .34603 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.31598 .34603 L
s
0 0 0 r
2 Mabswid
.22488 .33593 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.22488 .33593 L
s
0 0 0 r
2 Mabswid
.2521 .334 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.2521 .334 L
s
0 0 0 r
2 Mabswid
.23202 .3278 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.23202 .3278 L
s
0 0 0 r
2 Mabswid
.27249 .32654 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.27249 .32654 L
s
0 0 0 r
2 Mabswid
.226 .32137 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.226 .32137 L
s
0 0 0 r
2 Mabswid
.21111 .32131 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.21111 .32131 L
s
0 0 0 r
2 Mabswid
.29186 .31946 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.29186 .31946 L
s
0 0 0 r
2 Mabswid
.19963 .30912 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.19963 .30912 L
s
0 0 0 r
2 Mabswid
.22713 .30715 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.22713 .30715 L
s
0 0 0 r
2 Mabswid
.20676 .30081 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.20676 .30081 L
s
0 0 0 r
2 Mabswid
.24768 .29952 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.24768 .29952 L
s
0 0 0 r
2 Mabswid
.20061 .29424 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.20061 .29424 L
s
0 0 0 r
2 Mabswid
.18555 .29418 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.18555 .29418 L
s
0 0 0 r
2 Mabswid
.26718 .29228 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.26718 .29228 L
s
0 0 0 r
2 Mabswid
.2016 .2797 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.2016 .2797 L
s
0 0 0 r
2 Mabswid
.18092 .2732 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.18092 .2732 L
s
0 0 0 r
2 Mabswid
.22229 .27189 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.22229 .27189 L
s
0 0 0 r
2 Mabswid
.1594 .26642 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.1594 .26642 L
s
0 0 0 r
2 Mabswid
.24195 .26448 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.24195 .26448 L
s
0 0 0 r
2 Mabswid
.77506 .24333 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.77506 .24333 L
s
0 0 0 r
2 Mabswid
.77929 .22906 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.77929 .22906 L
s
0 0 0 r
2 Mabswid
.75524 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.75524 .2144 L
s
0 0 0 r
2 Mabswid
.78372 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.78372 .2142 L
s
0 0 0 r
2 Mabswid
.76469 .20757 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.76469 .20757 L
s
0 0 0 r
2 Mabswid
.80841 .20543 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.80841 .20543 L
s
0 0 0 r
2 Mabswid
.74611 .20107 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.74611 .20107 L
s
0 0 0 r
2 Mabswid
.7594 .19978 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.7594 .19978 L
s
0 0 0 r
2 Mabswid
.83506 .19596 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.83506 .19596 L
s
0 0 0 r
2 Mabswid
.19048 .79164 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.19048 .79164 L
s
0 0 0 r
2 Mabswid
.73495 .18477 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.73495 .18477 L
s
0 0 0 r
2 Mabswid
.76376 .18458 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.76376 .18458 L
s
0 0 0 r
2 Mabswid
.20456 .85447 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.20456 .85447 L
s
0 0 0 r
2 Mabswid
.18939 .80725 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.18939 .80725 L
s
0 0 0 r
2 Mabswid
.19635 .83882 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.19635 .83882 L
s
0 0 0 r
2 Mabswid
.74446 .17779 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.74446 .17779 L
s
0 0 0 r
2 Mabswid
.78867 .1756 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.78867 .1756 L
s
0 0 0 r
2 Mabswid
.18826 .82337 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.18826 .82337 L
s
0 0 0 r
2 Mabswid
.7256 .17113 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.7256 .17113 L
s
0 0 0 r
2 Mabswid
.73904 .16981 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.73904 .16981 L
s
0 0 0 r
2 Mabswid
.81557 .1659 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.81557 .1659 L
s
0 0 0 r
2 Mabswid
.16328 .76863 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.16328 .76863 L
s
0 0 0 r
2 Mabswid
.17895 .82442 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.17895 .82442 L
s
0 0 0 r
2 Mabswid
.71417 .15444 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.71417 .15444 L
s
0 0 0 r
2 Mabswid
.74333 .15424 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.74333 .15424 L
s
0 0 0 r
2 Mabswid
.17743 .83213 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.17743 .83213 L
s
0 0 0 r
2 Mabswid
.16208 .78435 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.16208 .78435 L
s
0 0 0 r
2 Mabswid
.16907 .81625 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.16907 .81625 L
s
0 0 0 r
2 Mabswid
.72374 .14729 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.72374 .14729 L
s
0 0 0 r
2 Mabswid
.76846 .14504 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.76846 .14504 L
s
0 0 0 r
2 Mabswid
.16935 .82548 Mdot
.039 .916 .04 r
.5 Mabswid
.53712 .60982 m
.16935 .82548 L
s
0 0 0 r
2 Mabswid
.16083 .80058 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.16083 .80058 L
s
0 0 0 r
2 Mabswid
.7046 .14047 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.7046 .14047 L
s
0 0 0 r
2 Mabswid
.71819 .13912 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.71819 .13912 L
s
0 0 0 r
2 Mabswid
.7956 .13511 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.7956 .13511 L
s
0 0 0 r
2 Mabswid
.13543 .74508 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.13543 .74508 L
s
0 0 0 r
2 Mabswid
.15125 .80151 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.15125 .80151 L
s
0 0 0 r
2 Mabswid
.69289 .12338 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.69289 .12338 L
s
0 0 0 r
2 Mabswid
.7224 .12317 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.7224 .12317 L
s
0 0 0 r
2 Mabswid
.14965 .80926 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.14965 .80926 L
s
0 0 0 r
2 Mabswid
.13411 .7609 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.13411 .7609 L
s
0 0 0 r
2 Mabswid
.14113 .79314 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.14113 .79314 L
s
0 0 0 r
2 Mabswid
.70251 .11605 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.70251 .11605 L
s
0 0 0 r
2 Mabswid
.74776 .11375 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.74776 .11375 L
s
0 0 0 r
2 Mabswid
.14137 .80244 Mdot
.039 .916 .04 r
.5 Mabswid
.51326 .58378 m
.14137 .80244 L
s
0 0 0 r
2 Mabswid
.13274 .77723 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.13274 .77723 L
s
0 0 0 r
2 Mabswid
.68309 .10906 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.68309 .10906 L
s
0 0 0 r
2 Mabswid
.69683 .10768 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.69683 .10768 L
s
.53712 .60982 m
.54139 .97069 L
s
.53712 .60982 m
.57382 .98032 L
s
.53712 .60982 m
.54298 .95203 L
s
.53712 .60982 m
.50733 .97945 L
s
.53712 .60982 m
.55763 .97551 L
s
.53712 .60982 m
.54219 .96143 L
s
.53712 .60982 m
.52435 .97507 L
s
.53712 .60982 m
.92872 .60579 L
s
.53712 .60982 m
.93958 .60626 L
s
.53712 .60982 m
.91398 .57094 L
s
.53712 .60982 m
.93262 .64192 L
s
.53712 .60982 m
.93421 .60601 L
s
.53712 .60982 m
.92133 .5883 L
s
.53712 .60982 m
.93063 .62348 L
s
0 0 0 r
2 Mabswid
.77516 .10358 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.77516 .10358 L
s
0 0 0 r
2 Mabswid
.1069 .72094 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.1069 .72094 L
s
0 0 0 r
2 Mabswid
.12287 .77803 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.12287 .77803 L
s
0 0 0 r
2 Mabswid
.70096 .09134 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.70096 .09134 L
s
0 0 0 r
2 Mabswid
.12119 .78582 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.12119 .78582 L
s
0 0 0 r
2 Mabswid
.10545 .73687 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.10545 .73687 L
s
0 0 0 r
2 Mabswid
.11251 .76946 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.11251 .76946 L
s
0 0 0 r
2 Mabswid
.68077 .08405 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.68077 .08405 L
s
0 0 0 r
2 Mabswid
.72656 .08169 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.72656 .08169 L
s
0 0 0 r
2 Mabswid
.1127 .77883 Mdot
.039 .916 .04 r
.5 Mabswid
.48881 .5571 m
.1127 .77883 L
s
0 0 0 r
2 Mabswid
.10396 .75331 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.10396 .75331 L
s
0 0 0 r
2 Mabswid
.66105 .07689 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.66105 .07689 L
s
.51326 .58378 m
.51545 .94717 L
s
.51326 .58378 m
.54846 .95706 L
s
.51326 .58378 m
.51678 .92801 L
s
.51326 .58378 m
.48106 .95616 L
s
.51326 .58378 m
.53198 .95212 L
s
.51326 .58378 m
.51613 .93766 L
s
.51326 .58378 m
.49825 .95167 L
s
.51326 .58378 m
.90803 .57744 L
s
.51326 .58378 m
.91929 .57826 L
s
.51326 .58378 m
.89301 .54199 L
s
.51326 .58378 m
.91179 .6138 L
s
.51326 .58378 m
.91372 .57784 L
s
.51326 .58378 m
.9005 .55965 L
s
.51326 .58378 m
.90987 .59524 L
s
0 0 0 r
2 Mabswid
.7542 .07126 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.7542 .07126 L
s
0 0 0 r
2 Mabswid
.07766 .69621 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.07766 .69621 L
s
0 0 0 r
2 Mabswid
.09379 .75398 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.09379 .75398 L
s
0 0 0 r
2 Mabswid
.09202 .7618 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.09202 .7618 L
s
0 0 0 r
2 Mabswid
.07608 .71224 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.07608 .71224 L
s
0 0 0 r
2 Mabswid
.08317 .74519 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.08317 .74519 L
s
0 0 0 r
2 Mabswid
.08332 .75464 Mdot
.039 .916 .04 r
.5 Mabswid
.46374 .52974 m
.08332 .75464 L
s
0 0 0 r
2 Mabswid
.07445 .72879 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.07445 .72879 L
s
.48881 .5571 m
.48881 .92301 L
s
.48881 .5571 m
.52241 .93317 L
s
.48881 .5571 m
.48986 .90332 L
s
.48881 .5571 m
.45409 .93225 L
s
.48881 .5571 m
.50563 .92809 L
s
.48881 .5571 m
.48935 .91324 L
s
.48881 .5571 m
.47144 .92763 L
s
.48881 .5571 m
.88678 .54831 L
s
.48881 .5571 m
.89846 .54951 L
s
.48881 .5571 m
.87146 .51226 L
s
.48881 .5571 m
.8904 .58491 L
s
.48881 .5571 m
.89268 .5489 L
s
.48881 .5571 m
.87909 .53022 L
s
.48881 .5571 m
.88855 .56623 L
s
0 0 0 r
2 Mabswid
.06399 .72932 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.06399 .72932 L
s
0 0 0 r
2 Mabswid
.0532 .72984 Mdot
.039 .916 .04 r
.5 Mabswid
.43802 .50168 m
.0532 .72984 L
s
.46374 .52974 m
.46143 .89818 L
s
.46374 .52974 m
.49565 .90862 L
s
.46374 .52974 m
.46219 .87794 L
s
.46374 .52974 m
.42638 .90768 L
s
.46374 .52974 m
.47856 .9034 L
s
.46374 .52974 m
.46182 .88813 L
s
.46374 .52974 m
.44389 .90293 L
s
.46374 .52974 m
.86494 .51838 L
s
.46374 .52974 m
.87706 .51999 L
s
.46374 .52974 m
.84931 .48171 L
s
.46374 .52974 m
.86841 .55521 L
s
.46374 .52974 m
.87106 .51918 L
s
.46374 .52974 m
.8571 .49998 L
s
.46374 .52974 m
.86664 .53641 L
s
.43802 .50168 m
.43328 .87266 L
s
.43802 .50168 m
.46814 .88339 L
s
.43802 .50168 m
.43374 .85184 L
s
.43802 .50168 m
.39789 .88242 L
s
.43802 .50168 m
.45074 .87803 L
s
.43802 .50168 m
.43352 .86233 L
s
.43802 .50168 m
.41557 .87755 L
s
.43802 .50168 m
.84249 .48762 L
s
.43802 .50168 m
.85507 .48965 L
s
.43802 .50168 m
.82655 .45029 L
s
.43802 .50168 m
.8458 .52468 L
s
.43802 .50168 m
.84885 .48863 L
s
.43802 .50168 m
.8345 .46889 L
s
.43802 .50168 m
.84411 .50576 L
s
0 0 0 r
2 Mabswid
.93958 .60626 Mdot
.93421 .60601 Mdot
.57382 .98032 Mdot
.50733 .97945 Mdot
.55763 .97551 Mdot
.52435 .97507 Mdot
.92872 .60579 Mdot
.91929 .57826 Mdot
.92133 .5883 Mdot
.54139 .97069 Mdot
.91398 .57094 Mdot
.93063 .62348 Mdot
.91372 .57784 Mdot
.54219 .96143 Mdot
.93262 .64192 Mdot
.54846 .95706 Mdot
.48106 .95616 Mdot
.53198 .95212 Mdot
.54298 .95203 Mdot
.49825 .95167 Mdot
.90803 .57744 Mdot
.89846 .54951 Mdot
.9005 .55965 Mdot
.51545 .94717 Mdot
.89301 .54199 Mdot
.90987 .59524 Mdot
.89268 .5489 Mdot
.51613 .93766 Mdot
.91179 .6138 Mdot
.52241 .93317 Mdot
.45409 .93225 Mdot
.50563 .92809 Mdot
.51678 .92801 Mdot
.47144 .92763 Mdot
.88678 .54831 Mdot
.87706 .51999 Mdot
.87909 .53022 Mdot
.48881 .92301 Mdot
.87146 .51226 Mdot
.88855 .56623 Mdot
.87106 .51918 Mdot
.48935 .91324 Mdot
.8904 .58491 Mdot
.49565 .90862 Mdot
.42638 .90768 Mdot
.47856 .9034 Mdot
.48986 .90332 Mdot
.44389 .90293 Mdot
.86494 .51838 Mdot
.85507 .48965 Mdot
.8571 .49998 Mdot
.46143 .89818 Mdot
.84931 .48171 Mdot
.86664 .53641 Mdot
.84885 .48863 Mdot
.46182 .88813 Mdot
.86841 .55521 Mdot
.46814 .88339 Mdot
.39789 .88242 Mdot
.45074 .87803 Mdot
.46219 .87794 Mdot
.41557 .87755 Mdot
.84249 .48762 Mdot
.8345 .46889 Mdot
.43328 .87266 Mdot
.82655 .45029 Mdot
.84411 .50576 Mdot
.43352 .86233 Mdot
.8458 .52468 Mdot
.43374 .85184 Mdot
0 g
.25 Mabswid
.80248 0 m
.91631 .18547 L
s
.91631 .18547 m
1 .90232 L
s
1 .90232 m
.86933 .74088 L
s
.86933 .74088 m
.80248 0 L
s
.07708 .27905 m
0 .98202 L
s
0 .98202 m
.86933 .74088 L
s
.86933 .74088 m
.80248 0 L
s
.80248 0 m
.07708 .27905 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"In:= ",
  GeneratedCell->True,
  ImageSize->{259.75, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400043000180P10`40000100000?ooodA4A6EUIEEE
EC0`<7EeMB0P88T0002908V90000RHT0R@29RJFUYDa<C?l0003o0?oo0000ool0o`3ookjn_UeMGL;2
`W5aLH61P@00PF72PBPXoaPHoeUIogUiocPhomkNonk^olk>ojj^okJfomKFoc0`oe1@ofUYodQ8okjn
oifMooKfog5aoiFEohf=om;BdVUYJ@1U002108400840PA0@4>:Q2021PH610=[JfP3^0>k^003^k^h0
0000kY400;Xd1;;2gP00HH6=^P00XOoof_[BXN;RPL;20>k>465Q03`d93PH6000<000>0P82000VCPP
7000cP00nP3>002I0=jI46D`09U44;YU801m08G>jR2bZ_X@@?nQ06EUooo>c]8PT@1<0?;b0=K2085m
OIVIVF5QHD10@761TCSj=51@nYW>c/[oofFIVBPTKB@TB2PPREU@EGUaJG5mbYf5HC0L/VeeXE1@SA0@
om:fSH5iJBa<C?ook/h00025RHTP831UIEEEohDL:?H`B:ZZoeE4OJieD7U]cTAI_R@TQGemofE4D=jZ
TO[jn]H`A51@m_Y0FI6AodQ8f_KfmP@@210H=5UEi/[>ofe]oifEkR`D?5eMoni0FBPTJHF5ogEeokJj
ol[6nV5UmSPX8:6QnXV9nXV9oh61n_ojcZ5@;?nU0?mm0<K6aP00E@00ZP1E001EE@1EZP1Eo`2Z002Z
E@2ZZP2Zo`3oE@3oZUD005D0EED0ZUD0oeEE05EEZUFZ05FZEEFZZUFZoeGo05GoEEGoZUGoojX00:X0
EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZ[o0:[oEJ[oZZ[oool0EOl0Z_mE0?mEEOmEZ_mEoonZ
0?nZEOnZZ_nZooooEOooZYfMWFe]KJ4PlZj^[WUiNGem_Wfn07fn?7fnOGfn_Wfnoggo07go?7goOGgo
_Wgookh00;h0?;h0OKh0_[h0okhl0;hl?;hlOKhl_[hlool110400<h10P0c0@00c04200030@000381
00390@<00`42038100360@<01P400`01000a0@00a04200T100@00@40<0400<410`0;0@0400410301
002o0@803`4010010@0_0@00_043014100@00@40;`400;T10`0D0@0500410@00;P400;L10P0G0@03
0041008100<00@40:`400;@10`0I0@030041008100<00@40:`400;410`0L0@03004100<100<00@40
:P400:l10P0O0@03004100@100<00@40:@400:`10`0Q0@03004100@100<00@40:@400:X10P0T0@03
004100D100<00@40:0400:L10`0V0@03004100D100<00@40:0400:@10`0Y0@03004100H100<00@40
9`400:810P0]0@03004100H100<00@409P4009l10`0P0@03014100`100<00@401P400`010@0V0@00
W@4200/10P0F0@03]`0100`100<00@401`400`010@0U0@00VP4300h100<A0@403@4200D100<A0@40
30400`010@080@03004102@1002G0@<040400kL10@020@030;L100T100<A00400`400a410@0=0@03
004100P100<00@40904009D10P0C0@034@41008100<A004020400a410@030@034@4100h100<00@40
2@400`010@0S0@00TP4301@100<A0@400`400a410@020@03014100<100>g0@400P400a410@0?0@03
004100T100<00@408`4009010P0G0@034@41008100<A0@400`400a400@020@034@4100<100<A0@40
3`400`010@0:0@0300410281002=0@<060400kL10@030@03]`4100<100Fg0@41]`050@03]`410101
00<00@402`400`010@0Q0@00RP4301/100<A0@400P400a410@030@034@41008100<A0@400P400a41
0@080@034@0100H100<00@402`400`010@0Q0@00R04201d100<A0@400`400a410@020003]`000081
00<A0@400P400kL10@080@034@4000L100<00@4030400`010@0P0@00Q@4301l100<A0@400P402a41
0@4A01414@4A00D100<A0@4020400a410@070@03004100d100<00@407`4008810`0Q0@03]`410081
00`A0@414@4A0A410;L40@034@41008100<04@400`400kL10@090@03004100`100<00@407`400801
0P0T0@034@41008100`A0@414@4A0A414@030@034@4100<100<A00400P400a410@0:0@03004100d1
00<00@407P4007d10`0U0@034@41008100^g0@41]`6g0KL0]`040@034@0000@100Fg0@41]`0=0@03
004100d100<00@407P4007/10P0X0@034@41008100@A0@410Q400`4A0@024@@10Q401@010@4A00@1
00<A0@402`400`010@0>0@03004101d1001h0@<0:@400kL10@020@0;4@410A414@4A]a4010400kLA
0@030@03]`41008100<A0@4030400`010@0?0@03004101`1001e0@<0;0401A410@4A00@10Q400`4A
0@024@<100<A0A4010401A410@4A00X10P030@03004100l100<00@40704007<10P0^0@034@410081
00^g0@41]a414@4A]`030@03]`6g00800P401A410@4A00/100<A00400P400`010@0@0@03004101/1
001`0@<0;`400a410@020@034@4100810Q400`4A4@024@8100P04A414@014@@100<A0@4020400a41
0@030@030041014100<00@406P4006h10P0b0@03]`41008100/A0@414KL1]`6g4@030@054@0A]`40
0P001KL10@6g00D100>g00400`400kL10@030@030041014100<00@406P4006/10`0c0@034@410081
00<A0@400P4011414@424@<10a401@4A0@4A00<100<A0@400`400a4100030@034@4100@100<00@40
4P400`010@0I0@00J04303H100<A0@400P402kL10@6g4@4A]a6g008100DA]`6g4@020003]`410081
00<A00400`400a410@020@03]`4100D100<00@404P400`010@0I0@00IP4203P100<A0@400P400a41
0@020@044@4A0@8A0`444@040A4A4@<100<A0A400`400a410@020@034@4100L100<00@404P400`01
0@0H0@00H`4303X100Fg0@41]`040@074@4A0A414@020@08]a6g0KLA0A430@034@4A00<100<A0@40
0`400a410@070@03004101<100<00@405`4006410P0l0@034@41008100<A0@400P400a414@034@81
00<A0A400Q40104A4A420@044@414@<100<A0@400P400a410@070@805@400`010@0G0@00GP4303h1
00DA0@414@040@06]`6g0KLA0`40216g4KL1]a6g0P401@2g0KL0008100>g0@400P400a410@090@03
004101@100<00@405P4005/10`100@034@41008100<A0@400P424@040A414@8100@A0A410Q400`4A
4@020@074@0A0A414@040@034@4100T100<A00405P400`010@0E0@00F@4204<100Fg0@41]`040@06
4@4A]a6g0P402A414KLA0A6g4@020@08]`414KL101440@03]`41008100<0]`4010400kL00@0F0@03
004101D1001F0@<0A0401A410@4A00@11A40104A0A420@8A00@14A4A0P424@070A414@4A00030@03
4@4100<100<A00400`400a41000H0@03004101@1001C0@<0A`401A410@4A00@100Jg4@4A0A420@09
]`6g0KLA0A6g008100LA0@6g4KLA00@100>g4@0010400a410@020@04]`4101P100<00@4050400541
0P190@054@410A4010454@040A414@810Q40104A4A420@8A00H14A4A01440@034@4000<100<A0@40
0P401A410@4001P10P0E0@00CP4304/100Fg0@41]`030@09]a6g4KL1]`6g0081010A0A6g4@4A0A6g
0KL1]a6g10400a6g0@030@034@4100<100DA0@41000E0@<000<10040504004`10P1=0@054@410A40
10424@060A414@4A0`434@080A4A0A414@454@<10Q450@034@41008100<A0@400P401P010@404@d1
0`040@03004101<100190@<0C`401A410@4A00<100@A]a6g0P400a414@020@0@]a414KL1]`6g4@4A
]a414@8100D04@4A]`030@03]`41008100<A0@4010401@010A4000/10P070@03004101<100160@<0
D@401A410@4A00<11A40104A0A420@DA00D14@4A0@024@030A4A008A0`434@0400414@@100@A0@41
0P020@0400414@T10`090@03004101<100140@80D`401A410@4A00@100Bg4@4A0P400kLA0@020@0@
4KLA0A6g0KL1]`6g4KLA]`<100Rg4@4A0A404@@100>g0@400P401Q410@01]`L10`0=0@0300410181
00110@<0E@401A410@4A00<111420@8A0`424@080A4A0A414@424@040A414@<11140104A0A440@03
4@41008100HA0@4101450@<040400`010@0B0@00?`4205L100Fg0@41]`030@05]`6g4KL00P405A6g
0@4A]a6g4@4A0A414KL1]a6g4@030@074KLA016g4@040@03]`0100<100Fg0@4100030@<04`400`01
0@0B0@00?04305T100DA0@414@030@8A00@14@410Q430@<A00<14@400Q420@HA0`424@060A4A4@4A
0`400a4100030@034@410081100F0@0300410181000i0@<0F`401A410@4A00<100@A0A6g0P400a6g
0@020@08]a414KL1]a420@07]a414@4A]`020@084KLA]`6g4KL40@034@41008100>g0@400P400a40
0@0H0@0300410181000g0@80GP4011410A440@@A0P401Q410@4A0@<A00@14@4A0P464@8100@A0A41
11440@034@0000<100LA0@004@4001T100<00@404P4003@10`1O0@05]`410KL00`401;LA]a420@03
]a41008100@A]a6g0P402a6g0@4A]a6g4@4A008100Ng4KLA]`6g00@100@A0A400P401A40004A0081
00<00@405`400`010@0B0@00<P42068100@A0@4A0`4011414A430@044@410@DA00<14A400`401141
4@424@8100DA0A4A0@034@@10Q40104001440@044@4101T100<00@404P4002l10`1S0@054@410A40
0`40116g4KL20@094@410A414KLA008100Zg0@41]a6g4KLA0P402;L1]`6g4KLA10401;L0]`020@05
]`410KL00`400`010@0G0@0300410181000/0@<0IP4011410A430@@A0P400a410@020@@A0P424@<1
1140104A0A420@<A00<14@400P40100A4A4200030A41008100<A0@400`400`010@0G0@0300410141
000Z0@80J0401KL10@6g008100@A0A6g0`402KL10@6g4KLA]`020@0:4@410A414@4A]`8100PA0A6g
0KLA]`<000Ng4KL1]`2g00@100<A0@400`400`010@0G0@0300410141000W0@<0JP4011410A430@@A
0P400a410@020@@A0P400a410@020@@A00D14@4A0@044@030A4000<100HA0A4A0A440@034@4100@1
00<00@405`400`010@0A0@00904306`100@A0@6g0`401;LA0A420@03]a41008100@A]a6g0P400a6g
0@020@08]a6g4@4A0A420@05]a6g0;L010401a6g4@4A0A400`400a410@050@03004101L100<00@40
4@4002810P1_0@044@414@8100@A0A4A0`4011410@454@8100<A0@400P434@8100@A0A410Q40100A
0A430@8A00D14A414@030@034@4100H100<00@405`400`010@0A0@007`43070100Bg0@4A0`40116g
4KL20@034KL1008100Bg4KLA0P400kL10@020@084KLA]`6g0KL200054KLA0A400`401a6g0KLA0A40
10400kL10@060@03004101L100<00@404@4001d10P090@8050400a400@1@0@054@410A400P424@04
0A410@8A0`444@810Q430@@A00@14@0A0P434@030A4100<10a40104A0A430@034@4100L100<00@40
5`400`010@0A0@006P4300`100<A0@404`400a410@1?0@044@41]`8100PA0A6g4@4A]`<100Fg4@4A
]`020@034@41008100>g4KL00P002Q6g0@4A]`6g0KL30@07]a414KL1]`030@03]`4100P100<00@40
5`400`010@0A0@005`43010100HA0@414@090@034@0100@100<A0@40C@4011410A430@@A0P424@<1
11420@8A0`444@040A414@810a400`4A0@020@034@4A008A00<14@400P400a410@090@03004101L1
00<00@404@4001D10P0D0@054@410A402P400kL10@040@034@4104`100Bg0@4A0P402;LA]a6g0KLA
0`40116g4KL20@094KL10@2g4KLA008100Zg4@41]a414KLA0`401a6g4@4A0A400`400a410@090@03
004101P100<00@40404001<10P0G0@8A0P401A410@0A00H100<A0@400`400a410@1;0@044@414@<1
1140104A0A420@8A00@14A410Q4300040A4A4@810Q420@064@4A4@4A0`424@050A4A0A400`400a41
0@0:0@03004101P100<00@40404001<10P0I0@04]`414@8100<04@401@400kL10@030@03]`4104X1
00@A0@6g0P40216g4KL1]`6g0`402;LA]a410;LA0`40116g4KL20@0:4@410A6g4@4A]`8100LA0A6g
4@4A00<100<A0@402`400`010@0H0@0300410101000C0@03004001T100<A0@400Q420@034@4100@1
00<A0@400`400a410@180@044@414@811A40104A0A420@@A0P024@<100@A0A4A0P424@810Q40104A
4A420@084@4A4@4A0A430@034@4100`100<00@405`400`010@0@0@004`4010010@0H0@060;L10@2g
0P400a410@040@03]`4100<100>g4@40A`401;L10A420@08]a6g4@4A0A430@084KLA]`6g0KL30@03
]a6g008100<A]`400P401[LA]`6g4@8100Ng4@4A]`6g00<100>g0@403@400`010@0G0@0300410101
000C0@0500410@0060424@040A404@8100<A0@4010400a410@030@8AAP4011410A420@<A00D14A41
4@020@03014A008A0P424@<111420@044@410@<A00<14A400P400a414@024@030A41008100<A0@40
3P400`010@0G0@0300410101000B0@03004100<100<00@405P401Q6g4KL0]`8100<A0@400`400`2g
0@040@03]a4104@100<A0A400P401[LA]a6g4@8100bg000A]a6g4@4A0A430@034KLA008100Zg4@41
]a6g4KLA0P402;L1]a414@4A0P400kL10@0?0@03004101L100<00@404040018100<00@4010400`01
0@0F0@064@4A4@0A0P400a410@030@03014100<10Q540@044@414@810a401@4A4@0A00<11140104A
0A430@<A0`4011410@434@050A4A0A400P434@030A41008100<A0@403`400`010@0G0@0300410101
000B0@03004100D100<00@405P402Q6g4KLA]`6g4KL50@03]`41008100<A]`40@P400kL1]`020@06
4KLA016g0P402a410KLA]a6g4@4A00<100@A]a6g0P402Q410@4A]a414KL20@074@4A]a414@030@03
4@41010100<00@4060400`010@0?0@004P400`010@060@03004101D100<A01401140104A0A440@8A
10424D4100LA0@4A0A40008A00D14@414@020@DA00@14@4A0`434@810Q420@DA00L14@4A0A41008A
00D14@414@0C0@03004101P100<00@403`40018100<00@401`400`010@0E0@0;]`6g4KLA]a6g0KL0
10400a6g0@030@034KL103l100<A0A400P001KLA]`6g008100`A0@414KLA0A6g0KL30@03]a6g00<1
00bg0@41]a6g0KLA0A420@05]a6g0KL00P400a410@0B0@03004101P100<00@403`40018100<00@40
20400`010@0E0@HA00D14A414@040@8A10424@03004103/100DA01400@034@8100@A0@4A0P464@81
00<A0@4011420@044@410@<A00<14@400Q420@<A00<14@400P400a410@0B0@03004101P100<00@40
3`40018100<00@402@400`010@0E0@0;]a6g0KLA0A6g0KL010400a410@030@034KL103/100@A006g
0P401A6g4@4A008100Vg0@4A]a6g0KL00P401a410@4A]a400P400kLA0@020@0?4KLA]`6g0KL1]`6g
4@4A008100>g0@404`400`010@0H0@03004100l1000B0@03004100X100<00@405@434@040A4A0@8A
00<14@400`400a400@020@<A>04300034@4A00810a400`4A4@020@034@4100<A00<14A400P400a41
0@034@810Q430@<A00D14A414@020@<A00D14@414@0F0@03004101P100<00@403`40018100<00@40
2`400`010@0E0@0;]a6g4KLA]a6g0KL010400a410@020@03]a4103@10`020@08]`414@4A]a420@04
]`414@8100Jg4KLA0A420@07]`414KLA]`020@0<4KL10A6g4KLA0A6g0P401A6g4@4A008100>g0@40
5P400`010@0G0@03004100l1000B0@03004100`100<00@405@494@030A4100<100<A0@400P424C41
0`050@034@4A00810Q420@8A0P400a410@034@050A410A400`434@810Q430@@A00@14@4A0P444@<1
00<A0@405P400`010@0G0@03004100l1000A0@03004100h100<00@405@402kLA]a6g4KLA]`6g00@1
00<A0@400P400kLA0@0/0@<01`402a410KL1]a6g0KLA008100Vg0@4A]a414KL00P402a410KLA]a41
4@4A008100Bg4KLA0P402KLA0@6g4KL1]`020@034@4101L100<00@405`400`010@0?0@004@400`01
0@0?0@03004101D111400`4A4@024@030A4100<100<A0@400P424BT10`0:0@044@4A0@<A00H14@4A
0A420@@A00D14@414@030@<A0P424@811A400`4A4@020@8A00<14A400P400a410@0H0@03004101P1
00<00@403P40014100<00@4040400`010@0E0@0;]a6g4@0A]`6g4KL010400a410@020@03]a4002D1
0P0<0@03]`6g008100HA]`414KL20@094@41]a6g0KLA008100Zg0@4A]a6g0KLA0`40116g4KL20@08
4@410A6g4KL30@03]`4101P100<00@4060400`010@0>0@004@400`010@0A0@03004101D10Q400`4A
00024@040A4A4@@100@A0@410a4R0@<03P4011414@434@060A414@4A0P434@030A4A008100<A0@40
1140104A0A420@@A0P424@810a401@4A0@4A01/100<00@4060400`010@0>0@004@400`010@0B0@03
004101D100^g4KLA]a6g4KLA]`030@03]a41008100<A]a407P43010100/A0A414KLA0A414@020@08
]`6g4KLA0A430@0:4@41]a6g4KL1]`<100Ng4@4A0A6g008100DA]`6g4@020@03]`4101X100<00@40
60400`010@0>0@004@400`010@0C0@03004101D12a430@8A0`424A/10`0C0@044@4A0@8A00L14@41
4@4A00810a400`4A4@020@034@4100@A00@14@4A0P444@8100@A0@4111420@034@4101/100<00@40
60400`010@0>0@004@400`010@0D0@03004101D100bg4KLA]a6g4KLA]a420@03]a41008100<A]`40
5P4301D100fg0KL1]a6g0KL1]`6g008100HA]a414KL20@0;4@41]a6g0KLA0A400P401kLA]a6g0KL0
0`401KLA]`6g008100<A0@406`400`010@0H0@03004100h1000A0@03004101D100<00@405@434@03
0A4A00@A00@14@410Q430@8A4`4301P10Q40204A4A414@4A0P400a414@024@040A414@8100<A0@40
1A420@034@41008A00D14@414@030@@A0P400a410@0L0@03004101P100<00@403P40014100<00@40
5P400`010@0E0@0<]a6g0KLA]a6g4@4A0P400kLA0@020@044KL000h10P0J0@084@4A0A6g0KL20@03
4@4A008100Jg4KL1]a420@0;]`414KLA0A6g0KL00P40116g4KL20@084@410A6g4KL20@034@4101d1
00<00@4060400`010@0>0@0040400`010@0H0@03004101@100D04A4A00064@040A410@8A0P434@03
004100T10`0L0@8A00<14A400Q420@054@414@400a40104A0A420@034@4A008A00D14A414@020@DA
00<14A400P434@040A414B4100<00@405`400`010@0>0@0040400`010@0I0@03004101@100d0]a6g
4KLA]a6g4@4A008100Ng4@41]a6g00P10`0N0@08]`6g0KLA0A420@03]`6g008100HA]`6g0KL20@08
4@41]a6g0KL20@074@41]a414@020@08]`410KLA]a420@03]`4101l100<00@4060400`010@0=0@00
40400`010@0J0@03004101D12Q400`4A0@034@810a440@<0804011414@424@050A410A400P400a41
4@034@8100<A0A400P434@050A410A400P454@030A41008111420@034@41020100<00@4060400`01
0@0=0@0040400`010@0K0@03004101D1012g4KLA]a6g4KLA0A414KLA0P400kLA]`0302<100LA0A6g
4KLA00<100/A0A414KLA0A414@020@05]`414KL00P4011410KL20@074KLA]`6g4@020@07]a6g0KL1
]`0S0@03004101P100<00@403@40010100<00@4070400`010@0D0@034@0A00PA00<14@400Q420@03
014A02D100@A0A410a430@034@4A00810Q401`4A0@4A0A400P434@050A410A400P424@030A4A008A
0`444@8100<A0@408@400`010@0H0@03004100d1000@0@03004101d100<00@4050404A414KLA]a6g
4KLA0A414KL0008100>g4@408`401kLA0A6g0KL00`402;L1]`6g4KLA0P402kL10A414KLA0A6g0081
00XA0A6g4KLA0A6g0P40116g4KL20@034@41028100<00@4060400`010@0=0@0040400`010@0N0@03
004101@12a400`0A0@024@810a4R0@034@4A00@A0`4011414@434@070A410A414@020@8A00<14A40
0P400a410@034@040A4A4@<10Q40104A0A4U0@03004101P100<00@403@40010100<00@407`400`01
0@0E0@0?]a6g4KLA]a6g4KLA0A6g008100<A]a408@401Q6g0KLA]`@100PA0A414KL1]`8100dA0@6g
0KLA]`6g4@4A008100Rg4KLA]a414@8100Jg4KLA0A4V0@03004101P100<00@403@40010100<00@40
80400`010@0E0@`A00<14A400P434Al100<A0A400a440@044@4A0@@A0`4011414@434@030A4A0081
00<A0A400a40104A0A420@@A0P400a410@0T0@03004101P100<00@403@40010100<00@408@400`01
0@0C0@8000ng4KLA]a6g4KLA]a414KL00P400a6g4@0N0@06]a6g4@4A10401kL1]a6g4KL00`400kL1
]`020@084KL1]`6g0KL20@084KLA0A6g0KL20@064KL1]`6g9`400`010@0H0@03004100d1000?0@03
004102<100<00@403`43008100<04@402Q400`4A4@020@8A7@424@040A4A4@@100@A0A410Q400`4A
0@020@044@4A0@<A00<14A400P400a414@034@040A414@8111400`4A0@0W0@03004101T100<00@40
304000l100<00@4090400`010@0;0@<01@404KL0]a6g4KLA]a6g4KLA0A6g008100<A]`406`401A6g
4KLA00D100LA]`6g4KLA00<100dA0A414KLA0A414@4A008100Ng4KL1]`6g008100HA]a6g0KLZ0@03
004101P100<00@40304000l100<00@409@400`010@080@802@400a410@0>4@040A4A4AX111400`4A
0@030@044@4A0@<A104011414@424@040A414@8100<A0A400Q401@4A4@4A00810a420@034@4102P1
00<00@4060400`010@0<0@003`400`010@0V0@03004100@10`0<0@0E]a414KLA]a6g4KLA]`6g4KL1
]a6g01T100Fg4KLA]`050@06]a414KLA10402;L1]`6g4KLA0P403;L1]`6g4KLA0A414@8100Jg4KLA
0A4[0@03004101P100<00@40304000l100<00@409`400`010@03014100<A0A402A401@4A4A4100<A
5`454@D100<A0A4011440@044@4A0@8A00H14@4A0A420@<A00H14A414@444@030A4102/100<00@40
60400`010@0<0@003`400`010@0X0@805@4051414KLA]a6g4KLA]a6g4KL1]a6g5P40116g4KL60@06
4KL1]a6g104021414@4A]`6g0P4031414@4A]a414KL1]`8100<A]a400P400kL10@0Z0@03004101P1
00<00@40304000l100<00@40:0400`010@0E0@034@4A00dA00<14A405@454@D10Q40104A4A450@8A
00<14A400Q420@044@4A0@<A0P424@030A4100@A00<14@40;0400`010@0H0@03004100`1000?0@03
004102P100<00@405P404a6g0KLA]a6g4KLA]a6g4KL1]a4050401;LA]a460@06]a6g4@4A10401kL1
]`6g4KL00`403;L1]`6g4KL1]a414@8100Fg4KL1]`0^0@03004101P100<00@40304000l100<00@40
:0400`010@0H0@034@4A00lA4P444@H10Q40104A4A450@8A00D14A414@020@044@4A0@<A00<14@40
0Q420@<A00<14@40;P400`010@0H0@03004100`1000?0@03004102P100<00@406@404[L1]a6g4KLA
]a6g4KLA]a6g4A0100Bg4KLA1`401A6g4KLA00D100LA0A6g4KLA00<101<A0A414KL1]`6g0KL1]a6g
4@4A02l100<00@406@400`010@0;0@003P400`010@0Y0@03004101X100<A0A403a4?0@@A1P454@H1
0Q40104A4A430@044@4A0@<A00D14A414@020@<A00<14@40:0434@800P400`010@0I0@03004100/1
000>0@03004102T100<00@406`404[LA0A6g4KLA]a6g4KLA]a6g4@d100@A]a6g1P401Q414KLA]`D1
00Ng0KLA]`6g008101<A0A414KLA0A414@4A0A6g4@4A028100Rg4KLA]a6g4@@100@00@406`400`01
0@0;0@003P400`010@0Y0@03004101d100<A0A403A4=0@<A1`454@D100LA0A414@4A00<100@A0A41
0Q401`4A0A414@401A4K0@PA40400`010@0H0@03004100/1000>0@03004102P100<00@407`404141
4KLA]a6g4KLA]a6g4KL;0@03]a6g00L100Fg4KLA]`060@064KL1]a6g0`402;L1]`6g4KLA0P402KL1
]`6g4KL1]`0D0@074KLA]a6g4@0H0@03004101P100<00@402`4000h100<00@40:0400`010@0P0@03
4@4A00dA2P434@L111460@034@4A00<A10400a414@034@070A414@4A0@034@030A4100`1214O0@03
004101P100<00@402`4000h100<00@40:0400`010@0Q0@0@4@4A]a6g4KLA]a6g4KLA]`P100<A]a40
1`401A6g4KLA00H100Jg4@4A0A430@084@4A0A6g0KL20@084KL10A6g4KL60@084KLA]a6g4KLN0@06
4KLA]a6g0P000`400@0I0@03004100/1000>0@03004102P100<00@408P424@030A4A00/A1`424@P1
11460@034@4A00<A10400a414@044@8100@A0A412a4I0@dA1`400`01000J0@03004100/1000>0@03
004102P100<00@4090403kL1]a6g4KLA]a6g4KLA]`050@03]a4100L100Bg4KLA1`401A6g4KLA00@1
00Ng0KL1]a6g00<100Rg4KLA]a6g4A@100bg4KLA]a6g4KLA]a4F0@03004101T100<00@402P4000h1
00<00@40:0400`010@0U0@034@4A00HA00<14A400Q450@8A20434@L100<A0A400Q450@XA00<14@40
11480@dA80424@<06@400`010@0:0@003@400`010@0Y0@03004102H100jg0KLA]a6g4KL1]a6g4@<1
00<A]`401`40116g4KL70@0@]a6g4KLA]a6g4KLA]a6g4@<1010A]`6g4KLA]a6g4KLA]a6g9@402KLA
]a6g4KLA0@0200030@0101P100<00@402P4000d100<00@40:@400`010@0W0@TA00<14A400Q420@03
4@4100L10a450@LA1@4?4@030A4102D14Q4401P100<00@402P4000d100<00@40:@400`010@0Y0@0>
4@4A]a6g4KLA]a6g4KL90@0K]a6g4KLA]a6g4KLA]a6g4KLA]a6g0KLA]`6g00<100Ng4@4A]`6g00@1
02HA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]`l100@00@0060400`010@0:0@00
3@400`010@0Y0@03004102X100<A0A402Q420C8A4P484AT100<00@406@400`010@0:0@003@400`01
0@0Y0@03004102/102DA0A6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA00<100HA0A6g
4KL40@064KL1]a6g4P40216g4KLA]a6g7P401Q6g4@0A]`805`400`010@0:0@003@400`010@0Y0@03
004102`131460DHA2P4=4@810`020@03004101D100<00@402P4000d100<00@40:@400`010@0^0@0;
]`6g4KLA]a6g4KL01@400kLA0@080@034KLA00@101:g4KLA]a6g4KLA]a6g4KLA]a440@07]a6g4KLA
]`0E0@0L]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4@806P400`010@0:0@003@400`010@0Y0@03
004102l12a440@8A20444@H11A440@8A00<14A404a420@dA7@400`014@024@805@400`010@090@00
3@400`010@0X0@03004102h100hA]a6g0KLA]a6g4KLA]`8100<A]`4020400kLA]`060@0?4KLA]a6g
4KLA]a6g4KLA00P101bg4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA5@40216g4KLA]`2g0P4301D1
00<00@402@4000d100<00@40:0400`010@0/0@DA00<14A402A400`4A0@080@<A1@474@@13Q4L0A/A
00<04A400Q4401<100<00@402@4000`100<00@40:@400`010@0[0@04]a6g4@D100XA]a6g4KLA]a6g
2P40616g4KLA]a6g4KLA]a6g4KLA]a6g0KLA]a0102lA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g
4KLA]a6g4KLA]`6g4KLA]a6g4@0200D100<00@004`400`010@090@0030400`010@0Y0@03004102T1
1A470@TA0P4b4@l12A4F0@03004100@10P0C0@03004100T1000<0@03004102T100<00@409`401[LA
]a6g4@P103bg4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA
]a6g4KLA]a480@08]a6g4KLA]a4O0@090;LA]a6g4KL001<100<00@402@4000`100<00@40:@400`01
0@0U0@HA2P4;4@D14Q420@DA4`4_4@04014A4@805P400`010@090@0030400`010@0Y0@03004102<1
00Ng4KLA]a6g00/100bg4KLA]a6g4KLA]a450@034KL100H100Bg4KLA10406[LA]a6g4KLA]a6g4KLA
]a6g0KLA]a6g4KLA4`403a6g4KLA]a6g4KLA]a6g4@0=0@030041008100<00@400`4200l100<00@40
2@4000`100<00@40:@400`010@0R0@LA30444@030A4A00HA0`424@P10a460@@A104T4A`100<00@40
1@444@03004100d100<00@402@4000`100<00@40:@400`010@0P0@074KLA]a6g4@0=0@044KLA]`<1
00Rg4KLA]a6g4@8100>g0@401P400a6g4@060@09]a6g4KLA]a6g00P100hA]a6g4KLA]a6g4KLA]`@1
014A]a6g4KLA]a6g4KLA]a6g4@0D0@0:]a404KLA]a6g0@D03`400`010@080@0030400`010@0Y0@03
004101h11Q400`4A0@0;0@HA10474@030A4100P16Q4S0AHA00<04A401Q40100A000?0@03004100P1
000<0@03004102T100<00@4070402A6g4KLA]a6g4@0;0@084KLA]a6g4KL30@0:]a6g4KLA]a6g4@<1
018A]a6g4KLA]a6g4KLA]a6g4KL30@0i]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA
]a6g4KLA]a6g4KLA]a6g4KLA]a6g00L100Rg4KLA016g4@805P400`010@080@002`400`010@0Z0@03
004101X11A40104A0A4;0@XA0`434@030A4A01dA9P494A@100<00@400P400`0A4@044@803P400`01
0@080@002`400`010@0Z0@03004101P100XA]a6g4KLA]`6g2`401KLA]a6g008100@A]a6g0`400kLA
]`020@064KLA]a6g1@403kLA]a6g4KLA]a6g4KLA]`030@0d]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA
]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4@P100jg4KLA]a6g4@0A]a6g4@L100<00@4030400`01
0@080@002`400`010@0Z0@03004101L100<A0A400Q400`4A0@024@X11Q430@@A0`434@030A4A00HA
1@424@L10a420@lA2@494@l15a400`0A4@064@804@400`010@080@002`400`010@0Z0@03004101D1
00Zg4KLA]a6g4@4A2P401kLA]a6g4KL01040116g4KL30@05]a6g4KL00P401Q6g4KLA]`<100>g4@40
1P400a6g4@0B0@0>]a6g4KLA]a6g4KLA]a450@0>4KLA]a6g4KLA]a6g4KLG0@03004100L100D00KLA
]`0200/100<00@40204000/100<00@40:@400`010@0D0@HA00D14@414@090@LA1P454@8111440@DA
0`400a410@060@<A2@494@D1614K0@03004A00TA10400`010@090@03004100P1000;0@03004102T1
00<00@404P401[LA]a6g4@8100Bg0KLA20402;LA]a6g4KLA1`402Q6g4KLA]a6g4KL50@08]`6g4KLA
0A480@0K]a6g0KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g01P102TA]a6g4KLA]a6g4KLA]a414KLA]a6g
4KLA]a404KLA]a6g4KLA]a6g4@0500T100<00@40204000/100<00@40:@400`010@0@0@8A00<14A40
0Q401@4A4@4A00P11A40104A4A480@XA10434@030A4A00<A0`4A4@@1?Q400`0A4@0<0@8000<10040
2@400`010@070@002`400`010@0Y0@03004100h100Ng4@4A]a6g008100@A0@6g1`402KLA]a6g4KLA
]`0:0@0:4KLA]a6g4KLA]`@100<A]a400P407KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g0241
00Zg4KLA]a6g4KLA4P402@010A6g4KLA]`0200H10P0:0@03004100L1000;0@03004102T100<00@40
3@400a414@044@040A4A0@8A1P424@080A4A4@4A0A4:0@HA0P434@@10a420@DA1@4d4Ad100<00@40
10424@03014A00DA00<00@4020400`010@070@002`400`010@0Y0@03004100/100LA]`6g4KLA0081
00Bg0@4A1`402Q414KLA]`6g4KL90@08]a6g4KLA]a420@03]a6g00@100DA]a6g4@020@04]a6g4@@1
00>g4@4030403Q6g4KLA]a6g4KLA]a6g1040=a6g4KLA]a6g4KL1]a6g4KLA]a6g4KLA]a6g4KLA]a6g
4KLA]a6g4KLA]a6g4KLA]`2g4KLA]a401P4200d100<00@401`4000X100<00@40:P400`010@090@8A
00<14A400Q420@8A0P400a410@040@HA00@14A4A2P494@030A4A00<A0`444@<100@A0A4A10400a41
0@0D0ADA104D4@X10a400`0A4@0;4@03004100/100<00@401`4000X100<00@40:P400`010@070@08
4KL1]a6g4KL20@054@41]a401@401Q6g4KLA]`8100<A0A402@404A6g4KLA]a414KLA0A6g4KLA0081
00Bg4KLA10401KL10A6g008100<A0@402`402Q6g4KLA]a6g4KL50@0O]a6g4KLA]a6g4KLA]a6g4KLA
]a6g4KLA]a6g4KLA]`0F0@03004101T100<00@401`4000X100<00@40:P400`010@050@8A00<14A40
0a420@8A0P400a410@030@8A00<14A400Q400`4A4@024@P12A401@4A4A4100/A10400a410@020@03
4@4A00<16A4E0B0A00<04A403a4500D100<00@401`4000X100<00@40:P400`010@040@08]`414KLA
]a420@05]`410KL010401a6g0KLA]a400P400kL1]`080@0K4KLA]a414KLA]a414KLA0A6g4KLA]a6g
4KLA00@100>g4@400`40J;LA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA
]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a6g0;LA]a6g4KLA]a6g4KLA]a6g4@0A
0P050@03004100L1000:0@03004102X100<00@400P424@030A4A00<A0P424@810Q430@8A00<14A40
0a401@4A4@4A00L12A420@8A00D14A4A0@074@040A4A4@<10a420@<A1@4Q4B`100<00@4010474@80
30400`010@070@002P400`010@0Z0@0;0041]a414KLA]a400`401A410@4A00<100PA]`6g4KLA]`81
00@A0A6g1P402Q6g0KLA]`6g0KL30@0<]a414KLA0A6g4KLA0`400a6g4@030@054KLA]a400P400kL1
0@0?0@0;]a6g4KLA]a6g4KL02P406A6g4KLA]a6g4KLA]a6g4KLA]a6g4KLA]a404`400`010@0<0@03
004100/100<00@401P4000X100<00@40:P400`0A4@020@DA0P424@<100<A0@400Q420@@A0P424@03
0A4100D10Q401@4A4A4100@A10424@030A4A00LA0`434@<111430@034@4101X1314G0A<A00<04A40
114F0@03004100H1000:0@03004102T100Vg4@41]a6g4KL00`402KL10@6g4@4A]`020@054KLA]a40
0P401;L10A450@0;4KL1]a6g4@4A0A401@403A414@4A]a6g4KLA]a400P402[LA]a6g0KLA]a440@03
]`4102H100/A]a6g4KLA]a6g4@0O0@03004100@100bg4KLA]a6g4KLA]a4200P100<00@401P4000X1
00<00@409`424@030@0A00DA0`401A410@4A008100<A0@401A420@8A00<14A4010424@030A4A008A
00<14A400Q460@034@4A00XA0P4:4@@10Q4b0@/A50400`010@0A0@03004100H100<00@401P4000T1
00<00@409`402A410@0A]a414@030@034KL1008100^g0KLA0A6g4KLA]`020@044@41]`D100^g0@4A
]a6g0KL1]`080@0=4KLA]a6g0KLA]a6g4@020@0:]a6g4KLA]a6g4@@100>g4@40?040316g4KLA]a6g
4KLA]`T100<00@406@400`010@060@002@400`010@0U0@8A0P464@<100<A0@400P434@811A430@04
4@414@@10Q400`4A4@024@050A4A0A401`4?4@811Q40104A4A430@<AB@494@03014101T100<00@40
1P4000T100<00@408`402Q6g0@4A]a6g4KL30@03]a41008100<A]a400P401KLA]a6g00<100Fg4@4A
]`030@07]a414KLA]`020@044@4A]`H101PA]a6g4KLA0A6g0KL1]a6g0KLA]a6g4KL20@034KLA00<1
00<A]a40DP403P01]a6g4KLA]a6g4KLA104200P100<00@401P4000T100<00@408@424@8111400`4A
0@030@034@4100810Q420@HA0`4011410A430@8A00<14A400a401@4A4@4A00H13140104A4@4:4@81
0a430@<ADP400`010@0;0@DA00<00@401P400`010@060@002@400`010@0O0@034KL1008100Ng4KLA
]a40008100<A]`400P400kLA0@020@054KLA]a400`401A6g0@4A008100Rg4@41]a6g4@8100Bg0@4A
1P406kL1]a6g0KLA]a414KL1]a414KLA]a6g4KLA]`020@034KLA00<100<A]a40DP400`010@0J0@03
004100D100090@03004101d10Q430@@A00L14@41004A00<10a420@HA0`400a410@024@030A4A0081
1A40104A4@424@D11Q401`4A0A414@400Q400`4A4@0;4@8111420@<ADP400`010@0J0@03004100D1
00090@03004101`100^g0@41]a6g4KLA]`030@07]a410KLA]`020@064KLA]a6g0`402;LA0@6g0KLA
0P401KLA]a6g008100@A0@6g1@407kLA]a6g4@4A]a6g4@4A0A6g4KLA]a6g4KL1]a6g4KL00P40116g
4KL20@034KLA058100<00@406P400`010@050@002@400`010@0J0@8A0`464@@100PA00414@4A0@HA
104011410@434@811A420@8A0P400a410@020@HA0P401a414@4A0A400P454@030A4A008A00<14A40
0a400`4A4@034@810a5B0@03004101X100<00@401@4000T100<00@4060400kLA0@020@064KLA]`6g
10403a6g0@0A]a6g0KLA]a6g4@030@074KL10A6g4@030@054KLA]a400P401KL10A6g00<100bg4@4A
]a6g0KLA0A420@0K]`6g0KLA]a6g4KLA]`6g4@4A]a414KLA]a6g008100<A]a40DP400`010@0J0@03
004100D100090@03004101H10Q430@LA10400a410@024@030A4100HA104011410@424@<11A420@8A
0P4011410@424@030A4A008A0P4011414A430@034@4A00@A00<14A400a40104A4@434@030A4A00@A
0P444E4100<00@406P400`010@050@0020400`010@0E0@03]a41008100LA]a6g4@4A00D100hA0A6g
0@0A]a6g4KLA]`@100DA0@414@030@054KLA]a400`401A410@4A008100fg4@4A]a6g4@4A]`6g00D1
01^g4KLA]a6g4KLA0A6g0KLA]`6g4@4A]a6g4KL00P40116g4KMA0@03004101X100<00@401@4000P1
00<00@4050400a410@020@054@4A4@400Q440@@A0P484@@10Q420@8A0`454@810Q420@8A00@14A41
1A420@044@414@@11Q400`4A4@034@030A4100@A00@14A411Q420@@AD@400`010@0J0@03004100D1
00080@030041018100<A]`400P401kLA]a6g4KL01@400kLA]`030@07]a6g4KLA]`050@05]`414KL0
0`401KLA]a6g00<100Fg0@41]`020@074@41]a6g4@020@05]a414KL00`407kLA0A6g4KLA]a6g0KLA
0A414KLA]`6g4@4A]a6g4KL00P40116g4KMB0@03004101T100<00@401@4000P100<00@4040424@<1
1A400`4A0@040@<A10434@04014A4@@10Q40104A4A420@HA0`400a410@024@040A4A0@DA0P401141
0A430@8A00<14A400Q400`4A0@044@070A414@4A0@024@040A4A0@HA0P444E8100<00@406P400`01
0@040@0020400`010@0>0@034KL100<100LA0A6g0KLA00D100<A]`400`401a6g4KLA]a401@403A41
4KLA]`6g4KLA]a400`403Q6g0@4A0A6g0KLA]a6g0P401A6g0KLA008102>g4@4A]a6g0KLA]a6g4KLA
0A414@4A0A6g0KLA0A6g4KLA]`020@044KLA]e8100<00@406P400`010@040@0020400`010@0<0@8A
10454@030A4100@10Q440@@A00@14A4A10444@040A410@DA104011410@434@030A4A00<A0`401141
0A430@034@4100@A00P14A414@4A0@8A00L14@4A0A41008A00@14A411A400`4A4@044E8100<00@40
6P400`010@040@0020400`010@080@8000<A]`400`40216g4KLA0A6g1@400kLA0@030@08]a6g0KLA
]`040@03]a6g008100PA0A6g4KLA]`<100Ng4@41]a6g008100DA]a6g4@020@05]a410KL00P40416g
0KLA]a414KLA]a6g0KL20@0J4@4A0A414@4A]`6g4@4A]a6g4@4A]a6g4KMB0@03004101X100<00@40
104000P100<00@402@400a410@020@8A00@14A410Q450@8A10474@8100<00@400a420@HA00<14@40
0`4011410@424@811A430@034@41008A00@14A4111420@044@414@8100<A0A400P4021414@4A0A41
0Q40104A4@444@030A4A00DADP400`010@0J0@03004100@100080@03004100d100Ng0KLA]`6g00D1
00>g4@400`402;LA]a414KLA0`4010014KL30@08]a6g4KLA]a430@064KL10A6g0P401Q6g4KLA]`81
00PA]`414@4A]`8100@A]a6g0P401A410KLA008100>g0KL00P406Q414@4A0A414KL1]`6g4KLA]`6g
4KLA0A6gDP400`010@0J0@03004100@100080@03004100/11A400`4A4@040@<A104011414@434@D1
0Q440@LA10400a410@034@030A4A00@A0`4011410@434@8111420@8A00D14A414@020@034@4A0081
00HA0A414@444@030A4100DA00<14A400Q40104A4A5A0@03004101X100<00@40104000L100<00@40
2@402@2g4@4A]a414@040@03]a6g00@100PA]a6g4KLA]`D100>g4@400P401a6g4KLA0A4010401[LA
0@6g4@8100Fg4@4A]`030@07]a410KLA]`020@054KLA]a400P401;L10A430@064@41]`6g0P406a41
4@4A0A6g4KL1]`6g4KLA]`6g4KLA0A6g4@1A0@03004101X100<00@40104000L100<00@402@400a40
4@024@030A4A00<111430@@A00@14A4A1@424@040@010@LA10400a410@034@030A4A00@A0`401141
0@424@811A420@8A0P400a410@020@064@414@4A0P401Q414@4A0@@A00<14@401A400`4A4@024@04
0A4A4E4100<00@406P400`010@040@001`400`010@090@064KLA0A6g0`401;LA0A430@084KL1]a6g
4KL50@03]a6g008100P0]a6g4KL1]`@100dA]`6g4KLA]a6g4KLA00<100<A]`400P402;LA0@6g4KLA
0`401A410KLA00D100HA0@6g0KL20@0K4@4A]a414KLA]`6g0KLA]a6g0KLA]a414KLA054100<00@40
6`400`010@030@001`400`010@080@<A00<14@400`4011400A430@034@4A00DA10434@@111400`4A
4@040@054@4A4@4011400`4A4@040@044@410@8A0P454@810Q420@034@4100D100HA0@4A0A420@8A
00@14A4111400`4A0@054@030A4A008A00@14A4ADP400`010@0J0@03004100<100070@03004100H1
00Jg4KL1]a460@0<]a410KLA]a6g4@4A10401;LA]a430@074KLA]a6g4@040@04]a6g4@8100Ng4KLA
]a6g00<100Jg4@41]a420@05]a6g4KL00`401KL10@6g00P100<A0A400P407[L1]a6g0KLA0A6g0KL1
]`6g4KL1]`6g4KLA0A6g4E8100<00@406P400`010@030@001`400`010@030@04014A4@8000<A0@40
1@400a410@044@030A4A008A0`424@030A4100811A400`4A0@040@<A0P474@@100<A0@400a420@@A
0`424@810Q480@044@414@8100<A0A400Q40104A4@424@050A414@400a400`4A0@044@040A4A4E81
00<00@406P400`010@030@001`400`010@030@074@010@0100050@0<4KL1]a414@4A]a6g0`401KLA
0A6g00<100Ng4KLA0A6g00@100<A]a400`401a6g4@4A]a400`403A6g0KLA]a414KLA]a400`401A41
0@4A00X100Bg0@4A0P407[L1]a6g0KLA0A6g0KL1]`6g4KL1]`6g0KLA0A6g4E8100<00@406P400`01
0@030@001`400`010@0>0@054@404@400Q40104A4A430@8A0P4011410@474@03004100810Q430@<A
00@14A4A10401a414A414@401A430@8A0P424@/100@A0@4A0P400a414@024@040A4A0@8A00D14@4A
0@034@050A414@400Q40104A4A5B0@03004101X100<00@400`4000L100<00@4030400kLA0@020@07
4KL1]a6g4@020@06]a410KLA0P401kLA]a6g0KL00P401@010KLA00@100Jg4KLA]a440@0=]a414@4A
]a6g4KLA]`030@05]`410KL03@401;L10A420@0O]`6g4KL1]a414KL1]`6g0KLA]`6g0KL1]a414KL1
]`1@0@8070400`010@030@001P400`010@0<0@034@01008100<A0@400a420@030141008100<A0@40
1A400`4A4@020@030041008A0`434@040A4A4@@100LA0A4A0A4100DA0`424@<100<A0@4030401141
0A420@034@4A008A00@14A410Q401@4A0A4100<A00<14@4011401@4A4@4A04`110020@03004101T1
00<00@400`4000H100<00@403@402@01]a414KLA]`040@04004A]`8100LA]a6g4@4A00@100<04KL0
0`401kLA]`6g4KL01040116g4KL20@064KLA0A6g10401Q410@4A]`l100Bg0@4A0P407kL1]a6g0KLA
0A414KL1]`6g4KLA]`6g4KLA0A6g0KL0B@4300L100<00@4060400`010@030@001P400`010@0<0@04
014A00@A1`400a410@054@030A4A00@10Q430@LA1@434@811a430@8A0`400a410@0?0@044@414@81
00<A0A400Q401P4A4@4A0@8A00D14@4A0@034@030A4A008A00D14A414@150@@02P400`010@0I0@03
0041008100060@03004100`100LA006g4KL000L100XA0A6g4KLA]a6g1040116g4@020@074KLA0A6g
4@040@03]a6g00<100Jg4KLA]a440@03]`41008100<A0@4040401;L10A420@0O]`6g4KL1]a414@4A
]`6g0KL1]a6g0KLA]a414KL1]`110@@03`400`010@0H0@030041008100060@03004100h100<04@40
1`484@030A4100<111400`404@064@D10Q440@8A00@14A4A104011410@424A<100@A0@4A0P400a41
4@024@060A4A0A410Q401@4A0A4100PA00D14A414@0n0@<050400`010@0G0@030041008100060@03
004100h100<A00401P402[L1]a6g4KLA]a430@044KL1]`8100PA]a6g4KLA]`@100<A]`400`401Q6g
0KLA]`@100<A]`400P400kL10@0B0@054@410A400P407kLA0A6g0KLA0A414@4A]`6g0KLA]a6g4KLA
0A414KL0>P4401P100<00@405P400`010@020@001P400`010@0C0@800Q420@034@4A00<A00<10000
0Q40104A4@484@D10Q430@HA1@400a410@020@034@4101<100DA0@414@020@8A00<14A400P400a41
4@024@060A4A0A4121400`4A0@024CL10`0M0@03004101D100<00@400P4000H100<00@4050402Q41
0KLA]a6g4KL30@04]`414@8100Ng4KLA]a6g00D100>g4@400`401[LA0A6g4@@100>g4@400P400a6g
0@0E0@054@410A400P401KLA0A6g008101PA0A6g4@4A]`6g0KLA0A414KLA0A414KLc0@@080400`01
0@0E0@030041008100060@03004101D111400`0A4@060@8A00D14A4A0@044@@10a430@HA1@400a41
0@020@034@4101H100DA0@414@020@8A00<14A400P400a414@024@060A4A0A410Q402@4A0A414@4A
0@024C010`0U0@03004101@100<00@400P4000H100<00@404`401`0A0A404KL01`402kL1]a6g4@4A
]a4000<100>g4KL00`401kLA]a6g4KL010400a6g0@030@034@4101L100DA0@414@020@05]a414KL0
0P406A414KLA0A6g0KL1]a414@4A0A414@4A0A40:`4402T100<00@404`400`010@020@001@400`01
0@0E0@0400414@L11Q40104A4A420@03004A00<A0`464@D100<A0@400P424AX100DA0@414@020@8A
00<14A400P400a414@024@060A4A0A410Q40304A0A414@4A0A414BP10`0^0@030041018100<00@40
0P4000D100<00@405P400`0A0@060@0:4@4A]a414KLA]`<100Bg4@4A0`401Q6g4KLA]`D100>g4@40
0`400kL10@0J0@044@41]`<100Fg4@4A]`020@0I4@4A]a414KL1]`6g4@4A0A414@4A0A414@0T0@@0
<P400`010@0B0@030041004100050@03004101L100<00@400P400`0A4@020@034@4100<A00<10000
0Q400`0A4@020@LA1@400a410@030@034@4101/100@A0@4A0`424@030A4A00810Q40104A4@424@05
0A414@400Q402P4A0A414@4A0A4P0@@0=`400`010@0A0@030041004100050@03004101`100Zg004A
]`6g4KLA0`4011410KL20@074KLA]a414@050@034KL100<100<A]`407@4011410KL30@04]a414@<1
01TA]`6g4@4A]`6g4KL1]a414KLA0A414@4A01d10`0k0@030041014100<00@400@4000D100<00@40
7@424@030A4A008A1P424@810Q400`4A4@024@D100<A0@400`400a410@0M0@054@410A400`424@03
0A4100810Q40104A4@434@040A4A0@HA00H14@4A0A4I0@@0?`400`010@0@0@030041004100050@03
004101`100Ng000A0A4000H100XA0@2g4KL1]a6g1@400kLA0@040@034@4101h100Fg0@41]`030@04
]a414@<101TA]`6g4@4A]a414KL1]a6g4KLA0A414@4A01H10`140@03004100l100<00@400@4000D1
00<00@407@4010014A460@8A00D04A4A0@034@H100<A0@400`424B4100DA0@414@030@044@414@<1
0Q400`4A4@020@8A00@14A411Q401P4A0A414A8110180@03004100h100<00@400@4000D100<00@40
7P400kL00@050@0:]`414KL0]a6g4@D100<A]`4010400kL10@0Q0@05]`410KL00`401;L10A430@05
4KL1]a400P404[LA0A6g0KLA]a6g4@4A0A414@l10`1=0@03004100d100<00@400@4000D100<00@40
7`401@010@40008A0P400a410@034@H100<A0@4010400a410@0R0@054@410A400`4011410A430@8A
00<14A400P424@040A4A0@DA00D14A414@020@034@4100P1101@0@03004100d100<00@400@4000@1
00<00@4090402Q400KLA0A6g4KL60@034@4100<100<A]`4090401KL10@6g00<100Fg0@4A]`020@05
4KL1]a400P401;LA0A420@0:]a6g4KL1]a414@8100>g0@401@4305D100<00@403@4100410@4000@1
00<00@409@424@03014A008A00<00@400`424@D100<A0@409@401A410@4A00<100<A0@400Q420@8A
00<14@400P424@040A410@DA00D14A414@020@044@410@@0F@400`010@0<0@400@410@0010400`01
0@0T0@094@01]`6g004000@100>g0@4010400a410@0V0@05]`410KL00`401KL10A6g008100@A]`6g
0`401;LA0A420@08]a6g4KL1]a420@03]`4000<0GP400`010@0;0@400@410@0010400`010@0U0@80
0Q430@030041008A1@424BT100DA0@414@030@034@41008A0P424@030A4100810Q40104A0@454@04
0A4A0@<000<A0@40H0400`010@0:0@400@410@0010400`010@0V0@034@0100<100<00A401P400kL1
0@0X0@034@41008100Fg0@41]`020@084KL10A6g0KL30@04]a414@<100@A]a6g1000106g0KMR0@03
004100X10@010@4100040@03004102/100<04A401P400a410@0Y0@034@41008100DA0@414@020@8A
0P424@030A4100810Q400`4A0@020@054@0000400Q420@034@4A06<100<00@402@4100410@4000@1
00<00@40:`400kL00@040@034KL102/100<A0@400P401KL10@6g008100PA]`414KL1]`<100Bg4@4A
10001[LA]`6g4@8100>g0KL0I0400`010@080@400@410@0010400`010@0/0@030041008100<A0@40
;0400a410@020@054@410A400P424@810Q400`4A0@020@044@0000<10Q400`4A0@024@8100<A0A40
I@400`010@070@400@410@0010400`010@0/0@0500410A40;`401A410@4A00<100HA]`414KL20@04
4KL1]`@000<A0A400`401a410KL1]a400P400kL1]`1V0@03004100H10@010@4100040@03004102`1
0P024C0100DA0@414@030@800P424@8100@A00000`424@030A41008100DA0@4A0@024@8100@A0@4A
I@400`010@070@400@4000<100<00@40;0401001]`0a0@054@410A400`401A400@4A00@000>g0KL0
0`401;LA0A430@044@41]`8100@A0@6g0P400a410@1T0@03004100H10@010@000`400`010@0/0@03
0041038100DA0@414@030@D000DA0@4A0@034@810Q400`4A0@020@044@414@8100@A0@4A0P400a41
0@1U0@03004100D10@010@000`400`010@0/0@030041038100HA0@414@44008100TA]`414@4A]a40
0P401;LA0A430@044@41]`8100@A0@6g0P400a410@1V0@03004100@10@010@000`400`010@0/0@03
0041034100<A0@4010020@8A00@14@4A0P400a414@024@810Q400`4A0@020@044@414@810Q401@4A
0@4A06T100<00@400`41004100030@03004102`100<00@40<@43008100@A0@410P002`6g0KL1]a41
4KLA008100Bg4@4A0`40116g0KL20@044KL1]`8100<A0@40J0400`010@020@400@4000<100<00@40
;0400`010@0]0@@000<A0@400P42008100DA004A0@0200034@0000<A0P424@030A4100810Q40104A
0@424@050A410A40JP400`010@020@400@4000<100<00@40;0400`010@0Z0@<010400kL10@020@05
4@010A400P402[L1]`2g4@0A]a420@04]a414@<100@A]`6g0P40116g0KL20@034@4106T100D00@41
00010@000`400`010@0/0@03004102H110070@801`4011410A430@8A0P024@810Q400`4A0@020@8A
00@14@410Q401@4A0@4A06`100@00@400@4000<100<00@40;0400`010@0S0@<030400`010@050@04
4@41]`<10P001040]a420@05]a414KL00P40116g0KL20@074KL10A414@1]0@030041004000030@03
004102`100<00@407`4401H100DA0@414@030@044@010@8A00@14A410a420@8A00@14@410Q420@04
4@414Fd10@010@4000020@03004102d100<00@406`4401X100Fg0@41]`030@0=]a414@4A0A6g0KLA
]`020@044KL1]`8100DA]`414@020@03]`4106/10@010@4000020@03004102d100<00@40604301h1
00DA0@414@030@8000D14@4A0@024@040A4A4@810Q400`4A0@020@044@414@8100<A0@40K0420000
0P400`010@0]0@03004101@1100Q0@04]`410@800P401KL00A41008000`A002g4KL1]a6g0KL30@04
]`414@8100>g0@40K04200000P400`010@0]0@03004101410`0T0@80104010010A420@044@41008A
0P024@060A4A4@4A0`4011410A420@034@4106P110020@000P400`010@0/0@03004100h1100X0@03
004100D100Bg0@4A0`4031400001]`6g4KL1]`<100Bg0@4A0P400kL10@1T0@@01P40008100<00@40
;0400`010@0;0@<0<`401A410@4A00<10Q401@0A0A41008A00<14A400`4011410A420@034@410601
100:0@000P400`010@0/0@03004100L1100f0@054@410A400`403A6g0KL1]`6g4@4A0A400P401;L1
0A420@03]`4105`1100>0@000P400`010@0/0@03004100@10`0j0@054@410A400`4200050A414@40
0Q40104A0A420@044@414@8100<A0@40F044018100020@03004102`100<00@40100m0@044@410@80
0P401A400KL1008000Jg000A0A420@04]`414@<100<A0@40D`4401H100000`400@0]0@@0@04200<1
00DA00414@020@044@4A008A00@04@4A0P4011410A430@034@4104l1100J0@0000<10040:P430003
0@01048100<00@401@4011410KL30@06]a40004A0P401;L10A430@034@4104/1100N0@0000<10040
9P4400@100<00@40B0401A410@4A00<100HA00000A420@8A00<14@400P400a410@170@@08P400003
0@0102<10`080@03004104P100Fg0@41]`030@06]a404@4A0P401;LA0A430@034@4104<1100V0@00
00<100407`4400/100<00@40B0401A410@4A00<10P00104A0A420@8A00<14@400P400a410@0o0@@0
:P4000030@0101`10`0?0@03004104P100Bg0@410P020@06]`014@4A0P401KLA0@6g008100<A0@40
>`4402h100000`400@0H0@@04P400`010@180@064@410A400P401A410A4100@000@A0@4A0P400a41
0@0g0@@0<P4000030@0101D10`0F0@03004104L10P060@054@410A400P400`01000200050KL10A40
=@4403H100000`400@0A0@@06@400`010@180@03004100@100DA0@414@030@8000@1004A0P400a41
0@0_0@@0>P4000030@0100d1100M0@03004104l100DA0@414@040@0500410KL00`400kL10@0Z0@@0
?P400003004100X10`0P0@030041050100DA0@414@030@800`401A410@4A02P110120@0000<00@40
1P4402<100<00@40D04011410@4200<100D00@41]`030@03]`41028110160@0000<00@400`4302L1
00<00@40D0401Q410@4A00H10P030@034@4101h1101:0@0000<00@000`0Z0@03004104l10P0<0@03
00410080704404h1000202h100<00@40D0400`010@0>0@03004101H1101B0@0000<10000;@400`01
0@1f0@@0EP4000<100<00@40:P400`010@1b0@@0FP4000@10P0Z0@03004106h1101N0@001P400`01
0@0W0@03004106X1101R0@001`400`010@0V0@03004106H1101V0@00204202H100<00@40HP4406X1
000:0@03004102<100<00@40GP4406h1000;0@808`400`010@1J0@@0LP4000d100<00@4080400`01
0@1F0@@0MP4000h10P0P0@0300410581101j0@0040400`010@0L0@03004104l1101n0@004@400`01
0@0K0@03004104/110220@004P4201/100<00@40A`4408H1000D0@03004101P100<00@40@`4408X1
000E0@8060400`010@0o0@@0SP4001L100<00@405@400`010@0k0@@0TP4001P10P0E0@03004103L1
102F0@006P400`010@0B0@03004103<1102J0@006`42018100<00@40;`4409h1000M0@03004100l1
00<00@40:`440:81000N0@03004100h100<00@409`440:H1000O0@803P400`010@0S0@@0ZP400241
00<00@402`400`010@0O0@@0[P4002810P0;0@03004101/1102b0@0090400`010@070@03004101P1
102f0@009@4200L100<00@4050440;X1000W0@03004100@100<00@4040440;h1000X0@03004100<1
00<00@4030440<81000Y0@800`400`010@080@@0aP4002/100@00@401P440<X1000/0@<00P440<h1
000^0@<0dP400001\
\>"],
  ImageRangeCache->{{{0, 258.75}, {287, 0}} -> {0.0612859, -0.000623692, 
  0.00346865, 0.00346865}},
  CellTags->"NeonTube"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["See",
          "Input"], 
        StyleBox[" ",
          "Input"], 
        RowBox[{
          StyleBox["also",
            "Input"], 
          StyleBox[":",
            "Input"], "\n", 
          RowBox[{
            ButtonBox["LineOfRays",
              ButtonData:>{"LineOfRays"},
              ButtonStyle->"AddOnsLink"], "   ", 
            ButtonBox["WedgeOfRays",
              ButtonData:>{"WedgeOfRays"},
              ButtonStyle->"AddOnsLink"], "   ", 
            ButtonBox["PointOfRays",
              ButtonData:>{"PointOfRays"},
              ButtonStyle->"AddOnsLink"], "   ", 
            ButtonBox["Move",
              ButtonData:>{"Move"},
              ButtonStyle->"AddOnsLink"]}]}]}], "   "}]], "NotesList",
  GeneratedCell->False,
  CellTags->"NeonTube"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowToolbars->"EditBar",
WindowSize->{858, 594},
WindowMargins->{{174, Automatic}, {Automatic, 65}},
ShowCellTags->True,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "NeonTube"->{
    Cell[1769, 53, 87, 2, 45, "ObjectName",
      CellTags->"NeonTube"],
    Cell[1859, 57, 317, 8, 109, "ExampleText",
      CellTags->"NeonTube"],
    Cell[2179, 67, 173, 6, 46, "ExampleText",
      CellTags->"NeonTube"],
    Cell[2355, 75, 142, 4, 39, "Input",
      CellTags->"NeonTube"],
    Cell[2500, 81, 214, 6, 46, "ExampleText",
      CellTags->"NeonTube"],
    Cell[2717, 89, 191, 7, 39, "Input",
      CellTags->"NeonTube"],
    Cell[2911, 98, 260, 7, 61, "ExampleText",
      CellTags->"NeonTube"],
    Cell[3174, 107, 220, 13, 144, "Input",
      CellTags->"NeonTube"],
    Cell[3397, 122, 150, 3, 46, "ExampleText",
      CellTags->"NeonTube"],
    Cell[3550, 127, 169, 4, 39, "Input",
      CellTags->"NeonTube"],
    Cell[3744, 135, 167, 8, 92, "Input",
      CellTags->"NeonTube"],
    Cell[3914, 145, 53502, 1714, 307, 15262, 1235, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"NeonTube"],
    Cell[57431, 1862, 841, 26, 54, "NotesList",
      CellTags->"NeonTube"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"NeonTube", 58959, 1910}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 35, 0, 38, "SubsectionIcon"],
Cell[1769, 53, 87, 2, 45, "ObjectName",
  CellTags->"NeonTube"],
Cell[1859, 57, 317, 8, 109, "ExampleText",
  CellTags->"NeonTube"],
Cell[2179, 67, 173, 6, 46, "ExampleText",
  CellTags->"NeonTube"],
Cell[2355, 75, 142, 4, 39, "Input",
  CellTags->"NeonTube"],
Cell[2500, 81, 214, 6, 46, "ExampleText",
  CellTags->"NeonTube"],
Cell[2717, 89, 191, 7, 39, "Input",
  CellTags->"NeonTube"],
Cell[2911, 98, 260, 7, 61, "ExampleText",
  CellTags->"NeonTube"],
Cell[3174, 107, 220, 13, 144, "Input",
  CellTags->"NeonTube"],
Cell[3397, 122, 150, 3, 46, "ExampleText",
  CellTags->"NeonTube"],
Cell[3550, 127, 169, 4, 39, "Input",
  CellTags->"NeonTube"],

Cell[CellGroupData[{
Cell[3744, 135, 167, 8, 92, "Input",
  CellTags->"NeonTube"],
Cell[3914, 145, 53502, 1714, 307, 15262, 1235, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"NeonTube"]
}, Open  ]],
Cell[57431, 1862, 841, 26, 54, "NotesList",
  CellTags->"NeonTube"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

